# coding: utf8
from __future__ import unicode_literals

LOOKUP = {
    "ABMs": "ABM",
    "ADACs": "ADAC",
    "AGs": "AG",
    "AKWs": "AKW",
    "ARTEs": "ARTE",
    "AStAs": "AStA",
    "Aachens": "Aachen",
    "Aal": "aalen",
    "Aale": "aalen",
    "Aalen": "Aal",
    "Aalenden": "Aalende",
    "Aalenderen": "Aalendere",
    "Aalendsten": "Aalendste",
    "Aalens": "Aalen",
    "Aales": "Aal",
    "Aalglatten": "Aalglatte",
    "Aalglatteren": "Aalglattere",
    "Aalglattesten": "Aalglatteste",
    "Aalquappen": "Aalquappe",
    "Aals": "Aal",
    "Abarbeitenden": "Abarbeitende",
    "Abarbeitens": "Abarbeiten",
    "Abartigen": "Abartige",
    "Abartigeren": "Abartigere",
    "Abartigsten": "Abartigste",
    "Abbalgenden": "Abbalgende",
    "Abbalgens": "Abbalgen",
    "Abbaubaren": "Abbaubare",
    "Abbaubareren": "Abbaubarere",
    "Abbaubarsten": "Abbaubarste",
    "Abbauenden": "Abbauende",
    "Abbauens": "Abbauen",
    "Abbaus": "Abbau",
    "Abbauten": "abbauen",
    "Abbehaltenden": "Abbehaltende",
    "Abbehaltenen": "Abbehaltene",
    "Abbehaltens": "Abbehalten",
    "Abbeizenden": "Abbeizende",
    "Abbeizens": "Abbeizen",
    "Abbeißenden": "Abbeißende",
    "Abbeißens": "Abbeißen",
    "Abbekommenden": "Abbekommende",
    "Abbekommenen": "Abbekommene",
    "Abbekommens": "Abbekommen",
    "Abberufenden": "Abberufende",
    "Abberufenen": "Abberufene",
    "Abberufens": "Abberufen",
    "Abbestellenden": "Abbestellende",
    "Abbestellens": "Abbestellen",
    "Abbestellte": "abbestellt",
    "Abbestellten": "Abbestellte",
    "Abbetenden": "Abbetende",
    "Abbetens": "Abbeten",
    "Abbettelnden": "Abbettelnde",
    "Abbettelns": "Abbetteln",
    "Abbezahlenden": "Abbezahlende",
    "Abbezahlens": "Abbezahlen",
    "Abbezahlte": "abbezahlt",
    "Abbezahlten": "Abbezahlte",
    "Abbiegenden": "Abbiegende",
    "Abbiegens": "Abbiegen",
    "Abbiegern": "Abbieger",
    "Abbiegers": "Abbieger",
    "Abbilde": "abbilden",
    "Abbildenden": "Abbildende",
    "Abbildens": "Abbilden",
    "Abbilder": "Abbild",
    "Abbildern": "Abbild",
    "Abbildes": "Abbild",
    "Abbilds": "Abbild",
    "Abbildungen": "Abbildung",
    "Abbindenden": "Abbindende",
    "Abbindenderen": "Abbindendere",
    "Abbindendsten": "Abbindendste",
    "Abbindens": "Abbinden",
    "Abbitten": "Abbitte",
    "Abbittenden": "Abbittende",
    "Abbittens": "Abbitten",
    "Abblasenden": "Abblasende",
    "Abblasens": "Abblasen",
    "Abblassenden": "Abblassende",
    "Abblassens": "Abblassen",
    "Abbleibenden": "Abbleibende",
    "Abbleibens": "Abbleiben",
    "Abblendenden": "Abblendende",
    "Abblendens": "Abblenden",
    "Abblendlichte": "Abblendlicht",
    "Abblendlichter": "Abblendlicht",
    "Abblendlichtern": "Abblendlicht",
    "Abblendlichtes": "Abblendlicht",
    "Abblendlichts": "Abblendlicht",
    "Abblitzenden": "Abblitzende",
    "Abblitzenderen": "Abblitzendere",
    "Abblitzendsten": "Abblitzendste",
    "Abblitzens": "Abblitzen",
    "Abblätternden": "Abblätternde",
    "Abblätternderen": "Abblätterndere",
    "Abblätterndsten": "Abblätterndste",
    "Abblätterns": "Abblättern",
    "Abblühenden": "Abblühende",
    "Abblühenderen": "Abblühendere",
    "Abblühendsten": "Abblühendste",
    "Abblühens": "Abblühen",
    "Abbrausenden": "Abbrausende",
    "Abbrausens": "Abbrausen",
    "Abbrechenden": "Abbrechende",
    "Abbrechens": "Abbrechen",
    "Abbremsenden": "Abbremsende",
    "Abbremsens": "Abbremsen",
    "Abbrennenden": "Abbrennende",
    "Abbrennens": "Abbrennen",
    "Abbringenden": "Abbringende",
    "Abbringens": "Abbringen",
    "Abbruche": "Abbruch",
    "Abbruches": "Abbruch",
    "Abbruchreife": "abbruchreif",
    "Abbruchreifen": "Abbruchreife",
    "Abbruchreiferen": "Abbruchreifere",
    "Abbruchreifsten": "Abbruchreifste",
    "Abbruchs": "Abbruch",
    "Abbröckelnden": "Abbröckelnde",
    "Abbröckelnderen": "Abbröckelndere",
    "Abbröckelndsten": "Abbröckelndste",
    "Abbröckelns": "Abbröckeln",
    "Abbrüche": "Abbruch",
    "Abbrüchen": "Abbruch",
    "Abbrühenden": "Abbrühende",
    "Abbrühenderen": "Abbrühendere",
    "Abbrühendsten": "Abbrühendste",
    "Abbrühens": "Abbrühen",
    "Abbuchenden": "Abbuchende",
    "Abbuchens": "Abbuchen",
    "Abbürstenden": "Abbürstende",
    "Abbürstens": "Abbürsten",
    "Abbüßenden": "Abbüßende",
    "Abbüßens": "Abbüßen",
    "Abchasiens": "Abchasien",
    "Abdachenden": "Abdachende",
    "Abdachens": "Abdachen",
    "Abdampfe": "abdampfen",
    "Abdampfenden": "Abdampfende",
    "Abdampfens": "Abdampfen",
    "Abdampfs": "Abdampf",
    "Abdampfturbinen": "Abdampfturbine",
    "Abdankenden": "Abdankende",
    "Abdankens": "Abdanken",
    "Abdankungen": "Abdankung",
    "Abdarbenden": "Abdarbende",
    "Abdarbens": "Abdarben",
    "Abdeckenden": "Abdeckende",
    "Abdeckens": "Abdecken",
    "Abdeckmitteln": "Abdeckmittel",
    "Abdeckmittels": "Abdeckmittel",
    "Abdeckungen": "Abdeckung",
    "Abdichtenden": "Abdichtende",
    "Abdichtens": "Abdichten",
    "Abdienenden": "Abdienende",
    "Abdienens": "Abdienen",
    "Abdingenden": "Abdingende",
    "Abdingens": "Abdingen",
    "Abdizierenden": "Abdizierende",
    "Abdizierens": "Abdizieren",
    "Abdizierte": "abdiziert",
    "Abdizierten": "Abdizierte",
    "Abdrehenden": "Abdrehende",
    "Abdrehenderen": "Abdrehendere",
    "Abdrehendsten": "Abdrehendste",
    "Abdrehens": "Abdrehen",
    "Abdriftenden": "Abdriftende",
    "Abdriftenderen": "Abdriftendere",
    "Abdriftendsten": "Abdriftendste",
    "Abdriftens": "Abdriften",
    "Abdrosselnden": "Abdrosselnde",
    "Abdrosselns": "Abdrosseln",
    "Abdrucke": "abdrucken",
    "Abdruckenden": "Abdruckende",
    "Abdruckens": "Abdrucken",
    "Abdruckes": "Abdruck",
    "Abdrucks": "Abdruck",
    "Abdrängenden": "Abdrängende",
    "Abdrängens": "Abdrängen",
    "Abdrücke": "abdrücken",
    "Abdrücken": "Abdruck",
    "Abdrückende": "abdrückend",
    "Abdrückenden": "Abdrückende",
    "Abdrückens": "Abdrücken",
    "Abduktore": "Abduktor",
    "Abduktoren": "Abduktor",
    "Abduktors": "Abduktor",
    "Abdunkelnden": "Abdunkelnde",
    "Abdunkelnderen": "Abdunkelndere",
    "Abdunkelndsten": "Abdunkelndste",
    "Abdunkelns": "Abdunkeln",
    "Abduschenden": "Abduschende",
    "Abduschens": "Abduschen",
    "Abduzierenden": "Abduzierende",
    "Abduzierens": "Abduzieren",
    "Abduzierte": "abduziert",
    "Abduzierten": "Abduzierte",
    "Abdämmenden": "Abdämmende",
    "Abdämmenderen": "Abdämmendere",
    "Abdämmendsten": "Abdämmendste",
    "Abdämmens": "Abdämmen",
    "Abdämpfe": "Abdampf",
    "Abdämpfen": "Abdampf",
    "Abebbenden": "Abebbende",
    "Abebbenderen": "Abebbendere",
    "Abebbendsten": "Abebbendste",
    "Abebbens": "Abebben",
    "Abende": "Abend",
    "Abenden": "Abend",
    "Abendfüllende": "abendfüllend",
    "Abendfüllenden": "Abendfüllende",
    "Abendlichen": "Abendliche",
    "Abendländischen": "Abendländische",
    "Abenteuerlichen": "Abenteuerliche",
    "Abenteuerlicheren": "Abenteuerlichere",
    "Abenteuerlichsten": "Abenteuerlichste",
    "Abenteuerlustigen": "Abenteuerlustige",
    "Abenteuerlustigeren": "Abenteuerlustigere",
    "Abenteuern": "Abenteuer",
    "Abenteuers": "Abenteuer",
    "Abenteurerinnen": "Abenteurerin",
    "Abergläubische": "abergläubisch",
    "Abergläubischen": "Abergläubische",
    "Abergläubischeren": "Abergläubischere",
    "Abergläubischsten": "Abergläubischste",
    "Aberkannte": "aberkennen",
    "Aberkannten": "aberkennen",
    "Aberkennenden": "Aberkennende",
    "Aberkennens": "Aberkennen",
    "Abermaligen": "Abermalige",
    "Abern": "Aber",
    "Abers": "Aber",
    "Aberwitzige": "aberwitzig",
    "Aberwitzigen": "Aberwitzige",
    "Aberwitzigeren": "Aberwitzigere",
    "Aberwitzigsten": "Aberwitzigste",
    "Abessenden": "Abessende",
    "Abessens": "Abessen",
    "Abfahrenden": "Abfahrende",
    "Abfahrens": "Abfahren",
    "Abfahrten": "Abfahrt",
    "Abfalle": "abfallen",
    "Abfallenden": "Abfallende",
    "Abfallenderen": "Abfallendere",
    "Abfallendsten": "Abfallendste",
    "Abfallens": "Abfallen",
    "Abfalles": "Abfall",
    "Abfalls": "Abfall",
    "Abfangenden": "Abfangende",
    "Abfangens": "Abfangen",
    "Abfassenden": "Abfassende",
    "Abfassens": "Abfassen",
    "Abfedernden": "Abfedernde",
    "Abfedernderen": "Abfederndere",
    "Abfederndsten": "Abfederndste",
    "Abfederns": "Abfedern",
    "Abfeiernden": "Abfeiernde",
    "Abfeiernderen": "Abfeierndere",
    "Abfeierndsten": "Abfeierndste",
    "Abfeierns": "Abfeiern",
    "Abfeilenden": "Abfeilende",
    "Abfeilenderen": "Abfeilendere",
    "Abfeilendsten": "Abfeilendste",
    "Abfeilens": "Abfeilen",
    "Abfertigenden": "Abfertigende",
    "Abfertigens": "Abfertigen",
    "Abfertigungen": "Abfertigung",
    "Abfeuernden": "Abfeuernde",
    "Abfeuerns": "Abfeuern",
    "Abfiebernden": "Abfiebernde",
    "Abfieberns": "Abfiebern",
    "Abfilmenden": "Abfilmende",
    "Abfilmens": "Abfilmen",
    "Abfindenden": "Abfindende",
    "Abfindens": "Abfinden",
    "Abfindungen": "Abfindung",
    "Abfischenden": "Abfischende",
    "Abfischenderen": "Abfischendere",
    "Abfischendsten": "Abfischendste",
    "Abfischens": "Abfischen",
    "Abflachenden": "Abflachende",
    "Abflachenderen": "Abflachendere",
    "Abflachendsten": "Abflachendste",
    "Abflachens": "Abflachen",
    "Abflauenden": "Abflauende",
    "Abflauens": "Abflauen",
    "Abfliegenden": "Abfliegende",
    "Abfliegens": "Abfliegen",
    "Abfließenden": "Abfließende",
    "Abfließens": "Abfließen",
    "Abfluchtenden": "Abfluchtende",
    "Abfluchtens": "Abfluchten",
    "Abflugschneisen": "Abflugschneise",
    "Abflusse": "Abfluß",
    "Abflusses": "Abfluß",
    "Abflüsse": "Abfluß",
    "Abflüssen": "Abfluß",
    "Abfordernden": "Abfordernde",
    "Abfordernderen": "Abforderndere",
    "Abforderndsten": "Abforderndste",
    "Abforderns": "Abfordern",
    "Abformenden": "Abformende",
    "Abformens": "Abformen",
    "Abfragen": "Abfrage",
    "Abfragenden": "Abfragende",
    "Abfragens": "Abfragen",
    "Abfressenden": "Abfressende",
    "Abfressenderen": "Abfressendere",
    "Abfressendsten": "Abfressendste",
    "Abfressens": "Abfressen",
    "Abfrierenden": "Abfrierende",
    "Abfrierenderen": "Abfrierendere",
    "Abfrierendsten": "Abfrierendste",
    "Abfrierens": "Abfrieren",
    "Abfuhren": "Abfuhr",
    "Abfälle": "Abfall",
    "Abfällen": "Abfall",
    "Abfälligen": "Abfällige",
    "Abfälschenden": "Abfälschende",
    "Abfälschens": "Abfälschen",
    "Abfärbenden": "Abfärbende",
    "Abfärbenderen": "Abfärbendere",
    "Abfärbendsten": "Abfärbendste",
    "Abfärbens": "Abfärben",
    "Abführen": "abfahren",
    "Abführenden": "Abführende",
    "Abführens": "Abführen",
    "Abführungen": "Abführung",
    "Abfüllenden": "Abfüllende",
    "Abfüllens": "Abfüllen",
    "Abfütternden": "Abfütternde",
    "Abfütterns": "Abfüttern",
    "Abgaben": "abgeben",
    "Abgabenfreien": "Abgabenfreie",
    "Abgange": "Abgang",
    "Abganges": "Abgang",
    "Abgangs": "Abgang",
    "Abgasarme": "abgasarm",
    "Abgasarmen": "Abgasarme",
    "Abgase": "Abgas",
    "Abgasen": "Abgas",
    "Abgases": "Abgas",
    "Abgasnormen": "Abgasnorm",
    "Abgasturbinen": "Abgasturbine",
    "Abgasärmeren": "Abgasärmere",
    "Abgaunernden": "Abgaunernde",
    "Abgaunerns": "Abgaunern",
    "Abgearbeiteten": "Abgearbeitete",
    "Abgebalgten": "Abgebalgte",
    "Abgebauten": "Abgebaute",
    "Abgebauteren": "Abgebautere",
    "Abgebautesten": "Abgebauteste",
    "Abgebeizten": "Abgebeizte",
    "Abgebenden": "Abgebende",
    "Abgebens": "Abgeben",
    "Abgebetenen": "Abgebetene",
    "Abgebeteten": "Abgebetete",
    "Abgebettelten": "Abgebettelte",
    "Abgebildeten": "Abgebildete",
    "Abgebissenen": "Abgebissene",
    "Abgebisseneren": "Abgebissenere",
    "Abgebissensten": "Abgebissenste",
    "Abgeblasenen": "Abgeblasene",
    "Abgeblaßten": "Abgeblaßte",
    "Abgeblendeten": "Abgeblendete",
    "Abgebliebenen": "Abgebliebene",
    "Abgeblitzten": "Abgeblitzte",
    "Abgeblitzteren": "Abgeblitztere",
    "Abgeblitztesten": "Abgeblitzteste",
    "Abgeblätterten": "Abgeblätterte",
    "Abgeblätterteren": "Abgeblättertere",
    "Abgeblättertesten": "Abgeblätterteste",
    "Abgeblühten": "Abgeblühte",
    "Abgeblühteren": "Abgeblühtere",
    "Abgeblühtesten": "Abgeblühteste",
    "Abgebogenen": "Abgebogene",
    "Abgebrachten": "Abgebrachte",
    "Abgebrannten": "Abgebrannte",
    "Abgebrannteren": "Abgebranntere",
    "Abgebranntesten": "Abgebrannteste",
    "Abgebrausten": "Abgebrauste",
    "Abgebremsten": "Abgebremste",
    "Abgebrochenen": "Abgebrochene",
    "Abgebrocheneren": "Abgebrochenere",
    "Abgebrochensten": "Abgebrochenste",
    "Abgebröckelten": "Abgebröckelte",
    "Abgebröckelteren": "Abgebröckeltere",
    "Abgebröckeltesten": "Abgebröckelteste",
    "Abgebrühten": "Abgebrühte",
    "Abgebrühteren": "Abgebrühtere",
    "Abgebrühtesten": "Abgebrühteste",
    "Abgebuchten": "Abgebuchte",
    "Abgebundenen": "Abgebundene",
    "Abgebundeneren": "Abgebundenere",
    "Abgebundensten": "Abgebundenste",
    "Abgebürsteten": "Abgebürstete",
    "Abgebüßten": "Abgebüßte",
    "Abgedachten": "Abgedachte",
    "Abgedampften": "Abgedampfte",
    "Abgedankten": "Abgedankte",
    "Abgedarbten": "Abgedarbte",
    "Abgedeckten": "Abgedeckte",
    "Abgedichteten": "Abgedichtete",
    "Abgedichteteren": "Abgedichtetere",
    "Abgedichtetesten": "Abgedichteteste",
    "Abgedienten": "Abgediente",
    "Abgedrehten": "Abgedrehte",
    "Abgedrehteren": "Abgedrehtere",
    "Abgedrehtesten": "Abgedrehteste",
    "Abgedrifteten": "Abgedriftete",
    "Abgedrifteteren": "Abgedriftetere",
    "Abgedriftetesten": "Abgedrifteteste",
    "Abgedroschenen": "Abgedroschene",
    "Abgedroscheneren": "Abgedroschenere",
    "Abgedroschensten": "Abgedroschenste",
    "Abgedrosselten": "Abgedrosselte",
    "Abgedruckten": "Abgedruckte",
    "Abgedrängten": "Abgedrängte",
    "Abgedrückte": "abgedrückt",
    "Abgedrückten": "Abgedrückte",
    "Abgedungenen": "Abgedungene",
    "Abgedunkelten": "Abgedunkelte",
    "Abgedunkelteren": "Abgedunkeltere",
    "Abgedunkeltesten": "Abgedunkelteste",
    "Abgeduschten": "Abgeduschte",
    "Abgedämmten": "Abgedämmte",
    "Abgedämmteren": "Abgedämmtere",
    "Abgedämmtesten": "Abgedämmteste",
    "Abgeebbten": "Abgeebbte",
    "Abgeebbteren": "Abgeebbtere",
    "Abgeebbtesten": "Abgeebbteste",
    "Abgefahrenen": "Abgefahrene",
    "Abgefahreneren": "Abgefahrenere",
    "Abgefahrensten": "Abgefahrenste",
    "Abgefallenen": "Abgefallene",
    "Abgefalleneren": "Abgefallenere",
    "Abgefallensten": "Abgefallenste",
    "Abgefangenen": "Abgefangene",
    "Abgefaßten": "Abgefaßte",
    "Abgefederten": "Abgefederte",
    "Abgefederteren": "Abgefedertere",
    "Abgefedertesten": "Abgefederteste",
    "Abgefeierten": "Abgefeierte",
    "Abgefeierteren": "Abgefeiertere",
    "Abgefeiertesten": "Abgefeierteste",
    "Abgefeilten": "Abgefeilte",
    "Abgefeilteren": "Abgefeiltere",
    "Abgefeiltesten": "Abgefeilteste",
    "Abgefertigten": "Abgefertigte",
    "Abgefeuerten": "Abgefeuerte",
    "Abgefieberten": "Abgefieberte",
    "Abgefilmten": "Abgefilmte",
    "Abgefischten": "Abgefischte",
    "Abgefischteren": "Abgefischtere",
    "Abgefischtesten": "Abgefischteste",
    "Abgeflachten": "Abgeflachte",
    "Abgeflachteren": "Abgeflachtere",
    "Abgeflachtesten": "Abgeflachteste",
    "Abgeflauten": "Abgeflaute",
    "Abgeflogenen": "Abgeflogene",
    "Abgeflossenen": "Abgeflossene",
    "Abgeflosseneren": "Abgeflossenere",
    "Abgeflossensten": "Abgeflossenste",
    "Abgefluchteten": "Abgefluchtete",
    "Abgeforderten": "Abgeforderte",
    "Abgeforderteren": "Abgefordertere",
    "Abgefordertesten": "Abgeforderteste",
    "Abgeformten": "Abgeformte",
    "Abgefragten": "Abgefragte",
    "Abgefressenen": "Abgefressene",
    "Abgefresseneren": "Abgefressenere",
    "Abgefressensten": "Abgefressenste",
    "Abgefrorenen": "Abgefrorene",
    "Abgefroreneren": "Abgefrorenere",
    "Abgefrorensten": "Abgefrorenste",
    "Abgefundenen": "Abgefundene",
    "Abgefälschten": "Abgefälschte",
    "Abgefärbten": "Abgefärbte",
    "Abgefärbteren": "Abgefärbtere",
    "Abgefärbtesten": "Abgefärbteste",
    "Abgeführten": "Abgeführte",
    "Abgefüllten": "Abgefüllte",
    "Abgefüllteren": "Abgefülltere",
    "Abgefülltesten": "Abgefüllteste",
    "Abgefütterten": "Abgefütterte",
    "Abgegangenen": "Abgegangene",
    "Abgegaunerten": "Abgegaunerte",
    "Abgegebenen": "Abgegebene",
    "Abgegessenen": "Abgegessene",
    "Abgeglichenen": "Abgeglichene",
    "Abgeglicheneren": "Abgeglichenere",
    "Abgeglichensten": "Abgeglichenste",
    "Abgeglittenen": "Abgeglittene",
    "Abgeglitteneren": "Abgeglittenere",
    "Abgeglittensten": "Abgeglittenste",
    "Abgegoltenen": "Abgegoltene",
    "Abgegossenen": "Abgegossene",
    "Abgegrabenen": "Abgegrabene",
    "Abgegrasten": "Abgegraste",
    "Abgegrasteren": "Abgegrastere",
    "Abgegrastesten": "Abgegrasteste",
    "Abgegrenzten": "Abgegrenzte",
    "Abgegrenzteren": "Abgegrenztere",
    "Abgegrenztesten": "Abgegrenzteste",
    "Abgegriffenen": "Abgegriffene",
    "Abgegriffeneren": "Abgegriffenere",
    "Abgegriffensten": "Abgegriffenste",
    "Abgegrätschten": "Abgegrätschte",
    "Abgegrätschteren": "Abgegrätschtere",
    "Abgegrätschtesten": "Abgegrätschteste",
    "Abgehackten": "Abgehackte",
    "Abgehackteren": "Abgehacktere",
    "Abgehacktesten": "Abgehackteste",
    "Abgehakten": "Abgehakte",
    "Abgehalfterten": "Abgehalfterte",
    "Abgehaltenen": "Abgehaltene",
    "Abgehandelten": "Abgehandelte",
    "Abgehaspelten": "Abgehaspelte",
    "Abgehaspelteren": "Abgehaspeltere",
    "Abgehaspeltesten": "Abgehaspelteste",
    "Abgehauenen": "Abgehauene",
    "Abgehefteten": "Abgeheftete",
    "Abgeheilten": "Abgeheilte",
    "Abgeheilteren": "Abgeheiltere",
    "Abgeheiltesten": "Abgeheilteste",
    "Abgehenden": "Abgehende",
    "Abgehens": "Abgehen",
    "Abgehetzten": "Abgehetzte",
    "Abgehetzteren": "Abgehetztere",
    "Abgehetztesten": "Abgehetzteste",
    "Abgehobelten": "Abgehobelte",
    "Abgehobelteren": "Abgehobeltere",
    "Abgehobeltesten": "Abgehobelteste",
    "Abgehobenen": "Abgehobene",
    "Abgeholfenen": "Abgeholfene",
    "Abgeholten": "Abgeholte",
    "Abgeholzten": "Abgeholzte",
    "Abgeholzteren": "Abgeholztere",
    "Abgeholztesten": "Abgeholzteste",
    "Abgehorchten": "Abgehorchte",
    "Abgehorchteren": "Abgehorchtere",
    "Abgehorchtesten": "Abgehorchteste",
    "Abgehängten": "Abgehängte",
    "Abgehärteten": "Abgehärtete",
    "Abgehärteteren": "Abgehärtetere",
    "Abgehärtetesten": "Abgehärteteste",
    "Abgehäuteten": "Abgehäutete",
    "Abgehörten": "Abgehörte",
    "Abgejagten": "Abgejagte",
    "Abgekanteten": "Abgekantete",
    "Abgekanteteren": "Abgekantetere",
    "Abgekantetesten": "Abgekanteteste",
    "Abgekanzelten": "Abgekanzelte",
    "Abgekanzelteren": "Abgekanzeltere",
    "Abgekanzeltesten": "Abgekanzelteste",
    "Abgekappten": "Abgekappte",
    "Abgekapselten": "Abgekapselte",
    "Abgekapselteren": "Abgekapseltere",
    "Abgekapseltesten": "Abgekapselteste",
    "Abgekarteten": "Abgekartete",
    "Abgekarteteren": "Abgekartetere",
    "Abgekartetesten": "Abgekarteteste",
    "Abgekauften": "Abgekaufte",
    "Abgekehrten": "Abgekehrte",
    "Abgeklapperten": "Abgeklapperte",
    "Abgeklatschten": "Abgeklatschte",
    "Abgeklaubten": "Abgeklaubte",
    "Abgeklaubteren": "Abgeklaubtere",
    "Abgeklaubtesten": "Abgeklaubteste",
    "Abgeklebten": "Abgeklebte",
    "Abgeklemmten": "Abgeklemmte",
    "Abgeklopften": "Abgeklopfte",
    "Abgeklungenen": "Abgeklungene",
    "Abgeklärten": "Abgeklärte",
    "Abgeklärteren": "Abgeklärtere",
    "Abgeklärtesten": "Abgeklärteste",
    "Abgeknabberten": "Abgeknabberte",
    "Abgeknabberteren": "Abgeknabbertere",
    "Abgeknabbertesten": "Abgeknabberteste",
    "Abgeknallten": "Abgeknallte",
    "Abgeknapsten": "Abgeknapste",
    "Abgeknapsteren": "Abgeknapstere",
    "Abgeknapstesten": "Abgeknapsteste",
    "Abgeknickten": "Abgeknickte",
    "Abgekniffenen": "Abgekniffene",
    "Abgekniffeneren": "Abgekniffenere",
    "Abgekniffensten": "Abgekniffenste",
    "Abgeknipsten": "Abgeknipste",
    "Abgeknutschten": "Abgeknutschte",
    "Abgeknutschteren": "Abgeknutschtere",
    "Abgeknutschtesten": "Abgeknutschteste",
    "Abgeknöpften": "Abgeknöpfte",
    "Abgekochten": "Abgekochte",
    "Abgekochteren": "Abgekochtere",
    "Abgekochtesten": "Abgekochteste",
    "Abgekommenen": "Abgekommene",
    "Abgekoppelten": "Abgekoppelte",
    "Abgekotzten": "Abgekotzte",
    "Abgekratzten": "Abgekratzte",
    "Abgekriegten": "Abgekriegte",
    "Abgekuppelten": "Abgekuppelte",
    "Abgekämmten": "Abgekämmte",
    "Abgekämpften": "Abgekämpfte",
    "Abgekämpfteren": "Abgekämpftere",
    "Abgekämpftesten": "Abgekämpfteste",
    "Abgekühlten": "Abgekühlte",
    "Abgekühlteren": "Abgekühltere",
    "Abgekühltesten": "Abgekühlteste",
    "Abgekürzten": "Abgekürzte",
    "Abgeküßten": "Abgeküßte",
    "Abgelachten": "Abgelachte",
    "Abgeladenen": "Abgeladene",
    "Abgelagerten": "Abgelagerte",
    "Abgelassenen": "Abgelassene",
    "Abgelatschten": "Abgelatschte",
    "Abgelatschteren": "Abgelatschtere",
    "Abgelatschtesten": "Abgelatschteste",
    "Abgelaufenen": "Abgelaufene",
    "Abgelauteten": "Abgelautete",
    "Abgelebten": "Abgelebte",
    "Abgelederten": "Abgelederte",
    "Abgelederteren": "Abgeledertere",
    "Abgeledertesten": "Abgelederteste",
    "Abgelegenen": "Abgelegene",
    "Abgelegeneren": "Abgelegenere",
    "Abgelegensten": "Abgelegenste",
    "Abgelegten": "Abgelegte",
    "Abgelehnten": "Abgelehnte",
    "Abgeleisteten": "Abgeleistete",
    "Abgeleiteten": "Abgeleitete",
    "Abgelenkten": "Abgelenkte",
    "Abgelenkteren": "Abgelenktere",
    "Abgelenktesten": "Abgelenkteste",
    "Abgelesenen": "Abgelesene",
    "Abgeleuchteten": "Abgeleuchtete",
    "Abgelichteten": "Abgelichtete",
    "Abgelieferten": "Abgelieferte",
    "Abgeloschenen": "Abgeloschene",
    "Abgeltenden": "Abgeltende",
    "Abgeltens": "Abgelten",
    "Abgelöschten": "Abgelöschte",
    "Abgelösten": "Abgelöste",
    "Abgemachten": "Abgemachte",
    "Abgemagerten": "Abgemagerte",
    "Abgemagerteren": "Abgemagertere",
    "Abgemagertesten": "Abgemagerteste",
    "Abgemalten": "Abgemalte",
    "Abgemeldeten": "Abgemeldete",
    "Abgemessenen": "Abgemessene",
    "Abgemilderten": "Abgemilderte",
    "Abgemurksten": "Abgemurkste",
    "Abgemusterten": "Abgemusterte",
    "Abgemähten": "Abgemähte",
    "Abgemähteren": "Abgemähtere",
    "Abgemähtesten": "Abgemähteste",
    "Abgemühten": "Abgemühte",
    "Abgenabelten": "Abgenabelte",
    "Abgenagten": "Abgenagte",
    "Abgenagteren": "Abgenagtere",
    "Abgenagtesten": "Abgenagteste",
    "Abgeneigten": "Abgeneigte",
    "Abgenommenen": "Abgenommene",
    "Abgenommeneren": "Abgenommenere",
    "Abgenommensten": "Abgenommenste",
    "Abgenutzten": "Abgenutzte",
    "Abgenutzteren": "Abgenutztere",
    "Abgenutztesten": "Abgenutzteste",
    "Abgenähten": "Abgenähte",
    "Abgeordneten": "Abgeordnete",
    "Abgepaßten": "Abgepaßte",
    "Abgepellten": "Abgepellte",
    "Abgepellteren": "Abgepelltere",
    "Abgepelltesten": "Abgepellteste",
    "Abgepfiffenen": "Abgepfiffene",
    "Abgeplatzten": "Abgeplatzte",
    "Abgeplatzteren": "Abgeplatztere",
    "Abgeplatztesten": "Abgeplatzteste",
    "Abgeprallten": "Abgeprallte",
    "Abgepreßten": "Abgepreßte",
    "Abgepumpten": "Abgepumpte",
    "Abgepumpteren": "Abgepumptere",
    "Abgepumptesten": "Abgepumpteste",
    "Abgeputzten": "Abgeputzte",
    "Abgequetschten": "Abgequetschte",
    "Abgequetschteren": "Abgequetschtere",
    "Abgequetschtesten": "Abgequetschteste",
    "Abgequälten": "Abgequälte",
    "Abgequälteren": "Abgequältere",
    "Abgequältesten": "Abgequälteste",
    "Abgeratenen": "Abgeratene",
    "Abgerauschten": "Abgerauschte",
    "Abgerauschteren": "Abgerauschtere",
    "Abgerauschtesten": "Abgerauschteste",
    "Abgerechneten": "Abgerechnete",
    "Abgeregten": "Abgeregte",
    "Abgereichten": "Abgereichte",
    "Abgereisten": "Abgereiste",
    "Abgerichteten": "Abgerichtete",
    "Abgerichteteren": "Abgerichtetere",
    "Abgerichtetesten": "Abgerichteteste",
    "Abgeriebenen": "Abgeriebene",
    "Abgeriebeneren": "Abgeriebenere",
    "Abgeriebensten": "Abgeriebenste",
    "Abgeriegelten": "Abgeriegelte",
    "Abgeriffelten": "Abgeriffelte",
    "Abgerindeten": "Abgerindete",
    "Abgerissenen": "Abgerissene",
    "Abgerisseneren": "Abgerissenere",
    "Abgerissensten": "Abgerissenste",
    "Abgerittenen": "Abgerittene",
    "Abgerodeten": "Abgerodete",
    "Abgerodeteren": "Abgerodetere",
    "Abgerodetesten": "Abgerodeteste",
    "Abgerollten": "Abgerollte",
    "Abgerollteren": "Abgerolltere",
    "Abgerolltesten": "Abgerollteste",
    "Abgeruderten": "Abgeruderte",
    "Abgerufenen": "Abgerufene",
    "Abgerundeten": "Abgerundete",
    "Abgerungenen": "Abgerungene",
    "Abgerupften": "Abgerupfte",
    "Abgerupfteren": "Abgerupftere",
    "Abgerupftesten": "Abgerupfteste",
    "Abgerutschten": "Abgerutschte",
    "Abgeräumten": "Abgeräumte",
    "Abgeräumteren": "Abgeräumtere",
    "Abgeräumtesten": "Abgeräumteste",
    "Abgerückten": "Abgerückte",
    "Abgerührten": "Abgerührte",
    "Abgerüsteten": "Abgerüstete",
    "Abgesagten": "Abgesagte",
    "Abgesahnten": "Abgesahnte",
    "Abgesandten": "Abgesandte",
    "Abgesattelten": "Abgesattelte",
    "Abgesaugten": "Abgesaugte",
    "Abgesaugteren": "Abgesaugtere",
    "Abgesaugtesten": "Abgesaugteste",
    "Abgesausten": "Abgesauste",
    "Abgeschabten": "Abgeschabte",
    "Abgeschabteren": "Abgeschabtere",
    "Abgeschabtesten": "Abgeschabteste",
    "Abgeschafften": "Abgeschaffte",
    "Abgeschalteten": "Abgeschaltete",
    "Abgeschauten": "Abgeschaute",
    "Abgescherten": "Abgescherte",
    "Abgescheuerten": "Abgescheuerte",
    "Abgescheuerteren": "Abgescheuertere",
    "Abgescheuertesten": "Abgescheuerteste",
    "Abgeschiedenen": "Abgeschiedene",
    "Abgeschieferten": "Abgeschieferte",
    "Abgeschirmten": "Abgeschirmte",
    "Abgeschirmteren": "Abgeschirmtere",
    "Abgeschirmtesten": "Abgeschirmteste",
    "Abgeschirrten": "Abgeschirrte",
    "Abgeschlachteten": "Abgeschlachtete",
    "Abgeschlafften": "Abgeschlaffte",
    "Abgeschlaffteren": "Abgeschlafftere",
    "Abgeschlafftesten": "Abgeschlaffteste",
    "Abgeschlagenen": "Abgeschlagene",
    "Abgeschleiften": "Abgeschleifte",
    "Abgeschleifteren": "Abgeschleiftere",
    "Abgeschleiftesten": "Abgeschleifteste",
    "Abgeschleppten": "Abgeschleppte",
    "Abgeschliffenen": "Abgeschliffene",
    "Abgeschlossenen": "Abgeschlossene",
    "Abgeschlämmten": "Abgeschlämmte",
    "Abgeschmatzten": "Abgeschmatzte",
    "Abgeschmatzteren": "Abgeschmatztere",
    "Abgeschmatztesten": "Abgeschmatzteste",
    "Abgeschmeichelten": "Abgeschmeichelte",
    "Abgeschmeichelteren": "Abgeschmeicheltere",
    "Abgeschmetterten": "Abgeschmetterte",
    "Abgeschmierten": "Abgeschmierte",
    "Abgeschminkten": "Abgeschminkte",
    "Abgeschmolzenen": "Abgeschmolzene",
    "Abgeschnallten": "Abgeschnallte",
    "Abgeschnappten": "Abgeschnappte",
    "Abgeschnittenen": "Abgeschnittene",
    "Abgeschnitteneren": "Abgeschnittenere",
    "Abgeschnittensten": "Abgeschnittenste",
    "Abgeschnürten": "Abgeschnürte",
    "Abgeschnürteren": "Abgeschnürtere",
    "Abgeschnürtesten": "Abgeschnürteste",
    "Abgeschobenen": "Abgeschobene",
    "Abgeschorenen": "Abgeschorene",
    "Abgeschossenen": "Abgeschossene",
    "Abgeschraubten": "Abgeschraubte",
    "Abgeschreckten": "Abgeschreckte",
    "Abgeschreckteren": "Abgeschrecktere",
    "Abgeschrecktesten": "Abgeschreckteste",
    "Abgeschriebenen": "Abgeschriebene",
    "Abgeschriebeneren": "Abgeschriebenere",
    "Abgeschriebensten": "Abgeschriebenste",
    "Abgeschrittenen": "Abgeschrittene",
    "Abgeschrockenen": "Abgeschrockene",
    "Abgeschrägten": "Abgeschrägte",
    "Abgeschröpften": "Abgeschröpfte",
    "Abgeschufteten": "Abgeschuftete",
    "Abgeschundenen": "Abgeschundene",
    "Abgeschundeneren": "Abgeschundenere",
    "Abgeschundensten": "Abgeschundenste",
    "Abgeschwatzten": "Abgeschwatzte",
    "Abgeschweiften": "Abgeschweifte",
    "Abgeschweifteren": "Abgeschweiftere",
    "Abgeschweiftesten": "Abgeschweifteste",
    "Abgeschwellten": "Abgeschwellte",
    "Abgeschwenkten": "Abgeschwenkte",
    "Abgeschwindelten": "Abgeschwindelte",
    "Abgeschwirrten": "Abgeschwirrte",
    "Abgeschwollenen": "Abgeschwollene",
    "Abgeschwolleneren": "Abgeschwollenere",
    "Abgeschwollensten": "Abgeschwollenste",
    "Abgeschworenen": "Abgeschworene",
    "Abgeschwungenen": "Abgeschwungene",
    "Abgeschwächten": "Abgeschwächte",
    "Abgeschwächteren": "Abgeschwächtere",
    "Abgeschwächtesten": "Abgeschwächteste",
    "Abgeschälten": "Abgeschälte",
    "Abgeschätzten": "Abgeschätzte",
    "Abgeschäumten": "Abgeschäumte",
    "Abgeschöpften": "Abgeschöpfte",
    "Abgeschürften": "Abgeschürfte",
    "Abgeschürfteren": "Abgeschürftere",
    "Abgeschürftesten": "Abgeschürfteste",
    "Abgeschüttelten": "Abgeschüttelte",
    "Abgesegneten": "Abgesegnete",
    "Abgesehenen": "Abgesehene",
    "Abgeseiften": "Abgeseifte",
    "Abgeseifteren": "Abgeseiftere",
    "Abgeseiftesten": "Abgeseifteste",
    "Abgeseilten": "Abgeseilte",
    "Abgeseilteren": "Abgeseiltere",
    "Abgeseiltesten": "Abgeseilteste",
    "Abgesendeten": "Abgesendete",
    "Abgesengten": "Abgesengte",
    "Abgesengteren": "Abgesengtere",
    "Abgesengtesten": "Abgesengteste",
    "Abgesenkten": "Abgesenkte",
    "Abgesessenen": "Abgesessene",
    "Abgesetzten": "Abgesetzte",
    "Abgesicherten": "Abgesicherte",
    "Abgesicherteren": "Abgesichertere",
    "Abgesichertesten": "Abgesicherteste",
    "Abgesoffenen": "Abgesoffene",
    "Abgesoffeneren": "Abgesoffenere",
    "Abgesoffensten": "Abgesoffenste",
    "Abgesogenen": "Abgesogene",
    "Abgesonderten": "Abgesonderte",
    "Abgespaltenen": "Abgespaltene",
    "Abgespalteneren": "Abgespaltenere",
    "Abgespaltensten": "Abgespaltenste",
    "Abgespannten": "Abgespannte",
    "Abgesparten": "Abgesparte",
    "Abgesparteren": "Abgespartere",
    "Abgespartesten": "Abgesparteste",
    "Abgespeicherten": "Abgespeicherte",
    "Abgespeisten": "Abgespeiste",
    "Abgesperrten": "Abgesperrte",
    "Abgespiegelten": "Abgespiegelte",
    "Abgespielten": "Abgespielte",
    "Abgesplitterten": "Abgesplitterte",
    "Abgespreizten": "Abgespreizte",
    "Abgesprengten": "Abgesprengte",
    "Abgespritzten": "Abgespritzte",
    "Abgesprochenen": "Abgesprochene",
    "Abgesprungenen": "Abgesprungene",
    "Abgesprühten": "Abgesprühte",
    "Abgespulten": "Abgespulte",
    "Abgespülte": "abgespült",
    "Abgespülten": "Abgespülte",
    "Abgestammten": "Abgestammte",
    "Abgestandenen": "Abgestandene",
    "Abgestandeneren": "Abgestandenere",
    "Abgestandensten": "Abgestandenste",
    "Abgestatteten": "Abgestattete",
    "Abgestaubten": "Abgestaubte",
    "Abgestaubteren": "Abgestaubtere",
    "Abgestaubtesten": "Abgestaubteste",
    "Abgesteiften": "Abgesteifte",
    "Abgesteifteren": "Abgesteiftere",
    "Abgesteiftesten": "Abgesteifteste",
    "Abgestellten": "Abgestellte",
    "Abgestempelten": "Abgestempelte",
    "Abgesteppten": "Abgesteppte",
    "Abgesteppteren": "Abgestepptere",
    "Abgestepptesten": "Abgesteppteste",
    "Abgestiegenen": "Abgestiegene",
    "Abgestielten": "Abgestielte",
    "Abgestillten": "Abgestillte",
    "Abgestimmten": "Abgestimmte",
    "Abgestochenen": "Abgestochene",
    "Abgestoppten": "Abgestoppte",
    "Abgestorbenen": "Abgestorbene",
    "Abgestorbeneren": "Abgestorbenere",
    "Abgestorbensten": "Abgestorbenste",
    "Abgestotterten": "Abgestotterte",
    "Abgestoßenen": "Abgestoßene",
    "Abgestraften": "Abgestrafte",
    "Abgestrahlten": "Abgestrahlte",
    "Abgestrampelten": "Abgestrampelte",
    "Abgestrebten": "Abgestrebte",
    "Abgestreiften": "Abgestreifte",
    "Abgestrichenen": "Abgestrichene",
    "Abgestrittenen": "Abgestrittene",
    "Abgeströmten": "Abgeströmte",
    "Abgestuften": "Abgestufte",
    "Abgestumpften": "Abgestumpfte",
    "Abgestumpfteren": "Abgestumpftere",
    "Abgestumpftesten": "Abgestumpfteste",
    "Abgestürzten": "Abgestürzte",
    "Abgestürzteren": "Abgestürztere",
    "Abgestürztesten": "Abgestürzteste",
    "Abgestützten": "Abgestützte",
    "Abgesuchten": "Abgesuchte",
    "Abgesuchteren": "Abgesuchtere",
    "Abgesuchtesten": "Abgesuchteste",
    "Abgesungenen": "Abgesungene",
    "Abgesäbelten": "Abgesäbelte",
    "Abgesägte": "abgesägt",
    "Abgesägten": "Abgesägte",
    "Abgetakelten": "Abgetakelte",
    "Abgetankten": "Abgetankte",
    "Abgetanzten": "Abgetanzte",
    "Abgetanzteren": "Abgetanztere",
    "Abgetanztesten": "Abgetanzteste",
    "Abgetasteten": "Abgetastete",
    "Abgetauchten": "Abgetauchte",
    "Abgetauten": "Abgetaute",
    "Abgeteilten": "Abgeteilte",
    "Abgetippten": "Abgetippte",
    "Abgetragenen": "Abgetragene",
    "Abgetrageneren": "Abgetragenere",
    "Abgetragensten": "Abgetragenste",
    "Abgetrennten": "Abgetrennte",
    "Abgetretenen": "Abgetretene",
    "Abgetriebenen": "Abgetriebene",
    "Abgetrockneten": "Abgetrocknete",
    "Abgetrockneteren": "Abgetrocknetere",
    "Abgetrocknetesten": "Abgetrockneteste",
    "Abgetropften": "Abgetropfte",
    "Abgetrotzten": "Abgetrotzte",
    "Abgetrudelten": "Abgetrudelte",
    "Abgetrunkenen": "Abgetrunkene",
    "Abgeträufelten": "Abgeträufelte",
    "Abgetupften": "Abgetupfte",
    "Abgetönten": "Abgetönte",
    "Abgetöteten": "Abgetötete",
    "Abgeurteilten": "Abgeurteilte",
    "Abgewandelten": "Abgewandelte",
    "Abgewandelteren": "Abgewandeltere",
    "Abgewandeltesten": "Abgewandelteste",
    "Abgewanderten": "Abgewanderte",
    "Abgewarteten": "Abgewartete",
    "Abgewaschenen": "Abgewaschene",
    "Abgewascheneren": "Abgewaschenere",
    "Abgewaschensten": "Abgewaschenste",
    "Abgewechselten": "Abgewechselte",
    "Abgewehrten": "Abgewehrte",
    "Abgeweichten": "Abgeweichte",
    "Abgeweichteren": "Abgeweichtere",
    "Abgeweichtesten": "Abgeweichteste",
    "Abgeweideten": "Abgeweidete",
    "Abgeweideteren": "Abgeweidetere",
    "Abgeweidetesten": "Abgeweideteste",
    "Abgewendeten": "Abgewendete",
    "Abgewerteten": "Abgewertete",
    "Abgewetzten": "Abgewetzte",
    "Abgewetzteren": "Abgewetztere",
    "Abgewetztesten": "Abgewetzteste",
    "Abgewichenen": "Abgewichene",
    "Abgewicheneren": "Abgewichenere",
    "Abgewichensten": "Abgewichenste",
    "Abgewickelten": "Abgewickelte",
    "Abgewickelteren": "Abgewickeltere",
    "Abgewickeltesten": "Abgewickelteste",
    "Abgewiesenen": "Abgewiesene",
    "Abgewimmelten": "Abgewimmelte",
    "Abgewinkten": "Abgewinkte",
    "Abgewinnenden": "Abgewinnende",
    "Abgewinnenderen": "Abgewinnendere",
    "Abgewinnendsten": "Abgewinnendste",
    "Abgewinnens": "Abgewinnen",
    "Abgewirtschafteten": "Abgewirtschaftete",
    "Abgewirtschafteteren": "Abgewirtschaftetere",
    "Abgewischten": "Abgewischte",
    "Abgewogenen": "Abgewogene",
    "Abgewohnten": "Abgewohnte",
    "Abgewohnteren": "Abgewohntere",
    "Abgewohntesten": "Abgewohnteste",
    "Abgewonnenen": "Abgewonnene",
    "Abgewonneneren": "Abgewonnenere",
    "Abgewonnensten": "Abgewonnenste",
    "Abgeworbenen": "Abgeworbene",
    "Abgeworfenen": "Abgeworfene",
    "Abgewrackten": "Abgewrackte",
    "Abgewrackteren": "Abgewracktere",
    "Abgewracktesten": "Abgewrackteste",
    "Abgewundenen": "Abgewundene",
    "Abgewählten": "Abgewählte",
    "Abgewälzten": "Abgewälzte",
    "Abgewälzteren": "Abgewälztere",
    "Abgewälztesten": "Abgewälzteste",
    "Abgewöhnenden": "Abgewöhnende",
    "Abgewöhnens": "Abgewöhnen",
    "Abgewöhnte": "abgewöhnen",
    "Abgewöhnten": "Abgewöhnte",
    "Abgewürgten": "Abgewürgte",
    "Abgewürgteren": "Abgewürgtere",
    "Abgewürgtesten": "Abgewürgteste",
    "Abgezahlten": "Abgezahlte",
    "Abgezapften": "Abgezapfte",
    "Abgezappelten": "Abgezappelte",
    "Abgezappelteren": "Abgezappeltere",
    "Abgezappeltesten": "Abgezappelteste",
    "Abgezeichneten": "Abgezeichnete",
    "Abgezielten": "Abgezielte",
    "Abgezirkelten": "Abgezirkelte",
    "Abgezischten": "Abgezischte",
    "Abgezitterten": "Abgezitterte",
    "Abgezogenen": "Abgezogene",
    "Abgezupften": "Abgezupfte",
    "Abgezweigten": "Abgezweigte",
    "Abgezwitscherten": "Abgezwitscherte",
    "Abgezwungenen": "Abgezwungene",
    "Abgezählte": "abgezählt",
    "Abgezählten": "Abgezählte",
    "Abgezählteren": "Abgezähltere",
    "Abgezähltesten": "Abgezählteste",
    "Abgezäumten": "Abgezäumte",
    "Abgezäumteren": "Abgezäumtere",
    "Abgezäumtesten": "Abgezäumteste",
    "Abgezäunten": "Abgezäunte",
    "Abgeänderten": "Abgeänderte",
    "Abgeänderteren": "Abgeändertere",
    "Abgeändertesten": "Abgeänderteste",
    "Abgeästeten": "Abgeästete",
    "Abgießenden": "Abgießende",
    "Abgießens": "Abgießen",
    "Abgleichenden": "Abgleichende",
    "Abgleichens": "Abgleichen",
    "Abgleitenden": "Abgleitende",
    "Abgleitenderen": "Abgleitendere",
    "Abgleitendsten": "Abgleitendste",
    "Abgleitens": "Abgleiten",
    "Abgotte": "Abgott",
    "Abgottes": "Abgott",
    "Abgotts": "Abgott",
    "Abgrabenden": "Abgrabende",
    "Abgrabens": "Abgraben",
    "Abgrasenden": "Abgrasende",
    "Abgrasenderen": "Abgrasendere",
    "Abgrasendsten": "Abgrasendste",
    "Abgrasens": "Abgrasen",
    "Abgreifenden": "Abgreifende",
    "Abgreifens": "Abgreifen",
    "Abgrenzenden": "Abgrenzende",
    "Abgrenzenderen": "Abgrenzendere",
    "Abgrenzendsten": "Abgrenzendste",
    "Abgrenzens": "Abgrenzen",
    "Abgrunde": "Abgrund",
    "Abgrunds": "Abgrund",
    "Abgrätschenden": "Abgrätschende",
    "Abgrätschenderen": "Abgrätschendere",
    "Abgrätschendsten": "Abgrätschendste",
    "Abgrätschens": "Abgrätschen",
    "Abgründe": "Abgrund",
    "Abgründen": "Abgrund",
    "Abgründige": "abgründig",
    "Abgründigen": "Abgründige",
    "Abgänge": "Abgang",
    "Abgängen": "Abgang",
    "Abgötter": "Abgott",
    "Abgöttern": "Abgott",
    "Abgöttische": "abgöttisch",
    "Abgöttischen": "Abgöttische",
    "Abhackenden": "Abhackende",
    "Abhackenderen": "Abhackendere",
    "Abhackendsten": "Abhackendste",
    "Abhackens": "Abhacken",
    "Abhakenden": "Abhakende",
    "Abhakens": "Abhaken",
    "Abhalfternden": "Abhalfternde",
    "Abhalfterns": "Abhalftern",
    "Abhaltenden": "Abhaltende",
    "Abhaltens": "Abhalten",
    "Abhaltungen": "Abhaltung",
    "Abhandelnden": "Abhandelnde",
    "Abhandelns": "Abhandeln",
    "Abhandlungen": "Abhandlung",
    "Abhaspelnden": "Abhaspelnde",
    "Abhaspelns": "Abhaspeln",
    "Abhauenden": "Abhauende",
    "Abhauens": "Abhauen",
    "Abhebenden": "Abhebende",
    "Abhebens": "Abheben",
    "Abheftenden": "Abheftende",
    "Abheftens": "Abheften",
    "Abheilenden": "Abheilende",
    "Abheilenderen": "Abheilendere",
    "Abheilendsten": "Abheilendste",
    "Abheilens": "Abheilen",
    "Abhelfenden": "Abhelfende",
    "Abhelfens": "Abhelfen",
    "Abhetzenden": "Abhetzende",
    "Abhetzenderen": "Abhetzendere",
    "Abhetzendsten": "Abhetzendste",
    "Abhetzens": "Abhetzen",
    "Abhilfen": "Abhilfe",
    "Abhobelnden": "Abhobelnde",
    "Abhobelnderen": "Abhobelndere",
    "Abhobelndsten": "Abhobelndste",
    "Abhobelns": "Abhobeln",
    "Abholenden": "Abholende",
    "Abholens": "Abholen",
    "Abholern": "Abholer",
    "Abholers": "Abholer",
    "Abholzenden": "Abholzende",
    "Abholzens": "Abholzen",
    "Abholzungen": "Abholzung",
    "Abhorchenden": "Abhorchende",
    "Abhorchenderen": "Abhorchendere",
    "Abhorchendsten": "Abhorchendste",
    "Abhorchens": "Abhorchen",
    "Abhängenden": "Abhängende",
    "Abhängens": "Abhängen",
    "Abhängigen": "Abhängige",
    "Abhängigeren": "Abhängigere",
    "Abhängigkeiten": "Abhängigkeit",
    "Abhängigste": "abhängig",
    "Abhängigsten": "Abhängigste",
    "Abhärtenden": "Abhärtende",
    "Abhärtenderen": "Abhärtendere",
    "Abhärtendsten": "Abhärtendste",
    "Abhärtens": "Abhärten",
    "Abhäutenden": "Abhäutende",
    "Abhäutens": "Abhäuten",
    "Abhörenden": "Abhörende",
    "Abhörens": "Abhören",
    "Abhörgeräte": "Abhörgerät",
    "Abhörgeräten": "Abhörgerät",
    "Abhörgeräts": "Abhörgerät",
    "Abirrungen": "Abirrung",
    "Abis": "Abi",
    "Abisolierzangen": "Abisolierzange",
    "Abiturienten": "Abiturient",
    "Abiturs": "Abitur",
    "Abjagenden": "Abjagende",
    "Abjagens": "Abjagen",
    "Abjudikationen": "Abjudikation",
    "Abkantenden": "Abkantende",
    "Abkantenderen": "Abkantendere",
    "Abkantendsten": "Abkantendste",
    "Abkantens": "Abkanten",
    "Abkanzelnden": "Abkanzelnde",
    "Abkanzelnderen": "Abkanzelndere",
    "Abkanzelndsten": "Abkanzelndste",
    "Abkanzelns": "Abkanzeln",
    "Abkappenden": "Abkappende",
    "Abkappens": "Abkappen",
    "Abkapselnden": "Abkapselnde",
    "Abkapselnderen": "Abkapselndere",
    "Abkapselndsten": "Abkapselndste",
    "Abkapselns": "Abkapseln",
    "Abkartenden": "Abkartende",
    "Abkartenderen": "Abkartendere",
    "Abkartendsten": "Abkartendste",
    "Abkartens": "Abkarten",
    "Abkassierenden": "Abkassierende",
    "Abkassierenderen": "Abkassierendere",
    "Abkassierendsten": "Abkassierendste",
    "Abkassierens": "Abkassieren",
    "Abkassierte": "abkassiert",
    "Abkassierten": "Abkassierte",
    "Abkassierteren": "Abkassiertere",
    "Abkassiertesten": "Abkassierteste",
    "Abkaufenden": "Abkaufende",
    "Abkaufens": "Abkaufen",
    "Abkehrenden": "Abkehrende",
    "Abkehrens": "Abkehren",
    "Abklappernden": "Abklappernde",
    "Abklapperns": "Abklappern",
    "Abklatschenden": "Abklatschende",
    "Abklatschens": "Abklatschen",
    "Abklaubenden": "Abklaubende",
    "Abklaubenderen": "Abklaubendere",
    "Abklaubendsten": "Abklaubendste",
    "Abklaubens": "Abklauben",
    "Abklebenden": "Abklebende",
    "Abklebens": "Abkleben",
    "Abklemmenden": "Abklemmende",
    "Abklemmens": "Abklemmen",
    "Abklingenden": "Abklingende",
    "Abklingens": "Abklingen",
    "Abklopfenden": "Abklopfende",
    "Abklopfens": "Abklopfen",
    "Abklärenden": "Abklärende",
    "Abklärens": "Abklären",
    "Abknabbernden": "Abknabbernde",
    "Abknabbernderen": "Abknabberndere",
    "Abknabberndsten": "Abknabberndste",
    "Abknabberns": "Abknabbern",
    "Abknallenden": "Abknallende",
    "Abknallens": "Abknallen",
    "Abknapsenden": "Abknapsende",
    "Abknapsenderen": "Abknapsendere",
    "Abknapsendsten": "Abknapsendste",
    "Abknapsens": "Abknapsen",
    "Abkneifenden": "Abkneifende",
    "Abkneifens": "Abkneifen",
    "Abknickenden": "Abknickende",
    "Abknickens": "Abknicken",
    "Abknipsenden": "Abknipsende",
    "Abknipsens": "Abknipsen",
    "Abknutschenden": "Abknutschende",
    "Abknutschenderen": "Abknutschendere",
    "Abknutschendsten": "Abknutschendste",
    "Abknutschens": "Abknutschen",
    "Abknöpfenden": "Abknöpfende",
    "Abknöpfens": "Abknöpfen",
    "Abkochenden": "Abkochende",
    "Abkochenderen": "Abkochendere",
    "Abkochendsten": "Abkochendste",
    "Abkochens": "Abkochen",
    "Abkochungen": "Abkochung",
    "Abkommandierenden": "Abkommandierende",
    "Abkommandierens": "Abkommandieren",
    "Abkommandierte": "abkommandiert",
    "Abkommandierten": "Abkommandierte",
    "Abkommandierungen": "Abkommandierung",
    "Abkomme": "abkommen",
    "Abkommen": "Abkomme",
    "Abkommenden": "Abkommende",
    "Abkommens": "Abkommen",
    "Abkoppelnden": "Abkoppelnde",
    "Abkoppelns": "Abkoppeln",
    "Abkotzenden": "Abkotzende",
    "Abkotzens": "Abkotzen",
    "Abkratzenden": "Abkratzende",
    "Abkratzens": "Abkratzen",
    "Abkriegenden": "Abkriegende",
    "Abkriegens": "Abkriegen",
    "Abkuppelnden": "Abkuppelnde",
    "Abkuppelns": "Abkuppeln",
    "Abkämmenden": "Abkämmende",
    "Abkämmens": "Abkämmen",
    "Abkämpfenden": "Abkämpfende",
    "Abkämpfenderen": "Abkämpfendere",
    "Abkämpfendsten": "Abkämpfendste",
    "Abkämpfens": "Abkämpfen",
    "Abkömmlichen": "Abkömmliche",
    "Abkömmlicheren": "Abkömmlichere",
    "Abkömmlichsten": "Abkömmlichste",
    "Abkühlenden": "Abkühlende",
    "Abkühlenderen": "Abkühlendere",
    "Abkühlendsten": "Abkühlendste",
    "Abkühlens": "Abkühlen",
    "Abkürzenden": "Abkürzende",
    "Abkürzens": "Abkürzen",
    "Abkürzungen": "Abkürzung",
    "Abküssenden": "Abküssende",
    "Abküssens": "Abküssen",
    "Ablachenden": "Ablachende",
    "Ablachens": "Ablachen",
    "Abladenden": "Abladende",
    "Abladens": "Abladen",
    "Ablagen": "Ablage",
    "Ablagernden": "Ablagernde",
    "Ablagerns": "Ablagern",
    "Ablaktierenden": "Ablaktierende",
    "Ablaktierens": "Ablaktieren",
    "Ablaktierte": "ablaktiert",
    "Ablaktierten": "Ablaktierte",
    "Ablassenden": "Ablassende",
    "Ablassens": "Ablassen",
    "Ablative": "Ablativ",
    "Ablativen": "Ablativ",
    "Ablativs": "Ablativ",
    "Ablatschenden": "Ablatschende",
    "Ablatschenderen": "Ablatschendere",
    "Ablatschendsten": "Ablatschendste",
    "Ablatschens": "Ablatschen",
    "Ablaufe": "ablaufen",
    "Ablaufenden": "Ablaufende",
    "Ablaufens": "Ablaufen",
    "Ablaufes": "Ablauf",
    "Ablaufs": "Ablauf",
    "Ablautenden": "Ablautende",
    "Ablautens": "Ablauten",
    "Ablaßbriefe": "Ablaßbrief",
    "Ablaßbriefen": "Ablaßbrief",
    "Ablaßbriefs": "Ablaßbrief",
    "Ablebenden": "Ablebende",
    "Ablebens": "Ableben",
    "Abledernden": "Abledernde",
    "Abledernderen": "Ablederndere",
    "Ablederndsten": "Ablederndste",
    "Ablederns": "Abledern",
    "Ablegenden": "Ablegende",
    "Ablegens": "Ablegen",
    "Ablegern": "Ableger",
    "Ablegers": "Ableger",
    "Ablehnenden": "Ablehnende",
    "Ablehnenderen": "Ablehnendere",
    "Ablehnendsten": "Ablehnendste",
    "Ablehnens": "Ablehnen",
    "Ablehnungen": "Ablehnung",
    "Ableistenden": "Ableistende",
    "Ableistens": "Ableisten",
    "Ableitbaren": "Ableitbare",
    "Ableitenden": "Ableitende",
    "Ableitens": "Ableiten",
    "Ablenkenden": "Ablenkende",
    "Ablenkenderen": "Ablenkendere",
    "Ablenkendsten": "Ablenkendste",
    "Ablenkens": "Ablenken",
    "Ablenkungen": "Ablenkung",
    "Ablesenden": "Ablesende",
    "Ablesens": "Ablesen",
    "Ableuchtenden": "Ableuchtende",
    "Ableuchtens": "Ableuchten",
    "Ablichtenden": "Ablichtende",
    "Ablichtens": "Ablichten",
    "Ablichtungen": "Ablichtung",
    "Abliefernden": "Abliefernde",
    "Ablieferns": "Abliefern",
    "Abläufe": "Ablauf",
    "Abläufen": "Ablauf",
    "Ablöschenden": "Ablöschende",
    "Ablöschens": "Ablöschen",
    "Ablösen": "Ablöse",
    "Ablösenden": "Ablösende",
    "Ablösens": "Ablösen",
    "Ablösesummen": "Ablösesumme",
    "Abmachenden": "Abmachende",
    "Abmachens": "Abmachen",
    "Abmachungen": "Abmachung",
    "Abmagernden": "Abmagernde",
    "Abmagernderen": "Abmagerndere",
    "Abmagerndsten": "Abmagerndste",
    "Abmagerns": "Abmagern",
    "Abmalenden": "Abmalende",
    "Abmalens": "Abmalen",
    "Abmarschierenden": "Abmarschierende",
    "Abmarschierens": "Abmarschieren",
    "Abmarschierte": "abmarschiert",
    "Abmarschierten": "Abmarschierte",
    "Abmarschs": "Abmarsch",
    "Abmeldenden": "Abmeldende",
    "Abmeldens": "Abmelden",
    "Abmeldungen": "Abmeldung",
    "Abmessenden": "Abmessende",
    "Abmessens": "Abmessen",
    "Abmessungen": "Abmessung",
    "Abmildernden": "Abmildernde",
    "Abmilderns": "Abmildern",
    "Abmontierenden": "Abmontierende",
    "Abmontierens": "Abmontieren",
    "Abmontierte": "abmontiert",
    "Abmontierten": "Abmontierte",
    "Abmurksenden": "Abmurksende",
    "Abmurksens": "Abmurksen",
    "Abmusternden": "Abmusternde",
    "Abmusterns": "Abmustern",
    "Abmähenden": "Abmähende",
    "Abmähenderen": "Abmähendere",
    "Abmähendsten": "Abmähendste",
    "Abmähens": "Abmähen",
    "Abmühenden": "Abmühende",
    "Abmühens": "Abmühen",
    "Abnabelnden": "Abnabelnde",
    "Abnabelns": "Abnabeln",
    "Abnagenden": "Abnagende",
    "Abnagenderen": "Abnagendere",
    "Abnagendsten": "Abnagendste",
    "Abnagens": "Abnagen",
    "Abnehmbaren": "Abnehmbare",
    "Abnehmenden": "Abnehmende",
    "Abnehmens": "Abnehmen",
    "Abnehmern": "Abnehmer",
    "Abnehmers": "Abnehmer",
    "Abneigenden": "Abneigende",
    "Abneigens": "Abneigen",
    "Abneigungen": "Abneigung",
    "Abnormalen": "Abnormale",
    "Abnormen": "Abnorme",
    "Abnutzenden": "Abnutzende",
    "Abnutzens": "Abnutzen",
    "Abnähenden": "Abnähende",
    "Abnähens": "Abnähen",
    "Abonnements": "Abonnement",
    "Abonnierenden": "Abonnierende",
    "Abonnierenderen": "Abonnierendere",
    "Abonnierendsten": "Abonnierendste",
    "Abonnierens": "Abonnieren",
    "Abonnierte": "abonniert",
    "Abonnierten": "Abonnierte",
    "Abordnenden": "Abordnende",
    "Abordnens": "Abordnen",
    "Abordnungen": "Abordnung",
    "Aborte": "Abort",
    "Aborten": "Abort",
    "Aborts": "Abort",
    "Abpassenden": "Abpassende",
    "Abpassens": "Abpassen",
    "Abpellenden": "Abpellende",
    "Abpellenderen": "Abpellendere",
    "Abpellendsten": "Abpellendste",
    "Abpellens": "Abpellen",
    "Abpfeifenden": "Abpfeifende",
    "Abpfeifens": "Abpfeifen",
    "Abplatzenden": "Abplatzende",
    "Abplatzenderen": "Abplatzendere",
    "Abplatzendsten": "Abplatzendste",
    "Abplatzens": "Abplatzen",
    "Abprallenden": "Abprallende",
    "Abprallens": "Abprallen",
    "Abpressenden": "Abpressende",
    "Abpressens": "Abpressen",
    "Abpumpenden": "Abpumpende",
    "Abpumpenderen": "Abpumpendere",
    "Abpumpendsten": "Abpumpendste",
    "Abpumpens": "Abpumpen",
    "Abputzenden": "Abputzende",
    "Abputzens": "Abputzen",
    "Abqualifizierenden": "Abqualifizierende",
    "Abqualifizierenderen": "Abqualifizierendere",
    "Abqualifizierens": "Abqualifizieren",
    "Abqualifizierte": "abqualifiziert",
    "Abqualifizierten": "Abqualifizierte",
    "Abqualifizierteren": "Abqualifiziertere",
    "Abquetschenden": "Abquetschende",
    "Abquetschenderen": "Abquetschendere",
    "Abquetschendsten": "Abquetschendste",
    "Abquetschens": "Abquetschen",
    "Abquälenden": "Abquälende",
    "Abquälenderen": "Abquälendere",
    "Abquälendsten": "Abquälendste",
    "Abquälens": "Abquälen",
    "Abrahams": "Abraham",
    "Abrakadabras": "Abrakadabra",
    "Abrasierenden": "Abrasierende",
    "Abrasierens": "Abrasieren",
    "Abrasierte": "abrasiert",
    "Abrasierten": "Abrasierte",
    "Abratenden": "Abratende",
    "Abratens": "Abraten",
    "Abrauschenden": "Abrauschende",
    "Abrauschenderen": "Abrauschendere",
    "Abrauschendsten": "Abrauschendste",
    "Abrauschens": "Abrauschen",
    "Abreagierenden": "Abreagierende",
    "Abreagierenderen": "Abreagierendere",
    "Abreagierendsten": "Abreagierendste",
    "Abreagierens": "Abreagieren",
    "Abreagierte": "abreagiert",
    "Abreagierten": "Abreagierte",
    "Abreagierteren": "Abreagiertere",
    "Abreagiertesten": "Abreagierteste",
    "Abreaktionen": "Abreaktion",
    "Abrechnenden": "Abrechnende",
    "Abrechnens": "Abrechnen",
    "Abrechnungen": "Abrechnung",
    "Abreden": "Abrede",
    "Abregenden": "Abregende",
    "Abregens": "Abregen",
    "Abreibenden": "Abreibende",
    "Abreibenderen": "Abreibendere",
    "Abreibendsten": "Abreibendste",
    "Abreibens": "Abreiben",
    "Abreibungen": "Abreibung",
    "Abreichenden": "Abreichende",
    "Abreichens": "Abreichen",
    "Abreisenden": "Abreisende",
    "Abreisens": "Abreisen",
    "Abreitenden": "Abreitende",
    "Abreitens": "Abreiten",
    "Abreißenden": "Abreißende",
    "Abreißens": "Abreißen",
    "Abreißkalendern": "Abreißkalender",
    "Abreißkalenders": "Abreißkalender",
    "Abrichtenden": "Abrichtende",
    "Abrichtens": "Abrichten",
    "Abrichtern": "Abrichter",
    "Abrichters": "Abrichter",
    "Abriebfesten": "Abriebfeste",
    "Abriebfesteren": "Abriebfestere",
    "Abriebfestesten": "Abriebfesteste",
    "Abriegelnden": "Abriegelnde",
    "Abriegelns": "Abriegeln",
    "Abriffelnden": "Abriffelnde",
    "Abriffelns": "Abriffeln",
    "Abrindenden": "Abrindende",
    "Abrindens": "Abrinden",
    "Abringenden": "Abringende",
    "Abringens": "Abringen",
    "Abrodenden": "Abrodende",
    "Abrodenderen": "Abrodendere",
    "Abrodendsten": "Abrodendste",
    "Abrodens": "Abroden",
    "Abrollenden": "Abrollende",
    "Abrollenderen": "Abrollendere",
    "Abrollendsten": "Abrollendste",
    "Abrollens": "Abrollen",
    "Abrudernden": "Abrudernde",
    "Abruderns": "Abrudern",
    "Abrufenden": "Abrufende",
    "Abrufens": "Abrufen",
    "Abrufs": "Abruf",
    "Abrundenden": "Abrundende",
    "Abrundens": "Abrunden",
    "Abrupfenden": "Abrupfende",
    "Abrupfenderen": "Abrupfendere",
    "Abrupfendsten": "Abrupfendste",
    "Abrupfens": "Abrupfen",
    "Abrupten": "Abrupte",
    "Abrupteren": "Abruptere",
    "Abruptesten": "Abrupteste",
    "Abrutschenden": "Abrutschende",
    "Abrutschens": "Abrutschen",
    "Abräumenden": "Abräumende",
    "Abräumenderen": "Abräumendere",
    "Abräumendsten": "Abräumendste",
    "Abräumens": "Abräumen",
    "Abrückenden": "Abrückende",
    "Abrückens": "Abrücken",
    "Abrührenden": "Abrührende",
    "Abrührens": "Abrühren",
    "Abrüstenden": "Abrüstende",
    "Abrüstens": "Abrüsten",
    "Absagenden": "Absagende",
    "Absagens": "Absagen",
    "Absahnenden": "Absahnende",
    "Absahnens": "Absahnen",
    "Absattelnden": "Absattelnde",
    "Absattelns": "Absatteln",
    "Absatze": "Absatz",
    "Absatzes": "Absatz",
    "Absatzfähige": "absatzfähig",
    "Absatzfähigen": "Absatzfähige",
    "Absatzfähigeren": "Absatzfähigere",
    "Absatzfähigsten": "Absatzfähigste",
    "Absatzquoten": "Absatzquote",
    "Absaufenden": "Absaufende",
    "Absaufens": "Absaufen",
    "Absaugenden": "Absaugende",
    "Absaugens": "Absaugen",
    "Absausenden": "Absausende",
    "Absausens": "Absausen",
    "Abschabenden": "Abschabende",
    "Abschabenderen": "Abschabendere",
    "Abschabendsten": "Abschabendste",
    "Abschabens": "Abschaben",
    "Abschaffenden": "Abschaffende",
    "Abschaffens": "Abschaffen",
    "Abschaffungen": "Abschaffung",
    "Abschaltenden": "Abschaltende",
    "Abschaltens": "Abschalten",
    "Abschauenden": "Abschauende",
    "Abschauens": "Abschauen",
    "Abschaums": "Abschaum",
    "Abscheidenden": "Abscheidende",
    "Abscheidens": "Abscheiden",
    "Abscheidern": "Abscheider",
    "Abscheiders": "Abscheider",
    "Abscherenden": "Abscherende",
    "Abscherens": "Abscheren",
    "Abscherungen": "Abscherung",
    "Abscheuernden": "Abscheuernde",
    "Abscheuernderen": "Abscheuerndere",
    "Abscheuerndsten": "Abscheuerndste",
    "Abscheuerns": "Abscheuern",
    "Abscheulichen": "Abscheuliche",
    "Abscheulicheren": "Abscheulichere",
    "Abscheulichsten": "Abscheulichste",
    "Abscheus": "Abscheu",
    "Abschiebenden": "Abschiebende",
    "Abschiebens": "Abschieben",
    "Abschiebungen": "Abschiebung",
    "Abschied": "abscheiden",
    "Abschiede": "Abschied",
    "Abschieden": "Abschied",
    "Abschieds": "Abschied",
    "Abschiefernden": "Abschiefernde",
    "Abschieferns": "Abschiefern",
    "Abschießenden": "Abschießende",
    "Abschießens": "Abschießen",
    "Abschindenden": "Abschindende",
    "Abschindenderen": "Abschindendere",
    "Abschindendsten": "Abschindendste",
    "Abschindens": "Abschinden",
    "Abschirmenden": "Abschirmende",
    "Abschirmenderen": "Abschirmendere",
    "Abschirmendsten": "Abschirmendste",
    "Abschirmens": "Abschirmen",
    "Abschirrenden": "Abschirrende",
    "Abschirrens": "Abschirren",
    "Abschlachtenden": "Abschlachtende",
    "Abschlachtens": "Abschlachten",
    "Abschlaffenden": "Abschlaffende",
    "Abschlaffenderen": "Abschlaffendere",
    "Abschlaffendsten": "Abschlaffendste",
    "Abschlaffens": "Abschlaffen",
    "Abschlage": "abschlagen",
    "Abschlagenden": "Abschlagende",
    "Abschlagens": "Abschlagen",
    "Abschlages": "Abschlag",
    "Abschlags": "Abschlag",
    "Abschleifenden": "Abschleifende",
    "Abschleifenderen": "Abschleifendere",
    "Abschleifendsten": "Abschleifendste",
    "Abschleifens": "Abschleifen",
    "Abschleppenden": "Abschleppende",
    "Abschleppens": "Abschleppen",
    "Abschließenden": "Abschließende",
    "Abschließens": "Abschließen",
    "Abschlusse": "Abschluß",
    "Abschlusses": "Abschluß",
    "Abschläge": "Abschlag",
    "Abschlägen": "Abschlag",
    "Abschlämmenden": "Abschlämmende",
    "Abschlämmens": "Abschlämmen",
    "Abschlüsse": "Abschluß",
    "Abschlüssen": "Abschluß",
    "Abschmatzenden": "Abschmatzende",
    "Abschmatzenderen": "Abschmatzendere",
    "Abschmatzendsten": "Abschmatzendste",
    "Abschmatzens": "Abschmatzen",
    "Abschmeichelnden": "Abschmeichelnde",
    "Abschmeichelnderen": "Abschmeichelndere",
    "Abschmeichelns": "Abschmeicheln",
    "Abschmelzenden": "Abschmelzende",
    "Abschmelzens": "Abschmelzen",
    "Abschmetternden": "Abschmetternde",
    "Abschmetterns": "Abschmettern",
    "Abschmierenden": "Abschmierende",
    "Abschmierens": "Abschmieren",
    "Abschminkenden": "Abschminkende",
    "Abschminkens": "Abschminken",
    "Abschnallenden": "Abschnallende",
    "Abschnallens": "Abschnallen",
    "Abschnappenden": "Abschnappende",
    "Abschnappens": "Abschnappen",
    "Abschneidenden": "Abschneidende",
    "Abschneidens": "Abschneiden",
    "Abschnitte": "Abschnitt",
    "Abschnitten": "Abschnitt",
    "Abschnittes": "Abschnitt",
    "Abschnitts": "Abschnitt",
    "Abschnürenden": "Abschnürende",
    "Abschnürenderen": "Abschnürendere",
    "Abschnürendsten": "Abschnürendste",
    "Abschnürens": "Abschnüren",
    "Abschnürungen": "Abschnürung",
    "Abschraubenden": "Abschraubende",
    "Abschraubens": "Abschrauben",
    "Abschreckenden": "Abschreckende",
    "Abschreckenderen": "Abschreckendere",
    "Abschreckendsten": "Abschreckendste",
    "Abschreckens": "Abschrecken",
    "Abschreibenden": "Abschreibende",
    "Abschreibens": "Abschreiben",
    "Abschreibungen": "Abschreibung",
    "Abschreitenden": "Abschreitende",
    "Abschreitens": "Abschreiten",
    "Abschriften": "Abschrift",
    "Abschrägenden": "Abschrägende",
    "Abschrägens": "Abschrägen",
    "Abschrägungen": "Abschrägung",
    "Abschröpfenden": "Abschröpfende",
    "Abschröpfens": "Abschröpfen",
    "Abschuftenden": "Abschuftende",
    "Abschuftenderen": "Abschuftendere",
    "Abschuftendsten": "Abschuftendste",
    "Abschuftens": "Abschuften",
    "Abschußlisten": "Abschußliste",
    "Abschußrampen": "Abschußrampe",
    "Abschwatzenden": "Abschwatzende",
    "Abschwatzenderen": "Abschwatzendere",
    "Abschwatzendsten": "Abschwatzendste",
    "Abschwatzens": "Abschwatzen",
    "Abschweifenden": "Abschweifende",
    "Abschweifenderen": "Abschweifendere",
    "Abschweifendsten": "Abschweifendste",
    "Abschweifens": "Abschweifen",
    "Abschweifungen": "Abschweifung",
    "Abschwellenden": "Abschwellende",
    "Abschwellenderen": "Abschwellendere",
    "Abschwellendsten": "Abschwellendste",
    "Abschwellens": "Abschwellen",
    "Abschwenkenden": "Abschwenkende",
    "Abschwenkens": "Abschwenken",
    "Abschwindelnden": "Abschwindelnde",
    "Abschwindelns": "Abschwindeln",
    "Abschwingenden": "Abschwingende",
    "Abschwingens": "Abschwingen",
    "Abschwirrenden": "Abschwirrende",
    "Abschwirrens": "Abschwirren",
    "Abschwunge": "Abschwung",
    "Abschwungs": "Abschwung",
    "Abschwächenden": "Abschwächende",
    "Abschwächenderen": "Abschwächendere",
    "Abschwächendsten": "Abschwächendste",
    "Abschwächens": "Abschwächen",
    "Abschwächern": "Abschwächer",
    "Abschwächers": "Abschwächer",
    "Abschwächungen": "Abschwächung",
    "Abschwörenden": "Abschwörende",
    "Abschwörens": "Abschwören",
    "Abschwünge": "Abschwung",
    "Abschwüngen": "Abschwung",
    "Abschälenden": "Abschälende",
    "Abschälens": "Abschälen",
    "Abschätzenden": "Abschätzende",
    "Abschätzens": "Abschätzen",
    "Abschäumenden": "Abschäumende",
    "Abschäumens": "Abschäumen",
    "Abschöpfenden": "Abschöpfende",
    "Abschöpfens": "Abschöpfen",
    "Abschürfenden": "Abschürfende",
    "Abschürfenderen": "Abschürfendere",
    "Abschürfendsten": "Abschürfendste",
    "Abschürfens": "Abschürfen",
    "Abschürfungen": "Abschürfung",
    "Abschüssige": "abschüssig",
    "Abschüssigen": "Abschüssige",
    "Abschüssigeren": "Abschüssigere",
    "Abschüssigsten": "Abschüssigste",
    "Abschüttelnden": "Abschüttelnde",
    "Abschüttelns": "Abschütteln",
    "Absegnenden": "Absegnende",
    "Absegnens": "Absegnen",
    "Absehbaren": "Absehbare",
    "Absehenden": "Absehende",
    "Absehens": "Absehen",
    "Abseifenden": "Abseifende",
    "Abseifenderen": "Abseifendere",
    "Abseifendsten": "Abseifendste",
    "Abseifens": "Abseifen",
    "Abseilenden": "Abseilende",
    "Abseilenderen": "Abseilendere",
    "Abseilendsten": "Abseilendste",
    "Abseilens": "Abseilen",
    "Abseiten": "Abseite",
    "Absendenden": "Absendende",
    "Absendens": "Absenden",
    "Absengenden": "Absengende",
    "Absengenderen": "Absengendere",
    "Absengendsten": "Absengendste",
    "Absengens": "Absengen",
    "Absenkenden": "Absenkende",
    "Absenkens": "Absenken",
    "Absenkern": "Absenker",
    "Absenkers": "Absenker",
    "Absetzenden": "Absetzende",
    "Absetzens": "Absetzen",
    "Absichernden": "Absichernde",
    "Absichernderen": "Absicherndere",
    "Absicherndsten": "Absicherndste",
    "Absicherns": "Absichern",
    "Absicherungen": "Absicherung",
    "Absichten": "Absicht",
    "Absingenden": "Absingende",
    "Absingens": "Absingen",
    "Absitzenden": "Absitzende",
    "Absitzens": "Absitzen",
    "Absoluten": "Absolute",
    "Absolutionen": "Absolution",
    "Absolutistische": "absolutistisch",
    "Absolutistischen": "Absolutistische",
    "Absolutistischeren": "Absolutistischere",
    "Absolvierenden": "Absolvierende",
    "Absolvierens": "Absolvieren",
    "Absolvierte": "absolviert",
    "Absolvierten": "Absolvierte",
    "Absonderlichen": "Absonderliche",
    "Absonderlicheren": "Absonderlichere",
    "Absonderlichkeiten": "Absonderlichkeit",
    "Absonderlichste": "absonderlich",
    "Absonderlichsten": "Absonderlichste",
    "Absondernden": "Absondernde",
    "Absonderns": "Absondern",
    "Absonderungen": "Absonderung",
    "Absorbern": "Absorber",
    "Absorbers": "Absorber",
    "Absorbierenden": "Absorbierende",
    "Absorbierenderen": "Absorbierendere",
    "Absorbierendsten": "Absorbierendste",
    "Absorbierens": "Absorbieren",
    "Absorbierte": "absorbiert",
    "Absorbierten": "Absorbierte",
    "Absorbierteren": "Absorbiertere",
    "Absorbiertesten": "Absorbierteste",
    "Absorptionen": "Absorption",
    "Absorptionsanalysen": "Absorptionsanalyse",
    "Absorptionskanten": "Absorptionskante",
    "Abspaltenden": "Abspaltende",
    "Abspaltenderen": "Abspaltendere",
    "Abspaltendsten": "Abspaltendste",
    "Abspaltens": "Abspalten",
    "Abspannenden": "Abspannende",
    "Abspannens": "Abspannen",
    "Absparenden": "Absparende",
    "Absparenderen": "Absparendere",
    "Absparendsten": "Absparendste",
    "Absparens": "Absparen",
    "Abspeichernden": "Abspeichernde",
    "Abspeicherns": "Abspeichern",
    "Abspeisenden": "Abspeisende",
    "Abspeisens": "Abspeisen",
    "Abspenstigen": "Abspenstige",
    "Absperrenden": "Absperrende",
    "Absperrens": "Absperren",
    "Absperrungen": "Absperrung",
    "Abspiegelnden": "Abspiegelnde",
    "Abspiegelns": "Abspiegeln",
    "Abspiele": "abspielen",
    "Abspielen": "Abspiel",
    "Abspielenden": "Abspielende",
    "Abspielens": "Abspielen",
    "Abspiels": "Abspiel",
    "Absplitternden": "Absplitternde",
    "Absplitterns": "Absplittern",
    "Absprachen": "absprechen",
    "Absprechenden": "Absprechende",
    "Absprechens": "Absprechen",
    "Abspreizenden": "Abspreizende",
    "Abspreizens": "Abspreizen",
    "Absprengenden": "Absprengende",
    "Absprengens": "Absprengen",
    "Abspringenden": "Abspringende",
    "Abspringens": "Abspringen",
    "Abspritzenden": "Abspritzende",
    "Abspritzens": "Abspritzen",
    "Absprunge": "Absprung",
    "Absprungs": "Absprung",
    "Absprühenden": "Absprühende",
    "Absprühens": "Absprühen",
    "Absprünge": "Absprung",
    "Absprüngen": "Absprung",
    "Abspulenden": "Abspulende",
    "Abspulens": "Abspulen",
    "Abspülende": "abspülend",
    "Abspülenden": "Abspülende",
    "Abspülens": "Abspülen",
    "Abstammenden": "Abstammende",
    "Abstammens": "Abstammen",
    "Abstammungen": "Abstammung",
    "Abstand": "abstehen",
    "Abstande": "Abstand",
    "Abstandes": "Abstand",
    "Abstands": "Abstand",
    "Abstattenden": "Abstattende",
    "Abstattens": "Abstatten",
    "Abstaubenden": "Abstaubende",
    "Abstaubenderen": "Abstaubendere",
    "Abstaubendsten": "Abstaubendste",
    "Abstaubens": "Abstauben",
    "Abstechenden": "Abstechende",
    "Abstechens": "Abstechen",
    "Abstehenden": "Abstehende",
    "Abstehenderen": "Abstehendere",
    "Abstehendsten": "Abstehendste",
    "Abstehens": "Abstehen",
    "Absteifenden": "Absteifende",
    "Absteifenderen": "Absteifendere",
    "Absteifendsten": "Absteifendste",
    "Absteifens": "Absteifen",
    "Absteigen": "Absteige",
    "Absteigenden": "Absteigende",
    "Absteigens": "Absteigen",
    "Absteigern": "Absteiger",
    "Absteigers": "Absteiger",
    "Abstellenden": "Abstellende",
    "Abstellens": "Abstellen",
    "Abstellflächen": "Abstellfläche",
    "Abstellgleise": "Abstellgleis",
    "Abstellgleisen": "Abstellgleis",
    "Abstellgleises": "Abstellgleis",
    "Abstellgleiss": "Abstellgleis",
    "Abstellplatze": "Abstellplatz",
    "Abstellplatzes": "Abstellplatz",
    "Abstellplätze": "Abstellplatz",
    "Abstellplätzen": "Abstellplatz",
    "Abstellraume": "Abstellraum",
    "Abstellraums": "Abstellraum",
    "Abstellräume": "Abstellraum",
    "Abstellräumen": "Abstellraum",
    "Abstelltische": "Abstelltisch",
    "Abstelltischen": "Abstelltisch",
    "Abstelltischs": "Abstelltisch",
    "Abstempelnden": "Abstempelnde",
    "Abstempelns": "Abstempeln",
    "Absteppenden": "Absteppende",
    "Absteppenderen": "Absteppendere",
    "Absteppendsten": "Absteppendste",
    "Absteppens": "Absteppen",
    "Absterbenden": "Absterbende",
    "Absterbenderen": "Absterbendere",
    "Absterbendsten": "Absterbendste",
    "Absterbens": "Absterben",
    "Abstiche": "Abstich",
    "Abstichen": "Abstich",
    "Abstichs": "Abstich",
    "Abstiege": "Abstieg",
    "Abstiegen": "Abstieg",
    "Abstiegs": "Abstieg",
    "Abstiegsgefährdete": "abstiegsgefährdet",
    "Abstiegsgefährdeten": "Abstiegsgefährdete",
    "Abstiegsgefährdeteren": "Abstiegsgefährdetere",
    "Abstielenden": "Abstielende",
    "Abstielens": "Abstielen",
    "Abstillenden": "Abstillende",
    "Abstillens": "Abstillen",
    "Abstimmenden": "Abstimmende",
    "Abstimmens": "Abstimmen",
    "Abstimmungen": "Abstimmung",
    "Abstoppenden": "Abstoppende",
    "Abstoppens": "Abstoppen",
    "Abstotternden": "Abstotternde",
    "Abstotterns": "Abstottern",
    "Abstoßenden": "Abstoßende",
    "Abstoßenderen": "Abstoßendere",
    "Abstoßendsten": "Abstoßendste",
    "Abstoßens": "Abstoßen",
    "Abstrafenden": "Abstrafende",
    "Abstrafens": "Abstrafen",
    "Abstrahlenden": "Abstrahlende",
    "Abstrahlens": "Abstrahlen",
    "Abstrahlungen": "Abstrahlung",
    "Abstrakta": "Abstraktum",
    "Abstrakte": "abstrakt",
    "Abstrakten": "Abstrakte",
    "Abstrakteren": "Abstraktere",
    "Abstraktesten": "Abstrakteste",
    "Abstraktums": "Abstraktum",
    "Abstrampelnden": "Abstrampelnde",
    "Abstrampelns": "Abstrampeln",
    "Abstrebenden": "Abstrebende",
    "Abstrebens": "Abstreben",
    "Abstreichenden": "Abstreichende",
    "Abstreichens": "Abstreichen",
    "Abstreichern": "Abstreicher",
    "Abstreichers": "Abstreicher",
    "Abstreifenden": "Abstreifende",
    "Abstreifens": "Abstreifen",
    "Abstreitenden": "Abstreitende",
    "Abstreitens": "Abstreiten",
    "Abstriche": "Abstrich",
    "Abstrichen": "Abstrich",
    "Abstrichs": "Abstrich",
    "Abströmenden": "Abströmende",
    "Abströmens": "Abströmen",
    "Abstufenden": "Abstufende",
    "Abstufens": "Abstufen",
    "Abstufungen": "Abstufung",
    "Abstumpfenden": "Abstumpfende",
    "Abstumpfenderen": "Abstumpfendere",
    "Abstumpfendsten": "Abstumpfendste",
    "Abstumpfens": "Abstumpfen",
    "Absturze": "Absturz",
    "Absturzes": "Absturz",
    "Abstände": "Abstand",
    "Abständen": "Abstand",
    "Abstürze": "abstürzen",
    "Abstürzen": "Absturz",
    "Abstürzenden": "Abstürzende",
    "Abstürzenderen": "Abstürzendere",
    "Abstürzendsten": "Abstürzendste",
    "Abstürzens": "Abstürzen",
    "Abstützenden": "Abstützende",
    "Abstützens": "Abstützen",
    "Absuchenden": "Absuchende",
    "Absuchens": "Absuchen",
    "Absurden": "Absurde",
    "Absurderen": "Absurdere",
    "Absurdesten": "Absurdeste",
    "Abszesse": "Abszeß",
    "Abszessen": "Abszeß",
    "Abszesses": "Abszeß",
    "Absäbelnden": "Absäbelnde",
    "Absäbelns": "Absäbeln",
    "Absägende": "absägend",
    "Absägenden": "Absägende",
    "Absägens": "Absägen",
    "Absätze": "Absatz",
    "Absätzen": "Absatz",
    "Abtakelnden": "Abtakelnde",
    "Abtakelns": "Abtakeln",
    "Abtankenden": "Abtankende",
    "Abtanzenden": "Abtanzende",
    "Abtanzenderen": "Abtanzendere",
    "Abtanzendsten": "Abtanzendste",
    "Abtanzens": "Abtanzen",
    "Abtastenden": "Abtastende",
    "Abtastens": "Abtasten",
    "Abtauchenden": "Abtauchende",
    "Abtauchens": "Abtauchen",
    "Abtauenden": "Abtauende",
    "Abtauens": "Abtauen",
    "Abte": "Abt",
    "Abteien": "Abtei",
    "Abteile": "abteilen",
    "Abteilen": "Abteil",
    "Abteilenden": "Abteilende",
    "Abteilens": "Abteilen",
    "Abteils": "Abteil",
    "Abteilungen": "Abteilung",
    "Abtelefonierenden": "Abtelefonierende",
    "Abtelefonierens": "Abtelefonieren",
    "Abtelefonierte": "abtelefoniert",
    "Abtelefonierten": "Abtelefonierte",
    "Abtes": "Abt",
    "Abtippenden": "Abtippende",
    "Abtippens": "Abtippen",
    "Abtrage": "abtragen",
    "Abtragenden": "Abtragende",
    "Abtragens": "Abtragen",
    "Abtrags": "Abtrag",
    "Abtragungen": "Abtragung",
    "Abtransportierenden": "Abtransportierende",
    "Abtransportierens": "Abtransportieren",
    "Abtransportierte": "abtransportiert",
    "Abtransportierten": "Abtransportierte",
    "Abtreibenden": "Abtreibende",
    "Abtreibens": "Abtreiben",
    "Abtreibungen": "Abtreibung",
    "Abtrennbare": "abtrennbar",
    "Abtrennbaren": "Abtrennbare",
    "Abtrennenden": "Abtrennende",
    "Abtrennens": "Abtrennen",
    "Abtretenden": "Abtretende",
    "Abtretens": "Abtreten",
    "Abtretern": "Abtreter",
    "Abtreters": "Abtreter",
    "Abtretungen": "Abtretung",
    "Abtrieb": "abtreiben",
    "Abtriebe": "Abtrieb",
    "Abtrieben": "Abtrieb",
    "Abtriebs": "Abtrieb",
    "Abtrinkenden": "Abtrinkende",
    "Abtrinkens": "Abtrinken",
    "Abtritte": "Abtritt",
    "Abtritten": "Abtritt",
    "Abtritts": "Abtritt",
    "Abtrocknenden": "Abtrocknende",
    "Abtrocknenderen": "Abtrocknendere",
    "Abtrocknendsten": "Abtrocknendste",
    "Abtrocknens": "Abtrocknen",
    "Abtropfenden": "Abtropfende",
    "Abtropfens": "Abtropfen",
    "Abtropfflächen": "Abtropffläche",
    "Abtrotzenden": "Abtrotzende",
    "Abtrotzens": "Abtrotzen",
    "Abtrudelnden": "Abtrudelnde",
    "Abtrudelns": "Abtrudeln",
    "Abträge": "Abtrag",
    "Abträgen": "Abtrag",
    "Abträglichen": "Abträgliche",
    "Abträufelnden": "Abträufelnde",
    "Abträufelns": "Abträufeln",
    "Abtrünnigen": "Abtrünnige",
    "Abtrünnigeren": "Abtrünnigere",
    "Abtrünnigsten": "Abtrünnigste",
    "Abts": "Abt",
    "Abtupfenden": "Abtupfende",
    "Abtupfens": "Abtupfen",
    "Abtönenden": "Abtönende",
    "Abtönens": "Abtönen",
    "Abtötenden": "Abtötende",
    "Abtötens": "Abtöten",
    "Aburteilenden": "Aburteilende",
    "Aburteilens": "Aburteilen",
    "Aburteilungen": "Aburteilung",
    "Abverkaufe": "Abverkauf",
    "Abverkaufs": "Abverkauf",
    "Abverkäufe": "Abverkauf",
    "Abverkäufen": "Abverkauf",
    "Abverlangenden": "Abverlangende",
    "Abverlangens": "Abverlangen",
    "Abverlangte": "abverlangt",
    "Abverlangten": "Abverlangte",
    "Abwahlen": "Abwahl",
    "Abwandelnden": "Abwandelnde",
    "Abwandelns": "Abwandeln",
    "Abwandernden": "Abwandernde",
    "Abwanderns": "Abwandern",
    "Abwandlungen": "Abwandlung",
    "Abwartenden": "Abwartende",
    "Abwartenderen": "Abwartendere",
    "Abwartendsten": "Abwartendste",
    "Abwartens": "Abwarten",
    "Abwaschenden": "Abwaschende",
    "Abwaschens": "Abwaschen",
    "Abwassers": "Abwasser",
    "Abwechselnden": "Abwechselnde",
    "Abwechselns": "Abwechseln",
    "Abwechslungen": "Abwechslung",
    "Abwechslungsreiche": "abwechslungsreich",
    "Abwechslungsreichen": "Abwechslungsreiche",
    "Abwechslungsreicheren": "Abwechslungsreichere",
    "Abwegigen": "Abwegige",
    "Abwegigeren": "Abwegigere",
    "Abwegigsten": "Abwegigste",
    "Abwehren": "Abwehr",
    "Abwehrenden": "Abwehrende",
    "Abwehrens": "Abwehren",
    "Abweichenden": "Abweichende",
    "Abweichenderen": "Abweichendere",
    "Abweichendsten": "Abweichendste",
    "Abweichens": "Abweichen",
    "Abweichungen": "Abweichung",
    "Abweidenden": "Abweidende",
    "Abweidenderen": "Abweidendere",
    "Abweidendsten": "Abweidendste",
    "Abweidens": "Abweiden",
    "Abweisenden": "Abweisende",
    "Abweisenderen": "Abweisendere",
    "Abweisendsten": "Abweisendste",
    "Abweisens": "Abweisen",
    "Abweisungen": "Abweisung",
    "Abwendbare": "abwendbar",
    "Abwendbaren": "Abwendbare",
    "Abwendenden": "Abwendende",
    "Abwendens": "Abwenden",
    "Abwerbenden": "Abwerbende",
    "Abwerbens": "Abwerben",
    "Abwerfenden": "Abwerfende",
    "Abwerfens": "Abwerfen",
    "Abwertenden": "Abwertende",
    "Abwertenderen": "Abwertendere",
    "Abwertendsten": "Abwertendste",
    "Abwertens": "Abwerten",
    "Abwertungen": "Abwertung",
    "Abwesende": "abwesend",
    "Abwesenden": "Abwesende",
    "Abwetzenden": "Abwetzende",
    "Abwetzenderen": "Abwetzendere",
    "Abwetzendsten": "Abwetzendste",
    "Abwetzens": "Abwetzen",
    "Abwickelnden": "Abwickelnde",
    "Abwickelns": "Abwickeln",
    "Abwicklungen": "Abwicklung",
    "Abwiegenden": "Abwiegende",
    "Abwiegens": "Abwiegen",
    "Abwimmelnden": "Abwimmelnde",
    "Abwimmelns": "Abwimmeln",
    "Abwindenden": "Abwindende",
    "Abwindens": "Abwinden",
    "Abwinkenden": "Abwinkende",
    "Abwinkens": "Abwinken",
    "Abwirtschaftenden": "Abwirtschaftende",
    "Abwirtschaftenderen": "Abwirtschaftendere",
    "Abwirtschaftens": "Abwirtschaften",
    "Abwischenden": "Abwischende",
    "Abwischens": "Abwischen",
    "Abwohnenden": "Abwohnende",
    "Abwohnenderen": "Abwohnendere",
    "Abwohnendsten": "Abwohnendste",
    "Abwohnens": "Abwohnen",
    "Abwurfe": "Abwurf",
    "Abwurfs": "Abwurf",
    "Abwägenden": "Abwägende",
    "Abwägens": "Abwägen",
    "Abwählenden": "Abwählende",
    "Abwählens": "Abwählen",
    "Abwälzenden": "Abwälzende",
    "Abwälzenderen": "Abwälzendere",
    "Abwälzendsten": "Abwälzendste",
    "Abwälzens": "Abwälzen",
    "Abwärtsgegangenen": "Abwärtsgegangene",
    "Abwärtsgehenden": "Abwärtsgehende",
    "Abwärtsgehens": "Abwärtsgehen",
    "Abwässer": "Abwasser",
    "Abwässern": "Abwasser",
    "Abwürfe": "Abwurf",
    "Abwürfen": "Abwurf",
    "Abwürgenden": "Abwürgende",
    "Abwürgenderen": "Abwürgendere",
    "Abwürgendsten": "Abwürgendste",
    "Abwürgens": "Abwürgen",
    "Abzahlenden": "Abzahlende",
    "Abzahlens": "Abzahlen",
    "Abzahlungen": "Abzahlung",
    "Abzapfenden": "Abzapfende",
    "Abzapfens": "Abzapfen",
    "Abzappelnden": "Abzappelnde",
    "Abzappelnderen": "Abzappelndere",
    "Abzappelndsten": "Abzappelndste",
    "Abzappelns": "Abzappeln",
    "Abzehrungen": "Abzehrung",
    "Abzeichens": "Abzeichen",
    "Abzeichnenden": "Abzeichnende",
    "Abzeichnens": "Abzeichnen",
    "Abziehenden": "Abziehende",
    "Abziehens": "Abziehen",
    "Abziehern": "Abzieher",
    "Abziehers": "Abzieher",
    "Abziehpressen": "Abziehpresse",
    "Abzielenden": "Abzielende",
    "Abzielens": "Abzielen",
    "Abzirkelnden": "Abzirkelnde",
    "Abzirkelns": "Abzirkeln",
    "Abzischenden": "Abzischende",
    "Abzischens": "Abzischen",
    "Abzitternden": "Abzitternde",
    "Abzitterns": "Abzittern",
    "Abzuge": "Abzug",
    "Abzuges": "Abzug",
    "Abzugs": "Abzug",
    "Abzugsfähige": "abzugsfähig",
    "Abzugsfähigen": "Abzugsfähige",
    "Abzupfenden": "Abzupfende",
    "Abzupfens": "Abzupfen",
    "Abzweigenden": "Abzweigende",
    "Abzweigens": "Abzweigen",
    "Abzweigungen": "Abzweigung",
    "Abzwingenden": "Abzwingende",
    "Abzwingens": "Abzwingen",
    "Abzwitschernden": "Abzwitschernde",
    "Abzwitscherns": "Abzwitschern",
    "Abzählende": "abzählend",
    "Abzählenden": "Abzählende",
    "Abzählens": "Abzählen",
    "Abzählreime": "Abzählreim",
    "Abzählreimen": "Abzählreim",
    "Abzählreims": "Abzählreim",
    "Abzäumenden": "Abzäumende",
    "Abzäumenderen": "Abzäumendere",
    "Abzäumendsten": "Abzäumendste",
    "Abzäumens": "Abzäumen",
    "Abzäunenden": "Abzäunende",
    "Abzäunens": "Abzäunen",
    "Abzäunungen": "Abzäunung",
    "Abzüge": "Abzug",
    "Abzügen": "Abzug",
    "Abändernden": "Abändernde",
    "Abändernderen": "Abänderndere",
    "Abänderndsten": "Abänderndste",
    "Abänderns": "Abändern",
    "Abänderungen": "Abänderung",
    "Abästenden": "Abästende",
    "Abästens": "Abästen",
    "Achims": "Achim",
    "Achs": "Ach",
    "Achselhöhlen": "Achselhöhle",
    "Achseln": "Achsel",
    "Achsen": "Achse",
    "Achtarmige": "achtarmig",
    "Achtarmigen": "Achtarmige",
    "Achtbaren": "Achtbare",
    "Achtelnoten": "Achtelnote",
    "Achtelpausen": "Achtelpause",
    "Achten": "Acht",
    "Achtenden": "Achtende",
    "Achtenderen": "Achtendere",
    "Achtendsten": "Achtendste",
    "Achtens": "Achten",
    "Achterbahnen": "Achterbahn",
    "Achtfachen": "Achtfache",
    "Achtgebenden": "Achtgebende",
    "Achtgebenderen": "Achtgebendere",
    "Achtgebendsten": "Achtgebendste",
    "Achtgebens": "Achtgeben",
    "Achtgegebenen": "Achtgegebene",
    "Achtgegebeneren": "Achtgegebenere",
    "Achtgegebensten": "Achtgegebenste",
    "Achtjährigen": "Achtjährige",
    "Achtkantigen": "Achtkantige",
    "Achtlosen": "Achtlose",
    "Achtloseren": "Achtlosere",
    "Achtlosesten": "Achtloseste",
    "Achtmaligen": "Achtmalige",
    "Achtpfündern": "Achtpfünder",
    "Achtpfünders": "Achtpfünder",
    "Achtprozentige": "achtprozentig",
    "Achtprozentigen": "Achtprozentige",
    "Achtsaitigen": "Achtsaitige",
    "Achtsamen": "Achtsame",
    "Achtsameren": "Achtsamere",
    "Achtsamsten": "Achtsamste",
    "Achtseitigen": "Achtseitige",
    "Achtsilbigen": "Achtsilbige",
    "Achtstundentage": "Achtstundentag",
    "Achtstundentagen": "Achtstundentag",
    "Achtstundentags": "Achtstundentag",
    "Achtstündige": "achtstündig",
    "Achtstündigen": "Achtstündige",
    "Achttägigen": "Achttägige",
    "Achtzigfachen": "Achtzigfache",
    "Achtzigjährigen": "Achtzigjährige",
    "Achtzigsteln": "Achtzigstel",
    "Achtzigstels": "Achtzigstel",
    "Achtzylindern": "Achtzylinder",
    "Achtzylinders": "Achtzylinder",
    "Ackers": "Acker",
    "Adams": "Adam",
    "Addierenden": "Addierende",
    "Addierens": "Addieren",
    "Addiermaschinen": "Addiermaschine",
    "Addierte": "addiert",
    "Addierten": "Addierte",
    "Additionalen": "Additionale",
    "Additionen": "Addition",
    "Additive": "additiv",
    "Additiven": "Additive",
    "Adduktionen": "Adduktion",
    "Adduktore": "Adduktor",
    "Adduktoren": "Adduktor",
    "Adduktors": "Adduktor",
    "Adel": "adeln",
    "Adeligen": "Adelige",
    "Adeln": "Adel",
    "Adelnden": "Adelnde",
    "Adelns": "Adeln",
    "Adels": "Adel",
    "Adenauers": "Adenauer",
    "Adern": "Ader",
    "Aderreiche": "aderreich",
    "Aderreichen": "Aderreiche",
    "Aderreicheren": "Aderreichere",
    "Aderreichsten": "Aderreichste",
    "Adhärenten": "Adhärente",
    "Adjektive": "Adjektiv",
    "Adjektiven": "Adjektiv",
    "Adjektivische": "adjektivisch",
    "Adjektivischen": "Adjektivische",
    "Adjektivs": "Adjektiv",
    "Adjunktionen": "Adjunktion",
    "Adjustierenden": "Adjustierende",
    "Adjustierens": "Adjustieren",
    "Adjustierte": "adjustiert",
    "Adjustierten": "Adjustierte",
    "Adjustierungen": "Adjustierung",
    "Adjutanten": "Adjutant",
    "Adjutore": "Adjutor",
    "Adjutoren": "Adjutor",
    "Adjutors": "Adjutor",
    "Adlern": "Adler",
    "Adlers": "Adler",
    "Adligen": "Adlige",
    "Administrationen": "Administration",
    "Admirale": "Admiral",
    "Admiralen": "Admiral",
    "Admiralitäten": "Admiralität",
    "Admirals": "Admiral",
    "Admissionen": "Admission",
    "Adoleszente": "adoleszent",
    "Adoleszenten": "Adoleszente",
    "Adolfs": "Adolf",
    "Adressanten": "Adressant",
    "Adressaten": "Adressat",
    "Adressatinnen": "Adressatin",
    "Adressen": "Adresse",
    "Adressierenden": "Adressierende",
    "Adressierens": "Adressieren",
    "Adressiermaschinen": "Adressiermaschine",
    "Adressierte": "adressiert",
    "Adressierten": "Adressierte",
    "Adsorbierbaren": "Adsorbierbare",
    "Adsorbierbareren": "Adsorbierbarere",
    "Adsorbierbarsten": "Adsorbierbarste",
    "Adsorbierenden": "Adsorbierende",
    "Adsorbierenderen": "Adsorbierendere",
    "Adsorbierendsten": "Adsorbierendste",
    "Adsorbierens": "Adsorbieren",
    "Adsorbierte": "adsorbiert",
    "Adsorbierten": "Adsorbierte",
    "Adsorbierteren": "Adsorbiertere",
    "Adsorbiertesten": "Adsorbierteste",
    "Adsorptionen": "Adsorption",
    "Advents": "Advent",
    "Aerosols": "Aerosol",
    "Affekte": "Affekt",
    "Affekten": "Affekt",
    "Affektes": "Affekt",
    "Affektierenden": "Affektierende",
    "Affektierenderen": "Affektierendere",
    "Affektierendsten": "Affektierendste",
    "Affektierens": "Affektieren",
    "Affektierte": "affektiert",
    "Affektierten": "Affektierte",
    "Affektierteren": "Affektiertere",
    "Affektiertesten": "Affektierteste",
    "Affektionierten": "Affektionierte",
    "Affektionierteren": "Affektioniertere",
    "Affektiven": "Affektive",
    "Affektiveren": "Affektivere",
    "Affektivsten": "Affektivste",
    "Affekts": "Affekt",
    "Affen": "Affe",
    "Affenartige": "affenartig",
    "Affenartigen": "Affenartige",
    "Affenartigeren": "Affenartigere",
    "Affenartigsten": "Affenartigste",
    "Affengeilen": "Affengeile",
    "Affengeileren": "Affengeilere",
    "Affengeilsten": "Affengeilste",
    "Affigen": "Affige",
    "Affigeren": "Affigere",
    "Affigsten": "Affigste",
    "Affiliationen": "Affiliation",
    "Affine": "affin",
    "Affinen": "Affine",
    "Affirmationen": "Affirmation",
    "Affirmative": "affirmativ",
    "Affirmativen": "Affirmative",
    "Affirmativeren": "Affirmativere",
    "Affirmativsten": "Affirmativste",
    "Affirmierenden": "Affirmierende",
    "Affirmierenderen": "Affirmierendere",
    "Affirmierendsten": "Affirmierendste",
    "Affirmierens": "Affirmieren",
    "Affirmierte": "affirmiert",
    "Affirmierten": "Affirmierte",
    "Affirmierteren": "Affirmiertere",
    "Affirmiertesten": "Affirmierteste",
    "Affären": "Affäre",
    "Afghanen": "Afghane",
    "Afghaninnen": "Afghanin",
    "Afghanische": "afghanisch",
    "Afghanischen": "Afghanische",
    "Afghanistans": "Afghanistan",
    "Afrikanern": "Afrikaner",
    "Afrikaners": "Afrikaner",
    "Afrikanische": "afrikanisch",
    "Afrikanischen": "Afrikanische",
    "Afrikanischeren": "Afrikanischere",
    "Afrikanischsten": "Afrikanischste",
    "Afrikanisten": "Afrikanist",
    "Afrikas": "Afrika",
    "Afterdrüsen": "Afterdrüse",
    "Afterklauen": "Afterklaue",
    "Aftern": "After",
    "Afters": "After",
    "Aftershaves": "Aftershave",
    "Afterzehen": "Afterzehe",
    "Agenten": "Agent",
    "Agenturen": "Agentur",
    "Agglomerate": "Agglomerat",
    "Agglomeraten": "Agglomerat",
    "Agglomerationen": "Agglomeration",
    "Agglomerats": "Agglomerat",
    "Agglomeriere": "agglomerieren",
    "Agglomerierenden": "Agglomerierende",
    "Agglomerierenderen": "Agglomerierendere",
    "Agglomerierens": "Agglomerieren",
    "Agglomerierte": "agglomeriert",
    "Agglomerierten": "Agglomerierte",
    "Agglomerierteren": "Agglomeriertere",
    "Agglomeriertesten": "Agglomerierteste",
    "Agglutinationen": "Agglutination",
    "Agglutinierenden": "Agglutinierende",
    "Agglutinierens": "Agglutinieren",
    "Agglutinierte": "agglutiniert",
    "Agglutinierten": "Agglutinierte",
    "Aggregate": "Aggregat",
    "Aggregaten": "Aggregat",
    "Aggregationen": "Aggregation",
    "Aggregats": "Aggregat",
    "Aggressionen": "Aggression",
    "Aggressive": "aggressiv",
    "Aggressiven": "Aggressive",
    "Aggressiveren": "Aggressivere",
    "Aggressivitäten": "Aggressivität",
    "Aggressivste": "aggressiv",
    "Aggressivsten": "Aggressivste",
    "Agierenden": "Agierende",
    "Agierenderen": "Agierendere",
    "Agierendsten": "Agierendste",
    "Agierens": "Agieren",
    "Agierte": "agiert",
    "Agierten": "Agierte",
    "Agilen": "Agile",
    "Agileren": "Agilere",
    "Agilsten": "Agilste",
    "Agitationen": "Agitation",
    "Agitatore": "Agitator",
    "Agitatoren": "Agitator",
    "Agitatorische": "agitatorisch",
    "Agitatorischen": "Agitatorische",
    "Agitatorischeren": "Agitatorischere",
    "Agitatorischsten": "Agitatorischste",
    "Agitators": "Agitator",
    "Agonisten": "Agonist",
    "Agrargute": "Agrargut",
    "Agrargutes": "Agrargut",
    "Agrarguts": "Agrargut",
    "Agrargüter": "Agrargut",
    "Agrargütern": "Agrargut",
    "Agronomen": "Agronom",
    "Agrotechnische": "agrotechnisch",
    "Agrotechnischen": "Agrotechnische",
    "Ahlens": "Ahlen",
    "Ahmenden": "Ahmende",
    "Ahmenderen": "Ahmendere",
    "Ahmendsten": "Ahmendste",
    "Ahmens": "Ahmen",
    "Ahndenden": "Ahndende",
    "Ahndenderen": "Ahndendere",
    "Ahndendsten": "Ahndendste",
    "Ahndens": "Ahnden",
    "Ahnenden": "Ahnende",
    "Ahnenderen": "Ahnendere",
    "Ahnendsten": "Ahnendste",
    "Ahnens": "Ahnen",
    "Ahninnen": "Ahnin",
    "Ahnungen": "Ahnung",
    "Ahnungslose": "ahnungslos",
    "Ahnungslosen": "Ahnungslose",
    "Ahnungsloseren": "Ahnungslosere",
    "Ahnungslosesten": "Ahnungsloseste",
    "Ahnungsvollen": "Ahnungsvolle",
    "Ahnungsvolleren": "Ahnungsvollere",
    "Ahnungsvollsten": "Ahnungsvollste",
    "Airbusse": "Airbus",
    "Airbussen": "Airbus",
    "Airbusses": "Airbus",
    "Airlenbachs": "Airlenbach",
    "Airlines": "Airline",
    "Akademien": "Akademie",
    "Akademikern": "Akademiker",
    "Akademikers": "Akademiker",
    "Akademische": "akademisch",
    "Akademischen": "Akademische",
    "Akazien": "Akazie",
    "Akklamationen": "Akklamation",
    "Akklamierenden": "Akklamierende",
    "Akklamierenderen": "Akklamierendere",
    "Akklamierendsten": "Akklamierendste",
    "Akklamierens": "Akklamieren",
    "Akklamierte": "akklamiert",
    "Akklamierten": "Akklamierte",
    "Akklamierteren": "Akklamiertere",
    "Akklamiertesten": "Akklamierteste",
    "Akklimatisierenden": "Akklimatisierende",
    "Akklimatisierens": "Akklimatisieren",
    "Akklimatisierte": "akklimatisiert",
    "Akklimatisierten": "Akklimatisierte",
    "Akkommodierenden": "Akkommodierende",
    "Akkommodierens": "Akkommodieren",
    "Akkommodierte": "akkommodiert",
    "Akkommodierten": "Akkommodierte",
    "Akkorde": "Akkord",
    "Akkorden": "Akkord",
    "Akkordeons": "Akkordeon",
    "Akkordes": "Akkord",
    "Akkords": "Akkord",
    "Akkreditierenden": "Akkreditierende",
    "Akkreditierens": "Akkreditieren",
    "Akkreditierte": "akkreditiert",
    "Akkreditierten": "Akkreditierte",
    "Akkumulationen": "Akkumulation",
    "Akkumulatore": "Akkumulator",
    "Akkumulatoren": "Akkumulator",
    "Akkumulators": "Akkumulator",
    "Akkumulierenden": "Akkumulierende",
    "Akkumulierens": "Akkumulieren",
    "Akkumulierte": "akkumuliert",
    "Akkumulierten": "Akkumulierte",
    "Akkuraten": "Akkurate",
    "Akkurateren": "Akkuratere",
    "Akkuratesten": "Akkurateste",
    "Akkus": "Akku",
    "Akkusative": "Akkusativ",
    "Akkusativen": "Akkusativ",
    "Akkusativs": "Akkusativ",
    "Aknen": "Akne",
    "Akquirierenden": "Akquirierende",
    "Akquirierens": "Akquirieren",
    "Akquirierte": "akquiriert",
    "Akquirierten": "Akquirierte",
    "Akquisitionen": "Akquisition",
    "Akrobatische": "akrobatisch",
    "Akrobatischen": "Akrobatische",
    "Akrobatischeren": "Akrobatischere",
    "Akrobatischsten": "Akrobatischste",
    "Akronyme": "Akronym",
    "Akronymen": "Akronym",
    "Akronyms": "Akronym",
    "Akte": "Akt",
    "Akten": "Akte",
    "Aktenkundige": "aktenkundig",
    "Aktenkundigen": "Aktenkundige",
    "Aktenkundigeren": "Aktenkundigere",
    "Aktenkundigsten": "Aktenkundigste",
    "Aktes": "Akt",
    "Akteure": "Akteur",
    "Akteuren": "Akteur",
    "Akteurs": "Akteur",
    "Aktien": "Aktie",
    "Aktionen": "Aktion",
    "Aktionisten": "Aktionist",
    "Aktionäre": "Aktionär",
    "Aktionären": "Aktionär",
    "Aktionärs": "Aktionär",
    "Aktivbestande": "Aktivbestand",
    "Aktivbestands": "Aktivbestand",
    "Aktivbestände": "Aktivbestand",
    "Aktivbeständen": "Aktivbestand",
    "Aktivbürgern": "Aktivbürger",
    "Aktivbürgers": "Aktivbürger",
    "Aktive": "aktiv",
    "Aktiven": "Aktive",
    "Aktiveren": "Aktivere",
    "Aktivgeschäfte": "Aktivgeschäft",
    "Aktivgeschäften": "Aktivgeschäft",
    "Aktivgeschäfts": "Aktivgeschäft",
    "Aktivierenden": "Aktivierende",
    "Aktivierens": "Aktivieren",
    "Aktivierte": "aktiviert",
    "Aktivierten": "Aktivierte",
    "Aktivierungen": "Aktivierung",
    "Aktivisten": "Aktivist",
    "Aktivitäten": "Aktivität",
    "Aktivrudern": "Aktivruder",
    "Aktivruders": "Aktivruder",
    "Aktivsaldos": "Aktivsaldo",
    "Aktivste": "aktiv",
    "Aktivsten": "Aktivste",
    "Aktivurlaube": "Aktivurlaub",
    "Aktivurlauben": "Aktivurlaub",
    "Aktivurlaubs": "Aktivurlaub",
    "Aktivvermögens": "Aktivvermögen",
    "Akts": "Akt",
    "Aktualisiere": "aktualisieren",
    "Aktualisierenden": "Aktualisierende",
    "Aktualisierenderen": "Aktualisierendere",
    "Aktualisierens": "Aktualisieren",
    "Aktualisierte": "aktualisiert",
    "Aktualisierten": "Aktualisierte",
    "Aktualisierteren": "Aktualisiertere",
    "Aktualisiertesten": "Aktualisierteste",
    "Aktuellen": "Aktuelle",
    "Aktuelleren": "Aktuellere",
    "Aktuellsten": "Aktuellste",
    "Akupressuren": "Akupressur",
    "Akupunktierenden": "Akupunktierende",
    "Akupunktierens": "Akupunktieren",
    "Akupunktierte": "akupunktiert",
    "Akupunktierten": "Akupunktierte",
    "Akupunkturen": "Akupunktur",
    "Akustische": "akustisch",
    "Akustischen": "Akustische",
    "Akustischeren": "Akustischere",
    "Akustischsten": "Akustischste",
    "Akuten": "Akute",
    "Akuteren": "Akutere",
    "Akutesten": "Akuteste",
    "Akzeleratore": "Akzelerator",
    "Akzeleratoren": "Akzelerator",
    "Akzelerators": "Akzelerator",
    "Akzente": "Akzent",
    "Akzenten": "Akzent",
    "Akzents": "Akzent",
    "Akzentuierenden": "Akzentuierende",
    "Akzentuierenderen": "Akzentuierendere",
    "Akzentuierendsten": "Akzentuierendste",
    "Akzentuierens": "Akzentuieren",
    "Akzentuierte": "akzentuiert",
    "Akzentuierten": "Akzentuierte",
    "Akzentuierteren": "Akzentuiertere",
    "Akzentuiertesten": "Akzentuierteste",
    "Akzeptabelsten": "Akzeptabelste",
    "Akzeptablen": "Akzeptable",
    "Akzeptableren": "Akzeptablere",
    "Akzeptanten": "Akzeptant",
    "Akzeptanzen": "Akzeptanz",
    "Akzeptierenden": "Akzeptierende",
    "Akzeptierens": "Akzeptieren",
    "Akzeptierte": "akzeptiert",
    "Akzeptierten": "Akzeptierte",
    "Akzeptierteren": "Akzeptiertere",
    "Akzeptiertesten": "Akzeptierteste",
    "Akzeptore": "Akzeptor",
    "Akzeptoren": "Akzeptor",
    "Akzeptors": "Akzeptor",
    "Alabastern": "Alabaster",
    "Alabasters": "Alabaster",
    "Alarme": "Alarm",
    "Alarmen": "Alarm",
    "Alarmes": "Alarm",
    "Alarmierenden": "Alarmierende",
    "Alarmierenderen": "Alarmierendere",
    "Alarmierendsten": "Alarmierendste",
    "Alarmierens": "Alarmieren",
    "Alarmierte": "alarmiert",
    "Alarmierten": "Alarmierte",
    "Alarms": "Alarm",
    "Albanern": "Albaner",
    "Albaners": "Albaner",
    "Albaniens": "Albanien",
    "Albanische": "albanisch",
    "Albanischen": "Albanische",
    "Albas": "Alba",
    "Alben": "Album",
    "Albereien": "Alberei",
    "Albernden": "Albernde",
    "Albernderen": "Alberndere",
    "Alberndsten": "Alberndste",
    "Albernheiten": "Albernheit",
    "Alberns": "Albern",
    "Alberts": "Albert",
    "Albinos": "Albino",
    "Albrechts": "Albrecht",
    "Albtraume": "Albtraum",
    "Albtraumes": "Albtraum",
    "Albtraums": "Albtraum",
    "Albträume": "Albtraum",
    "Albträumen": "Albtraum",
    "Albums": "Album",
    "Alemannen": "Alemanne",
    "Alemannische": "alemannisch",
    "Alemannischen": "Alemannische",
    "Alexanders": "Alexander",
    "Alexandras": "Alexandra",
    "Alfreds": "Alfred",
    "Alfs": "Alf",
    "Algen": "Alge",
    "Algeriens": "Algerien",
    "Algiers": "Algier",
    "Alibis": "Alibi",
    "Aliens": "Alien",
    "Alis": "Ali",
    "Alkalimetalle": "Alkalimetall",
    "Alkalimetallen": "Alkalimetall",
    "Alkalimetalls": "Alkalimetall",
    "Alkalische": "alkalisch",
    "Alkalischen": "Alkalische",
    "Alkalisierenden": "Alkalisierende",
    "Alkalisierenderen": "Alkalisierendere",
    "Alkalisierendsten": "Alkalisierendste",
    "Alkalisierens": "Alkalisieren",
    "Alkalisierte": "alkalisiert",
    "Alkalisierten": "Alkalisierte",
    "Alkalisierteren": "Alkalisiertere",
    "Alkalisiertesten": "Alkalisierteste",
    "Alkaloide": "Alkaloid",
    "Alkaloiden": "Alkaloid",
    "Alkaloids": "Alkaloid",
    "Alkohole": "Alkohol",
    "Alkoholes": "Alkohol",
    "Alkoholfreie": "alkoholfrei",
    "Alkoholfreien": "Alkoholfreie",
    "Alkoholfreieren": "Alkoholfreiere",
    "Alkoholfreisten": "Alkoholfreiste",
    "Alkoholikern": "Alkoholiker",
    "Alkoholikers": "Alkoholiker",
    "Alkoholische": "alkoholisch",
    "Alkoholischen": "Alkoholische",
    "Alkoholischeren": "Alkoholischere",
    "Alkoholischsten": "Alkoholischste",
    "Alkoholisierenden": "Alkoholisierende",
    "Alkoholisierenderen": "Alkoholisierendere",
    "Alkoholisierens": "Alkoholisieren",
    "Alkoholisierte": "alkoholisiert",
    "Alkoholisierten": "Alkoholisierte",
    "Alkoholisierteren": "Alkoholisiertere",
    "Alkoholisierteste": "alkoholisiert",
    "Alkohols": "Alkohol",
    "Allbekannte": "allbekannt",
    "Allbekannten": "Allbekannte",
    "Allbeliebten": "Allbeliebte",
    "Alleen": "Allee",
    "Allegationen": "Allegation",
    "Alleinerben": "Alleinerbe",
    "Alleinerziehende": "alleinerziehend",
    "Alleinerziehenden": "Alleinerziehende",
    "Alleinfluge": "Alleinflug",
    "Alleinflugs": "Alleinflug",
    "Alleinflüge": "Alleinflug",
    "Alleinflügen": "Alleinflug",
    "Alleingange": "Alleingang",
    "Alleingangs": "Alleingang",
    "Alleingänge": "Alleingang",
    "Alleingängen": "Alleingang",
    "Alleinherrschern": "Alleinherrscher",
    "Alleinherrschers": "Alleinherrscher",
    "Alleinige": "alleinig",
    "Alleinigen": "Alleinige",
    "Alleininhabern": "Alleininhaber",
    "Alleininhabers": "Alleininhaber",
    "Alleinseins": "Alleinsein",
    "Alleinstehende": "alleinstehend",
    "Alleinstehenden": "Alleinstehende",
    "Alleinverkaufs": "Alleinverkauf",
    "Alleinvertretern": "Alleinvertreter",
    "Alleinvertreters": "Alleinvertreter",
    "Alleinvertriebs": "Alleinvertrieb",
    "Allergien": "Allergie",
    "Allerwertesten": "Allerwerteste",
    "Allesfressenden": "Allesfressende",
    "Allesfressern": "Allesfresser",
    "Allesfressers": "Allesfresser",
    "Allesklebern": "Alleskleber",
    "Allesklebers": "Alleskleber",
    "Allesreinigern": "Allesreiniger",
    "Allesreinigers": "Allesreiniger",
    "Allgegenwärtige": "allgegenwärtig",
    "Allgegenwärtigen": "Allgegenwärtige",
    "Allgemeinbefindens": "Allgemeinbefinden",
    "Allgemeinbildende": "allgemeinbildend",
    "Allgemeinbildenden": "Allgemeinbildende",
    "Allgemeinen": "Allgemeine",
    "Allgemeineren": "Allgemeinere",
    "Allgemeinguts": "Allgemeingut",
    "Allgemeingültigen": "Allgemeingültige",
    "Allgemeingültigeren": "Allgemeingültigere",
    "Allgemeinheiten": "Allgemeinheit",
    "Allgemeinmedizinern": "Allgemeinmediziner",
    "Allgemeinmediziners": "Allgemeinmediziner",
    "Allgemeinste": "allgemein",
    "Allgemeinsten": "Allgemeinste",
    "Allgäus": "Allgäu",
    "Allianzen": "Allianz",
    "Alligatore": "Alligator",
    "Alligatoren": "Alligator",
    "Alligators": "Alligator",
    "Alliierten": "Alliierte",
    "Alliterationen": "Alliteration",
    "Allmonatlichen": "Allmonatliche",
    "Allmächtige": "allmächtig",
    "Allmächtigen": "Allmächtige",
    "Allmählichen": "Allmähliche",
    "Allofone": "Allofon",
    "Allofonen": "Allofon",
    "Allofons": "Allofon",
    "Allokationen": "Allokation",
    "Allomorphe": "Allomorph",
    "Allomorphen": "Allomorph",
    "Allomorphs": "Allomorph",
    "Allopathen": "Allopath",
    "Allophone": "Allophon",
    "Allophonen": "Allophon",
    "Allophons": "Allophon",
    "Allradantriebs": "Allradantrieb",
    "Alls": "All",
    "Allseitige": "allseitig",
    "Allseitigen": "Allseitige",
    "Allstündlichen": "Allstündliche",
    "Alltage": "Alltag",
    "Alltagen": "Alltag",
    "Alltages": "Alltag",
    "Alltags": "Alltag",
    "Alltagstypische": "alltagstypisch",
    "Alltagstypischen": "Alltagstypische",
    "Alltagstypischeren": "Alltagstypischere",
    "Alltägliche": "alltäglich",
    "Alltäglichen": "Alltägliche",
    "Allumfassenden": "Allumfassende",
    "Allumfassenderen": "Allumfassendere",
    "Allumfassendsten": "Allumfassendste",
    "Allwissende": "allwissend",
    "Allwissenden": "Allwissende",
    "Allwöchentlichen": "Allwöchentliche",
    "Allzweckreinigern": "Allzweckreiniger",
    "Allzweckreinigers": "Allzweckreiniger",
    "Allüren": "Allüre",
    "Almas": "Alma",
    "Almen": "Alm",
    "Alpen": "Alpe",
    "Alpenrosen": "Alpenrose",
    "Alpenveilchens": "Alpenveilchen",
    "Alphabete": "Alphabet",
    "Alphabeten": "Alphabet",
    "Alphabetes": "Alphabet",
    "Alphabetische": "alphabetisch",
    "Alphabetischen": "Alphabetische",
    "Alphabetisierenden": "Alphabetisierende",
    "Alphabetisierenderen": "Alphabetisierendere",
    "Alphabetisierens": "Alphabetisieren",
    "Alphabetisierte": "alphabetisiert",
    "Alphabetisierten": "Alphabetisierte",
    "Alphabetisierteren": "Alphabetisiertere",
    "Alphabets": "Alphabet",
    "Alphanumerische": "alphanumerisch",
    "Alphanumerischen": "Alphanumerische",
    "Alphateilchens": "Alphateilchen",
    "Alpine": "alpin",
    "Alpinen": "Alpine",
    "Alpinisten": "Alpinist",
    "Alptraume": "Alptraum",
    "Alptraumes": "Alptraum",
    "Alptraums": "Alptraum",
    "Alpträume": "Alptraum",
    "Alpträumen": "Alptraum",
    "Alsbaldige": "alsbaldig",
    "Alsbaldigen": "Alsbaldige",
    "Altare": "Altar",
    "Altars": "Altar",
    "Altbewährte": "altbewährt",
    "Altbewährten": "Altbewährte",
    "Altbewährteren": "Altbewährtere",
    "Altbewährtesten": "Altbewährteste",
    "Altdeutschen": "Altdeutsche",
    "Alteingesessene": "alteingesessen",
    "Alteingesessenen": "Alteingesessene",
    "Alteingesesseneren": "Alteingesessenere",
    "Alteingewurzelten": "Alteingewurzelte",
    "Alten": "Alte",
    "Altenstadts": "Altenstadt",
    "Alter": "alt",
    "Alterationen": "Alteration",
    "Alterierenden": "Alterierende",
    "Alterierenderen": "Alterierendere",
    "Alterierendsten": "Alterierendste",
    "Alterierens": "Alterieren",
    "Alterierte": "alteriert",
    "Alterierten": "Alterierte",
    "Alterierteren": "Alteriertere",
    "Alteriertesten": "Alterierteste",
    "Altern": "Alter",
    "Alternationen": "Alternation",
    "Alternative": "alternativ",
    "Alternativen": "Alternative",
    "Alternativeren": "Alternativere",
    "Alternativsten": "Alternativste",
    "Alternden": "Alternde",
    "Alternderen": "Alterndere",
    "Alterndsten": "Alterndste",
    "Alternierenden": "Alternierende",
    "Alternierenderen": "Alternierendere",
    "Alternierendsten": "Alternierendste",
    "Alternierens": "Alternieren",
    "Alternierte": "alterniert",
    "Alternierten": "Alternierte",
    "Alterns": "Altern",
    "Alters": "Alter",
    "Altersbedingte": "altersbedingt",
    "Altersbedingten": "Altersbedingte",
    "Altersgrenzen": "Altersgrenze",
    "Altersschwache": "altersschwach",
    "Altersschwachen": "Altersschwache",
    "Altersschwächeren": "Altersschwächere",
    "Altersstufen": "Altersstufe",
    "Altertums": "Altertum",
    "Altertümlern": "Altertümler",
    "Altertümlers": "Altertümler",
    "Altertümliche": "altertümlich",
    "Altertümlichen": "Altertümliche",
    "Altertümlicheren": "Altertümlichere",
    "Altertümlichsten": "Altertümlichste",
    "Altfranzösischen": "Altfranzösische",
    "Altfranzösischeren": "Altfranzösischere",
    "Altfränkischen": "Altfränkische",
    "Altfränkischeren": "Altfränkischere",
    "Altfränkischsten": "Altfränkischste",
    "Altgeigen": "Altgeige",
    "Altgriechische": "altgriechisch",
    "Altgriechischen": "Altgriechische",
    "Althergebrachten": "Althergebrachte",
    "Altherrenmannschaften": "Altherrenmannschaft",
    "Althochdeutsche": "althochdeutsch",
    "Althochdeutschen": "Althochdeutsche",
    "Altindischen": "Altindische",
    "Altisten": "Altist",
    "Altistinnen": "Altistin",
    "Altkatholische": "altkatholisch",
    "Altkatholischen": "Altkatholische",
    "Altkatholischeren": "Altkatholischere",
    "Altkatholischsten": "Altkatholischste",
    "Altklarinetten": "Altklarinette",
    "Altkluge": "altklug",
    "Altklugen": "Altkluge",
    "Altklügeren": "Altklügere",
    "Altmodischen": "Altmodische",
    "Altmodischeren": "Altmodischere",
    "Altmodischsten": "Altmodischste",
    "Altonas": "Altona",
    "Altpapiere": "Altpapier",
    "Altpapieren": "Altpapier",
    "Altpapieres": "Altpapier",
    "Altpapiers": "Altpapier",
    "Altpreußische": "altpreußisch",
    "Altpreußischen": "Altpreußische",
    "Alts": "Alt",
    "Altsprachliche": "altsprachlich",
    "Altsprachlichen": "Altsprachliche",
    "Altstädte": "Altstadt",
    "Altstädten": "Altstadt",
    "Alttestamentarische": "alttestamentarisch",
    "Alttestamentarischen": "Alttestamentarische",
    "Alttestamentlichen": "Alttestamentliche",
    "Altweiberknotens": "Altweiberknoten",
    "Altäre": "Altar",
    "Altären": "Altar",
    "Altöle": "Altöl",
    "Altölen": "Altöl",
    "Altöls": "Altöl",
    "Altüberlieferten": "Altüberlieferte",
    "Aluminiums": "Aluminium",
    "Alzenaus": "Alzenau",
    "Amateure": "Amateur",
    "Amateuren": "Amateur",
    "Amateures": "Amateur",
    "Amateurs": "Amateur",
    "Amazonen": "Amazone",
    "Ambientes": "Ambiente",
    "Ambiguitäten": "Ambiguität",
    "Ambitionen": "Ambition",
    "Ambitionierte": "ambitioniert",
    "Ambitionierten": "Ambitionierte",
    "Ambitionierteren": "Ambitioniertere",
    "Ambitioniertesten": "Ambitionierteste",
    "Ambosse": "Amboß",
    "Ambossen": "Amboß",
    "Ambosses": "Amboß",
    "Ambulante": "ambulant",
    "Ambulanten": "Ambulante",
    "Ambulanzen": "Ambulanz",
    "Ameisen": "Ameise",
    "Amens": "Amen",
    "Amerikanerinnen": "Amerikanerin",
    "Amerikanern": "Amerikaner",
    "Amerikaners": "Amerikaner",
    "Amerikanische": "amerikanisch",
    "Amerikanischen": "Amerikanische",
    "Amerikanischeren": "Amerikanischere",
    "Amerikanischsten": "Amerikanischste",
    "Amerikanisierenden": "Amerikanisierende",
    "Amerikanisierenderen": "Amerikanisierendere",
    "Amerikanisierens": "Amerikanisieren",
    "Amerikanisierte": "amerikanisiert",
    "Amerikanisierten": "Amerikanisierte",
    "Amerikanisierteren": "Amerikanisiertere",
    "Amerikanisten": "Amerikanist",
    "Amerikas": "Amerika",
    "Amis": "Ami",
    "Ammen": "Amme",
    "Ammern": "Ammer",
    "Ammoniaks": "Ammoniak",
    "Ammoniten": "Ammonit",
    "Ammoniums": "Ammonium",
    "Amnesien": "Amnesie",
    "Amnestien": "Amnestie",
    "Amoklaufens": "Amoklaufen",
    "Amokläufern": "Amokläufer",
    "Amokläufers": "Amokläufer",
    "Amokschützen": "Amokschütze",
    "Amors": "Amor",
    "Amortisationen": "Amortisation",
    "Amortisierenden": "Amortisierende",
    "Amortisierenderen": "Amortisierendere",
    "Amortisierendsten": "Amortisierendste",
    "Amortisierens": "Amortisieren",
    "Amortisierte": "amortisiert",
    "Amortisierten": "Amortisierte",
    "Amortisierteren": "Amortisiertere",
    "Amortisiertesten": "Amortisierteste",
    "Amortisierungen": "Amortisierung",
    "Ampelmasten": "Ampelmast",
    "Ampeln": "Ampel",
    "Amperes": "Ampere",
    "Ampfern": "Ampfer",
    "Ampfers": "Ampfer",
    "Amphibien": "Amphibie",
    "Ampullen": "Ampulle",
    "Amputationen": "Amputation",
    "Amputierenden": "Amputierende",
    "Amputierens": "Amputieren",
    "Amputierte": "amputiert",
    "Amputierten": "Amputierte",
    "Amseln": "Amsel",
    "Amsterdams": "Amsterdam",
    "Amte": "Amt",
    "Amtes": "Amt",
    "Amtierenden": "Amtierende",
    "Amtierens": "Amtieren",
    "Amtierte": "amtiert",
    "Amtierten": "Amtierte",
    "Amtlichen": "Amtliche",
    "Amtlicheren": "Amtlichere",
    "Amtlichsten": "Amtlichste",
    "Amtmanne": "Amtmann",
    "Amtmannes": "Amtmann",
    "Amtmanns": "Amtmann",
    "Amtmänner": "Amtmann",
    "Amtmännern": "Amtmann",
    "Amts": "Amt",
    "Amtsmüderen": "Amtsmüdere",
    "Amtsmüdesten": "Amtsmüdeste",
    "Amöben": "Amöbe",
    "Amüsanten": "Amüsante",
    "Amüsanteren": "Amüsantere",
    "Amüsantesten": "Amüsanteste",
    "Amüsierenden": "Amüsierende",
    "Amüsierenderen": "Amüsierendere",
    "Amüsierendsten": "Amüsierendste",
    "Amüsierens": "Amüsieren",
    "Amüsierte": "amüsiert",
    "Amüsierten": "Amüsierte",
    "Amüsierteren": "Amüsiertere",
    "Amüsiertesten": "Amüsierteste",
    "Anabaptisten": "Anabaptist",
    "Anabolien": "Anabolie",
    "Anagenesen": "Anagenese",
    "Anagramme": "Anagramm",
    "Anagrammen": "Anagramm",
    "Anagramms": "Anagramm",
    "Anakondas": "Anakonda",
    "Analoge": "analog",
    "Analogen": "Analoge",
    "Analogien": "Analogie",
    "Analogrechnern": "Analogrechner",
    "Analogrechners": "Analogrechner",
    "Analphabeten": "Analphabet",
    "Analphabetentume": "Analphabetentum",
    "Analphabetentumes": "Analphabetentum",
    "Analphabetentums": "Analphabetentum",
    "Analphabetentümer": "Analphabetentum",
    "Analphabetentümern": "Analphabetentum",
    "Analysatore": "Analysator",
    "Analysatoren": "Analysator",
    "Analysators": "Analysator",
    "Analysen": "Analyse",
    "Analysierenden": "Analysierende",
    "Analysierens": "Analysieren",
    "Analysierte": "analysiert",
    "Analysierten": "Analysierte",
    "Analytikern": "Analytiker",
    "Analytikers": "Analytiker",
    "Analytische": "analytisch",
    "Analytischen": "Analytische",
    "Anarchien": "Anarchie",
    "Anatomien": "Anatomie",
    "Anatomische": "anatomisch",
    "Anatomischen": "Anatomische",
    "Anbackenden": "Anbackende",
    "Anbackenderen": "Anbackendere",
    "Anbackendsten": "Anbackendste",
    "Anbackens": "Anbacken",
    "Anbaggernden": "Anbaggernde",
    "Anbaggerns": "Anbaggern",
    "Anbahnenden": "Anbahnende",
    "Anbahnens": "Anbahnen",
    "Anbandelnden": "Anbandelnde",
    "Anbandelns": "Anbandeln",
    "Anbauenden": "Anbauende",
    "Anbauens": "Anbauen",
    "Anbaufähigen": "Anbaufähige",
    "Anbaufähigeren": "Anbaufähigere",
    "Anbaufähigsten": "Anbaufähigste",
    "Anbauküchen": "Anbauküche",
    "Anbauraupen": "Anbauraupe",
    "Anbaus": "Anbau",
    "Anbauten": "anbauen",
    "Anbauwände": "Anbauwand",
    "Anbauwänden": "Anbauwand",
    "Anbeginns": "Anbeginn",
    "Anbehaltenden": "Anbehaltende",
    "Anbehaltenen": "Anbehaltene",
    "Anbehaltens": "Anbehalten",
    "Anbeißenden": "Anbeißende",
    "Anbeißens": "Anbeißen",
    "Anbelangenden": "Anbelangende",
    "Anbelangens": "Anbelangen",
    "Anbelangte": "anbelangt",
    "Anbelangten": "Anbelangte",
    "Anbequemenden": "Anbequemende",
    "Anbequemens": "Anbequemen",
    "Anbequemte": "anbequemt",
    "Anbequemten": "Anbequemte",
    "Anberaumenden": "Anberaumende",
    "Anberaumens": "Anberaumen",
    "Anberaumte": "anberaumt",
    "Anberaumten": "Anberaumte",
    "Anbetenden": "Anbetende",
    "Anbetens": "Anbeten",
    "Anbetern": "Anbeter",
    "Anbeters": "Anbeter",
    "Anbetreffenden": "Anbetreffende",
    "Anbetreffens": "Anbetreffen",
    "Anbetroffenen": "Anbetroffene",
    "Anbettelnden": "Anbettelnde",
    "Anbettelnderen": "Anbettelndere",
    "Anbettelndsten": "Anbettelndste",
    "Anbettelns": "Anbetteln",
    "Anbiedernden": "Anbiedernde",
    "Anbiedernderen": "Anbiederndere",
    "Anbiederndsten": "Anbiederndste",
    "Anbiederns": "Anbiedern",
    "Anbiederungen": "Anbiederung",
    "Anbietenden": "Anbietende",
    "Anbietens": "Anbieten",
    "Anbietern": "Anbieter",
    "Anbieters": "Anbieter",
    "Anbindenden": "Anbindende",
    "Anbindens": "Anbinden",
    "Anbindungen": "Anbindung",
    "Anblaffenden": "Anblaffende",
    "Anblaffenderen": "Anblaffendere",
    "Anblaffendsten": "Anblaffendste",
    "Anblaffens": "Anblaffen",
    "Anblasenden": "Anblasende",
    "Anblasens": "Anblasen",
    "Anblicke": "anblicken",
    "Anblicken": "Anblick",
    "Anblickenden": "Anblickende",
    "Anblickens": "Anblicken",
    "Anblicks": "Anblick",
    "Anblinzelnden": "Anblinzelnde",
    "Anblinzelns": "Anblinzeln",
    "Anblitzenden": "Anblitzende",
    "Anblitzens": "Anblitzen",
    "Anbohrenden": "Anbohrende",
    "Anbohrens": "Anbohren",
    "Anbratenden": "Anbratende",
    "Anbratens": "Anbraten",
    "Anbrechenden": "Anbrechende",
    "Anbrechens": "Anbrechen",
    "Anbremsenden": "Anbremsende",
    "Anbremsens": "Anbremsen",
    "Anbrennenden": "Anbrennende",
    "Anbrennenderen": "Anbrennendere",
    "Anbrennendsten": "Anbrennendste",
    "Anbrennens": "Anbrennen",
    "Anbringenden": "Anbringende",
    "Anbringens": "Anbringen",
    "Anbrummenden": "Anbrummende",
    "Anbrummens": "Anbrummen",
    "Anbrüllenden": "Anbrüllende",
    "Anbrüllens": "Anbrüllen",
    "Anbrütenden": "Anbrütende",
    "Anbrütens": "Anbrüten",
    "Andachten": "andenken",
    "Andauernden": "Andauernde",
    "Andauerns": "Andauern",
    "Andenkenden": "Andenkende",
    "Andenkens": "Andenken",
    "Anderen": "Andere",
    "Andersartigen": "Andersartige",
    "Andersgearteten": "Andersgeartete",
    "Andersgläubigen": "Andersgläubige",
    "Anderssprachigen": "Anderssprachige",
    "Anderweitigen": "Anderweitige",
    "Andeutenden": "Andeutende",
    "Andeutens": "Andeuten",
    "Andeutungen": "Andeutung",
    "Andichtenden": "Andichtende",
    "Andichtens": "Andichten",
    "Andienenden": "Andienende",
    "Andienens": "Andienen",
    "Andis": "Andi",
    "Andiskutierenden": "Andiskutierende",
    "Andiskutierens": "Andiskutieren",
    "Andiskutierte": "andiskutiert",
    "Andiskutierten": "Andiskutierte",
    "Andrange": "Andrang",
    "Andranges": "Andrang",
    "Andrangs": "Andrang",
    "Andreas": "Andrea",
    "Andrehenden": "Andrehende",
    "Andrehens": "Andrehen",
    "Andrews": "Andrew",
    "Andringenden": "Andringende",
    "Andringens": "Andringen",
    "Androhenden": "Androhende",
    "Androhens": "Androhen",
    "Andrucke": "Andruck",
    "Andrucken": "Andruck",
    "Andruckkissens": "Andruckkissen",
    "Andrucks": "Andruck",
    "Andränge": "andrängen",
    "Andrängen": "andringen",
    "Andrängenden": "Andrängende",
    "Andrängens": "Andrängen",
    "Andächtigen": "Andächtige",
    "Andächtigeren": "Andächtigere",
    "Andächtigsten": "Andächtigste",
    "Aneignenden": "Aneignende",
    "Aneignens": "Aneignen",
    "Aneinanderfügenden": "Aneinanderfügende",
    "Aneinanderfügens": "Aneinanderfügen",
    "Aneinandergefügte": "aneinandergefügt",
    "Aneinandergefügten": "Aneinandergefügte",
    "Aneinandergegrenzte": "aneinandergegrenzt",
    "Aneinandergegrenzten": "Aneinandergegrenzte",
    "Aneinandergehangenen": "Aneinandergehangene",
    "Aneinandergehängte": "aneinandergehängt",
    "Aneinandergehängten": "Aneinandergehängte",
    "Aneinandergeratenden": "Aneinandergeratende",
    "Aneinandergeratenen": "Aneinandergeratene",
    "Aneinandergeratens": "Aneinandergeraten",
    "Aneinandergrenzenden": "Aneinandergrenzende",
    "Aneinandergrenzens": "Aneinandergrenzen",
    "Aneinanderhängenden": "Aneinanderhängende",
    "Aneinanderhängenderen": "Aneinanderhängendere",
    "Aneinanderhängens": "Aneinanderhängen",
    "Anekdoten": "Anekdote",
    "Anekelnden": "Anekelnde",
    "Anekelnderen": "Anekelndere",
    "Anekelndsten": "Anekelndste",
    "Anekelns": "Anekeln",
    "Anemonen": "Anemone",
    "Anerben": "Anerbe",
    "Anerkannte": "anerkennen",
    "Anerkannten": "anerkennen",
    "Anerkannteren": "Anerkanntere",
    "Anerkanntesten": "Anerkannteste",
    "Anerkennenden": "Anerkennende",
    "Anerkennenderen": "Anerkennendere",
    "Anerkennendsten": "Anerkennendste",
    "Anerkennens": "Anerkennen",
    "Anerkennenswerte": "anerkennenswert",
    "Anerkennenswerten": "Anerkennenswerte",
    "Anerkennenswerteren": "Anerkennenswertere",
    "Anerkenntnisn": "Anerkenntnis",
    "Anerkennungen": "Anerkennung",
    "Anerziehenden": "Anerziehende",
    "Anerziehens": "Anerziehen",
    "Anerzogenen": "Anerzogene",
    "Anfachenden": "Anfachende",
    "Anfachens": "Anfachen",
    "Anfahrenden": "Anfahrende",
    "Anfahrens": "Anfahren",
    "Anfahrten": "Anfahrt",
    "Anfalle": "anfallen",
    "Anfallenden": "Anfallende",
    "Anfallens": "Anfallen",
    "Anfalls": "Anfall",
    "Anfange": "anfangen",
    "Anfangenden": "Anfangende",
    "Anfangens": "Anfangen",
    "Anfangs": "Anfang",
    "Anfassenden": "Anfassende",
    "Anfassens": "Anfassen",
    "Anfauchenden": "Anfauchende",
    "Anfauchenderen": "Anfauchendere",
    "Anfauchendsten": "Anfauchendste",
    "Anfauchens": "Anfauchen",
    "Anfaulenden": "Anfaulende",
    "Anfaulenderen": "Anfaulendere",
    "Anfaulendsten": "Anfaulendste",
    "Anfaulens": "Anfaulen",
    "Anfaxenden": "Anfaxende",
    "Anfaxens": "Anfaxen",
    "Anfechtbaren": "Anfechtbare",
    "Anfechtbareren": "Anfechtbarere",
    "Anfechtbarsten": "Anfechtbarste",
    "Anfechtenden": "Anfechtende",
    "Anfechtens": "Anfechten",
    "Anfeindenden": "Anfeindende",
    "Anfeindenderen": "Anfeindendere",
    "Anfeindendsten": "Anfeindendste",
    "Anfeindens": "Anfeinden",
    "Anfeindungen": "Anfeindung",
    "Anfertigenden": "Anfertigende",
    "Anfertigens": "Anfertigen",
    "Anfertigungen": "Anfertigung",
    "Anfeuchtenden": "Anfeuchtende",
    "Anfeuchtenderen": "Anfeuchtendere",
    "Anfeuchtendsten": "Anfeuchtendste",
    "Anfeuchtens": "Anfeuchten",
    "Anfeuernden": "Anfeuernde",
    "Anfeuernderen": "Anfeuerndere",
    "Anfeuerndsten": "Anfeuerndste",
    "Anfeuerns": "Anfeuern",
    "Anfeuerungen": "Anfeuerung",
    "Anfindenden": "Anfindende",
    "Anfindens": "Anfinden",
    "Anfixenden": "Anfixende",
    "Anfixens": "Anfixen",
    "Anflehenden": "Anflehende",
    "Anflehenderen": "Anflehendere",
    "Anflehendsten": "Anflehendste",
    "Anflehens": "Anflehen",
    "Anfliegenden": "Anfliegende",
    "Anfliegens": "Anfliegen",
    "Anfluge": "Anflug",
    "Anflughöhen": "Anflughöhe",
    "Anflugs": "Anflug",
    "Anflüge": "Anflug",
    "Anflügen": "Anflug",
    "Anfordernden": "Anfordernde",
    "Anforderns": "Anfordern",
    "Anforderungen": "Anforderung",
    "Anfrage": "anfragen",
    "Anfragen": "Anfrage",
    "Anfragenden": "Anfragende",
    "Anfragens": "Anfragen",
    "Anfressenden": "Anfressende",
    "Anfressenderen": "Anfressendere",
    "Anfressendsten": "Anfressendste",
    "Anfressens": "Anfressen",
    "Anfreundenden": "Anfreundende",
    "Anfreundens": "Anfreunden",
    "Anfrierenden": "Anfrierende",
    "Anfrierenderen": "Anfrierendere",
    "Anfrierendsten": "Anfrierendste",
    "Anfrierens": "Anfrieren",
    "Anfunkelnden": "Anfunkelnde",
    "Anfunkelns": "Anfunkeln",
    "Anfunkenden": "Anfunkende",
    "Anfunkens": "Anfunken",
    "Anfälle": "Anfall",
    "Anfällen": "Anfall",
    "Anfälligen": "Anfällige",
    "Anfälligeren": "Anfälligere",
    "Anfälligsten": "Anfälligste",
    "Anfänge": "Anfang",
    "Anfängen": "Anfang",
    "Anfängern": "Anfänger",
    "Anfängers": "Anfänger",
    "Anfänglichen": "Anfängliche",
    "Anfügenden": "Anfügende",
    "Anfügens": "Anfügen",
    "Anfühlenden": "Anfühlende",
    "Anfühlens": "Anfühlen",
    "Anführenden": "Anführende",
    "Anführens": "Anführen",
    "Anführungen": "Anführung",
    "Anführungszeichens": "Anführungszeichen",
    "Anfüllenden": "Anfüllende",
    "Anfüllens": "Anfüllen",
    "Angaben": "angeben",
    "Angaffenden": "Angaffende",
    "Angaffenderen": "Angaffendere",
    "Angaffendsten": "Angaffendste",
    "Angaffens": "Angaffen",
    "Angaloppierenden": "Angaloppierende",
    "Angaloppierens": "Angaloppieren",
    "Angaloppierte": "angaloppiert",
    "Angaloppierten": "Angaloppierte",
    "Angebackenen": "Angebackene",
    "Angebackeneren": "Angebackenere",
    "Angebackensten": "Angebackenste",
    "Angebaggerten": "Angebaggerte",
    "Angebahnten": "Angebahnte",
    "Angebandelten": "Angebandelte",
    "Angebauten": "Angebaute",
    "Angebenden": "Angebende",
    "Angebenderen": "Angebendere",
    "Angebendsten": "Angebendste",
    "Angebens": "Angeben",
    "Angebereien": "Angeberei",
    "Angeberische": "angeberisch",
    "Angeberischen": "Angeberische",
    "Angeberischeren": "Angeberischere",
    "Angeberischsten": "Angeberischste",
    "Angebeteten": "Angebetete",
    "Angebettelten": "Angebettelte",
    "Angebettelteren": "Angebetteltere",
    "Angebetteltesten": "Angebettelteste",
    "Angebiederten": "Angebiederte",
    "Angebiederteren": "Angebiedertere",
    "Angebiedertesten": "Angebiederteste",
    "Angebinden": "Angebinde",
    "Angebindes": "Angebinde",
    "Angebissenen": "Angebissene",
    "Angebisseneren": "Angebissenere",
    "Angebissensten": "Angebissenste",
    "Angeblafften": "Angeblaffte",
    "Angeblaffteren": "Angeblafftere",
    "Angeblafftesten": "Angeblaffteste",
    "Angeblasenen": "Angeblasene",
    "Angeblichen": "Angebliche",
    "Angeblickten": "Angeblickte",
    "Angeblickteren": "Angeblicktere",
    "Angeblicktesten": "Angeblickteste",
    "Angeblinzelten": "Angeblinzelte",
    "Angeblitzten": "Angeblitzte",
    "Angebohrten": "Angebohrte",
    "Angeborenen": "Angeborene",
    "Angebote": "Angebot",
    "Angeboten": "Angebot",
    "Angebotene": "angeboten",
    "Angebotenen": "Angebotene",
    "Angebots": "Angebot",
    "Angebrachten": "Angebrachte",
    "Angebrachteren": "Angebrachtere",
    "Angebrachtesten": "Angebrachteste",
    "Angebrannten": "Angebrannte",
    "Angebrannteren": "Angebranntere",
    "Angebranntesten": "Angebrannteste",
    "Angebratenen": "Angebratene",
    "Angebrateneren": "Angebratenere",
    "Angebratensten": "Angebratenste",
    "Angebremsten": "Angebremste",
    "Angebrochenen": "Angebrochene",
    "Angebrocheneren": "Angebrochenere",
    "Angebrochensten": "Angebrochenste",
    "Angebrummten": "Angebrummte",
    "Angebrüllten": "Angebrüllte",
    "Angebrüteten": "Angebrütete",
    "Angebundenen": "Angebundene",
    "Angedachten": "Angedachte",
    "Angedauerten": "Angedauerte",
    "Angedeuteten": "Angedeutete",
    "Angedichteten": "Angedichtete",
    "Angedienten": "Angediente",
    "Angedrehten": "Angedrehte",
    "Angedrohten": "Angedrohte",
    "Angedrungenen": "Angedrungene",
    "Angedrängten": "Angedrängte",
    "Angeeigneten": "Angeeignete",
    "Angeekelten": "Angeekelte",
    "Angeekelteren": "Angeekeltere",
    "Angeekeltesten": "Angeekelteste",
    "Angefachten": "Angefachte",
    "Angefahrenen": "Angefahrene",
    "Angefallenen": "Angefallene",
    "Angefalleneren": "Angefallenere",
    "Angefallensten": "Angefallenste",
    "Angefangenen": "Angefangene",
    "Angefauchten": "Angefauchte",
    "Angefauchteren": "Angefauchtere",
    "Angefauchtesten": "Angefauchteste",
    "Angefaulten": "Angefaulte",
    "Angefaulteren": "Angefaultere",
    "Angefaultesten": "Angefaulteste",
    "Angefaxten": "Angefaxte",
    "Angefaßten": "Angefaßte",
    "Angefeindeten": "Angefeindete",
    "Angefeindeteren": "Angefeindetere",
    "Angefeindetesten": "Angefeindeteste",
    "Angefertigten": "Angefertigte",
    "Angefeuchteten": "Angefeuchtete",
    "Angefeuchteteren": "Angefeuchtetere",
    "Angefeuchtetesten": "Angefeuchteteste",
    "Angefeuerten": "Angefeuerte",
    "Angefeuerteren": "Angefeuertere",
    "Angefeuertesten": "Angefeuerteste",
    "Angefixten": "Angefixte",
    "Angeflehten": "Angeflehte",
    "Angeflehteren": "Angeflehtere",
    "Angeflehtesten": "Angeflehteste",
    "Angeflogenen": "Angeflogene",
    "Angefochtenen": "Angefochtene",
    "Angeforderten": "Angeforderte",
    "Angefragten": "Angefragte",
    "Angefressenen": "Angefressene",
    "Angefresseneren": "Angefressenere",
    "Angefressensten": "Angefressenste",
    "Angefreundeten": "Angefreundete",
    "Angefrorenen": "Angefrorene",
    "Angefroreneren": "Angefrorenere",
    "Angefrorensten": "Angefrorenste",
    "Angefundenen": "Angefundene",
    "Angefunkelten": "Angefunkelte",
    "Angefunkten": "Angefunkte",
    "Angefügten": "Angefügte",
    "Angefühlten": "Angefühlte",
    "Angeführten": "Angeführte",
    "Angefüllten": "Angefüllte",
    "Angegafften": "Angegaffte",
    "Angegaffteren": "Angegafftere",
    "Angegafftesten": "Angegaffteste",
    "Angegangenen": "Angegangene",
    "Angegebenen": "Angegebene",
    "Angegifteten": "Angegiftete",
    "Angegifteteren": "Angegiftetere",
    "Angegiftetesten": "Angegifteteste",
    "Angeglichenen": "Angeglichene",
    "Angeglicheneren": "Angeglichenere",
    "Angeglichensten": "Angeglichenste",
    "Angegliederten": "Angegliederte",
    "Angegliederteren": "Angegliedertere",
    "Angegliedertesten": "Angegliederteste",
    "Angeglotzten": "Angeglotzte",
    "Angeglotzteren": "Angeglotztere",
    "Angeglotztesten": "Angeglotzteste",
    "Angegossenen": "Angegossene",
    "Angegrauten": "Angegraute",
    "Angegrauteren": "Angegrautere",
    "Angegrautesten": "Angegrauteste",
    "Angegrenzten": "Angegrenzte",
    "Angegriffenen": "Angegriffene",
    "Angegriffeneren": "Angegriffenere",
    "Angegriffensten": "Angegriffenste",
    "Angegrinsten": "Angegrinste",
    "Angegrinsteren": "Angegrinstere",
    "Angegrinstesten": "Angegrinsteste",
    "Angegurteten": "Angegurtete",
    "Angehafteten": "Angehaftete",
    "Angehakten": "Angehakte",
    "Angehalfterten": "Angehalfterte",
    "Angehaltenen": "Angehaltene",
    "Angehauchten": "Angehauchte",
    "Angehauenen": "Angehauene",
    "Angehefteten": "Angeheftete",
    "Angeheimelten": "Angeheimelte",
    "Angeheirateten": "Angeheiratete",
    "Angeheiterten": "Angeheiterte",
    "Angeheiterteren": "Angeheitertere",
    "Angeheitertesten": "Angeheiterteste",
    "Angeheizten": "Angeheizte",
    "Angeheizteren": "Angeheiztere",
    "Angeheiztesten": "Angeheizteste",
    "Angehenden": "Angehende",
    "Angehens": "Angehen",
    "Angeheuerten": "Angeheuerte",
    "Angehimmelten": "Angehimmelte",
    "Angehimmelteren": "Angehimmeltere",
    "Angehimmeltesten": "Angehimmelteste",
    "Angehobenen": "Angehobene",
    "Angeholten": "Angeholte",
    "Angehängten": "Angehängte",
    "Angehärteten": "Angehärtete",
    "Angehärteteren": "Angehärtetere",
    "Angehärtetesten": "Angehärteteste",
    "Angehörenden": "Angehörende",
    "Angehörens": "Angehören",
    "Angehörigen": "Angehörige",
    "Angehörte": "angehört",
    "Angehörten": "Angehörte",
    "Angejagten": "Angejagte",
    "Angejahrten": "Angejahrte",
    "Angejahrteren": "Angejahrtere",
    "Angejahrtesten": "Angejahrteste",
    "Angekauften": "Angekaufte",
    "Angekeilten": "Angekeilte",
    "Angekeilteren": "Angekeiltere",
    "Angekeiltesten": "Angekeilteste",
    "Angeketteten": "Angekettete",
    "Angeklagten": "Angeklagte",
    "Angeklammerten": "Angeklammerte",
    "Angeklebten": "Angeklebte",
    "Angekleideten": "Angekleidete",
    "Angeklingelten": "Angeklingelte",
    "Angeklopften": "Angeklopfte",
    "Angeklungenen": "Angeklungene",
    "Angeknabberten": "Angeknabberte",
    "Angeknabberteren": "Angeknabbertere",
    "Angeknabbertesten": "Angeknabberteste",
    "Angeknacksten": "Angeknackste",
    "Angeknacksteren": "Angeknackstere",
    "Angeknackstesten": "Angeknacksteste",
    "Angeknipsten": "Angeknipste",
    "Angeknöpften": "Angeknöpfte",
    "Angeknüpften": "Angeknüpfte",
    "Angekohlten": "Angekohlte",
    "Angekohlteren": "Angekohltere",
    "Angekohltesten": "Angekohlteste",
    "Angekommenen": "Angekommene",
    "Angekoppelten": "Angekoppelte",
    "Angekotzten": "Angekotzte",
    "Angekrallten": "Angekrallte",
    "Angekreideten": "Angekreidete",
    "Angekreuzten": "Angekreuzte",
    "Angekuppelten": "Angekuppelte",
    "Angekurbelten": "Angekurbelte",
    "Angekurbelteren": "Angekurbeltere",
    "Angekurbeltesten": "Angekurbelteste",
    "Angekämpften": "Angekämpfte",
    "Angeköderten": "Angeköderte",
    "Angekündigten": "Angekündigte",
    "Angelachten": "Angelachte",
    "Angelagerten": "Angelagerte",
    "Angelas": "Angela",
    "Angelassenen": "Angelassene",
    "Angelasteten": "Angelastete",
    "Angelaufenen": "Angelaufene",
    "Angelauteten": "Angelautete",
    "Angelegenen": "Angelegene",
    "Angelegenheiten": "Angelegenheit",
    "Angelegten": "Angelegte",
    "Angelehnten": "Angelehnte",
    "Angeleimten": "Angeleimte",
    "Angeleinten": "Angeleinte",
    "Angeleiteten": "Angeleitete",
    "Angelernten": "Angelernte",
    "Angelesenen": "Angelesene",
    "Angeleuchteten": "Angeleuchtete",
    "Angelieferten": "Angelieferte",
    "Angelikas": "Angelika",
    "Angelnden": "Angelnde",
    "Angelnderen": "Angelndere",
    "Angelndsten": "Angelndste",
    "Angelns": "Angeln",
    "Angelogenen": "Angelogene",
    "Angelogeneren": "Angelogenere",
    "Angelogensten": "Angelogenste",
    "Angelsächsischen": "Angelsächsische",
    "Angelusläutens": "Angelusläuten",
    "Angelächelten": "Angelächelte",
    "Angeläutete": "angeläutet",
    "Angeläuteten": "Angeläutete",
    "Angelöteten": "Angelötete",
    "Angemachten": "Angemachte",
    "Angemahnten": "Angemahnte",
    "Angemalten": "Angemalte",
    "Angemalteren": "Angemaltere",
    "Angemaltesten": "Angemalteste",
    "Angemaßten": "Angemaßte",
    "Angemeldeten": "Angemeldete",
    "Angemerkten": "Angemerkte",
    "Angemessenen": "Angemessene",
    "Angemesseneren": "Angemessenere",
    "Angemessensten": "Angemessenste",
    "Angemieteten": "Angemietete",
    "Angemotzten": "Angemotzte",
    "Angemotzteren": "Angemotztere",
    "Angemotztesten": "Angemotzteste",
    "Angemusterten": "Angemusterte",
    "Angemuteten": "Angemutete",
    "Angenagelten": "Angenagelte",
    "Angenagten": "Angenagte",
    "Angenagteren": "Angenagtere",
    "Angenagtesten": "Angenagteste",
    "Angenehmen": "Angenehme",
    "Angenehmeren": "Angenehmere",
    "Angenehmsten": "Angenehmste",
    "Angenieteten": "Angenietete",
    "Angenommenen": "Angenommene",
    "Angenommeneren": "Angenommenere",
    "Angenommensten": "Angenommenste",
    "Angenäherten": "Angenäherte",
    "Angenähten": "Angenähte",
    "Angeordneten": "Angeordnete",
    "Angeordneteren": "Angeordnetere",
    "Angeordnetesten": "Angeordneteste",
    "Angepackten": "Angepackte",
    "Angepaddelten": "Angepaddelte",
    "Angepaßten": "Angepaßte",
    "Angepaßteren": "Angepaßtere",
    "Angepaßtesten": "Angepaßteste",
    "Angepaßtheiten": "Angepaßtheit",
    "Angepeilten": "Angepeilte",
    "Angepfiffenen": "Angepfiffene",
    "Angepflanzten": "Angepflanzte",
    "Angepflaumten": "Angepflaumte",
    "Angepflaumteren": "Angepflaumtere",
    "Angepflaumtesten": "Angepflaumteste",
    "Angepirschten": "Angepirschte",
    "Angeprallten": "Angeprallte",
    "Angeprangerten": "Angeprangerte",
    "Angeprangerteren": "Angeprangertere",
    "Angeprangertesten": "Angeprangerteste",
    "Angepreßten": "Angepreßte",
    "Angepriesenen": "Angepriesene",
    "Angeprieseneren": "Angepriesenere",
    "Angepriesensten": "Angepriesenste",
    "Angepumpten": "Angepumpte",
    "Angeputzten": "Angeputzte",
    "Angepöbelten": "Angepöbelte",
    "Angepöbelteren": "Angepöbeltere",
    "Angepöbeltesten": "Angepöbelteste",
    "Angequälten": "Angequälte",
    "Angerannten": "Angerannte",
    "Angeranzten": "Angeranzte",
    "Angeranzteren": "Angeranztere",
    "Angeranztesten": "Angeranzteste",
    "Angeratenen": "Angeratene",
    "Angerauhten": "Angerauhte",
    "Angerauhteren": "Angerauhtere",
    "Angerauhtesten": "Angerauhteste",
    "Angerechneten": "Angerechnete",
    "Angeredeten": "Angeredete",
    "Angeregten": "Angeregte",
    "Angeregteren": "Angeregtere",
    "Angeregtesten": "Angeregteste",
    "Angereicherten": "Angereicherte",
    "Angereichten": "Angereichte",
    "Angereihten": "Angereihte",
    "Angereisten": "Angereiste",
    "Angereizten": "Angereizte",
    "Angereizteren": "Angereiztere",
    "Angereiztesten": "Angereizteste",
    "Angerempelten": "Angerempelte",
    "Angerichteten": "Angerichtete",
    "Angeriebenen": "Angeriebene",
    "Angerissenen": "Angerissene",
    "Angerisseneren": "Angerissenere",
    "Angerissensten": "Angerissenste",
    "Angerittenen": "Angerittene",
    "Angerollten": "Angerollte",
    "Angeruderten": "Angeruderte",
    "Angerufenen": "Angerufene",
    "Angerückten": "Angerückte",
    "Angerührten": "Angerührte",
    "Angesagten": "Angesagte",
    "Angesagteren": "Angesagtere",
    "Angesagtesten": "Angesagteste",
    "Angesammelten": "Angesammelte",
    "Angesamten": "Angesamte",
    "Angesaugten": "Angesaugte",
    "Angeschafften": "Angeschaffte",
    "Angeschalteten": "Angeschaltete",
    "Angeschauten": "Angeschaute",
    "Angeschienenen": "Angeschienene",
    "Angeschifften": "Angeschiffte",
    "Angeschirrten": "Angeschirrte",
    "Angeschissenen": "Angeschissene",
    "Angeschisseneren": "Angeschissenere",
    "Angeschissensten": "Angeschissenste",
    "Angeschlagenen": "Angeschlagene",
    "Angeschleiften": "Angeschleifte",
    "Angeschlichenen": "Angeschlichene",
    "Angeschliffenen": "Angeschliffene",
    "Angeschliffeneren": "Angeschliffenere",
    "Angeschliffensten": "Angeschliffenste",
    "Angeschlossenen": "Angeschlossene",
    "Angeschlosseneren": "Angeschlossenere",
    "Angeschlossensten": "Angeschlossenste",
    "Angeschlämmten": "Angeschlämmte",
    "Angeschmiegten": "Angeschmiegte",
    "Angeschmiegteren": "Angeschmiegtere",
    "Angeschmiegtesten": "Angeschmiegteste",
    "Angeschmierten": "Angeschmierte",
    "Angeschmissenen": "Angeschmissene",
    "Angeschnallten": "Angeschnallte",
    "Angeschnauzten": "Angeschnauzte",
    "Angeschnittenen": "Angeschnittene",
    "Angeschnitteneren": "Angeschnittenere",
    "Angeschnittensten": "Angeschnittenste",
    "Angeschobenen": "Angeschobene",
    "Angeschossenen": "Angeschossene",
    "Angeschraubten": "Angeschraubte",
    "Angeschriebenen": "Angeschriebene",
    "Angeschrienen": "Angeschriene",
    "Angeschrieneren": "Angeschrienere",
    "Angeschriensten": "Angeschrienste",
    "Angeschrägten": "Angeschrägte",
    "Angeschrägteren": "Angeschrägtere",
    "Angeschrägtesten": "Angeschrägteste",
    "Angeschuldigten": "Angeschuldigte",
    "Angeschweißten": "Angeschweißte",
    "Angeschwellten": "Angeschwellte",
    "Angeschwemmten": "Angeschwemmte",
    "Angeschwiegenen": "Angeschwiegene",
    "Angeschwindelten": "Angeschwindelte",
    "Angeschwollenen": "Angeschwollene",
    "Angeschwolleneren": "Angeschwollenere",
    "Angeschwollensten": "Angeschwollenste",
    "Angeschwommenen": "Angeschwommene",
    "Angeschwärzten": "Angeschwärzte",
    "Angeschwärzteren": "Angeschwärztere",
    "Angeschwärztesten": "Angeschwärzteste",
    "Angesehenen": "Angesehene",
    "Angeseheneren": "Angesehenere",
    "Angesehensten": "Angesehenste",
    "Angeseilten": "Angeseilte",
    "Angeseilteren": "Angeseiltere",
    "Angeseiltesten": "Angeseilteste",
    "Angesengten": "Angesengte",
    "Angesengteren": "Angesengtere",
    "Angesengtesten": "Angesengteste",
    "Angesessenen": "Angesessene",
    "Angesetzten": "Angesetzte",
    "Angesiedelten": "Angesiedelte",
    "Angesoffenen": "Angesoffene",
    "Angesoffeneren": "Angesoffenere",
    "Angesoffensten": "Angesoffenste",
    "Angesogenen": "Angesogene",
    "Angesohlten": "Angesohlte",
    "Angesohlteren": "Angesohltere",
    "Angesohltesten": "Angesohlteste",
    "Angespannten": "Angespannte",
    "Angespannteren": "Angespanntere",
    "Angespanntesten": "Angespannteste",
    "Angesparten": "Angesparte",
    "Angesparteren": "Angespartere",
    "Angespartesten": "Angesparteste",
    "Angespielten": "Angespielte",
    "Angespienen": "Angespiene",
    "Angespitzten": "Angespitzte",
    "Angespitzteren": "Angespitztere",
    "Angespitztesten": "Angespitzteste",
    "Angespornten": "Angespornte",
    "Angespornteren": "Angesporntere",
    "Angesporntesten": "Angespornteste",
    "Angesprengten": "Angesprengte",
    "Angespritzten": "Angespritzte",
    "Angesprochenen": "Angesprochene",
    "Angesprocheneren": "Angesprochenere",
    "Angesprochensten": "Angesprochenste",
    "Angesprungenen": "Angesprungene",
    "Angesprühten": "Angesprühte",
    "Angespülten": "Angespülte",
    "Angestachelten": "Angestachelte",
    "Angestachelteren": "Angestacheltere",
    "Angestacheltesten": "Angestachelteste",
    "Angestammten": "Angestammte",
    "Angestammteren": "Angestammtere",
    "Angestammtesten": "Angestammteste",
    "Angestandenen": "Angestandene",
    "Angestarrten": "Angestarrte",
    "Angestarrteren": "Angestarrtere",
    "Angestarrtesten": "Angestarrteste",
    "Angestaubten": "Angestaubte",
    "Angestaubteren": "Angestaubtere",
    "Angestaubtesten": "Angestaubteste",
    "Angestauten": "Angestaute",
    "Angesteckten": "Angesteckte",
    "Angestellten": "Angestellte",
    "Angestemmten": "Angestemmte",
    "Angestiegenen": "Angestiegene",
    "Angestiegeneren": "Angestiegenere",
    "Angestiegensten": "Angestiegenste",
    "Angestifteten": "Angestiftete",
    "Angestifteteren": "Angestiftetere",
    "Angestiftetesten": "Angestifteteste",
    "Angestimmten": "Angestimmte",
    "Angestochenen": "Angestochene",
    "Angestoßenen": "Angestoßene",
    "Angestrahlten": "Angestrahlte",
    "Angestrahlteren": "Angestrahltere",
    "Angestrahltesten": "Angestrahlteste",
    "Angestrebten": "Angestrebte",
    "Angestrengten": "Angestrengte",
    "Angestrengteren": "Angestrengtere",
    "Angestrengtesten": "Angestrengteste",
    "Angestrichenen": "Angestrichene",
    "Angestunkenen": "Angestunkene",
    "Angestürmten": "Angestürmte",
    "Angesuchten": "Angesuchte",
    "Angesungenen": "Angesungene",
    "Angesägte": "angesägt",
    "Angesägten": "Angesägte",
    "Angesäten": "Angesäte",
    "Angesäuerten": "Angesäuerte",
    "Angesäuerteren": "Angesäuertere",
    "Angesäuertesten": "Angesäuerteste",
    "Angesäuselten": "Angesäuselte",
    "Angesäuselteren": "Angesäuseltere",
    "Angesäuseltesten": "Angesäuselteste",
    "Angetanzten": "Angetanzte",
    "Angetasteten": "Angetastete",
    "Angetesteten": "Angetestete",
    "Angetesteteren": "Angetestetere",
    "Angetestetesten": "Angetesteteste",
    "Angetippten": "Angetippte",
    "Angetrabten": "Angetrabte",
    "Angetragenen": "Angetragene",
    "Angetrauten": "Angetraute",
    "Angetretenen": "Angetretene",
    "Angetriebenen": "Angetriebene",
    "Angetroffenen": "Angetroffene",
    "Angetrunkenen": "Angetrunkene",
    "Angetrunkeneren": "Angetrunkenere",
    "Angetrunkensten": "Angetrunkenste",
    "Angetönten": "Angetönte",
    "Angetörnten": "Angetörnte",
    "Angetörnteren": "Angetörntere",
    "Angetörntesten": "Angetörnteste",
    "Angewachsenen": "Angewachsene",
    "Angewachsten": "Angewachste",
    "Angewandelten": "Angewandelte",
    "Angewehten": "Angewehte",
    "Angewendeten": "Angewendete",
    "Angewiderten": "Angewiderte",
    "Angewiderteren": "Angewidertere",
    "Angewidertesten": "Angewiderteste",
    "Angewiesenen": "Angewiesene",
    "Angewinkelten": "Angewinkelte",
    "Angewohnheiten": "Angewohnheit",
    "Angewohnten": "Angewohnte",
    "Angeworbenen": "Angeworbene",
    "Angeworfenen": "Angeworfene",
    "Angewurzelten": "Angewurzelte",
    "Angewählten": "Angewählte",
    "Angewärmten": "Angewärmte",
    "Angewöhnenden": "Angewöhnende",
    "Angewöhnens": "Angewöhnen",
    "Angewöhnte": "angewöhnen",
    "Angewöhnten": "Angewöhnte",
    "Angezahlten": "Angezahlte",
    "Angezapften": "Angezapfte",
    "Angezauberten": "Angezauberte",
    "Angezeichneten": "Angezeichnete",
    "Angezeigten": "Angezeigte",
    "Angezettelten": "Angezettelte",
    "Angezogenen": "Angezogene",
    "Angezogeneren": "Angezogenere",
    "Angezogensten": "Angezogenste",
    "Angezweifelten": "Angezweifelte",
    "Angezweifelteren": "Angezweifeltere",
    "Angezweifeltesten": "Angezweifelteste",
    "Angezählte": "angezählt",
    "Angezählten": "Angezählte",
    "Angezählteren": "Angezähltere",
    "Angezähltesten": "Angezählteste",
    "Angezündeten": "Angezündete",
    "Angeödeten": "Angeödete",
    "Angeödeteren": "Angeödetere",
    "Angeödetesten": "Angeödeteste",
    "Angießenden": "Angießende",
    "Angießens": "Angießen",
    "Angiftenden": "Angiftende",
    "Angiftenderen": "Angiftendere",
    "Angiftendsten": "Angiftendste",
    "Angiftens": "Angiften",
    "Angleichenden": "Angleichende",
    "Angleichens": "Angleichen",
    "Angleichungen": "Angleichung",
    "Anglern": "Angler",
    "Anglers": "Angler",
    "Angliedernden": "Angliedernde",
    "Angliedernderen": "Angliederndere",
    "Angliederndsten": "Angliederndste",
    "Angliederns": "Angliedern",
    "Anglotzenden": "Anglotzende",
    "Anglotzenderen": "Anglotzendere",
    "Anglotzendsten": "Anglotzendste",
    "Anglotzens": "Anglotzen",
    "Angolas": "Angola",
    "Angorakatzen": "Angorakatze",
    "Angoraziegen": "Angoraziege",
    "Angreifbaren": "Angreifbare",
    "Angreifbareren": "Angreifbarere",
    "Angreifbarsten": "Angreifbarste",
    "Angreifenden": "Angreifende",
    "Angreifens": "Angreifen",
    "Angreifern": "Angreifer",
    "Angreifers": "Angreifer",
    "Angrenzenden": "Angrenzende",
    "Angrenzenderen": "Angrenzendere",
    "Angrenzendsten": "Angrenzendste",
    "Angrenzens": "Angrenzen",
    "Angriffe": "Angriff",
    "Angriffen": "Angriff",
    "Angriffes": "Angriff",
    "Angriffs": "Angriff",
    "Angriffslustige": "angriffslustig",
    "Angriffslustigen": "Angriffslustige",
    "Angriffslustigeren": "Angriffslustigere",
    "Angrinsenden": "Angrinsende",
    "Angrinsenderen": "Angrinsendere",
    "Angrinsendsten": "Angrinsendste",
    "Angrinsens": "Angrinsen",
    "Angsterfüllten": "Angsterfüllte",
    "Angsterfüllteren": "Angsterfülltere",
    "Angsterfülltesten": "Angsterfüllteste",
    "Angurtenden": "Angurtende",
    "Angurtens": "Angurten",
    "Angußfarben": "Angußfarbe",
    "Anhaftenden": "Anhaftende",
    "Anhaftens": "Anhaften",
    "Anhakenden": "Anhakende",
    "Anhakens": "Anhaken",
    "Anhalfternden": "Anhalfternde",
    "Anhalfterns": "Anhalftern",
    "Anhalte": "anhalten",
    "Anhalten": "Anhalt",
    "Anhaltenden": "Anhaltende",
    "Anhaltens": "Anhalten",
    "Anhalts": "Anhalt",
    "Anhange": "Anhang",
    "Anhanges": "Anhang",
    "Anhangs": "Anhang",
    "Anhauchenden": "Anhauchende",
    "Anhauchens": "Anhauchen",
    "Anhauenden": "Anhauende",
    "Anhauens": "Anhauen",
    "Anhebenden": "Anhebende",
    "Anhebens": "Anheben",
    "Anhebungen": "Anhebung",
    "Anheftenden": "Anheftende",
    "Anheftens": "Anheften",
    "Anheimelnden": "Anheimelnde",
    "Anheimelnderen": "Anheimelndere",
    "Anheimelndsten": "Anheimelndste",
    "Anheimelns": "Anheimeln",
    "Anheimfallenden": "Anheimfallende",
    "Anheimfallens": "Anheimfallen",
    "Anheimgebenden": "Anheimgebende",
    "Anheimgebens": "Anheimgeben",
    "Anheimgefallenen": "Anheimgefallene",
    "Anheimgegebenen": "Anheimgegebene",
    "Anheimgestellten": "Anheimgestellte",
    "Anheimstellenden": "Anheimstellende",
    "Anheimstellens": "Anheimstellen",
    "Anheizenden": "Anheizende",
    "Anheizenderen": "Anheizendere",
    "Anheizendsten": "Anheizendste",
    "Anheizens": "Anheizen",
    "Anheuernden": "Anheuernde",
    "Anheuerns": "Anheuern",
    "Anhiebe": "Anhieb",
    "Anhieben": "Anhieb",
    "Anhiebs": "Anhieb",
    "Anhimmelnden": "Anhimmelnde",
    "Anhimmelnderen": "Anhimmelndere",
    "Anhimmelndsten": "Anhimmelndste",
    "Anhimmelns": "Anhimmeln",
    "Anholenden": "Anholende",
    "Anholens": "Anholen",
    "Anhänge": "anhängen",
    "Anhängen": "Anhang",
    "Anhängenden": "Anhängende",
    "Anhängens": "Anhängen",
    "Anhängern": "Anhänger",
    "Anhängers": "Anhänger",
    "Anhängigen": "Anhängige",
    "Anhänglichen": "Anhängliche",
    "Anhänglicheren": "Anhänglichere",
    "Anhänglichsten": "Anhänglichste",
    "Anhängseln": "Anhängsel",
    "Anhängsels": "Anhängsel",
    "Anhärtenden": "Anhärtende",
    "Anhärtenderen": "Anhärtendere",
    "Anhärtendsten": "Anhärtendste",
    "Anhärtens": "Anhärten",
    "Anhäufungen": "Anhäufung",
    "Anhörenden": "Anhörende",
    "Anhörens": "Anhören",
    "Anhörungen": "Anhörung",
    "Animalische": "animalisch",
    "Animalischen": "Animalische",
    "Animalischeren": "Animalischere",
    "Animalischsten": "Animalischste",
    "Animalisierenden": "Animalisierende",
    "Animalisierens": "Animalisieren",
    "Animalisierte": "animalisiert",
    "Animalisierten": "Animalisierte",
    "Animalisierteren": "Animalisiertere",
    "Animalisiertesten": "Animalisierteste",
    "Animationen": "Animation",
    "Animatore": "Animator",
    "Animatoren": "Animator",
    "Animators": "Animator",
    "Animierdamen": "Animierdame",
    "Animierenden": "Animierende",
    "Animierenderen": "Animierendere",
    "Animierendsten": "Animierendste",
    "Animierens": "Animieren",
    "Animierte": "animiert",
    "Animierten": "Animierte",
    "Animierteren": "Animiertere",
    "Animiertesten": "Animierteste",
    "Animositäten": "Animosität",
    "Anitas": "Anita",
    "Anjagenden": "Anjagende",
    "Anjagens": "Anjagen",
    "Anjas": "Anja",
    "Ankaras": "Ankara",
    "Ankatheten": "Ankathete",
    "Ankaufe": "ankaufen",
    "Ankaufenden": "Ankaufende",
    "Ankaufens": "Ankaufen",
    "Ankaufs": "Ankauf",
    "Ankeilenden": "Ankeilende",
    "Ankeilenderen": "Ankeilendere",
    "Ankeilendsten": "Ankeilendste",
    "Ankeilens": "Ankeilen",
    "Anker": "ankern",
    "Ankerketten": "Ankerkette",
    "Ankern": "Anker",
    "Ankernden": "Ankernde",
    "Ankernderen": "Ankerndere",
    "Ankerndsten": "Ankerndste",
    "Ankerns": "Ankern",
    "Ankers": "Anker",
    "Ankerwinden": "Ankerwinde",
    "Ankes": "Anke",
    "Ankettenden": "Ankettende",
    "Ankettens": "Anketten",
    "Anklagen": "Anklage",
    "Anklagenden": "Anklagende",
    "Anklagenderen": "Anklagendere",
    "Anklagendsten": "Anklagendste",
    "Anklagens": "Anklagen",
    "Anklagereden": "Anklagerede",
    "Anklammernden": "Anklammernde",
    "Anklammerns": "Anklammern",
    "Anklebenden": "Anklebende",
    "Anklebens": "Ankleben",
    "Ankleidenden": "Ankleidende",
    "Ankleidens": "Ankleiden",
    "Anklingelnden": "Anklingelnde",
    "Anklingelns": "Anklingeln",
    "Anklingenden": "Anklingende",
    "Anklingens": "Anklingen",
    "Anklopfenden": "Anklopfende",
    "Anklopfens": "Anklopfen",
    "Anknabbernden": "Anknabbernde",
    "Anknabbernderen": "Anknabberndere",
    "Anknabberndsten": "Anknabberndste",
    "Anknabberns": "Anknabbern",
    "Anknacksenden": "Anknacksende",
    "Anknacksenderen": "Anknacksendere",
    "Anknacksendsten": "Anknacksendste",
    "Anknacksens": "Anknacksen",
    "Anknipsenden": "Anknipsende",
    "Anknipsens": "Anknipsen",
    "Anknöpfenden": "Anknöpfende",
    "Anknöpfens": "Anknöpfen",
    "Anknüpfenden": "Anknüpfende",
    "Anknüpfens": "Anknüpfen",
    "Ankohlenden": "Ankohlende",
    "Ankohlenderen": "Ankohlendere",
    "Ankohlendsten": "Ankohlendste",
    "Ankohlens": "Ankohlen",
    "Ankommenden": "Ankommende",
    "Ankommens": "Ankommen",
    "Ankoppelnden": "Ankoppelnde",
    "Ankoppelns": "Ankoppeln",
    "Ankotzenden": "Ankotzende",
    "Ankotzens": "Ankotzen",
    "Ankrallenden": "Ankrallende",
    "Ankrallens": "Ankrallen",
    "Ankreidenden": "Ankreidende",
    "Ankreidens": "Ankreiden",
    "Ankreise": "Ankreis",
    "Ankreisen": "Ankreis",
    "Ankreises": "Ankreis",
    "Ankreuzenden": "Ankreuzende",
    "Ankreuzens": "Ankreuzen",
    "Ankuppelnden": "Ankuppelnde",
    "Ankuppelns": "Ankuppeln",
    "Ankurbelnden": "Ankurbelnde",
    "Ankurbelnderen": "Ankurbelndere",
    "Ankurbelndsten": "Ankurbelndste",
    "Ankurbelns": "Ankurbeln",
    "Ankämpfenden": "Ankämpfende",
    "Ankämpfens": "Ankämpfen",
    "Ankäufe": "Ankauf",
    "Ankäufen": "Ankauf",
    "Anködernden": "Anködernde",
    "Anköderns": "Anködern",
    "Ankömmlinge": "Ankömmling",
    "Ankömmlingen": "Ankömmling",
    "Ankömmlings": "Ankömmling",
    "Ankündigenden": "Ankündigende",
    "Ankündigens": "Ankündigen",
    "Ankündigungen": "Ankündigung",
    "Ankünfte": "Ankunft",
    "Ankünften": "Ankunft",
    "Anlachenden": "Anlachende",
    "Anlachens": "Anlachen",
    "Anlagen": "anliegen",
    "Anlagernden": "Anlagernde",
    "Anlagerns": "Anlagern",
    "Anlasse": "anlassen",
    "Anlassenden": "Anlassende",
    "Anlassens": "Anlassen",
    "Anlasses": "Anlaß",
    "Anlastenden": "Anlastende",
    "Anlastenderen": "Anlastendere",
    "Anlastendsten": "Anlastendste",
    "Anlastens": "Anlasten",
    "Anlaufe": "anlaufen",
    "Anlaufenden": "Anlaufende",
    "Anlaufens": "Anlaufen",
    "Anlaufes": "Anlauf",
    "Anlaufs": "Anlauf",
    "Anlaufstellen": "Anlaufstelle",
    "Anlautenden": "Anlautende",
    "Anlautens": "Anlauten",
    "Anlaßfarben": "Anlaßfarbe",
    "Anlegenden": "Anlegende",
    "Anlegens": "Anlegen",
    "Anlegern": "Anleger",
    "Anlegers": "Anleger",
    "Anlegestege": "Anlegesteg",
    "Anlegestegen": "Anlegesteg",
    "Anlegestegs": "Anlegesteg",
    "Anlehnenden": "Anlehnende",
    "Anlehnens": "Anlehnen",
    "Anlehnungen": "Anlehnung",
    "Anlehnungsbedürftige": "anlehnungsbedürftig",
    "Anlehnungsbedürftigen": "Anlehnungsbedürftige",
    "Anlehnungsbedürftigeren": "Anlehnungsbedürftigere",
    "Anleihen": "Anleihe",
    "Anleimenden": "Anleimende",
    "Anleimens": "Anleimen",
    "Anleinenden": "Anleinende",
    "Anleinens": "Anleinen",
    "Anleitenden": "Anleitende",
    "Anleitens": "Anleiten",
    "Anleitungen": "Anleitung",
    "Anlernenden": "Anlernende",
    "Anlernens": "Anlernen",
    "Anlernlinge": "Anlernling",
    "Anlernlingen": "Anlernling",
    "Anlernlings": "Anlernling",
    "Anlernzeiten": "Anlernzeit",
    "Anlesenden": "Anlesende",
    "Anlesens": "Anlesen",
    "Anleuchtenden": "Anleuchtende",
    "Anleuchtens": "Anleuchten",
    "Anlieferern": "Anlieferer",
    "Anlieferers": "Anlieferer",
    "Anliefernden": "Anliefernde",
    "Anlieferns": "Anliefern",
    "Anliegenden": "Anliegende",
    "Anliegens": "Anliegen",
    "Anliegern": "Anlieger",
    "Anliegers": "Anlieger",
    "Anlächelnden": "Anlächelnde",
    "Anlächelns": "Anlächeln",
    "Anländen": "Anlände",
    "Anlässe": "Anlaß",
    "Anlässen": "Anlaß",
    "Anläufe": "Anlauf",
    "Anläufen": "Anlauf",
    "Anläutende": "anläutend",
    "Anläutenden": "Anläutende",
    "Anläutens": "Anläuten",
    "Anlötenden": "Anlötende",
    "Anlötens": "Anlöten",
    "Anlügenden": "Anlügende",
    "Anlügens": "Anlügen",
    "Anmachenden": "Anmachende",
    "Anmachens": "Anmachen",
    "Anmahnenden": "Anmahnende",
    "Anmahnens": "Anmahnen",
    "Anmalenden": "Anmalende",
    "Anmalens": "Anmalen",
    "Anmarschierenden": "Anmarschierende",
    "Anmarschierens": "Anmarschieren",
    "Anmarschierte": "anmarschiert",
    "Anmarschierten": "Anmarschierte",
    "Anmarschwege": "Anmarschweg",
    "Anmarschwegen": "Anmarschweg",
    "Anmarschwegs": "Anmarschweg",
    "Anmaßenden": "Anmaßende",
    "Anmaßenderen": "Anmaßendere",
    "Anmaßendsten": "Anmaßendste",
    "Anmaßens": "Anmaßen",
    "Anmaßungen": "Anmaßung",
    "Anmeldegebühren": "Anmeldegebühr",
    "Anmeldenden": "Anmeldende",
    "Anmeldens": "Anmelden",
    "Anmeldepflichten": "Anmeldepflicht",
    "Anmeldepflichtige": "anmeldepflichtig",
    "Anmeldepflichtigen": "Anmeldepflichtige",
    "Anmeldungen": "Anmeldung",
    "Anmerkenden": "Anmerkende",
    "Anmerkens": "Anmerken",
    "Anmerkungen": "Anmerkung",
    "Anmessenden": "Anmessende",
    "Anmessens": "Anmessen",
    "Anmietenden": "Anmietende",
    "Anmietens": "Anmieten",
    "Anmotzenden": "Anmotzende",
    "Anmotzenderen": "Anmotzendere",
    "Anmotzendsten": "Anmotzendste",
    "Anmotzens": "Anmotzen",
    "Anmusternden": "Anmusternde",
    "Anmusterns": "Anmustern",
    "Anmute": "anmuten",
    "Anmutenden": "Anmutende",
    "Anmutens": "Anmuten",
    "Anmutes": "Anmut",
    "Anmutigen": "Anmutige",
    "Anmutigeren": "Anmutigere",
    "Anmutigsten": "Anmutigste",
    "Anmuts": "Anmut",
    "Annagelnden": "Annagelnde",
    "Annagelns": "Annageln",
    "Annagenden": "Annagende",
    "Annagenderen": "Annagendere",
    "Annagendsten": "Annagendste",
    "Annagens": "Annagen",
    "Annahmen": "annehmen",
    "Annas": "Anna",
    "Annehmbare": "annehmbar",
    "Annehmbaren": "Annehmbare",
    "Annehmenden": "Annehmende",
    "Annehmenderen": "Annehmendere",
    "Annehmendsten": "Annehmendste",
    "Annehmens": "Annehmen",
    "Annehmlichen": "Annehmliche",
    "Annehmlichkeiten": "Annehmlichkeit",
    "Annektierenden": "Annektierende",
    "Annektierenderen": "Annektierendere",
    "Annektierendsten": "Annektierendste",
    "Annektierens": "Annektieren",
    "Annektierte": "annektiert",
    "Annektierten": "Annektierte",
    "Annelieses": "Anneliese",
    "Annes": "Anne",
    "Annettes": "Annette",
    "Annexionisten": "Annexionist",
    "Annietenden": "Annietende",
    "Annietens": "Annieten",
    "Annoncen": "Annonce",
    "Annotationen": "Annotation",
    "Anns": "Ann",
    "Annuitäten": "Annuität",
    "Annullierenden": "Annullierende",
    "Annullierenderen": "Annullierendere",
    "Annullierendsten": "Annullierendste",
    "Annullierens": "Annullieren",
    "Annullierte": "annulliert",
    "Annullierten": "Annullierte",
    "Annähenden": "Annähende",
    "Annähens": "Annähen",
    "Annähernden": "Annähernde",
    "Annäherns": "Annähern",
    "Annäherungen": "Annäherung",
    "Anonymen": "Anonyme",
    "Anonymeren": "Anonymere",
    "Anonymsten": "Anonymste",
    "Anoraks": "Anorak",
    "Anordnenden": "Anordnende",
    "Anordnens": "Anordnen",
    "Anordnungen": "Anordnung",
    "Anorganische": "anorganisch",
    "Anorganischen": "Anorganische",
    "Anpaarungen": "Anpaarung",
    "Anpackenden": "Anpackende",
    "Anpackens": "Anpacken",
    "Anpaddelnden": "Anpaddelnde",
    "Anpaddelns": "Anpaddeln",
    "Anpassenden": "Anpassende",
    "Anpassenderen": "Anpassendere",
    "Anpassendsten": "Anpassendste",
    "Anpassens": "Anpassen",
    "Anpassungsfähigen": "Anpassungsfähige",
    "Anpassungsfähigeren": "Anpassungsfähigere",
    "Anpeilenden": "Anpeilende",
    "Anpeilens": "Anpeilen",
    "Anpfeifenden": "Anpfeifende",
    "Anpfeifenderen": "Anpfeifendere",
    "Anpfeifendsten": "Anpfeifendste",
    "Anpfeifens": "Anpfeifen",
    "Anpflanzenden": "Anpflanzende",
    "Anpflanzens": "Anpflanzen",
    "Anpflanzungen": "Anpflanzung",
    "Anpflaumenden": "Anpflaumende",
    "Anpflaumenderen": "Anpflaumendere",
    "Anpflaumendsten": "Anpflaumendste",
    "Anpflaumens": "Anpflaumen",
    "Anpirschenden": "Anpirschende",
    "Anpirschens": "Anpirschen",
    "Anprallenden": "Anprallende",
    "Anprallens": "Anprallen",
    "Anprangernden": "Anprangernde",
    "Anprangernderen": "Anprangerndere",
    "Anprangerndsten": "Anprangerndste",
    "Anprangerns": "Anprangern",
    "Anpreisenden": "Anpreisende",
    "Anpreisens": "Anpreisen",
    "Anpreisungen": "Anpreisung",
    "Anpressenden": "Anpressende",
    "Anpressens": "Anpressen",
    "Anproben": "Anprobe",
    "Anprobierenden": "Anprobierende",
    "Anprobierens": "Anprobieren",
    "Anprobierte": "anprobiert",
    "Anprobierten": "Anprobierte",
    "Anpumpenden": "Anpumpende",
    "Anpumpens": "Anpumpen",
    "Anputzenden": "Anputzende",
    "Anputzens": "Anputzen",
    "Anpöbelnden": "Anpöbelnde",
    "Anpöbelnderen": "Anpöbelndere",
    "Anpöbelndsten": "Anpöbelndste",
    "Anpöbelns": "Anpöbeln",
    "Anquälenden": "Anquälende",
    "Anquälens": "Anquälen",
    "Anrainern": "Anrainer",
    "Anrainers": "Anrainer",
    "Anranzenden": "Anranzende",
    "Anranzenderen": "Anranzendere",
    "Anranzendsten": "Anranzendste",
    "Anranzens": "Anranzen",
    "Anranzern": "Anranzer",
    "Anranzers": "Anranzer",
    "Anratenden": "Anratende",
    "Anratens": "Anraten",
    "Anrauhenden": "Anrauhende",
    "Anrauhenderen": "Anrauhendere",
    "Anrauhendsten": "Anrauhendste",
    "Anrauhens": "Anrauhen",
    "Anrechnenden": "Anrechnende",
    "Anrechnens": "Anrechnen",
    "Anrechnungen": "Anrechnung",
    "Anrechte": "Anrecht",
    "Anrechten": "Anrecht",
    "Anrechts": "Anrecht",
    "Anrede": "anreden",
    "Anredefürworte": "Anredefürwort",
    "Anredefürwortes": "Anredefürwort",
    "Anredefürworts": "Anredefürwort",
    "Anredefürwörter": "Anredefürwort",
    "Anredefürwörtern": "Anredefürwort",
    "Anreden": "Anrede",
    "Anredenden": "Anredende",
    "Anredens": "Anreden",
    "Anregenden": "Anregende",
    "Anregenderen": "Anregendere",
    "Anregendsten": "Anregendste",
    "Anregens": "Anregen",
    "Anregern": "Anreger",
    "Anregers": "Anreger",
    "Anregungen": "Anregung",
    "Anreibenden": "Anreibende",
    "Anreibens": "Anreiben",
    "Anreichenden": "Anreichende",
    "Anreichens": "Anreichen",
    "Anreichernden": "Anreichernde",
    "Anreicherns": "Anreichern",
    "Anreihenden": "Anreihende",
    "Anreihens": "Anreihen",
    "Anreisenden": "Anreisende",
    "Anreisens": "Anreisen",
    "Anreitenden": "Anreitende",
    "Anreitens": "Anreiten",
    "Anreize": "anreizen",
    "Anreizen": "Anreiz",
    "Anreizenden": "Anreizende",
    "Anreizenderen": "Anreizendere",
    "Anreizendsten": "Anreizendste",
    "Anreizens": "Anreizen",
    "Anreizes": "Anreiz",
    "Anreißenden": "Anreißende",
    "Anreißens": "Anreißen",
    "Anreißern": "Anreißer",
    "Anreißers": "Anreißer",
    "Anrempelnden": "Anrempelnde",
    "Anrempelns": "Anrempeln",
    "Anrennenden": "Anrennende",
    "Anrennens": "Anrennen",
    "Anrichten": "Anrichte",
    "Anrichtenden": "Anrichtende",
    "Anrichtens": "Anrichten",
    "Anrollenden": "Anrollende",
    "Anrollens": "Anrollen",
    "Anrudernden": "Anrudernde",
    "Anruderns": "Anrudern",
    "Anrufe": "anrufen",
    "Anrufen": "Anruf",
    "Anrufenden": "Anrufende",
    "Anrufens": "Anrufen",
    "Anrufern": "Anrufer",
    "Anrufers": "Anrufer",
    "Anrufs": "Anruf",
    "Anrüchigen": "Anrüchige",
    "Anrüchigeren": "Anrüchigere",
    "Anrüchigsten": "Anrüchigste",
    "Anrückenden": "Anrückende",
    "Anrückens": "Anrücken",
    "Anrührenden": "Anrührende",
    "Anrührens": "Anrühren",
    "Ansagen": "Ansage",
    "Ansagenden": "Ansagende",
    "Ansagens": "Ansagen",
    "Ansamenden": "Ansamende",
    "Ansamens": "Ansamen",
    "Ansammelnden": "Ansammelnde",
    "Ansammelns": "Ansammeln",
    "Ansammlungen": "Ansammlung",
    "Ansatze": "Ansatz",
    "Ansatzes": "Ansatz",
    "Ansatzs": "Ansatz",
    "Ansaufenden": "Ansaufende",
    "Ansaufenderen": "Ansaufendere",
    "Ansaufendsten": "Ansaufendste",
    "Ansaufens": "Ansaufen",
    "Ansaugenden": "Ansaugende",
    "Ansaugens": "Ansaugen",
    "Ansbachs": "Ansbach",
    "Anschaffenden": "Anschaffende",
    "Anschaffens": "Anschaffen",
    "Anschaffungen": "Anschaffung",
    "Anschaltenden": "Anschaltende",
    "Anschaltens": "Anschalten",
    "Anschauenden": "Anschauende",
    "Anschauens": "Anschauen",
    "Anschaulichen": "Anschauliche",
    "Anschaulicheren": "Anschaulichere",
    "Anschaulichsten": "Anschaulichste",
    "Anschauungen": "Anschauung",
    "Anscheinenden": "Anscheinende",
    "Anscheinens": "Anscheinen",
    "Anscheins": "Anschein",
    "Anscheißenden": "Anscheißende",
    "Anscheißenderen": "Anscheißendere",
    "Anscheißendsten": "Anscheißendste",
    "Anscheißens": "Anscheißen",
    "Anschiebenden": "Anschiebende",
    "Anschiebens": "Anschieben",
    "Anschießenden": "Anschießende",
    "Anschießens": "Anschießen",
    "Anschiffenden": "Anschiffende",
    "Anschiffens": "Anschiffen",
    "Anschirrenden": "Anschirrende",
    "Anschirrens": "Anschirren",
    "Anschlage": "anschlagen",
    "Anschlagenden": "Anschlagende",
    "Anschlagens": "Anschlagen",
    "Anschlages": "Anschlag",
    "Anschlags": "Anschlag",
    "Anschlagsäulen": "Anschlagsäule",
    "Anschleichenden": "Anschleichende",
    "Anschleichens": "Anschleichen",
    "Anschleifenden": "Anschleifende",
    "Anschleifens": "Anschleifen",
    "Anschließenden": "Anschließende",
    "Anschließens": "Anschließen",
    "Anschlusse": "Anschluß",
    "Anschlusses": "Anschluß",
    "Anschläge": "Anschlag",
    "Anschlägen": "Anschlag",
    "Anschlämmenden": "Anschlämmende",
    "Anschlämmens": "Anschlämmen",
    "Anschlüsse": "Anschluß",
    "Anschlüssen": "Anschluß",
    "Anschmeißenden": "Anschmeißende",
    "Anschmeißens": "Anschmeißen",
    "Anschmiegenden": "Anschmiegende",
    "Anschmiegenderen": "Anschmiegendere",
    "Anschmiegendsten": "Anschmiegendste",
    "Anschmiegens": "Anschmiegen",
    "Anschmiegsamen": "Anschmiegsame",
    "Anschmiegsameren": "Anschmiegsamere",
    "Anschmiegsamsten": "Anschmiegsamste",
    "Anschmierenden": "Anschmierende",
    "Anschmierens": "Anschmieren",
    "Anschnallenden": "Anschnallende",
    "Anschnallens": "Anschnallen",
    "Anschnauzenden": "Anschnauzende",
    "Anschnauzens": "Anschnauzen",
    "Anschnauzern": "Anschnauzer",
    "Anschnauzers": "Anschnauzer",
    "Anschneidenden": "Anschneidende",
    "Anschneidens": "Anschneiden",
    "Anschnitte": "Anschnitt",
    "Anschnitten": "Anschnitt",
    "Anschnitts": "Anschnitt",
    "Anschraubenden": "Anschraubende",
    "Anschraubens": "Anschrauben",
    "Anschreibenden": "Anschreibende",
    "Anschreibens": "Anschreiben",
    "Anschreienden": "Anschreiende",
    "Anschreienderen": "Anschreiendere",
    "Anschreiendsten": "Anschreiendste",
    "Anschreiens": "Anschreien",
    "Anschrägenden": "Anschrägende",
    "Anschrägenderen": "Anschrägendere",
    "Anschrägendsten": "Anschrägendste",
    "Anschrägens": "Anschrägen",
    "Anschuldigungen": "Anschuldigung",
    "Anschweigenden": "Anschweigende",
    "Anschweigens": "Anschweigen",
    "Anschweißenden": "Anschweißende",
    "Anschweißens": "Anschweißen",
    "Anschwellenden": "Anschwellende",
    "Anschwellenderen": "Anschwellendere",
    "Anschwellendsten": "Anschwellendste",
    "Anschwellens": "Anschwellen",
    "Anschwellungen": "Anschwellung",
    "Anschwemmenden": "Anschwemmende",
    "Anschwemmens": "Anschwemmen",
    "Anschwemmungen": "Anschwemmung",
    "Anschwimmenden": "Anschwimmende",
    "Anschwimmens": "Anschwimmen",
    "Anschwindelnden": "Anschwindelnde",
    "Anschwindelns": "Anschwindeln",
    "Anschwärzenden": "Anschwärzende",
    "Anschwärzenderen": "Anschwärzendere",
    "Anschwärzendsten": "Anschwärzendste",
    "Anschwärzens": "Anschwärzen",
    "Ansegelns": "Ansegeln",
    "Ansehenden": "Ansehende",
    "Ansehens": "Ansehen",
    "Ansehnlichen": "Ansehnliche",
    "Ansehnlicheren": "Ansehnlichere",
    "Ansehnlichsten": "Ansehnlichste",
    "Anseilenden": "Anseilende",
    "Anseilenderen": "Anseilendere",
    "Anseilendsten": "Anseilendste",
    "Anseilens": "Anseilen",
    "Ansengenden": "Ansengende",
    "Ansengenderen": "Ansengendere",
    "Ansengendsten": "Ansengendste",
    "Ansengens": "Ansengen",
    "Ansetzenden": "Ansetzende",
    "Ansetzens": "Ansetzen",
    "Ansichseins": "Ansichsein",
    "Ansichten": "Ansicht",
    "Ansiedelnden": "Ansiedelnde",
    "Ansiedelns": "Ansiedeln",
    "Ansiedlungen": "Ansiedlung",
    "Ansingenden": "Ansingende",
    "Ansingens": "Ansingen",
    "Ansinnens": "Ansinnen",
    "Ansitzenden": "Ansitzende",
    "Ansitzens": "Ansitzen",
    "Ansohlenden": "Ansohlende",
    "Ansohlenderen": "Ansohlendere",
    "Ansohlendsten": "Ansohlendste",
    "Ansohlens": "Ansohlen",
    "Anspannenden": "Anspannende",
    "Anspannenderen": "Anspannendere",
    "Anspannendsten": "Anspannendste",
    "Anspannens": "Anspannen",
    "Ansparenden": "Ansparende",
    "Ansparenderen": "Ansparendere",
    "Ansparendsten": "Ansparendste",
    "Ansparens": "Ansparen",
    "Anspeienden": "Anspeiende",
    "Anspeiens": "Anspeien",
    "Anspielenden": "Anspielende",
    "Anspielens": "Anspielen",
    "Anspielungen": "Anspielung",
    "Anspitzenden": "Anspitzende",
    "Anspitzenderen": "Anspitzendere",
    "Anspitzendsten": "Anspitzendste",
    "Anspitzens": "Anspitzen",
    "Anspornenden": "Anspornende",
    "Anspornenderen": "Anspornendere",
    "Anspornendsten": "Anspornendste",
    "Anspornens": "Anspornen",
    "Ansporns": "Ansporn",
    "Ansprachen": "ansprechen",
    "Ansprechenden": "Ansprechende",
    "Ansprechenderen": "Ansprechendere",
    "Ansprechendsten": "Ansprechendste",
    "Ansprechens": "Ansprechen",
    "Ansprechpartnerinnen": "Ansprechpartnerin",
    "Ansprechpartnern": "Ansprechpartner",
    "Ansprechpartners": "Ansprechpartner",
    "Ansprengenden": "Ansprengende",
    "Ansprengens": "Ansprengen",
    "Anspringenden": "Anspringende",
    "Anspringens": "Anspringen",
    "Anspritzenden": "Anspritzende",
    "Anspritzens": "Anspritzen",
    "Anspruche": "Anspruch",
    "Anspruches": "Anspruch",
    "Anspruchs": "Anspruch",
    "Anspruchslose": "anspruchslos",
    "Anspruchslosen": "Anspruchslose",
    "Anspruchsloseren": "Anspruchslosere",
    "Anspruchslosesten": "Anspruchsloseste",
    "Anspruchstellern": "Anspruchsteller",
    "Anspruchstellers": "Anspruchsteller",
    "Anspruchsvolle": "anspruchsvoll",
    "Anspruchsvollen": "Anspruchsvolle",
    "Anspruchsvolleren": "Anspruchsvollere",
    "Anspruchsvollsten": "Anspruchsvollste",
    "Ansprüche": "Anspruch",
    "Ansprüchen": "Anspruch",
    "Ansprühenden": "Ansprühende",
    "Ansprühenderen": "Ansprühendere",
    "Ansprühendsten": "Ansprühendste",
    "Ansprühens": "Ansprühen",
    "Anspülenden": "Anspülende",
    "Anspülens": "Anspülen",
    "Anstachelnden": "Anstachelnde",
    "Anstachelnderen": "Anstachelndere",
    "Anstachelndsten": "Anstachelndste",
    "Anstachelns": "Anstacheln",
    "Anstalten": "Anstalt",
    "Anstammenden": "Anstammende",
    "Anstammens": "Anstammen",
    "Anstandsdamen": "Anstandsdame",
    "Anstandslose": "anstandslos",
    "Anstandslosen": "Anstandslose",
    "Anstarrenden": "Anstarrende",
    "Anstarrenderen": "Anstarrendere",
    "Anstarrendsten": "Anstarrendste",
    "Anstarrens": "Anstarren",
    "Anstaubenden": "Anstaubende",
    "Anstaubenderen": "Anstaubendere",
    "Anstaubendsten": "Anstaubendste",
    "Anstaubens": "Anstauben",
    "Anstauenden": "Anstauende",
    "Anstauens": "Anstauen",
    "Anstechenden": "Anstechende",
    "Anstechens": "Anstechen",
    "Ansteckenden": "Ansteckende",
    "Ansteckenderen": "Ansteckendere",
    "Ansteckendsten": "Ansteckendste",
    "Ansteckens": "Anstecken",
    "Anstecknadeln": "Anstecknadel",
    "Anstehenden": "Anstehende",
    "Anstehens": "Anstehen",
    "Ansteigenden": "Ansteigende",
    "Ansteigenderen": "Ansteigendere",
    "Ansteigendsten": "Ansteigendste",
    "Ansteigens": "Ansteigen",
    "Anstellenden": "Anstellende",
    "Anstellens": "Anstellen",
    "Anstellungen": "Anstellung",
    "Anstellwinkeln": "Anstellwinkel",
    "Anstellwinkels": "Anstellwinkel",
    "Anstemmenden": "Anstemmende",
    "Anstemmens": "Anstemmen",
    "Ansteuernden": "Ansteuernde",
    "Ansteuerns": "Ansteuern",
    "Ansteuerte": "ansteuert",
    "Ansteuerten": "Ansteuerte",
    "Anstiche": "Anstich",
    "Anstichen": "Anstich",
    "Anstichs": "Anstich",
    "Anstiege": "Anstieg",
    "Anstiegen": "Anstieg",
    "Anstiegs": "Anstieg",
    "Anstiftenden": "Anstiftende",
    "Anstiftenderen": "Anstiftendere",
    "Anstiftendsten": "Anstiftendste",
    "Anstiftens": "Anstiften",
    "Anstiftungen": "Anstiftung",
    "Anstimmenden": "Anstimmende",
    "Anstimmens": "Anstimmen",
    "Anstinkenden": "Anstinkende",
    "Anstinkens": "Anstinken",
    "Anstoße": "anstoßen",
    "Anstoßenden": "Anstoßende",
    "Anstoßens": "Anstoßen",
    "Anstoßes": "Anstoß",
    "Anstrahlenden": "Anstrahlende",
    "Anstrahlenderen": "Anstrahlendere",
    "Anstrahlendsten": "Anstrahlendste",
    "Anstrahlens": "Anstrahlen",
    "Anstrebenden": "Anstrebende",
    "Anstrebens": "Anstreben",
    "Anstreichenden": "Anstreichende",
    "Anstreichens": "Anstreichen",
    "Anstreichern": "Anstreicher",
    "Anstreichers": "Anstreicher",
    "Anstrengenden": "Anstrengende",
    "Anstrengenderen": "Anstrengendere",
    "Anstrengendsten": "Anstrengendste",
    "Anstrengens": "Anstrengen",
    "Anstrengungen": "Anstrengung",
    "Ansturme": "Ansturm",
    "Ansturms": "Ansturm",
    "Anständigen": "Anständige",
    "Anständigeren": "Anständigere",
    "Anständigsten": "Anständigste",
    "Anstöße": "Anstoß",
    "Anstößen": "Anstoß",
    "Anstößigen": "Anstößige",
    "Anstößigeren": "Anstößigere",
    "Anstößigkeiten": "Anstößigkeit",
    "Anstößigste": "anstößig",
    "Anstößigsten": "Anstößigste",
    "Anstürme": "anstürmen",
    "Anstürmen": "Ansturm",
    "Anstürmenden": "Anstürmende",
    "Anstürmenderen": "Anstürmendere",
    "Anstürmendsten": "Anstürmendste",
    "Anstürmens": "Anstürmen",
    "Ansuchenden": "Ansuchende",
    "Ansuchens": "Ansuchen",
    "Ansäenden": "Ansäende",
    "Ansäens": "Ansäen",
    "Ansägende": "ansägend",
    "Ansägenden": "Ansägende",
    "Ansägens": "Ansägen",
    "Ansässigen": "Ansässige",
    "Ansätze": "Ansatz",
    "Ansätzen": "Ansatz",
    "Ansäuernden": "Ansäuernde",
    "Ansäuernderen": "Ansäuerndere",
    "Ansäuerndsten": "Ansäuerndste",
    "Ansäuerns": "Ansäuern",
    "Ansäuselnden": "Ansäuselnde",
    "Ansäuselnderen": "Ansäuselndere",
    "Ansäuselndsten": "Ansäuselndste",
    "Ansäuselns": "Ansäuseln",
    "Antanzenden": "Antanzende",
    "Antanzens": "Antanzen",
    "Antarktischen": "Antarktische",
    "Antastenden": "Antastende",
    "Antastens": "Antasten",
    "Anteile": "Anteil",
    "Anteilen": "Anteil",
    "Anteilige": "anteilig",
    "Anteiligen": "Anteilige",
    "Anteils": "Anteil",
    "Antennen": "Antenne",
    "Antestenden": "Antestende",
    "Antestens": "Antesten",
    "Anthologien": "Anthologie",
    "Anthropologen": "Anthropologe",
    "Anthropologische": "anthropologisch",
    "Anthropologischen": "Anthropologische",
    "Anthropomorphisten": "Anthropomorphist",
    "Anthroposophen": "Anthroposoph",
    "Antibabypillen": "Antibabypille",
    "Antibakterielle": "antibakteriell",
    "Antibakteriellen": "Antibakterielle",
    "Antibaptisten": "Antibaptist",
    "Antifaschistische": "antifaschistisch",
    "Antifaschistischen": "Antifaschistische",
    "Antigene": "Antigen",
    "Antigenen": "Antigen",
    "Antigens": "Antigen",
    "Antihelden": "Antiheld",
    "Antike": "antik",
    "Antiken": "Antike",
    "Antikeren": "Antikere",
    "Antikommunisten": "Antikommunist",
    "Antikommunistische": "antikommunistisch",
    "Antikommunistischen": "Antikommunistische",
    "Antikonzeptionellen": "Antikonzeptionelle",
    "Antikriege": "Antikrieg",
    "Antikriegen": "Antikrieg",
    "Antikrieges": "Antikrieg",
    "Antikriegs": "Antikrieg",
    "Antikste": "antik",
    "Antiksten": "Antikste",
    "Antikörpern": "Antikörper",
    "Antikörpers": "Antikörper",
    "Antilopen": "Antilope",
    "Antimilitaristen": "Antimilitarist",
    "Antimilitaristische": "antimilitaristisch",
    "Antimilitaristischen": "Antimilitaristische",
    "Antipapisten": "Antipapist",
    "Antipathien": "Antipathie",
    "Antiphrasen": "Antiphrase",
    "Antippenden": "Antippende",
    "Antippens": "Antippen",
    "Antiquariate": "Antiquariat",
    "Antiquariaten": "Antiquariat",
    "Antiquariates": "Antiquariat",
    "Antiquariats": "Antiquariat",
    "Antiquarische": "antiquarisch",
    "Antiquarischen": "Antiquarische",
    "Antiquarischeren": "Antiquarischere",
    "Antiquarischsten": "Antiquarischste",
    "Antiquierten": "Antiquierte",
    "Antiquierteren": "Antiquiertere",
    "Antiquiertesten": "Antiquierteste",
    "Antiquitäten": "Antiquität",
    "Antisemiten": "Antisemit",
    "Antisemitische": "antisemitisch",
    "Antisemitischen": "Antisemitische",
    "Antiseptischen": "Antiseptische",
    "Antistatischen": "Antistatische",
    "Antistrophen": "Antistrophe",
    "Antiteilchens": "Antiteilchen",
    "Antitoxine": "Antitoxin",
    "Antitoxinen": "Antitoxin",
    "Antitoxins": "Antitoxin",
    "Antizipationen": "Antizipation",
    "Antizipierenden": "Antizipierende",
    "Antizipierenderen": "Antizipierendere",
    "Antizipierendsten": "Antizipierendste",
    "Antizipierens": "Antizipieren",
    "Antizipierte": "antizipiert",
    "Antizipierten": "Antizipierte",
    "Antjes": "Antje",
    "Antoines": "Antoine",
    "Antonios": "Antonio",
    "Antons": "Anton",
    "Antrabenden": "Antrabende",
    "Antrabens": "Antraben",
    "Antrage": "antragen",
    "Antragenden": "Antragende",
    "Antragens": "Antragen",
    "Antrags": "Antrag",
    "Antrauenden": "Antrauende",
    "Antrauens": "Antrauen",
    "Antreffenden": "Antreffende",
    "Antreffens": "Antreffen",
    "Antreibenden": "Antreibende",
    "Antreibens": "Antreiben",
    "Antretenden": "Antretende",
    "Antretens": "Antreten",
    "Antriebe": "Antrieb",
    "Antrieben": "Antrieb",
    "Antriebs": "Antrieb",
    "Antriebswellen": "Antriebswelle",
    "Antrinkenden": "Antrinkende",
    "Antrinkenderen": "Antrinkendere",
    "Antrinkendsten": "Antrinkendste",
    "Antrinkens": "Antrinken",
    "Antritts": "Antritt",
    "Antrittsreden": "Antrittsrede",
    "Anträge": "Antrag",
    "Anträgen": "Antrag",
    "Antwerpens": "Antwerpen",
    "Antworten": "Antwort",
    "Antwortenden": "Antwortende",
    "Antwortenderen": "Antwortendere",
    "Antwortendsten": "Antwortendste",
    "Antwortens": "Antworten",
    "Antönenden": "Antönende",
    "Antönens": "Antönen",
    "Antörnenden": "Antörnende",
    "Antörnenderen": "Antörnendere",
    "Antörnendsten": "Antörnendste",
    "Antörnens": "Antörnen",
    "Anvertrauenden": "Anvertrauende",
    "Anvertrauens": "Anvertrauen",
    "Anvertraute": "anvertraut",
    "Anvertrauten": "Anvertraute",
    "Anverwandten": "Anverwandte",
    "Anwachsenden": "Anwachsende",
    "Anwachsens": "Anwachsen",
    "Anwalte": "Anwalt",
    "Anwalts": "Anwalt",
    "Anwaltschaften": "Anwaltschaft",
    "Anwandelnden": "Anwandelnde",
    "Anwandelns": "Anwandeln",
    "Anwehenden": "Anwehende",
    "Anwehens": "Anwehen",
    "Anweisenden": "Anweisende",
    "Anweisens": "Anweisen",
    "Anweisungen": "Anweisung",
    "Anwendbare": "anwendbar",
    "Anwendbaren": "Anwendbare",
    "Anwendbareren": "Anwendbarere",
    "Anwendbarsten": "Anwendbarste",
    "Anwendenden": "Anwendende",
    "Anwendens": "Anwenden",
    "Anwendungen": "Anwendung",
    "Anwerbenden": "Anwerbende",
    "Anwerbens": "Anwerben",
    "Anwerfenden": "Anwerfende",
    "Anwerfens": "Anwerfen",
    "Anwesenden": "Anwesende",
    "Anwesens": "Anwesen",
    "Anwidernden": "Anwidernde",
    "Anwidernderen": "Anwiderndere",
    "Anwiderndsten": "Anwiderndste",
    "Anwiderns": "Anwidern",
    "Anwinkelnden": "Anwinkelnde",
    "Anwinkelns": "Anwinkeln",
    "Anwohnenden": "Anwohnende",
    "Anwohnens": "Anwohnen",
    "Anwohnern": "Anwohner",
    "Anwohners": "Anwohner",
    "Anwurzelnden": "Anwurzelnde",
    "Anwurzelns": "Anwurzeln",
    "Anwählenden": "Anwählende",
    "Anwählens": "Anwählen",
    "Anwälte": "Anwalt",
    "Anwälten": "Anwalt",
    "Anwärmenden": "Anwärmende",
    "Anwärmens": "Anwärmen",
    "Anwärtern": "Anwärter",
    "Anwärters": "Anwärter",
    "Anzahlen": "Anzahl",
    "Anzahlenden": "Anzahlende",
    "Anzahlens": "Anzahlen",
    "Anzahlungen": "Anzahlung",
    "Anzapfenden": "Anzapfende",
    "Anzapfens": "Anzapfen",
    "Anzaubernden": "Anzaubernde",
    "Anzauberns": "Anzaubern",
    "Anzeichens": "Anzeichen",
    "Anzeichnenden": "Anzeichnende",
    "Anzeichnens": "Anzeichnen",
    "Anzeigen": "Anzeige",
    "Anzeigenden": "Anzeigende",
    "Anzeigens": "Anzeigen",
    "Anzettelnden": "Anzettelnde",
    "Anzettelns": "Anzetteln",
    "Anziehenden": "Anziehende",
    "Anziehenderen": "Anziehendere",
    "Anziehendsten": "Anziehendste",
    "Anziehens": "Anziehen",
    "Anziehsachen": "Anziehsache",
    "Anzuge": "Anzug",
    "Anzugs": "Anzug",
    "Anzweifelnden": "Anzweifelnde",
    "Anzweifelnderen": "Anzweifelndere",
    "Anzweifelndsten": "Anzweifelndste",
    "Anzweifelns": "Anzweifeln",
    "Anzählende": "anzählend",
    "Anzählenden": "Anzählende",
    "Anzählenderen": "Anzählendere",
    "Anzählendsten": "Anzählendste",
    "Anzählens": "Anzählen",
    "Anzüge": "Anzug",
    "Anzügen": "Anzug",
    "Anzüglichen": "Anzügliche",
    "Anzüglicheren": "Anzüglichere",
    "Anzüglichsten": "Anzüglichste",
    "Anzündenden": "Anzündende",
    "Anzündens": "Anzünden",
    "Anödenden": "Anödende",
    "Anödenderen": "Anödendere",
    "Anödendsten": "Anödendste",
    "Anödens": "Anöden",
    "Aoriste": "Aorist",
    "Aoristen": "Aorist",
    "Aorists": "Aorist",
    "Aperiodische": "aperiodisch",
    "Aperiodischen": "Aperiodische",
    "Aperitifs": "Aperitif",
    "Apfelgrüne": "apfelgrün",
    "Apfelgrünen": "Apfelgrüne",
    "Apfelquitten": "Apfelquitte",
    "Apfels": "Apfel",
    "Apfelsinen": "Apfelsine",
    "Aphasien": "Aphasie",
    "Aphoristikern": "Aphoristiker",
    "Aphoristikers": "Aphoristiker",
    "Apokalypsen": "Apokalypse",
    "Apokalyptikern": "Apokalyptiker",
    "Apokalyptikers": "Apokalyptiker",
    "Apokalyptische": "apokalyptisch",
    "Apokalyptischen": "Apokalyptische",
    "Apolitischen": "Apolitische",
    "Apologe": "Apolog",
    "Apologen": "Apolog",
    "Apologien": "Apologie",
    "Apologs": "Apolog",
    "Apomorphine": "Apomorphin",
    "Apomorphinen": "Apomorphin",
    "Apomorphines": "Apomorphin",
    "Apomorphins": "Apomorphin",
    "Apophysen": "Apophyse",
    "Apoplektikern": "Apoplektiker",
    "Apoplektikers": "Apoplektiker",
    "Apostate": "Apostat",
    "Apostaten": "Apostat",
    "Apostats": "Apostat",
    "Aposteln": "Apostel",
    "Apostels": "Apostel",
    "Apostolate": "Apostolat",
    "Apostolaten": "Apostolat",
    "Apostolats": "Apostolat",
    "Apostolische": "apostolisch",
    "Apostolischen": "Apostolische",
    "Apotheken": "Apotheke",
    "Apothekenpflichtige": "apothekenpflichtig",
    "Apothekenpflichtigen": "Apothekenpflichtige",
    "Apothekern": "Apotheker",
    "Apothekers": "Apotheker",
    "Apparate": "Apparat",
    "Apparaten": "Apparat",
    "Apparates": "Apparat",
    "Apparative": "apparativ",
    "Apparativen": "Apparative",
    "Apparats": "Apparat",
    "Apparaturen": "Apparatur",
    "Appellationen": "Appellation",
    "Appellative": "Appellativ",
    "Appellativen": "Appellativ",
    "Appellativs": "Appellativ",
    "Appelle": "Appell",
    "Appellen": "Appell",
    "Appellierenden": "Appellierende",
    "Appellierens": "Appellieren",
    "Appellierte": "appelliert",
    "Appellierten": "Appellierte",
    "Appells": "Appell",
    "Appels": "Appel",
    "Apperzeptionen": "Apperzeption",
    "Appetitanregende": "appetitanregend",
    "Appetitanregenden": "Appetitanregende",
    "Appetitanregenderen": "Appetitanregendere",
    "Appetite": "Appetit",
    "Appetiten": "Appetit",
    "Appetitliche": "appetitlich",
    "Appetitlichen": "Appetitliche",
    "Appetitlicheren": "Appetitlichere",
    "Appetitlichsten": "Appetitlichste",
    "Appetitlosen": "Appetitlose",
    "Appetitloseren": "Appetitlosere",
    "Appetitlosesten": "Appetitloseste",
    "Appetits": "Appetit",
    "Applaudierenden": "Applaudierende",
    "Applaudierenderen": "Applaudierendere",
    "Applaudierendsten": "Applaudierendste",
    "Applaudierens": "Applaudieren",
    "Applaudierte": "applaudiert",
    "Applaudierten": "Applaudierte",
    "Applikationen": "Applikation",
    "Applikatore": "Applikator",
    "Applikatoren": "Applikator",
    "Applikators": "Applikator",
    "Apportierenden": "Apportierende",
    "Apportierenderen": "Apportierendere",
    "Apportierendsten": "Apportierendste",
    "Apportierens": "Apportieren",
    "Apportierte": "apportiert",
    "Apportierten": "Apportierte",
    "Appositionen": "Apposition",
    "Apprehensionen": "Apprehension",
    "Appretierenden": "Appretierende",
    "Appretierenderen": "Appretierendere",
    "Appretierendsten": "Appretierendste",
    "Appretierens": "Appretieren",
    "Appretierte": "appretiert",
    "Appretierten": "Appretierte",
    "Appretierteren": "Appretiertere",
    "Appretiertesten": "Appretierteste",
    "Appreturen": "Appretur",
    "Approbationen": "Approbation",
    "Approximationen": "Approximation",
    "Approximative": "approximativ",
    "Approximativen": "Approximative",
    "Aprikosen": "Aprikose",
    "Aprilias": "Aprilia",
    "Aprils": "April",
    "Aquakulturen": "Aquakultur",
    "Aquanauten": "Aquanaut",
    "Aquarelle": "Aquarell",
    "Aquarellen": "Aquarell",
    "Aquarelles": "Aquarell",
    "Aquarells": "Aquarell",
    "Aquastrippings": "Aquastripping",
    "Aquädukte": "Aquädukt",
    "Aquädukten": "Aquädukt",
    "Aquädukts": "Aquädukt",
    "Arabern": "Araber",
    "Arabers": "Araber",
    "Arabiens": "Arabien",
    "Arabische": "arabisch",
    "Arabischen": "Arabische",
    "Arabisten": "Arabist",
    "Arachnologen": "Arachnologe",
    "Arafats": "Arafat",
    "Arbeiten": "Arbeit",
    "Arbeitenden": "Arbeitende",
    "Arbeitens": "Arbeiten",
    "Arbeiterinnen": "Arbeiterin",
    "Arbeitern": "Arbeiter",
    "Arbeiters": "Arbeiter",
    "Arbeitgebern": "Arbeitgeber",
    "Arbeitgebers": "Arbeitgeber",
    "Arbeitnehmern": "Arbeitnehmer",
    "Arbeitnehmers": "Arbeitnehmer",
    "Arbeitsame": "arbeitsam",
    "Arbeitsamen": "Arbeitsame",
    "Arbeitsameren": "Arbeitsamere",
    "Arbeitsamsten": "Arbeitsamste",
    "Arbeitsamte": "Arbeitsamt",
    "Arbeitsamtes": "Arbeitsamt",
    "Arbeitsamts": "Arbeitsamt",
    "Arbeitsfähige": "arbeitsfähig",
    "Arbeitsfähigen": "Arbeitsfähige",
    "Arbeitsfähigeren": "Arbeitsfähigere",
    "Arbeitsfähigsten": "Arbeitsfähigste",
    "Arbeitsintensiven": "Arbeitsintensive",
    "Arbeitsintensiveren": "Arbeitsintensivere",
    "Arbeitslosen": "Arbeitslose",
    "Arbeitsrechtlichen": "Arbeitsrechtliche",
    "Arbeitsscheuen": "Arbeitsscheue",
    "Arbeitsscheueren": "Arbeitsscheuere",
    "Arbeitsscheuesten": "Arbeitsscheueste",
    "Arbeitsunfähigen": "Arbeitsunfähige",
    "Arbeitswilligen": "Arbeitswillige",
    "Arbeitsämter": "Arbeitsamt",
    "Arbeitsämtern": "Arbeitsamt",
    "Archen": "Arche",
    "Architekten": "Architekt",
    "Architektinnen": "Architektin",
    "Archive": "Archiv",
    "Archiven": "Archiv",
    "Archives": "Archiv",
    "Archivs": "Archiv",
    "Archäologen": "Archäologe",
    "Archäologische": "archäologisch",
    "Archäologischen": "Archäologische",
    "Areale": "Areal",
    "Arealen": "Areal",
    "Areales": "Areal",
    "Areals": "Areal",
    "Arenen": "Arena",
    "Arge": "arg",
    "Argen": "Arge",
    "Argentiniens": "Argentinien",
    "Arglistigen": "Arglistige",
    "Arglistigeren": "Arglistigere",
    "Arglistigsten": "Arglistigste",
    "Arglosen": "Arglose",
    "Argloseren": "Arglosere",
    "Arglosesten": "Argloseste",
    "Argumentationen": "Argumentation",
    "Argumentative": "argumentativ",
    "Argumentativen": "Argumentative",
    "Argumente": "Argument",
    "Argumenten": "Argument",
    "Argumentiere": "argumentieren",
    "Argumentierenden": "Argumentierende",
    "Argumentierenderen": "Argumentierendere",
    "Argumentierens": "Argumentieren",
    "Argumentierte": "argumentiert",
    "Argumentierten": "Argumentierte",
    "Arguments": "Argument",
    "Argwohns": "Argwohn",
    "Argwöhnenden": "Argwöhnende",
    "Argwöhnenderen": "Argwöhnendere",
    "Argwöhnendsten": "Argwöhnendste",
    "Argwöhnens": "Argwöhnen",
    "Argwöhnischen": "Argwöhnische",
    "Argwöhnischeren": "Argwöhnischere",
    "Argwöhnischsten": "Argwöhnischste",
    "Arhythmischen": "Arhythmische",
    "Arien": "Arie",
    "Ariern": "Arier",
    "Ariers": "Arier",
    "Arische": "arisch",
    "Arischen": "Arische",
    "Aristokraten": "Aristokrat",
    "Aristokratien": "Aristokratie",
    "Aristokratische": "aristokratisch",
    "Aristokratischen": "Aristokratische",
    "Arithmetikern": "Arithmetiker",
    "Arithmetikers": "Arithmetiker",
    "Arithmetische": "arithmetisch",
    "Arithmetischen": "Arithmetische",
    "Arkaden": "Arkade",
    "Arkadiern": "Arkadier",
    "Arkadiers": "Arkadier",
    "Arktikern": "Arktiker",
    "Arktikers": "Arktiker",
    "Arktische": "arktisch",
    "Arktischen": "Arktische",
    "Arkusfunktionen": "Arkusfunktion",
    "Arme": "Arm",
    "Armeen": "Armee",
    "Armen": "Arme",
    "Armeniens": "Armenien",
    "Armenische": "armenisch",
    "Armenischen": "Armenische",
    "Armenkassen": "Armenkasse",
    "Armierungen": "Armierung",
    "Armins": "Armin",
    "Armlehnen": "Armlehne",
    "Arms": "Arm",
    "Armselige": "armselig",
    "Armseligen": "Armselige",
    "Armseligeren": "Armseligere",
    "Armseligsten": "Armseligste",
    "Arndts": "Arndt",
    "Arnolds": "Arnold",
    "Aromatische": "aromatisch",
    "Aromatischen": "Aromatische",
    "Aromatischeren": "Aromatischere",
    "Aromatischsten": "Aromatischste",
    "Aromatisierenden": "Aromatisierende",
    "Aromatisierenderen": "Aromatisierendere",
    "Aromatisierens": "Aromatisieren",
    "Aromatisierte": "aromatisiert",
    "Aromatisierten": "Aromatisierte",
    "Aromatisierteren": "Aromatisiertere",
    "Aromatisiertesten": "Aromatisierteste",
    "Arraks": "Arrak",
    "Arrangements": "Arrangement",
    "Arrangierenden": "Arrangierende",
    "Arrangierens": "Arrangieren",
    "Arrangierte": "arrangiert",
    "Arrangierten": "Arrangierte",
    "Arreste": "Arrest",
    "Arresten": "Arrest",
    "Arrestes": "Arrest",
    "Arrests": "Arrest",
    "Arrogante": "arrogant",
    "Arroganten": "Arrogante",
    "Arroganteren": "Arrogantere",
    "Arrogantesten": "Arroganteste",
    "Arschkalten": "Arschkalte",
    "Arschs": "Arsch",
    "Arsenale": "Arsenal",
    "Arsenalen": "Arsenal",
    "Arsenals": "Arsenal",
    "Arten": "Art",
    "Artenden": "Artende",
    "Artens": "Arten",
    "Arterien": "Arterie",
    "Artfremden": "Artfremde",
    "Artgenossen": "Artgenosse",
    "Artgleiche": "artgleich",
    "Artgleichen": "Artgleiche",
    "Arthurs": "Arthur",
    "Artige": "artig",
    "Artigen": "Artige",
    "Artigeren": "Artigere",
    "Artigsten": "Artigste",
    "Artikeln": "Artikel",
    "Artikels": "Artikel",
    "Artikulationen": "Artikulation",
    "Artikulationsstellen": "Artikulationsstelle",
    "Artikulierenden": "Artikulierende",
    "Artikulierenderen": "Artikulierendere",
    "Artikulierendsten": "Artikulierendste",
    "Artikulierens": "Artikulieren",
    "Artikulierte": "artikuliert",
    "Artikulierten": "Artikulierte",
    "Artillerien": "Artillerie",
    "Artischocken": "Artischocke",
    "Artisten": "Artist",
    "Artistinnen": "Artistin",
    "Artotheken": "Artothek",
    "Artungen": "Artung",
    "Artverwandte": "artverwandt",
    "Artverwandten": "Artverwandte",
    "Arzte": "Arzt",
    "Arztes": "Arzt",
    "As": "﻿A",
    "Asbeste": "Asbest",
    "Asbesten": "Asbest",
    "Asbestes": "Asbest",
    "Asbests": "Asbest",
    "Aschaffenburgs": "Aschaffenburg",
    "Aschbleiche": "aschbleich",
    "Aschbleichen": "Aschbleiche",
    "Aschbleicheren": "Aschbleichere",
    "Aschbleichsten": "Aschbleichste",
    "Aschblonden": "Aschblonde",
    "Aschblonderen": "Aschblondere",
    "Aschblondesten": "Aschblondeste",
    "Ascheimern": "Ascheimer",
    "Ascheimers": "Ascheimer",
    "Aschen": "Asche",
    "Aschermittwoche": "Aschermittwoch",
    "Aschermittwochen": "Aschermittwoch",
    "Aschermittwochs": "Aschermittwoch",
    "Aserbaidschanische": "aserbaidschanisch",
    "Aserbaidschanischen": "Aserbaidschanische",
    "Aserbaidschans": "Aserbaidschan",
    "Asiaten": "Asiat",
    "Asiatische": "asiatisch",
    "Asiatischen": "Asiatische",
    "Asiatischeren": "Asiatischere",
    "Asiatischsten": "Asiatischste",
    "Asiens": "Asien",
    "Asketische": "asketisch",
    "Asketischen": "Asketische",
    "Asozialen": "Asoziale",
    "Asparaginsäuren": "Asparaginsäure",
    "Aspekte": "Aspekt",
    "Aspekten": "Aspekt",
    "Aspektes": "Aspekt",
    "Aspekts": "Aspekt",
    "Asphalte": "Asphalt",
    "Asphalten": "Asphalt",
    "Asphaltes": "Asphalt",
    "Asphaltierenden": "Asphaltierende",
    "Asphaltierens": "Asphaltieren",
    "Asphaltierte": "asphaltiert",
    "Asphaltierten": "Asphaltierte",
    "Asphaltierteren": "Asphaltiertere",
    "Asphaltiertesten": "Asphaltierteste",
    "Asphalts": "Asphalt",
    "Assekuranzen": "Assekuranz",
    "Asseln": "Assel",
    "Assenheimern": "Assenheimer",
    "Assenheimers": "Assenheimer",
    "Assenheims": "Assenheim",
    "Assertionen": "Assertion",
    "Assessore": "Assessor",
    "Assessoren": "Assessor",
    "Assessorinnen": "Assessorin",
    "Assessors": "Assessor",
    "Assimilationen": "Assimilation",
    "Assimilierenden": "Assimilierende",
    "Assimilierenderen": "Assimilierendere",
    "Assimilierendsten": "Assimilierendste",
    "Assimilierens": "Assimilieren",
    "Assimilierte": "assimiliert",
    "Assimilierten": "Assimilierte",
    "Assimilierteren": "Assimiliertere",
    "Assimiliertesten": "Assimilierteste",
    "Assimilierungen": "Assimilierung",
    "Assistenten": "Assistent",
    "Assistenzen": "Assistenz",
    "Assistierenden": "Assistierende",
    "Assistierens": "Assistieren",
    "Assistierte": "assistiert",
    "Assistierten": "Assistierte",
    "Assmanns": "Assmann",
    "Associations": "Association",
    "Assonanzen": "Assonanz",
    "Assoziationen": "Assoziation",
    "Assoziative": "assoziativ",
    "Assoziativen": "Assoziative",
    "Assoziativeren": "Assoziativere",
    "Assoziativsten": "Assoziativste",
    "Assoziierenden": "Assoziierende",
    "Assoziierenderen": "Assoziierendere",
    "Assoziierendsten": "Assoziierendste",
    "Assoziierens": "Assoziieren",
    "Assoziierte": "assoziiert",
    "Assoziierten": "Assoziierte",
    "Assoziierteren": "Assoziiertere",
    "Assoziiertesten": "Assoziierteste",
    "Aste": "Ast",
    "Asteroiden": "Asteroid",
    "Asthmas": "Asthma",
    "Asthmatische": "asthmatisch",
    "Asthmatischen": "Asthmatische",
    "Astreinen": "Astreine",
    "Astrids": "Astrid",
    "Astrographen": "Astrograph",
    "Astrologen": "Astrologe",
    "Astrologische": "astrologisch",
    "Astrologischen": "Astrologische",
    "Astronauten": "Astronaut",
    "Astronomen": "Astronom",
    "Astronomische": "astronomisch",
    "Astronomischen": "Astronomische",
    "Asts": "Ast",
    "Astwerke": "Astwerk",
    "Astwerken": "Astwerk",
    "Astwerkes": "Astwerk",
    "Astwerks": "Astwerk",
    "Asylanten": "Asylant",
    "Asyls": "Asyl",
    "Aszendenten": "Aszendent",
    "Aszendenzen": "Aszendenz",
    "Ateliers": "Atelier",
    "Atemberaubende": "atemberaubend",
    "Atemberaubenden": "Atemberaubende",
    "Atemberaubenderen": "Atemberaubendere",
    "Atemberaubendsten": "Atemberaubendste",
    "Atemlosen": "Atemlose",
    "Atemloseren": "Atemlosere",
    "Atemlosesten": "Atemloseste",
    "Atemraubenden": "Atemraubende",
    "Atems": "Atem",
    "Atheisten": "Atheist",
    "Atheistische": "atheistisch",
    "Atheistischen": "Atheistische",
    "Athens": "Athen",
    "Athleten": "Athlet",
    "Athletinnen": "Athletin",
    "Athletische": "athletisch",
    "Athletischen": "Athletische",
    "Athletischeren": "Athletischere",
    "Athletischsten": "Athletischste",
    "Atlanten": "Atlas",
    "Atlantiks": "Atlantik",
    "Atlantische": "atlantisch",
    "Atlantischen": "Atlantische",
    "Atmenden": "Atmende",
    "Atmens": "Atmen",
    "Atmosphären": "Atmosphäre",
    "Atmungsketten": "Atmungskette",
    "Atomare": "atomar",
    "Atomaren": "Atomare",
    "Atombomben": "Atombombe",
    "Atomisierenden": "Atomisierende",
    "Atomisierenderen": "Atomisierendere",
    "Atomisierendsten": "Atomisierendste",
    "Atomisierens": "Atomisieren",
    "Atomisierte": "atomisiert",
    "Atomisierten": "Atomisierte",
    "Atomisierteren": "Atomisiertere",
    "Atomisiertesten": "Atomisierteste",
    "Atoxischen": "Atoxische",
    "Atrazins": "Atrazin",
    "Attacken": "Attacke",
    "Attackierenden": "Attackierende",
    "Attackierenderen": "Attackierendere",
    "Attackierendsten": "Attackierendste",
    "Attackierens": "Attackieren",
    "Attackierte": "attackiert",
    "Attackierten": "Attackierte",
    "Attackierteren": "Attackiertere",
    "Attackiertesten": "Attackierteste",
    "Attentate": "Attentat",
    "Attentaten": "Attentat",
    "Attentates": "Attentat",
    "Attentats": "Attentat",
    "Atteste": "Attest",
    "Attesten": "Attest",
    "Attestes": "Attest",
    "Attestierenden": "Attestierende",
    "Attestierens": "Attestieren",
    "Attestierte": "attestiert",
    "Attestierten": "Attestierte",
    "Attests": "Attest",
    "Attitüden": "Attitüde",
    "Attraktionen": "Attraktion",
    "Attraktive": "attraktiv",
    "Attraktiven": "Attraktive",
    "Attraktiveren": "Attraktivere",
    "Attraktivitäten": "Attraktivität",
    "Attraktivste": "attraktiv",
    "Attraktivsten": "Attraktivste",
    "Attribute": "Attribut",
    "Attributen": "Attribut",
    "Attributes": "Attribut",
    "Attributive": "attributiv",
    "Attributiven": "Attributive",
    "Attributs": "Attribut",
    "Atüs": "Atü",
    "Audienzen": "Audienz",
    "Audiovisuelle": "audiovisuell",
    "Audiovisuellen": "Audiovisuelle",
    "Auditiven": "Auditive",
    "Auditore": "Auditor",
    "Auditoren": "Auditor",
    "Auditors": "Auditor",
    "Auen": "Aue",
    "Auerbachs": "Auerbach",
    "Auerhennen": "Auerhenne",
    "Aufarbeitenden": "Aufarbeitende",
    "Aufarbeitens": "Aufarbeiten",
    "Aufarbeitungen": "Aufarbeitung",
    "Aufatmenden": "Aufatmende",
    "Aufatmens": "Aufatmen",
    "Aufbackenden": "Aufbackende",
    "Aufbackens": "Aufbacken",
    "Aufbahrenden": "Aufbahrende",
    "Aufbahrens": "Aufbahren",
    "Aufbahrungen": "Aufbahrung",
    "Aufbauenden": "Aufbauende",
    "Aufbauens": "Aufbauen",
    "Aufbaus": "Aufbau",
    "Aufbauschenden": "Aufbauschende",
    "Aufbauschenderen": "Aufbauschendere",
    "Aufbauschendsten": "Aufbauschendste",
    "Aufbauschens": "Aufbauschen",
    "Aufbauten": "aufbauen",
    "Aufbegehrenden": "Aufbegehrende",
    "Aufbegehrenderen": "Aufbegehrendere",
    "Aufbegehrendsten": "Aufbegehrendste",
    "Aufbegehrens": "Aufbegehren",
    "Aufbegehrte": "aufbegehrt",
    "Aufbegehrten": "Aufbegehrte",
    "Aufbegehrteren": "Aufbegehrtere",
    "Aufbegehrtesten": "Aufbegehrteste",
    "Aufbehaltenden": "Aufbehaltende",
    "Aufbehaltenen": "Aufbehaltene",
    "Aufbehaltens": "Aufbehalten",
    "Aufbeißenden": "Aufbeißende",
    "Aufbeißens": "Aufbeißen",
    "Aufbekommenden": "Aufbekommende",
    "Aufbekommenen": "Aufbekommene",
    "Aufbekommens": "Aufbekommen",
    "Aufbereitenden": "Aufbereitende",
    "Aufbereitenderen": "Aufbereitendere",
    "Aufbereitendsten": "Aufbereitendste",
    "Aufbereitens": "Aufbereiten",
    "Aufbereitete": "aufbereitet",
    "Aufbereiteten": "Aufbereitete",
    "Aufbereiteteren": "Aufbereitetere",
    "Aufbereitetesten": "Aufbereiteteste",
    "Aufberittenen": "Aufberittene",
    "Aufbeschworenen": "Aufbeschworene",
    "Aufbeschwörenden": "Aufbeschwörende",
    "Aufbeschwörens": "Aufbeschwören",
    "Aufbessernden": "Aufbessernde",
    "Aufbesserns": "Aufbessern",
    "Aufbesserungen": "Aufbesserung",
    "Aufbettenden": "Aufbettende",
    "Aufbettens": "Aufbetten",
    "Aufbewahrenden": "Aufbewahrende",
    "Aufbewahrens": "Aufbewahren",
    "Aufbewahrte": "aufbewahrt",
    "Aufbewahrten": "Aufbewahrte",
    "Aufbewahrungen": "Aufbewahrung",
    "Aufbiegenden": "Aufbiegende",
    "Aufbiegens": "Aufbiegen",
    "Aufbietenden": "Aufbietende",
    "Aufbietens": "Aufbieten",
    "Aufbindenden": "Aufbindende",
    "Aufbindens": "Aufbinden",
    "Aufblasenden": "Aufblasende",
    "Aufblasens": "Aufblasen",
    "Aufbleibenden": "Aufbleibende",
    "Aufbleibens": "Aufbleiben",
    "Aufblendenden": "Aufblendende",
    "Aufblendens": "Aufblenden",
    "Aufblicke": "Aufblick",
    "Aufblicken": "Aufblick",
    "Aufblicks": "Aufblick",
    "Aufblitzenden": "Aufblitzende",
    "Aufblitzens": "Aufblitzen",
    "Aufblähenden": "Aufblähende",
    "Aufblähenderen": "Aufblähendere",
    "Aufblähendsten": "Aufblähendste",
    "Aufblähens": "Aufblähen",
    "Aufblätternden": "Aufblätternde",
    "Aufblätterns": "Aufblättern",
    "Aufblühenden": "Aufblühende",
    "Aufblühenderen": "Aufblühendere",
    "Aufblühendsten": "Aufblühendste",
    "Aufblühens": "Aufblühen",
    "Aufbratenden": "Aufbratende",
    "Aufbratens": "Aufbraten",
    "Aufbrauchenden": "Aufbrauchende",
    "Aufbrauchens": "Aufbrauchen",
    "Aufbrausenden": "Aufbrausende",
    "Aufbrausenderen": "Aufbrausendere",
    "Aufbrausendsten": "Aufbrausendste",
    "Aufbrausens": "Aufbrausen",
    "Aufbrechenden": "Aufbrechende",
    "Aufbrechens": "Aufbrechen",
    "Aufbrennenden": "Aufbrennende",
    "Aufbrennens": "Aufbrennen",
    "Aufbringenden": "Aufbringende",
    "Aufbringens": "Aufbringen",
    "Aufbruche": "Aufbruch",
    "Aufbruchs": "Aufbruch",
    "Aufbrummenden": "Aufbrummende",
    "Aufbrummenderen": "Aufbrummendere",
    "Aufbrummendsten": "Aufbrummendste",
    "Aufbrummens": "Aufbrummen",
    "Aufbrüche": "Aufbruch",
    "Aufbrüchen": "Aufbruch",
    "Aufbrühenden": "Aufbrühende",
    "Aufbrühens": "Aufbrühen",
    "Aufbäumenden": "Aufbäumende",
    "Aufbäumenderen": "Aufbäumendere",
    "Aufbäumendsten": "Aufbäumendste",
    "Aufbäumens": "Aufbäumen",
    "Aufbügelnden": "Aufbügelnde",
    "Aufbügelns": "Aufbügeln",
    "Aufbürdenden": "Aufbürdende",
    "Aufbürdens": "Aufbürden",
    "Aufdampfenden": "Aufdampfende",
    "Aufdampfens": "Aufdampfen",
    "Aufdeckenden": "Aufdeckende",
    "Aufdeckens": "Aufdecken",
    "Aufdonnernden": "Aufdonnernde",
    "Aufdonnernderen": "Aufdonnerndere",
    "Aufdonnerndsten": "Aufdonnerndste",
    "Aufdonnerns": "Aufdonnern",
    "Aufdrehenden": "Aufdrehende",
    "Aufdrehenderen": "Aufdrehendere",
    "Aufdrehendsten": "Aufdrehendste",
    "Aufdrehens": "Aufdrehen",
    "Aufdringlichen": "Aufdringliche",
    "Aufdringlicheren": "Aufdringlichere",
    "Aufdringlichsten": "Aufdringlichste",
    "Aufdrucke": "Aufdruck",
    "Aufdrucken": "Aufdruck",
    "Aufdrucks": "Aufdruck",
    "Aufdrängenden": "Aufdrängende",
    "Aufdrängenderen": "Aufdrängendere",
    "Aufdrängendsten": "Aufdrängendste",
    "Aufdrängens": "Aufdrängen",
    "Aufdröselnden": "Aufdröselnde",
    "Aufdröselnderen": "Aufdröselndere",
    "Aufdröselndsten": "Aufdröselndste",
    "Aufdröselns": "Aufdröseln",
    "Aufdrückenden": "Aufdrückende",
    "Aufdrückens": "Aufdrücken",
    "Aufdämmenden": "Aufdämmende",
    "Aufdämmens": "Aufdämmen",
    "Aufenthalte": "Aufenthalt",
    "Aufenthalten": "Aufenthalt",
    "Aufenthalts": "Aufenthalt",
    "Auferlegenden": "Auferlegende",
    "Auferlegens": "Auferlegen",
    "Auferlegte": "auferlegt",
    "Auferlegten": "Auferlegte",
    "Auferstandenen": "Auferstandene",
    "Auferstehenden": "Auferstehende",
    "Auferstehens": "Auferstehen",
    "Auferstehungen": "Auferstehung",
    "Aufessenden": "Aufessende",
    "Aufessens": "Aufessen",
    "Auffahrenden": "Auffahrende",
    "Auffahrens": "Auffahren",
    "Auffahrten": "Auffahrt",
    "Auffallenden": "Auffallende",
    "Auffallenderen": "Auffallendere",
    "Auffallendsten": "Auffallendste",
    "Auffallens": "Auffallen",
    "Auffangenden": "Auffangende",
    "Auffangens": "Auffangen",
    "Auffanglagern": "Auffanglager",
    "Auffanglagers": "Auffanglager",
    "Auffassenden": "Auffassende",
    "Auffassens": "Auffassen",
    "Auffassungen": "Auffassung",
    "Auffindenden": "Auffindende",
    "Auffindens": "Auffinden",
    "Auffischenden": "Auffischende",
    "Auffischens": "Auffischen",
    "Aufflammenden": "Aufflammende",
    "Aufflammenderen": "Aufflammendere",
    "Aufflammendsten": "Aufflammendste",
    "Aufflammens": "Aufflammen",
    "Auffliegenden": "Auffliegende",
    "Auffliegens": "Auffliegen",
    "Auffordernden": "Auffordernde",
    "Auffordernderen": "Aufforderndere",
    "Aufforderndsten": "Aufforderndste",
    "Aufforderns": "Auffordern",
    "Aufforderungen": "Aufforderung",
    "Aufforstenden": "Aufforstende",
    "Aufforstens": "Aufforsten",
    "Auffressenden": "Auffressende",
    "Auffressens": "Auffressen",
    "Auffrischenden": "Auffrischende",
    "Auffrischenderen": "Auffrischendere",
    "Auffrischendsten": "Auffrischendste",
    "Auffrischens": "Auffrischen",
    "Auffrischungen": "Auffrischung",
    "Auffädelnden": "Auffädelnde",
    "Auffädelns": "Auffädeln",
    "Auffälligen": "Auffällige",
    "Auffälligeren": "Auffälligere",
    "Auffälligsten": "Auffälligste",
    "Auffärbenden": "Auffärbende",
    "Auffärbens": "Auffärben",
    "Aufführenden": "Aufführende",
    "Aufführens": "Aufführen",
    "Aufführungen": "Aufführung",
    "Auffüllenden": "Auffüllende",
    "Auffüllens": "Auffüllen",
    "Aufgabelnden": "Aufgabelnde",
    "Aufgabelns": "Aufgabeln",
    "Aufgaben": "aufgeben",
    "Aufgaloppierenden": "Aufgaloppierende",
    "Aufgaloppierens": "Aufgaloppieren",
    "Aufgaloppierte": "aufgaloppiert",
    "Aufgaloppierten": "Aufgaloppierte",
    "Aufgange": "Aufgang",
    "Aufgangs": "Aufgang",
    "Aufgangspunkte": "Aufgangspunkt",
    "Aufgangspunkten": "Aufgangspunkt",
    "Aufgangspunkts": "Aufgangspunkt",
    "Aufgearbeiteten": "Aufgearbeitete",
    "Aufgeatmeten": "Aufgeatmete",
    "Aufgebackenen": "Aufgebackene",
    "Aufgebackeneren": "Aufgebackenere",
    "Aufgebackensten": "Aufgebackenste",
    "Aufgebahrten": "Aufgebahrte",
    "Aufgebauschten": "Aufgebauschte",
    "Aufgebauschteren": "Aufgebauschtere",
    "Aufgebauschtesten": "Aufgebauschteste",
    "Aufgebauten": "Aufgebaute",
    "Aufgebenden": "Aufgebende",
    "Aufgebens": "Aufgeben",
    "Aufgebesserten": "Aufgebesserte",
    "Aufgebetteten": "Aufgebettete",
    "Aufgebissenen": "Aufgebissene",
    "Aufgeblasenen": "Aufgeblasene",
    "Aufgeblaseneren": "Aufgeblasenere",
    "Aufgeblasensten": "Aufgeblasenste",
    "Aufgeblendeten": "Aufgeblendete",
    "Aufgebliebenen": "Aufgebliebene",
    "Aufgeblitzten": "Aufgeblitzte",
    "Aufgeblähten": "Aufgeblähte",
    "Aufgeblähteren": "Aufgeblähtere",
    "Aufgeblähtesten": "Aufgeblähteste",
    "Aufgeblätterten": "Aufgeblätterte",
    "Aufgeblühten": "Aufgeblühte",
    "Aufgeblühteren": "Aufgeblühtere",
    "Aufgeblühtesten": "Aufgeblühteste",
    "Aufgebogenen": "Aufgebogene",
    "Aufgebote": "Aufgebot",
    "Aufgeboten": "Aufgebot",
    "Aufgebotene": "aufgeboten",
    "Aufgebotenen": "Aufgebotene",
    "Aufgeboteneren": "Aufgebotenere",
    "Aufgebotensten": "Aufgebotenste",
    "Aufgebotes": "Aufgebot",
    "Aufgebots": "Aufgebot",
    "Aufgebrachten": "Aufgebrachte",
    "Aufgebrachteren": "Aufgebrachtere",
    "Aufgebrachtesten": "Aufgebrachteste",
    "Aufgebrannten": "Aufgebrannte",
    "Aufgebratenen": "Aufgebratene",
    "Aufgebrauchten": "Aufgebrauchte",
    "Aufgebrausten": "Aufgebrauste",
    "Aufgebrausteren": "Aufgebraustere",
    "Aufgebraustesten": "Aufgebrausteste",
    "Aufgebrochenen": "Aufgebrochene",
    "Aufgebrocheneren": "Aufgebrochenere",
    "Aufgebrochensten": "Aufgebrochenste",
    "Aufgebrummten": "Aufgebrummte",
    "Aufgebrummteren": "Aufgebrummtere",
    "Aufgebrummtesten": "Aufgebrummteste",
    "Aufgebrühten": "Aufgebrühte",
    "Aufgebundenen": "Aufgebundene",
    "Aufgebäumten": "Aufgebäumte",
    "Aufgebäumteren": "Aufgebäumtere",
    "Aufgebäumtesten": "Aufgebäumteste",
    "Aufgebügelten": "Aufgebügelte",
    "Aufgebürdeten": "Aufgebürdete",
    "Aufgedampften": "Aufgedampfte",
    "Aufgedeckten": "Aufgedeckte",
    "Aufgedonnerten": "Aufgedonnerte",
    "Aufgedonnerteren": "Aufgedonnertere",
    "Aufgedonnertesten": "Aufgedonnerteste",
    "Aufgedrehten": "Aufgedrehte",
    "Aufgedrehteren": "Aufgedrehtere",
    "Aufgedrehtesten": "Aufgedrehteste",
    "Aufgedrängten": "Aufgedrängte",
    "Aufgedrängteren": "Aufgedrängtere",
    "Aufgedrängtesten": "Aufgedrängteste",
    "Aufgedröselten": "Aufgedröselte",
    "Aufgedröselteren": "Aufgedröseltere",
    "Aufgedröseltesten": "Aufgedröselteste",
    "Aufgedrückten": "Aufgedrückte",
    "Aufgedunsenen": "Aufgedunsene",
    "Aufgedunseneren": "Aufgedunsenere",
    "Aufgedunsensten": "Aufgedunsenste",
    "Aufgedämmten": "Aufgedämmte",
    "Aufgefahrenen": "Aufgefahrene",
    "Aufgefallenen": "Aufgefallene",
    "Aufgefangenen": "Aufgefangene",
    "Aufgefangeneren": "Aufgefangenere",
    "Aufgefangensten": "Aufgefangenste",
    "Aufgefaßten": "Aufgefaßte",
    "Aufgefischten": "Aufgefischte",
    "Aufgeflammten": "Aufgeflammte",
    "Aufgeflammteren": "Aufgeflammtere",
    "Aufgeflammtesten": "Aufgeflammteste",
    "Aufgeflogenen": "Aufgeflogene",
    "Aufgeflogeneren": "Aufgeflogenere",
    "Aufgeflogensten": "Aufgeflogenste",
    "Aufgeforderten": "Aufgeforderte",
    "Aufgeforsteten": "Aufgeforstete",
    "Aufgeforsteteren": "Aufgeforstetere",
    "Aufgeforstetesten": "Aufgeforsteteste",
    "Aufgefressenen": "Aufgefressene",
    "Aufgefresseneren": "Aufgefressenere",
    "Aufgefressensten": "Aufgefressenste",
    "Aufgefrischten": "Aufgefrischte",
    "Aufgefrischteren": "Aufgefrischtere",
    "Aufgefrischtesten": "Aufgefrischteste",
    "Aufgefundenen": "Aufgefundene",
    "Aufgefädelten": "Aufgefädelte",
    "Aufgefärbten": "Aufgefärbte",
    "Aufgeführten": "Aufgeführte",
    "Aufgefüllten": "Aufgefüllte",
    "Aufgegabelten": "Aufgegabelte",
    "Aufgegangenen": "Aufgegangene",
    "Aufgegebenen": "Aufgegebene",
    "Aufgegeilten": "Aufgegeilte",
    "Aufgegeilteren": "Aufgegeiltere",
    "Aufgegeiltesten": "Aufgegeilteste",
    "Aufgegessenen": "Aufgegessene",
    "Aufgegesseneren": "Aufgegessenere",
    "Aufgegessensten": "Aufgegessenste",
    "Aufgegleisten": "Aufgegleiste",
    "Aufgegliederten": "Aufgegliederte",
    "Aufgeglommenen": "Aufgeglommene",
    "Aufgeglommeneren": "Aufgeglommenere",
    "Aufgeglommensten": "Aufgeglommenste",
    "Aufgeglühten": "Aufgeglühte",
    "Aufgeglühteren": "Aufgeglühtere",
    "Aufgeglühtesten": "Aufgeglühteste",
    "Aufgegossenen": "Aufgegossene",
    "Aufgegriffenen": "Aufgegriffene",
    "Aufgehakten": "Aufgehakte",
    "Aufgehalsten": "Aufgehalste",
    "Aufgehaltenen": "Aufgehaltene",
    "Aufgehauenen": "Aufgehauene",
    "Aufgeheiterten": "Aufgeheiterte",
    "Aufgeheiterteren": "Aufgeheitertere",
    "Aufgeheitertesten": "Aufgeheiterteste",
    "Aufgehellten": "Aufgehellte",
    "Aufgehellteren": "Aufgehelltere",
    "Aufgehelltesten": "Aufgehellteste",
    "Aufgehenden": "Aufgehende",
    "Aufgehens": "Aufgehen",
    "Aufgehetzten": "Aufgehetzte",
    "Aufgehetzteren": "Aufgehetztere",
    "Aufgehetztesten": "Aufgehetzteste",
    "Aufgehobenen": "Aufgehobene",
    "Aufgeholten": "Aufgeholte",
    "Aufgeholteren": "Aufgeholtere",
    "Aufgeholtesten": "Aufgeholteste",
    "Aufgehorchten": "Aufgehorchte",
    "Aufgehorchteren": "Aufgehorchtere",
    "Aufgehorchtesten": "Aufgehorchteste",
    "Aufgehängten": "Aufgehängte",
    "Aufgehärteten": "Aufgehärtete",
    "Aufgehörten": "Aufgehörte",
    "Aufgeilenden": "Aufgeilende",
    "Aufgeilenderen": "Aufgeilendere",
    "Aufgeilendsten": "Aufgeilendste",
    "Aufgeilens": "Aufgeilen",
    "Aufgejagten": "Aufgejagte",
    "Aufgejauchzten": "Aufgejauchzte",
    "Aufgejauchzteren": "Aufgejauchztere",
    "Aufgejauchztesten": "Aufgejauchzteste",
    "Aufgekauften": "Aufgekaufte",
    "Aufgekeimten": "Aufgekeimte",
    "Aufgekeimteren": "Aufgekeimtere",
    "Aufgekeimtesten": "Aufgekeimteste",
    "Aufgeklappten": "Aufgeklappte",
    "Aufgeklarten": "Aufgeklarte",
    "Aufgeklarteren": "Aufgeklartere",
    "Aufgeklartesten": "Aufgeklarteste",
    "Aufgeklaubten": "Aufgeklaubte",
    "Aufgeklaubteren": "Aufgeklaubtere",
    "Aufgeklaubtesten": "Aufgeklaubteste",
    "Aufgeklebten": "Aufgeklebte",
    "Aufgeklingelten": "Aufgeklingelte",
    "Aufgeklinkten": "Aufgeklinkte",
    "Aufgeklärte": "aufgeklärt",
    "Aufgeklärten": "Aufgeklärte",
    "Aufgeklärtere": "aufgeklärt",
    "Aufgeklärteren": "Aufgeklärtere",
    "Aufgeklärteste": "aufgeklärt",
    "Aufgeklärtesten": "Aufgeklärteste",
    "Aufgeknoteten": "Aufgeknotete",
    "Aufgeknöpften": "Aufgeknöpfte",
    "Aufgeknüpften": "Aufgeknüpfte",
    "Aufgekochten": "Aufgekochte",
    "Aufgekochteren": "Aufgekochtere",
    "Aufgekochtesten": "Aufgekochteste",
    "Aufgekommenen": "Aufgekommene",
    "Aufgekratzten": "Aufgekratzte",
    "Aufgekratzteren": "Aufgekratztere",
    "Aufgekratztesten": "Aufgekratzteste",
    "Aufgekrempelten": "Aufgekrempelte",
    "Aufgekrempelteren": "Aufgekrempeltere",
    "Aufgekreuzten": "Aufgekreuzte",
    "Aufgekriegten": "Aufgekriegte",
    "Aufgekämmten": "Aufgekämmte",
    "Aufgekündigten": "Aufgekündigte",
    "Aufgelachten": "Aufgelachte",
    "Aufgeladenen": "Aufgeladene",
    "Aufgeladeneren": "Aufgeladenere",
    "Aufgeladensten": "Aufgeladenste",
    "Aufgelassenen": "Aufgelassene",
    "Aufgelasteten": "Aufgelastete",
    "Aufgelauerten": "Aufgelauerte",
    "Aufgelaufenen": "Aufgelaufene",
    "Aufgelebten": "Aufgelebte",
    "Aufgelegenen": "Aufgelegene",
    "Aufgelegten": "Aufgelegte",
    "Aufgelehnten": "Aufgelehnte",
    "Aufgelehnteren": "Aufgelehntere",
    "Aufgelehntesten": "Aufgelehnteste",
    "Aufgeleimten": "Aufgeleimte",
    "Aufgelesenen": "Aufgelesene",
    "Aufgeleuchteten": "Aufgeleuchtete",
    "Aufgelichteten": "Aufgelichtete",
    "Aufgelieferten": "Aufgelieferte",
    "Aufgelisteten": "Aufgelistete",
    "Aufgelockerten": "Aufgelockerte",
    "Aufgelockerteren": "Aufgelockertere",
    "Aufgelockertesten": "Aufgelockerteste",
    "Aufgeloderten": "Aufgeloderte",
    "Aufgeloderteren": "Aufgelodertere",
    "Aufgelodertesten": "Aufgeloderteste",
    "Aufgelösten": "Aufgelöste",
    "Aufgelösteren": "Aufgelöstere",
    "Aufgelöstesten": "Aufgelösteste",
    "Aufgemachten": "Aufgemachte",
    "Aufgemachteren": "Aufgemachtere",
    "Aufgemachtesten": "Aufgemachteste",
    "Aufgemeißelten": "Aufgemeißelte",
    "Aufgemerkten": "Aufgemerkte",
    "Aufgemotzten": "Aufgemotzte",
    "Aufgemotzteren": "Aufgemotztere",
    "Aufgemotztesten": "Aufgemotzteste",
    "Aufgemunterten": "Aufgemunterte",
    "Aufgemunterteren": "Aufgemuntertere",
    "Aufgemuntertesten": "Aufgemunterteste",
    "Aufgemöbelten": "Aufgemöbelte",
    "Aufgemöbelteren": "Aufgemöbeltere",
    "Aufgemöbeltesten": "Aufgemöbelteste",
    "Aufgenagelten": "Aufgenagelte",
    "Aufgenommenen": "Aufgenommene",
    "Aufgenähten": "Aufgenähte",
    "Aufgeopferten": "Aufgeopferte",
    "Aufgeopferteren": "Aufgeopfertere",
    "Aufgeopfertesten": "Aufgeopferteste",
    "Aufgepaßten": "Aufgepaßte",
    "Aufgepflanzten": "Aufgepflanzte",
    "Aufgepfropften": "Aufgepfropfte",
    "Aufgepfropfteren": "Aufgepfropftere",
    "Aufgepfropftesten": "Aufgepfropfteste",
    "Aufgeplatzten": "Aufgeplatzte",
    "Aufgeplatzteren": "Aufgeplatztere",
    "Aufgeplatztesten": "Aufgeplatzteste",
    "Aufgeplusterten": "Aufgeplusterte",
    "Aufgeplusterteren": "Aufgeplustertere",
    "Aufgepolsterten": "Aufgepolsterte",
    "Aufgepolsterteren": "Aufgepolstertere",
    "Aufgepoppten": "Aufgepoppte",
    "Aufgeprallten": "Aufgeprallte",
    "Aufgeprägten": "Aufgeprägte",
    "Aufgepumpten": "Aufgepumpte",
    "Aufgepumpteren": "Aufgepumptere",
    "Aufgepumptesten": "Aufgepumpteste",
    "Aufgeputschten": "Aufgeputschte",
    "Aufgeputschteren": "Aufgeputschtere",
    "Aufgeputschtesten": "Aufgeputschteste",
    "Aufgeputzten": "Aufgeputzte",
    "Aufgepäppelten": "Aufgepäppelte",
    "Aufgepäppelteren": "Aufgepäppeltere",
    "Aufgepäppeltesten": "Aufgepäppelteste",
    "Aufgequellten": "Aufgequellte",
    "Aufgequellteren": "Aufgequelltere",
    "Aufgequelltesten": "Aufgequellteste",
    "Aufgequollenen": "Aufgequollene",
    "Aufgequolleneren": "Aufgequollenere",
    "Aufgequollensten": "Aufgequollenste",
    "Aufgerafften": "Aufgeraffte",
    "Aufgeragten": "Aufgeragte",
    "Aufgerappelten": "Aufgerappelte",
    "Aufgerappelteren": "Aufgerappeltere",
    "Aufgerappeltesten": "Aufgerappelteste",
    "Aufgerauchten": "Aufgerauchte",
    "Aufgerauhten": "Aufgerauhte",
    "Aufgerauhteren": "Aufgerauhtere",
    "Aufgerauhtesten": "Aufgerauhteste",
    "Aufgerauten": "Aufgeraute",
    "Aufgerauteren": "Aufgerautere",
    "Aufgerautesten": "Aufgerauteste",
    "Aufgerechneten": "Aufgerechnete",
    "Aufgeregten": "Aufgeregte",
    "Aufgeregteren": "Aufgeregtere",
    "Aufgeregtesten": "Aufgeregteste",
    "Aufgereihten": "Aufgereihte",
    "Aufgereizten": "Aufgereizte",
    "Aufgereizteren": "Aufgereiztere",
    "Aufgereiztesten": "Aufgereizteste",
    "Aufgeribbelten": "Aufgeribbelte",
    "Aufgerichteten": "Aufgerichtete",
    "Aufgeriebenen": "Aufgeriebene",
    "Aufgeriebeneren": "Aufgeriebenere",
    "Aufgeriebensten": "Aufgeriebenste",
    "Aufgerissenen": "Aufgerissene",
    "Aufgerittenen": "Aufgerittene",
    "Aufgerollten": "Aufgerollte",
    "Aufgerollteren": "Aufgerolltere",
    "Aufgerolltesten": "Aufgerollteste",
    "Aufgerufenen": "Aufgerufene",
    "Aufgerundeten": "Aufgerundete",
    "Aufgeräumten": "Aufgeräumte",
    "Aufgeräumteren": "Aufgeräumtere",
    "Aufgeräumtesten": "Aufgeräumteste",
    "Aufgerührten": "Aufgerührte",
    "Aufgerührteren": "Aufgerührtere",
    "Aufgerührtesten": "Aufgerührteste",
    "Aufgerüsteten": "Aufgerüstete",
    "Aufgerüttelten": "Aufgerüttelte",
    "Aufgesagten": "Aufgesagte",
    "Aufgesammelten": "Aufgesammelte",
    "Aufgesange": "Aufgesang",
    "Aufgesangs": "Aufgesang",
    "Aufgesaugten": "Aufgesaugte",
    "Aufgesaugteren": "Aufgesaugtere",
    "Aufgesaugtesten": "Aufgesaugteste",
    "Aufgeschaukelten": "Aufgeschaukelte",
    "Aufgeschaukelteren": "Aufgeschaukeltere",
    "Aufgeschauten": "Aufgeschaute",
    "Aufgescheuchten": "Aufgescheuchte",
    "Aufgescheuchteren": "Aufgescheuchtere",
    "Aufgescheuerten": "Aufgescheuerte",
    "Aufgescheuerteren": "Aufgescheuertere",
    "Aufgeschichteten": "Aufgeschichtete",
    "Aufgeschienenen": "Aufgeschienene",
    "Aufgeschlagenen": "Aufgeschlagene",
    "Aufgeschlitzten": "Aufgeschlitzte",
    "Aufgeschlitzteren": "Aufgeschlitztere",
    "Aufgeschlossenen": "Aufgeschlossene",
    "Aufgeschluchzten": "Aufgeschluchzte",
    "Aufgeschlämmten": "Aufgeschlämmte",
    "Aufgeschlüsselten": "Aufgeschlüsselte",
    "Aufgeschlüsselteren": "Aufgeschlüsseltere",
    "Aufgeschmissenen": "Aufgeschmissene",
    "Aufgeschmisseneren": "Aufgeschmissenere",
    "Aufgeschnallten": "Aufgeschnallte",
    "Aufgeschnappten": "Aufgeschnappte",
    "Aufgeschnellten": "Aufgeschnellte",
    "Aufgeschnittenen": "Aufgeschnittene",
    "Aufgeschnürten": "Aufgeschnürte",
    "Aufgeschobenen": "Aufgeschobene",
    "Aufgeschobeneren": "Aufgeschobenere",
    "Aufgeschobensten": "Aufgeschobenste",
    "Aufgeschossenen": "Aufgeschossene",
    "Aufgeschraubten": "Aufgeschraubte",
    "Aufgeschreckten": "Aufgeschreckte",
    "Aufgeschreckteren": "Aufgeschrecktere",
    "Aufgeschriebenen": "Aufgeschriebene",
    "Aufgeschriebeneren": "Aufgeschriebenere",
    "Aufgeschrienen": "Aufgeschriene",
    "Aufgeschrieneren": "Aufgeschrienere",
    "Aufgeschriensten": "Aufgeschrienste",
    "Aufgeschrockenen": "Aufgeschrockene",
    "Aufgeschrockeneren": "Aufgeschrockenere",
    "Aufgeschrumpften": "Aufgeschrumpfte",
    "Aufgeschundenen": "Aufgeschundene",
    "Aufgeschwatzten": "Aufgeschwatzte",
    "Aufgeschwemmten": "Aufgeschwemmte",
    "Aufgeschwungenen": "Aufgeschwungene",
    "Aufgeschürften": "Aufgeschürfte",
    "Aufgeschürfteren": "Aufgeschürftere",
    "Aufgeschürftesten": "Aufgeschürfteste",
    "Aufgeschüttelten": "Aufgeschüttelte",
    "Aufgeschüttelteren": "Aufgeschütteltere",
    "Aufgeschütteten": "Aufgeschüttete",
    "Aufgesehenen": "Aufgesehene",
    "Aufgesessenen": "Aufgesessene",
    "Aufgesetzten": "Aufgesetzte",
    "Aufgeseufzten": "Aufgeseufzte",
    "Aufgeseufzteren": "Aufgeseufztere",
    "Aufgeseufztesten": "Aufgeseufzteste",
    "Aufgesogenen": "Aufgesogene",
    "Aufgesogeneren": "Aufgesogenere",
    "Aufgesogensten": "Aufgesogenste",
    "Aufgespaltenen": "Aufgespaltene",
    "Aufgespalteneren": "Aufgespaltenere",
    "Aufgespaltensten": "Aufgespaltenste",
    "Aufgesparten": "Aufgesparte",
    "Aufgesparteren": "Aufgespartere",
    "Aufgespartesten": "Aufgesparteste",
    "Aufgespeicherten": "Aufgespeicherte",
    "Aufgesperrten": "Aufgesperrte",
    "Aufgespielten": "Aufgespielte",
    "Aufgespießten": "Aufgespießte",
    "Aufgesponnenen": "Aufgesponnene",
    "Aufgesprengten": "Aufgesprengte",
    "Aufgespritzten": "Aufgespritzte",
    "Aufgesprungenen": "Aufgesprungene",
    "Aufgespulten": "Aufgespulte",
    "Aufgespürten": "Aufgespürte",
    "Aufgestachelten": "Aufgestachelte",
    "Aufgestampften": "Aufgestampfte",
    "Aufgestandenen": "Aufgestandene",
    "Aufgestapelten": "Aufgestapelte",
    "Aufgestauten": "Aufgestaute",
    "Aufgestauteren": "Aufgestautere",
    "Aufgestautesten": "Aufgestauteste",
    "Aufgesteckten": "Aufgesteckte",
    "Aufgestellten": "Aufgestellte",
    "Aufgestemmten": "Aufgestemmte",
    "Aufgestiegenen": "Aufgestiegene",
    "Aufgestielten": "Aufgestielte",
    "Aufgestifteten": "Aufgestiftete",
    "Aufgestochenen": "Aufgestochene",
    "Aufgestocheneren": "Aufgestochenere",
    "Aufgestochensten": "Aufgestochenste",
    "Aufgestockten": "Aufgestockte",
    "Aufgestoßenen": "Aufgestoßene",
    "Aufgestrebten": "Aufgestrebte",
    "Aufgestrebteren": "Aufgestrebtere",
    "Aufgestrebtesten": "Aufgestrebteste",
    "Aufgestrichenen": "Aufgestrichene",
    "Aufgestöberten": "Aufgestöberte",
    "Aufgestülpten": "Aufgestülpte",
    "Aufgestützten": "Aufgestützte",
    "Aufgesuchten": "Aufgesuchte",
    "Aufgesänge": "Aufgesang",
    "Aufgesängen": "Aufgesang",
    "Aufgetakelten": "Aufgetakelte",
    "Aufgetakelteren": "Aufgetakeltere",
    "Aufgetakeltesten": "Aufgetakelteste",
    "Aufgetankten": "Aufgetankte",
    "Aufgetauchten": "Aufgetauchte",
    "Aufgetauten": "Aufgetaute",
    "Aufgeteilten": "Aufgeteilte",
    "Aufgetischten": "Aufgetischte",
    "Aufgetragenen": "Aufgetragene",
    "Aufgetrageneren": "Aufgetragenere",
    "Aufgetragensten": "Aufgetragenste",
    "Aufgetrennten": "Aufgetrennte",
    "Aufgetretenen": "Aufgetretene",
    "Aufgetriebenen": "Aufgetriebene",
    "Aufgetroffenen": "Aufgetroffene",
    "Aufgetrumpften": "Aufgetrumpfte",
    "Aufgetürmten": "Aufgetürmte",
    "Aufgewachsenen": "Aufgewachsene",
    "Aufgewachsten": "Aufgewachste",
    "Aufgewachten": "Aufgewachte",
    "Aufgewallten": "Aufgewallte",
    "Aufgewallteren": "Aufgewalltere",
    "Aufgewalltesten": "Aufgewallteste",
    "Aufgewalzten": "Aufgewalzte",
    "Aufgewarteten": "Aufgewartete",
    "Aufgewaschenen": "Aufgewaschene",
    "Aufgeweckten": "Aufgeweckte",
    "Aufgeweckteren": "Aufgewecktere",
    "Aufgewecktesten": "Aufgeweckteste",
    "Aufgeweichten": "Aufgeweichte",
    "Aufgeweichteren": "Aufgeweichtere",
    "Aufgeweichtesten": "Aufgeweichteste",
    "Aufgewendeten": "Aufgewendete",
    "Aufgewerteten": "Aufgewertete",
    "Aufgewichenen": "Aufgewichene",
    "Aufgewicheneren": "Aufgewichenere",
    "Aufgewichensten": "Aufgewichenste",
    "Aufgewiegelten": "Aufgewiegelte",
    "Aufgewiegelteren": "Aufgewiegeltere",
    "Aufgewiegeltesten": "Aufgewiegelteste",
    "Aufgewiesenen": "Aufgewiesene",
    "Aufgewirbelten": "Aufgewirbelte",
    "Aufgewirbelteren": "Aufgewirbeltere",
    "Aufgewirbeltesten": "Aufgewirbelteste",
    "Aufgewischten": "Aufgewischte",
    "Aufgewogenen": "Aufgewogene",
    "Aufgeworfenen": "Aufgeworfene",
    "Aufgewundenen": "Aufgewundene",
    "Aufgewärmten": "Aufgewärmte",
    "Aufgewärmteren": "Aufgewärmtere",
    "Aufgewärmtesten": "Aufgewärmteste",
    "Aufgewühlten": "Aufgewühlte",
    "Aufgewühlteren": "Aufgewühltere",
    "Aufgewühltesten": "Aufgewühlteste",
    "Aufgezehrten": "Aufgezehrte",
    "Aufgezehrteren": "Aufgezehrtere",
    "Aufgezehrtesten": "Aufgezehrteste",
    "Aufgezeichneten": "Aufgezeichnete",
    "Aufgezeigten": "Aufgezeigte",
    "Aufgezogenen": "Aufgezogene",
    "Aufgezwirbelten": "Aufgezwirbelte",
    "Aufgezwirbelteren": "Aufgezwirbeltere",
    "Aufgezwungenen": "Aufgezwungene",
    "Aufgezählten": "Aufgezählte",
    "Aufgezäumten": "Aufgezäumte",
    "Aufgezäumteren": "Aufgezäumtere",
    "Aufgezäumtesten": "Aufgezäumteste",
    "Aufgießenden": "Aufgießende",
    "Aufgießens": "Aufgießen",
    "Aufgleisenden": "Aufgleisende",
    "Aufgleisens": "Aufgleisen",
    "Aufgliedernden": "Aufgliedernde",
    "Aufgliederns": "Aufgliedern",
    "Aufgliederungen": "Aufgliederung",
    "Aufglimmenden": "Aufglimmende",
    "Aufglimmenderen": "Aufglimmendere",
    "Aufglimmendsten": "Aufglimmendste",
    "Aufglimmens": "Aufglimmen",
    "Aufglühenden": "Aufglühende",
    "Aufglühenderen": "Aufglühendere",
    "Aufglühendsten": "Aufglühendste",
    "Aufglühens": "Aufglühen",
    "Aufgreifenden": "Aufgreifende",
    "Aufgreifens": "Aufgreifen",
    "Aufgänge": "Aufgang",
    "Aufgängen": "Aufgang",
    "Aufhakenden": "Aufhakende",
    "Aufhakens": "Aufhaken",
    "Aufhalsenden": "Aufhalsende",
    "Aufhalsens": "Aufhalsen",
    "Aufhaltenden": "Aufhaltende",
    "Aufhaltenderen": "Aufhaltendere",
    "Aufhaltendsten": "Aufhaltendste",
    "Aufhaltens": "Aufhalten",
    "Aufhauenden": "Aufhauende",
    "Aufhauens": "Aufhauen",
    "Aufhebenden": "Aufhebende",
    "Aufhebens": "Aufheben",
    "Aufhebungen": "Aufhebung",
    "Aufheiternden": "Aufheiternde",
    "Aufheiternderen": "Aufheiterndere",
    "Aufheiterndsten": "Aufheiterndste",
    "Aufheiterns": "Aufheitern",
    "Aufhellenden": "Aufhellende",
    "Aufhellenderen": "Aufhellendere",
    "Aufhellendsten": "Aufhellendste",
    "Aufhellens": "Aufhellen",
    "Aufhellungen": "Aufhellung",
    "Aufhetzenden": "Aufhetzende",
    "Aufhetzenderen": "Aufhetzendere",
    "Aufhetzendsten": "Aufhetzendste",
    "Aufhetzens": "Aufhetzen",
    "Aufholenden": "Aufholende",
    "Aufholenderen": "Aufholendere",
    "Aufholendsten": "Aufholendste",
    "Aufholens": "Aufholen",
    "Aufhorchenden": "Aufhorchende",
    "Aufhorchenderen": "Aufhorchendere",
    "Aufhorchendsten": "Aufhorchendste",
    "Aufhorchens": "Aufhorchen",
    "Aufhängenden": "Aufhängende",
    "Aufhängens": "Aufhängen",
    "Aufhängern": "Aufhänger",
    "Aufhängers": "Aufhänger",
    "Aufhängungen": "Aufhängung",
    "Aufhärtenden": "Aufhärtende",
    "Aufhärtens": "Aufhärten",
    "Aufhörenden": "Aufhörende",
    "Aufhörens": "Aufhören",
    "Aufjagenden": "Aufjagende",
    "Aufjagens": "Aufjagen",
    "Aufjauchzenden": "Aufjauchzende",
    "Aufjauchzenderen": "Aufjauchzendere",
    "Aufjauchzendsten": "Aufjauchzendste",
    "Aufjauchzens": "Aufjauchzen",
    "Aufkaufe": "aufkaufen",
    "Aufkaufenden": "Aufkaufende",
    "Aufkaufens": "Aufkaufen",
    "Aufkaufs": "Aufkauf",
    "Aufkeimenden": "Aufkeimende",
    "Aufkeimenderen": "Aufkeimendere",
    "Aufkeimendsten": "Aufkeimendste",
    "Aufkeimens": "Aufkeimen",
    "Aufklappenden": "Aufklappende",
    "Aufklappens": "Aufklappen",
    "Aufklarenden": "Aufklarende",
    "Aufklarenderen": "Aufklarendere",
    "Aufklarendsten": "Aufklarendste",
    "Aufklarens": "Aufklaren",
    "Aufklaubenden": "Aufklaubende",
    "Aufklaubenderen": "Aufklaubendere",
    "Aufklaubendsten": "Aufklaubendste",
    "Aufklaubens": "Aufklauben",
    "Aufklebenden": "Aufklebende",
    "Aufklebens": "Aufkleben",
    "Aufklebern": "Aufkleber",
    "Aufklebers": "Aufkleber",
    "Aufklingelnden": "Aufklingelnde",
    "Aufklingelns": "Aufklingeln",
    "Aufklinkenden": "Aufklinkende",
    "Aufklinkens": "Aufklinken",
    "Aufklärende": "aufklärend",
    "Aufklärenden": "Aufklärende",
    "Aufklärens": "Aufklären",
    "Aufklärerische": "aufklärerisch",
    "Aufklärerischen": "Aufklärerische",
    "Aufklärern": "Aufklärer",
    "Aufklärers": "Aufklärer",
    "Aufklärungen": "Aufklärung",
    "Aufknotenden": "Aufknotende",
    "Aufknotens": "Aufknoten",
    "Aufknöpfenden": "Aufknöpfende",
    "Aufknöpfens": "Aufknöpfen",
    "Aufknüpfenden": "Aufknüpfende",
    "Aufknüpfens": "Aufknüpfen",
    "Aufkochenden": "Aufkochende",
    "Aufkochenderen": "Aufkochendere",
    "Aufkochendsten": "Aufkochendste",
    "Aufkochens": "Aufkochen",
    "Aufkommenden": "Aufkommende",
    "Aufkommens": "Aufkommen",
    "Aufkratzenden": "Aufkratzende",
    "Aufkratzenderen": "Aufkratzendere",
    "Aufkratzendsten": "Aufkratzendste",
    "Aufkratzens": "Aufkratzen",
    "Aufkrempelnden": "Aufkrempelnde",
    "Aufkrempelnderen": "Aufkrempelndere",
    "Aufkrempelndsten": "Aufkrempelndste",
    "Aufkrempelns": "Aufkrempeln",
    "Aufkreuzenden": "Aufkreuzende",
    "Aufkreuzens": "Aufkreuzen",
    "Aufkriegenden": "Aufkriegende",
    "Aufkriegens": "Aufkriegen",
    "Aufkämmenden": "Aufkämmende",
    "Aufkämmens": "Aufkämmen",
    "Aufkäufe": "Aufkauf",
    "Aufkäufen": "Aufkauf",
    "Aufkäufern": "Aufkäufer",
    "Aufkäufers": "Aufkäufer",
    "Aufkündigenden": "Aufkündigende",
    "Aufkündigens": "Aufkündigen",
    "Auflachenden": "Auflachende",
    "Auflachens": "Auflachen",
    "Aufladenden": "Aufladende",
    "Aufladens": "Aufladen",
    "Auflagen": "aufliegen",
    "Auflagenschwachen": "Auflagenschwache",
    "Auflagenschwächeren": "Auflagenschwächere",
    "Auflagenstarken": "Auflagenstarke",
    "Auflagenstärkeren": "Auflagenstärkere",
    "Auflassenden": "Auflassende",
    "Auflassens": "Auflassen",
    "Auflastenden": "Auflastende",
    "Auflastens": "Auflasten",
    "Auflauernden": "Auflauernde",
    "Auflauerns": "Auflauern",
    "Auflaufe": "auflaufen",
    "Auflaufenden": "Auflaufende",
    "Auflaufens": "Auflaufen",
    "Auflaufs": "Auflauf",
    "Auflebenden": "Auflebende",
    "Auflebens": "Aufleben",
    "Auflegenden": "Auflegende",
    "Auflegens": "Auflegen",
    "Auflegern": "Aufleger",
    "Auflegers": "Aufleger",
    "Auflehnenden": "Auflehnende",
    "Auflehnenderen": "Auflehnendere",
    "Auflehnendsten": "Auflehnendste",
    "Auflehnens": "Auflehnen",
    "Aufleimenden": "Aufleimende",
    "Aufleimens": "Aufleimen",
    "Auflesenden": "Auflesende",
    "Auflesens": "Auflesen",
    "Aufleuchtenden": "Aufleuchtende",
    "Aufleuchtens": "Aufleuchten",
    "Auflichtenden": "Auflichtende",
    "Auflichtens": "Auflichten",
    "Auflieferern": "Auflieferer",
    "Auflieferers": "Auflieferer",
    "Aufliefernden": "Aufliefernde",
    "Auflieferns": "Aufliefern",
    "Aufliegenden": "Aufliegende",
    "Aufliegens": "Aufliegen",
    "Auflistenden": "Auflistende",
    "Auflistens": "Auflisten",
    "Auflockernden": "Auflockernde",
    "Auflockernderen": "Auflockerndere",
    "Auflockerndsten": "Auflockerndste",
    "Auflockerns": "Auflockern",
    "Auflodernden": "Auflodernde",
    "Auflodernderen": "Aufloderndere",
    "Aufloderndsten": "Aufloderndste",
    "Aufloderns": "Auflodern",
    "Aufläufe": "Auflauf",
    "Aufläufen": "Auflauf",
    "Auflösbaren": "Auflösbare",
    "Auflösbareren": "Auflösbarere",
    "Auflösbarsten": "Auflösbarste",
    "Auflösenden": "Auflösende",
    "Auflösenderen": "Auflösendere",
    "Auflösendsten": "Auflösendste",
    "Auflösens": "Auflösen",
    "Auflösungen": "Auflösung",
    "Aufmachenden": "Aufmachende",
    "Aufmachenderen": "Aufmachendere",
    "Aufmachendsten": "Aufmachendste",
    "Aufmachens": "Aufmachen",
    "Aufmachern": "Aufmacher",
    "Aufmachers": "Aufmacher",
    "Aufmachungen": "Aufmachung",
    "Aufmarsche": "Aufmarsch",
    "Aufmarsches": "Aufmarsch",
    "Aufmarschierenden": "Aufmarschierende",
    "Aufmarschierens": "Aufmarschieren",
    "Aufmarschierte": "aufmarschiert",
    "Aufmarschierten": "Aufmarschierte",
    "Aufmarschs": "Aufmarsch",
    "Aufmeißelnden": "Aufmeißelnde",
    "Aufmeißelns": "Aufmeißeln",
    "Aufmerkenden": "Aufmerkende",
    "Aufmerkens": "Aufmerken",
    "Aufmerksamen": "Aufmerksame",
    "Aufmerksameren": "Aufmerksamere",
    "Aufmerksamkeiten": "Aufmerksamkeit",
    "Aufmerksamste": "aufmerksam",
    "Aufmerksamsten": "Aufmerksamste",
    "Aufmotzenden": "Aufmotzende",
    "Aufmotzenderen": "Aufmotzendere",
    "Aufmotzendsten": "Aufmotzendste",
    "Aufmotzens": "Aufmotzen",
    "Aufmunternden": "Aufmunternde",
    "Aufmunternderen": "Aufmunterndere",
    "Aufmunterndsten": "Aufmunterndste",
    "Aufmunterns": "Aufmuntern",
    "Aufmärsche": "Aufmarsch",
    "Aufmärschen": "Aufmarsch",
    "Aufmöbelnden": "Aufmöbelnde",
    "Aufmöbelnderen": "Aufmöbelndere",
    "Aufmöbelndsten": "Aufmöbelndste",
    "Aufmöbelns": "Aufmöbeln",
    "Aufmüpfigen": "Aufmüpfige",
    "Aufmüpfigeren": "Aufmüpfigere",
    "Aufmüpfigsten": "Aufmüpfigste",
    "Aufnagelnden": "Aufnagelnde",
    "Aufnagelns": "Aufnageln",
    "Aufnahmefähigen": "Aufnahmefähige",
    "Aufnahmefähigeren": "Aufnahmefähigere",
    "Aufnahmefähigsten": "Aufnahmefähigste",
    "Aufnahmen": "aufnehmen",
    "Aufnehmenden": "Aufnehmende",
    "Aufnehmens": "Aufnehmen",
    "Aufnähenden": "Aufnähende",
    "Aufnähens": "Aufnähen",
    "Aufnähern": "Aufnäher",
    "Aufnähers": "Aufnäher",
    "Aufopfernden": "Aufopfernde",
    "Aufopfernderen": "Aufopferndere",
    "Aufopferndsten": "Aufopferndste",
    "Aufopferns": "Aufopfern",
    "Aufpassenden": "Aufpassende",
    "Aufpassens": "Aufpassen",
    "Aufpassern": "Aufpasser",
    "Aufpassers": "Aufpasser",
    "Aufpflanzenden": "Aufpflanzende",
    "Aufpflanzens": "Aufpflanzen",
    "Aufpfropfenden": "Aufpfropfende",
    "Aufpfropfenderen": "Aufpfropfendere",
    "Aufpfropfendsten": "Aufpfropfendste",
    "Aufpfropfens": "Aufpfropfen",
    "Aufplatzenden": "Aufplatzende",
    "Aufplatzenderen": "Aufplatzendere",
    "Aufplatzendsten": "Aufplatzendste",
    "Aufplatzens": "Aufplatzen",
    "Aufplusternden": "Aufplusternde",
    "Aufplusternderen": "Aufplusterndere",
    "Aufplusterndsten": "Aufplusterndste",
    "Aufplusterns": "Aufplustern",
    "Aufpolierenden": "Aufpolierende",
    "Aufpolierenderen": "Aufpolierendere",
    "Aufpolierendsten": "Aufpolierendste",
    "Aufpolierens": "Aufpolieren",
    "Aufpolierte": "aufpoliert",
    "Aufpolierten": "Aufpolierte",
    "Aufpolierteren": "Aufpoliertere",
    "Aufpoliertesten": "Aufpolierteste",
    "Aufpolsternden": "Aufpolsternde",
    "Aufpolsternderen": "Aufpolsterndere",
    "Aufpolsterndsten": "Aufpolsterndste",
    "Aufpolsterns": "Aufpolstern",
    "Aufpoppenden": "Aufpoppende",
    "Aufpoppens": "Aufpoppen",
    "Aufpralle": "aufprallen",
    "Aufprallen": "Aufprall",
    "Aufprallenden": "Aufprallende",
    "Aufprallens": "Aufprallen",
    "Aufpralles": "Aufprall",
    "Aufpralls": "Aufprall",
    "Aufpreise": "Aufpreis",
    "Aufpreisen": "Aufpreis",
    "Aufpreises": "Aufpreis",
    "Aufprobierenden": "Aufprobierende",
    "Aufprobierens": "Aufprobieren",
    "Aufprobierte": "aufprobiert",
    "Aufprobierten": "Aufprobierte",
    "Aufprägenden": "Aufprägende",
    "Aufprägens": "Aufprägen",
    "Aufpumpenden": "Aufpumpende",
    "Aufpumpenderen": "Aufpumpendere",
    "Aufpumpendsten": "Aufpumpendste",
    "Aufpumpens": "Aufpumpen",
    "Aufputschenden": "Aufputschende",
    "Aufputschenderen": "Aufputschendere",
    "Aufputschendsten": "Aufputschendste",
    "Aufputschens": "Aufputschen",
    "Aufputschmitteln": "Aufputschmittel",
    "Aufputschmittels": "Aufputschmittel",
    "Aufputzenden": "Aufputzende",
    "Aufputzens": "Aufputzen",
    "Aufpäppelnden": "Aufpäppelnde",
    "Aufpäppelnderen": "Aufpäppelndere",
    "Aufpäppelndsten": "Aufpäppelndste",
    "Aufpäppelns": "Aufpäppeln",
    "Aufquellenden": "Aufquellende",
    "Aufquellenderen": "Aufquellendere",
    "Aufquellendsten": "Aufquellendste",
    "Aufquellens": "Aufquellen",
    "Aufraffenden": "Aufraffende",
    "Aufraffens": "Aufraffen",
    "Aufragenden": "Aufragende",
    "Aufragens": "Aufragen",
    "Aufrappelnden": "Aufrappelnde",
    "Aufrappelnderen": "Aufrappelndere",
    "Aufrappelndsten": "Aufrappelndste",
    "Aufrappelns": "Aufrappeln",
    "Aufrauchenden": "Aufrauchende",
    "Aufrauchens": "Aufrauchen",
    "Aufrauenden": "Aufrauende",
    "Aufrauenderen": "Aufrauendere",
    "Aufrauendsten": "Aufrauendste",
    "Aufrauens": "Aufrauen",
    "Aufrauhenden": "Aufrauhende",
    "Aufrauhenderen": "Aufrauhendere",
    "Aufrauhendsten": "Aufrauhendste",
    "Aufrauhens": "Aufrauhen",
    "Aufrechnenden": "Aufrechnende",
    "Aufrechnens": "Aufrechnen",
    "Aufrechterhaltenden": "Aufrechterhaltende",
    "Aufrechterhaltenderen": "Aufrechterhaltendere",
    "Aufrechterhaltenen": "Aufrechterhaltene",
    "Aufrechterhalteneren": "Aufrechterhaltenere",
    "Aufrechterhaltens": "Aufrechterhalten",
    "Aufrechterhaltenste": "aufrechterhalten",
    "Aufrechterhaltungen": "Aufrechterhaltung",
    "Aufregenden": "Aufregende",
    "Aufregenderen": "Aufregendere",
    "Aufregendsten": "Aufregendste",
    "Aufregens": "Aufregen",
    "Aufregungen": "Aufregung",
    "Aufreibenden": "Aufreibende",
    "Aufreibenderen": "Aufreibendere",
    "Aufreibendsten": "Aufreibendste",
    "Aufreibens": "Aufreiben",
    "Aufreihenden": "Aufreihende",
    "Aufreihens": "Aufreihen",
    "Aufreitenden": "Aufreitende",
    "Aufreitens": "Aufreiten",
    "Aufreizenden": "Aufreizende",
    "Aufreizenderen": "Aufreizendere",
    "Aufreizendsten": "Aufreizendste",
    "Aufreizens": "Aufreizen",
    "Aufreißenden": "Aufreißende",
    "Aufreißenderen": "Aufreißendere",
    "Aufreißendsten": "Aufreißendste",
    "Aufreißens": "Aufreißen",
    "Aufreißerische": "aufreißerisch",
    "Aufreißerischen": "Aufreißerische",
    "Aufreißerischeren": "Aufreißerischere",
    "Aufreißerischsten": "Aufreißerischste",
    "Aufribbelnden": "Aufribbelnde",
    "Aufribbelns": "Aufribbeln",
    "Aufrichtenden": "Aufrichtende",
    "Aufrichtens": "Aufrichten",
    "Aufrichtigen": "Aufrichtige",
    "Aufrichtigeren": "Aufrichtigere",
    "Aufrichtigsten": "Aufrichtigste",
    "Aufrollenden": "Aufrollende",
    "Aufrollens": "Aufrollen",
    "Aufrufe": "aufrufen",
    "Aufrufen": "Aufruf",
    "Aufrufenden": "Aufrufende",
    "Aufrufens": "Aufrufen",
    "Aufrufes": "Aufruf",
    "Aufrufs": "Aufruf",
    "Aufrundenden": "Aufrundende",
    "Aufrundens": "Aufrunden",
    "Aufräumenden": "Aufräumende",
    "Aufräumens": "Aufräumen",
    "Aufrührenden": "Aufrührende",
    "Aufrührenderen": "Aufrührendere",
    "Aufrührendsten": "Aufrührendste",
    "Aufrührens": "Aufrühren",
    "Aufrührerische": "aufrührerisch",
    "Aufrührerischen": "Aufrührerische",
    "Aufrührerischeren": "Aufrührerischere",
    "Aufrührerischsten": "Aufrührerischste",
    "Aufrührern": "Aufrührer",
    "Aufrührers": "Aufrührer",
    "Aufrüstenden": "Aufrüstende",
    "Aufrüstens": "Aufrüsten",
    "Aufrüttelnden": "Aufrüttelnde",
    "Aufrüttelns": "Aufrütteln",
    "Aufsagenden": "Aufsagende",
    "Aufsagens": "Aufsagen",
    "Aufsammelnden": "Aufsammelnde",
    "Aufsammelns": "Aufsammeln",
    "Aufsatze": "Aufsatz",
    "Aufsatzes": "Aufsatz",
    "Aufsaugenden": "Aufsaugende",
    "Aufsaugenderen": "Aufsaugendere",
    "Aufsaugendsten": "Aufsaugendste",
    "Aufsaugens": "Aufsaugen",
    "Aufschauenden": "Aufschauende",
    "Aufschauens": "Aufschauen",
    "Aufschaukelnden": "Aufschaukelnde",
    "Aufschaukelnderen": "Aufschaukelndere",
    "Aufschaukelndsten": "Aufschaukelndste",
    "Aufschaukelns": "Aufschaukeln",
    "Aufscheinenden": "Aufscheinende",
    "Aufscheinens": "Aufscheinen",
    "Aufscheuchenden": "Aufscheuchende",
    "Aufscheuchenderen": "Aufscheuchendere",
    "Aufscheuchendsten": "Aufscheuchendste",
    "Aufscheuchens": "Aufscheuchen",
    "Aufscheuernden": "Aufscheuernde",
    "Aufscheuernderen": "Aufscheuerndere",
    "Aufscheuerndsten": "Aufscheuerndste",
    "Aufscheuerns": "Aufscheuern",
    "Aufschichtenden": "Aufschichtende",
    "Aufschichtens": "Aufschichten",
    "Aufschiebenden": "Aufschiebende",
    "Aufschiebenderen": "Aufschiebendere",
    "Aufschiebendsten": "Aufschiebendste",
    "Aufschiebens": "Aufschieben",
    "Aufschießenden": "Aufschießende",
    "Aufschießens": "Aufschießen",
    "Aufschindenden": "Aufschindende",
    "Aufschindens": "Aufschinden",
    "Aufschlage": "aufschlagen",
    "Aufschlagenden": "Aufschlagende",
    "Aufschlagens": "Aufschlagen",
    "Aufschlages": "Aufschlag",
    "Aufschlags": "Aufschlag",
    "Aufschließenden": "Aufschließende",
    "Aufschließens": "Aufschließen",
    "Aufschlitzenden": "Aufschlitzende",
    "Aufschlitzenderen": "Aufschlitzendere",
    "Aufschlitzendsten": "Aufschlitzendste",
    "Aufschlitzens": "Aufschlitzen",
    "Aufschluchzenden": "Aufschluchzende",
    "Aufschluchzens": "Aufschluchzen",
    "Aufschlusse": "Aufschluß",
    "Aufschlusses": "Aufschluß",
    "Aufschlußreichen": "Aufschlußreiche",
    "Aufschlußreicheren": "Aufschlußreichere",
    "Aufschläge": "Aufschlag",
    "Aufschlägen": "Aufschlag",
    "Aufschlämmenden": "Aufschlämmende",
    "Aufschlämmens": "Aufschlämmen",
    "Aufschlüsse": "Aufschluß",
    "Aufschlüsselnden": "Aufschlüsselnde",
    "Aufschlüsselnderen": "Aufschlüsselndere",
    "Aufschlüsselns": "Aufschlüsseln",
    "Aufschlüssen": "Aufschluß",
    "Aufschmeißenden": "Aufschmeißende",
    "Aufschmeißens": "Aufschmeißen",
    "Aufschnallenden": "Aufschnallende",
    "Aufschnallens": "Aufschnallen",
    "Aufschnappenden": "Aufschnappende",
    "Aufschnappens": "Aufschnappen",
    "Aufschneidenden": "Aufschneidende",
    "Aufschneidens": "Aufschneiden",
    "Aufschneidereien": "Aufschneiderei",
    "Aufschneiderische": "aufschneiderisch",
    "Aufschneiderischen": "Aufschneiderische",
    "Aufschneiderischeren": "Aufschneiderischere",
    "Aufschnellenden": "Aufschnellende",
    "Aufschnellens": "Aufschnellen",
    "Aufschnitts": "Aufschnitt",
    "Aufschnürenden": "Aufschnürende",
    "Aufschnürens": "Aufschnüren",
    "Aufschraubenden": "Aufschraubende",
    "Aufschraubens": "Aufschrauben",
    "Aufschreckenden": "Aufschreckende",
    "Aufschreckenderen": "Aufschreckendere",
    "Aufschreckendsten": "Aufschreckendste",
    "Aufschreckens": "Aufschrecken",
    "Aufschreibenden": "Aufschreibende",
    "Aufschreibens": "Aufschreiben",
    "Aufschreie": "aufschreien",
    "Aufschreien": "Aufschrei",
    "Aufschreienden": "Aufschreiende",
    "Aufschreienderen": "Aufschreiendere",
    "Aufschreiendsten": "Aufschreiendste",
    "Aufschreiens": "Aufschreien",
    "Aufschreis": "Aufschrei",
    "Aufschriften": "Aufschrift",
    "Aufschrumpfenden": "Aufschrumpfende",
    "Aufschrumpfens": "Aufschrumpfen",
    "Aufschwatzenden": "Aufschwatzende",
    "Aufschwatzenderen": "Aufschwatzendere",
    "Aufschwatzendsten": "Aufschwatzendste",
    "Aufschwatzens": "Aufschwatzen",
    "Aufschwemmenden": "Aufschwemmende",
    "Aufschwemmens": "Aufschwemmen",
    "Aufschwingenden": "Aufschwingende",
    "Aufschwingens": "Aufschwingen",
    "Aufschwunge": "Aufschwung",
    "Aufschwunges": "Aufschwung",
    "Aufschwungs": "Aufschwung",
    "Aufschwünge": "Aufschwung",
    "Aufschwüngen": "Aufschwung",
    "Aufschürfenden": "Aufschürfende",
    "Aufschürfenderen": "Aufschürfendere",
    "Aufschürfendsten": "Aufschürfendste",
    "Aufschürfens": "Aufschürfen",
    "Aufschüttelnden": "Aufschüttelnde",
    "Aufschüttelnderen": "Aufschüttelndere",
    "Aufschüttelndsten": "Aufschüttelndste",
    "Aufschüttelns": "Aufschütteln",
    "Aufschüttenden": "Aufschüttende",
    "Aufschüttens": "Aufschütten",
    "Aufschüttungen": "Aufschüttung",
    "Aufsehenden": "Aufsehende",
    "Aufsehenerregenden": "Aufsehenerregende",
    "Aufsehenerregenderen": "Aufsehenerregendere",
    "Aufsehens": "Aufsehen",
    "Aufsetzenden": "Aufsetzende",
    "Aufsetzens": "Aufsetzen",
    "Aufsetzern": "Aufsetzer",
    "Aufsetzers": "Aufsetzer",
    "Aufseufzenden": "Aufseufzende",
    "Aufseufzenderen": "Aufseufzendere",
    "Aufseufzendsten": "Aufseufzendste",
    "Aufseufzens": "Aufseufzen",
    "Aufsichten": "Aufsicht",
    "Aufsitzenden": "Aufsitzende",
    "Aufsitzens": "Aufsitzen",
    "Aufspaltenden": "Aufspaltende",
    "Aufspaltenderen": "Aufspaltendere",
    "Aufspaltendsten": "Aufspaltendste",
    "Aufspaltens": "Aufspalten",
    "Aufsparenden": "Aufsparende",
    "Aufsparenderen": "Aufsparendere",
    "Aufsparendsten": "Aufsparendste",
    "Aufsparens": "Aufsparen",
    "Aufspeichernden": "Aufspeichernde",
    "Aufspeicherns": "Aufspeichern",
    "Aufsperrenden": "Aufsperrende",
    "Aufsperrens": "Aufsperren",
    "Aufspielenden": "Aufspielende",
    "Aufspielens": "Aufspielen",
    "Aufspießenden": "Aufspießende",
    "Aufspießens": "Aufspießen",
    "Aufspinnenden": "Aufspinnende",
    "Aufspinnens": "Aufspinnen",
    "Aufsprengenden": "Aufsprengende",
    "Aufsprengens": "Aufsprengen",
    "Aufspringenden": "Aufspringende",
    "Aufspringens": "Aufspringen",
    "Aufspritzenden": "Aufspritzende",
    "Aufspritzens": "Aufspritzen",
    "Aufsprunge": "Aufsprung",
    "Aufsprungs": "Aufsprung",
    "Aufsprünge": "Aufsprung",
    "Aufsprüngen": "Aufsprung",
    "Aufspulenden": "Aufspulende",
    "Aufspulens": "Aufspulen",
    "Aufspürenden": "Aufspürende",
    "Aufspürens": "Aufspüren",
    "Aufstachelnden": "Aufstachelnde",
    "Aufstachelns": "Aufstacheln",
    "Aufstampfenden": "Aufstampfende",
    "Aufstampfens": "Aufstampfen",
    "Aufstande": "Aufstand",
    "Aufstands": "Aufstand",
    "Aufstapelnden": "Aufstapelnde",
    "Aufstapelns": "Aufstapeln",
    "Aufstauenden": "Aufstauende",
    "Aufstauenderen": "Aufstauendere",
    "Aufstauendsten": "Aufstauendste",
    "Aufstauens": "Aufstauen",
    "Aufstechenden": "Aufstechende",
    "Aufstechens": "Aufstechen",
    "Aufsteckbaren": "Aufsteckbare",
    "Aufsteckenden": "Aufsteckende",
    "Aufsteckens": "Aufstecken",
    "Aufstehenden": "Aufstehende",
    "Aufstehens": "Aufstehen",
    "Aufsteigenden": "Aufsteigende",
    "Aufsteigens": "Aufsteigen",
    "Aufsteigern": "Aufsteiger",
    "Aufsteigers": "Aufsteiger",
    "Aufstellenden": "Aufstellende",
    "Aufstellens": "Aufstellen",
    "Aufstellern": "Aufsteller",
    "Aufstellers": "Aufsteller",
    "Aufstellungen": "Aufstellung",
    "Aufstemmenden": "Aufstemmende",
    "Aufstemmens": "Aufstemmen",
    "Aufstielenden": "Aufstielende",
    "Aufstielens": "Aufstielen",
    "Aufstiftenden": "Aufstiftende",
    "Aufstiftens": "Aufstiften",
    "Aufstockenden": "Aufstockende",
    "Aufstockens": "Aufstocken",
    "Aufstoßenden": "Aufstoßende",
    "Aufstoßens": "Aufstoßen",
    "Aufstrebenden": "Aufstrebende",
    "Aufstrebenderen": "Aufstrebendere",
    "Aufstrebendsten": "Aufstrebendste",
    "Aufstrebens": "Aufstreben",
    "Aufstreichenden": "Aufstreichende",
    "Aufstreichens": "Aufstreichen",
    "Aufstriche": "Aufstrich",
    "Aufstrichen": "Aufstrich",
    "Aufstrichs": "Aufstrich",
    "Aufstände": "Aufstand",
    "Aufständen": "Aufstand",
    "Aufständischen": "Aufständische",
    "Aufstöbernden": "Aufstöbernde",
    "Aufstöberns": "Aufstöbern",
    "Aufstülpenden": "Aufstülpende",
    "Aufstülpens": "Aufstülpen",
    "Aufstützenden": "Aufstützende",
    "Aufstützens": "Aufstützen",
    "Aufsuchenden": "Aufsuchende",
    "Aufsuchens": "Aufsuchen",
    "Aufsässigen": "Aufsässige",
    "Aufsässigeren": "Aufsässigere",
    "Aufsässigsten": "Aufsässigste",
    "Aufsätze": "Aufsatz",
    "Aufsätzen": "Aufsatz",
    "Auftakelnden": "Auftakelnde",
    "Auftakelnderen": "Auftakelndere",
    "Auftakelndsten": "Auftakelndste",
    "Auftakelns": "Auftakeln",
    "Auftakte": "Auftakt",
    "Auftakten": "Auftakt",
    "Auftaktes": "Auftakt",
    "Auftakts": "Auftakt",
    "Auftankenden": "Auftankende",
    "Auftankens": "Auftanken",
    "Auftauchenden": "Auftauchende",
    "Auftauchens": "Auftauchen",
    "Auftauenden": "Auftauende",
    "Auftauens": "Auftauen",
    "Aufteilenden": "Aufteilende",
    "Aufteilens": "Aufteilen",
    "Aufteilungen": "Aufteilung",
    "Auftischenden": "Auftischende",
    "Auftischens": "Auftischen",
    "Auftrage": "auftragen",
    "Auftragenden": "Auftragende",
    "Auftragens": "Auftragen",
    "Auftrages": "Auftrag",
    "Auftrags": "Auftrag",
    "Auftreffenden": "Auftreffende",
    "Auftreffens": "Auftreffen",
    "Auftreibenden": "Auftreibende",
    "Auftreibens": "Auftreiben",
    "Auftrennenden": "Auftrennende",
    "Auftrennens": "Auftrennen",
    "Auftretenden": "Auftretende",
    "Auftretens": "Auftreten",
    "Auftritte": "Auftritt",
    "Auftritten": "Auftritt",
    "Auftrittes": "Auftritt",
    "Auftritts": "Auftritt",
    "Auftrumpfenden": "Auftrumpfende",
    "Auftrumpfens": "Auftrumpfen",
    "Aufträge": "Auftrag",
    "Aufträgen": "Auftrag",
    "Auftürmenden": "Auftürmende",
    "Auftürmens": "Auftürmen",
    "Aufwachenden": "Aufwachende",
    "Aufwachens": "Aufwachen",
    "Aufwachsenden": "Aufwachsende",
    "Aufwachsens": "Aufwachsen",
    "Aufwallenden": "Aufwallende",
    "Aufwallenderen": "Aufwallendere",
    "Aufwallendsten": "Aufwallendste",
    "Aufwallens": "Aufwallen",
    "Aufwalzenden": "Aufwalzende",
    "Aufwalzens": "Aufwalzen",
    "Aufwande": "Aufwand",
    "Aufwandes": "Aufwand",
    "Aufwands": "Aufwand",
    "Aufwartenden": "Aufwartende",
    "Aufwartens": "Aufwarten",
    "Aufwartungen": "Aufwartung",
    "Aufwaschenden": "Aufwaschende",
    "Aufwaschens": "Aufwaschen",
    "Aufwaschs": "Aufwasch",
    "Aufwaschwassers": "Aufwaschwasser",
    "Aufweckenden": "Aufweckende",
    "Aufweckens": "Aufwecken",
    "Aufweichenden": "Aufweichende",
    "Aufweichenderen": "Aufweichendere",
    "Aufweichendsten": "Aufweichendste",
    "Aufweichens": "Aufweichen",
    "Aufweisenden": "Aufweisende",
    "Aufweisens": "Aufweisen",
    "Aufwendenden": "Aufwendende",
    "Aufwendens": "Aufwenden",
    "Aufwendigen": "Aufwendige",
    "Aufwendigeren": "Aufwendigere",
    "Aufwendigsten": "Aufwendigste",
    "Aufwendungen": "Aufwendung",
    "Aufwerfenden": "Aufwerfende",
    "Aufwerfens": "Aufwerfen",
    "Aufwertenden": "Aufwertende",
    "Aufwertenderen": "Aufwertendere",
    "Aufwertendsten": "Aufwertendste",
    "Aufwertens": "Aufwerten",
    "Aufwiegeleien": "Aufwiegelei",
    "Aufwiegelnden": "Aufwiegelnde",
    "Aufwiegelnderen": "Aufwiegelndere",
    "Aufwiegelndsten": "Aufwiegelndste",
    "Aufwiegelns": "Aufwiegeln",
    "Aufwiegelungen": "Aufwiegelung",
    "Aufwiegenden": "Aufwiegende",
    "Aufwiegens": "Aufwiegen",
    "Aufwieglerischen": "Aufwieglerische",
    "Aufwieglerischeren": "Aufwieglerischere",
    "Aufwieglern": "Aufwiegler",
    "Aufwieglers": "Aufwiegler",
    "Aufwinde": "aufwinden",
    "Aufwinden": "Aufwind",
    "Aufwindenden": "Aufwindende",
    "Aufwindens": "Aufwinden",
    "Aufwinds": "Aufwind",
    "Aufwirbelnden": "Aufwirbelnde",
    "Aufwirbelnderen": "Aufwirbelndere",
    "Aufwirbelndsten": "Aufwirbelndste",
    "Aufwirbelns": "Aufwirbeln",
    "Aufwischenden": "Aufwischende",
    "Aufwischens": "Aufwischen",
    "Aufwändigen": "Aufwändige",
    "Aufwändigeren": "Aufwändigere",
    "Aufwändigsten": "Aufwändigste",
    "Aufwärmenden": "Aufwärmende",
    "Aufwärmens": "Aufwärmen",
    "Aufwärtern": "Aufwärter",
    "Aufwärters": "Aufwärter",
    "Aufwärtsgegangenen": "Aufwärtsgegangene",
    "Aufwärtsgehenden": "Aufwärtsgehende",
    "Aufwärtsgehens": "Aufwärtsgehen",
    "Aufwärtshakens": "Aufwärtshaken",
    "Aufwühlenden": "Aufwühlende",
    "Aufwühlenderen": "Aufwühlendere",
    "Aufwühlendsten": "Aufwühlendste",
    "Aufwühlens": "Aufwühlen",
    "Aufzehrenden": "Aufzehrende",
    "Aufzehrenderen": "Aufzehrendere",
    "Aufzehrendsten": "Aufzehrendste",
    "Aufzehrens": "Aufzehren",
    "Aufzeichnenden": "Aufzeichnende",
    "Aufzeichnens": "Aufzeichnen",
    "Aufzeichnungen": "Aufzeichnung",
    "Aufzeigenden": "Aufzeigende",
    "Aufzeigens": "Aufzeigen",
    "Aufziehenden": "Aufziehende",
    "Aufziehens": "Aufziehen",
    "Aufzuge": "Aufzug",
    "Aufzuges": "Aufzug",
    "Aufzugs": "Aufzug",
    "Aufzwingenden": "Aufzwingende",
    "Aufzwingens": "Aufzwingen",
    "Aufzwirbelnden": "Aufzwirbelnde",
    "Aufzwirbelnderen": "Aufzwirbelndere",
    "Aufzwirbelndsten": "Aufzwirbelndste",
    "Aufzwirbelns": "Aufzwirbeln",
    "Aufzählenden": "Aufzählende",
    "Aufzählens": "Aufzählen",
    "Aufzählungen": "Aufzählung",
    "Aufzäumenden": "Aufzäumende",
    "Aufzäumenderen": "Aufzäumendere",
    "Aufzäumendsten": "Aufzäumendste",
    "Aufzäumens": "Aufzäumen",
    "Aufzüge": "Aufzug",
    "Aufzügen": "Aufzug",
    "Augapfels": "Augapfel",
    "Augen": "Auge",
    "Augenblickliche": "augenblicklich",
    "Augenblicklichen": "Augenblickliche",
    "Augenbrauen": "Augenbraue",
    "Augenfällige": "augenfällig",
    "Augenfälligen": "Augenfällige",
    "Augenfälligeren": "Augenfälligere",
    "Augenfälligsten": "Augenfälligste",
    "Augenmerke": "Augenmerk",
    "Augenmerken": "Augenmerk",
    "Augenmerkes": "Augenmerk",
    "Augenmerks": "Augenmerk",
    "Augenscheinliche": "augenscheinlich",
    "Augenscheinlichen": "Augenscheinliche",
    "Augenzwinkernden": "Augenzwinkernde",
    "Auges": "Auge",
    "Augmentationen": "Augmentation",
    "Augmente": "Augment",
    "Augmenten": "Augment",
    "Augments": "Augment",
    "Augsburgern": "Augsburger",
    "Augsburgers": "Augsburger",
    "Augsburgs": "Augsburg",
    "Auguste": "August",
    "Augusten": "August",
    "Augusts": "August",
    "Augäpfel": "Augapfel",
    "Augäpfeln": "Augapfel",
    "Auheims": "Auheim",
    "Auktionen": "Auktion",
    "Auktionierenden": "Auktionierende",
    "Auktionierens": "Auktionieren",
    "Auktionierte": "auktioniert",
    "Auktionierten": "Auktionierte",
    "Aupairmädchens": "Aupairmädchen",
    "Auren": "Aura",
    "Aurums": "Aurum",
    "Ausarbeitenden": "Ausarbeitende",
    "Ausarbeitens": "Ausarbeiten",
    "Ausartenden": "Ausartende",
    "Ausartenderen": "Ausartendere",
    "Ausartendsten": "Ausartendste",
    "Ausartens": "Ausarten",
    "Ausatmenden": "Ausatmende",
    "Ausatmens": "Ausatmen",
    "Ausbadenden": "Ausbadende",
    "Ausbadens": "Ausbaden",
    "Ausbaggernden": "Ausbaggernde",
    "Ausbaggerns": "Ausbaggern",
    "Ausbaldowernden": "Ausbaldowernde",
    "Ausbaldowerns": "Ausbaldowern",
    "Ausbaldowerte": "ausbaldowert",
    "Ausbaldowerten": "Ausbaldowerte",
    "Ausbauchenden": "Ausbauchende",
    "Ausbauchenderen": "Ausbauchendere",
    "Ausbauchendsten": "Ausbauchendste",
    "Ausbauchens": "Ausbauchen",
    "Ausbauenden": "Ausbauende",
    "Ausbauens": "Ausbauen",
    "Ausbaufähigen": "Ausbaufähige",
    "Ausbaufähigeren": "Ausbaufähigere",
    "Ausbaufähigsten": "Ausbaufähigste",
    "Ausbaus": "Ausbau",
    "Ausbauten": "ausbauen",
    "Ausbeißenden": "Ausbeißende",
    "Ausbeißens": "Ausbeißen",
    "Ausbessernden": "Ausbessernde",
    "Ausbessernderen": "Ausbesserndere",
    "Ausbesserndsten": "Ausbesserndste",
    "Ausbesserns": "Ausbessern",
    "Ausbesserungen": "Ausbesserung",
    "Ausbetonierenden": "Ausbetonierende",
    "Ausbetonierens": "Ausbetonieren",
    "Ausbetonierte": "ausbetoniert",
    "Ausbetonierten": "Ausbetonierte",
    "Ausbeulenden": "Ausbeulende",
    "Ausbeulens": "Ausbeulen",
    "Ausbeutelnden": "Ausbeutelnde",
    "Ausbeutelns": "Ausbeuteln",
    "Ausbeuten": "Ausbeute",
    "Ausbeutenden": "Ausbeutende",
    "Ausbeutenderen": "Ausbeutendere",
    "Ausbeutendsten": "Ausbeutendste",
    "Ausbeutens": "Ausbeuten",
    "Ausbeutern": "Ausbeuter",
    "Ausbeuters": "Ausbeuter",
    "Ausbeutungen": "Ausbeutung",
    "Ausbezahlenden": "Ausbezahlende",
    "Ausbezahlens": "Ausbezahlen",
    "Ausbezahlte": "ausbezahlt",
    "Ausbezahlten": "Ausbezahlte",
    "Ausbiegenden": "Ausbiegende",
    "Ausbiegenderen": "Ausbiegendere",
    "Ausbiegendsten": "Ausbiegendste",
    "Ausbiegens": "Ausbiegen",
    "Ausbietenden": "Ausbietende",
    "Ausbietens": "Ausbieten",
    "Ausbildenden": "Ausbildende",
    "Ausbildens": "Ausbilden",
    "Ausbilderinnen": "Ausbilderin",
    "Ausbildern": "Ausbilder",
    "Ausbilders": "Ausbilder",
    "Ausbildungen": "Ausbildung",
    "Ausbittenden": "Ausbittende",
    "Ausbittens": "Ausbitten",
    "Ausblasenden": "Ausblasende",
    "Ausblasens": "Ausblasen",
    "Ausbleibenden": "Ausbleibende",
    "Ausbleibens": "Ausbleiben",
    "Ausbleichenden": "Ausbleichende",
    "Ausbleichenderen": "Ausbleichendere",
    "Ausbleichendsten": "Ausbleichendste",
    "Ausbleichens": "Ausbleichen",
    "Ausblendenden": "Ausblendende",
    "Ausblendens": "Ausblenden",
    "Ausblicke": "Ausblick",
    "Ausblicken": "Ausblick",
    "Ausblickes": "Ausblick",
    "Ausblicks": "Ausblick",
    "Ausblutenden": "Ausblutende",
    "Ausblutenderen": "Ausblutendere",
    "Ausblutendsten": "Ausblutendste",
    "Ausblutens": "Ausbluten",
    "Ausbohrenden": "Ausbohrende",
    "Ausbohrenderen": "Ausbohrendere",
    "Ausbohrendsten": "Ausbohrendste",
    "Ausbohrens": "Ausbohren",
    "Ausbombenden": "Ausbombende",
    "Ausbombenderen": "Ausbombendere",
    "Ausbombendsten": "Ausbombendste",
    "Ausbombens": "Ausbomben",
    "Ausbootenden": "Ausbootende",
    "Ausbootenderen": "Ausbootendere",
    "Ausbootendsten": "Ausbootendste",
    "Ausbootens": "Ausbooten",
    "Ausborgenden": "Ausborgende",
    "Ausborgens": "Ausborgen",
    "Ausbratenden": "Ausbratende",
    "Ausbratens": "Ausbraten",
    "Ausbrechenden": "Ausbrechende",
    "Ausbrechens": "Ausbrechen",
    "Ausbrechern": "Ausbrecher",
    "Ausbrechers": "Ausbrecher",
    "Ausbreitenden": "Ausbreitende",
    "Ausbreitenderen": "Ausbreitendere",
    "Ausbreitendsten": "Ausbreitendste",
    "Ausbreitens": "Ausbreiten",
    "Ausbremsenden": "Ausbremsende",
    "Ausbremsens": "Ausbremsen",
    "Ausbrennenden": "Ausbrennende",
    "Ausbrennens": "Ausbrennen",
    "Ausbringenden": "Ausbringende",
    "Ausbringens": "Ausbringen",
    "Ausbruche": "Ausbruch",
    "Ausbruches": "Ausbruch",
    "Ausbruchs": "Ausbruch",
    "Ausbrüche": "Ausbruch",
    "Ausbrüchen": "Ausbruch",
    "Ausbrütenden": "Ausbrütende",
    "Ausbrütens": "Ausbrüten",
    "Ausbuchenden": "Ausbuchende",
    "Ausbuchens": "Ausbuchen",
    "Ausbuchtenden": "Ausbuchtende",
    "Ausbuchtens": "Ausbuchten",
    "Ausbuddelnden": "Ausbuddelnde",
    "Ausbuddelns": "Ausbuddeln",
    "Ausbügelnden": "Ausbügelnde",
    "Ausbügelns": "Ausbügeln",
    "Ausbürgernden": "Ausbürgernde",
    "Ausbürgerns": "Ausbürgern",
    "Ausbürgerungen": "Ausbürgerung",
    "Ausbürstenden": "Ausbürstende",
    "Ausbürstens": "Ausbürsten",
    "Ausbüxenden": "Ausbüxende",
    "Ausbüxens": "Ausbüxen",
    "Auscheckenden": "Auscheckende",
    "Auscheckens": "Auschecken",
    "Ausdauernden": "Ausdauernde",
    "Ausdauernderen": "Ausdauerndere",
    "Ausdauerndsten": "Ausdauerndste",
    "Ausdauerns": "Ausdauern",
    "Ausdehnenden": "Ausdehnende",
    "Ausdehnenderen": "Ausdehnendere",
    "Ausdehnendsten": "Ausdehnendste",
    "Ausdehnens": "Ausdehnen",
    "Ausdehnungen": "Ausdehnung",
    "Ausdenkenden": "Ausdenkende",
    "Ausdenkens": "Ausdenken",
    "Ausdeutenden": "Ausdeutende",
    "Ausdeutens": "Ausdeuten",
    "Ausdeutungen": "Ausdeutung",
    "Ausdienenden": "Ausdienende",
    "Ausdienens": "Ausdienen",
    "Ausdifferenzierenden": "Ausdifferenzierende",
    "Ausdifferenzierenderen": "Ausdifferenzierendere",
    "Ausdifferenzierens": "Ausdifferenzieren",
    "Ausdifferenzierte": "ausdifferenziert",
    "Ausdifferenzierten": "Ausdifferenzierte",
    "Ausdifferenzierteren": "Ausdifferenziertere",
    "Ausdifferenzierungen": "Ausdifferenzierung",
    "Ausdiskutierenden": "Ausdiskutierende",
    "Ausdiskutierens": "Ausdiskutieren",
    "Ausdiskutierte": "ausdiskutiert",
    "Ausdiskutierten": "Ausdiskutierte",
    "Ausdiskutierteren": "Ausdiskutiertere",
    "Ausdiskutierteste": "ausdiskutiert",
    "Ausdrehenden": "Ausdrehende",
    "Ausdrehens": "Ausdrehen",
    "Ausdreschenden": "Ausdreschende",
    "Ausdreschens": "Ausdreschen",
    "Ausdringenden": "Ausdringende",
    "Ausdringens": "Ausdringen",
    "Ausdrucke": "ausdrucken",
    "Ausdrucken": "Ausdruck",
    "Ausdruckenden": "Ausdruckende",
    "Ausdruckens": "Ausdrucken",
    "Ausdruckes": "Ausdruck",
    "Ausdrucks": "Ausdruck",
    "Ausdruckslose": "ausdruckslos",
    "Ausdruckslosen": "Ausdruckslose",
    "Ausdrucksloseren": "Ausdruckslosere",
    "Ausdruckslosesten": "Ausdrucksloseste",
    "Ausdrucksvollen": "Ausdrucksvolle",
    "Ausdrucksvolleren": "Ausdrucksvollere",
    "Ausdrucksvollsten": "Ausdrucksvollste",
    "Ausdrückende": "ausdrückend",
    "Ausdrückenden": "Ausdrückende",
    "Ausdrückens": "Ausdrücken",
    "Ausdrücklichen": "Ausdrückliche",
    "Ausdunstenden": "Ausdunstende",
    "Ausdunstenderen": "Ausdunstendere",
    "Ausdunstendsten": "Ausdunstendste",
    "Ausdunstens": "Ausdunsten",
    "Ausdörrenden": "Ausdörrende",
    "Ausdörrenderen": "Ausdörrendere",
    "Ausdörrendsten": "Ausdörrendste",
    "Ausdörrens": "Ausdörren",
    "Auseinandersetzungen": "Auseinandersetzung",
    "Auserkiesenden": "Auserkiesende",
    "Auserkiesens": "Auserkiesen",
    "Auserkorenen": "Auserkorene",
    "Auserkoreneren": "Auserkorenere",
    "Auserkorensten": "Auserkorenste",
    "Auserlesenen": "Auserlesene",
    "Ausersehenden": "Ausersehende",
    "Ausersehenen": "Ausersehene",
    "Ausersehens": "Ausersehen",
    "Auserwählenden": "Auserwählende",
    "Auserwählens": "Auserwählen",
    "Auserwählte": "auserwählt",
    "Auserwählten": "Auserwählte",
    "Ausessenden": "Ausessende",
    "Ausessens": "Ausessen",
    "Ausfahrenden": "Ausfahrende",
    "Ausfahrens": "Ausfahren",
    "Ausfahrten": "Ausfahrt",
    "Ausfalle": "ausfallen",
    "Ausfallenden": "Ausfallende",
    "Ausfallens": "Ausfallen",
    "Ausfalls": "Ausfall",
    "Ausfasernden": "Ausfasernde",
    "Ausfasernderen": "Ausfaserndere",
    "Ausfaserndsten": "Ausfaserndste",
    "Ausfaserns": "Ausfasern",
    "Ausfechtenden": "Ausfechtende",
    "Ausfechtens": "Ausfechten",
    "Ausfegenden": "Ausfegende",
    "Ausfegenderen": "Ausfegendere",
    "Ausfegendsten": "Ausfegendste",
    "Ausfegens": "Ausfegen",
    "Ausfeilenden": "Ausfeilende",
    "Ausfeilenderen": "Ausfeilendere",
    "Ausfeilendsten": "Ausfeilendste",
    "Ausfeilens": "Ausfeilen",
    "Ausfertigenden": "Ausfertigende",
    "Ausfertigens": "Ausfertigen",
    "Ausfertigungen": "Ausfertigung",
    "Ausfilternden": "Ausfilternde",
    "Ausfilternderen": "Ausfilterndere",
    "Ausfilterndsten": "Ausfilterndste",
    "Ausfilterns": "Ausfiltern",
    "Ausfischenden": "Ausfischende",
    "Ausfischens": "Ausfischen",
    "Ausflaggenden": "Ausflaggende",
    "Ausflaggenderen": "Ausflaggendere",
    "Ausflaggendsten": "Ausflaggendste",
    "Ausflaggens": "Ausflaggen",
    "Ausfliegenden": "Ausfliegende",
    "Ausfliegens": "Ausfliegen",
    "Ausfließenden": "Ausfließende",
    "Ausfließens": "Ausfließen",
    "Ausflippenden": "Ausflippende",
    "Ausflippenderen": "Ausflippendere",
    "Ausflippendsten": "Ausflippendste",
    "Ausflippens": "Ausflippen",
    "Ausflockenden": "Ausflockende",
    "Ausflockens": "Ausflocken",
    "Ausfluge": "Ausflug",
    "Ausfluges": "Ausflug",
    "Ausflugs": "Ausflug",
    "Ausflugschneisen": "Ausflugschneise",
    "Ausflusse": "Ausfluß",
    "Ausflusses": "Ausfluß",
    "Ausflüchte": "Ausflucht",
    "Ausflüchten": "Ausflucht",
    "Ausflüge": "Ausflug",
    "Ausflügen": "Ausflug",
    "Ausflüsse": "Ausfluß",
    "Ausflüssen": "Ausfluß",
    "Ausfolgenden": "Ausfolgende",
    "Ausfolgens": "Ausfolgen",
    "Ausformulierenden": "Ausformulierende",
    "Ausformulierens": "Ausformulieren",
    "Ausformulierte": "ausformuliert",
    "Ausformulierten": "Ausformulierte",
    "Ausformulierteren": "Ausformuliertere",
    "Ausformulierteste": "ausformuliert",
    "Ausforschenden": "Ausforschende",
    "Ausforschens": "Ausforschen",
    "Ausfragenden": "Ausfragende",
    "Ausfragens": "Ausfragen",
    "Ausfransenden": "Ausfransende",
    "Ausfransenderen": "Ausfransendere",
    "Ausfransendsten": "Ausfransendste",
    "Ausfransens": "Ausfransen",
    "Ausfressenden": "Ausfressende",
    "Ausfressens": "Ausfressen",
    "Ausfrierenden": "Ausfrierende",
    "Ausfrierens": "Ausfrieren",
    "Ausfugenden": "Ausfugende",
    "Ausfugenderen": "Ausfugendere",
    "Ausfugendsten": "Ausfugendste",
    "Ausfugens": "Ausfugen",
    "Ausfuhrhafens": "Ausfuhrhafen",
    "Ausfuhrhäfen": "Ausfuhrhafen",
    "Ausfuhrlande": "Ausfuhrland",
    "Ausfuhrlandes": "Ausfuhrland",
    "Ausfuhrlands": "Ausfuhrland",
    "Ausfuhrländer": "Ausfuhrland",
    "Ausfuhrländern": "Ausfuhrland",
    "Ausfädelnden": "Ausfädelnde",
    "Ausfädelns": "Ausfädeln",
    "Ausfälle": "ausfällen",
    "Ausfällen": "Ausfall",
    "Ausfällende": "ausfällend",
    "Ausfällenden": "Ausfällende",
    "Ausfällens": "Ausfällen",
    "Ausfälligen": "Ausfällige",
    "Ausfälligeren": "Ausfälligere",
    "Ausfälligsten": "Ausfälligste",
    "Ausführbare": "ausführbar",
    "Ausführbaren": "Ausführbare",
    "Ausführenden": "Ausführende",
    "Ausführens": "Ausführen",
    "Ausführliche": "ausführlich",
    "Ausführlichen": "Ausführliche",
    "Ausführlicheren": "Ausführlichere",
    "Ausführlichsten": "Ausführlichste",
    "Ausführungen": "Ausführung",
    "Ausfüllenden": "Ausfüllende",
    "Ausfüllens": "Ausfüllen",
    "Ausfütternden": "Ausfütternde",
    "Ausfütterns": "Ausfüttern",
    "Ausgaben": "ausgeben",
    "Ausgange": "Ausgang",
    "Ausganges": "Ausgang",
    "Ausgangs": "Ausgang",
    "Ausgearbeiteten": "Ausgearbeitete",
    "Ausgearbeiteteren": "Ausgearbeitetere",
    "Ausgearteten": "Ausgeartete",
    "Ausgearteteren": "Ausgeartetere",
    "Ausgeartetesten": "Ausgearteteste",
    "Ausgeatmeten": "Ausgeatmete",
    "Ausgebadeten": "Ausgebadete",
    "Ausgebaggerten": "Ausgebaggerte",
    "Ausgebauchten": "Ausgebauchte",
    "Ausgebauchteren": "Ausgebauchtere",
    "Ausgebauchtesten": "Ausgebauchteste",
    "Ausgebauten": "Ausgebaute",
    "Ausgebauteren": "Ausgebautere",
    "Ausgebautesten": "Ausgebauteste",
    "Ausgebenden": "Ausgebende",
    "Ausgebens": "Ausgeben",
    "Ausgebesserten": "Ausgebesserte",
    "Ausgebesserteren": "Ausgebessertere",
    "Ausgebessertesten": "Ausgebesserteste",
    "Ausgebetenen": "Ausgebetene",
    "Ausgebeulten": "Ausgebeulte",
    "Ausgebeutelten": "Ausgebeutelte",
    "Ausgebeuteten": "Ausgebeutete",
    "Ausgebeuteteren": "Ausgebeutetere",
    "Ausgebeutetesten": "Ausgebeuteteste",
    "Ausgebildeten": "Ausgebildete",
    "Ausgebildeteren": "Ausgebildetere",
    "Ausgebildetesten": "Ausgebildeteste",
    "Ausgebissenen": "Ausgebissene",
    "Ausgeblasenen": "Ausgeblasene",
    "Ausgeblendeten": "Ausgeblendete",
    "Ausgeblichenen": "Ausgeblichene",
    "Ausgeblicheneren": "Ausgeblichenere",
    "Ausgeblichensten": "Ausgeblichenste",
    "Ausgebliebenen": "Ausgebliebene",
    "Ausgebluteten": "Ausgeblutete",
    "Ausgebluteteren": "Ausgeblutetere",
    "Ausgeblutetesten": "Ausgebluteteste",
    "Ausgebogenen": "Ausgebogene",
    "Ausgebogeneren": "Ausgebogenere",
    "Ausgebogensten": "Ausgebogenste",
    "Ausgebohrten": "Ausgebohrte",
    "Ausgebohrteren": "Ausgebohrtere",
    "Ausgebohrtesten": "Ausgebohrteste",
    "Ausgebombten": "Ausgebombte",
    "Ausgebombteren": "Ausgebombtere",
    "Ausgebombtesten": "Ausgebombteste",
    "Ausgebooteten": "Ausgebootete",
    "Ausgebooteteren": "Ausgebootetere",
    "Ausgebootetesten": "Ausgebooteteste",
    "Ausgeborgten": "Ausgeborgte",
    "Ausgebotenen": "Ausgebotene",
    "Ausgebrachten": "Ausgebrachte",
    "Ausgebrannten": "Ausgebrannte",
    "Ausgebrannteren": "Ausgebranntere",
    "Ausgebranntesten": "Ausgebrannteste",
    "Ausgebratenen": "Ausgebratene",
    "Ausgebreiteten": "Ausgebreitete",
    "Ausgebreiteteren": "Ausgebreitetere",
    "Ausgebreitetesten": "Ausgebreiteteste",
    "Ausgebremsten": "Ausgebremste",
    "Ausgebrochenen": "Ausgebrochene",
    "Ausgebrocheneren": "Ausgebrochenere",
    "Ausgebrochensten": "Ausgebrochenste",
    "Ausgebrüteten": "Ausgebrütete",
    "Ausgebuchten": "Ausgebuchte",
    "Ausgebuchteten": "Ausgebuchtete",
    "Ausgebuddelten": "Ausgebuddelte",
    "Ausgebufften": "Ausgebuffte",
    "Ausgebuffteren": "Ausgebufftere",
    "Ausgebufftesten": "Ausgebuffteste",
    "Ausgeburten": "Ausgeburt",
    "Ausgebügelten": "Ausgebügelte",
    "Ausgebürgerten": "Ausgebürgerte",
    "Ausgebürsteten": "Ausgebürstete",
    "Ausgebüxten": "Ausgebüxte",
    "Ausgecheckten": "Ausgecheckte",
    "Ausgedachten": "Ausgedachte",
    "Ausgedauerten": "Ausgedauerte",
    "Ausgedauerteren": "Ausgedauertere",
    "Ausgedauertesten": "Ausgedauerteste",
    "Ausgedehnten": "Ausgedehnte",
    "Ausgedehnteren": "Ausgedehntere",
    "Ausgedehntesten": "Ausgedehnteste",
    "Ausgedeuteten": "Ausgedeutete",
    "Ausgedienten": "Ausgediente",
    "Ausgedrehten": "Ausgedrehte",
    "Ausgedroschenen": "Ausgedroschene",
    "Ausgedroscheneren": "Ausgedroschenere",
    "Ausgedroschensten": "Ausgedroschenste",
    "Ausgedruckten": "Ausgedruckte",
    "Ausgedrungenen": "Ausgedrungene",
    "Ausgedrungeneren": "Ausgedrungenere",
    "Ausgedrungensten": "Ausgedrungenste",
    "Ausgedrückte": "ausgedrückt",
    "Ausgedrückten": "Ausgedrückte",
    "Ausgedunsteten": "Ausgedunstete",
    "Ausgedunsteteren": "Ausgedunstetere",
    "Ausgedunstetesten": "Ausgedunsteteste",
    "Ausgedörrten": "Ausgedörrte",
    "Ausgedörrteren": "Ausgedörrtere",
    "Ausgedörrtesten": "Ausgedörrteste",
    "Ausgefahrenen": "Ausgefahrene",
    "Ausgefallenen": "Ausgefallene",
    "Ausgefalleneren": "Ausgefallenere",
    "Ausgefallensten": "Ausgefallenste",
    "Ausgefaserten": "Ausgefaserte",
    "Ausgefaserteren": "Ausgefasertere",
    "Ausgefasertesten": "Ausgefaserteste",
    "Ausgefegten": "Ausgefegte",
    "Ausgefegteren": "Ausgefegtere",
    "Ausgefegtesten": "Ausgefegteste",
    "Ausgefeilten": "Ausgefeilte",
    "Ausgefeilteren": "Ausgefeiltere",
    "Ausgefeiltesten": "Ausgefeilteste",
    "Ausgefertigten": "Ausgefertigte",
    "Ausgefilterten": "Ausgefilterte",
    "Ausgefilterteren": "Ausgefiltertere",
    "Ausgefiltertesten": "Ausgefilterteste",
    "Ausgefischten": "Ausgefischte",
    "Ausgeflaggten": "Ausgeflaggte",
    "Ausgeflaggteren": "Ausgeflaggtere",
    "Ausgeflaggtesten": "Ausgeflaggteste",
    "Ausgeflippten": "Ausgeflippte",
    "Ausgeflippteren": "Ausgeflipptere",
    "Ausgeflipptesten": "Ausgeflippteste",
    "Ausgeflockten": "Ausgeflockte",
    "Ausgeflogenen": "Ausgeflogene",
    "Ausgeflossenen": "Ausgeflossene",
    "Ausgefochtenen": "Ausgefochtene",
    "Ausgefochteneren": "Ausgefochtenere",
    "Ausgefochtensten": "Ausgefochtenste",
    "Ausgefolgten": "Ausgefolgte",
    "Ausgeforschten": "Ausgeforschte",
    "Ausgefragten": "Ausgefragte",
    "Ausgefragteren": "Ausgefragtere",
    "Ausgefragtesten": "Ausgefragteste",
    "Ausgefransten": "Ausgefranste",
    "Ausgefransteren": "Ausgefranstere",
    "Ausgefranstesten": "Ausgefransteste",
    "Ausgefressenen": "Ausgefressene",
    "Ausgefrorenen": "Ausgefrorene",
    "Ausgefugten": "Ausgefugte",
    "Ausgefugteren": "Ausgefugtere",
    "Ausgefugtesten": "Ausgefugteste",
    "Ausgefädelten": "Ausgefädelte",
    "Ausgefällten": "Ausgefällte",
    "Ausgeführten": "Ausgeführte",
    "Ausgefüllten": "Ausgefüllte",
    "Ausgefütterten": "Ausgefütterte",
    "Ausgegangenen": "Ausgegangene",
    "Ausgegebenen": "Ausgegebene",
    "Ausgegeizten": "Ausgegeizte",
    "Ausgegessenen": "Ausgegessene",
    "Ausgeglichenen": "Ausgeglichene",
    "Ausgeglicheneren": "Ausgeglichenere",
    "Ausgeglichensten": "Ausgeglichenste",
    "Ausgegliederten": "Ausgegliederte",
    "Ausgeglitschten": "Ausgeglitschte",
    "Ausgeglittenen": "Ausgeglittene",
    "Ausgeglommenen": "Ausgeglommene",
    "Ausgeglommeneren": "Ausgeglommenere",
    "Ausgeglommensten": "Ausgeglommenste",
    "Ausgeglühten": "Ausgeglühte",
    "Ausgeglühteren": "Ausgeglühtere",
    "Ausgeglühtesten": "Ausgeglühteste",
    "Ausgegossenen": "Ausgegossene",
    "Ausgegrabenen": "Ausgegrabene",
    "Ausgegrenzten": "Ausgegrenzte",
    "Ausgegrenzteren": "Ausgegrenztere",
    "Ausgegrenztesten": "Ausgegrenzteste",
    "Ausgegriffenen": "Ausgegriffene",
    "Ausgehakten": "Ausgehakte",
    "Ausgehaltenen": "Ausgehaltene",
    "Ausgehandelten": "Ausgehandelte",
    "Ausgehangenen": "Ausgehangene",
    "Ausgeharrten": "Ausgeharrte",
    "Ausgehauchten": "Ausgehauchte",
    "Ausgehauenen": "Ausgehauene",
    "Ausgeheilten": "Ausgeheilte",
    "Ausgeheilteren": "Ausgeheiltere",
    "Ausgeheiltesten": "Ausgeheilteste",
    "Ausgehenden": "Ausgehende",
    "Ausgehens": "Ausgehen",
    "Ausgehobenen": "Ausgehobene",
    "Ausgeholfenen": "Ausgeholfene",
    "Ausgeholten": "Ausgeholte",
    "Ausgeholzten": "Ausgeholzte",
    "Ausgehorchten": "Ausgehorchte",
    "Ausgehorchteren": "Ausgehorchtere",
    "Ausgehorchtesten": "Ausgehorchteste",
    "Ausgehungerten": "Ausgehungerte",
    "Ausgehungerteren": "Ausgehungertere",
    "Ausgehungertesten": "Ausgehungerteste",
    "Ausgehusteten": "Ausgehustete",
    "Ausgehverbote": "Ausgehverbot",
    "Ausgehverboten": "Ausgehverbot",
    "Ausgehverbots": "Ausgehverbot",
    "Ausgehändigten": "Ausgehändigte",
    "Ausgehängten": "Ausgehängte",
    "Ausgehängteren": "Ausgehängtere",
    "Ausgehängtesten": "Ausgehängteste",
    "Ausgehärteten": "Ausgehärtete",
    "Ausgehärteteren": "Ausgehärtetere",
    "Ausgehärtetesten": "Ausgehärteteste",
    "Ausgehöhlten": "Ausgehöhlte",
    "Ausgehöhlteren": "Ausgehöhltere",
    "Ausgehöhltesten": "Ausgehöhlteste",
    "Ausgehülsten": "Ausgehülste",
    "Ausgehülsteren": "Ausgehülstere",
    "Ausgehülstesten": "Ausgehülsteste",
    "Ausgeizenden": "Ausgeizende",
    "Ausgeizens": "Ausgeizen",
    "Ausgekannten": "Ausgekannte",
    "Ausgekegelten": "Ausgekegelte",
    "Ausgekehrten": "Ausgekehrte",
    "Ausgekeilten": "Ausgekeilte",
    "Ausgekeilteren": "Ausgekeiltere",
    "Ausgekeiltesten": "Ausgekeilteste",
    "Ausgekeimten": "Ausgekeimte",
    "Ausgekeimteren": "Ausgekeimtere",
    "Ausgekeimtesten": "Ausgekeimteste",
    "Ausgekelterten": "Ausgekelterte",
    "Ausgekelterteren": "Ausgekeltertere",
    "Ausgekeltertesten": "Ausgekelterteste",
    "Ausgekernten": "Ausgekernte",
    "Ausgekernteren": "Ausgekerntere",
    "Ausgekerntesten": "Ausgekernteste",
    "Ausgeklammerten": "Ausgeklammerte",
    "Ausgeklebten": "Ausgeklebte",
    "Ausgekleideten": "Ausgekleidete",
    "Ausgeklinkten": "Ausgeklinkte",
    "Ausgeklopften": "Ausgeklopfte",
    "Ausgeklungenen": "Ausgeklungene",
    "Ausgeklügelten": "Ausgeklügelte",
    "Ausgeklügelteren": "Ausgeklügeltere",
    "Ausgeklügeltesten": "Ausgeklügelteste",
    "Ausgekniffenen": "Ausgekniffene",
    "Ausgekniffeneren": "Ausgekniffenere",
    "Ausgekniffensten": "Ausgekniffenste",
    "Ausgeknipsten": "Ausgeknipste",
    "Ausgeknobelten": "Ausgeknobelte",
    "Ausgeknobelteren": "Ausgeknobeltere",
    "Ausgeknobeltesten": "Ausgeknobelteste",
    "Ausgekochten": "Ausgekochte",
    "Ausgekochteren": "Ausgekochtere",
    "Ausgekochtesten": "Ausgekochteste",
    "Ausgekommenen": "Ausgekommene",
    "Ausgekosteten": "Ausgekostete",
    "Ausgekosteteren": "Ausgekostetere",
    "Ausgekostetesten": "Ausgekosteteste",
    "Ausgekramten": "Ausgekramte",
    "Ausgekratzten": "Ausgekratzte",
    "Ausgekratzteren": "Ausgekratztere",
    "Ausgekratztesten": "Ausgekratzteste",
    "Ausgekrochenen": "Ausgekrochene",
    "Ausgekugelten": "Ausgekugelte",
    "Ausgekundschafteten": "Ausgekundschaftete",
    "Ausgekuppelten": "Ausgekuppelte",
    "Ausgekämmten": "Ausgekämmte",
    "Ausgekämpften": "Ausgekämpfte",
    "Ausgekühlten": "Ausgekühlte",
    "Ausgekühlteren": "Ausgekühltere",
    "Ausgekühltesten": "Ausgekühlteste",
    "Ausgelachten": "Ausgelachte",
    "Ausgeladenen": "Ausgeladene",
    "Ausgelagerten": "Ausgelagerte",
    "Ausgelangten": "Ausgelangte",
    "Ausgelassenen": "Ausgelassene",
    "Ausgelasseneren": "Ausgelassenere",
    "Ausgelassensten": "Ausgelassenste",
    "Ausgelasteten": "Ausgelastete",
    "Ausgelasteteren": "Ausgelastetere",
    "Ausgelastetesten": "Ausgelasteteste",
    "Ausgelatschten": "Ausgelatschte",
    "Ausgelatschteren": "Ausgelatschtere",
    "Ausgelatschtesten": "Ausgelatschteste",
    "Ausgelaufenen": "Ausgelaufene",
    "Ausgelaufeneren": "Ausgelaufenere",
    "Ausgelaufensten": "Ausgelaufenste",
    "Ausgelaugten": "Ausgelaugte",
    "Ausgelaugteren": "Ausgelaugtere",
    "Ausgelaugtesten": "Ausgelaugteste",
    "Ausgelauteten": "Ausgelautete",
    "Ausgelebten": "Ausgelebte",
    "Ausgeleerten": "Ausgeleerte",
    "Ausgelegten": "Ausgelegte",
    "Ausgeleierten": "Ausgeleierte",
    "Ausgeleierteren": "Ausgeleiertere",
    "Ausgeleiertesten": "Ausgeleierteste",
    "Ausgelernten": "Ausgelernte",
    "Ausgelesenen": "Ausgelesene",
    "Ausgeleuchteten": "Ausgeleuchtete",
    "Ausgeleuchteteren": "Ausgeleuchtetere",
    "Ausgelichteten": "Ausgelichtete",
    "Ausgelieferten": "Ausgelieferte",
    "Ausgeliehenen": "Ausgeliehene",
    "Ausgelittenen": "Ausgelittene",
    "Ausgelitteneren": "Ausgelittenere",
    "Ausgelittensten": "Ausgelittenste",
    "Ausgeloschenen": "Ausgeloschene",
    "Ausgelosten": "Ausgeloste",
    "Ausgeloteten": "Ausgelotete",
    "Ausgeläutete": "ausgeläutet",
    "Ausgeläuteten": "Ausgeläutete",
    "Ausgelöffelten": "Ausgelöffelte",
    "Ausgelöschten": "Ausgelöschte",
    "Ausgelöste": "ausgelöst",
    "Ausgelösten": "Ausgelöste",
    "Ausgelüfteten": "Ausgelüftete",
    "Ausgelüfteteren": "Ausgelüftetere",
    "Ausgelüftetesten": "Ausgelüfteteste",
    "Ausgemachten": "Ausgemachte",
    "Ausgemahlenen": "Ausgemahlene",
    "Ausgemahleneren": "Ausgemahlenere",
    "Ausgemahlensten": "Ausgemahlenste",
    "Ausgemalten": "Ausgemalte",
    "Ausgemalteren": "Ausgemaltere",
    "Ausgemaltesten": "Ausgemalteste",
    "Ausgemeißelten": "Ausgemeißelte",
    "Ausgemelkten": "Ausgemelkte",
    "Ausgemerzten": "Ausgemerzte",
    "Ausgemerzteren": "Ausgemerztere",
    "Ausgemerztesten": "Ausgemerzteste",
    "Ausgemessenen": "Ausgemessene",
    "Ausgemisteten": "Ausgemistete",
    "Ausgemolkenen": "Ausgemolkene",
    "Ausgemusterten": "Ausgemusterte",
    "Ausgemündeten": "Ausgemündete",
    "Ausgenommenen": "Ausgenommene",
    "Ausgenommeneren": "Ausgenommenere",
    "Ausgenommensten": "Ausgenommenste",
    "Ausgenutzten": "Ausgenutzte",
    "Ausgenutzteren": "Ausgenutztere",
    "Ausgenutztesten": "Ausgenutzteste",
    "Ausgepackten": "Ausgepackte",
    "Ausgeparkten": "Ausgeparkte",
    "Ausgepeitschten": "Ausgepeitschte",
    "Ausgepeitschteren": "Ausgepeitschtere",
    "Ausgependelten": "Ausgependelte",
    "Ausgependelteren": "Ausgependeltere",
    "Ausgependeltesten": "Ausgependelteste",
    "Ausgepfiffenen": "Ausgepfiffene",
    "Ausgepfiffeneren": "Ausgepfiffenere",
    "Ausgepfiffensten": "Ausgepfiffenste",
    "Ausgepflanzten": "Ausgepflanzte",
    "Ausgeplapperten": "Ausgeplapperte",
    "Ausgeplauderten": "Ausgeplauderte",
    "Ausgeplünderten": "Ausgeplünderte",
    "Ausgeplünderteren": "Ausgeplündertere",
    "Ausgepolsterten": "Ausgepolsterte",
    "Ausgepolsterteren": "Ausgepolstertere",
    "Ausgepowerten": "Ausgepowerte",
    "Ausgepowerteren": "Ausgepowertere",
    "Ausgepowertesten": "Ausgepowerteste",
    "Ausgepreßten": "Ausgepreßte",
    "Ausgepreßteren": "Ausgepreßtere",
    "Ausgepreßtesten": "Ausgepreßteste",
    "Ausgeprägten": "Ausgeprägte",
    "Ausgeprägteren": "Ausgeprägtere",
    "Ausgeprägtesten": "Ausgeprägteste",
    "Ausgepumpten": "Ausgepumpte",
    "Ausgepumpteren": "Ausgepumptere",
    "Ausgepumptesten": "Ausgepumpteste",
    "Ausgepusteten": "Ausgepustete",
    "Ausgeputzten": "Ausgeputzte",
    "Ausgequatschten": "Ausgequatschte",
    "Ausgequatschteren": "Ausgequatschtere",
    "Ausgequetschten": "Ausgequetschte",
    "Ausgequetschteren": "Ausgequetschtere",
    "Ausgerasteten": "Ausgerastete",
    "Ausgerasteteren": "Ausgerastetere",
    "Ausgerastetesten": "Ausgerasteteste",
    "Ausgeraubten": "Ausgeraubte",
    "Ausgerauchten": "Ausgerauchte",
    "Ausgerechneten": "Ausgerechnete",
    "Ausgeredeten": "Ausgeredete",
    "Ausgeregneten": "Ausgeregnete",
    "Ausgereichten": "Ausgereichte",
    "Ausgereiften": "Ausgereifte",
    "Ausgereifteren": "Ausgereiftere",
    "Ausgereiftesten": "Ausgereifteste",
    "Ausgereisten": "Ausgereiste",
    "Ausgereizten": "Ausgereizte",
    "Ausgereizteren": "Ausgereiztere",
    "Ausgereiztesten": "Ausgereizteste",
    "Ausgerenkten": "Ausgerenkte",
    "Ausgerichteten": "Ausgerichtete",
    "Ausgeriebenen": "Ausgeriebene",
    "Ausgerissenen": "Ausgerissene",
    "Ausgerisseneren": "Ausgerissenere",
    "Ausgerissensten": "Ausgerissenste",
    "Ausgerittenen": "Ausgerittene",
    "Ausgerodeten": "Ausgerodete",
    "Ausgerodeteren": "Ausgerodetere",
    "Ausgerodetesten": "Ausgerodeteste",
    "Ausgerollten": "Ausgerollte",
    "Ausgerollteren": "Ausgerolltere",
    "Ausgerolltesten": "Ausgerollteste",
    "Ausgerotteten": "Ausgerottete",
    "Ausgerufenen": "Ausgerufene",
    "Ausgeruhten": "Ausgeruhte",
    "Ausgeruhteren": "Ausgeruhtere",
    "Ausgeruhtesten": "Ausgeruhteste",
    "Ausgerupften": "Ausgerupfte",
    "Ausgerupfteren": "Ausgerupftere",
    "Ausgerupftesten": "Ausgerupfteste",
    "Ausgerutschten": "Ausgerutschte",
    "Ausgeräucherten": "Ausgeräucherte",
    "Ausgeräucherteren": "Ausgeräuchertere",
    "Ausgeräumten": "Ausgeräumte",
    "Ausgerückten": "Ausgerückte",
    "Ausgerüsteten": "Ausgerüstete",
    "Ausgesagten": "Ausgesagte",
    "Ausgesalzenen": "Ausgesalzene",
    "Ausgesalzeneren": "Ausgesalzenere",
    "Ausgesalzensten": "Ausgesalzenste",
    "Ausgesandten": "Ausgesandte",
    "Ausgesaugten": "Ausgesaugte",
    "Ausgesaugteren": "Ausgesaugtere",
    "Ausgesaugtesten": "Ausgesaugteste",
    "Ausgeschabten": "Ausgeschabte",
    "Ausgeschabteren": "Ausgeschabtere",
    "Ausgeschabtesten": "Ausgeschabteste",
    "Ausgeschachtelten": "Ausgeschachtelte",
    "Ausgeschachtelteren": "Ausgeschachteltere",
    "Ausgeschalten": "Ausgeschalte",
    "Ausgeschalteren": "Ausgeschaltere",
    "Ausgeschaltesten": "Ausgeschalteste",
    "Ausgeschalteten": "Ausgeschaltete",
    "Ausgescharrten": "Ausgescharrte",
    "Ausgeschaufelten": "Ausgeschaufelte",
    "Ausgeschauten": "Ausgeschaute",
    "Ausgeschenkten": "Ausgeschenkte",
    "Ausgescherten": "Ausgescherte",
    "Ausgescherteren": "Ausgeschertere",
    "Ausgeschertesten": "Ausgescherteste",
    "Ausgeschiedenen": "Ausgeschiedene",
    "Ausgeschifften": "Ausgeschiffte",
    "Ausgeschilderten": "Ausgeschilderte",
    "Ausgeschimpften": "Ausgeschimpfte",
    "Ausgeschimpfteren": "Ausgeschimpftere",
    "Ausgeschirrten": "Ausgeschirrte",
    "Ausgeschlachteten": "Ausgeschlachtete",
    "Ausgeschlachteteren": "Ausgeschlachtetere",
    "Ausgeschlafenen": "Ausgeschlafene",
    "Ausgeschlafeneren": "Ausgeschlafenere",
    "Ausgeschlafensten": "Ausgeschlafenste",
    "Ausgeschlagenen": "Ausgeschlagene",
    "Ausgeschleimten": "Ausgeschleimte",
    "Ausgeschleimteren": "Ausgeschleimtere",
    "Ausgeschlossenen": "Ausgeschlossene",
    "Ausgeschlämmten": "Ausgeschlämmte",
    "Ausgeschlüpften": "Ausgeschlüpfte",
    "Ausgeschlürften": "Ausgeschlürfte",
    "Ausgeschmierten": "Ausgeschmierte",
    "Ausgeschmolzenen": "Ausgeschmolzene",
    "Ausgeschnappten": "Ausgeschnappte",
    "Ausgeschnaubten": "Ausgeschnaubte",
    "Ausgeschnaubteren": "Ausgeschnaubtere",
    "Ausgeschnauften": "Ausgeschnaufte",
    "Ausgeschnaufteren": "Ausgeschnauftere",
    "Ausgeschneuzten": "Ausgeschneuzte",
    "Ausgeschnittenen": "Ausgeschnittene",
    "Ausgeschnäuzten": "Ausgeschnäuzte",
    "Ausgescholtenen": "Ausgescholtene",
    "Ausgescholteneren": "Ausgescholtenere",
    "Ausgescholtensten": "Ausgescholtenste",
    "Ausgeschorenen": "Ausgeschorene",
    "Ausgeschoreneren": "Ausgeschorenere",
    "Ausgeschorensten": "Ausgeschorenste",
    "Ausgeschossenen": "Ausgeschossene",
    "Ausgeschraubten": "Ausgeschraubte",
    "Ausgeschriebenen": "Ausgeschriebene",
    "Ausgeschrienen": "Ausgeschriene",
    "Ausgeschrieneren": "Ausgeschrienere",
    "Ausgeschriensten": "Ausgeschrienste",
    "Ausgeschrittenen": "Ausgeschrittene",
    "Ausgeschulten": "Ausgeschulte",
    "Ausgeschwefelten": "Ausgeschwefelte",
    "Ausgeschwefelteren": "Ausgeschwefeltere",
    "Ausgeschweiften": "Ausgeschweifte",
    "Ausgeschweifteren": "Ausgeschweiftere",
    "Ausgeschwemmten": "Ausgeschwemmte",
    "Ausgeschwemmteren": "Ausgeschwemmtere",
    "Ausgeschwenkten": "Ausgeschwenkte",
    "Ausgeschwiegenen": "Ausgeschwiegene",
    "Ausgeschwiegeneren": "Ausgeschwiegenere",
    "Ausgeschwitzten": "Ausgeschwitzte",
    "Ausgeschwitzteren": "Ausgeschwitztere",
    "Ausgeschwungenen": "Ausgeschwungene",
    "Ausgeschwärmten": "Ausgeschwärmte",
    "Ausgeschälte": "ausgeschält",
    "Ausgeschälten": "Ausgeschälte",
    "Ausgeschöpften": "Ausgeschöpfte",
    "Ausgeschöpfteren": "Ausgeschöpftere",
    "Ausgeschöpftesten": "Ausgeschöpfteste",
    "Ausgeschüttelten": "Ausgeschüttelte",
    "Ausgeschüttelteren": "Ausgeschütteltere",
    "Ausgeschütteten": "Ausgeschüttete",
    "Ausgesehenen": "Ausgesehene",
    "Ausgesendeten": "Ausgesendete",
    "Ausgesessenen": "Ausgesessene",
    "Ausgesetzten": "Ausgesetzte",
    "Ausgesiebten": "Ausgesiebte",
    "Ausgesiebteren": "Ausgesiebtere",
    "Ausgesiebtesten": "Ausgesiebteste",
    "Ausgesiedelten": "Ausgesiedelte",
    "Ausgesoffenen": "Ausgesoffene",
    "Ausgesoffeneren": "Ausgesoffenere",
    "Ausgesoffensten": "Ausgesoffenste",
    "Ausgesogenen": "Ausgesogene",
    "Ausgesonderten": "Ausgesonderte",
    "Ausgespannten": "Ausgespannte",
    "Ausgesparten": "Ausgesparte",
    "Ausgesperrten": "Ausgesperrte",
    "Ausgespielten": "Ausgespielte",
    "Ausgespienen": "Ausgespiene",
    "Ausgesprengten": "Ausgesprengte",
    "Ausgespritzten": "Ausgespritzte",
    "Ausgesprochenen": "Ausgesprochene",
    "Ausgesprühten": "Ausgesprühte",
    "Ausgespuckten": "Ausgespuckte",
    "Ausgespähten": "Ausgespähte",
    "Ausgespähteren": "Ausgespähtere",
    "Ausgespähtesten": "Ausgespähteste",
    "Ausgespülten": "Ausgespülte",
    "Ausgestaltenden": "Ausgestaltende",
    "Ausgestaltens": "Ausgestalten",
    "Ausgestaltete": "ausgestaltet",
    "Ausgestalteten": "Ausgestaltete",
    "Ausgestalteteren": "Ausgestaltetere",
    "Ausgestaltetesten": "Ausgestalteteste",
    "Ausgestaltungen": "Ausgestaltung",
    "Ausgestandenen": "Ausgestandene",
    "Ausgestanzten": "Ausgestanzte",
    "Ausgestatteten": "Ausgestattete",
    "Ausgestatteteren": "Ausgestattetere",
    "Ausgestattetesten": "Ausgestatteteste",
    "Ausgesteiften": "Ausgesteifte",
    "Ausgesteifteren": "Ausgesteiftere",
    "Ausgesteiftesten": "Ausgesteifteste",
    "Ausgestellten": "Ausgestellte",
    "Ausgesteuerten": "Ausgesteuerte",
    "Ausgestiegenen": "Ausgestiegene",
    "Ausgestochenen": "Ausgestochene",
    "Ausgestopften": "Ausgestopfte",
    "Ausgestopfteren": "Ausgestopftere",
    "Ausgestopftesten": "Ausgestopfteste",
    "Ausgestorbenen": "Ausgestorbene",
    "Ausgestorbeneren": "Ausgestorbenere",
    "Ausgestorbensten": "Ausgestorbenste",
    "Ausgestoßenen": "Ausgestoßene",
    "Ausgestrahlten": "Ausgestrahlte",
    "Ausgestreuten": "Ausgestreute",
    "Ausgestrichenen": "Ausgestrichene",
    "Ausgeströmten": "Ausgeströmte",
    "Ausgestülpten": "Ausgestülpte",
    "Ausgesuchten": "Ausgesuchte",
    "Ausgesuchteren": "Ausgesuchtere",
    "Ausgesuchtesten": "Ausgesuchteste",
    "Ausgesägte": "ausgesägt",
    "Ausgesägten": "Ausgesägte",
    "Ausgesäten": "Ausgesäte",
    "Ausgesöhnten": "Ausgesöhnte",
    "Ausgetauschten": "Ausgetauschte",
    "Ausgeteilten": "Ausgeteilte",
    "Ausgetilgten": "Ausgetilgte",
    "Ausgetobten": "Ausgetobte",
    "Ausgetobteren": "Ausgetobtere",
    "Ausgetobtesten": "Ausgetobteste",
    "Ausgetragenen": "Ausgetragene",
    "Ausgetretenen": "Ausgetretene",
    "Ausgetricksten": "Ausgetrickste",
    "Ausgetricksteren": "Ausgetrickstere",
    "Ausgetrickstesten": "Ausgetricksteste",
    "Ausgetriebenen": "Ausgetriebene",
    "Ausgetrockneten": "Ausgetrocknete",
    "Ausgetrockneteren": "Ausgetrocknetere",
    "Ausgetrunkenen": "Ausgetrunkene",
    "Ausgetrunkeneren": "Ausgetrunkenere",
    "Ausgetrunkensten": "Ausgetrunkenste",
    "Ausgeträumten": "Ausgeträumte",
    "Ausgetupften": "Ausgetupfte",
    "Ausgetüftelten": "Ausgetüftelte",
    "Ausgetüftelteren": "Ausgetüfteltere",
    "Ausgetüfteltesten": "Ausgetüftelteste",
    "Ausgeuferten": "Ausgeuferte",
    "Ausgeuferteren": "Ausgeufertere",
    "Ausgeufertesten": "Ausgeuferteste",
    "Ausgewachsenen": "Ausgewachsene",
    "Ausgewachseneren": "Ausgewachsenere",
    "Ausgewachsensten": "Ausgewachsenste",
    "Ausgewachsten": "Ausgewachste",
    "Ausgewachsteren": "Ausgewachstere",
    "Ausgewachstesten": "Ausgewachsteste",
    "Ausgewalzten": "Ausgewalzte",
    "Ausgewanderten": "Ausgewanderte",
    "Ausgewaschenen": "Ausgewaschene",
    "Ausgewechselten": "Ausgewechselte",
    "Ausgeweichten": "Ausgeweichte",
    "Ausgeweideten": "Ausgeweidete",
    "Ausgeweinten": "Ausgeweinte",
    "Ausgeweiteten": "Ausgeweitete",
    "Ausgeweiteteren": "Ausgeweitetere",
    "Ausgeweitetesten": "Ausgeweiteteste",
    "Ausgewerteten": "Ausgewertete",
    "Ausgewetzten": "Ausgewetzte",
    "Ausgewetzteren": "Ausgewetztere",
    "Ausgewetztesten": "Ausgewetzteste",
    "Ausgewichenen": "Ausgewichene",
    "Ausgewickelten": "Ausgewickelte",
    "Ausgewickelteren": "Ausgewickeltere",
    "Ausgewickeltesten": "Ausgewickelteste",
    "Ausgewiesenen": "Ausgewiesene",
    "Ausgewieseneren": "Ausgewiesenere",
    "Ausgewiesensten": "Ausgewiesenste",
    "Ausgewirkten": "Ausgewirkte",
    "Ausgewischten": "Ausgewischte",
    "Ausgewogenen": "Ausgewogene",
    "Ausgewogeneren": "Ausgewogenere",
    "Ausgewogensten": "Ausgewogenste",
    "Ausgeworfenen": "Ausgeworfene",
    "Ausgewrungenen": "Ausgewrungene",
    "Ausgewrungeneren": "Ausgewrungenere",
    "Ausgewrungensten": "Ausgewrungenste",
    "Ausgewuchteten": "Ausgewuchtete",
    "Ausgewuchteteren": "Ausgewuchtetere",
    "Ausgewuchtetesten": "Ausgewuchteteste",
    "Ausgewundenen": "Ausgewundene",
    "Ausgewählten": "Ausgewählte",
    "Ausgewärmten": "Ausgewärmte",
    "Ausgezahlten": "Ausgezahlte",
    "Ausgezahnten": "Ausgezahnte",
    "Ausgezahnteren": "Ausgezahntere",
    "Ausgezahntesten": "Ausgezahnteste",
    "Ausgezankten": "Ausgezankte",
    "Ausgezankteren": "Ausgezanktere",
    "Ausgezanktesten": "Ausgezankteste",
    "Ausgezeichneten": "Ausgezeichnete",
    "Ausgezeichneteren": "Ausgezeichnetere",
    "Ausgezierten": "Ausgezierte",
    "Ausgezierteren": "Ausgeziertere",
    "Ausgeziertesten": "Ausgezierteste",
    "Ausgezirkelten": "Ausgezirkelte",
    "Ausgezischten": "Ausgezischte",
    "Ausgezogenen": "Ausgezogene",
    "Ausgezogeneren": "Ausgezogenere",
    "Ausgezogensten": "Ausgezogenste",
    "Ausgezupften": "Ausgezupfte",
    "Ausgezählte": "ausgezählt",
    "Ausgezählten": "Ausgezählte",
    "Ausgeübten": "Ausgeübte",
    "Ausgiebigen": "Ausgiebige",
    "Ausgießenden": "Ausgießende",
    "Ausgießens": "Ausgießen",
    "Ausgießungen": "Ausgießung",
    "Ausgleichbaren": "Ausgleichbare",
    "Ausgleichen": "Ausgleich",
    "Ausgleichenden": "Ausgleichende",
    "Ausgleichens": "Ausgleichen",
    "Ausgleichs": "Ausgleich",
    "Ausgleitenden": "Ausgleitende",
    "Ausgleitens": "Ausgleiten",
    "Ausgliedernden": "Ausgliedernde",
    "Ausgliederns": "Ausgliedern",
    "Ausglimmenden": "Ausglimmende",
    "Ausglimmenderen": "Ausglimmendere",
    "Ausglimmendsten": "Ausglimmendste",
    "Ausglimmens": "Ausglimmen",
    "Ausglitschenden": "Ausglitschende",
    "Ausglitschens": "Ausglitschen",
    "Ausglühenden": "Ausglühende",
    "Ausglühenderen": "Ausglühendere",
    "Ausglühendsten": "Ausglühendste",
    "Ausglühens": "Ausglühen",
    "Ausgrabenden": "Ausgrabende",
    "Ausgrabens": "Ausgraben",
    "Ausgrabungen": "Ausgrabung",
    "Ausgreifenden": "Ausgreifende",
    "Ausgreifens": "Ausgreifen",
    "Ausgrenzenden": "Ausgrenzende",
    "Ausgrenzenderen": "Ausgrenzendere",
    "Ausgrenzendsten": "Ausgrenzendste",
    "Ausgrenzens": "Ausgrenzen",
    "Ausgrenzungen": "Ausgrenzung",
    "Ausgänge": "Ausgang",
    "Ausgängen": "Ausgang",
    "Aushakenden": "Aushakende",
    "Aushakens": "Aushaken",
    "Aushaltenden": "Aushaltende",
    "Aushaltens": "Aushalten",
    "Aushandelnden": "Aushandelnde",
    "Aushandelns": "Aushandeln",
    "Aushange": "Aushang",
    "Aushangs": "Aushang",
    "Ausharrenden": "Ausharrende",
    "Ausharrenderen": "Ausharrendere",
    "Ausharrendsten": "Ausharrendste",
    "Ausharrens": "Ausharren",
    "Aushauchenden": "Aushauchende",
    "Aushauchens": "Aushauchen",
    "Aushauenden": "Aushauende",
    "Aushauens": "Aushauen",
    "Aushebenden": "Aushebende",
    "Aushebens": "Ausheben",
    "Aushebungen": "Aushebung",
    "Ausheilenden": "Ausheilende",
    "Ausheilenderen": "Ausheilendere",
    "Ausheilendsten": "Ausheilendste",
    "Ausheilens": "Ausheilen",
    "Aushelfenden": "Aushelfende",
    "Aushelfens": "Aushelfen",
    "Aushilfen": "Aushilfe",
    "Aushilfskräfte": "Aushilfskraft",
    "Aushilfskräften": "Aushilfskraft",
    "Ausholenden": "Ausholende",
    "Ausholens": "Ausholen",
    "Ausholzenden": "Ausholzende",
    "Ausholzens": "Ausholzen",
    "Aushorchenden": "Aushorchende",
    "Aushorchenderen": "Aushorchendere",
    "Aushorchendsten": "Aushorchendste",
    "Aushorchens": "Aushorchen",
    "Aushubs": "Aushub",
    "Aushungernden": "Aushungernde",
    "Aushungernderen": "Aushungerndere",
    "Aushungerndsten": "Aushungerndste",
    "Aushungerns": "Aushungern",
    "Aushustenden": "Aushustende",
    "Aushustens": "Aushusten",
    "Aushändigenden": "Aushändigende",
    "Aushändigens": "Aushändigen",
    "Aushänge": "aushängen",
    "Aushängen": "Aushang",
    "Aushängenden": "Aushängende",
    "Aushängenderen": "Aushängendere",
    "Aushängendsten": "Aushängendste",
    "Aushängens": "Aushängen",
    "Aushärtenden": "Aushärtende",
    "Aushärtenderen": "Aushärtendere",
    "Aushärtendsten": "Aushärtendste",
    "Aushärtens": "Aushärten",
    "Aushäusigen": "Aushäusige",
    "Aushöhlenden": "Aushöhlende",
    "Aushöhlenderen": "Aushöhlendere",
    "Aushöhlendsten": "Aushöhlendste",
    "Aushöhlens": "Aushöhlen",
    "Aushöhlungen": "Aushöhlung",
    "Aushülsenden": "Aushülsende",
    "Aushülsenderen": "Aushülsendere",
    "Aushülsendsten": "Aushülsendste",
    "Aushülsens": "Aushülsen",
    "Auskegelnden": "Auskegelnde",
    "Auskegelns": "Auskegeln",
    "Auskehrenden": "Auskehrende",
    "Auskehrens": "Auskehren",
    "Auskeilenden": "Auskeilende",
    "Auskeilenderen": "Auskeilendere",
    "Auskeilendsten": "Auskeilendste",
    "Auskeilens": "Auskeilen",
    "Auskeimenden": "Auskeimende",
    "Auskeimenderen": "Auskeimendere",
    "Auskeimendsten": "Auskeimendste",
    "Auskeimens": "Auskeimen",
    "Auskelternden": "Auskelternde",
    "Auskelternderen": "Auskelterndere",
    "Auskelterndsten": "Auskelterndste",
    "Auskelterns": "Auskeltern",
    "Auskennenden": "Auskennende",
    "Auskennens": "Auskennen",
    "Auskernenden": "Auskernende",
    "Auskernenderen": "Auskernendere",
    "Auskernendsten": "Auskernendste",
    "Auskernens": "Auskernen",
    "Ausklammernden": "Ausklammernde",
    "Ausklammerns": "Ausklammern",
    "Ausklammerungen": "Ausklammerung",
    "Ausklamüsernden": "Ausklamüsernde",
    "Ausklamüsernderen": "Ausklamüserndere",
    "Ausklamüserndsten": "Ausklamüserndste",
    "Ausklamüserns": "Ausklamüsern",
    "Ausklamüserte": "ausklamüsert",
    "Ausklamüserten": "Ausklamüserte",
    "Ausklamüserteren": "Ausklamüsertere",
    "Ausklamüsertesten": "Ausklamüserteste",
    "Ausklange": "Ausklang",
    "Ausklangs": "Ausklang",
    "Ausklebenden": "Ausklebende",
    "Ausklebens": "Auskleben",
    "Auskleidenden": "Auskleidende",
    "Auskleidens": "Auskleiden",
    "Auskleidungen": "Auskleidung",
    "Ausklingenden": "Ausklingende",
    "Ausklingens": "Ausklingen",
    "Ausklinkenden": "Ausklinkende",
    "Ausklinkens": "Ausklinken",
    "Ausklopfenden": "Ausklopfende",
    "Ausklopfens": "Ausklopfen",
    "Ausklopfern": "Ausklopfer",
    "Ausklopfers": "Ausklopfer",
    "Ausklänge": "ausklingen",
    "Ausklängen": "ausklingen",
    "Ausklügelnden": "Ausklügelnde",
    "Ausklügelnderen": "Ausklügelndere",
    "Ausklügelndsten": "Ausklügelndste",
    "Ausklügelns": "Ausklügeln",
    "Auskneifenden": "Auskneifende",
    "Auskneifenderen": "Auskneifendere",
    "Auskneifendsten": "Auskneifendste",
    "Auskneifens": "Auskneifen",
    "Ausknipsenden": "Ausknipsende",
    "Ausknipsens": "Ausknipsen",
    "Ausknobelnden": "Ausknobelnde",
    "Ausknobelnderen": "Ausknobelndere",
    "Ausknobelndsten": "Ausknobelndste",
    "Ausknobelns": "Ausknobeln",
    "Auskochenden": "Auskochende",
    "Auskochenderen": "Auskochendere",
    "Auskochendsten": "Auskochendste",
    "Auskochens": "Auskochen",
    "Auskommenden": "Auskommende",
    "Auskommens": "Auskommen",
    "Auskostenden": "Auskostende",
    "Auskostenderen": "Auskostendere",
    "Auskostendsten": "Auskostendste",
    "Auskostens": "Auskosten",
    "Auskramenden": "Auskramende",
    "Auskramens": "Auskramen",
    "Auskratzenden": "Auskratzende",
    "Auskratzenderen": "Auskratzendere",
    "Auskratzendsten": "Auskratzendste",
    "Auskratzens": "Auskratzen",
    "Auskratzungen": "Auskratzung",
    "Auskriechenden": "Auskriechende",
    "Auskriechens": "Auskriechen",
    "Auskristallisierenden": "Auskristallisierende",
    "Auskristallisierens": "Auskristallisieren",
    "Auskristallisierte": "auskristallisiert",
    "Auskristallisierten": "Auskristallisierte",
    "Auskugelnden": "Auskugelnde",
    "Auskugelns": "Auskugeln",
    "Auskundschaftenden": "Auskundschaftende",
    "Auskundschaftens": "Auskundschaften",
    "Auskundschaftern": "Auskundschafter",
    "Auskundschafters": "Auskundschafter",
    "Auskuppelnden": "Auskuppelnde",
    "Auskuppelns": "Auskuppeln",
    "Auskurierenden": "Auskurierende",
    "Auskurierens": "Auskurieren",
    "Auskurierte": "auskuriert",
    "Auskurierten": "Auskurierte",
    "Auskämmenden": "Auskämmende",
    "Auskämmens": "Auskämmen",
    "Auskämpfenden": "Auskämpfende",
    "Auskämpfens": "Auskämpfen",
    "Auskühlenden": "Auskühlende",
    "Auskühlenderen": "Auskühlendere",
    "Auskühlendsten": "Auskühlendste",
    "Auskühlens": "Auskühlen",
    "Auskünfte": "Auskunft",
    "Auskünften": "Auskunft",
    "Auslachenden": "Auslachende",
    "Auslachens": "Auslachen",
    "Ausladenden": "Ausladende",
    "Ausladenderen": "Ausladendere",
    "Ausladendsten": "Ausladendste",
    "Ausladens": "Ausladen",
    "Ausladern": "Auslader",
    "Ausladers": "Auslader",
    "Auslagen": "Auslage",
    "Auslagernden": "Auslagernde",
    "Auslagerns": "Auslagern",
    "Auslands": "Ausland",
    "Auslandsdeutsche": "auslandsdeutsch",
    "Auslandsdeutschen": "Auslandsdeutsche",
    "Auslangenden": "Auslangende",
    "Auslangens": "Auslangen",
    "Auslassenden": "Auslassende",
    "Auslassenderen": "Auslassendere",
    "Auslassendsten": "Auslassendste",
    "Auslassens": "Auslassen",
    "Auslassungen": "Auslassung",
    "Auslastenden": "Auslastende",
    "Auslastenderen": "Auslastendere",
    "Auslastendsten": "Auslastendste",
    "Auslastens": "Auslasten",
    "Auslatschenden": "Auslatschende",
    "Auslatschenderen": "Auslatschendere",
    "Auslatschendsten": "Auslatschendste",
    "Auslatschens": "Auslatschen",
    "Auslaufe": "auslaufen",
    "Auslaufenden": "Auslaufende",
    "Auslaufenderen": "Auslaufendere",
    "Auslaufendsten": "Auslaufendste",
    "Auslaufens": "Auslaufen",
    "Auslaufmodelle": "Auslaufmodell",
    "Auslaufmodellen": "Auslaufmodell",
    "Auslaufmodells": "Auslaufmodell",
    "Auslaufs": "Auslauf",
    "Auslaugenden": "Auslaugende",
    "Auslaugenderen": "Auslaugendere",
    "Auslaugendsten": "Auslaugendste",
    "Auslaugens": "Auslaugen",
    "Auslautenden": "Auslautende",
    "Auslautens": "Auslauten",
    "Auslebenden": "Auslebende",
    "Auslebenderen": "Auslebendere",
    "Auslebendsten": "Auslebendste",
    "Auslebens": "Ausleben",
    "Ausleerenden": "Ausleerende",
    "Ausleerens": "Ausleeren",
    "Auslegenden": "Auslegende",
    "Auslegens": "Auslegen",
    "Auslegern": "Ausleger",
    "Auslegers": "Ausleger",
    "Auslegungen": "Auslegung",
    "Ausleidenden": "Ausleidende",
    "Ausleidenderen": "Ausleidendere",
    "Ausleidendsten": "Ausleidendste",
    "Ausleidens": "Ausleiden",
    "Ausleiernden": "Ausleiernde",
    "Ausleiernderen": "Ausleierndere",
    "Ausleierndsten": "Ausleierndste",
    "Ausleierns": "Ausleiern",
    "Ausleihen": "Ausleihe",
    "Ausleihenden": "Ausleihende",
    "Ausleihens": "Ausleihen",
    "Auslernenden": "Auslernende",
    "Auslernens": "Auslernen",
    "Auslesen": "Auslese",
    "Auslesenden": "Auslesende",
    "Auslesens": "Auslesen",
    "Ausleuchtenden": "Ausleuchtende",
    "Ausleuchtenderen": "Ausleuchtendere",
    "Ausleuchtendsten": "Ausleuchtendste",
    "Ausleuchtens": "Ausleuchten",
    "Auslichtenden": "Auslichtende",
    "Auslichtens": "Auslichten",
    "Ausliefernden": "Ausliefernde",
    "Auslieferns": "Ausliefern",
    "Auslobungen": "Auslobung",
    "Auslosenden": "Auslosende",
    "Auslosens": "Auslosen",
    "Auslosungen": "Auslosung",
    "Auslotenden": "Auslotende",
    "Auslotens": "Ausloten",
    "Ausluge": "Auslug",
    "Auslugen": "Auslug",
    "Auslugs": "Auslug",
    "Ausländerfeindlichen": "Ausländerfeindliche",
    "Ausländerfeindlicheren": "Ausländerfeindlichere",
    "Ausländerinnen": "Ausländerin",
    "Ausländern": "Ausländer",
    "Ausländers": "Ausländer",
    "Ausländische": "ausländisch",
    "Ausländischen": "Ausländische",
    "Ausläufe": "Auslauf",
    "Ausläufen": "Auslauf",
    "Ausläufern": "Ausläufer",
    "Ausläufers": "Ausläufer",
    "Ausläutende": "ausläutend",
    "Ausläutenden": "Ausläutende",
    "Ausläutens": "Ausläuten",
    "Auslöffelnden": "Auslöffelnde",
    "Auslöffelns": "Auslöffeln",
    "Auslöschenden": "Auslöschende",
    "Auslöschens": "Auslöschen",
    "Auslöschungen": "Auslöschung",
    "Auslösende": "auslösend",
    "Auslösenden": "Auslösende",
    "Auslösens": "Auslösen",
    "Auslösern": "Auslöser",
    "Auslösers": "Auslöser",
    "Auslösungen": "Auslösung",
    "Auslüftenden": "Auslüftende",
    "Auslüftenderen": "Auslüftendere",
    "Auslüftendsten": "Auslüftendste",
    "Auslüftens": "Auslüften",
    "Ausmachenden": "Ausmachende",
    "Ausmachens": "Ausmachen",
    "Ausmahlenden": "Ausmahlende",
    "Ausmahlenderen": "Ausmahlendere",
    "Ausmahlendsten": "Ausmahlendste",
    "Ausmahlens": "Ausmahlen",
    "Ausmalenden": "Ausmalende",
    "Ausmalenderen": "Ausmalendere",
    "Ausmalendsten": "Ausmalendste",
    "Ausmalens": "Ausmalen",
    "Ausmaße": "Ausmaß",
    "Ausmaßen": "ausmessen",
    "Ausmaßes": "Ausmaß",
    "Ausmeißelnden": "Ausmeißelnde",
    "Ausmeißelns": "Ausmeißeln",
    "Ausmelkenden": "Ausmelkende",
    "Ausmelkens": "Ausmelken",
    "Ausmerzenden": "Ausmerzende",
    "Ausmerzenderen": "Ausmerzendere",
    "Ausmerzendsten": "Ausmerzendste",
    "Ausmerzens": "Ausmerzen",
    "Ausmessenden": "Ausmessende",
    "Ausmessens": "Ausmessen",
    "Ausmistenden": "Ausmistende",
    "Ausmistens": "Ausmisten",
    "Ausmusternden": "Ausmusternde",
    "Ausmusterns": "Ausmustern",
    "Ausmusterungen": "Ausmusterung",
    "Ausmündenden": "Ausmündende",
    "Ausmündens": "Ausmünden",
    "Ausnahmen": "ausnehmen",
    "Ausnahmslosen": "Ausnahmslose",
    "Ausnehmenden": "Ausnehmende",
    "Ausnehmenderen": "Ausnehmendere",
    "Ausnehmendsten": "Ausnehmendste",
    "Ausnehmens": "Ausnehmen",
    "Ausnehmern": "Ausnehmer",
    "Ausnehmers": "Ausnehmer",
    "Ausnutzenden": "Ausnutzende",
    "Ausnutzenderen": "Ausnutzendere",
    "Ausnutzendsten": "Ausnutzendste",
    "Ausnutzens": "Ausnutzen",
    "Auspackenden": "Auspackende",
    "Auspackens": "Auspacken",
    "Ausparkenden": "Ausparkende",
    "Ausparkens": "Ausparken",
    "Auspeitschenden": "Auspeitschende",
    "Auspeitschenderen": "Auspeitschendere",
    "Auspeitschendsten": "Auspeitschendste",
    "Auspeitschens": "Auspeitschen",
    "Auspendelnden": "Auspendelnde",
    "Auspendelnderen": "Auspendelndere",
    "Auspendelndsten": "Auspendelndste",
    "Auspendelns": "Auspendeln",
    "Auspfeifenden": "Auspfeifende",
    "Auspfeifenderen": "Auspfeifendere",
    "Auspfeifendsten": "Auspfeifendste",
    "Auspfeifens": "Auspfeifen",
    "Auspflanzenden": "Auspflanzende",
    "Auspflanzens": "Auspflanzen",
    "Ausplappernden": "Ausplappernde",
    "Ausplapperns": "Ausplappern",
    "Ausplaudernden": "Ausplaudernde",
    "Ausplauderns": "Ausplaudern",
    "Ausplündernden": "Ausplündernde",
    "Ausplündernderen": "Ausplünderndere",
    "Ausplünderndsten": "Ausplünderndste",
    "Ausplünderns": "Ausplündern",
    "Auspolsternden": "Auspolsternde",
    "Auspolsternderen": "Auspolsterndere",
    "Auspolsterndsten": "Auspolsterndste",
    "Auspolsterns": "Auspolstern",
    "Ausposaunenden": "Ausposaunende",
    "Ausposaunens": "Ausposaunen",
    "Ausposaunte": "ausposaunt",
    "Ausposaunten": "Ausposaunte",
    "Auspowernden": "Auspowernde",
    "Auspowernderen": "Auspowerndere",
    "Auspowerndsten": "Auspowerndste",
    "Auspowerns": "Auspowern",
    "Auspressenden": "Auspressende",
    "Auspressenderen": "Auspressendere",
    "Auspressendsten": "Auspressendste",
    "Auspressens": "Auspressen",
    "Ausprobierenden": "Ausprobierende",
    "Ausprobierens": "Ausprobieren",
    "Ausprobierte": "ausprobiert",
    "Ausprobierten": "Ausprobierte",
    "Ausprägenden": "Ausprägende",
    "Ausprägenderen": "Ausprägendere",
    "Ausprägendsten": "Ausprägendste",
    "Ausprägens": "Ausprägen",
    "Ausprägungen": "Ausprägung",
    "Auspuffe": "Auspuff",
    "Auspuffen": "Auspuff",
    "Auspuffes": "Auspuff",
    "Auspuffs": "Auspuff",
    "Auspumpenden": "Auspumpende",
    "Auspumpenderen": "Auspumpendere",
    "Auspumpendsten": "Auspumpendste",
    "Auspumpens": "Auspumpen",
    "Auspustenden": "Auspustende",
    "Auspustens": "Auspusten",
    "Ausputzenden": "Ausputzende",
    "Ausputzens": "Ausputzen",
    "Ausputzern": "Ausputzer",
    "Ausputzers": "Ausputzer",
    "Ausquartierenden": "Ausquartierende",
    "Ausquartierens": "Ausquartieren",
    "Ausquartierte": "ausquartiert",
    "Ausquartierten": "Ausquartierte",
    "Ausquatschenden": "Ausquatschende",
    "Ausquatschenderen": "Ausquatschendere",
    "Ausquatschendsten": "Ausquatschendste",
    "Ausquatschens": "Ausquatschen",
    "Ausquetschenden": "Ausquetschende",
    "Ausquetschenderen": "Ausquetschendere",
    "Ausquetschendsten": "Ausquetschendste",
    "Ausquetschens": "Ausquetschen",
    "Ausradierenden": "Ausradierende",
    "Ausradierens": "Ausradieren",
    "Ausradierte": "ausradiert",
    "Ausradierten": "Ausradierte",
    "Ausrangierenden": "Ausrangierende",
    "Ausrangierens": "Ausrangieren",
    "Ausrangierte": "ausrangiert",
    "Ausrangierten": "Ausrangierte",
    "Ausrasierenden": "Ausrasierende",
    "Ausrasierens": "Ausrasieren",
    "Ausrasierte": "ausrasiert",
    "Ausrasierten": "Ausrasierte",
    "Ausrastenden": "Ausrastende",
    "Ausrastenderen": "Ausrastendere",
    "Ausrastendsten": "Ausrastendste",
    "Ausrastens": "Ausrasten",
    "Ausraubenden": "Ausraubende",
    "Ausraubens": "Ausrauben",
    "Ausrauchenden": "Ausrauchende",
    "Ausrauchens": "Ausrauchen",
    "Ausrechnenden": "Ausrechnende",
    "Ausrechnens": "Ausrechnen",
    "Ausreden": "Ausrede",
    "Ausredenden": "Ausredende",
    "Ausredens": "Ausreden",
    "Ausregnenden": "Ausregnende",
    "Ausregnens": "Ausregnen",
    "Ausreibenden": "Ausreibende",
    "Ausreibens": "Ausreiben",
    "Ausreichenden": "Ausreichende",
    "Ausreichens": "Ausreichen",
    "Ausreifenden": "Ausreifende",
    "Ausreifens": "Ausreifen",
    "Ausreisen": "Ausreise",
    "Ausreisenden": "Ausreisende",
    "Ausreisens": "Ausreisen",
    "Ausreitenden": "Ausreitende",
    "Ausreitens": "Ausreiten",
    "Ausreizenden": "Ausreizende",
    "Ausreizenderen": "Ausreizendere",
    "Ausreizendsten": "Ausreizendste",
    "Ausreizens": "Ausreizen",
    "Ausreißenden": "Ausreißende",
    "Ausreißenderen": "Ausreißendere",
    "Ausreißendsten": "Ausreißendste",
    "Ausreißens": "Ausreißen",
    "Ausrenkenden": "Ausrenkende",
    "Ausrenkens": "Ausrenken",
    "Ausrenkungen": "Ausrenkung",
    "Ausrichtenden": "Ausrichtende",
    "Ausrichtens": "Ausrichten",
    "Ausrichtern": "Ausrichter",
    "Ausrichters": "Ausrichter",
    "Ausritte": "Ausritt",
    "Ausritten": "Ausritt",
    "Ausritts": "Ausritt",
    "Ausrodenden": "Ausrodende",
    "Ausrodenderen": "Ausrodendere",
    "Ausrodendsten": "Ausrodendste",
    "Ausrodens": "Ausroden",
    "Ausrollenden": "Ausrollende",
    "Ausrollenderen": "Ausrollendere",
    "Ausrollendsten": "Ausrollendste",
    "Ausrollens": "Ausrollen",
    "Ausrottenden": "Ausrottende",
    "Ausrottens": "Ausrotten",
    "Ausrottungen": "Ausrottung",
    "Ausrufe": "ausrufen",
    "Ausrufen": "Ausruf",
    "Ausrufenden": "Ausrufende",
    "Ausrufens": "Ausrufen",
    "Ausrufern": "Ausrufer",
    "Ausrufers": "Ausrufer",
    "Ausrufezeichens": "Ausrufezeichen",
    "Ausrufs": "Ausruf",
    "Ausrufungszeichens": "Ausrufungszeichen",
    "Ausruhenden": "Ausruhende",
    "Ausruhenderen": "Ausruhendere",
    "Ausruhendsten": "Ausruhendste",
    "Ausruhens": "Ausruhen",
    "Ausrupfenden": "Ausrupfende",
    "Ausrupfenderen": "Ausrupfendere",
    "Ausrupfendsten": "Ausrupfendste",
    "Ausrupfens": "Ausrupfen",
    "Ausrutschenden": "Ausrutschende",
    "Ausrutschens": "Ausrutschen",
    "Ausrutschern": "Ausrutscher",
    "Ausrutschers": "Ausrutscher",
    "Ausräuchernden": "Ausräuchernde",
    "Ausräuchernderen": "Ausräucherndere",
    "Ausräucherndsten": "Ausräucherndste",
    "Ausräucherns": "Ausräuchern",
    "Ausräumenden": "Ausräumende",
    "Ausräumens": "Ausräumen",
    "Ausrückenden": "Ausrückende",
    "Ausrückens": "Ausrücken",
    "Ausrüstenden": "Ausrüstende",
    "Ausrüstens": "Ausrüsten",
    "Ausrüstungen": "Ausrüstung",
    "Aussaaten": "Aussaat",
    "Aussagen": "Aussage",
    "Aussagenden": "Aussagende",
    "Aussagens": "Aussagen",
    "Aussalzenden": "Aussalzende",
    "Aussalzenderen": "Aussalzendere",
    "Aussalzendsten": "Aussalzendste",
    "Aussalzens": "Aussalzen",
    "Aussaufenden": "Aussaufende",
    "Aussaufens": "Aussaufen",
    "Aussaugenden": "Aussaugende",
    "Aussaugens": "Aussaugen",
    "Ausschabenden": "Ausschabende",
    "Ausschabenderen": "Ausschabendere",
    "Ausschabendsten": "Ausschabendste",
    "Ausschabens": "Ausschaben",
    "Ausschabungen": "Ausschabung",
    "Ausschachtelnden": "Ausschachtelnde",
    "Ausschachtelnderen": "Ausschachtelndere",
    "Ausschachtelns": "Ausschachteln",
    "Ausschachtungen": "Ausschachtung",
    "Ausschalenden": "Ausschalende",
    "Ausschalenderen": "Ausschalendere",
    "Ausschalendsten": "Ausschalendste",
    "Ausschalens": "Ausschalen",
    "Ausschalten": "ausschelten",
    "Ausschaltenden": "Ausschaltende",
    "Ausschaltens": "Ausschalten",
    "Ausschaltungen": "Ausschaltung",
    "Ausschalungen": "Ausschalung",
    "Ausschanks": "Ausschank",
    "Ausscharrenden": "Ausscharrende",
    "Ausscharrens": "Ausscharren",
    "Ausschauenden": "Ausschauende",
    "Ausschauens": "Ausschauen",
    "Ausschaufelnden": "Ausschaufelnde",
    "Ausschaufelns": "Ausschaufeln",
    "Ausscheidenden": "Ausscheidende",
    "Ausscheidens": "Ausscheiden",
    "Ausscheidungen": "Ausscheidung",
    "Ausscheltenden": "Ausscheltende",
    "Ausscheltenderen": "Ausscheltendere",
    "Ausscheltendsten": "Ausscheltendste",
    "Ausscheltens": "Ausschelten",
    "Ausschenkenden": "Ausschenkende",
    "Ausschenkens": "Ausschenken",
    "Ausscherenden": "Ausscherende",
    "Ausscherenderen": "Ausscherendere",
    "Ausscherendsten": "Ausscherendste",
    "Ausscherens": "Ausscheren",
    "Ausschießenden": "Ausschießende",
    "Ausschießens": "Ausschießen",
    "Ausschiffenden": "Ausschiffende",
    "Ausschiffens": "Ausschiffen",
    "Ausschiffungen": "Ausschiffung",
    "Ausschildernden": "Ausschildernde",
    "Ausschilderns": "Ausschildern",
    "Ausschilderungen": "Ausschilderung",
    "Ausschimpfenden": "Ausschimpfende",
    "Ausschimpfenderen": "Ausschimpfendere",
    "Ausschimpfendsten": "Ausschimpfendste",
    "Ausschimpfens": "Ausschimpfen",
    "Ausschirrenden": "Ausschirrende",
    "Ausschirrens": "Ausschirren",
    "Ausschlachtenden": "Ausschlachtende",
    "Ausschlachtenderen": "Ausschlachtendere",
    "Ausschlachtens": "Ausschlachten",
    "Ausschlachtungen": "Ausschlachtung",
    "Ausschlafenden": "Ausschlafende",
    "Ausschlafens": "Ausschlafen",
    "Ausschlage": "ausschlagen",
    "Ausschlagenden": "Ausschlagende",
    "Ausschlagens": "Ausschlagen",
    "Ausschlages": "Ausschlag",
    "Ausschlaggebenden": "Ausschlaggebende",
    "Ausschlags": "Ausschlag",
    "Ausschleimenden": "Ausschleimende",
    "Ausschleimenderen": "Ausschleimendere",
    "Ausschleimendsten": "Ausschleimendste",
    "Ausschleimens": "Ausschleimen",
    "Ausschließenden": "Ausschließende",
    "Ausschließens": "Ausschließen",
    "Ausschließlichen": "Ausschließliche",
    "Ausschlupfe": "Ausschlupf",
    "Ausschlupfs": "Ausschlupf",
    "Ausschlusse": "Ausschluß",
    "Ausschlusses": "Ausschluß",
    "Ausschlämmenden": "Ausschlämmende",
    "Ausschlämmens": "Ausschlämmen",
    "Ausschlüpfe": "ausschlüpfen",
    "Ausschlüpfenden": "Ausschlüpfende",
    "Ausschlüpfens": "Ausschlüpfen",
    "Ausschlürfenden": "Ausschlürfende",
    "Ausschlürfens": "Ausschlürfen",
    "Ausschlüsse": "Ausschluß",
    "Ausschlüssen": "Ausschluß",
    "Ausschmelzenden": "Ausschmelzende",
    "Ausschmelzens": "Ausschmelzen",
    "Ausschmierenden": "Ausschmierende",
    "Ausschmierens": "Ausschmieren",
    "Ausschnappenden": "Ausschnappende",
    "Ausschnappens": "Ausschnappen",
    "Ausschnaubenden": "Ausschnaubende",
    "Ausschnaubenderen": "Ausschnaubendere",
    "Ausschnaubendsten": "Ausschnaubendste",
    "Ausschnaubens": "Ausschnauben",
    "Ausschnaufenden": "Ausschnaufende",
    "Ausschnaufenderen": "Ausschnaufendere",
    "Ausschnaufendsten": "Ausschnaufendste",
    "Ausschnaufens": "Ausschnaufen",
    "Ausschneidenden": "Ausschneidende",
    "Ausschneidens": "Ausschneiden",
    "Ausschneuzenden": "Ausschneuzende",
    "Ausschneuzens": "Ausschneuzen",
    "Ausschnitte": "Ausschnitt",
    "Ausschnitten": "Ausschnitt",
    "Ausschnittes": "Ausschnitt",
    "Ausschnitts": "Ausschnitt",
    "Ausschnäuzenden": "Ausschnäuzende",
    "Ausschnäuzens": "Ausschnäuzen",
    "Ausschraubenden": "Ausschraubende",
    "Ausschraubens": "Ausschrauben",
    "Ausschreibenden": "Ausschreibende",
    "Ausschreibens": "Ausschreiben",
    "Ausschreibungen": "Ausschreibung",
    "Ausschreienden": "Ausschreiende",
    "Ausschreienderen": "Ausschreiendere",
    "Ausschreiendsten": "Ausschreiendste",
    "Ausschreiens": "Ausschreien",
    "Ausschreitenden": "Ausschreitende",
    "Ausschreitens": "Ausschreiten",
    "Ausschreitungen": "Ausschreitung",
    "Ausschulenden": "Ausschulende",
    "Ausschulens": "Ausschulen",
    "Ausschusse": "Ausschuß",
    "Ausschusses": "Ausschuß",
    "Ausschwefelnden": "Ausschwefelnde",
    "Ausschwefelnderen": "Ausschwefelndere",
    "Ausschwefelndsten": "Ausschwefelndste",
    "Ausschwefelns": "Ausschwefeln",
    "Ausschweifenden": "Ausschweifende",
    "Ausschweifenderen": "Ausschweifendere",
    "Ausschweifendsten": "Ausschweifendste",
    "Ausschweifens": "Ausschweifen",
    "Ausschweifungen": "Ausschweifung",
    "Ausschweigenden": "Ausschweigende",
    "Ausschweigenderen": "Ausschweigendere",
    "Ausschweigendsten": "Ausschweigendste",
    "Ausschweigens": "Ausschweigen",
    "Ausschwemmenden": "Ausschwemmende",
    "Ausschwemmenderen": "Ausschwemmendere",
    "Ausschwemmendsten": "Ausschwemmendste",
    "Ausschwemmens": "Ausschwemmen",
    "Ausschwenkenden": "Ausschwenkende",
    "Ausschwenkens": "Ausschwenken",
    "Ausschwingenden": "Ausschwingende",
    "Ausschwingens": "Ausschwingen",
    "Ausschwitzenden": "Ausschwitzende",
    "Ausschwitzenderen": "Ausschwitzendere",
    "Ausschwitzendsten": "Ausschwitzendste",
    "Ausschwitzens": "Ausschwitzen",
    "Ausschwärmenden": "Ausschwärmende",
    "Ausschwärmens": "Ausschwärmen",
    "Ausschälende": "ausschälend",
    "Ausschälenden": "Ausschälende",
    "Ausschälens": "Ausschälen",
    "Ausschöpfenden": "Ausschöpfende",
    "Ausschöpfenderen": "Ausschöpfendere",
    "Ausschöpfendsten": "Ausschöpfendste",
    "Ausschöpfens": "Ausschöpfen",
    "Ausschüsse": "Ausschuß",
    "Ausschüssen": "Ausschuß",
    "Ausschüttelnden": "Ausschüttelnde",
    "Ausschüttelnderen": "Ausschüttelndere",
    "Ausschüttelndsten": "Ausschüttelndste",
    "Ausschüttelns": "Ausschütteln",
    "Ausschüttenden": "Ausschüttende",
    "Ausschüttens": "Ausschütten",
    "Aussehenden": "Aussehende",
    "Aussehens": "Aussehen",
    "Aussendenden": "Aussendende",
    "Aussendens": "Aussenden",
    "Aussetzenden": "Aussetzende",
    "Aussetzens": "Aussetzen",
    "Aussichten": "Aussicht",
    "Aussichtslose": "aussichtslos",
    "Aussichtslosen": "Aussichtslose",
    "Aussichtsloseren": "Aussichtslosere",
    "Aussichtslosesten": "Aussichtsloseste",
    "Aussichtsreichen": "Aussichtsreiche",
    "Aussichtsreicheren": "Aussichtsreichere",
    "Aussiebenden": "Aussiebende",
    "Aussiebenderen": "Aussiebendere",
    "Aussiebendsten": "Aussiebendste",
    "Aussiebens": "Aussieben",
    "Aussiedelnden": "Aussiedelnde",
    "Aussiedelns": "Aussiedeln",
    "Aussiedlern": "Aussiedler",
    "Aussiedlers": "Aussiedler",
    "Aussitzenden": "Aussitzende",
    "Aussitzens": "Aussitzen",
    "Aussondernden": "Aussondernde",
    "Aussonderns": "Aussondern",
    "Aussortierenden": "Aussortierende",
    "Aussortierenderen": "Aussortierendere",
    "Aussortierendsten": "Aussortierendste",
    "Aussortierens": "Aussortieren",
    "Aussortierte": "aussortiert",
    "Aussortierten": "Aussortierte",
    "Aussortierteren": "Aussortiertere",
    "Aussortiertesten": "Aussortierteste",
    "Ausspannenden": "Ausspannende",
    "Ausspannens": "Ausspannen",
    "Aussparenden": "Aussparende",
    "Aussparens": "Aussparen",
    "Aussparungen": "Aussparung",
    "Ausspeienden": "Ausspeiende",
    "Ausspeiens": "Ausspeien",
    "Aussperrenden": "Aussperrende",
    "Aussperrens": "Aussperren",
    "Aussperrungen": "Aussperrung",
    "Ausspielenden": "Ausspielende",
    "Ausspielens": "Ausspielen",
    "Ausspielungen": "Ausspielung",
    "Ausspionierenden": "Ausspionierende",
    "Ausspionierenderen": "Ausspionierendere",
    "Ausspionierens": "Ausspionieren",
    "Ausspionierte": "ausspioniert",
    "Ausspionierten": "Ausspionierte",
    "Ausspionierteren": "Ausspioniertere",
    "Ausspioniertesten": "Ausspionierteste",
    "Aussprachen": "aussprechen",
    "Aussprechbaren": "Aussprechbare",
    "Aussprechenden": "Aussprechende",
    "Aussprechens": "Aussprechen",
    "Aussprengenden": "Aussprengende",
    "Aussprengens": "Aussprengen",
    "Ausspritzenden": "Ausspritzende",
    "Ausspritzens": "Ausspritzen",
    "Ausspruche": "Ausspruch",
    "Ausspruchs": "Ausspruch",
    "Aussprühenden": "Aussprühende",
    "Aussprühens": "Aussprühen",
    "Ausspuckenden": "Ausspuckende",
    "Ausspuckens": "Ausspucken",
    "Ausspähenden": "Ausspähende",
    "Ausspähenderen": "Ausspähendere",
    "Ausspähendsten": "Ausspähendste",
    "Ausspähens": "Ausspähen",
    "Ausspülenden": "Ausspülende",
    "Ausspülens": "Ausspülen",
    "Ausspülungen": "Ausspülung",
    "Ausstaffierenden": "Ausstaffierende",
    "Ausstaffierenderen": "Ausstaffierendere",
    "Ausstaffierens": "Ausstaffieren",
    "Ausstaffierte": "ausstaffiert",
    "Ausstaffierten": "Ausstaffierte",
    "Ausstaffierteren": "Ausstaffiertere",
    "Ausstaffiertesten": "Ausstaffierteste",
    "Ausstande": "Ausstand",
    "Ausstands": "Ausstand",
    "Ausstanzenden": "Ausstanzende",
    "Ausstanzens": "Ausstanzen",
    "Ausstattenden": "Ausstattende",
    "Ausstattens": "Ausstatten",
    "Ausstattungen": "Ausstattung",
    "Ausstechenden": "Ausstechende",
    "Ausstechens": "Ausstechen",
    "Ausstehenden": "Ausstehende",
    "Ausstehens": "Ausstehen",
    "Aussteifenden": "Aussteifende",
    "Aussteifenderen": "Aussteifendere",
    "Aussteifendsten": "Aussteifendste",
    "Aussteifens": "Aussteifen",
    "Aussteigenden": "Aussteigende",
    "Aussteigens": "Aussteigen",
    "Aussteigern": "Aussteiger",
    "Aussteigers": "Aussteiger",
    "Ausstellenden": "Ausstellende",
    "Ausstellens": "Ausstellen",
    "Ausstellern": "Aussteller",
    "Ausstellers": "Aussteller",
    "Ausstellfenstern": "Ausstellfenster",
    "Ausstellfensters": "Ausstellfenster",
    "Ausstellungen": "Ausstellung",
    "Aussterbenden": "Aussterbende",
    "Aussterbenderen": "Aussterbendere",
    "Aussterbendsten": "Aussterbendste",
    "Aussterbens": "Aussterben",
    "Aussteuernden": "Aussteuernde",
    "Aussteuerns": "Aussteuern",
    "Ausstiche": "Ausstich",
    "Ausstichen": "Ausstich",
    "Ausstichs": "Ausstich",
    "Ausstiege": "Ausstieg",
    "Ausstiegen": "Ausstieg",
    "Ausstiegs": "Ausstieg",
    "Ausstopfenden": "Ausstopfende",
    "Ausstopfenderen": "Ausstopfendere",
    "Ausstopfendsten": "Ausstopfendste",
    "Ausstopfens": "Ausstopfen",
    "Ausstoßenden": "Ausstoßende",
    "Ausstoßens": "Ausstoßen",
    "Ausstrahlenden": "Ausstrahlende",
    "Ausstrahlenderen": "Ausstrahlendere",
    "Ausstrahlendsten": "Ausstrahlendste",
    "Ausstrahlens": "Ausstrahlen",
    "Ausstrahlungen": "Ausstrahlung",
    "Ausstreichenden": "Ausstreichende",
    "Ausstreichens": "Ausstreichen",
    "Ausstreuenden": "Ausstreuende",
    "Ausstreuens": "Ausstreuen",
    "Ausströmenden": "Ausströmende",
    "Ausströmens": "Ausströmen",
    "Ausständigen": "Ausständige",
    "Ausstülpenden": "Ausstülpende",
    "Ausstülpens": "Ausstülpen",
    "Aussuchenden": "Aussuchende",
    "Aussuchens": "Aussuchen",
    "Aussäenden": "Aussäende",
    "Aussäens": "Aussäen",
    "Aussägende": "aussägend",
    "Aussägenden": "Aussägende",
    "Aussägens": "Aussägen",
    "Aussätzigen": "Aussätzige",
    "Aussöhnenden": "Aussöhnende",
    "Aussöhnens": "Aussöhnen",
    "Aussöhnungen": "Aussöhnung",
    "Austarierenden": "Austarierende",
    "Austarierens": "Austarieren",
    "Austarierte": "austariert",
    "Austarierten": "Austarierte",
    "Austauschbaren": "Austauschbare",
    "Austausche": "austauschen",
    "Austauschen": "Austausch",
    "Austauschenden": "Austauschende",
    "Austauschens": "Austauschen",
    "Austausches": "Austausch",
    "Austeilenden": "Austeilende",
    "Austeilens": "Austeilen",
    "Austellungen": "Austellung",
    "Austern": "Auster",
    "Austilgenden": "Austilgende",
    "Austilgens": "Austilgen",
    "Austobenden": "Austobende",
    "Austobenderen": "Austobendere",
    "Austobendsten": "Austobendste",
    "Austobens": "Austoben",
    "Austragenden": "Austragende",
    "Austragens": "Austragen",
    "Austragungen": "Austragung",
    "Australiden": "Australide",
    "Australiens": "Australien",
    "Australiern": "Australier",
    "Australiers": "Australier",
    "Australische": "australisch",
    "Australischen": "Australische",
    "Austreibenden": "Austreibende",
    "Austreibens": "Austreiben",
    "Austreibungen": "Austreibung",
    "Austreibungsperioden": "Austreibungsperiode",
    "Austretenden": "Austretende",
    "Austretens": "Austreten",
    "Austricksenden": "Austricksende",
    "Austricksenderen": "Austricksendere",
    "Austricksendsten": "Austricksendste",
    "Austricksens": "Austricksen",
    "Austrinkenden": "Austrinkende",
    "Austrinkenderen": "Austrinkendere",
    "Austrinkendsten": "Austrinkendste",
    "Austrinkens": "Austrinken",
    "Austritte": "Austritt",
    "Austritten": "Austritt",
    "Austritts": "Austritt",
    "Austrocknenden": "Austrocknende",
    "Austrocknenderen": "Austrocknendere",
    "Austrocknendsten": "Austrocknendste",
    "Austrocknens": "Austrocknen",
    "Austrompetenden": "Austrompetende",
    "Austrompetens": "Austrompeten",
    "Austrompetete": "austrompetet",
    "Austrompeteten": "Austrompetete",
    "Austrägern": "Austräger",
    "Austrägers": "Austräger",
    "Austräumenden": "Austräumende",
    "Austräumens": "Austräumen",
    "Austupfenden": "Austupfende",
    "Austupfens": "Austupfen",
    "Austüftelnden": "Austüftelnde",
    "Austüftelnderen": "Austüftelndere",
    "Austüftelndsten": "Austüftelndste",
    "Austüftelns": "Austüfteln",
    "Ausufernden": "Ausufernde",
    "Ausufernderen": "Ausuferndere",
    "Ausuferndsten": "Ausuferndste",
    "Ausuferns": "Ausufern",
    "Ausverkaufe": "ausverkaufen",
    "Ausverkaufenden": "Ausverkaufende",
    "Ausverkaufens": "Ausverkaufen",
    "Ausverkaufs": "Ausverkauf",
    "Ausverkaufte": "ausverkauft",
    "Ausverkauften": "Ausverkaufte",
    "Ausverkäufe": "Ausverkauf",
    "Ausverkäufen": "Ausverkauf",
    "Auswachsenden": "Auswachsende",
    "Auswachsenderen": "Auswachsendere",
    "Auswachsendsten": "Auswachsendste",
    "Auswachsens": "Auswachsen",
    "Auswahlen": "Auswahl",
    "Auswalzenden": "Auswalzende",
    "Auswalzens": "Auswalzen",
    "Auswandernden": "Auswandernde",
    "Auswanderns": "Auswandern",
    "Auswanderungen": "Auswanderung",
    "Auswaschenden": "Auswaschende",
    "Auswaschens": "Auswaschen",
    "Auswechselbaren": "Auswechselbare",
    "Auswechselnden": "Auswechselnde",
    "Auswechselns": "Auswechseln",
    "Auswege": "Ausweg",
    "Auswegen": "Ausweg",
    "Ausweglose": "ausweglos",
    "Ausweglosen": "Ausweglose",
    "Auswegloseren": "Ausweglosere",
    "Ausweglosesten": "Auswegloseste",
    "Auswegs": "Ausweg",
    "Ausweiche": "ausweichen",
    "Ausweichen": "Ausweiche",
    "Ausweichenden": "Ausweichende",
    "Ausweichens": "Ausweichen",
    "Ausweichflughafens": "Ausweichflughafen",
    "Ausweichflughäfen": "Ausweichflughafen",
    "Ausweichmöglichkeiten": "Ausweichmöglichkeit",
    "Ausweichstellen": "Ausweichstelle",
    "Ausweidenden": "Ausweidende",
    "Ausweidens": "Ausweiden",
    "Ausweinenden": "Ausweinende",
    "Ausweinens": "Ausweinen",
    "Ausweise": "ausweisen",
    "Ausweisen": "Ausweis",
    "Ausweisenden": "Ausweisende",
    "Ausweisenderen": "Ausweisendere",
    "Ausweisendsten": "Ausweisendste",
    "Ausweisens": "Ausweisen",
    "Ausweises": "Ausweis",
    "Ausweisungen": "Ausweisung",
    "Ausweitenden": "Ausweitende",
    "Ausweitenderen": "Ausweitendere",
    "Ausweitendsten": "Ausweitendste",
    "Ausweitens": "Ausweiten",
    "Ausweitungen": "Ausweitung",
    "Auswendige": "auswendig",
    "Auswendigen": "Auswendige",
    "Auswerfenden": "Auswerfende",
    "Auswerfens": "Auswerfen",
    "Auswertenden": "Auswertende",
    "Auswertens": "Auswerten",
    "Auswertungen": "Auswertung",
    "Auswetzenden": "Auswetzende",
    "Auswetzenderen": "Auswetzendere",
    "Auswetzendsten": "Auswetzendste",
    "Auswetzens": "Auswetzen",
    "Auswickelnden": "Auswickelnde",
    "Auswickelns": "Auswickeln",
    "Auswiegenden": "Auswiegende",
    "Auswiegens": "Auswiegen",
    "Auswindenden": "Auswindende",
    "Auswindens": "Auswinden",
    "Auswirkenden": "Auswirkende",
    "Auswirkens": "Auswirken",
    "Auswirkungen": "Auswirkung",
    "Auswischenden": "Auswischende",
    "Auswischens": "Auswischen",
    "Auswringenden": "Auswringende",
    "Auswringens": "Auswringen",
    "Auswuchtenden": "Auswuchtende",
    "Auswuchtenderen": "Auswuchtendere",
    "Auswuchtendsten": "Auswuchtendste",
    "Auswuchtens": "Auswuchten",
    "Auswählenden": "Auswählende",
    "Auswählens": "Auswählen",
    "Auswärmenden": "Auswärmende",
    "Auswärmens": "Auswärmen",
    "Auswärtigen": "Auswärtige",
    "Auszahlenden": "Auszahlende",
    "Auszahlens": "Auszahlen",
    "Auszahlungen": "Auszahlung",
    "Auszahnenden": "Auszahnende",
    "Auszahnenderen": "Auszahnendere",
    "Auszahnendsten": "Auszahnendste",
    "Auszahnens": "Auszahnen",
    "Auszankenden": "Auszankende",
    "Auszankenderen": "Auszankendere",
    "Auszankendsten": "Auszankendste",
    "Auszankens": "Auszanken",
    "Auszeichnenden": "Auszeichnende",
    "Auszeichnens": "Auszeichnen",
    "Auszeichnungen": "Auszeichnung",
    "Ausziehenden": "Ausziehende",
    "Ausziehens": "Ausziehen",
    "Ausziehleitern": "Ausziehleiter",
    "Ausziehplatten": "Ausziehplatte",
    "Auszierenden": "Auszierende",
    "Auszierenderen": "Auszierendere",
    "Auszierendsten": "Auszierendste",
    "Auszierens": "Auszieren",
    "Auszirkelnden": "Auszirkelnde",
    "Auszirkelns": "Auszirkeln",
    "Auszischenden": "Auszischende",
    "Auszischens": "Auszischen",
    "Auszubildenden": "Auszubildende",
    "Auszuge": "Auszug",
    "Auszugs": "Auszug",
    "Auszupfenden": "Auszupfende",
    "Auszupfens": "Auszupfen",
    "Auszählende": "auszählend",
    "Auszählenden": "Auszählende",
    "Auszählens": "Auszählen",
    "Auszählungen": "Auszählung",
    "Auszüge": "Auszug",
    "Auszügen": "Auszug",
    "Auszüglern": "Auszügler",
    "Auszüglers": "Auszügler",
    "Ausübenden": "Ausübende",
    "Ausübens": "Ausüben",
    "Authentifizierenden": "Authentifizierende",
    "Authentifizierenderen": "Authentifizierendere",
    "Authentifizierens": "Authentifizieren",
    "Authentifizierte": "authentifiziert",
    "Authentifizierten": "Authentifizierte",
    "Authentischen": "Authentische",
    "Authentischeren": "Authentischere",
    "Authentischsten": "Authentischste",
    "Authentisierenden": "Authentisierende",
    "Authentisierenderen": "Authentisierendere",
    "Authentisierens": "Authentisieren",
    "Authentisierte": "authentisiert",
    "Authentisierten": "Authentisierte",
    "Authentizitäten": "Authentizität",
    "Autisten": "Autist",
    "Autistische": "autistisch",
    "Autistischen": "Autistische",
    "Autobahnen": "Autobahn",
    "Autobiographien": "Autobiographie",
    "Autobiographische": "autobiographisch",
    "Autobiographischen": "Autobiographische",
    "Autodidakten": "Autodidakt",
    "Autodidaktische": "autodidaktisch",
    "Autodidaktischen": "Autodidaktische",
    "Autofreie": "autofrei",
    "Autofreien": "Autofreie",
    "Autofähren": "Autofähre",
    "Autogenen": "Autogene",
    "Autogramme": "Autogramm",
    "Autogrammen": "Autogramm",
    "Autogrammes": "Autogramm",
    "Autogramms": "Autogramm",
    "Autographien": "Autographie",
    "Autographische": "autographisch",
    "Autographischen": "Autographische",
    "Autohilfen": "Autohilfe",
    "Autokarten": "Autokarte",
    "Autokratien": "Autokratie",
    "Autokratische": "autokratisch",
    "Autokratischen": "Autokratische",
    "Autolysen": "Autolyse",
    "Automarken": "Automarke",
    "Automaten": "Automat",
    "Automatische": "automatisch",
    "Automatischen": "Automatische",
    "Automatischeren": "Automatischere",
    "Automatischsten": "Automatischste",
    "Automatisierenden": "Automatisierende",
    "Automatisierenderen": "Automatisierendere",
    "Automatisierens": "Automatisieren",
    "Automatisierte": "automatisiert",
    "Automatisierten": "Automatisierte",
    "Automatisierteren": "Automatisiertere",
    "Automatisierteste": "automatisiert",
    "Automatisierungen": "Automatisierung",
    "Autominuten": "Autominute",
    "Autonome": "autonom",
    "Autonomen": "Autonome",
    "Autonomeren": "Autonomere",
    "Autonomien": "Autonomie",
    "Autonomste": "autonom",
    "Autonomsten": "Autonomste",
    "Autopiloten": "Autopilot",
    "Autore": "Autor",
    "Autoren": "Autor",
    "Autorinnen": "Autorin",
    "Autorisierenden": "Autorisierende",
    "Autorisierens": "Autorisieren",
    "Autorisierte": "autorisiert",
    "Autorisierten": "Autorisierte",
    "Autoritative": "autoritativ",
    "Autoritativen": "Autoritative",
    "Autoritativeren": "Autoritativere",
    "Autoritativsten": "Autoritativste",
    "Autoritären": "Autoritäre",
    "Autoritäreren": "Autoritärere",
    "Autoritärsten": "Autoritärste",
    "Autoritäten": "Autorität",
    "Autors": "Autor",
    "Autos": "Auto",
    "Autostraßen": "Autostraße",
    "Autosuggestive": "autosuggestiv",
    "Autosuggestiven": "Autosuggestive",
    "Autosuggestiveren": "Autosuggestivere",
    "Autosuggestivsten": "Autosuggestivste",
    "Autotoxine": "Autotoxin",
    "Autotoxinen": "Autotoxin",
    "Autotoxins": "Autotoxin",
    "Autotypien": "Autotypie",
    "Außenantennen": "Außenantenne",
    "Außenaufnahmen": "Außenaufnahme",
    "Außenbezirke": "Außenbezirk",
    "Außenbezirken": "Außenbezirk",
    "Außenbezirks": "Außenbezirk",
    "Außenbordmotore": "Außenbordmotor",
    "Außenbordmotoren": "Außenbordmotor",
    "Außenbordmotors": "Außenbordmotor",
    "Außendienste": "Außendienst",
    "Außendiensten": "Außendienst",
    "Außendienstes": "Außendienst",
    "Außendiensts": "Außendienst",
    "Außengalopps": "Außengalopp",
    "Außengeländen": "Außengelände",
    "Außengeländes": "Außengelände",
    "Außenhafens": "Außenhafen",
    "Außenhandels": "Außenhandel",
    "Außenhäfen": "Außenhafen",
    "Außenhäute": "Außenhaut",
    "Außenhäuten": "Außenhaut",
    "Außenlandungen": "Außenlandung",
    "Außenministerien": "Außenministerium",
    "Außenministeriums": "Außenministerium",
    "Außenministern": "Außenminister",
    "Außenministers": "Außenminister",
    "Außenpolitiken": "Außenpolitik",
    "Außenpolitische": "außenpolitisch",
    "Außenpolitischen": "Außenpolitische",
    "Außenpolitischeren": "Außenpolitischere",
    "Außenseiterinnen": "Außenseiterin",
    "Außenseitern": "Außenseiter",
    "Außenseiters": "Außenseiter",
    "Außenspiegeln": "Außenspiegel",
    "Außenspiegels": "Außenspiegel",
    "Außenstauraume": "Außenstauraum",
    "Außenstauraumes": "Außenstauraum",
    "Außenstauraums": "Außenstauraum",
    "Außenstauräume": "Außenstauraum",
    "Außenstauräumen": "Außenstauraum",
    "Außenstellen": "Außenstelle",
    "Außenstürmern": "Außenstürmer",
    "Außenstürmers": "Außenstürmer",
    "Außentemperaturen": "Außentemperatur",
    "Außenwinkeln": "Außenwinkel",
    "Außenwinkels": "Außenwinkel",
    "Außenwände": "Außenwand",
    "Außenwänden": "Außenwand",
    "Außeramtliche": "außeramtlich",
    "Außeramtlichen": "Außeramtliche",
    "Außerdeutschen": "Außerdeutsche",
    "Außerdienstlichen": "Außerdienstliche",
    "Außerehelichen": "Außereheliche",
    "Außereuropäischen": "Außereuropäische",
    "Außergalaktischen": "Außergalaktische",
    "Außergerichtlichen": "Außergerichtliche",
    "Außergewöhnlichen": "Außergewöhnliche",
    "Außergewöhnlicheren": "Außergewöhnlichere",
    "Außerirdischen": "Außerirdische",
    "Außerkirchlichen": "Außerkirchliche",
    "Außerordentlichen": "Außerordentliche",
    "Außerordentlicheren": "Außerordentlichere",
    "Außerparlamentarischen": "Außerparlamentarische",
    "Außerplanmäßigen": "Außerplanmäßige",
    "Avancierenden": "Avancierende",
    "Avancierenderen": "Avancierendere",
    "Avancierendsten": "Avancierendste",
    "Avancierens": "Avancieren",
    "Avancierte": "avanciert",
    "Avancierten": "Avancierte",
    "Avancierteren": "Avanciertere",
    "Avanciertesten": "Avancierteste",
    "Avisierenden": "Avisierende",
    "Avisierens": "Avisieren",
    "Avisierte": "avisiert",
    "Avisierten": "Avisierte",
    "Axels": "Axel",
    "Axiomatische": "axiomatisch",
    "Axiomatischen": "Axiomatische",
    "Axiomatisierenden": "Axiomatisierende",
    "Axiomatisierenderen": "Axiomatisierendere",
    "Axiomatisierens": "Axiomatisieren",
    "Axiomatisierte": "axiomatisiert",
    "Axiomatisierten": "Axiomatisierte",
    "Axiomatisierteren": "Axiomatisiertere",
    "Axiomatisierteste": "axiomatisiert",
    "Axiome": "Axiom",
    "Axiomen": "Axiom",
    "Axioms": "Axiom",
    "Azetone": "Azeton",
    "Azetonen": "Azeton",
    "Azetones": "Azeton",
    "Azetons": "Azeton",
    "Azteken": "Azteke",
    "Aztekische": "aztekisch",
    "Aztekischen": "Aztekische",
    "BMWs": "BMW",
    "Babels": "Babel",
    "Babylonische": "babylonisch",
    "Babylonischen": "Babylonische",
    "Babys": "Baby",
    "Babysittern": "Babysitter",
    "Babysitters": "Babysitter",
    "Bache": "Bach",
    "Baches": "Bach",
    "Bachs": "Bach",
    "Bachstelzen": "Bachstelze",
    "Backe": "backen",
    "Backen": "Backe",
    "Backenden": "Backende",
    "Backens": "Backen",
    "Backfische": "Backfisch",
    "Backfischen": "Backfisch",
    "Backfischs": "Backfisch",
    "Backformen": "Backform",
    "Backmulden": "Backmulde",
    "Backofens": "Backofen",
    "Backpflaumen": "Backpflaume",
    "Backpulvern": "Backpulver",
    "Backpulvers": "Backpulver",
    "Backsteine": "Backstein",
    "Backsteinen": "Backstein",
    "Backsteins": "Backstein",
    "Backstuben": "Backstube",
    "Backöfen": "Backofen",
    "Bade": "baden",
    "Badenden": "Badende",
    "Badens": "Baden",
    "Badereisen": "Badereise",
    "Bades": "Bad",
    "Badewannen": "Badewanne",
    "Badische": "badisch",
    "Badischen": "Badische",
    "Bads": "Bad",
    "Baedekern": "Baedeker",
    "Baedekers": "Baedeker",
    "Bagagen": "Bagage",
    "Bagatellen": "Bagatelle",
    "Bagatellisierenden": "Bagatellisierende",
    "Bagatellisierenderen": "Bagatellisierendere",
    "Bagatellisierens": "Bagatellisieren",
    "Bagatellisierte": "bagatellisiert",
    "Bagatellisierten": "Bagatellisierte",
    "Bagatellisierteren": "Bagatellisiertere",
    "Bagatellschadens": "Bagatellschaden",
    "Bagatellschäden": "Bagatellschaden",
    "Bagdads": "Bagdad",
    "Bagger": "baggern",
    "Baggern": "Bagger",
    "Baggernden": "Baggernde",
    "Baggernderen": "Baggerndere",
    "Baggerndsten": "Baggerndste",
    "Baggerns": "Baggern",
    "Baggers": "Bagger",
    "Baguettes": "Baguette",
    "Bahn": "bahnen",
    "Bahnbrechende": "bahnbrechend",
    "Bahnbrechenden": "Bahnbrechende",
    "Bahnbrechenderen": "Bahnbrechendere",
    "Bahnbrechendsten": "Bahnbrechendste",
    "Bahnen": "Bahn",
    "Bahnenden": "Bahnende",
    "Bahnens": "Bahnen",
    "Bahnhofe": "Bahnhof",
    "Bahnhofes": "Bahnhof",
    "Bahnhofs": "Bahnhof",
    "Bahnhöfe": "Bahnhof",
    "Bahnhöfen": "Bahnhof",
    "Bahren": "Bahre",
    "Bahrenden": "Bahrende",
    "Bahrens": "Bahren",
    "Baiers": "Baier",
    "Bairische": "bairisch",
    "Bairischen": "Bairische",
    "Bajonette": "Bajonett",
    "Bajonetten": "Bajonett",
    "Bajonetts": "Bajonett",
    "Bajuwaren": "Bajuware",
    "Bajuwarische": "bajuwarisch",
    "Bajuwarischen": "Bajuwarische",
    "Bakers": "Baker",
    "Bakterielle": "bakteriell",
    "Bakteriellen": "Bakterielle",
    "Bakterien": "Bakterie",
    "Bakteriologen": "Bakteriologe",
    "Bakteriologische": "bakteriologisch",
    "Bakteriologischen": "Bakteriologische",
    "Balalaikas": "Balalaika",
    "Balancen": "Balance",
    "Balbiere": "Balbier",
    "Balbieren": "Balbier",
    "Balbiers": "Balbier",
    "Baldige": "baldig",
    "Baldigen": "Baldige",
    "Baldower": "baldowern",
    "Baldowern": "Baldower",
    "Baldowernden": "Baldowernde",
    "Baldowerns": "Baldowern",
    "Baldowers": "Baldower",
    "Baldowerte": "baldowert",
    "Baldowerten": "Baldowerte",
    "Baldrians": "Baldrian",
    "Balgenden": "Balgende",
    "Balgenderen": "Balgendere",
    "Balgendsten": "Balgendste",
    "Balgens": "Balgen",
    "Balgereien": "Balgerei",
    "Balkanisierenden": "Balkanisierende",
    "Balkanisierenderen": "Balkanisierendere",
    "Balkanisierens": "Balkanisieren",
    "Balkanisierte": "balkanisiert",
    "Balkanisierten": "Balkanisierte",
    "Balkanisierteren": "Balkanisiertere",
    "Balkanisiertesten": "Balkanisierteste",
    "Balkans": "Balkan",
    "Balkens": "Balken",
    "Balkenwaagen": "Balkenwaage",
    "Balkone": "Balkon",
    "Balkonen": "Balkon",
    "Balkons": "Balkon",
    "Ball": "ballen",
    "Balladen": "Ballade",
    "Balladenhafte": "balladenhaft",
    "Balladenhaften": "Balladenhafte",
    "Balladenhafteren": "Balladenhaftere",
    "Balladenhaftesten": "Balladenhafteste",
    "Balle": "ballen",
    "Ballenden": "Ballende",
    "Ballenderen": "Ballendere",
    "Ballendsten": "Ballendste",
    "Ballens": "Ballen",
    "Ballermanne": "Ballermann",
    "Ballermannes": "Ballermann",
    "Ballermanns": "Ballermann",
    "Ballermänner": "Ballermann",
    "Ballermännern": "Ballermann",
    "Ballernden": "Ballernde",
    "Ballernderen": "Ballerndere",
    "Ballerndsten": "Ballerndste",
    "Ballerns": "Ballern",
    "Balles": "Ball",
    "Ballette": "Ballett",
    "Balletten": "Ballett",
    "Ballettes": "Ballett",
    "Balletts": "Ballett",
    "Ballistische": "ballistisch",
    "Ballistischen": "Ballistische",
    "Ballons": "Ballon",
    "Balls": "Ball",
    "Ballungen": "Ballung",
    "Balsame": "Balsam",
    "Balsamen": "Balsam",
    "Balsamierenden": "Balsamierende",
    "Balsamierenderen": "Balsamierendere",
    "Balsamierendsten": "Balsamierendste",
    "Balsamierens": "Balsamieren",
    "Balsamierte": "balsamiert",
    "Balsamierten": "Balsamierte",
    "Balsamierteren": "Balsamiertere",
    "Balsamiertesten": "Balsamierteste",
    "Balsams": "Balsam",
    "Baltische": "baltisch",
    "Baltischen": "Baltische",
    "Balustraden": "Balustrade",
    "Balzenden": "Balzende",
    "Balzenderen": "Balzendere",
    "Balzendsten": "Balzendste",
    "Balzens": "Balzen",
    "Bambergs": "Bamberg",
    "Bambis": "Bambi",
    "Bambuspalmen": "Bambuspalme",
    "Bambusse": "Bambus",
    "Bambussen": "Bambus",
    "Bambusses": "Bambus",
    "Bammeln": "Bammel",
    "Bammels": "Bammel",
    "Banale": "banal",
    "Banalen": "Banale",
    "Banaleren": "Banalere",
    "Banalisierenden": "Banalisierende",
    "Banalisierenderen": "Banalisierendere",
    "Banalisierendsten": "Banalisierendste",
    "Banalisierens": "Banalisieren",
    "Banalisierte": "banalisiert",
    "Banalisierten": "Banalisierte",
    "Banalitäten": "Banalität",
    "Banalste": "banal",
    "Banalsten": "Banalste",
    "Bananen": "Banane",
    "Banausen": "Banause",
    "Band": "binden",
    "Bandagen": "Bandage",
    "Bande": "Band",
    "Bandelnden": "Bandelnde",
    "Bandelns": "Bandeln",
    "Banden": "binden",
    "Banderolen": "Banderole",
    "Banditen": "Bandit",
    "Bands": "Band",
    "Banduras": "Bandura",
    "Bandwirkereien": "Bandwirkerei",
    "Bange": "bangen",
    "Bangenden": "Bangende",
    "Bangens": "Bangen",
    "Bangkoks": "Bangkok",
    "Bankette": "Bankett",
    "Banketten": "Bankett",
    "Bankettes": "Bankett",
    "Banketts": "Bankett",
    "Bankiers": "Bankier",
    "Bann": "bannen",
    "Banne": "bannen",
    "Bannenden": "Bannende",
    "Bannenderen": "Bannendere",
    "Bannendsten": "Bannendste",
    "Bannens": "Bannen",
    "Bannern": "Banner",
    "Banners": "Banner",
    "Bannes": "Bann",
    "Banns": "Bann",
    "Baptisten": "Baptist",
    "Baracken": "Baracke",
    "Barbaras": "Barbara",
    "Barbaren": "Barbar",
    "Barbarische": "barbarisch",
    "Barbarischen": "Barbarische",
    "Barbestande": "Barbestand",
    "Barbestands": "Barbestand",
    "Barbestände": "Barbestand",
    "Barbeständen": "Barbestand",
    "Barbier": "barbieren",
    "Barbiere": "barbieren",
    "Barbieren": "Barbier",
    "Barbierenden": "Barbierende",
    "Barbierens": "Barbieren",
    "Barbiers": "Barbier",
    "Barbierte": "barbiert",
    "Barbierten": "Barbierte",
    "Barbierteren": "Barbiertere",
    "Barbiertesten": "Barbierteste",
    "Barbies": "Barbie",
    "Barbusige": "barbusig",
    "Barbusigen": "Barbusige",
    "Barcelonas": "Barcelona",
    "Bardamen": "Bardame",
    "Barden": "Barde",
    "Bare": "bar",
    "Baren": "Bare",
    "Barette": "Barett",
    "Baretten": "Barett",
    "Barettes": "Barett",
    "Baretts": "Barett",
    "Barfüßige": "barfüßig",
    "Barfüßigen": "Barfüßige",
    "Barfüßigeren": "Barfüßigere",
    "Barfüßigsten": "Barfüßigste",
    "Bargelde": "Bargeld",
    "Bargeldes": "Bargeld",
    "Bargeldlose": "bargeldlos",
    "Bargeldlosen": "Bargeldlose",
    "Bargelds": "Bargeld",
    "Baritone": "Bariton",
    "Baritonen": "Bariton",
    "Baritonisten": "Baritonist",
    "Baritons": "Bariton",
    "Barkarolen": "Barkarole",
    "Barkassen": "Barkasse",
    "Barkaufe": "Barkauf",
    "Barkaufs": "Barkauf",
    "Barken": "Barke",
    "Barkäufe": "Barkauf",
    "Barkäufen": "Barkauf",
    "Barmanne": "Barmann",
    "Barmannes": "Barmann",
    "Barmanns": "Barmann",
    "Barmherzige": "barmherzig",
    "Barmherzigen": "Barmherzige",
    "Barmherzigeren": "Barmherzigere",
    "Barmherzigsten": "Barmherzigste",
    "Barmänner": "Barmann",
    "Barmännern": "Barmann",
    "Barocken": "Barocke",
    "Barometern": "Barometer",
    "Barometers": "Barometer",
    "Barone": "Baron",
    "Baronen": "Baron",
    "Barones": "Baron",
    "Baroninnen": "Baronin",
    "Barons": "Baron",
    "Barrakudas": "Barrakuda",
    "Barre": "barren",
    "Barrels": "Barrel",
    "Barren": "Barre",
    "Barrenden": "Barrende",
    "Barrenderen": "Barrendere",
    "Barrendsten": "Barrendste",
    "Barrens": "Barren",
    "Barrieren": "Barriere",
    "Barrikaden": "Barrikade",
    "Barrikadiere": "barrikadieren",
    "Barrikadierenden": "Barrikadierende",
    "Barrikadierenderen": "Barrikadierendere",
    "Barrikadierens": "Barrikadieren",
    "Barrikadierte": "barrikadiert",
    "Barrikadierten": "Barrikadierte",
    "Barrikadierteren": "Barrikadiertere",
    "Barrikadiertesten": "Barrikadierteste",
    "Bars": "Bar",
    "Barsche": "Barsch",
    "Barschels": "Barschel",
    "Barschen": "Barsche",
    "Barschs": "Barsch",
    "Barte": "Bart",
    "Bartes": "Bart",
    "Bartlosen": "Bartlose",
    "Barts": "Bart",
    "Barzahlungen": "Barzahlung",
    "Basalte": "Basalt",
    "Basalten": "Basalt",
    "Basalts": "Basalt",
    "Basare": "Basar",
    "Basaren": "Basar",
    "Basares": "Basar",
    "Basars": "Basar",
    "Basels": "Basel",
    "Basen": "Basis",
    "Basierenden": "Basierende",
    "Basierens": "Basieren",
    "Basierte": "basiert",
    "Basierten": "Basierte",
    "Basilikas": "Basilika",
    "Basilisken": "Basilisk",
    "Basisdemokratische": "basisdemokratisch",
    "Basisdemokratischen": "Basisdemokratische",
    "Basisgruppen": "Basisgruppe",
    "Basketballs": "Basketball",
    "Baskische": "baskisch",
    "Baskischen": "Baskische",
    "Basse": "Baß",
    "Basses": "Baß",
    "Bassins": "Bassin",
    "Bassisten": "Bassist",
    "Bastarde": "Bastard",
    "Bastarden": "Bastard",
    "Bastards": "Bastard",
    "Basteien": "Bastei",
    "Bastelnden": "Bastelnde",
    "Bastelns": "Basteln",
    "Bastians": "Bastian",
    "Bastionen": "Bastion",
    "Bastlern": "Bastler",
    "Bastlers": "Bastler",
    "Battenhausens": "Battenhausen",
    "Batterien": "Batterie",
    "Bau": "bauen",
    "Bauch": "bauchen",
    "Bauche": "bauchen",
    "Bauchenden": "Bauchende",
    "Bauchenderen": "Bauchendere",
    "Bauchendsten": "Bauchendste",
    "Bauchens": "Bauchen",
    "Bauches": "Bauch",
    "Bauchflossen": "Bauchflosse",
    "Bauchhöhlen": "Bauchhöhle",
    "Bauchige": "bauchig",
    "Bauchigen": "Bauchige",
    "Bauchklatschern": "Bauchklatscher",
    "Bauchklatschers": "Bauchklatscher",
    "Bauchredenden": "Bauchredende",
    "Bauchredenderen": "Bauchredendere",
    "Bauchredendsten": "Bauchredendste",
    "Bauchredens": "Bauchreden",
    "Bauchs": "Bauch",
    "Bauchwehs": "Bauchweh",
    "Bauen": "Bau",
    "Bauenden": "Bauende",
    "Bauens": "Bauen",
    "Bauern": "Bauer",
    "Bauerntums": "Bauerntum",
    "Bauers": "Bauer",
    "Baufälligen": "Baufällige",
    "Baufälligeren": "Baufälligere",
    "Baufälligsten": "Baufälligste",
    "Baulichen": "Bauliche",
    "Baume": "Baum",
    "Baumelnden": "Baumelnde",
    "Baumelnderen": "Baumelndere",
    "Baumelndsten": "Baumelndste",
    "Baumelns": "Baumeln",
    "Baumes": "Baum",
    "Baumgruppen": "Baumgruppe",
    "Baumkundlern": "Baumkundler",
    "Baumkundlers": "Baumkundler",
    "Baumlange": "baumlang",
    "Baumlangen": "Baumlange",
    "Baums": "Baum",
    "Baumsägen": "Baumsäge",
    "Baumwuchse": "Baumwuchs",
    "Baumwuchses": "Baumwuchs",
    "Baumwüchse": "Baumwuchs",
    "Baumwüchsen": "Baumwuchs",
    "Baureife": "baureif",
    "Baureifen": "Baureife",
    "Baureiferen": "Baureifere",
    "Baureifsten": "Baureifste",
    "Baus": "Bau",
    "Bausch": "bauschen",
    "Bausche": "bauschen",
    "Bauschenden": "Bauschende",
    "Bauschens": "Bauschen",
    "Bausches": "Bausch",
    "Bauschigen": "Bauschige",
    "Bauschigeren": "Bauschigere",
    "Bauschigsten": "Bauschigste",
    "Bauschs": "Bausch",
    "Bausparenden": "Bausparende",
    "Bausparenderen": "Bausparendere",
    "Bausparendsten": "Bausparendste",
    "Bausparens": "Bausparen",
    "Bauten": "bauen",
    "Bayerischen": "Bayerische",
    "Bayerischeren": "Bayerischere",
    "Bayerischsten": "Bayerischste",
    "Bayern": "Bayer",
    "Bayerns": "Bayern",
    "Bayers": "Bayer",
    "Bayreuths": "Bayreuth",
    "Bayrische": "bayrisch",
    "Bayrischen": "Bayrische",
    "Bayrischeren": "Bayrischere",
    "Bayrischsten": "Bayrischste",
    "Bazare": "Bazar",
    "Bazaren": "Bazar",
    "Bazares": "Bazar",
    "Bazars": "Bazar",
    "Bazis": "Bazi",
    "Beabsichtigenden": "Beabsichtigende",
    "Beabsichtigens": "Beabsichtigen",
    "Beabsichtigte": "beabsichtigt",
    "Beabsichtigten": "Beabsichtigte",
    "Beachtenden": "Beachtende",
    "Beachtenderen": "Beachtendere",
    "Beachtendsten": "Beachtendste",
    "Beachtens": "Beachten",
    "Beachtenswerte": "beachtenswert",
    "Beachtenswerten": "Beachtenswerte",
    "Beachtenswerteren": "Beachtenswertere",
    "Beachtete": "beachtet",
    "Beachteten": "Beachtete",
    "Beachteteren": "Beachtetere",
    "Beachtetesten": "Beachteteste",
    "Beachtlichen": "Beachtliche",
    "Beachtlicheren": "Beachtlichere",
    "Beachtlichsten": "Beachtlichste",
    "Beamten": "Beamte",
    "Beanspruchenden": "Beanspruchende",
    "Beanspruchens": "Beanspruchen",
    "Beanspruchte": "beansprucht",
    "Beanspruchten": "Beanspruchte",
    "Beanspruchteren": "Beanspruchtere",
    "Beanspruchtesten": "Beanspruchteste",
    "Beanstandenden": "Beanstandende",
    "Beanstandenderen": "Beanstandendere",
    "Beanstandendsten": "Beanstandendste",
    "Beanstandens": "Beanstanden",
    "Beanstandete": "beanstandet",
    "Beanstandeten": "Beanstandete",
    "Beanstandeteren": "Beanstandetere",
    "Beanstandetesten": "Beanstandeteste",
    "Beanstandungen": "Beanstandung",
    "Beantragenden": "Beantragende",
    "Beantragens": "Beantragen",
    "Beantragte": "beantragt",
    "Beantragten": "Beantragte",
    "Beantwortenden": "Beantwortende",
    "Beantwortens": "Beantworten",
    "Beantwortern": "Beantworter",
    "Beantworters": "Beantworter",
    "Beantwortete": "beantwortet",
    "Beantworteten": "Beantwortete",
    "Beantwortungen": "Beantwortung",
    "Bearbeitenden": "Bearbeitende",
    "Bearbeitens": "Bearbeiten",
    "Bearbeitern": "Bearbeiter",
    "Bearbeiters": "Bearbeiter",
    "Bearbeitete": "bearbeitet",
    "Bearbeiteten": "Bearbeitete",
    "Bearbeiteteren": "Bearbeitetere",
    "Bearbeitetesten": "Bearbeiteteste",
    "Bearbeitungen": "Bearbeitung",
    "Beates": "Beate",
    "Beatmenden": "Beatmende",
    "Beatmens": "Beatmen",
    "Beatmete": "beatmet",
    "Beatmeten": "Beatmete",
    "Beaufsichtigenden": "Beaufsichtigende",
    "Beaufsichtigenderen": "Beaufsichtigendere",
    "Beaufsichtigens": "Beaufsichtigen",
    "Beaufsichtigte": "beaufsichtigt",
    "Beaufsichtigten": "Beaufsichtigte",
    "Beaufsichtigteren": "Beaufsichtigtere",
    "Beaufsichtigteste": "beaufsichtigt",
    "Beauftragenden": "Beauftragende",
    "Beauftragens": "Beauftragen",
    "Beauftragte": "beauftragt",
    "Beauftragten": "Beauftragte",
    "Bebauenden": "Bebauende",
    "Bebauens": "Bebauen",
    "Bebaute": "bebaut",
    "Bebauten": "Bebaute",
    "Bebauteren": "Bebautere",
    "Bebautesten": "Bebauteste",
    "Bebauungen": "Bebauung",
    "Bebenden": "Bebende",
    "Bebenderen": "Bebendere",
    "Bebendsten": "Bebendste",
    "Bebens": "Beben",
    "Bebildernden": "Bebildernde",
    "Bebilderns": "Bebildern",
    "Bebilderte": "bebildert",
    "Bebilderten": "Bebilderte",
    "Bebilderteren": "Bebildertere",
    "Bebildertesten": "Bebilderteste",
    "Becher": "bechern",
    "Bechern": "Becher",
    "Bechernden": "Bechernde",
    "Bechernderen": "Becherndere",
    "Becherndsten": "Becherndste",
    "Becherns": "Bechern",
    "Bechers": "Becher",
    "Becircenden": "Becircende",
    "Becircenderen": "Becircendere",
    "Becircendsten": "Becircendste",
    "Becircens": "Becircen",
    "Becircte": "becirct",
    "Becircten": "Becircte",
    "Becircteren": "Becirctere",
    "Becirctesten": "Becircteste",
    "Beckens": "Becken",
    "Beckers": "Becker",
    "Becks": "Beck",
    "Bedachte": "bedenken",
    "Bedachten": "bedenken",
    "Bedankenden": "Bedankende",
    "Bedankens": "Bedanken",
    "Bedankte": "bedankt",
    "Bedankten": "Bedankte",
    "Bedarfs": "Bedarf",
    "Bedarfsgerechte": "bedarfsgerecht",
    "Bedarfsgerechten": "Bedarfsgerechte",
    "Bedauerlichen": "Bedauerliche",
    "Bedauerlicheren": "Bedauerlichere",
    "Bedauerlichsten": "Bedauerlichste",
    "Bedauernden": "Bedauernde",
    "Bedauernderen": "Bedauerndere",
    "Bedauerndsten": "Bedauerndste",
    "Bedauerns": "Bedauern",
    "Bedauernswerte": "bedauernswert",
    "Bedauernswerten": "Bedauernswerte",
    "Bedauernswerteren": "Bedauernswertere",
    "Bedauerte": "bedauert",
    "Bedauerten": "Bedauerte",
    "Bedauerteren": "Bedauertere",
    "Bedauertesten": "Bedauerteste",
    "Bedeckenden": "Bedeckende",
    "Bedeckenderen": "Bedeckendere",
    "Bedeckendsten": "Bedeckendste",
    "Bedeckens": "Bedecken",
    "Bedeckte": "bedeckt",
    "Bedeckten": "Bedeckte",
    "Bedeckteren": "Bedecktere",
    "Bedecktesten": "Bedeckteste",
    "Bedeckungen": "Bedeckung",
    "Bedenkenden": "Bedenkende",
    "Bedenkenderen": "Bedenkendere",
    "Bedenkendsten": "Bedenkendste",
    "Bedenkenlosen": "Bedenkenlose",
    "Bedenkens": "Bedenken",
    "Bedenklichen": "Bedenkliche",
    "Bedenklicheren": "Bedenklichere",
    "Bedenklichsten": "Bedenklichste",
    "Bedenkzeiten": "Bedenkzeit",
    "Bedepperte": "bedeppert",
    "Bedepperten": "Bedepperte",
    "Bedepperteren": "Bedeppertere",
    "Bedeppertesten": "Bedepperteste",
    "Bedeutenden": "Bedeutende",
    "Bedeutenderen": "Bedeutendere",
    "Bedeutendsten": "Bedeutendste",
    "Bedeutens": "Bedeuten",
    "Bedeutete": "bedeutet",
    "Bedeuteten": "Bedeutete",
    "Bedeutsamen": "Bedeutsame",
    "Bedeutsameren": "Bedeutsamere",
    "Bedeutsamsten": "Bedeutsamste",
    "Bedeutungen": "Bedeutung",
    "Bedeutungslose": "bedeutungslos",
    "Bedeutungslosen": "Bedeutungslose",
    "Bedeutungsloseren": "Bedeutungslosere",
    "Bedeutungsvollen": "Bedeutungsvolle",
    "Bedeutungsvolleren": "Bedeutungsvollere",
    "Bedienenden": "Bedienende",
    "Bedienens": "Bedienen",
    "Bediensteten": "Bedienstete",
    "Bediente": "bedient",
    "Bedienten": "Bediente",
    "Bedienteren": "Bedientere",
    "Bedientesten": "Bedienteste",
    "Bedienungen": "Bedienung",
    "Bedingte": "bedingt",
    "Bedingten": "Bedingte",
    "Bedingtsendungen": "Bedingtsendung",
    "Bedingungen": "Bedingung",
    "Bedingungslose": "bedingungslos",
    "Bedingungslosen": "Bedingungslose",
    "Bedingungsloseren": "Bedingungslosere",
    "Bedrohenden": "Bedrohende",
    "Bedrohenderen": "Bedrohendere",
    "Bedrohendsten": "Bedrohendste",
    "Bedrohens": "Bedrohen",
    "Bedrohlichen": "Bedrohliche",
    "Bedrohlicheren": "Bedrohlichere",
    "Bedrohlichsten": "Bedrohlichste",
    "Bedrohte": "bedroht",
    "Bedrohten": "Bedrohte",
    "Bedrohteren": "Bedrohtere",
    "Bedrohtesten": "Bedrohteste",
    "Bedrohungen": "Bedrohung",
    "Bedruckenden": "Bedruckende",
    "Bedruckens": "Bedrucken",
    "Bedruckte": "bedruckt",
    "Bedruckten": "Bedruckte",
    "Bedruckteren": "Bedrucktere",
    "Bedrucktesten": "Bedruckteste",
    "Bedruckungen": "Bedruckung",
    "Bedrängenden": "Bedrängende",
    "Bedrängenderen": "Bedrängendere",
    "Bedrängendsten": "Bedrängendste",
    "Bedrängens": "Bedrängen",
    "Bedrängte": "bedrängt",
    "Bedrängten": "Bedrängte",
    "Bedrängteren": "Bedrängtere",
    "Bedrängtesten": "Bedrängteste",
    "Bedrückende": "bedrückend",
    "Bedrückenden": "Bedrückende",
    "Bedrückenderen": "Bedrückendere",
    "Bedrückendsten": "Bedrückendste",
    "Bedrückens": "Bedrücken",
    "Bedrückte": "bedrückt",
    "Bedrückten": "Bedrückte",
    "Bedrücktere": "bedrückt",
    "Bedrückteren": "Bedrücktere",
    "Bedrückteste": "bedrückt",
    "Bedrücktesten": "Bedrückteste",
    "Beduselnden": "Beduselnde",
    "Beduselnderen": "Beduselndere",
    "Beduselndsten": "Beduselndste",
    "Beduselns": "Beduseln",
    "Beduselte": "beduselt",
    "Beduselten": "Beduselte",
    "Beduselteren": "Beduseltere",
    "Beduseltesten": "Beduselteste",
    "Bedächtigen": "Bedächtige",
    "Bedächtigeren": "Bedächtigere",
    "Bedächtigsten": "Bedächtigste",
    "Bedürfnislose": "bedürfnislos",
    "Bedürfnislosen": "Bedürfnislose",
    "Bedürfnisloseren": "Bedürfnislosere",
    "Bedürfnislosesten": "Bedürfnisloseste",
    "Bedürfnisse": "Bedürfnis",
    "Bedürfnissen": "Bedürfnis",
    "Bedürfnisses": "Bedürfnis",
    "Bedürftige": "bedürftig",
    "Bedürftigen": "Bedürftige",
    "Bedürftigeren": "Bedürftigere",
    "Bedürftigsten": "Bedürftigste",
    "Beehrenden": "Beehrende",
    "Beehrens": "Beehren",
    "Beehrte": "beehrt",
    "Beehrten": "Beehrte",
    "Beeilenden": "Beeilende",
    "Beeilenderen": "Beeilendere",
    "Beeilendsten": "Beeilendste",
    "Beeilens": "Beeilen",
    "Beeilte": "beeilt",
    "Beeilten": "Beeilte",
    "Beeindruckenden": "Beeindruckende",
    "Beeindruckenderen": "Beeindruckendere",
    "Beeindruckendsten": "Beeindruckendste",
    "Beeindruckens": "Beeindrucken",
    "Beeindruckte": "beeindruckt",
    "Beeindruckten": "Beeindruckte",
    "Beeindruckteren": "Beeindrucktere",
    "Beeindrucktesten": "Beeindruckteste",
    "Beeinflussenden": "Beeinflussende",
    "Beeinflussens": "Beeinflussen",
    "Beeinflussungen": "Beeinflussung",
    "Beeinflußte": "beeinflußt",
    "Beeinflußten": "Beeinflußte",
    "Beeinflußteren": "Beeinflußtere",
    "Beeinflußtesten": "Beeinflußteste",
    "Beeinträchtigenden": "Beeinträchtigende",
    "Beeinträchtigenderen": "Beeinträchtigendere",
    "Beeinträchtigens": "Beeinträchtigen",
    "Beeinträchtigte": "beeinträchtigt",
    "Beeinträchtigten": "Beeinträchtigte",
    "Beeinträchtigteren": "Beeinträchtigtere",
    "Beeinträchtigungen": "Beeinträchtigung",
    "Beendenden": "Beendende",
    "Beendens": "Beenden",
    "Beendete": "beendet",
    "Beendeten": "Beendete",
    "Beendigungen": "Beendigung",
    "Beerbenden": "Beerbende",
    "Beerbens": "Beerben",
    "Beerbte": "beerbt",
    "Beerbten": "Beerbte",
    "Beerdigenden": "Beerdigende",
    "Beerdigens": "Beerdigen",
    "Beerdigte": "beerdigt",
    "Beerdigten": "Beerdigte",
    "Beerdigungen": "Beerdigung",
    "Beeren": "Beere",
    "Beete": "Beet",
    "Beeten": "Beete",
    "Beetes": "Beet",
    "Beethovens": "Beethoven",
    "Beets": "Beet",
    "Befahrbaren": "Befahrbare",
    "Befahrbareren": "Befahrbarere",
    "Befahrbarsten": "Befahrbarste",
    "Befahrenden": "Befahrende",
    "Befahrenen": "Befahrene",
    "Befahreneren": "Befahrenere",
    "Befahrens": "Befahren",
    "Befahrenste": "befahren",
    "Befahrensten": "Befahrenste",
    "Befallenden": "Befallende",
    "Befallenen": "Befallene",
    "Befalleneren": "Befallenere",
    "Befallens": "Befallen",
    "Befallenste": "befallen",
    "Befallensten": "Befallenste",
    "Befangenen": "Befangene",
    "Befangeneren": "Befangenere",
    "Befangensten": "Befangenste",
    "Befassenden": "Befassende",
    "Befassens": "Befassen",
    "Befaßte": "befaßt",
    "Befaßten": "Befaßte",
    "Befehle": "befehlen",
    "Befehlen": "Befehl",
    "Befehlenden": "Befehlende",
    "Befehlenderen": "Befehlendere",
    "Befehlendsten": "Befehlendste",
    "Befehlens": "Befehlen",
    "Befehligenden": "Befehligende",
    "Befehligens": "Befehligen",
    "Befehligte": "befehligt",
    "Befehligten": "Befehligte",
    "Befehls": "Befehl",
    "Befestigenden": "Befestigende",
    "Befestigenderen": "Befestigendere",
    "Befestigendsten": "Befestigendste",
    "Befestigens": "Befestigen",
    "Befestigte": "befestigt",
    "Befestigten": "Befestigte",
    "Befestigteren": "Befestigtere",
    "Befestigtesten": "Befestigteste",
    "Befestigungen": "Befestigung",
    "Befeuchtenden": "Befeuchtende",
    "Befeuchtenderen": "Befeuchtendere",
    "Befeuchtendsten": "Befeuchtendste",
    "Befeuchtens": "Befeuchten",
    "Befeuchtete": "befeuchtet",
    "Befeuchteten": "Befeuchtete",
    "Befeuchteteren": "Befeuchtetere",
    "Befeuchtetesten": "Befeuchteteste",
    "Befeuernden": "Befeuernde",
    "Befeuernderen": "Befeuerndere",
    "Befeuerndsten": "Befeuerndste",
    "Befeuerns": "Befeuern",
    "Befeuerte": "befeuert",
    "Befeuerten": "Befeuerte",
    "Befeuerteren": "Befeuertere",
    "Befeuertesten": "Befeuerteste",
    "Befindenden": "Befindende",
    "Befindens": "Befinden",
    "Befindlichkeiten": "Befindlichkeit",
    "Beflaggenden": "Beflaggende",
    "Beflaggenderen": "Beflaggendere",
    "Beflaggendsten": "Beflaggendste",
    "Beflaggens": "Beflaggen",
    "Beflaggte": "beflaggt",
    "Beflaggten": "Beflaggte",
    "Beflaggteren": "Beflaggtere",
    "Beflaggtesten": "Beflaggteste",
    "Beflaggungen": "Beflaggung",
    "Befleckenden": "Befleckende",
    "Befleckens": "Beflecken",
    "Befleckte": "befleckt",
    "Befleckten": "Befleckte",
    "Befleckteren": "Beflecktere",
    "Beflecktesten": "Befleckteste",
    "Befleißenden": "Befleißende",
    "Befleißenderen": "Befleißendere",
    "Befleißendsten": "Befleißendste",
    "Befleißens": "Befleißen",
    "Beflissenen": "Beflissene",
    "Beflisseneren": "Beflissenere",
    "Beflissensten": "Beflissenste",
    "Beflügelnden": "Beflügelnde",
    "Beflügelns": "Beflügeln",
    "Beflügelte": "beflügelt",
    "Beflügelten": "Beflügelte",
    "Befohlenen": "Befohlene",
    "Befolgenden": "Befolgende",
    "Befolgenderen": "Befolgendere",
    "Befolgendsten": "Befolgendste",
    "Befolgens": "Befolgen",
    "Befolgte": "befolgt",
    "Befolgten": "Befolgte",
    "Befolgteren": "Befolgtere",
    "Befolgtesten": "Befolgteste",
    "Befragenden": "Befragende",
    "Befragens": "Befragen",
    "Befragte": "befragt",
    "Befragten": "Befragte",
    "Befragteren": "Befragtere",
    "Befragtesten": "Befragteste",
    "Befragungen": "Befragung",
    "Befreienden": "Befreiende",
    "Befreiens": "Befreien",
    "Befreiern": "Befreier",
    "Befreiers": "Befreier",
    "Befreite": "befreit",
    "Befreiten": "Befreite",
    "Befreiungen": "Befreiung",
    "Befremdenden": "Befremdende",
    "Befremdenderen": "Befremdendere",
    "Befremdendsten": "Befremdendste",
    "Befremdens": "Befremden",
    "Befremdete": "befremdet",
    "Befremdeten": "Befremdete",
    "Befreundeten": "Befreundete",
    "Befriedigenden": "Befriedigende",
    "Befriedigenderen": "Befriedigendere",
    "Befriedigendsten": "Befriedigendste",
    "Befriedigens": "Befriedigen",
    "Befriedigte": "befriedigt",
    "Befriedigten": "Befriedigte",
    "Befriedigteren": "Befriedigtere",
    "Befriedigtesten": "Befriedigteste",
    "Befriedigungen": "Befriedigung",
    "Befristenden": "Befristende",
    "Befristens": "Befristen",
    "Befristete": "befristet",
    "Befristeten": "Befristete",
    "Befristungen": "Befristung",
    "Befruchtenden": "Befruchtende",
    "Befruchtenderen": "Befruchtendere",
    "Befruchtendsten": "Befruchtendste",
    "Befruchtens": "Befruchten",
    "Befruchtete": "befruchtet",
    "Befruchteten": "Befruchtete",
    "Befruchteteren": "Befruchtetere",
    "Befruchtetesten": "Befruchteteste",
    "Befruchtungen": "Befruchtung",
    "Befugnisse": "Befugnis",
    "Befugnissen": "Befugnis",
    "Befummelnden": "Befummelnde",
    "Befummelnderen": "Befummelndere",
    "Befummelndsten": "Befummelndste",
    "Befummelns": "Befummeln",
    "Befummelte": "befummelt",
    "Befummelten": "Befummelte",
    "Befummelteren": "Befummeltere",
    "Befummeltesten": "Befummelteste",
    "Befunde": "Befund",
    "Befunden": "Befund",
    "Befundene": "befunden",
    "Befundenen": "Befundene",
    "Befundes": "Befund",
    "Befunds": "Befund",
    "Befähigenden": "Befähigende",
    "Befähigens": "Befähigen",
    "Befähigte": "befähigt",
    "Befähigten": "Befähigte",
    "Befähigungen": "Befähigung",
    "Befördernden": "Befördernde",
    "Beförderns": "Befördern",
    "Beförderte": "befördert",
    "Beförderten": "Beförderte",
    "Beförderungen": "Beförderung",
    "Befürchtenden": "Befürchtende",
    "Befürchtens": "Befürchten",
    "Befürchtete": "befürchtet",
    "Befürchteten": "Befürchtete",
    "Befürchtungen": "Befürchtung",
    "Befürsorgenden": "Befürsorgende",
    "Befürsorgenderen": "Befürsorgendere",
    "Befürsorgendsten": "Befürsorgendste",
    "Befürsorgens": "Befürsorgen",
    "Befürsorgte": "befürsorgt",
    "Befürsorgten": "Befürsorgte",
    "Befürsorgteren": "Befürsorgtere",
    "Befürsorgtesten": "Befürsorgteste",
    "Befürwortenden": "Befürwortende",
    "Befürwortens": "Befürworten",
    "Befürwortern": "Befürworter",
    "Befürworters": "Befürworter",
    "Befürwortete": "befürwortet",
    "Befürworteten": "Befürwortete",
    "Befürwortungen": "Befürwortung",
    "Begabungen": "Begabung",
    "Begaffenden": "Begaffende",
    "Begaffenderen": "Begaffendere",
    "Begaffendsten": "Begaffendste",
    "Begaffens": "Begaffen",
    "Begaffte": "begafft",
    "Begafften": "Begaffte",
    "Begaffteren": "Begafftere",
    "Begafftesten": "Begaffteste",
    "Begangenen": "Begangene",
    "Begattenden": "Begattende",
    "Begattens": "Begatten",
    "Begattete": "begattet",
    "Begatteten": "Begattete",
    "Begattungen": "Begattung",
    "Begebenden": "Begebende",
    "Begebenen": "Begebene",
    "Begebenheiten": "Begebenheit",
    "Begebens": "Begeben",
    "Begebungen": "Begebung",
    "Begegnenden": "Begegnende",
    "Begegnens": "Begegnen",
    "Begegnete": "begegnet",
    "Begegneten": "Begegnete",
    "Begegnungen": "Begegnung",
    "Begehbare": "begehbar",
    "Begehbaren": "Begehbare",
    "Begehbareren": "Begehbarere",
    "Begehbarsten": "Begehbarste",
    "Begehenden": "Begehende",
    "Begehens": "Begehen",
    "Begehr": "begehren",
    "Begehre": "begehren",
    "Begehren": "Begehr",
    "Begehrenden": "Begehrende",
    "Begehrenderen": "Begehrendere",
    "Begehrendsten": "Begehrendste",
    "Begehrens": "Begehren",
    "Begehrenswerte": "begehrenswert",
    "Begehrenswerten": "Begehrenswerte",
    "Begehrenswerteren": "Begehrenswertere",
    "Begehres": "Begehr",
    "Begehrs": "Begehr",
    "Begehrte": "begehrt",
    "Begehrten": "Begehrte",
    "Begehrteren": "Begehrtere",
    "Begehrtesten": "Begehrteste",
    "Begeisternden": "Begeisternde",
    "Begeisternderen": "Begeisterndere",
    "Begeisterndsten": "Begeisterndste",
    "Begeisterns": "Begeistern",
    "Begeisterte": "begeistert",
    "Begeisterten": "Begeisterte",
    "Begeisterteren": "Begeistertere",
    "Begeistertesten": "Begeisterteste",
    "Begeisterungen": "Begeisterung",
    "Begierdelosen": "Begierdelose",
    "Begierdeloseren": "Begierdelosere",
    "Begierdelosesten": "Begierdeloseste",
    "Begierigen": "Begierige",
    "Begierigeren": "Begierigere",
    "Begierigsten": "Begierigste",
    "Begießenden": "Begießende",
    "Begießens": "Begießen",
    "Beginn": "beginnen",
    "Beginnenden": "Beginnende",
    "Beginnens": "Beginnen",
    "Beginns": "Beginn",
    "Beglaubigenden": "Beglaubigende",
    "Beglaubigens": "Beglaubigen",
    "Beglaubigte": "beglaubigt",
    "Beglaubigten": "Beglaubigte",
    "Beglaubigungen": "Beglaubigung",
    "Begleichenden": "Begleichende",
    "Begleichens": "Begleichen",
    "Begleitbriefe": "Begleitbrief",
    "Begleitbriefen": "Begleitbrief",
    "Begleitbriefs": "Begleitbrief",
    "Begleitenden": "Begleitende",
    "Begleitens": "Begleiten",
    "Begleitern": "Begleiter",
    "Begleiters": "Begleiter",
    "Begleiterscheinungen": "Begleiterscheinung",
    "Begleitete": "begleitet",
    "Begleiteten": "Begleitete",
    "Begleitmusiken": "Begleitmusik",
    "Begleitpersonen": "Begleitperson",
    "Begleitschreibens": "Begleitschreiben",
    "Begleitstimmen": "Begleitstimme",
    "Begleitungen": "Begleitung",
    "Beglichenen": "Beglichene",
    "Beglotzenden": "Beglotzende",
    "Beglotzenderen": "Beglotzendere",
    "Beglotzendsten": "Beglotzendste",
    "Beglotzens": "Beglotzen",
    "Beglotzte": "beglotzt",
    "Beglotzten": "Beglotzte",
    "Beglotzteren": "Beglotztere",
    "Beglotztesten": "Beglotzteste",
    "Beglupschenden": "Beglupschende",
    "Beglupschenderen": "Beglupschendere",
    "Beglupschendsten": "Beglupschendste",
    "Beglupschens": "Beglupschen",
    "Beglupschte": "beglupscht",
    "Beglupschten": "Beglupschte",
    "Beglupschteren": "Beglupschtere",
    "Beglupschtesten": "Beglupschteste",
    "Beglückenden": "Beglückende",
    "Beglückenderen": "Beglückendere",
    "Beglückendsten": "Beglückendste",
    "Beglückens": "Beglücken",
    "Beglückte": "beglückt",
    "Beglückten": "Beglückte",
    "Beglückteren": "Beglücktere",
    "Beglücktesten": "Beglückteste",
    "Beglückwünschenden": "Beglückwünschende",
    "Beglückwünschens": "Beglückwünschen",
    "Beglückwünschte": "beglückwünscht",
    "Beglückwünschten": "Beglückwünschte",
    "Begnadigenden": "Begnadigende",
    "Begnadigens": "Begnadigen",
    "Begnadigte": "begnadigt",
    "Begnadigten": "Begnadigte",
    "Begnadigungen": "Begnadigung",
    "Begnügenden": "Begnügende",
    "Begnügens": "Begnügen",
    "Begnügte": "begnügt",
    "Begnügten": "Begnügte",
    "Begonien": "Begonie",
    "Begonnenen": "Begonnene",
    "Begossenen": "Begossene",
    "Begosseneren": "Begossenere",
    "Begossensten": "Begossenste",
    "Begrabenden": "Begrabende",
    "Begrabenen": "Begrabene",
    "Begrabens": "Begraben",
    "Begrabschenden": "Begrabschende",
    "Begrabschenderen": "Begrabschendere",
    "Begrabschendsten": "Begrabschendste",
    "Begrabschens": "Begrabschen",
    "Begrabschte": "begrabscht",
    "Begrabschten": "Begrabschte",
    "Begrabschteren": "Begrabschtere",
    "Begrabschtesten": "Begrabschteste",
    "Begradigenden": "Begradigende",
    "Begradigens": "Begradigen",
    "Begradigte": "begradigt",
    "Begradigten": "Begradigte",
    "Begradigungen": "Begradigung",
    "Begreifenden": "Begreifende",
    "Begreifens": "Begreifen",
    "Begreiflichen": "Begreifliche",
    "Begrenzenden": "Begrenzende",
    "Begrenzens": "Begrenzen",
    "Begrenzern": "Begrenzer",
    "Begrenzers": "Begrenzer",
    "Begrenzte": "begrenzt",
    "Begrenzten": "Begrenzte",
    "Begrenzungen": "Begrenzung",
    "Begriff": "begreifen",
    "Begriffe": "Begriff",
    "Begriffen": "Begriff",
    "Begriffene": "begriffen",
    "Begriffenen": "Begriffene",
    "Begriffeneren": "Begriffenere",
    "Begriffensten": "Begriffenste",
    "Begriffes": "Begriff",
    "Begrifflichen": "Begriffliche",
    "Begriffs": "Begriff",
    "Begräbnisse": "Begräbnis",
    "Begräbnissen": "Begräbnis",
    "Begräbnisses": "Begräbnis",
    "Begräbnisstätten": "Begräbnisstätte",
    "Begründenden": "Begründende",
    "Begründens": "Begründen",
    "Begründete": "begründet",
    "Begründeten": "Begründete",
    "Begründeteren": "Begründetere",
    "Begründetesten": "Begründeteste",
    "Begründungen": "Begründung",
    "Begrünenden": "Begrünende",
    "Begrünenderen": "Begrünendere",
    "Begrünendsten": "Begrünendste",
    "Begrünens": "Begrünen",
    "Begrünte": "begrünt",
    "Begrünten": "Begrünte",
    "Begrünteren": "Begrüntere",
    "Begrüntesten": "Begrünteste",
    "Begrünungen": "Begrünung",
    "Begrüßenden": "Begrüßende",
    "Begrüßens": "Begrüßen",
    "Begrüßenswerte": "begrüßenswert",
    "Begrüßenswerten": "Begrüßenswerte",
    "Begrüßenswerteren": "Begrüßenswertere",
    "Begrüßte": "begrüßt",
    "Begrüßten": "Begrüßte",
    "Begrüßungen": "Begrüßung",
    "Beguckenden": "Beguckende",
    "Beguckens": "Begucken",
    "Beguckte": "beguckt",
    "Beguckten": "Beguckte",
    "Beguckteren": "Begucktere",
    "Begucktesten": "Beguckteste",
    "Begutachtenden": "Begutachtende",
    "Begutachtens": "Begutachten",
    "Begutachtete": "begutachtet",
    "Begutachteten": "Begutachtete",
    "Begutachtungen": "Begutachtung",
    "Begünstigenden": "Begünstigende",
    "Begünstigenderen": "Begünstigendere",
    "Begünstigendsten": "Begünstigendste",
    "Begünstigens": "Begünstigen",
    "Begünstigte": "begünstigt",
    "Begünstigten": "Begünstigte",
    "Begünstigteren": "Begünstigtere",
    "Begünstigtesten": "Begünstigteste",
    "Begünstigungen": "Begünstigung",
    "Begüternden": "Begüternde",
    "Begüterns": "Begütern",
    "Begüterte": "begütert",
    "Begüterten": "Begüterte",
    "Begüterteren": "Begütertere",
    "Begütertesten": "Begüterteste",
    "Behaarten": "Behaarte",
    "Behaarteren": "Behaartere",
    "Behaartesten": "Behaarteste",
    "Behaftenden": "Behaftende",
    "Behaftens": "Behaften",
    "Behaftete": "behaftet",
    "Behafteten": "Behaftete",
    "Behagenden": "Behagende",
    "Behagenderen": "Behagendere",
    "Behagendsten": "Behagendste",
    "Behagens": "Behagen",
    "Behaglichen": "Behagliche",
    "Behaglicheren": "Behaglichere",
    "Behaglichsten": "Behaglichste",
    "Behagte": "behagt",
    "Behagten": "Behagte",
    "Behaltenden": "Behaltende",
    "Behaltenen": "Behaltene",
    "Behaltens": "Behalten",
    "Behandelnden": "Behandelnde",
    "Behandelns": "Behandeln",
    "Behandelte": "behandelt",
    "Behandelten": "Behandelte",
    "Behandlungen": "Behandlung",
    "Behange": "Behang",
    "Behangs": "Behang",
    "Beharrenden": "Beharrende",
    "Beharrens": "Beharren",
    "Beharrlichen": "Beharrliche",
    "Beharrlicheren": "Beharrlichere",
    "Beharrlichsten": "Beharrlichste",
    "Beharrte": "beharrt",
    "Beharrten": "Beharrte",
    "Beharrungen": "Beharrung",
    "Behauenden": "Behauende",
    "Behauenderen": "Behauendere",
    "Behauendsten": "Behauendste",
    "Behauenen": "Behauene",
    "Behaueneren": "Behauenere",
    "Behauens": "Behauen",
    "Behauenste": "behauen",
    "Behauensten": "Behauenste",
    "Behauptenden": "Behauptende",
    "Behauptens": "Behaupten",
    "Behauptete": "behauptet",
    "Behaupteten": "Behauptete",
    "Behauptungen": "Behauptung",
    "Behausenden": "Behausende",
    "Behausens": "Behausen",
    "Behauste": "behaust",
    "Behausten": "Behauste",
    "Behebenden": "Behebende",
    "Behebens": "Beheben",
    "Behebungen": "Behebung",
    "Beheimatete": "beheimatet",
    "Beheimateten": "Beheimatete",
    "Beheimateteren": "Beheimatetere",
    "Beheimatetesten": "Beheimateteste",
    "Beheizbaren": "Beheizbare",
    "Beheizenden": "Beheizende",
    "Beheizenderen": "Beheizendere",
    "Beheizendsten": "Beheizendste",
    "Beheizens": "Beheizen",
    "Beheizte": "beheizt",
    "Beheizten": "Beheizte",
    "Beheizteren": "Beheiztere",
    "Beheiztesten": "Beheizteste",
    "Behelfe": "behelfen",
    "Behelfen": "Behelf",
    "Behelfenden": "Behelfende",
    "Behelfens": "Behelfen",
    "Behelfs": "Behelf",
    "Behelfsmäßige": "behelfsmäßig",
    "Behelfsmäßigen": "Behelfsmäßige",
    "Behelligenden": "Behelligende",
    "Behelligens": "Behelligen",
    "Behelligte": "behelligt",
    "Behelligten": "Behelligte",
    "Behelligungen": "Behelligung",
    "Beherbergenden": "Beherbergende",
    "Beherbergens": "Beherbergen",
    "Beherbergte": "beherbergt",
    "Beherbergten": "Beherbergte",
    "Beherrschbaren": "Beherrschbare",
    "Beherrschbareren": "Beherrschbarere",
    "Beherrschbarsten": "Beherrschbarste",
    "Beherrschenden": "Beherrschende",
    "Beherrschenderen": "Beherrschendere",
    "Beherrschendsten": "Beherrschendste",
    "Beherrschens": "Beherrschen",
    "Beherrschern": "Beherrscher",
    "Beherrschers": "Beherrscher",
    "Beherrschte": "beherrscht",
    "Beherrschten": "Beherrschte",
    "Beherrschteren": "Beherrschtere",
    "Beherrschtesten": "Beherrschteste",
    "Beherzigenden": "Beherzigende",
    "Beherzigens": "Beherzigen",
    "Beherzigte": "beherzigt",
    "Beherzigten": "Beherzigte",
    "Beherzten": "Beherzte",
    "Beherzteren": "Beherztere",
    "Beherztesten": "Beherzteste",
    "Behilflichen": "Behilfliche",
    "Behindernden": "Behindernde",
    "Behinderns": "Behindern",
    "Behinderte": "behindert",
    "Behinderten": "Behinderte",
    "Behinderteren": "Behindertere",
    "Behindertesten": "Behinderteste",
    "Behinderungen": "Behinderung",
    "Behobenen": "Behobene",
    "Beholfenen": "Beholfene",
    "Beholfeneren": "Beholfenere",
    "Beholfensten": "Beholfenste",
    "Behutsamen": "Behutsame",
    "Behutsameren": "Behutsamere",
    "Behutsamsten": "Behutsamste",
    "Behäbigen": "Behäbige",
    "Behäbigeren": "Behäbigere",
    "Behäbigsten": "Behäbigste",
    "Behältern": "Behälter",
    "Behälters": "Behälter",
    "Behämmerten": "Behämmerte",
    "Behämmerteren": "Behämmertere",
    "Behämmertesten": "Behämmerteste",
    "Behänge": "behängen",
    "Behängen": "Behang",
    "Behängenden": "Behängende",
    "Behängens": "Behängen",
    "Behängte": "behängt",
    "Behängten": "Behängte",
    "Behörden": "Behörde",
    "Behütenden": "Behütende",
    "Behütenderen": "Behütendere",
    "Behütendsten": "Behütendste",
    "Behütens": "Behüten",
    "Behütete": "behütet",
    "Behüteten": "Behütete",
    "Behüteteren": "Behütetere",
    "Behütetesten": "Behüteteste",
    "Beibehaltenden": "Beibehaltende",
    "Beibehaltenen": "Beibehaltene",
    "Beibehaltens": "Beibehalten",
    "Beibiegenden": "Beibiegende",
    "Beibiegens": "Beibiegen",
    "Beiblatte": "Beiblatt",
    "Beiblattes": "Beiblatt",
    "Beiblatts": "Beiblatt",
    "Beiblätter": "Beiblatt",
    "Beiblättern": "Beiblatt",
    "Beibringenden": "Beibringende",
    "Beibringens": "Beibringen",
    "Beichten": "Beichte",
    "Beichtenden": "Beichtende",
    "Beichtenderen": "Beichtendere",
    "Beichtendsten": "Beichtendste",
    "Beichtens": "Beichten",
    "Beichtvaters": "Beichtvater",
    "Beichtväter": "Beichtvater",
    "Beichtvätern": "Beichtvater",
    "Beiderseitigen": "Beiderseitige",
    "Beidhändern": "Beidhänder",
    "Beidhänders": "Beidhänder",
    "Beidhändige": "beidhändig",
    "Beidhändigen": "Beidhändige",
    "Beidrehenden": "Beidrehende",
    "Beidrehens": "Beidrehen",
    "Beidseitigen": "Beidseitige",
    "Beifahrern": "Beifahrer",
    "Beifahrers": "Beifahrer",
    "Beifalls": "Beifall",
    "Beifolgenden": "Beifolgende",
    "Beifolgens": "Beifolgen",
    "Beifutters": "Beifutter",
    "Beifügenden": "Beifügende",
    "Beifügens": "Beifügen",
    "Beigaben": "beigeben",
    "Beigebenden": "Beigebende",
    "Beigebens": "Beigeben",
    "Beigebogenen": "Beigebogene",
    "Beigebrachten": "Beigebrachte",
    "Beigedrehten": "Beigedrehte",
    "Beigefolgten": "Beigefolgte",
    "Beigefügten": "Beigefügte",
    "Beigegebenen": "Beigegebene",
    "Beigeholten": "Beigeholte",
    "Beigekommenen": "Beigekommene",
    "Beigeladenen": "Beigeladene",
    "Beigelegenen": "Beigelegene",
    "Beigelegten": "Beigelegte",
    "Beigemengten": "Beigemengte",
    "Beigemessenen": "Beigemessene",
    "Beigemischten": "Beigemischte",
    "Beigeordneten": "Beigeordnete",
    "Beigepflichteten": "Beigepflichtete",
    "Beigeschaffenen": "Beigeschaffene",
    "Beigeschafften": "Beigeschaffte",
    "Beigeschmacke": "Beigeschmack",
    "Beigeschmackes": "Beigeschmack",
    "Beigeschmacks": "Beigeschmack",
    "Beigeschmäcker": "Beigeschmack",
    "Beigeschmäckern": "Beigeschmack",
    "Beigesellenden": "Beigesellende",
    "Beigesellens": "Beigesellen",
    "Beigesellte": "beigesellt",
    "Beigesellten": "Beigesellte",
    "Beigesessenen": "Beigesessene",
    "Beigesetzten": "Beigesetzte",
    "Beigesprungenen": "Beigesprungene",
    "Beigestandenen": "Beigestandene",
    "Beigestimmten": "Beigestimmte",
    "Beigetragenen": "Beigetragene",
    "Beigetretenen": "Beigetretene",
    "Beigewohnten": "Beigewohnte",
    "Beihefte": "Beiheft",
    "Beiheften": "Beiheft",
    "Beihefts": "Beiheft",
    "Beihilfen": "Beihilfe",
    "Beiholenden": "Beiholende",
    "Beiholens": "Beiholen",
    "Beiklange": "Beiklang",
    "Beiklangs": "Beiklang",
    "Beiklänge": "Beiklang",
    "Beiklängen": "Beiklang",
    "Beikommenden": "Beikommende",
    "Beikommens": "Beikommen",
    "Beiköchinnen": "Beiköchin",
    "Beiladenden": "Beiladende",
    "Beiladens": "Beiladen",
    "Beilagen": "beiliegen",
    "Beile": "Beil",
    "Beilegenden": "Beilegende",
    "Beilegens": "Beilegen",
    "Beilegungen": "Beilegung",
    "Beileide": "Beileid",
    "Beileides": "Beileid",
    "Beileids": "Beileid",
    "Beileidskarten": "Beileidskarte",
    "Beilen": "Beil",
    "Beiles": "Beil",
    "Beiliegenden": "Beiliegende",
    "Beiliegens": "Beiliegen",
    "Beils": "Beil",
    "Beiläufigen": "Beiläufige",
    "Beimengenden": "Beimengende",
    "Beimengens": "Beimengen",
    "Beimessenden": "Beimessende",
    "Beimessens": "Beimessen",
    "Beimischenden": "Beimischende",
    "Beimischens": "Beimischen",
    "Beinamen": "Beiname",
    "Beinbruche": "Beinbruch",
    "Beinbruches": "Beinbruch",
    "Beinbruchs": "Beinbruch",
    "Beinbrüche": "Beinbruch",
    "Beinbrüchen": "Beinbruch",
    "Beine": "Bein",
    "Beinen": "Bein",
    "Beines": "Bein",
    "Beinhaltenden": "Beinhaltende",
    "Beinhaltens": "Beinhalten",
    "Beinhaltete": "beinhaltet",
    "Beinhalteten": "Beinhaltete",
    "Beinhaltungen": "Beinhaltung",
    "Beinharte": "beinhart",
    "Beinharten": "Beinharte",
    "Beinhärteren": "Beinhärtere",
    "Beinhärtesten": "Beinhärteste",
    "Beins": "Bein",
    "Beinschienen": "Beinschiene",
    "Beiordnenden": "Beiordnende",
    "Beiordnens": "Beiordnen",
    "Beipflichtenden": "Beipflichtende",
    "Beipflichtens": "Beipflichten",
    "Beiprogramme": "Beiprogramm",
    "Beiprogrammen": "Beiprogramm",
    "Beiprogramms": "Beiprogramm",
    "Beirate": "Beirat",
    "Beirates": "Beirat",
    "Beirats": "Beirat",
    "Beirrenden": "Beirrende",
    "Beirrens": "Beirren",
    "Beirrte": "beirrt",
    "Beirrten": "Beirrte",
    "Beiruts": "Beirut",
    "Beiräte": "Beirat",
    "Beiräten": "Beirat",
    "Beisammenseins": "Beisammensein",
    "Beischaffenden": "Beischaffende",
    "Beischaffens": "Beischaffen",
    "Beischlafe": "Beischlaf",
    "Beischlafes": "Beischlaf",
    "Beischlafs": "Beischlaf",
    "Beischläferinnen": "Beischläferin",
    "Beisegeln": "Beisegel",
    "Beisegels": "Beisegel",
    "Beiseins": "Beisein",
    "Beisetzenden": "Beisetzende",
    "Beisetzens": "Beisetzen",
    "Beisetzungen": "Beisetzung",
    "Beisitzenden": "Beisitzende",
    "Beisitzens": "Beisitzen",
    "Beisitzern": "Beisitzer",
    "Beisitzers": "Beisitzer",
    "Beispiele": "Beispiel",
    "Beispielen": "Beispiel",
    "Beispieles": "Beispiel",
    "Beispielhafte": "beispielhaft",
    "Beispielhaften": "Beispielhafte",
    "Beispielhafteren": "Beispielhaftere",
    "Beispielhaftesten": "Beispielhafteste",
    "Beispiellosen": "Beispiellose",
    "Beispielloseren": "Beispiellosere",
    "Beispiellosesten": "Beispielloseste",
    "Beispiels": "Beispiel",
    "Beispringenden": "Beispringende",
    "Beispringens": "Beispringen",
    "Beistands": "Beistand",
    "Beistehenden": "Beistehende",
    "Beistehens": "Beistehen",
    "Beisteuern": "Beisteuer",
    "Beisteuernde": "beisteuernd",
    "Beisteuernden": "Beisteuernde",
    "Beisteuerns": "Beisteuern",
    "Beisteuerte": "beisteuert",
    "Beisteuerten": "Beisteuerte",
    "Beistimmenden": "Beistimmende",
    "Beistimmens": "Beistimmen",
    "Beistriche": "Beistrich",
    "Beistrichen": "Beistrich",
    "Beistrichs": "Beistrich",
    "Beitrage": "beitragen",
    "Beitragenden": "Beitragende",
    "Beitragenderen": "Beitragendere",
    "Beitragendsten": "Beitragendste",
    "Beitragens": "Beitragen",
    "Beitrages": "Beitrag",
    "Beitrags": "Beitrag",
    "Beitragspflichtige": "beitragspflichtig",
    "Beitragspflichtigen": "Beitragspflichtige",
    "Beitretenden": "Beitretende",
    "Beitretens": "Beitreten",
    "Beitritte": "Beitritt",
    "Beitritten": "Beitritt",
    "Beitrittes": "Beitritt",
    "Beitritts": "Beitritt",
    "Beiträge": "Beitrag",
    "Beiträgen": "Beitrag",
    "Beiträgern": "Beiträger",
    "Beiträgers": "Beiträger",
    "Beiwohnenden": "Beiwohnende",
    "Beiwohnens": "Beiwohnen",
    "Beiworte": "Beiwort",
    "Beiwortes": "Beiwort",
    "Beiworts": "Beiwort",
    "Beiwörter": "Beiwort",
    "Beiwörtern": "Beiwort",
    "Beize": "beizen",
    "Beizen": "Beize",
    "Beizenden": "Beizende",
    "Beizens": "Beizen",
    "Beizmitteln": "Beizmittel",
    "Beizmittels": "Beizmittel",
    "Beißenden": "Beißende",
    "Beißens": "Beißen",
    "Beißerchens": "Beißerchen",
    "Bejahenden": "Bejahende",
    "Bejahens": "Bejahen",
    "Bejahte": "bejaht",
    "Bejahten": "Bejahte",
    "Bejahungen": "Bejahung",
    "Bejammernswerte": "bejammernswert",
    "Bejammernswerten": "Bejammernswerte",
    "Bejammernswerteren": "Bejammernswertere",
    "Bejubelnden": "Bejubelnde",
    "Bejubelnderen": "Bejubelndere",
    "Bejubelndsten": "Bejubelndste",
    "Bejubelns": "Bejubeln",
    "Bejubelte": "bejubelt",
    "Bejubelten": "Bejubelte",
    "Bejubelteren": "Bejubeltere",
    "Bejubeltesten": "Bejubelteste",
    "Bekakelnden": "Bekakelnde",
    "Bekakelnderen": "Bekakelndere",
    "Bekakelndsten": "Bekakelndste",
    "Bekakelns": "Bekakeln",
    "Bekakelte": "bekakelt",
    "Bekakelten": "Bekakelte",
    "Bekakelteren": "Bekakeltere",
    "Bekakeltesten": "Bekakelteste",
    "Bekannte": "bekennen",
    "Bekannten": "bekennen",
    "Bekannteren": "Bekanntere",
    "Bekanntesten": "Bekannteste",
    "Bekanntgebenden": "Bekanntgebende",
    "Bekanntgebens": "Bekanntgeben",
    "Bekanntgegebenen": "Bekanntgegebene",
    "Bekanntmachungen": "Bekanntmachung",
    "Bekanntschaften": "Bekanntschaft",
    "Bekehrenden": "Bekehrende",
    "Bekehrenderen": "Bekehrendere",
    "Bekehrendsten": "Bekehrendste",
    "Bekehrens": "Bekehren",
    "Bekehrern": "Bekehrer",
    "Bekehrers": "Bekehrer",
    "Bekehrte": "bekehrt",
    "Bekehrten": "Bekehrte",
    "Bekehrteren": "Bekehrtere",
    "Bekehrtesten": "Bekehrteste",
    "Bekehrungen": "Bekehrung",
    "Bekennenden": "Bekennende",
    "Bekennens": "Bekennen",
    "Bekenntnisse": "Bekenntnis",
    "Bekenntnissen": "Bekenntnis",
    "Bekenntnisses": "Bekenntnis",
    "Beklage": "beklagen",
    "Beklagenden": "Beklagende",
    "Beklagenderen": "Beklagendere",
    "Beklagendsten": "Beklagendste",
    "Beklagens": "Beklagen",
    "Beklagenswerte": "beklagenswert",
    "Beklagenswerten": "Beklagenswerte",
    "Beklagenswerteren": "Beklagenswertere",
    "Beklagenswürdigen": "Beklagenswürdige",
    "Beklagenswürdigeren": "Beklagenswürdigere",
    "Beklagte": "beklagt",
    "Beklagten": "Beklagte",
    "Beklagteren": "Beklagtere",
    "Beklagtesten": "Beklagteste",
    "Beklatschenden": "Beklatschende",
    "Beklatschenderen": "Beklatschendere",
    "Beklatschendsten": "Beklatschendste",
    "Beklatschens": "Beklatschen",
    "Beklatschte": "beklatscht",
    "Beklatschten": "Beklatschte",
    "Beklatschteren": "Beklatschtere",
    "Beklatschtesten": "Beklatschteste",
    "Beklauenden": "Beklauende",
    "Beklauenderen": "Beklauendere",
    "Beklauendsten": "Beklauendste",
    "Beklauens": "Beklauen",
    "Beklaute": "beklaut",
    "Beklauten": "Beklaute",
    "Beklebenden": "Beklebende",
    "Beklebenderen": "Beklebendere",
    "Beklebendsten": "Beklebendste",
    "Beklebens": "Bekleben",
    "Beklebte": "beklebt",
    "Beklebten": "Beklebte",
    "Beklebteren": "Beklebtere",
    "Beklebtesten": "Beklebteste",
    "Bekleckernden": "Bekleckernde",
    "Bekleckernderen": "Bekleckerndere",
    "Bekleckerndsten": "Bekleckerndste",
    "Bekleckerns": "Bekleckern",
    "Bekleckerte": "bekleckert",
    "Bekleckerten": "Bekleckerte",
    "Bekleckerteren": "Bekleckertere",
    "Bekleckertesten": "Bekleckerteste",
    "Beklecksenden": "Beklecksende",
    "Beklecksenderen": "Beklecksendere",
    "Beklecksendsten": "Beklecksendste",
    "Beklecksens": "Beklecksen",
    "Bekleckste": "bekleckst",
    "Beklecksten": "Bekleckste",
    "Beklecksteren": "Bekleckstere",
    "Bekleckstesten": "Beklecksteste",
    "Bekleidenden": "Bekleidende",
    "Bekleidens": "Bekleiden",
    "Bekleidete": "bekleidet",
    "Bekleideten": "Bekleidete",
    "Bekleidungen": "Bekleidung",
    "Beklemmenden": "Beklemmende",
    "Beklemmens": "Beklemmen",
    "Beklemmte": "beklemmt",
    "Beklemmten": "Beklemmte",
    "Bekloppten": "Bekloppte",
    "Bekloppteren": "Beklopptere",
    "Beklopptesten": "Bekloppteste",
    "Beknackten": "Beknackte",
    "Beknackteren": "Beknacktere",
    "Beknacktesten": "Beknackteste",
    "Beknienden": "Bekniende",
    "Beknienderen": "Bekniendere",
    "Bekniendsten": "Bekniendste",
    "Bekniens": "Beknien",
    "Bekniete": "bekniet",
    "Beknieten": "Bekniete",
    "Bekochenden": "Bekochende",
    "Bekochens": "Bekochen",
    "Bekochte": "bekocht",
    "Bekochten": "Bekochte",
    "Bekommenden": "Bekommende",
    "Bekommenen": "Bekommene",
    "Bekommens": "Bekommen",
    "Bekreuzigenden": "Bekreuzigende",
    "Bekreuzigens": "Bekreuzigen",
    "Bekreuzigte": "bekreuzigt",
    "Bekreuzigten": "Bekreuzigte",
    "Bekriegenden": "Bekriegende",
    "Bekriegens": "Bekriegen",
    "Bekriegte": "bekriegt",
    "Bekriegten": "Bekriegte",
    "Bekräftigenden": "Bekräftigende",
    "Bekräftigens": "Bekräftigen",
    "Bekräftigte": "bekräftigt",
    "Bekräftigten": "Bekräftigte",
    "Bekrümelnden": "Bekrümelnde",
    "Bekrümelnderen": "Bekrümelndere",
    "Bekrümelndsten": "Bekrümelndste",
    "Bekrümelns": "Bekrümeln",
    "Bekrümelte": "bekrümelt",
    "Bekrümelten": "Bekrümelte",
    "Bekrümelteren": "Bekrümeltere",
    "Bekrümeltesten": "Bekrümelteste",
    "Bekundenden": "Bekundende",
    "Bekundens": "Bekunden",
    "Bekundete": "bekundet",
    "Bekundeten": "Bekundete",
    "Bekämpfenden": "Bekämpfende",
    "Bekämpfens": "Bekämpfen",
    "Bekämpfte": "bekämpft",
    "Bekämpften": "Bekämpfte",
    "Bekämpfungen": "Bekämpfung",
    "Bekömmlichen": "Bekömmliche",
    "Bekömmlicheren": "Bekömmlichere",
    "Bekömmlichsten": "Bekömmlichste",
    "Beköstigenden": "Beköstigende",
    "Beköstigens": "Beköstigen",
    "Beköstigte": "beköstigt",
    "Beköstigten": "Beköstigte",
    "Bekümmernisse": "Bekümmernis",
    "Bekümmernissen": "Bekümmernis",
    "Bekümmerte": "bekümmert",
    "Bekümmerten": "Bekümmerte",
    "Bekümmerteren": "Bekümmertere",
    "Bekümmertesten": "Bekümmerteste",
    "Bekürzenden": "Bekürzende",
    "Bekürzens": "Bekürzen",
    "Bekürzte": "bekürzt",
    "Bekürzten": "Bekürzte",
    "Beladenden": "Beladende",
    "Beladenen": "Beladene",
    "Beladeneren": "Beladenere",
    "Beladens": "Beladen",
    "Beladenste": "beladen",
    "Beladensten": "Beladenste",
    "Belage": "Belag",
    "Belagerern": "Belagerer",
    "Belagerers": "Belagerer",
    "Belagernden": "Belagernde",
    "Belagernderen": "Belagerndere",
    "Belagerndsten": "Belagerndste",
    "Belagerns": "Belagern",
    "Belagerte": "belagert",
    "Belagerten": "Belagerte",
    "Belagerteren": "Belagertere",
    "Belagertesten": "Belagerteste",
    "Belagerungen": "Belagerung",
    "Belags": "Belag",
    "Belangenden": "Belangende",
    "Belangens": "Belangen",
    "Belanglosen": "Belanglose",
    "Belangloseren": "Belanglosere",
    "Belanglosesten": "Belangloseste",
    "Belanglosigkeiten": "Belanglosigkeit",
    "Belangte": "belangt",
    "Belangten": "Belangte",
    "Belangvollen": "Belangvolle",
    "Belangvolleren": "Belangvollere",
    "Belangvollsten": "Belangvollste",
    "Belassenden": "Belassende",
    "Belassenen": "Belassene",
    "Belassens": "Belassen",
    "Belastbaren": "Belastbare",
    "Belastbareren": "Belastbarere",
    "Belastbarsten": "Belastbarste",
    "Belastenden": "Belastende",
    "Belastenderen": "Belastendere",
    "Belastendsten": "Belastendste",
    "Belastens": "Belasten",
    "Belastete": "belastet",
    "Belasteten": "Belastete",
    "Belasteteren": "Belastetere",
    "Belastetesten": "Belasteteste",
    "Belastungen": "Belastung",
    "Belauernden": "Belauernde",
    "Belauernderen": "Belauerndere",
    "Belauerndsten": "Belauerndste",
    "Belauerns": "Belauern",
    "Belauerte": "belauert",
    "Belauerten": "Belauerte",
    "Belaufenden": "Belaufende",
    "Belaufenen": "Belaufene",
    "Belaufens": "Belaufen",
    "Belauschenden": "Belauschende",
    "Belauschenderen": "Belauschendere",
    "Belauschendsten": "Belauschendste",
    "Belauschens": "Belauschen",
    "Belauschte": "belauscht",
    "Belauschten": "Belauschte",
    "Belebenden": "Belebende",
    "Belebenderen": "Belebendere",
    "Belebendsten": "Belebendste",
    "Belebens": "Beleben",
    "Belebte": "belebt",
    "Belebten": "Belebte",
    "Belebteren": "Belebtere",
    "Belebtesten": "Belebteste",
    "Beleg": "belegen",
    "Belegbette": "Belegbett",
    "Belegbetten": "Belegbett",
    "Belegbetts": "Belegbett",
    "Belege": "belegen",
    "Belegen": "Beleg",
    "Belegenden": "Belegende",
    "Belegens": "Belegen",
    "Belegs": "Beleg",
    "Belegschaften": "Belegschaft",
    "Belegte": "belegt",
    "Belegten": "Belegte",
    "Belegteren": "Belegtere",
    "Belegtesten": "Belegteste",
    "Belegungen": "Belegung",
    "Belehrenden": "Belehrende",
    "Belehrens": "Belehren",
    "Belehrte": "belehrt",
    "Belehrten": "Belehrte",
    "Beleibten": "Beleibte",
    "Beleibteren": "Beleibtere",
    "Beleibtesten": "Beleibteste",
    "Beleidigenden": "Beleidigende",
    "Beleidigenderen": "Beleidigendere",
    "Beleidigendsten": "Beleidigendste",
    "Beleidigens": "Beleidigen",
    "Beleidigte": "beleidigt",
    "Beleidigten": "Beleidigte",
    "Beleidigteren": "Beleidigtere",
    "Beleidigtesten": "Beleidigteste",
    "Beleidigungen": "Beleidigung",
    "Beleihenden": "Beleihende",
    "Beleihens": "Beleihen",
    "Beleihungen": "Beleihung",
    "Belesene": "belesen",
    "Belesenen": "Belesene",
    "Beleseneren": "Belesenere",
    "Belesensten": "Belesenste",
    "Beleuchtenden": "Beleuchtende",
    "Beleuchtens": "Beleuchten",
    "Beleuchtete": "beleuchtet",
    "Beleuchteten": "Beleuchtete",
    "Beleuchteteren": "Beleuchtetere",
    "Beleuchtetesten": "Beleuchteteste",
    "Beleuchtungen": "Beleuchtung",
    "Belgiens": "Belgien",
    "Belgische": "belgisch",
    "Belgischen": "Belgische",
    "Belgischeren": "Belgischere",
    "Belgischsten": "Belgischste",
    "Belgradern": "Belgrader",
    "Belgraders": "Belgrader",
    "Belgrads": "Belgrad",
    "Belichtenden": "Belichtende",
    "Belichtens": "Belichten",
    "Belichtete": "belichtet",
    "Belichteten": "Belichtete",
    "Belichtungen": "Belichtung",
    "Beliebenden": "Beliebende",
    "Beliebens": "Belieben",
    "Beliebigen": "Beliebige",
    "Beliebte": "beliebt",
    "Beliebten": "Beliebte",
    "Beliebteren": "Beliebtere",
    "Beliebtesten": "Beliebteste",
    "Beliefernden": "Beliefernde",
    "Belieferns": "Beliefern",
    "Belieferte": "beliefert",
    "Belieferten": "Belieferte",
    "Belieferungen": "Belieferung",
    "Beliehenen": "Beliehene",
    "Bellenden": "Bellende",
    "Bellenderen": "Bellendere",
    "Bellendsten": "Bellendste",
    "Bellens": "Bellen",
    "Belogenen": "Belogene",
    "Belogeneren": "Belogenere",
    "Belogensten": "Belogenste",
    "Belohnenden": "Belohnende",
    "Belohnens": "Belohnen",
    "Belohnte": "belohnt",
    "Belohnten": "Belohnte",
    "Belohnungen": "Belohnung",
    "Belustigenden": "Belustigende",
    "Belustigenderen": "Belustigendere",
    "Belustigendsten": "Belustigendste",
    "Belustigens": "Belustigen",
    "Belustigte": "belustigt",
    "Belustigten": "Belustigte",
    "Belzes": "Belz",
    "Belächelnden": "Belächelnde",
    "Belächelnderen": "Belächelndere",
    "Belächelndsten": "Belächelndste",
    "Belächelns": "Belächeln",
    "Belächelte": "belächelt",
    "Belächelten": "Belächelte",
    "Belächelteren": "Belächeltere",
    "Belächeltesten": "Belächelteste",
    "Beläge": "Belag",
    "Belägen": "Belag",
    "Belämmernden": "Belämmernde",
    "Belämmernderen": "Belämmerndere",
    "Belämmerndsten": "Belämmerndste",
    "Belämmerns": "Belämmern",
    "Belämmerte": "belämmert",
    "Belämmerten": "Belämmerte",
    "Belämmerteren": "Belämmertere",
    "Belämmertesten": "Belämmerteste",
    "Belästigenden": "Belästigende",
    "Belästigenderen": "Belästigendere",
    "Belästigendsten": "Belästigendste",
    "Belästigens": "Belästigen",
    "Belästigte": "belästigt",
    "Belästigten": "Belästigte",
    "Belästigteren": "Belästigtere",
    "Belästigtesten": "Belästigteste",
    "Belästigungen": "Belästigung",
    "Belüftenden": "Belüftende",
    "Belüftenderen": "Belüftendere",
    "Belüftendsten": "Belüftendste",
    "Belüftens": "Belüften",
    "Belüftete": "belüftet",
    "Belüfteten": "Belüftete",
    "Belüfteteren": "Belüftetere",
    "Belüftetesten": "Belüfteteste",
    "Belügenden": "Belügende",
    "Belügens": "Belügen",
    "Bemalenden": "Bemalende",
    "Bemalens": "Bemalen",
    "Bemalte": "bemalt",
    "Bemalten": "Bemalte",
    "Bemalteren": "Bemaltere",
    "Bemaltesten": "Bemalteste",
    "Bemalungen": "Bemalung",
    "Bemannenden": "Bemannende",
    "Bemannens": "Bemannen",
    "Bemannte": "bemannt",
    "Bemannten": "Bemannte",
    "Bemannungen": "Bemannung",
    "Bembeln": "Bembel",
    "Bembels": "Bembel",
    "Bemerkbare": "bemerkbar",
    "Bemerkbaren": "Bemerkbare",
    "Bemerkenden": "Bemerkende",
    "Bemerkens": "Bemerken",
    "Bemerkenswerte": "bemerkenswert",
    "Bemerkenswerten": "Bemerkenswerte",
    "Bemerkenswerteren": "Bemerkenswertere",
    "Bemerkte": "bemerkt",
    "Bemerkten": "Bemerkte",
    "Bemerkungen": "Bemerkung",
    "Bemessungen": "Bemessung",
    "Bemitleidenden": "Bemitleidende",
    "Bemitleidenderen": "Bemitleidendere",
    "Bemitleidendsten": "Bemitleidendste",
    "Bemitleidens": "Bemitleiden",
    "Bemitleidenswerte": "bemitleidenswert",
    "Bemitleidenswerten": "Bemitleidenswerte",
    "Bemitleidenswerteren": "Bemitleidenswertere",
    "Bemitleidete": "bemitleidet",
    "Bemitleideten": "Bemitleidete",
    "Bemitleideteren": "Bemitleidetere",
    "Bemitleidetesten": "Bemitleideteste",
    "Bemutternden": "Bemutternde",
    "Bemutterns": "Bemuttern",
    "Bemutterte": "bemuttert",
    "Bemutterten": "Bemutterte",
    "Bemächtigenden": "Bemächtigende",
    "Bemächtigens": "Bemächtigen",
    "Bemächtigte": "bemächtigt",
    "Bemächtigten": "Bemächtigte",
    "Bemängelnden": "Bemängelnde",
    "Bemängelns": "Bemängeln",
    "Bemängelte": "bemängelt",
    "Bemängelten": "Bemängelte",
    "Bemängelteren": "Bemängeltere",
    "Bemängeltesten": "Bemängelteste",
    "Bemäntelnden": "Bemäntelnde",
    "Bemäntelns": "Bemänteln",
    "Bemäntelte": "bemäntelt",
    "Bemäntelten": "Bemäntelte",
    "Bemühenden": "Bemühende",
    "Bemühens": "Bemühen",
    "Bemühte": "bemüht",
    "Bemühten": "Bemühte",
    "Bemühungen": "Bemühung",
    "Benachbarten": "Benachbarte",
    "Benachrichtigenden": "Benachrichtigende",
    "Benachrichtigens": "Benachrichtigen",
    "Benachrichtigte": "benachrichtigt",
    "Benachrichtigten": "Benachrichtigte",
    "Benachteiligenden": "Benachteiligende",
    "Benachteiligens": "Benachteiligen",
    "Benachteiligte": "benachteiligt",
    "Benachteiligten": "Benachteiligte",
    "Benachteiligteren": "Benachteiligtere",
    "Benachteiligteste": "benachteiligt",
    "Benachteiligungen": "Benachteiligung",
    "Benannte": "benennen",
    "Benannten": "benennen",
    "Benders": "Bender",
    "Bendits": "Bendit",
    "Benebelnden": "Benebelnde",
    "Benebelnderen": "Benebelndere",
    "Benebelndsten": "Benebelndste",
    "Benebelns": "Benebeln",
    "Benebelte": "benebelt",
    "Benebelten": "Benebelte",
    "Benebelteren": "Benebeltere",
    "Benebeltesten": "Benebelteste",
    "Benediktinern": "Benediktiner",
    "Benediktiners": "Benediktiner",
    "Benefizvorstellungen": "Benefizvorstellung",
    "Benehmenden": "Benehmende",
    "Benehmenderen": "Benehmendere",
    "Benehmendsten": "Benehmendste",
    "Benehmens": "Benehmen",
    "Beneidenden": "Beneidende",
    "Beneidenderen": "Beneidendere",
    "Beneidendsten": "Beneidendste",
    "Beneidens": "Beneiden",
    "Beneidenswerte": "beneidenswert",
    "Beneidenswerten": "Beneidenswerte",
    "Beneidenswerteren": "Beneidenswertere",
    "Beneidete": "beneidet",
    "Beneideten": "Beneidete",
    "Beneideteren": "Beneidetere",
    "Beneidetesten": "Beneideteste",
    "Benennenden": "Benennende",
    "Benennens": "Benennen",
    "Benennungen": "Benennung",
    "Benetzenden": "Benetzende",
    "Benetzens": "Benetzen",
    "Benetzte": "benetzt",
    "Benetzten": "Benetzte",
    "Bengalen": "Bengale",
    "Bengeln": "Bengel",
    "Bengels": "Bengel",
    "Benjamins": "Benjamin",
    "Bennos": "Benno",
    "Benommenen": "Benommene",
    "Benommeneren": "Benommenere",
    "Benommensten": "Benommenste",
    "Benotenden": "Benotende",
    "Benotens": "Benoten",
    "Benotete": "benotet",
    "Benoteten": "Benotete",
    "Bens": "Ben",
    "Benutzenden": "Benutzende",
    "Benutzens": "Benutzen",
    "Benutzern": "Benutzer",
    "Benutzers": "Benutzer",
    "Benutzte": "benutzt",
    "Benutzten": "Benutzte",
    "Benutzteren": "Benutztere",
    "Benutztesten": "Benutzteste",
    "Benutzungen": "Benutzung",
    "Benzine": "Benzin",
    "Benzinen": "Benzin",
    "Benzinern": "Benziner",
    "Benziners": "Benziner",
    "Benzines": "Benzin",
    "Benzins": "Benzin",
    "Benötigenden": "Benötigende",
    "Benötigens": "Benötigen",
    "Benötigte": "benötigt",
    "Benötigten": "Benötigte",
    "Benötigteren": "Benötigtere",
    "Benötigtesten": "Benötigteste",
    "Benützende": "benützend",
    "Benützenden": "Benützende",
    "Benützens": "Benützen",
    "Benützern": "Benützer",
    "Benützers": "Benützer",
    "Benützte": "benützt",
    "Benützten": "Benützte",
    "Benütztere": "benützt",
    "Benützteren": "Benütztere",
    "Benützteste": "benützt",
    "Benütztesten": "Benützteste",
    "Beobachtenden": "Beobachtende",
    "Beobachtens": "Beobachten",
    "Beobachtern": "Beobachter",
    "Beobachters": "Beobachter",
    "Beobachtete": "beobachtet",
    "Beobachteten": "Beobachtete",
    "Beobachteteren": "Beobachtetere",
    "Beobachtetesten": "Beobachteteste",
    "Beobachtungen": "Beobachtung",
    "Beordernden": "Beordernde",
    "Beordernderen": "Beorderndere",
    "Beorderndsten": "Beorderndste",
    "Beorderns": "Beordern",
    "Beorderte": "beordert",
    "Beorderten": "Beorderte",
    "Beorderteren": "Beordertere",
    "Beordertesten": "Beorderteste",
    "Bepackenden": "Bepackende",
    "Bepackens": "Bepacken",
    "Bepackte": "bepackt",
    "Bepackten": "Bepackte",
    "Bepackteren": "Bepacktere",
    "Bepacktesten": "Bepackteste",
    "Bepflanzenden": "Bepflanzende",
    "Bepflanzens": "Bepflanzen",
    "Bepflanzte": "bepflanzt",
    "Bepflanzten": "Bepflanzte",
    "Bepflanzteren": "Bepflanztere",
    "Bepflanztesten": "Bepflanzteste",
    "Bepieselnden": "Bepieselnde",
    "Bepieselnderen": "Bepieselndere",
    "Bepieselndsten": "Bepieselndste",
    "Bepieselns": "Bepieseln",
    "Bepieselte": "bepieselt",
    "Bepieselten": "Bepieselte",
    "Bepinselnden": "Bepinselnde",
    "Bepinselnderen": "Bepinselndere",
    "Bepinselndsten": "Bepinselndste",
    "Bepinselns": "Bepinseln",
    "Bepinselte": "bepinselt",
    "Bepinselten": "Bepinselte",
    "Bepissenden": "Bepissende",
    "Bepissenderen": "Bepissendere",
    "Bepissendsten": "Bepissendste",
    "Bepissens": "Bepissen",
    "Bepißte": "bepißt",
    "Bepißten": "Bepißte",
    "Bepißteren": "Bepißtere",
    "Bepißtesten": "Bepißteste",
    "Bequeme": "bequemen",
    "Bequemen": "Bequeme",
    "Bequemenden": "Bequemende",
    "Bequemens": "Bequemen",
    "Bequemeren": "Bequemere",
    "Bequemlichen": "Bequemliche",
    "Bequemlicheren": "Bequemlichere",
    "Bequemlichkeiten": "Bequemlichkeit",
    "Bequemlichste": "bequemlich",
    "Bequemlichsten": "Bequemlichste",
    "Bequemsten": "Bequemste",
    "Bequemte": "bequemt",
    "Bequemten": "Bequemte",
    "Berappenden": "Berappende",
    "Berappens": "Berappen",
    "Berappte": "berappt",
    "Berappten": "Berappte",
    "Beratenden": "Beratende",
    "Beratenen": "Beratene",
    "Beratens": "Beraten",
    "Beratern": "Berater",
    "Beraters": "Berater",
    "Beratschlagenden": "Beratschlagende",
    "Beratschlagenderen": "Beratschlagendere",
    "Beratschlagenen": "Beratschlagene",
    "Beratschlagens": "Beratschlagen",
    "Beratschlagungen": "Beratschlagung",
    "Beratungen": "Beratung",
    "Beraubenden": "Beraubende",
    "Beraubens": "Berauben",
    "Beraubte": "beraubt",
    "Beraubten": "Beraubte",
    "Beraubungen": "Beraubung",
    "Beraumenden": "Beraumende",
    "Beraumens": "Beraumen",
    "Beraumte": "beraumt",
    "Beraumten": "Beraumte",
    "Berauschenden": "Berauschende",
    "Berauschenderen": "Berauschendere",
    "Berauschendsten": "Berauschendste",
    "Berberischen": "Berberische",
    "Berbern": "Berber",
    "Berbers": "Berber",
    "Berechenbare": "berechenbar",
    "Berechenbaren": "Berechenbare",
    "Berechenbareren": "Berechenbarere",
    "Berechenbarsten": "Berechenbarste",
    "Berechnenden": "Berechnende",
    "Berechnens": "Berechnen",
    "Berechnete": "berechnet",
    "Berechneten": "Berechnete",
    "Berechnungen": "Berechnung",
    "Berechtigenden": "Berechtigende",
    "Berechtigens": "Berechtigen",
    "Berechtigte": "berechtigt",
    "Berechtigten": "Berechtigte",
    "Berechtigungen": "Berechtigung",
    "Beredenden": "Beredende",
    "Beredens": "Bereden",
    "Beredete": "beredet",
    "Beredeten": "Beredete",
    "Bereiche": "Bereich",
    "Bereichen": "Bereich",
    "Bereichernden": "Bereichernde",
    "Bereicherns": "Bereichern",
    "Bereicherte": "bereichert",
    "Bereicherten": "Bereicherte",
    "Bereicherungen": "Bereicherung",
    "Bereiches": "Bereich",
    "Bereichs": "Bereich",
    "Bereifenden": "Bereifende",
    "Bereifens": "Bereifen",
    "Bereifte": "bereift",
    "Bereiften": "Bereifte",
    "Bereifungen": "Bereifung",
    "Bereinigenden": "Bereinigende",
    "Bereinigenderen": "Bereinigendere",
    "Bereinigendsten": "Bereinigendste",
    "Bereinigens": "Bereinigen",
    "Bereinigte": "bereinigt",
    "Bereinigten": "Bereinigte",
    "Bereinigteren": "Bereinigtere",
    "Bereinigtesten": "Bereinigteste",
    "Bereisenden": "Bereisende",
    "Bereisens": "Bereisen",
    "Bereiste": "bereist",
    "Bereisten": "Bereiste",
    "Bereite": "bereiten",
    "Bereiten": "Bereite",
    "Bereitenden": "Bereitende",
    "Bereitens": "Bereiten",
    "Bereitete": "bereitet",
    "Bereiteten": "Bereitete",
    "Bereitgehaltenen": "Bereitgehaltene",
    "Bereitgestandenen": "Bereitgestandene",
    "Bereitgestellten": "Bereitgestellte",
    "Bereithaltenden": "Bereithaltende",
    "Bereithaltens": "Bereithalten",
    "Bereitschaften": "Bereitschaft",
    "Bereitstehenden": "Bereitstehende",
    "Bereitstehens": "Bereitstehen",
    "Bereitstellenden": "Bereitstellende",
    "Bereitstellens": "Bereitstellen",
    "Bereitwilligen": "Bereitwillige",
    "Bereitwilligeren": "Bereitwilligere",
    "Bereitwilligsten": "Bereitwilligste",
    "Bereuenden": "Bereuende",
    "Bereuenderen": "Bereuendere",
    "Bereuendsten": "Bereuendste",
    "Bereuens": "Bereuen",
    "Bereute": "bereut",
    "Bereuten": "Bereute",
    "Bereuteren": "Bereutere",
    "Bereutesten": "Bereuteste",
    "Berge": "bergen",
    "Bergen": "Berg",
    "Bergenden": "Bergende",
    "Bergens": "Bergen",
    "Bergers": "Berger",
    "Bergigen": "Bergige",
    "Bergigeren": "Bergigere",
    "Bergigsten": "Bergigste",
    "Bergkuppen": "Bergkuppe",
    "Berglands": "Bergland",
    "Bergmännische": "bergmännisch",
    "Bergmännischen": "Bergmännische",
    "Bergs": "Berg",
    "Bergsteigern": "Bergsteiger",
    "Bergsteigers": "Bergsteiger",
    "Berichte": "berichten",
    "Berichten": "Bericht",
    "Berichtenden": "Berichtende",
    "Berichtens": "Berichten",
    "Berichterstattern": "Berichterstatter",
    "Berichterstatters": "Berichterstatter",
    "Berichtes": "Bericht",
    "Berichtete": "berichtet",
    "Berichteten": "Berichtete",
    "Berichtigenden": "Berichtigende",
    "Berichtigens": "Berichtigen",
    "Berichtigte": "berichtigt",
    "Berichtigten": "Berichtigte",
    "Berichtigungen": "Berichtigung",
    "Berichts": "Bericht",
    "Berittenen": "Berittene",
    "Beritteneren": "Berittenere",
    "Berittensten": "Berittenste",
    "Berlinern": "Berliner",
    "Berliners": "Berliner",
    "Berlins": "Berlin",
    "Bernaus": "Bernau",
    "Bernbachs": "Bernbach",
    "Bernds": "Bernd",
    "Bernhardinern": "Bernhardiner",
    "Bernhardiners": "Bernhardiner",
    "Bernhards": "Bernhard",
    "Bernies": "Bernie",
    "Berns": "Bern",
    "Bernsteinfarbene": "bernsteinfarben",
    "Bernsteinfarbenen": "Bernsteinfarbene",
    "Berserkern": "Berserker",
    "Berserkers": "Berserker",
    "Berstenden": "Berstende",
    "Berstens": "Bersten",
    "Berthas": "Bertha",
    "Bertholds": "Berthold",
    "Bertis": "Berti",
    "Bertolds": "Bertold",
    "Beruf": "berufen",
    "Berufe": "berufen",
    "Berufen": "Beruf",
    "Berufenden": "Berufende",
    "Berufenen": "Berufene",
    "Berufens": "Berufen",
    "Berufes": "Beruf",
    "Beruflichen": "Berufliche",
    "Berufs": "Beruf",
    "Berufsbedingte": "berufsbedingt",
    "Berufsbedingten": "Berufsbedingte",
    "Berufsbegleitenden": "Berufsbegleitende",
    "Berufsbezogenen": "Berufsbezogene",
    "Berufsbildenden": "Berufsbildende",
    "Berufstätigen": "Berufstätige",
    "Berufsunfähigen": "Berufsunfähige",
    "Berufungen": "Berufung",
    "Beruhenden": "Beruhende",
    "Beruhens": "Beruhen",
    "Beruhigenden": "Beruhigende",
    "Beruhigenderen": "Beruhigendere",
    "Beruhigendsten": "Beruhigendste",
    "Beruhigens": "Beruhigen",
    "Beruhigte": "beruhigt",
    "Beruhigten": "Beruhigte",
    "Beruhigteren": "Beruhigtere",
    "Beruhigtesten": "Beruhigteste",
    "Beruhigungen": "Beruhigung",
    "Beruhte": "beruht",
    "Beruhten": "Beruhte",
    "Berüchtigte": "berüchtigt",
    "Berüchtigten": "Berüchtigte",
    "Berüchtigteren": "Berüchtigtere",
    "Berüchtigtesten": "Berüchtigteste",
    "Berücksichtigenden": "Berücksichtigende",
    "Berücksichtigens": "Berücksichtigen",
    "Berücksichtigte": "berücksichtigt",
    "Berücksichtigten": "Berücksichtigte",
    "Berücksichtigteren": "Berücksichtigtere",
    "Berücksichtigungen": "Berücksichtigung",
    "Berühmte": "berühmt",
    "Berühmten": "Berühmte",
    "Berühmteren": "Berühmtere",
    "Berühmtesten": "Berühmteste",
    "Berühmtheiten": "Berühmtheit",
    "Berührenden": "Berührende",
    "Berührens": "Berühren",
    "Berührte": "berührt",
    "Berührten": "Berührte",
    "Berührungen": "Berührung",
    "Berüstenden": "Berüstende",
    "Berüstens": "Berüsten",
    "Berüstete": "berüstet",
    "Berüsteten": "Berüstete",
    "Besabbernden": "Besabbernde",
    "Besabbernderen": "Besabberndere",
    "Besabberndsten": "Besabberndste",
    "Besabberns": "Besabbern",
    "Besabberte": "besabbert",
    "Besabberten": "Besabberte",
    "Besabberteren": "Besabbertere",
    "Besabbertesten": "Besabberteste",
    "Besagenden": "Besagende",
    "Besagens": "Besagen",
    "Besagte": "besagt",
    "Besagten": "Besagte",
    "Besaitenden": "Besaitende",
    "Besaitens": "Besaiten",
    "Besaitete": "besaitet",
    "Besaiteten": "Besaitete",
    "Besamenden": "Besamende",
    "Besamenderen": "Besamendere",
    "Besamendsten": "Besamendste",
    "Besamens": "Besamen",
    "Besamte": "besamt",
    "Besamten": "Besamte",
    "Besamteren": "Besamtere",
    "Besamtesten": "Besamteste",
    "Besatzungen": "Besatzung",
    "Besaufenden": "Besaufende",
    "Besaufenderen": "Besaufendere",
    "Besaufendsten": "Besaufendste",
    "Besaufens": "Besaufen",
    "Beschadenden": "Beschadende",
    "Beschadens": "Beschaden",
    "Beschadete": "beschadet",
    "Beschadeten": "Beschadete",
    "Beschadeteren": "Beschadetere",
    "Beschadetesten": "Beschadeteste",
    "Beschaffenden": "Beschaffende",
    "Beschaffens": "Beschaffen",
    "Beschaffte": "beschafft",
    "Beschafften": "Beschaffte",
    "Beschallenden": "Beschallende",
    "Beschallenderen": "Beschallendere",
    "Beschallendsten": "Beschallendste",
    "Beschallens": "Beschallen",
    "Beschallte": "beschallt",
    "Beschallten": "Beschallte",
    "Beschallteren": "Beschalltere",
    "Beschalltesten": "Beschallteste",
    "Beschattenden": "Beschattende",
    "Beschattenderen": "Beschattendere",
    "Beschattendsten": "Beschattendste",
    "Beschattens": "Beschatten",
    "Beschattete": "beschattet",
    "Beschatteten": "Beschattete",
    "Beschatteteren": "Beschattetere",
    "Beschattetesten": "Beschatteteste",
    "Beschau": "beschauen",
    "Beschauenden": "Beschauende",
    "Beschauens": "Beschauen",
    "Beschauern": "Beschauer",
    "Beschauers": "Beschauer",
    "Beschaulichen": "Beschauliche",
    "Beschaulicheren": "Beschaulichere",
    "Beschaulichkeiten": "Beschaulichkeit",
    "Beschaulichste": "beschaulich",
    "Beschaulichsten": "Beschaulichste",
    "Beschaute": "beschaut",
    "Beschauten": "Beschaute",
    "Bescheide": "Bescheid",
    "Bescheiden": "Bescheid",
    "Bescheidene": "bescheiden",
    "Bescheidenen": "Bescheidene",
    "Bescheideneren": "Bescheidenere",
    "Bescheidenheiten": "Bescheidenheit",
    "Bescheidenste": "bescheiden",
    "Bescheidensten": "Bescheidenste",
    "Bescheides": "Bescheid",
    "Bescheids": "Bescheid",
    "Bescheinenden": "Bescheinende",
    "Bescheinens": "Bescheinen",
    "Bescheinigenden": "Bescheinigende",
    "Bescheinigens": "Bescheinigen",
    "Bescheinigte": "bescheinigt",
    "Bescheinigten": "Bescheinigte",
    "Bescheißenden": "Bescheißende",
    "Bescheißens": "Bescheißen",
    "Beschenkenden": "Beschenkende",
    "Beschenkens": "Beschenken",
    "Beschenkte": "beschenkt",
    "Beschenkten": "Beschenkte",
    "Bescherenden": "Bescherende",
    "Bescherens": "Bescheren",
    "Bescherte": "beschert",
    "Bescherten": "Bescherte",
    "Bescherungen": "Bescherung",
    "Bescheuerte": "bescheuert",
    "Bescheuerten": "Bescheuerte",
    "Bescheuerteren": "Bescheuertere",
    "Bescheuertesten": "Bescheuerteste",
    "Beschichtenden": "Beschichtende",
    "Beschichtens": "Beschichten",
    "Beschichtete": "beschichtet",
    "Beschichteten": "Beschichtete",
    "Beschichteteren": "Beschichtetere",
    "Beschichtetesten": "Beschichteteste",
    "Beschienenen": "Beschienene",
    "Beschießenden": "Beschießende",
    "Beschießens": "Beschießen",
    "Beschildernden": "Beschildernde",
    "Beschilderns": "Beschildern",
    "Beschilderte": "beschildert",
    "Beschilderten": "Beschilderte",
    "Beschimpfenden": "Beschimpfende",
    "Beschimpfenderen": "Beschimpfendere",
    "Beschimpfendsten": "Beschimpfendste",
    "Beschimpfens": "Beschimpfen",
    "Beschimpfte": "beschimpft",
    "Beschimpften": "Beschimpfte",
    "Beschimpfteren": "Beschimpftere",
    "Beschimpftesten": "Beschimpfteste",
    "Beschimpfungen": "Beschimpfung",
    "Beschirmenden": "Beschirmende",
    "Beschirmens": "Beschirmen",
    "Beschirmte": "beschirmt",
    "Beschirmten": "Beschirmte",
    "Beschissenen": "Beschissene",
    "Beschisseneren": "Beschissenere",
    "Beschissensten": "Beschissenste",
    "Beschlag": "beschlagen",
    "Beschlage": "beschlagen",
    "Beschlagenden": "Beschlagende",
    "Beschlagenen": "Beschlagene",
    "Beschlagens": "Beschlagen",
    "Beschlagnahmenden": "Beschlagnahmende",
    "Beschlagnahmens": "Beschlagnahmen",
    "Beschlagnahmte": "beschlagnahmt",
    "Beschlagnahmten": "Beschlagnahmte",
    "Beschlags": "Beschlag",
    "Beschleichenden": "Beschleichende",
    "Beschleichens": "Beschleichen",
    "Beschleunigenden": "Beschleunigende",
    "Beschleunigenderen": "Beschleunigendere",
    "Beschleunigens": "Beschleunigen",
    "Beschleunigern": "Beschleuniger",
    "Beschleunigers": "Beschleuniger",
    "Beschleunigte": "beschleunigt",
    "Beschleunigten": "Beschleunigte",
    "Beschleunigteren": "Beschleunigtere",
    "Beschleunigtesten": "Beschleunigteste",
    "Beschleunigungen": "Beschleunigung",
    "Beschlichenen": "Beschlichene",
    "Beschließenden": "Beschließende",
    "Beschließens": "Beschließen",
    "Beschlossenen": "Beschlossene",
    "Beschlosseneren": "Beschlossenere",
    "Beschlossensten": "Beschlossenste",
    "Beschlusse": "Beschluß",
    "Beschlusses": "Beschluß",
    "Beschlußfähige": "beschlußfähig",
    "Beschlußfähigen": "Beschlußfähige",
    "Beschlußreifen": "Beschlußreife",
    "Beschläge": "Beschlag",
    "Beschlägen": "Beschlag",
    "Beschlüsse": "Beschluß",
    "Beschlüssen": "Beschluß",
    "Beschmierenden": "Beschmierende",
    "Beschmierenderen": "Beschmierendere",
    "Beschmierendsten": "Beschmierendste",
    "Beschmierens": "Beschmieren",
    "Beschmierte": "beschmiert",
    "Beschmierten": "Beschmierte",
    "Beschmierteren": "Beschmiertere",
    "Beschmiertesten": "Beschmierteste",
    "Beschmunzelnden": "Beschmunzelnde",
    "Beschmunzelnderen": "Beschmunzelndere",
    "Beschmunzelndsten": "Beschmunzelndste",
    "Beschmunzelns": "Beschmunzeln",
    "Beschmunzelte": "beschmunzelt",
    "Beschmunzelten": "Beschmunzelte",
    "Beschmunzelteren": "Beschmunzeltere",
    "Beschmunzeltesten": "Beschmunzelteste",
    "Beschmutzenden": "Beschmutzende",
    "Beschmutzenderen": "Beschmutzendere",
    "Beschmutzendsten": "Beschmutzendste",
    "Beschmutzens": "Beschmutzen",
    "Beschmutzte": "beschmutzt",
    "Beschmutzten": "Beschmutzte",
    "Beschmutzteren": "Beschmutztere",
    "Beschmutztesten": "Beschmutzteste",
    "Beschneidenden": "Beschneidende",
    "Beschneidens": "Beschneiden",
    "Beschnittenen": "Beschnittene",
    "Beschnitteneren": "Beschnittenere",
    "Beschnittensten": "Beschnittenste",
    "Beschnuppernden": "Beschnuppernde",
    "Beschnupperns": "Beschnuppern",
    "Beschnupperte": "beschnuppert",
    "Beschnupperten": "Beschnupperte",
    "Beschnüffelnden": "Beschnüffelnde",
    "Beschnüffelnderen": "Beschnüffelndere",
    "Beschnüffelndsten": "Beschnüffelndste",
    "Beschnüffelns": "Beschnüffeln",
    "Beschnüffelte": "beschnüffelt",
    "Beschnüffelten": "Beschnüffelte",
    "Beschossenen": "Beschossene",
    "Beschosseneren": "Beschossenere",
    "Beschossensten": "Beschossenste",
    "Beschreibenden": "Beschreibende",
    "Beschreibens": "Beschreiben",
    "Beschreibungen": "Beschreibung",
    "Beschreienden": "Beschreiende",
    "Beschreienderen": "Beschreiendere",
    "Beschreiendsten": "Beschreiendste",
    "Beschreiens": "Beschreien",
    "Beschreitenden": "Beschreitende",
    "Beschreitens": "Beschreiten",
    "Beschriebenen": "Beschriebene",
    "Beschrienen": "Beschriene",
    "Beschriftenden": "Beschriftende",
    "Beschriftens": "Beschriften",
    "Beschriftete": "beschriftet",
    "Beschrifteten": "Beschriftete",
    "Beschriftungen": "Beschriftung",
    "Beschrittenen": "Beschrittene",
    "Beschränkenden": "Beschränkende",
    "Beschränkenderen": "Beschränkendere",
    "Beschränkendsten": "Beschränkendste",
    "Beschränkens": "Beschränken",
    "Beschränkte": "beschränkt",
    "Beschränkten": "Beschränkte",
    "Beschränkteren": "Beschränktere",
    "Beschränktesten": "Beschränkteste",
    "Beschränkungen": "Beschränkung",
    "Beschuhenden": "Beschuhende",
    "Beschuhens": "Beschuhen",
    "Beschuhte": "beschuht",
    "Beschuhten": "Beschuhte",
    "Beschuldigenden": "Beschuldigende",
    "Beschuldigens": "Beschuldigen",
    "Beschuldigte": "beschuldigt",
    "Beschuldigten": "Beschuldigte",
    "Beschusse": "Beschuß",
    "Beschusses": "Beschuß",
    "Beschwerden": "Beschwerde",
    "Beschwerenden": "Beschwerende",
    "Beschwerens": "Beschweren",
    "Beschwerlichen": "Beschwerliche",
    "Beschwerlicheren": "Beschwerlichere",
    "Beschwerlichsten": "Beschwerlichste",
    "Beschwerte": "beschwert",
    "Beschwerten": "Beschwerte",
    "Beschwichtigenden": "Beschwichtigende",
    "Beschwichtigenderen": "Beschwichtigendere",
    "Beschwichtigens": "Beschwichtigen",
    "Beschwichtigte": "beschwichtigt",
    "Beschwichtigten": "Beschwichtigte",
    "Beschwingten": "Beschwingte",
    "Beschwingteren": "Beschwingtere",
    "Beschwingtesten": "Beschwingteste",
    "Beschworenen": "Beschworene",
    "Beschwörenden": "Beschwörende",
    "Beschwörens": "Beschwören",
    "Beschwörern": "Beschwörer",
    "Beschwörers": "Beschwörer",
    "Beschwörungen": "Beschwörung",
    "Beschädigenden": "Beschädigende",
    "Beschädigens": "Beschädigen",
    "Beschädigte": "beschädigt",
    "Beschädigten": "Beschädigte",
    "Beschädigteren": "Beschädigtere",
    "Beschädigtesten": "Beschädigteste",
    "Beschädigungen": "Beschädigung",
    "Beschäftigenden": "Beschäftigende",
    "Beschäftigens": "Beschäftigen",
    "Beschäftigte": "beschäftigt",
    "Beschäftigten": "Beschäftigte",
    "Beschäftigteren": "Beschäftigtere",
    "Beschäftigtesten": "Beschäftigteste",
    "Beschäftigungen": "Beschäftigung",
    "Beschäftigungslose": "beschäftigungslos",
    "Beschäftigungslosen": "Beschäftigungslose",
    "Beschönigenden": "Beschönigende",
    "Beschönigenderen": "Beschönigendere",
    "Beschönigendsten": "Beschönigendste",
    "Beschönigens": "Beschönigen",
    "Beschönigte": "beschönigt",
    "Beschönigten": "Beschönigte",
    "Beschönigteren": "Beschönigtere",
    "Beschönigtesten": "Beschönigteste",
    "Beschüsse": "Beschuß",
    "Beschüssen": "Beschuß",
    "Beschützenden": "Beschützende",
    "Beschützens": "Beschützen",
    "Beschützern": "Beschützer",
    "Beschützers": "Beschützer",
    "Beschützte": "beschützt",
    "Beschützten": "Beschützte",
    "Beschützteren": "Beschütztere",
    "Beschütztesten": "Beschützteste",
    "Beseelenden": "Beseelende",
    "Beseelens": "Beseelen",
    "Beseelte": "beseelt",
    "Beseelten": "Beseelte",
    "Besegelnden": "Besegelnde",
    "Besegelns": "Besegeln",
    "Besegelte": "besegelt",
    "Besegelten": "Besegelte",
    "Beseitigenden": "Beseitigende",
    "Beseitigens": "Beseitigen",
    "Beseitigte": "beseitigt",
    "Beseitigten": "Beseitigte",
    "Beseitigungen": "Beseitigung",
    "Besenreine": "besenrein",
    "Besenreinen": "Besenreine",
    "Besens": "Besen",
    "Besessenen": "Besessene",
    "Besesseneren": "Besessenere",
    "Besessensten": "Besessenste",
    "Besetzenden": "Besetzende",
    "Besetzens": "Besetzen",
    "Besetzern": "Besetzer",
    "Besetzers": "Besetzer",
    "Besetzte": "besetzt",
    "Besetzten": "Besetzte",
    "Besetztzeichens": "Besetztzeichen",
    "Besetzungen": "Besetzung",
    "Besichtigenden": "Besichtigende",
    "Besichtigens": "Besichtigen",
    "Besichtigte": "besichtigt",
    "Besichtigten": "Besichtigte",
    "Besichtigungen": "Besichtigung",
    "Besiedelnden": "Besiedelnde",
    "Besiedelns": "Besiedeln",
    "Besiedelte": "besiedelt",
    "Besiedelten": "Besiedelte",
    "Besiedelteren": "Besiedeltere",
    "Besiedeltesten": "Besiedelteste",
    "Besiegbaren": "Besiegbare",
    "Besiegelnden": "Besiegelnde",
    "Besiegelns": "Besiegeln",
    "Besiegelte": "besiegelt",
    "Besiegelten": "Besiegelte",
    "Besiegenden": "Besiegende",
    "Besiegens": "Besiegen",
    "Besiegte": "besiegt",
    "Besiegten": "Besiegte",
    "Besingenden": "Besingende",
    "Besingens": "Besingen",
    "Besinnenden": "Besinnende",
    "Besinnenderen": "Besinnendere",
    "Besinnendsten": "Besinnendste",
    "Besinnens": "Besinnen",
    "Besinnlichen": "Besinnliche",
    "Besinnlicheren": "Besinnlichere",
    "Besinnlichsten": "Besinnlichste",
    "Besinnungslosen": "Besinnungslose",
    "Besinnungsloseren": "Besinnungslosere",
    "Besitze": "besitzen",
    "Besitzen": "Besitz",
    "Besitzenden": "Besitzende",
    "Besitzens": "Besitzen",
    "Besitzern": "Besitzer",
    "Besitzers": "Besitzer",
    "Besitzes": "Besitz",
    "Besitzstande": "Besitzstand",
    "Besitzstandes": "Besitzstand",
    "Besitzstands": "Besitzstand",
    "Besitzstände": "Besitzstand",
    "Besitzständen": "Besitzstand",
    "Besitztume": "Besitztum",
    "Besitztumes": "Besitztum",
    "Besitztums": "Besitztum",
    "Besitztümer": "Besitztum",
    "Besitztümern": "Besitztum",
    "Besitzungen": "Besitzung",
    "Besoffenen": "Besoffene",
    "Besoffeneren": "Besoffenere",
    "Besoffensten": "Besoffenste",
    "Besohlenden": "Besohlende",
    "Besohlens": "Besohlen",
    "Besohlte": "besohlt",
    "Besohlten": "Besohlte",
    "Besoldenden": "Besoldende",
    "Besoldens": "Besolden",
    "Besoldete": "besoldet",
    "Besoldeten": "Besoldete",
    "Besonderen": "Besondere",
    "Besonderheiten": "Besonderheit",
    "Besonnenen": "Besonnene",
    "Besonneneren": "Besonnenere",
    "Besonnensten": "Besonnenste",
    "Besorgenden": "Besorgende",
    "Besorgens": "Besorgen",
    "Besorgern": "Besorger",
    "Besorgers": "Besorger",
    "Besorgniserregenden": "Besorgniserregende",
    "Besorgniserregenderen": "Besorgniserregendere",
    "Besorgnisse": "Besorgnis",
    "Besorgnissen": "Besorgnis",
    "Besorgte": "besorgt",
    "Besorgten": "Besorgte",
    "Besorgteren": "Besorgtere",
    "Besorgtesten": "Besorgteste",
    "Bespannenden": "Bespannende",
    "Bespannens": "Bespannen",
    "Bespannte": "bespannt",
    "Bespannten": "Bespannte",
    "Bespielenden": "Bespielende",
    "Bespielens": "Bespielen",
    "Bespielte": "bespielt",
    "Bespielten": "Bespielte",
    "Bespitzelnden": "Bespitzelnde",
    "Bespitzelnderen": "Bespitzelndere",
    "Bespitzelndsten": "Bespitzelndste",
    "Bespitzelns": "Bespitzeln",
    "Bespitzelte": "bespitzelt",
    "Bespitzelten": "Bespitzelte",
    "Bespitzelteren": "Bespitzeltere",
    "Bespitzeltesten": "Bespitzelteste",
    "Bespitzelungen": "Bespitzelung",
    "Besprechenden": "Besprechende",
    "Besprechenderen": "Besprechendere",
    "Besprechendsten": "Besprechendste",
    "Besprechens": "Besprechen",
    "Besprechungen": "Besprechung",
    "Besprenkelnden": "Besprenkelnde",
    "Besprenkelnderen": "Besprenkelndere",
    "Besprenkelndsten": "Besprenkelndste",
    "Besprenkelns": "Besprenkeln",
    "Besprenkelte": "besprenkelt",
    "Besprenkelten": "Besprenkelte",
    "Besprenkelteren": "Besprenkeltere",
    "Besprenkeltesten": "Besprenkelteste",
    "Bespritzenden": "Bespritzende",
    "Bespritzenderen": "Bespritzendere",
    "Bespritzendsten": "Bespritzendste",
    "Bespritzens": "Bespritzen",
    "Bespritzte": "bespritzt",
    "Bespritzten": "Bespritzte",
    "Bespritzteren": "Bespritztere",
    "Bespritztesten": "Bespritzteste",
    "Besprochenen": "Besprochene",
    "Besprocheneren": "Besprochenere",
    "Besprochensten": "Besprochenste",
    "Besprühenden": "Besprühende",
    "Besprühens": "Besprühen",
    "Besprühte": "besprüht",
    "Besprühten": "Besprühte",
    "Bespuckenden": "Bespuckende",
    "Bespuckenderen": "Bespuckendere",
    "Bespuckendsten": "Bespuckendste",
    "Bespuckens": "Bespucken",
    "Bespuckte": "bespuckt",
    "Bespuckten": "Bespuckte",
    "Bespuckteren": "Bespucktere",
    "Bespucktesten": "Bespuckteste",
    "Bessernden": "Bessernde",
    "Besserns": "Bessern",
    "Bestallungen": "Bestallung",
    "Bestand": "bestehen",
    "Bestande": "Bestand",
    "Bestandene": "bestanden",
    "Bestandenen": "Bestandene",
    "Bestandes": "Bestand",
    "Bestands": "Bestand",
    "Bestandsaufnahmen": "Bestandsaufnahme",
    "Bestandteile": "Bestandteil",
    "Bestandteilen": "Bestandteil",
    "Bestandteiles": "Bestandteil",
    "Bestandteils": "Bestandteil",
    "Bestattenden": "Bestattende",
    "Bestattens": "Bestatten",
    "Bestattete": "bestattet",
    "Bestatteten": "Bestattete",
    "Bestaunenden": "Bestaunende",
    "Bestaunens": "Bestaunen",
    "Bestaunte": "bestaunt",
    "Bestaunten": "Bestaunte",
    "Bestaunteren": "Bestauntere",
    "Bestauntesten": "Bestaunteste",
    "Bestechenden": "Bestechende",
    "Bestechenderen": "Bestechendere",
    "Bestechendsten": "Bestechendste",
    "Bestechens": "Bestechen",
    "Bestechlichen": "Bestechliche",
    "Bestechlicheren": "Bestechlichere",
    "Bestechlichsten": "Bestechlichste",
    "Bestechungen": "Bestechung",
    "Bestecke": "Besteck",
    "Bestecken": "Besteck",
    "Besteckes": "Besteck",
    "Bestecks": "Besteck",
    "Bestehenbleibenden": "Bestehenbleibende",
    "Bestehenbleibens": "Bestehenbleiben",
    "Bestehenden": "Bestehende",
    "Bestehengebliebenen": "Bestehengebliebene",
    "Bestehens": "Bestehen",
    "Bestehlenden": "Bestehlende",
    "Bestehlens": "Bestehlen",
    "Besteigenden": "Besteigende",
    "Besteigens": "Besteigen",
    "Bestellenden": "Bestellende",
    "Bestellens": "Bestellen",
    "Bestellern": "Besteller",
    "Bestellers": "Besteller",
    "Bestellnummern": "Bestellnummer",
    "Bestellscheine": "Bestellschein",
    "Bestellscheinen": "Bestellschein",
    "Bestellscheins": "Bestellschein",
    "Bestellte": "bestellt",
    "Bestellten": "Bestellte",
    "Bestellungen": "Bestellung",
    "Bestellzetteln": "Bestellzettel",
    "Bestellzettels": "Bestellzettel",
    "Besteuernden": "Besteuernde",
    "Besteuerns": "Besteuern",
    "Besteuerte": "besteuert",
    "Besteuerten": "Besteuerte",
    "Bestiegenen": "Bestiegene",
    "Bestimmbaren": "Bestimmbare",
    "Bestimmenden": "Bestimmende",
    "Bestimmenderen": "Bestimmendere",
    "Bestimmendsten": "Bestimmendste",
    "Bestimmens": "Bestimmen",
    "Bestimmte": "bestimmt",
    "Bestimmten": "Bestimmte",
    "Bestimmteren": "Bestimmtere",
    "Bestimmtesten": "Bestimmteste",
    "Bestimmtseins": "Bestimmtsein",
    "Bestimmungen": "Bestimmung",
    "Bestmögliche": "bestmöglich",
    "Bestmöglichen": "Bestmögliche",
    "Bestochenen": "Bestochene",
    "Bestocheneren": "Bestochenere",
    "Bestochensten": "Bestochenste",
    "Bestohlenen": "Bestohlene",
    "Bestrafenden": "Bestrafende",
    "Bestrafenderen": "Bestrafendere",
    "Bestrafendsten": "Bestrafendste",
    "Bestrafens": "Bestrafen",
    "Bestrafte": "bestraft",
    "Bestraften": "Bestrafte",
    "Bestrafteren": "Bestraftere",
    "Bestraftesten": "Bestrafteste",
    "Bestrafungen": "Bestrafung",
    "Bestrahlenden": "Bestrahlende",
    "Bestrahlens": "Bestrahlen",
    "Bestrahlte": "bestrahlt",
    "Bestrahlten": "Bestrahlte",
    "Bestrahlteren": "Bestrahltere",
    "Bestrahltesten": "Bestrahlteste",
    "Bestrahlungen": "Bestrahlung",
    "Bestrebens": "Bestreben",
    "Bestreikenden": "Bestreikende",
    "Bestreikens": "Bestreiken",
    "Bestreikte": "bestreikt",
    "Bestreikten": "Bestreikte",
    "Bestreitenden": "Bestreitende",
    "Bestreitens": "Bestreiten",
    "Bestreuenden": "Bestreuende",
    "Bestreuens": "Bestreuen",
    "Bestreute": "bestreut",
    "Bestreuten": "Bestreute",
    "Bestrittenen": "Bestrittene",
    "Bestritteneren": "Bestrittenere",
    "Bestrittensten": "Bestrittenste",
    "Bestsellern": "Bestseller",
    "Bestsellers": "Bestseller",
    "Bestuhlenden": "Bestuhlende",
    "Bestuhlens": "Bestuhlen",
    "Bestuhlte": "bestuhlt",
    "Bestuhlten": "Bestuhlte",
    "Bestände": "Bestand",
    "Beständen": "Bestand",
    "Bestärkenden": "Bestärkende",
    "Bestärkenderen": "Bestärkendere",
    "Bestärkendsten": "Bestärkendste",
    "Bestärkens": "Bestärken",
    "Bestärkte": "bestärkt",
    "Bestärkten": "Bestärkte",
    "Bestärkteren": "Bestärktere",
    "Bestärktesten": "Bestärkteste",
    "Bestätigenden": "Bestätigende",
    "Bestätigens": "Bestätigen",
    "Bestätigte": "bestätigt",
    "Bestätigten": "Bestätigte",
    "Bestätigungen": "Bestätigung",
    "Bestäubenden": "Bestäubende",
    "Bestäubens": "Bestäuben",
    "Bestäubte": "bestäubt",
    "Bestäubten": "Bestäubte",
    "Bestäubteren": "Bestäubtere",
    "Bestäubtesten": "Bestäubteste",
    "Bestöhnenden": "Bestöhnende",
    "Bestöhnenderen": "Bestöhnendere",
    "Bestöhnendsten": "Bestöhnendste",
    "Bestöhnens": "Bestöhnen",
    "Bestöhnte": "bestöhnt",
    "Bestöhnten": "Bestöhnte",
    "Bestöhnteren": "Bestöhntere",
    "Bestöhntesten": "Bestöhnteste",
    "Bestürzenden": "Bestürzende",
    "Bestürzens": "Bestürzen",
    "Bestürzte": "bestürzt",
    "Bestürzten": "Bestürzte",
    "Bestürzteren": "Bestürztere",
    "Bestürztesten": "Bestürzteste",
    "Besuch": "besuchen",
    "Besuche": "besuchen",
    "Besuchen": "Besuch",
    "Besuchenden": "Besuchende",
    "Besuchens": "Besuchen",
    "Besuchern": "Besucher",
    "Besuchers": "Besucher",
    "Besuches": "Besuch",
    "Besuchs": "Besuch",
    "Besuchskarten": "Besuchskarte",
    "Besuchte": "besucht",
    "Besuchten": "Besuchte",
    "Besuchteren": "Besuchtere",
    "Besuchtesten": "Besuchteste",
    "Besudelnden": "Besudelnde",
    "Besudelnderen": "Besudelndere",
    "Besudelndsten": "Besudelndste",
    "Besudelns": "Besudeln",
    "Besudelte": "besudelt",
    "Besudelten": "Besudelte",
    "Besudelteren": "Besudeltere",
    "Besudeltesten": "Besudelteste",
    "Besungenen": "Besungene",
    "Beswingenden": "Beswingende",
    "Beswingenderen": "Beswingendere",
    "Beswingendsten": "Beswingendste",
    "Beswingens": "Beswingen",
    "Beswingte": "beswingt",
    "Beswingten": "Beswingte",
    "Beswingteren": "Beswingtere",
    "Beswingtesten": "Beswingteste",
    "Besänftigenden": "Besänftigende",
    "Besänftigenderen": "Besänftigendere",
    "Besänftigendsten": "Besänftigendste",
    "Besänftigens": "Besänftigen",
    "Besänftigte": "besänftigt",
    "Besänftigten": "Besänftigte",
    "Besänftigteren": "Besänftigtere",
    "Besänftigtesten": "Besänftigteste",
    "Betagten": "Betagte",
    "Betagteren": "Betagtere",
    "Betagtesten": "Betagteste",
    "Betankenden": "Betankende",
    "Betankens": "Betanken",
    "Betankte": "betankt",
    "Betankten": "Betankte",
    "Betatschenden": "Betatschende",
    "Betatschens": "Betatschen",
    "Betatschte": "betatscht",
    "Betatschten": "Betatschte",
    "Betbruders": "Betbruder",
    "Betbrüder": "Betbruder",
    "Betbrüdern": "Betbruder",
    "Beteiligenden": "Beteiligende",
    "Beteiligens": "Beteiligen",
    "Beteiligte": "beteiligt",
    "Beteiligten": "Beteiligte",
    "Beteiligungen": "Beteiligung",
    "Betenden": "Betende",
    "Betens": "Beten",
    "Betern": "Beter",
    "Beters": "Beter",
    "Beteuernden": "Beteuernde",
    "Beteuerns": "Beteuern",
    "Beteuerte": "beteuert",
    "Beteuerten": "Beteuerte",
    "Beteuerungen": "Beteuerung",
    "Betfahrten": "Betfahrt",
    "Betgange": "Betgang",
    "Betgangs": "Betgang",
    "Betgänge": "Betgang",
    "Betgängen": "Betgang",
    "Betitelnden": "Betitelnde",
    "Betitelns": "Betiteln",
    "Betitelte": "betitelt",
    "Betitelten": "Betitelte",
    "Beton": "betonen",
    "Betonenden": "Betonende",
    "Betonens": "Betonen",
    "Betonierenden": "Betonierende",
    "Betonierens": "Betonieren",
    "Betonierte": "betoniert",
    "Betonierten": "Betonierte",
    "Betonierteren": "Betoniertere",
    "Betoniertesten": "Betonierteste",
    "Betons": "Beton",
    "Betonte": "betont",
    "Betonten": "Betonte",
    "Betonteren": "Betontere",
    "Betontesten": "Betonteste",
    "Betonungen": "Betonung",
    "Betrachte": "betrachten",
    "Betrachtenden": "Betrachtende",
    "Betrachtens": "Betrachten",
    "Betrachterinnen": "Betrachterin",
    "Betrachtern": "Betrachter",
    "Betrachters": "Betrachter",
    "Betrachtes": "Betracht",
    "Betrachtete": "betrachtet",
    "Betrachteten": "Betrachtete",
    "Betrachteteren": "Betrachtetere",
    "Betrachtetesten": "Betrachteteste",
    "Betrachts": "Betracht",
    "Betrachtungen": "Betrachtung",
    "Betrachtungsweisen": "Betrachtungsweise",
    "Betrag": "betragen",
    "Betrage": "betragen",
    "Betragenden": "Betragende",
    "Betragenen": "Betragene",
    "Betragens": "Betragen",
    "Betrages": "Betrag",
    "Betrags": "Betrag",
    "Betrauenden": "Betrauende",
    "Betrauens": "Betrauen",
    "Betraute": "betraut",
    "Betrauten": "Betraute",
    "Betreffenden": "Betreffende",
    "Betreffens": "Betreffen",
    "Betreibenden": "Betreibende",
    "Betreibens": "Betreiben",
    "Betreibern": "Betreiber",
    "Betreibers": "Betreiber",
    "Betretenden": "Betretende",
    "Betretenen": "Betretene",
    "Betreteneren": "Betretenere",
    "Betretens": "Betreten",
    "Betretenste": "betreten",
    "Betretensten": "Betretenste",
    "Betreuenden": "Betreuende",
    "Betreuens": "Betreuen",
    "Betreuern": "Betreuer",
    "Betreuers": "Betreuer",
    "Betreute": "betreut",
    "Betreuten": "Betreute",
    "Betreuungen": "Betreuung",
    "Betrieb": "betreiben",
    "Betriebe": "Betrieb",
    "Betrieben": "Betrieb",
    "Betriebene": "betrieben",
    "Betriebenen": "Betriebene",
    "Betriebes": "Betrieb",
    "Betrieblichen": "Betriebliche",
    "Betriebs": "Betrieb",
    "Betriebsame": "betriebsam",
    "Betriebsamen": "Betriebsame",
    "Betriebsameren": "Betriebsamere",
    "Betriebsamsten": "Betriebsamste",
    "Betriebsbereiten": "Betriebsbereite",
    "Betriebseigenen": "Betriebseigene",
    "Betrinkenden": "Betrinkende",
    "Betrinkenderen": "Betrinkendere",
    "Betrinkendsten": "Betrinkendste",
    "Betrinkens": "Betrinken",
    "Betroffenen": "Betroffene",
    "Betroffeneren": "Betroffenere",
    "Betroffenheiten": "Betroffenheit",
    "Betroffenste": "betroffen",
    "Betroffensten": "Betroffenste",
    "Betrogenen": "Betrogene",
    "Betrogeneren": "Betrogenere",
    "Betrogensten": "Betrogenste",
    "Betruge": "Betrug",
    "Betruges": "Betrug",
    "Betrugs": "Betrug",
    "Betrunkenen": "Betrunkene",
    "Betrunkeneren": "Betrunkenere",
    "Betrunkensten": "Betrunkenste",
    "Beträchtlichen": "Beträchtliche",
    "Beträge": "Betrag",
    "Beträgen": "Betrag",
    "Beträufelnden": "Beträufelnde",
    "Beträufelnderen": "Beträufelndere",
    "Beträufelndsten": "Beträufelndste",
    "Beträufelns": "Beträufeln",
    "Beträufelte": "beträufelt",
    "Beträufelten": "Beträufelte",
    "Beträufelteren": "Beträufeltere",
    "Beträufeltesten": "Beträufelteste",
    "Betrübenden": "Betrübende",
    "Betrübenderen": "Betrübendere",
    "Betrübendsten": "Betrübendste",
    "Betrübens": "Betrüben",
    "Betrüblichen": "Betrübliche",
    "Betrüblicheren": "Betrüblichere",
    "Betrüblichsten": "Betrüblichste",
    "Betrübte": "betrübt",
    "Betrübten": "Betrübte",
    "Betrübteren": "Betrübtere",
    "Betrübtesten": "Betrübteste",
    "Betrüge": "betrügen",
    "Betrügen": "Betrug",
    "Betrügenden": "Betrügende",
    "Betrügenderen": "Betrügendere",
    "Betrügendsten": "Betrügendste",
    "Betrügens": "Betrügen",
    "Betrügerinnen": "Betrügerin",
    "Betrügerische": "betrügerisch",
    "Betrügerischen": "Betrügerische",
    "Betrügern": "Betrüger",
    "Betrügers": "Betrüger",
    "Bettage": "Bettag",
    "Bettagen": "Bettag",
    "Bettags": "Bettag",
    "Bette": "betten",
    "Bettelarmen": "Bettelarme",
    "Bettelnden": "Bettelnde",
    "Bettelnderen": "Bettelndere",
    "Bettelndsten": "Bettelndste",
    "Bettelns": "Betteln",
    "Bettelordens": "Bettelorden",
    "Betten": "Bett",
    "Bettenden": "Bettende",
    "Bettenmachens": "Bettenmachen",
    "Bettens": "Betten",
    "Bettes": "Bett",
    "Bettgeschichten": "Bettgeschichte",
    "Bettinas": "Bettina",
    "Bettlern": "Bettler",
    "Bettlers": "Bettler",
    "Bettlägerige": "bettlägerig",
    "Bettlägerigen": "Bettlägerige",
    "Bettpfannen": "Bettpfanne",
    "Betts": "Bett",
    "Bettstellen": "Bettstelle",
    "Betuchte": "betucht",
    "Betuchten": "Betuchte",
    "Betuchteren": "Betuchtere",
    "Betuchtesten": "Betuchteste",
    "Betupfenden": "Betupfende",
    "Betupfens": "Betupfen",
    "Betupfte": "betupft",
    "Betupften": "Betupfte",
    "Betätigenden": "Betätigende",
    "Betätigens": "Betätigen",
    "Betätigte": "betätigt",
    "Betätigten": "Betätigte",
    "Betäubenden": "Betäubende",
    "Betäubens": "Betäuben",
    "Betäubte": "betäubt",
    "Betäubten": "Betäubte",
    "Betäubteren": "Betäubtere",
    "Betäubtesten": "Betäubteste",
    "Betörenden": "Betörende",
    "Betörenderen": "Betörendere",
    "Betörendsten": "Betörendste",
    "Betörens": "Betören",
    "Betörte": "betört",
    "Betörten": "Betörte",
    "Betörteren": "Betörtere",
    "Betörtesten": "Betörteste",
    "Beugen": "Beuge",
    "Beugenden": "Beugende",
    "Beugenderen": "Beugendere",
    "Beugendsten": "Beugendste",
    "Beugens": "Beugen",
    "Beulen": "Beule",
    "Beulenden": "Beulende",
    "Beulens": "Beulen",
    "Beunruhigenden": "Beunruhigende",
    "Beunruhigenderen": "Beunruhigendere",
    "Beunruhigendsten": "Beunruhigendste",
    "Beunruhigens": "Beunruhigen",
    "Beunruhigte": "beunruhigt",
    "Beunruhigten": "Beunruhigte",
    "Beurkundenden": "Beurkundende",
    "Beurkundens": "Beurkunden",
    "Beurkundete": "beurkundet",
    "Beurkundeten": "Beurkundete",
    "Beurkundungen": "Beurkundung",
    "Beurlaubenden": "Beurlaubende",
    "Beurlaubens": "Beurlauben",
    "Beurlaubte": "beurlaubt",
    "Beurlaubten": "Beurlaubte",
    "Beurteilenden": "Beurteilende",
    "Beurteilens": "Beurteilen",
    "Beurteilte": "beurteilt",
    "Beurteilten": "Beurteilte",
    "Beurteilungen": "Beurteilung",
    "Beute": "beuten",
    "Beutel": "beuteln",
    "Beuteln": "Beutel",
    "Beutelnden": "Beutelnde",
    "Beutelns": "Beuteln",
    "Beutels": "Beutel",
    "Beuten": "Beute",
    "Beutenden": "Beutende",
    "Beutenderen": "Beutendere",
    "Beutendsten": "Beutendste",
    "Beutens": "Beuten",
    "Bevollmächtigenden": "Bevollmächtigende",
    "Bevollmächtigens": "Bevollmächtigen",
    "Bevollmächtigte": "bevollmächtigt",
    "Bevollmächtigten": "Bevollmächtigte",
    "Bevorgestandenen": "Bevorgestandene",
    "Bevormundenden": "Bevormundende",
    "Bevormundenderen": "Bevormundendere",
    "Bevormundendsten": "Bevormundendste",
    "Bevormundens": "Bevormunden",
    "Bevormundete": "bevormundet",
    "Bevormundeten": "Bevormundete",
    "Bevormundeteren": "Bevormundetere",
    "Bevormundetesten": "Bevormundeteste",
    "Bevorstehenden": "Bevorstehende",
    "Bevorstehens": "Bevorstehen",
    "Bevorteilenden": "Bevorteilende",
    "Bevorteilens": "Bevorteilen",
    "Bevorteilte": "bevorteilt",
    "Bevorteilten": "Bevorteilte",
    "Bevorzugenden": "Bevorzugende",
    "Bevorzugens": "Bevorzugen",
    "Bevorzugte": "bevorzugt",
    "Bevorzugten": "Bevorzugte",
    "Bevorzugteren": "Bevorzugtere",
    "Bevorzugtesten": "Bevorzugteste",
    "Bevorzugungen": "Bevorzugung",
    "Bevölkernden": "Bevölkernde",
    "Bevölkernderen": "Bevölkerndere",
    "Bevölkerndsten": "Bevölkerndste",
    "Bevölkerns": "Bevölkern",
    "Bevölkerte": "bevölkert",
    "Bevölkerten": "Bevölkerte",
    "Bevölkerteren": "Bevölkertere",
    "Bevölkertesten": "Bevölkerteste",
    "Bevölkerungen": "Bevölkerung",
    "Bevölkerungsdichten": "Bevölkerungsdichte",
    "Bewachenden": "Bewachende",
    "Bewachens": "Bewachen",
    "Bewachsenden": "Bewachsende",
    "Bewachsenen": "Bewachsene",
    "Bewachseneren": "Bewachsenere",
    "Bewachsens": "Bewachsen",
    "Bewachsenste": "bewachsen",
    "Bewachsensten": "Bewachsenste",
    "Bewachte": "bewacht",
    "Bewachten": "Bewachte",
    "Bewachteren": "Bewachtere",
    "Bewachtesten": "Bewachteste",
    "Bewaffnenden": "Bewaffnende",
    "Bewaffnens": "Bewaffnen",
    "Bewaffnete": "bewaffnet",
    "Bewaffneten": "Bewaffnete",
    "Bewaffneteren": "Bewaffnetere",
    "Bewaffnetesten": "Bewaffneteste",
    "Bewaffnungen": "Bewaffnung",
    "Bewahrenden": "Bewahrende",
    "Bewahrens": "Bewahren",
    "Bewahrte": "bewahrt",
    "Bewahrten": "Bewahrte",
    "Bewahrteren": "Bewahrtere",
    "Bewahrtesten": "Bewahrteste",
    "Bewegbare": "bewegbar",
    "Bewegbaren": "Bewegbare",
    "Bewegenden": "Bewegende",
    "Bewegenderen": "Bewegendere",
    "Bewegendsten": "Bewegendste",
    "Bewegens": "Bewegen",
    "Beweglichen": "Bewegliche",
    "Beweglicheren": "Beweglichere",
    "Beweglichsten": "Beweglichste",
    "Bewegte": "bewegt",
    "Bewegten": "Bewegte",
    "Bewegteren": "Bewegtere",
    "Bewegtesten": "Bewegteste",
    "Bewegungen": "Bewegung",
    "Bewegungslose": "bewegungslos",
    "Bewegungslosen": "Bewegungslose",
    "Bewegungsloseren": "Bewegungslosere",
    "Bewegungslosesten": "Bewegungsloseste",
    "Beweihräuchernden": "Beweihräuchernde",
    "Beweihräuchernderen": "Beweihräucherndere",
    "Beweihräucherns": "Beweihräuchern",
    "Beweihräucherte": "beweihräuchert",
    "Beweihräucherten": "Beweihräucherte",
    "Beweihräucherteren": "Beweihräuchertere",
    "Beweinenden": "Beweinende",
    "Beweinenderen": "Beweinendere",
    "Beweinendsten": "Beweinendste",
    "Beweinens": "Beweinen",
    "Beweinte": "beweint",
    "Beweinten": "Beweinte",
    "Beweinteren": "Beweintere",
    "Beweintesten": "Beweinteste",
    "Beweis": "beweisen",
    "Beweisaufnahmen": "Beweisaufnahme",
    "Beweise": "beweisen",
    "Beweisen": "Beweis",
    "Beweisenden": "Beweisende",
    "Beweisens": "Beweisen",
    "Beweises": "Beweis",
    "Beweisketten": "Beweiskette",
    "Beweiskräftige": "beweiskräftig",
    "Beweiskräftigen": "Beweiskräftige",
    "Bewendenden": "Bewendende",
    "Bewendens": "Bewenden",
    "Bewendete": "bewendet",
    "Bewendeten": "Bewendete",
    "Bewerbenden": "Bewerbende",
    "Bewerbens": "Bewerben",
    "Bewerberinnen": "Bewerberin",
    "Bewerbern": "Bewerber",
    "Bewerbers": "Bewerber",
    "Bewerbungen": "Bewerbung",
    "Bewerfenden": "Bewerfende",
    "Bewerfens": "Bewerfen",
    "Bewerkstelligenden": "Bewerkstelligende",
    "Bewerkstelligens": "Bewerkstelligen",
    "Bewerkstelligte": "bewerkstelligt",
    "Bewerkstelligten": "Bewerkstelligte",
    "Bewertenden": "Bewertende",
    "Bewertenderen": "Bewertendere",
    "Bewertendsten": "Bewertendste",
    "Bewertens": "Bewerten",
    "Bewertete": "bewertet",
    "Bewerteten": "Bewertete",
    "Bewertungen": "Bewertung",
    "Bewiesenen": "Bewiesene",
    "Bewieseneren": "Bewiesenere",
    "Bewiesensten": "Bewiesenste",
    "Bewilligenden": "Bewilligende",
    "Bewilligens": "Bewilligen",
    "Bewilligte": "bewilligt",
    "Bewilligten": "Bewilligte",
    "Bewirkenden": "Bewirkende",
    "Bewirkenderen": "Bewirkendere",
    "Bewirkendsten": "Bewirkendste",
    "Bewirkens": "Bewirken",
    "Bewirkte": "bewirkt",
    "Bewirkten": "Bewirkte",
    "Bewirtenden": "Bewirtende",
    "Bewirtenderen": "Bewirtendere",
    "Bewirtendsten": "Bewirtendste",
    "Bewirtens": "Bewirten",
    "Bewirtete": "bewirtet",
    "Bewirteten": "Bewirtete",
    "Bewirteteren": "Bewirtetere",
    "Bewirtetesten": "Bewirteteste",
    "Bewirtschaftenden": "Bewirtschaftende",
    "Bewirtschaftens": "Bewirtschaften",
    "Bewirtschaftete": "bewirtschaftet",
    "Bewirtschafteten": "Bewirtschaftete",
    "Bewogenen": "Bewogene",
    "Bewohnbaren": "Bewohnbare",
    "Bewohnbareren": "Bewohnbarere",
    "Bewohnbarsten": "Bewohnbarste",
    "Bewohnenden": "Bewohnende",
    "Bewohnens": "Bewohnen",
    "Bewohnern": "Bewohner",
    "Bewohners": "Bewohner",
    "Bewohnte": "bewohnt",
    "Bewohnten": "Bewohnte",
    "Bewohnteren": "Bewohntere",
    "Bewohntesten": "Bewohnteste",
    "Beworbenen": "Beworbene",
    "Beworfenen": "Beworfene",
    "Beworfeneren": "Beworfenere",
    "Beworfensten": "Beworfenste",
    "Bewuchernden": "Bewuchernde",
    "Bewuchernderen": "Bewucherndere",
    "Bewucherndsten": "Bewucherndste",
    "Bewucherns": "Bewuchern",
    "Bewucherte": "bewuchert",
    "Bewucherten": "Bewucherte",
    "Bewucherteren": "Bewuchertere",
    "Bewuchertesten": "Bewucherteste",
    "Bewunderinnen": "Bewunderin",
    "Bewundernden": "Bewundernde",
    "Bewunderns": "Bewundern",
    "Bewundernswerte": "bewundernswert",
    "Bewundernswerten": "Bewundernswerte",
    "Bewundernswerteren": "Bewundernswertere",
    "Bewunderte": "bewundert",
    "Bewunderten": "Bewunderte",
    "Bewunderteren": "Bewundertere",
    "Bewundertesten": "Bewunderteste",
    "Bewunderungen": "Bewunderung",
    "Bewußte": "bewußt",
    "Bewußten": "Bewußte",
    "Bewußteren": "Bewußtere",
    "Bewußtesten": "Bewußteste",
    "Bewußtlosen": "Bewußtlose",
    "Bewußtseins": "Bewußtsein",
    "Bewährende": "bewährend",
    "Bewährenden": "Bewährende",
    "Bewährens": "Bewähren",
    "Bewährte": "bewährt",
    "Bewährten": "Bewährte",
    "Bewährtere": "bewährt",
    "Bewährteren": "Bewährtere",
    "Bewährteste": "bewährt",
    "Bewährtesten": "Bewährteste",
    "Bewährungen": "Bewährung",
    "Bewährungsproben": "Bewährungsprobe",
    "Bewältigenden": "Bewältigende",
    "Bewältigens": "Bewältigen",
    "Bewältigte": "bewältigt",
    "Bewältigten": "Bewältigte",
    "Bewältigungen": "Bewältigung",
    "Bewässernden": "Bewässernde",
    "Bewässernderen": "Bewässerndere",
    "Bewässerndsten": "Bewässerndste",
    "Bewässerns": "Bewässern",
    "Bewässerte": "bewässert",
    "Bewässerten": "Bewässerte",
    "Bewässerteren": "Bewässertere",
    "Bewässertesten": "Bewässerteste",
    "Bewässerungen": "Bewässerung",
    "Bewässerungsanlagen": "Bewässerungsanlage",
    "Bewölkenden": "Bewölkende",
    "Bewölkens": "Bewölken",
    "Bewölkte": "bewölkt",
    "Bewölkten": "Bewölkte",
    "Bewölkteren": "Bewölktere",
    "Bewölktesten": "Bewölkteste",
    "Bewölkungen": "Bewölkung",
    "Bezahlbare": "bezahlbar",
    "Bezahlbaren": "Bezahlbare",
    "Bezahlenden": "Bezahlende",
    "Bezahlens": "Bezahlen",
    "Bezahlte": "bezahlt",
    "Bezahlten": "Bezahlte",
    "Bezahlteren": "Bezahltere",
    "Bezahltesten": "Bezahlteste",
    "Bezahlungen": "Bezahlung",
    "Bezaubernden": "Bezaubernde",
    "Bezaubernderen": "Bezauberndere",
    "Bezauberndsten": "Bezauberndste",
    "Bezauberns": "Bezaubern",
    "Bezauberte": "bezaubert",
    "Bezauberten": "Bezauberte",
    "Bezeichnenden": "Bezeichnende",
    "Bezeichnens": "Bezeichnen",
    "Bezeichnete": "bezeichnet",
    "Bezeichneten": "Bezeichnete",
    "Bezeichnungen": "Bezeichnung",
    "Bezeugenden": "Bezeugende",
    "Bezeugens": "Bezeugen",
    "Bezeugte": "bezeugt",
    "Bezeugten": "Bezeugte",
    "Bezeugungen": "Bezeugung",
    "Bezichtigenden": "Bezichtigende",
    "Bezichtigens": "Bezichtigen",
    "Bezichtigte": "bezichtigt",
    "Bezichtigten": "Bezichtigte",
    "Beziehenden": "Beziehende",
    "Beziehens": "Beziehen",
    "Beziehungen": "Beziehung",
    "Beziehungskisten": "Beziehungskiste",
    "Beziffernden": "Beziffernde",
    "Bezifferns": "Beziffern",
    "Bezifferte": "beziffert",
    "Bezifferten": "Bezifferte",
    "Bezirke": "Bezirk",
    "Bezirken": "Bezirk",
    "Bezirkes": "Bezirk",
    "Bezirks": "Bezirk",
    "Bezogenen": "Bezogene",
    "Bezuge": "Bezug",
    "Bezuges": "Bezug",
    "Bezugnahmen": "Bezugnahme",
    "Bezugs": "Bezug",
    "Bezugsfertige": "bezugsfertig",
    "Bezugsfertigen": "Bezugsfertige",
    "Bezugsquellen": "Bezugsquelle",
    "Bezuschussenden": "Bezuschussende",
    "Bezuschussenderen": "Bezuschussendere",
    "Bezuschussendsten": "Bezuschussendste",
    "Bezuschussens": "Bezuschussen",
    "Bezuschußte": "bezuschußt",
    "Bezuschußten": "Bezuschußte",
    "Bezuschußteren": "Bezuschußtere",
    "Bezuschußtesten": "Bezuschußteste",
    "Bezweckenden": "Bezweckende",
    "Bezweckens": "Bezwecken",
    "Bezweckte": "bezweckt",
    "Bezweckten": "Bezweckte",
    "Bezweifelnden": "Bezweifelnde",
    "Bezweifelns": "Bezweifeln",
    "Bezweifelte": "bezweifelt",
    "Bezweifelten": "Bezweifelte",
    "Bezweifelteren": "Bezweifeltere",
    "Bezweifeltesten": "Bezweifelteste",
    "Bezwingbaren": "Bezwingbare",
    "Bezüge": "Bezug",
    "Bezügen": "Bezug",
    "Beängstigenden": "Beängstigende",
    "Beängstigenderen": "Beängstigendere",
    "Beängstigendsten": "Beängstigendste",
    "Beängstigens": "Beängstigen",
    "Beängstigte": "beängstigt",
    "Beängstigten": "Beängstigte",
    "Beängstigteren": "Beängstigtere",
    "Beängstigtesten": "Beängstigteste",
    "Beäugenden": "Beäugende",
    "Beäugenderen": "Beäugendere",
    "Beäugendsten": "Beäugendste",
    "Beäugens": "Beäugen",
    "Beäugte": "beäugt",
    "Beäugten": "Beäugte",
    "Beäugteren": "Beäugtere",
    "Beäugtesten": "Beäugteste",
    "Biathlons": "Biathlon",
    "Bibbernden": "Bibbernde",
    "Bibbernderen": "Bibberndere",
    "Bibberndsten": "Bibberndste",
    "Bibberns": "Bibbern",
    "Bibelfesten": "Bibelfeste",
    "Bibelfesteren": "Bibelfestere",
    "Bibelfestesten": "Bibelfesteste",
    "Bibeln": "Bibel",
    "Bibelsprachen": "Bibelsprache",
    "Bibelstunden": "Bibelstunde",
    "Bibern": "Biber",
    "Bibers": "Biber",
    "Bibliographen": "Bibliograph",
    "Bibliographien": "Bibliographie",
    "Bibliographierenden": "Bibliographierende",
    "Bibliographierenderen": "Bibliographierendere",
    "Bibliographierens": "Bibliographieren",
    "Bibliographierte": "bibliographiert",
    "Bibliographierten": "Bibliographierte",
    "Bibliographierteren": "Bibliographiertere",
    "Bibliographischen": "Bibliographische",
    "Bibliophilen": "Bibliophile",
    "Bibliothekare": "Bibliothekar",
    "Bibliothekaren": "Bibliothekar",
    "Bibliothekarinnen": "Bibliothekarin",
    "Bibliothekars": "Bibliothekar",
    "Bibliotheken": "Bibliothek",
    "Biedenkopfs": "Biedenkopf",
    "Biedere": "biedern",
    "Biederen": "Biedere",
    "Biedereren": "Biederere",
    "Biedernden": "Biedernde",
    "Biederns": "Biedern",
    "Biedersten": "Biederste",
    "Biegbaren": "Biegbare",
    "Biegbareren": "Biegbarere",
    "Biegbarsten": "Biegbarste",
    "Biegen": "Biege",
    "Biegenden": "Biegende",
    "Biegens": "Biegen",
    "Biegeproben": "Biegeprobe",
    "Biegsamen": "Biegsame",
    "Biegsameren": "Biegsamere",
    "Biegsamsten": "Biegsamste",
    "Bielefeldern": "Bielefelder",
    "Bielefelders": "Bielefelder",
    "Bielefelds": "Bielefeld",
    "Bienchens": "Bienchen",
    "Bienen": "Biene",
    "Bierchens": "Bierchen",
    "Biere": "Bier",
    "Bieren": "Bier",
    "Bierernste": "bierernst",
    "Bierernsten": "Bierernste",
    "Bieres": "Bier",
    "Bierideen": "Bieridee",
    "Biers": "Bier",
    "Bieste": "Biest",
    "Biester": "Biest",
    "Biestern": "Biest",
    "Biestes": "Biest",
    "Biestige": "biestig",
    "Biestigen": "Biestige",
    "Biestigeren": "Biestigere",
    "Biestigsten": "Biestigste",
    "Biests": "Biest",
    "Bietenden": "Bietende",
    "Bietens": "Bieten",
    "Bietern": "Bieter",
    "Bieters": "Bieter",
    "Bigamisten": "Bigamist",
    "Bikinis": "Bikini",
    "Bilanzen": "Bilanz",
    "Bilanzierenden": "Bilanzierende",
    "Bilanzierenderen": "Bilanzierendere",
    "Bilanzierendsten": "Bilanzierendste",
    "Bilanzierens": "Bilanzieren",
    "Bilanzierte": "bilanziert",
    "Bilanzierten": "Bilanzierte",
    "Bilanzierteren": "Bilanziertere",
    "Bilanziertesten": "Bilanzierteste",
    "Bilateralen": "Bilaterale",
    "Bilde": "bilden",
    "Bildenden": "Bildende",
    "Bildens": "Bilden",
    "Bilder": "Bild",
    "Bildern": "Bild",
    "Bilderreiche": "bilderreich",
    "Bilderreichen": "Bilderreiche",
    "Bilderreicheren": "Bilderreichere",
    "Bilderreichsten": "Bilderreichste",
    "Bildes": "Bild",
    "Bildhaften": "Bildhafte",
    "Bildhauer": "bildhauern",
    "Bildhauerischen": "Bildhauerische",
    "Bildhauern": "Bildhauer",
    "Bildhauernden": "Bildhauernde",
    "Bildhauerns": "Bildhauern",
    "Bildhauers": "Bildhauer",
    "Bildhübschen": "Bildhübsche",
    "Bildnern": "Bildner",
    "Bildners": "Bildner",
    "Bildnisse": "Bildnis",
    "Bildnissen": "Bildnis",
    "Bildnisses": "Bildnis",
    "Bilds": "Bild",
    "Bildschöne": "bildschön",
    "Bildschönen": "Bildschöne",
    "Bildschöneren": "Bildschönere",
    "Bildschönsten": "Bildschönste",
    "Bildungen": "Bildung",
    "Bildungsfähige": "bildungsfähig",
    "Bildungsfähigen": "Bildungsfähige",
    "Bildungshungrigen": "Bildungshungrige",
    "Bildungshungrigeren": "Bildungshungrigere",
    "Bildungspolitischen": "Bildungspolitische",
    "Bildungsreisen": "Bildungsreise",
    "Bilinguale": "bilingual",
    "Bilingualen": "Bilinguale",
    "Billarde": "Billard",
    "Billarden": "Billard",
    "Billards": "Billard",
    "Billige": "billigen",
    "Billigen": "Billige",
    "Billigenden": "Billigende",
    "Billigens": "Billigen",
    "Billigeren": "Billigere",
    "Billigsten": "Billigste",
    "Billigwaren": "Billigware",
    "Billionen": "Billion",
    "Billionsteln": "Billionstel",
    "Billionstels": "Billionstel",
    "Bills": "Bill",
    "Bimetalle": "Bimetall",
    "Bimetallen": "Bimetall",
    "Bimetalls": "Bimetall",
    "Bimmel": "bimmeln",
    "Bimmelbahnen": "Bimmelbahn",
    "Bimmeln": "Bimmel",
    "Bimmelnden": "Bimmelnde",
    "Bimmelnderen": "Bimmelndere",
    "Bimmelndsten": "Bimmelndste",
    "Bimmelns": "Bimmeln",
    "Bimsenden": "Bimsende",
    "Bimsenderen": "Bimsendere",
    "Bimsendsten": "Bimsendste",
    "Bimsens": "Bimsen",
    "Binde": "binden",
    "Bindegewebes": "Bindegewebe",
    "Bindegliede": "Bindeglied",
    "Bindeglieder": "Bindeglied",
    "Bindegliedern": "Bindeglied",
    "Bindegliedes": "Bindeglied",
    "Bindeglieds": "Bindeglied",
    "Binden": "Binde",
    "Bindenden": "Bindende",
    "Bindens": "Binden",
    "Bindern": "Binder",
    "Binders": "Binder",
    "Bindestriche": "Bindestrich",
    "Bindestrichen": "Bindestrich",
    "Bindestrichs": "Bindestrich",
    "Bindeworte": "Bindewort",
    "Bindewortes": "Bindewort",
    "Bindeworts": "Bindewort",
    "Bindewörter": "Bindewort",
    "Bindewörtern": "Bindewort",
    "Bindfadens": "Bindfaden",
    "Bindfäden": "Bindfaden",
    "Bindings": "Binding",
    "Bindungen": "Bindung",
    "Binnengewässern": "Binnengewässer",
    "Binnengewässers": "Binnengewässer",
    "Binnenhafens": "Binnenhafen",
    "Binnenhandels": "Binnenhandel",
    "Binnenhäfen": "Binnenhafen",
    "Binnenlande": "Binnenland",
    "Binnenlandes": "Binnenland",
    "Binnenlands": "Binnenland",
    "Binnenländer": "Binnenland",
    "Binnenländern": "Binnenland",
    "Binnenmarkte": "Binnenmarkt",
    "Binnenmarkts": "Binnenmarkt",
    "Binnenmeere": "Binnenmeer",
    "Binnenmeeren": "Binnenmeer",
    "Binnenmeers": "Binnenmeer",
    "Binnenmärkte": "Binnenmarkt",
    "Binnenmärkten": "Binnenmarkt",
    "Binnenreime": "Binnenreim",
    "Binnenreimen": "Binnenreim",
    "Binnenreims": "Binnenreim",
    "Binnentiefs": "Binnentief",
    "Binnenverkehrs": "Binnenverkehr",
    "Binnenwanderungen": "Binnenwanderung",
    "Binnenwährungen": "Binnenwährung",
    "Binnenzolle": "Binnenzoll",
    "Binnenzolls": "Binnenzoll",
    "Binnenzölle": "Binnenzoll",
    "Binnenzöllen": "Binnenzoll",
    "Binome": "Binom",
    "Binomen": "Binom",
    "Binomialkoeffizienten": "Binomialkoeffizient",
    "Binomische": "binomisch",
    "Binomischen": "Binomische",
    "Binoms": "Binom",
    "Binsen": "Binse",
    "Binärziffern": "Binärziffer",
    "Bioalkohole": "Bioalkohol",
    "Bioalkoholen": "Bioalkohol",
    "Bioalkohols": "Bioalkohol",
    "Biochemikern": "Biochemiker",
    "Biochemikers": "Biochemiker",
    "Biochemische": "biochemisch",
    "Biochemischen": "Biochemische",
    "Biogenesen": "Biogenese",
    "Biogenetische": "biogenetisch",
    "Biogenetischen": "Biogenetische",
    "Biografien": "Biografie",
    "Biographen": "Biograph",
    "Biographien": "Biographie",
    "Biographische": "biographisch",
    "Biographischen": "Biographische",
    "Biokatalysatore": "Biokatalysator",
    "Biokatalysatoren": "Biokatalysator",
    "Biokatalysators": "Biokatalysator",
    "Bioladens": "Bioladen",
    "Biolithen": "Biolith",
    "Biologen": "Biologe",
    "Biologische": "biologisch",
    "Biologischen": "Biologische",
    "Biologisierenden": "Biologisierende",
    "Biologisierens": "Biologisieren",
    "Biologisierte": "biologisiert",
    "Biologisierten": "Biologisierte",
    "Bioläden": "Bioladen",
    "Biomoleküle": "Biomolekül",
    "Biomolekülen": "Biomolekül",
    "Biomoleküls": "Biomolekül",
    "Biomorphosen": "Biomorphose",
    "Biomotore": "Biomotor",
    "Biomotoren": "Biomotor",
    "Biomotors": "Biomotor",
    "Biomülls": "Biomüll",
    "Biophysikalische": "biophysikalisch",
    "Biophysikalischen": "Biophysikalische",
    "Bioprodukte": "Bioprodukt",
    "Bioprodukten": "Bioprodukt",
    "Bioproduktes": "Bioprodukt",
    "Biosatelliten": "Biosatellit",
    "Biotechnische": "biotechnisch",
    "Biotechnischen": "Biotechnische",
    "Biotests": "Biotest",
    "Biotonnen": "Biotonne",
    "Biotope": "Biotop",
    "Biotopen": "Biotop",
    "Biotopes": "Biotop",
    "Biotops": "Biotop",
    "Biotype": "Biotyp",
    "Biotypen": "Biotyp",
    "Biotyps": "Biotyp",
    "Birgits": "Birgit",
    "Birken": "Birke",
    "Birkene": "birken",
    "Birkenen": "Birkene",
    "Birnen": "Birne",
    "Bisamratten": "Bisamratte",
    "Bischofe": "Bischof",
    "Bischofs": "Bischof",
    "Bischofsheims": "Bischofsheim",
    "Bischöfe": "Bischof",
    "Bischöfen": "Bischof",
    "Bischöfliche": "bischöflich",
    "Bischöflichen": "Bischöfliche",
    "Bisexuelle": "bisexuell",
    "Bisexuellen": "Bisexuelle",
    "Bisherigen": "Bisherige",
    "Bisons": "Bison",
    "Bissens": "Bissen",
    "Bissigen": "Bissige",
    "Bissigeren": "Bissigere",
    "Bissigsten": "Bissigste",
    "Bistros": "Bistro",
    "Bistume": "Bistum",
    "Bistums": "Bistum",
    "Bistümer": "Bistum",
    "Bistümern": "Bistum",
    "Bitburgs": "Bitburg",
    "Bittbriefe": "Bittbrief",
    "Bittbriefen": "Bittbrief",
    "Bittbriefs": "Bittbrief",
    "Bitte": "bitten",
    "Bitten": "Bitte",
    "Bittenden": "Bittende",
    "Bittens": "Bitten",
    "Bitterböseren": "Bitterbösere",
    "Bitterbösesten": "Bitterböseste",
    "Bitteren": "Bittere",
    "Bittereren": "Bitterere",
    "Bittermitteln": "Bittermittel",
    "Bittermittels": "Bittermittel",
    "Bitterste": "bitter",
    "Bittersten": "Bitterste",
    "Bittersüßen": "Bittersüße",
    "Bittersüßeren": "Bittersüßere",
    "Bittersüßesten": "Bittersüßeste",
    "Bittgange": "Bittgang",
    "Bittgangs": "Bittgang",
    "Bittgesuche": "Bittgesuch",
    "Bittgesuchen": "Bittgesuch",
    "Bittgesuchs": "Bittgesuch",
    "Bittgänge": "Bittgang",
    "Bittgängen": "Bittgang",
    "Bittschreibens": "Bittschreiben",
    "Bittstellern": "Bittsteller",
    "Bittstellers": "Bittsteller",
    "Bizarre": "bizarr",
    "Bizarren": "Bizarre",
    "Bizarreren": "Bizarrere",
    "Bizarrsten": "Bizarrste",
    "Bizzenbachs": "Bizzenbach",
    "Björns": "Björn",
    "Blaffenden": "Blaffende",
    "Blaffenderen": "Blaffendere",
    "Blaffendsten": "Blaffendste",
    "Blaffens": "Blaffen",
    "Blagen": "Blage",
    "Blamabelste": "blamabel",
    "Blamabelsten": "Blamabelste",
    "Blamablen": "Blamable",
    "Blamableren": "Blamablere",
    "Blamagen": "Blamage",
    "Blamierenden": "Blamierende",
    "Blamierenderen": "Blamierendere",
    "Blamierendsten": "Blamierendste",
    "Blamierens": "Blamieren",
    "Blamierte": "blamiert",
    "Blamierten": "Blamierte",
    "Blamierteren": "Blamiertere",
    "Blamiertesten": "Blamierteste",
    "Blanken": "Blanke",
    "Blankeren": "Blankere",
    "Blankesten": "Blankeste",
    "Blankette": "Blankett",
    "Blanketten": "Blankett",
    "Blanketts": "Blankett",
    "Blankogeschäfte": "Blankogeschäft",
    "Blankogeschäften": "Blankogeschäft",
    "Blankogeschäfts": "Blankogeschäft",
    "Blankokaufe": "Blankokauf",
    "Blankokaufs": "Blankokauf",
    "Blankokredite": "Blankokredit",
    "Blankokrediten": "Blankokredit",
    "Blankokredits": "Blankokredit",
    "Blankokäufe": "Blankokauf",
    "Blankokäufen": "Blankokauf",
    "Blankos": "Blanko",
    "Blankoschecks": "Blankoscheck",
    "Blaschkes": "Blaschke",
    "Blase": "blasen",
    "Blasen": "Blase",
    "Blasenden": "Blasende",
    "Blasens": "Blasen",
    "Blasierten": "Blasierte",
    "Blasierteren": "Blasiertere",
    "Blasiertesten": "Blasierteste",
    "Blasinstrumente": "Blasinstrument",
    "Blasinstrumenten": "Blasinstrument",
    "Blasinstrumentes": "Blasinstrument",
    "Blasinstruments": "Blasinstrument",
    "Blaskapellen": "Blaskapelle",
    "Blasorchestern": "Blasorchester",
    "Blasorchesters": "Blasorchester",
    "Blasphemien": "Blasphemie",
    "Blasphemische": "blasphemisch",
    "Blasphemischen": "Blasphemische",
    "Blasphemischeren": "Blasphemischere",
    "Blasphemischsten": "Blasphemischste",
    "Blasse": "blassen",
    "Blassen": "Blasse",
    "Blassenden": "Blassende",
    "Blassens": "Blassen",
    "Blasseren": "Blassere",
    "Blassesten": "Blasseste",
    "Blatte": "Blatt",
    "Blattes": "Blatt",
    "Blattlose": "blattlos",
    "Blattlosen": "Blattlose",
    "Blattloseren": "Blattlosere",
    "Blattlosesten": "Blattloseste",
    "Blatts": "Blatt",
    "Blattweiseren": "Blattweisere",
    "Blattweisesten": "Blattweiseste",
    "Blaualgen": "Blaualge",
    "Blaubeeren": "Blaubeere",
    "Blaublütige": "blaublütig",
    "Blaublütigen": "Blaublütige",
    "Blaublütigeren": "Blaublütigere",
    "Blaublütigsten": "Blaublütigste",
    "Blauen": "Blaue",
    "Blauhemde": "Blauhemd",
    "Blauhemden": "Blauhemd",
    "Blauhemds": "Blauhemd",
    "Blaupausen": "Blaupause",
    "Blaus": "Blau",
    "Blaustichigen": "Blaustichige",
    "Blaustichigeren": "Blaustichigere",
    "Blaustichigsten": "Blaustichigste",
    "Blauäugige": "blauäugig",
    "Blauäugigen": "Blauäugige",
    "Blauäugigeren": "Blauäugigere",
    "Blauäugigsten": "Blauäugigste",
    "Blazern": "Blazer",
    "Blazers": "Blazer",
    "Blech": "blechen",
    "Bleche": "blechen",
    "Blechen": "Blech",
    "Blechenden": "Blechende",
    "Blechens": "Blechen",
    "Blecherne": "blechern",
    "Blechernen": "Blecherne",
    "Blecherneren": "Blechernere",
    "Blechernsten": "Blechernste",
    "Bleches": "Blech",
    "Blechs": "Blech",
    "Bleibenden": "Bleibende",
    "Bleibengelassenen": "Bleibengelassene",
    "Bleibenlassenden": "Bleibenlassende",
    "Bleibenlassens": "Bleibenlassen",
    "Bleibens": "Bleiben",
    "Bleichenden": "Bleichende",
    "Bleichens": "Bleichen",
    "Bleichgesichte": "Bleichgesicht",
    "Bleichgesichter": "Bleichgesicht",
    "Bleichgesichtern": "Bleichgesicht",
    "Bleichgesichtes": "Bleichgesicht",
    "Bleichgesichts": "Bleichgesicht",
    "Bleie": "Blei",
    "Bleien": "Bleie",
    "Bleierne": "bleiern",
    "Bleiernen": "Bleierne",
    "Bleierneren": "Bleiernere",
    "Bleiernsten": "Bleiernste",
    "Bleifreien": "Bleifreie",
    "Bleifreieren": "Bleifreiere",
    "Bleifreiesten": "Bleifreieste",
    "Bleigießern": "Bleigießer",
    "Bleigießers": "Bleigießer",
    "Bleihaltige": "bleihaltig",
    "Bleihaltigen": "Bleihaltige",
    "Bleihaltigeren": "Bleihaltigere",
    "Bleihaltigsten": "Bleihaltigste",
    "Bleis": "Blei",
    "Blende": "blenden",
    "Blenden": "Blende",
    "Blendenden": "Blendende",
    "Blendenderen": "Blendendere",
    "Blendendsten": "Blendendste",
    "Blendens": "Blenden",
    "Blendern": "Blender",
    "Blenders": "Blender",
    "Blendungen": "Blendung",
    "Blendwerke": "Blendwerk",
    "Blendwerken": "Blendwerk",
    "Blendwerks": "Blendwerk",
    "Blessuren": "Blessur",
    "Bleuenden": "Bleuende",
    "Bleuens": "Bleuen",
    "Blick": "blicken",
    "Blicke": "blicken",
    "Blicken": "Blick",
    "Blickenden": "Blickende",
    "Blickens": "Blicken",
    "Blickfange": "Blickfang",
    "Blickfangs": "Blickfang",
    "Blickfänge": "Blickfang",
    "Blickfängen": "Blickfang",
    "Blicks": "Blick",
    "Blindarme": "Blindarm",
    "Blindarmes": "Blindarm",
    "Blindarms": "Blindarm",
    "Blinde": "blind",
    "Blinden": "Blinde",
    "Blindenbüchereien": "Blindenbücherei",
    "Blindenhunde": "Blindenhund",
    "Blindenhunden": "Blindenhund",
    "Blindenhunds": "Blindenhund",
    "Blinderen": "Blindere",
    "Blindesten": "Blindeste",
    "Blindfliegenden": "Blindfliegende",
    "Blindfliegens": "Blindfliegen",
    "Blindfluge": "Blindflug",
    "Blindflugs": "Blindflug",
    "Blindflüge": "Blindflug",
    "Blindflügen": "Blindflug",
    "Blindgeflogenen": "Blindgeflogene",
    "Blindgängern": "Blindgänger",
    "Blindgängers": "Blindgänger",
    "Blindheiten": "Blindheit",
    "Blindlandungen": "Blindlandung",
    "Blindschleichen": "Blindschleiche",
    "Blindspiele": "Blindspiel",
    "Blindspielen": "Blindspiel",
    "Blindspiels": "Blindspiel",
    "Blindärme": "Blindarm",
    "Blindärmen": "Blindarm",
    "Blinkenden": "Blinkende",
    "Blinkenderen": "Blinkendere",
    "Blinkendsten": "Blinkendste",
    "Blinkens": "Blinken",
    "Blinkern": "Blinker",
    "Blinkers": "Blinker",
    "Blinkgeräte": "Blinkgerät",
    "Blinkgeräten": "Blinkgerät",
    "Blinkgeräts": "Blinkgerät",
    "Blinkleuchten": "Blinkleuchte",
    "Blinklichte": "Blinklicht",
    "Blinklichter": "Blinklicht",
    "Blinklichtern": "Blinklicht",
    "Blinklichtes": "Blinklicht",
    "Blinklichts": "Blinklicht",
    "Blinkzeichens": "Blinkzeichen",
    "Blinzelnden": "Blinzelnde",
    "Blinzelnderen": "Blinzelndere",
    "Blinzelndsten": "Blinzelndste",
    "Blinzelns": "Blinzeln",
    "Blitz": "blitzen",
    "Blitzartige": "blitzartig",
    "Blitzartigen": "Blitzartige",
    "Blitzartigeren": "Blitzartigere",
    "Blitzartigsten": "Blitzartigste",
    "Blitzblanken": "Blitzblanke",
    "Blitzblankeren": "Blitzblankere",
    "Blitzblankesten": "Blitzblankeste",
    "Blitze": "blitzen",
    "Blitzen": "Blitz",
    "Blitzenden": "Blitzende",
    "Blitzens": "Blitzen",
    "Blitzes": "Blitz",
    "Blitzgescheiten": "Blitzgescheite",
    "Blitzgescheiteren": "Blitzgescheitere",
    "Blitzs": "Blitz",
    "Blitzsaubere": "blitzsauber",
    "Blitzsauberen": "Blitzsaubere",
    "Blitzsaubereren": "Blitzsauberere",
    "Blitzsaubersten": "Blitzsauberste",
    "Blitzschnellen": "Blitzschnelle",
    "Blitzschnelleren": "Blitzschnellere",
    "Blitzschnellsten": "Blitzschnellste",
    "Blockaden": "Blockade",
    "Blockbuchstaben": "Blockbuchstabe",
    "Blocke": "Block",
    "Blockes": "Block",
    "Blockierenden": "Blockierende",
    "Blockierenderen": "Blockierendere",
    "Blockierendsten": "Blockierendste",
    "Blockierens": "Blockieren",
    "Blockierte": "blockiert",
    "Blockierten": "Blockierte",
    "Blockierteren": "Blockiertere",
    "Blockiertesten": "Blockierteste",
    "Blocks": "Block",
    "Blohme": "Blohm",
    "Blohmen": "Blohm",
    "Blohmes": "Blohm",
    "Blohms": "Blohm",
    "Blonden": "Blonde",
    "Blonderen": "Blondere",
    "Blondesten": "Blondeste",
    "Blondhaarigen": "Blondhaarige",
    "Blondinen": "Blondine",
    "Blondkopfe": "Blondkopf",
    "Blondkopfs": "Blondkopf",
    "Blondköpfe": "Blondkopf",
    "Blondköpfen": "Blondkopf",
    "Bloße": "bloß",
    "Bloßen": "Bloße",
    "Bloßgelegenen": "Bloßgelegene",
    "Bloßgelegeneren": "Bloßgelegenere",
    "Bloßgelegensten": "Bloßgelegenste",
    "Bloßgelegten": "Bloßgelegte",
    "Bloßgelegteren": "Bloßgelegtere",
    "Bloßgelegtesten": "Bloßgelegteste",
    "Bloßgestellten": "Bloßgestellte",
    "Bloßgestellteren": "Bloßgestelltere",
    "Bloßgestelltesten": "Bloßgestellteste",
    "Bloßlegenden": "Bloßlegende",
    "Bloßlegenderen": "Bloßlegendere",
    "Bloßlegendsten": "Bloßlegendste",
    "Bloßlegens": "Bloßlegen",
    "Bloßliegenden": "Bloßliegende",
    "Bloßliegenderen": "Bloßliegendere",
    "Bloßliegendsten": "Bloßliegendste",
    "Bloßliegens": "Bloßliegen",
    "Bloßstellenden": "Bloßstellende",
    "Bloßstellenderen": "Bloßstellendere",
    "Bloßstellendsten": "Bloßstellendste",
    "Bloßstellens": "Bloßstellen",
    "Blubbernden": "Blubbernde",
    "Blubbernderen": "Blubberndere",
    "Blubberndsten": "Blubberndste",
    "Blubberns": "Blubbern",
    "Bluffs": "Bluff",
    "Blumen": "Blume",
    "Blumenreiche": "blumenreich",
    "Blumenreichen": "Blumenreiche",
    "Blumenreicheren": "Blumenreichere",
    "Blumenreichsten": "Blumenreichste",
    "Blumigen": "Blumige",
    "Blumigeren": "Blumigere",
    "Blumigsten": "Blumigste",
    "Blusen": "Bluse",
    "Blutalgen": "Blutalge",
    "Blutarme": "blutarm",
    "Blutarmen": "Blutarme",
    "Blutbefleckten": "Blutbefleckte",
    "Blute": "bluten",
    "Bluten": "Blut",
    "Blutenden": "Blutende",
    "Blutenderen": "Blutendere",
    "Blutendsten": "Blutendste",
    "Blutens": "Bluten",
    "Blutes": "Blut",
    "Blutgruppen": "Blutgruppe",
    "Blutige": "blutig",
    "Blutigen": "Blutige",
    "Blutigeren": "Blutigere",
    "Blutigsten": "Blutigste",
    "Blutjungen": "Blutjunge",
    "Blutkonserven": "Blutkonserve",
    "Blutrünstige": "blutrünstig",
    "Blutrünstigen": "Blutrünstige",
    "Blutrünstigeren": "Blutrünstigere",
    "Blutrünstigsten": "Blutrünstigste",
    "Bluts": "Blut",
    "Blutsverwandte": "blutsverwandt",
    "Blutsverwandten": "Blutsverwandte",
    "Blutungen": "Blutung",
    "Blutunterlaufene": "blutunterlaufen",
    "Blutunterlaufenen": "Blutunterlaufene",
    "Blutärmeren": "Blutärmere",
    "Blähenden": "Blähende",
    "Blähenderen": "Blähendere",
    "Blähendsten": "Blähendste",
    "Blähens": "Blähen",
    "Blähungen": "Blähung",
    "Bläsern": "Bläser",
    "Bläsers": "Bläser",
    "Blässlichen": "Blässliche",
    "Blässlicheren": "Blässlichere",
    "Blässlichsten": "Blässlichste",
    "Blättchens": "Blättchen",
    "Blätter": "blättern",
    "Blätterigen": "Blätterige",
    "Blätterigeren": "Blätterigere",
    "Blätterigsten": "Blätterigste",
    "Blätterlosen": "Blätterlose",
    "Blätterloseren": "Blätterlosere",
    "Blätterlosesten": "Blätterloseste",
    "Blättern": "Blatt",
    "Blätternden": "Blätternde",
    "Blätterns": "Blättern",
    "Blättrigen": "Blättrige",
    "Bläuenden": "Bläuende",
    "Bläuens": "Bläuen",
    "Bläuliche": "bläulich",
    "Bläulichen": "Bläuliche",
    "Bläulicheren": "Bläulichere",
    "Bläulichsten": "Bläulichste",
    "Blöckchens": "Blöckchen",
    "Blöcke": "Block",
    "Blöcken": "Block",
    "Blöde": "blöd",
    "Blödelnden": "Blödelnde",
    "Blödelnderen": "Blödelndere",
    "Blödelndsten": "Blödelndste",
    "Blödelns": "Blödeln",
    "Blöden": "Blöde",
    "Blöderen": "Blödere",
    "Blödesten": "Blödeste",
    "Blödmanne": "Blödmann",
    "Blödmannes": "Blödmann",
    "Blödmanns": "Blödmann",
    "Blödmänner": "Blödmann",
    "Blödmännern": "Blödmann",
    "Blödsinnige": "blödsinnig",
    "Blödsinnigen": "Blödsinnige",
    "Blödsinnigeren": "Blödsinnigere",
    "Blödsinnigsten": "Blödsinnigste",
    "Blödsinns": "Blödsinn",
    "Blökenden": "Blökende",
    "Blökenderen": "Blökendere",
    "Blökendsten": "Blökendste",
    "Blökens": "Blöken",
    "Blößen": "Blöße",
    "Blühenden": "Blühende",
    "Blühenderen": "Blühendere",
    "Blühendsten": "Blühendste",
    "Blühens": "Blühen",
    "Blümchens": "Blümchen",
    "Blümeleins": "Blümelein",
    "Blüms": "Blüm",
    "Blüten": "Blüte",
    "Blütenlesen": "Blütenlese",
    "Blütenreiche": "blütenreich",
    "Blütenreichen": "Blütenreiche",
    "Blütenreicheren": "Blütenreichere",
    "Blütenreichsten": "Blütenreichste",
    "Bobbys": "Bobby",
    "Bobs": "Bob",
    "Bochums": "Bochum",
    "Bockbiere": "Bockbier",
    "Bockbieren": "Bockbier",
    "Bockbiers": "Bockbier",
    "Bocke": "Bock",
    "Bockenheimern": "Bockenheimer",
    "Bockenheimers": "Bockenheimer",
    "Bockenheims": "Bockenheim",
    "Bockes": "Bock",
    "Bocks": "Bock",
    "Bodenlegern": "Bodenleger",
    "Bodenlegers": "Bodenleger",
    "Bodenlose": "bodenlos",
    "Bodenlosen": "Bodenlose",
    "Bodenloseren": "Bodenlosere",
    "Bodenlosesten": "Bodenloseste",
    "Bodens": "Boden",
    "Bodenständige": "bodenständig",
    "Bodenständigen": "Bodenständige",
    "Bodenständigeren": "Bodenständigere",
    "Bodenständigsten": "Bodenständigste",
    "Bodenwellen": "Bodenwelle",
    "Bodos": "Bodo",
    "Bogdans": "Bogdan",
    "Bogenlampen": "Bogenlampe",
    "Bogens": "Bogen",
    "Bohlen": "Bohle",
    "Bohnen": "Bohne",
    "Bohnernden": "Bohnernde",
    "Bohnernderen": "Bohnerndere",
    "Bohnerndsten": "Bohnerndste",
    "Bohnerns": "Bohnern",
    "Bohrenden": "Bohrende",
    "Bohrenderen": "Bohrendere",
    "Bohrendsten": "Bohrendste",
    "Bohrens": "Bohren",
    "Bohrern": "Bohrer",
    "Bohrers": "Bohrer",
    "Bohrfliegen": "Bohrfliege",
    "Bohrfuttern": "Bohrfutter",
    "Bohrfutters": "Bohrfutter",
    "Bohrgestängen": "Bohrgestänge",
    "Bohrgestänges": "Bohrgestänge",
    "Bohrinseln": "Bohrinsel",
    "Bohrloche": "Bohrloch",
    "Bohrloches": "Bohrloch",
    "Bohrlochs": "Bohrloch",
    "Bohrlöcher": "Bohrloch",
    "Bohrlöchern": "Bohrloch",
    "Bohrmaschinen": "Bohrmaschine",
    "Bohrspindeln": "Bohrspindel",
    "Bohrturme": "Bohrturm",
    "Bohrturms": "Bohrturm",
    "Bohrtürme": "Bohrturm",
    "Bohrtürmen": "Bohrturm",
    "Bohrungen": "Bohrung",
    "Bohrwinden": "Bohrwinde",
    "Boilern": "Boiler",
    "Boilers": "Boiler",
    "Bojen": "Boje",
    "Boleros": "Bolero",
    "Boliden": "Bolide",
    "Bollerwagens": "Bollerwagen",
    "Bolletten": "Bollette",
    "Bollwerke": "Bollwerk",
    "Bollwerken": "Bollwerk",
    "Bollwerks": "Bollwerk",
    "Bolschewisten": "Bolschewist",
    "Bolschewistische": "bolschewistisch",
    "Bolschewistischen": "Bolschewistische",
    "Bolzenden": "Bolzende",
    "Bolzenderen": "Bolzendere",
    "Bolzendsten": "Bolzendste",
    "Bolzens": "Bolzen",
    "Bolzplatze": "Bolzplatz",
    "Bolzplatzes": "Bolzplatz",
    "Bolzplätze": "Bolzplatz",
    "Bolzplätzen": "Bolzplatz",
    "Bombardierenden": "Bombardierende",
    "Bombardierenderen": "Bombardierendere",
    "Bombardierendsten": "Bombardierendste",
    "Bombardierens": "Bombardieren",
    "Bombardierte": "bombardiert",
    "Bombardierten": "Bombardierte",
    "Bombardierteren": "Bombardiertere",
    "Bombardiertesten": "Bombardierteste",
    "Bombastischen": "Bombastische",
    "Bombastischeren": "Bombastischere",
    "Bombastischsten": "Bombastischste",
    "Bomben": "Bombe",
    "Bombenden": "Bombende",
    "Bombenfesten": "Bombenfeste",
    "Bombens": "Bomben",
    "Bombensichere": "bombensicher",
    "Bombensicheren": "Bombensichere",
    "Bombensichereren": "Bombensicherere",
    "Bombensichersten": "Bombensicherste",
    "Bombigen": "Bombige",
    "Bombigeren": "Bombigere",
    "Bombigsten": "Bombigste",
    "Bommersheims": "Bommersheim",
    "Bonapartisten": "Bonapartist",
    "Bonbons": "Bonbon",
    "Bonifizierenden": "Bonifizierende",
    "Bonifizierenderen": "Bonifizierendere",
    "Bonifizierendsten": "Bonifizierendste",
    "Bonifizierens": "Bonifizieren",
    "Bonifizierte": "bonifiziert",
    "Bonifizierten": "Bonifizierte",
    "Bonifizierteren": "Bonifiziertere",
    "Bonifiziertesten": "Bonifizierteste",
    "Bonitäten": "Bonität",
    "Bonnern": "Bonner",
    "Bonners": "Bonner",
    "Bonns": "Bonn",
    "Bonsais": "Bonsai",
    "Bonusse": "Bonus",
    "Bonussen": "Bonus",
    "Bonusses": "Bonus",
    "Bonzen": "Bonze",
    "Boogiewoogies": "Boogiewoogie",
    "Boom": "boomen",
    "Boomenden": "Boomende",
    "Boomenderen": "Boomendere",
    "Boomendsten": "Boomendste",
    "Boomens": "Boomen",
    "Booms": "Boom",
    "Boote": "booten",
    "Booten": "Boot",
    "Bootenden": "Bootende",
    "Bootens": "Booten",
    "Bootes": "Boot",
    "Boots": "Boot",
    "Borde": "Bord",
    "Bordeauxs": "Bordeaux",
    "Bordelle": "Bordell",
    "Bordellen": "Bordell",
    "Bordelles": "Bordell",
    "Bordells": "Bordell",
    "Borden": "Bord",
    "Bordes": "Bord",
    "Bordkapellen": "Bordkapelle",
    "Bords": "Bord",
    "Bordwaffen": "Bordwaffe",
    "Borgenden": "Borgende",
    "Borgens": "Borgen",
    "Borken": "Borke",
    "Bornheimern": "Bornheimer",
    "Bornheimers": "Bornheimer",
    "Bornheims": "Bornheim",
    "Bornierte": "borniert",
    "Bornierten": "Bornierte",
    "Bornierteren": "Borniertere",
    "Borniertesten": "Bornierteste",
    "Borsdorfs": "Borsdorf",
    "Borsten": "Borste",
    "Borstige": "borstig",
    "Borstigen": "Borstige",
    "Borstigeren": "Borstigere",
    "Borstigsten": "Borstigste",
    "Borten": "Borte",
    "Boschs": "Bosch",
    "Boshafte": "boshaft",
    "Boshaften": "Boshafte",
    "Boshafteren": "Boshaftere",
    "Boshaftesten": "Boshafteste",
    "Bosheiten": "Bosheit",
    "Bosniens": "Bosnien",
    "Bosniern": "Bosnier",
    "Bosniers": "Bosnier",
    "Bosnische": "bosnisch",
    "Bosnischen": "Bosnische",
    "Bosse": "Boß",
    "Bossen": "Boß",
    "Bosses": "Boß",
    "Botanikern": "Botaniker",
    "Botanikers": "Botaniker",
    "Botanische": "botanisch",
    "Botanischen": "Botanische",
    "Botanisierenden": "Botanisierende",
    "Botanisierens": "Botanisieren",
    "Botanisierte": "botanisiert",
    "Botanisierten": "Botanisierte",
    "Boten": "Bote",
    "Botinnen": "Botin",
    "Botschaften": "Botschaft",
    "Botschaftern": "Botschafter",
    "Botschafters": "Botschafter",
    "Bottiche": "Bottich",
    "Bottichen": "Bottich",
    "Bottiches": "Bottich",
    "Bottichs": "Bottich",
    "Bouillons": "Bouillon",
    "Boulevards": "Boulevard",
    "Boutiquen": "Boutique",
    "Bowlen": "Bowle",
    "Box": "boxen",
    "Boxen": "Box",
    "Boxenden": "Boxende",
    "Boxenderen": "Boxendere",
    "Boxendsten": "Boxendste",
    "Boxens": "Boxen",
    "Boxern": "Boxer",
    "Boxers": "Boxer",
    "Boykotte": "Boykott",
    "Boykotten": "Boykott",
    "Boykottes": "Boykott",
    "Boykotts": "Boykott",
    "Boys": "Boy",
    "Brabbelnden": "Brabbelnde",
    "Brabbelnderen": "Brabbelndere",
    "Brabbelndsten": "Brabbelndste",
    "Brabbelns": "Brabbeln",
    "Brachen": "brechen",
    "Brachgelegenen": "Brachgelegene",
    "Brachgelegeneren": "Brachgelegenere",
    "Brachgelegensten": "Brachgelegenste",
    "Brachlands": "Brachland",
    "Brachliegenden": "Brachliegende",
    "Brachliegenderen": "Brachliegendere",
    "Brachliegendsten": "Brachliegendste",
    "Brachliegens": "Brachliegen",
    "Branchen": "Branche",
    "Brandaktuelle": "brandaktuell",
    "Brandaktuellen": "Brandaktuelle",
    "Brandblasen": "Brandblase",
    "Brande": "branden",
    "Brandeilige": "brandeilig",
    "Brandeiligen": "Brandeilige",
    "Brandenburgern": "Brandenburger",
    "Brandenburgers": "Brandenburger",
    "Brandenburgische": "brandenburgisch",
    "Brandenburgischen": "Brandenburgische",
    "Brandenburgs": "Brandenburg",
    "Brandenden": "Brandende",
    "Brandenderen": "Brandendere",
    "Brandendsten": "Brandendste",
    "Brandens": "Branden",
    "Brandes": "Brand",
    "Brandheißen": "Brandheiße",
    "Brandmarkenden": "Brandmarkende",
    "Brandmarkenderen": "Brandmarkendere",
    "Brandmarkendsten": "Brandmarkendste",
    "Brandmarkens": "Brandmarken",
    "Brandneuen": "Brandneue",
    "Brands": "Brand",
    "Brandstätten": "Brandstätte",
    "Brandts": "Brandt",
    "Brandungen": "Brandung",
    "Brandys": "Brandy",
    "Branntweine": "Branntwein",
    "Branntweinen": "Branntwein",
    "Branntweines": "Branntwein",
    "Branntweins": "Branntwein",
    "Brasilianische": "brasilianisch",
    "Brasilianischen": "Brasilianische",
    "Brasiliens": "Brasilien",
    "Brassen": "Brasse",
    "Bratenden": "Bratende",
    "Bratenderen": "Bratendere",
    "Bratendsten": "Bratendste",
    "Bratens": "Braten",
    "Bratfertigen": "Bratfertige",
    "Bratheringe": "Brathering",
    "Bratheringen": "Brathering",
    "Bratherings": "Brathering",
    "Brathuhne": "Brathuhn",
    "Brathuhnes": "Brathuhn",
    "Brathuhns": "Brathuhn",
    "Brathühner": "Brathuhn",
    "Brathühnern": "Brathuhn",
    "Bratkartoffeln": "Bratkartoffel",
    "Bratlinge": "Bratling",
    "Bratlingen": "Bratling",
    "Bratlings": "Bratling",
    "Bratpfannen": "Bratpfanne",
    "Bratroste": "Bratrost",
    "Bratrosten": "Bratrost",
    "Bratrosts": "Bratrost",
    "Bratschen": "Bratsche",
    "Bratwürste": "Bratwurst",
    "Bratwürsten": "Bratwurst",
    "Brauch": "brauchen",
    "Brauchbare": "brauchbar",
    "Brauchbaren": "Brauchbare",
    "Brauchbareren": "Brauchbarere",
    "Brauchbarkeiten": "Brauchbarkeit",
    "Brauchbarste": "brauchbar",
    "Brauchbarsten": "Brauchbarste",
    "Brauche": "brauchen",
    "Brauchenden": "Brauchende",
    "Brauchens": "Brauchen",
    "Brauches": "Brauch",
    "Brauchs": "Brauch",
    "Brauchtums": "Brauchtum",
    "Brauchwassers": "Brauchwasser",
    "Braue": "brauen",
    "Brauen": "Braue",
    "Brauenden": "Brauende",
    "Brauenderen": "Brauendere",
    "Brauendsten": "Brauendste",
    "Brauens": "Brauen",
    "Brauereien": "Brauerei",
    "Braumeistern": "Braumeister",
    "Braumeisters": "Braumeister",
    "Braunalgen": "Braunalge",
    "Braunbiere": "Braunbier",
    "Braunbieren": "Braunbier",
    "Braunbiers": "Braunbier",
    "Braunbären": "Braunbär",
    "Braune": "braun",
    "Braunen": "Braune",
    "Brauneren": "Braunere",
    "Braungebrannten": "Braungebrannte",
    "Braungebrannteren": "Braungebranntere",
    "Braunhaarigen": "Braunhaarige",
    "Braunkohlen": "Braunkohle",
    "Brauns": "Braun",
    "Braunschweigs": "Braunschweig",
    "Braunste": "braun",
    "Braunsten": "Braunste",
    "Brause": "brausen",
    "Brausen": "Brause",
    "Brausenden": "Brausende",
    "Brausenderen": "Brausendere",
    "Brausendsten": "Brausendste",
    "Brausens": "Brausen",
    "Brautführern": "Brautführer",
    "Brautführers": "Brautführer",
    "Brautgemache": "Brautgemach",
    "Brautgemaches": "Brautgemach",
    "Brautgemachs": "Brautgemach",
    "Brautgemächer": "Brautgemach",
    "Brautgemächern": "Brautgemach",
    "Brautkronen": "Brautkrone",
    "Brautmessen": "Brautmesse",
    "Brauwesens": "Brauwesen",
    "Brave": "brav",
    "Braven": "Brave",
    "Braveren": "Bravere",
    "Bravos": "Bravo",
    "Bravste": "brav",
    "Bravsten": "Bravste",
    "Breaks": "Break",
    "Brechenden": "Brechende",
    "Brechens": "Brechen",
    "Brechern": "Brecher",
    "Brechers": "Brecher",
    "Brechstangen": "Brechstange",
    "Brechungen": "Brechung",
    "Brechungsebenen": "Brechungsebene",
    "Brehls": "Brehl",
    "Breie": "Brei",
    "Breien": "Brei",
    "Breies": "Brei",
    "Breis": "Brei",
    "Breitbeinige": "breitbeinig",
    "Breitbeinigen": "Breitbeinige",
    "Breitbeinigeren": "Breitbeinigere",
    "Breitbeinigsten": "Breitbeinigste",
    "Breite": "breiten",
    "Breiteisens": "Breiteisen",
    "Breiten": "Breite",
    "Breitenden": "Breitende",
    "Breitens": "Breiten",
    "Breiteren": "Breitere",
    "Breitesten": "Breiteste",
    "Breitgefächerten": "Breitgefächerte",
    "Breitgeschlagenen": "Breitgeschlagene",
    "Breitgeschlageneren": "Breitgeschlagenere",
    "Breitgetretenen": "Breitgetretene",
    "Breitgetreteneren": "Breitgetretenere",
    "Breitgetretensten": "Breitgetretenste",
    "Breitrandigen": "Breitrandige",
    "Breitrandigeren": "Breitrandigere",
    "Breitrandigsten": "Breitrandigste",
    "Breitschlagenden": "Breitschlagende",
    "Breitschlagenderen": "Breitschlagendere",
    "Breitschlagens": "Breitschlagen",
    "Breitschulterigen": "Breitschulterige",
    "Breitseiten": "Breitseite",
    "Breitspurige": "breitspurig",
    "Breitspurigen": "Breitspurige",
    "Breittretenden": "Breittretende",
    "Breittretenderen": "Breittretendere",
    "Breittretendsten": "Breittretendste",
    "Breittretens": "Breittreten",
    "Breitwände": "Breitwand",
    "Breitwänden": "Breitwand",
    "Bremens": "Bremen",
    "Bremerhavenern": "Bremerhavener",
    "Bremerhaveners": "Bremerhavener",
    "Bremerhavens": "Bremerhaven",
    "Bremern": "Bremer",
    "Bremers": "Bremer",
    "Bremische": "bremisch",
    "Bremischen": "Bremische",
    "Bremsbelage": "Bremsbelag",
    "Bremsbelags": "Bremsbelag",
    "Bremsbeläge": "Bremsbelag",
    "Bremsbelägen": "Bremsbelag",
    "Bremse": "bremsen",
    "Bremsen": "Bremse",
    "Bremsenden": "Bremsende",
    "Bremsens": "Bremsen",
    "Bremsern": "Bremser",
    "Bremsers": "Bremser",
    "Bremslichte": "Bremslicht",
    "Bremslichter": "Bremslicht",
    "Bremslichtern": "Bremslicht",
    "Bremslichtes": "Bremslicht",
    "Bremslichts": "Bremslicht",
    "Bremsschuhe": "Bremsschuh",
    "Bremsschuhen": "Bremsschuh",
    "Bremsschuhs": "Bremsschuh",
    "Bremsspuren": "Bremsspur",
    "Bremswagens": "Bremswagen",
    "Bremswege": "Bremsweg",
    "Bremswegen": "Bremsweg",
    "Bremswegs": "Bremsweg",
    "Brennbare": "brennbar",
    "Brennbaren": "Brennbare",
    "Brennbareren": "Brennbarere",
    "Brennbarsten": "Brennbarste",
    "Brennelemente": "Brennelement",
    "Brennelementen": "Brennelement",
    "Brennelements": "Brennelement",
    "Brennenden": "Brennende",
    "Brennenderen": "Brennendere",
    "Brennendsten": "Brennendste",
    "Brennens": "Brennen",
    "Brennereien": "Brennerei",
    "Brennern": "Brenner",
    "Brenners": "Brenner",
    "Brennesseln": "Brennessel",
    "Brennholze": "Brennholz",
    "Brennholzes": "Brennholz",
    "Brennhölzer": "Brennholz",
    "Brennhölzern": "Brennholz",
    "Brennlinsen": "Brennlinse",
    "Brennofens": "Brennofen",
    "Brennpunkte": "Brennpunkt",
    "Brennpunkten": "Brennpunkt",
    "Brennpunktes": "Brennpunkt",
    "Brennpunkts": "Brennpunkt",
    "Brennstellen": "Brennstelle",
    "Brennstoffe": "Brennstoff",
    "Brennstoffen": "Brennstoff",
    "Brennstoffes": "Brennstoff",
    "Brennstoffs": "Brennstoff",
    "Brennstoffzellen": "Brennstoffzelle",
    "Brennweiten": "Brennweite",
    "Brennöfen": "Brennofen",
    "Brentanos": "Brentano",
    "Brenzlige": "brenzlig",
    "Brenzligen": "Brenzlige",
    "Brenzligeren": "Brenzligere",
    "Brenzligsten": "Brenzligste",
    "Breschen": "Bresche",
    "Brette": "Brett",
    "Bretter": "Brett",
    "Brettern": "Brett",
    "Brettes": "Brett",
    "Bretts": "Brett",
    "Bretzeln": "Bretzel",
    "Brezeln": "Brezel",
    "Brickets": "Bricket",
    "Briefe": "Brief",
    "Briefen": "Brief",
    "Briefes": "Brief",
    "Briefkarten": "Briefkarte",
    "Briefliche": "brieflich",
    "Brieflichen": "Briefliche",
    "Briefs": "Brief",
    "Brieftaschen": "Brieftasche",
    "Brigittes": "Brigitte",
    "Briketts": "Brikett",
    "Brillen": "Brille",
    "Brillianten": "Brilliant",
    "Brillierenden": "Brillierende",
    "Brillierens": "Brillieren",
    "Brillierte": "brilliert",
    "Brillierten": "Brillierte",
    "Bringenden": "Bringende",
    "Bringens": "Bringen",
    "Brisanten": "Brisante",
    "Brisanteren": "Brisantere",
    "Brisantesten": "Brisanteste",
    "Brisen": "Brise",
    "Briten": "Brite",
    "Britische": "britisch",
    "Britischen": "Britische",
    "Britischeren": "Britischere",
    "Britischsten": "Britischste",
    "Brockens": "Brocken",
    "Brodelnden": "Brodelnde",
    "Brodelnderen": "Brodelndere",
    "Brodelndsten": "Brodelndste",
    "Brodelns": "Brodeln",
    "Brokern": "Broker",
    "Brokers": "Broker",
    "Brombeeren": "Brombeere",
    "Bronchialspalten": "Bronchialspalte",
    "Bronchien": "Bronchie",
    "Bronzene": "bronzen",
    "Bronzenen": "Bronzene",
    "Bronzeneren": "Bronzenere",
    "Bronzensten": "Bronzenste",
    "Broschen": "Brosche",
    "Broschierladen": "Broschierlade",
    "Broschüren": "Broschüre",
    "Brote": "Brot",
    "Broten": "Brot",
    "Brotes": "Brot",
    "Brotlose": "brotlos",
    "Brotlosen": "Brotlose",
    "Brotloseren": "Brotlosere",
    "Brotlosesten": "Brotloseste",
    "Brots": "Brot",
    "Browns": "Brown",
    "Bruchbuden": "Bruchbude",
    "Bruche": "Bruch",
    "Bruchempfindliche": "bruchempfindlich",
    "Bruchempfindlichen": "Bruchempfindliche",
    "Bruchempfindlicheren": "Bruchempfindlichere",
    "Bruches": "Bruch",
    "Bruchfeste": "bruchfest",
    "Bruchfesten": "Bruchfeste",
    "Bruchfesteren": "Bruchfestere",
    "Bruchfestesten": "Bruchfesteste",
    "Bruchflächen": "Bruchfläche",
    "Bruchlosen": "Bruchlose",
    "Bruchloseren": "Bruchlosere",
    "Bruchlosesten": "Bruchloseste",
    "Bruchs": "Bruch",
    "Bruchstücke": "Bruchstück",
    "Bruchstücken": "Bruchstück",
    "Bruchstückhafte": "bruchstückhaft",
    "Bruchstückhaften": "Bruchstückhafte",
    "Bruchstückhafteren": "Bruchstückhaftere",
    "Bruchstücks": "Bruchstück",
    "Bruders": "Bruder",
    "Brummeisens": "Brummeisen",
    "Brummenden": "Brummende",
    "Brummenderen": "Brummendere",
    "Brummendsten": "Brummendste",
    "Brummens": "Brummen",
    "Brummern": "Brummer",
    "Brummers": "Brummer",
    "Brummfliegen": "Brummfliege",
    "Brummige": "brummig",
    "Brummigen": "Brummige",
    "Brummigeren": "Brummigere",
    "Brummigsten": "Brummigste",
    "Brummkreiseln": "Brummkreisel",
    "Brummkreisels": "Brummkreisel",
    "Brunchs": "Brunch",
    "Brunftdrüsen": "Brunftdrüse",
    "Brunftzeiten": "Brunftzeit",
    "Brunnens": "Brunnen",
    "Brunos": "Bruno",
    "Brutale": "brutal",
    "Brutalen": "Brutale",
    "Brutaleren": "Brutalere",
    "Brutalitäten": "Brutalität",
    "Brutalste": "brutal",
    "Brutalsten": "Brutalste",
    "Brutstätten": "Brutstätte",
    "Bruttogehalte": "Bruttogehalt",
    "Bruttogehaltes": "Bruttogehalt",
    "Bruttogehalts": "Bruttogehalt",
    "Bruttogehälter": "Bruttogehalt",
    "Bruttogehältern": "Bruttogehalt",
    "Bruttogewichte": "Bruttogewicht",
    "Bruttogewichten": "Bruttogewicht",
    "Bruttogewichts": "Bruttogewicht",
    "Bruttolohne": "Bruttolohn",
    "Bruttolohns": "Bruttolohn",
    "Bruttolöhne": "Bruttolohn",
    "Bruttolöhnen": "Bruttolohn",
    "Bruttoregistertonnen": "Bruttoregistertonne",
    "Bruttosozialprodukte": "Bruttosozialprodukt",
    "Bruttosozialprodukten": "Bruttosozialprodukt",
    "Bruttosozialprodukts": "Bruttosozialprodukt",
    "Bruttoverdienste": "Bruttoverdienst",
    "Bruttoverdiensten": "Bruttoverdienst",
    "Bruttoverdiensts": "Bruttoverdienst",
    "Bruttovermögens": "Bruttovermögen",
    "Brutzelnden": "Brutzelnde",
    "Brutzelnderen": "Brutzelndere",
    "Brutzelndsten": "Brutzelndste",
    "Brutzelns": "Brutzeln",
    "Brände": "Brand",
    "Bränden": "Brand",
    "Brätern": "Bräter",
    "Bräters": "Bräter",
    "Bräuche": "Brauch",
    "Bräuchen": "Brauch",
    "Bräunliche": "bräunlich",
    "Bräunlichen": "Bräunliche",
    "Bräunungen": "Bräunung",
    "Bräute": "Braut",
    "Bräuten": "Braut",
    "Bröckchens": "Bröckchen",
    "Bröckelnden": "Bröckelnde",
    "Bröckelnderen": "Bröckelndere",
    "Bröckelndsten": "Bröckelndste",
    "Bröckelns": "Bröckeln",
    "Bröckligen": "Bröcklige",
    "Bröckligeren": "Bröckligere",
    "Bröckligsten": "Bröckligste",
    "Brötchens": "Brötchen",
    "Brüche": "Bruch",
    "Brüchen": "Bruch",
    "Brüchige": "brüchig",
    "Brüchigen": "Brüchige",
    "Brüchigeren": "Brüchigere",
    "Brüchigsten": "Brüchigste",
    "Brücken": "Brücke",
    "Brüder": "Bruder",
    "Brüderliche": "brüderlich",
    "Brüderlichen": "Brüderliche",
    "Brüderlicheren": "Brüderlichere",
    "Brüderlichsten": "Brüderlichste",
    "Brüdern": "Bruder",
    "Brühe": "brühen",
    "Brühen": "Brühe",
    "Brühenden": "Brühende",
    "Brühenderen": "Brühendere",
    "Brühendsten": "Brühendste",
    "Brühens": "Brühen",
    "Brühwarmen": "Brühwarme",
    "Brühwürste": "Brühwurst",
    "Brühwürsten": "Brühwurst",
    "Brüllenden": "Brüllende",
    "Brüllenderen": "Brüllendere",
    "Brüllendsten": "Brüllendste",
    "Brüllens": "Brüllen",
    "Brüllern": "Brüller",
    "Brüllers": "Brüller",
    "Brünette": "brünett",
    "Brünetten": "Brünette",
    "Brünfte": "Brunft",
    "Brünften": "Brunft",
    "Brünings": "Brüning",
    "Brünnchens": "Brünnchen",
    "Brünnleins": "Brünnlein",
    "Brünste": "Brunst",
    "Brünsten": "Brunst",
    "Brüskierenden": "Brüskierende",
    "Brüskierenderen": "Brüskierendere",
    "Brüskierendsten": "Brüskierendste",
    "Brüskierens": "Brüskieren",
    "Brüskierte": "brüskiert",
    "Brüskierten": "Brüskierte",
    "Brüskierteren": "Brüskiertere",
    "Brüskiertesten": "Brüskierteste",
    "Brüsselern": "Brüsseler",
    "Brüsselers": "Brüsseler",
    "Brüssels": "Brüssel",
    "Brüste": "brüsten",
    "Brüsten": "Brust",
    "Brüstenden": "Brüstende",
    "Brüstenderen": "Brüstendere",
    "Brüstendsten": "Brüstendste",
    "Brüstens": "Brüsten",
    "Brüstungen": "Brüstung",
    "Brütenden": "Brütende",
    "Brütenderen": "Brütendere",
    "Brütendsten": "Brütendste",
    "Brütens": "Brüten",
    "Buben": "Bube",
    "Bubenhafte": "bubenhaft",
    "Bubenhaften": "Bubenhafte",
    "Bubenhafteren": "Bubenhaftere",
    "Bubenhaftesten": "Bubenhafteste",
    "Bubikopfe": "Bubikopf",
    "Bubikopfs": "Bubikopf",
    "Bubiköpfe": "Bubikopf",
    "Bubiköpfen": "Bubikopf",
    "Buch": "buchen",
    "Buchbindern": "Buchbinder",
    "Buchbinderpressen": "Buchbinderpresse",
    "Buchbinders": "Buchbinder",
    "Buche": "buchen",
    "Buchen": "Buche",
    "Buchenden": "Buchende",
    "Buchens": "Buchen",
    "Buches": "Buch",
    "Buchs": "Buch",
    "Buchstaben": "Buchstabe",
    "Buchstabierenden": "Buchstabierende",
    "Buchstabierens": "Buchstabieren",
    "Buchstabierte": "buchstabiert",
    "Buchstabierten": "Buchstabierte",
    "Buchstäblichen": "Buchstäbliche",
    "Buchstäblicheren": "Buchstäblichere",
    "Buchstäblichsten": "Buchstäblichste",
    "Buchten": "Bucht",
    "Buchtenden": "Buchtende",
    "Buchtens": "Buchten",
    "Buckeln": "Buckel",
    "Buckels": "Buckel",
    "Bucklige": "bucklig",
    "Buckligen": "Bucklige",
    "Buckligeren": "Buckligere",
    "Buckligsten": "Buckligste",
    "Budapests": "Budapest",
    "Buddel": "buddeln",
    "Buddeleien": "Buddelei",
    "Buddeln": "Buddel",
    "Buddelnden": "Buddelnde",
    "Buddelnderen": "Buddelndere",
    "Buddelndsten": "Buddelndste",
    "Buddelns": "Buddeln",
    "Buddelschiffe": "Buddelschiff",
    "Buddelschiffen": "Buddelschiff",
    "Buddelschiffs": "Buddelschiff",
    "Buddhas": "Buddha",
    "Buddhisten": "Buddhist",
    "Buden": "Bude",
    "Budenzaubers": "Budenzauber",
    "Budgets": "Budget",
    "Buffets": "Buffet",
    "Bugsierenden": "Bugsierende",
    "Bugsierens": "Bugsieren",
    "Bugsierern": "Bugsierer",
    "Bugsierers": "Bugsierer",
    "Bugsierte": "bugsiert",
    "Bugsierten": "Bugsierte",
    "Bugwellen": "Bugwelle",
    "Buhenden": "Buhende",
    "Buhenderen": "Buhendere",
    "Buhendsten": "Buhendste",
    "Buhens": "Buhen",
    "Buhlenden": "Buhlende",
    "Buhlenderen": "Buhlendere",
    "Buhlendsten": "Buhlendste",
    "Buhlens": "Buhlen",
    "Buhlerinnen": "Buhlerin",
    "Buhlgeiste": "Buhlgeist",
    "Buhlgeister": "Buhlgeist",
    "Buhlgeistern": "Buhlgeist",
    "Buhlgeistes": "Buhlgeist",
    "Buhlgeists": "Buhlgeist",
    "Buhlinnen": "Buhlin",
    "Buhmanne": "Buhmann",
    "Buhmannes": "Buhmann",
    "Buhmanns": "Buhmann",
    "Buhmänner": "Buhmann",
    "Buhmännern": "Buhmann",
    "Bukarests": "Bukarest",
    "Bukkale": "bukkal",
    "Bukkalen": "Bukkale",
    "Buletten": "Bulette",
    "Bulgaren": "Bulgare",
    "Bulgariens": "Bulgarien",
    "Bulgarische": "bulgarisch",
    "Bulgarischen": "Bulgarische",
    "Bullaugen": "Bullauge",
    "Bullauges": "Bullauge",
    "Bulldoggen": "Bulldogge",
    "Bullen": "Bulle",
    "Bullenbeißern": "Bullenbeißer",
    "Bullenbeißers": "Bullenbeißer",
    "Bullernden": "Bullernde",
    "Bullernderen": "Bullerndere",
    "Bullerndsten": "Bullerndste",
    "Bullerns": "Bullern",
    "Bulletins": "Bulletin",
    "Bullige": "bullig",
    "Bulligen": "Bullige",
    "Bulligeren": "Bulligere",
    "Bulligsten": "Bulligste",
    "Bullterriern": "Bullterrier",
    "Bullterriers": "Bullterrier",
    "Bullys": "Bully",
    "Bummel": "bummeln",
    "Bummelanten": "Bummelant",
    "Bummeleien": "Bummelei",
    "Bummelmützen": "Bummelmütze",
    "Bummeln": "Bummel",
    "Bummelnden": "Bummelnde",
    "Bummelnderen": "Bummelndere",
    "Bummelndsten": "Bummelndste",
    "Bummelns": "Bummeln",
    "Bummels": "Bummel",
    "Bummelzuge": "Bummelzug",
    "Bummelzugs": "Bummelzug",
    "Bummelzüge": "Bummelzug",
    "Bummelzügen": "Bummelzug",
    "Bumsenden": "Bumsende",
    "Bumsenderen": "Bumsendere",
    "Bumsendsten": "Bumsendste",
    "Bumsens": "Bumsen",
    "Bunde": "Bund",
    "Bunden": "Bund",
    "Bundes": "Bund",
    "Bundesdeutsche": "bundesdeutsch",
    "Bundesdeutschen": "Bundesdeutsche",
    "Bundeseigenen": "Bundeseigene",
    "Bundesgenössischen": "Bundesgenössische",
    "Bundesligen": "Bundesliga",
    "Bundesligisten": "Bundesligist",
    "Bundesrepublikanische": "bundesrepublikanisch",
    "Bundesrepublikanischen": "Bundesrepublikanische",
    "Bundestage": "Bundestag",
    "Bundestages": "Bundestag",
    "Bundestags": "Bundestag",
    "Bundesweite": "bundesweit",
    "Bundesweiten": "Bundesweite",
    "Bunds": "Bund",
    "Bungalows": "Bungalow",
    "Bunker": "bunkern",
    "Bunkern": "Bunker",
    "Bunkernden": "Bunkernde",
    "Bunkernderen": "Bunkerndere",
    "Bunkerndsten": "Bunkerndste",
    "Bunkerns": "Bunkern",
    "Bunkers": "Bunker",
    "Bunten": "Bunte",
    "Bunteren": "Buntere",
    "Buntesten": "Bunteste",
    "Buntkäfern": "Buntkäfer",
    "Buntkäfers": "Buntkäfer",
    "Buntmetalle": "Buntmetall",
    "Buntmetallen": "Buntmetall",
    "Buntmetalls": "Buntmetall",
    "Buntpapiere": "Buntpapier",
    "Buntpapieren": "Buntpapier",
    "Buntpapiers": "Buntpapier",
    "Buntspechte": "Buntspecht",
    "Buntspechten": "Buntspecht",
    "Buntspechts": "Buntspecht",
    "Buntstifte": "Buntstift",
    "Buntstiften": "Buntstift",
    "Buntstifts": "Buntstift",
    "Buntwebereien": "Buntweberei",
    "Burgards": "Burgard",
    "Burgen": "Burg",
    "Burglehens": "Burglehen",
    "Burgähnlichen": "Burgähnliche",
    "Burkhards": "Burkhard",
    "Burmas": "Burma",
    "Burows": "Burow",
    "Busche": "Busch",
    "Busches": "Busch",
    "Buschige": "buschig",
    "Buschigen": "Buschige",
    "Buschigeren": "Buschigere",
    "Buschigsten": "Buschigste",
    "Buschs": "Busch",
    "Busens": "Busen",
    "Bushs": "Bush",
    "Bussarde": "Bussard",
    "Bussarden": "Bussard",
    "Bussardes": "Bussard",
    "Bussards": "Bussard",
    "Busse": "Bus",
    "Bussen": "Bus",
    "Busses": "Bus",
    "Bussis": "Bussi",
    "Busukis": "Busuki",
    "Butane": "Butan",
    "Butanen": "Butan",
    "Butans": "Butan",
    "Butlern": "Butler",
    "Butlers": "Butler",
    "Butteln": "Buttel",
    "Butter": "buttern",
    "Butternden": "Butternde",
    "Butterns": "Buttern",
    "Butterweichen": "Butterweiche",
    "Butterweicheren": "Butterweichere",
    "Butterweichsten": "Butterweichste",
    "Butzbachern": "Butzbacher",
    "Butzbachers": "Butzbacher",
    "Butzbachs": "Butzbach",
    "Butzemanne": "Butzemann",
    "Butzemannes": "Butzemann",
    "Butzemanns": "Butzemann",
    "Butzemänner": "Butzemann",
    "Butzemännern": "Butzemann",
    "Bußen": "Buße",
    "Bußfertigen": "Bußfertige",
    "Bußfertigeren": "Bußfertigere",
    "Bußfertigsten": "Bußfertigste",
    "Bußmanns": "Bußmann",
    "Bußpredigern": "Bußprediger",
    "Bußpredigers": "Bußprediger",
    "Byzantinern": "Byzantiner",
    "Byzantiners": "Byzantiner",
    "Byzantinische": "byzantinisch",
    "Byzantinischen": "Byzantinische",
    "Byzantinisten": "Byzantinist",
    "Bäche": "Bach",
    "Bächen": "Bach",
    "Bächleins": "Bächlein",
    "Bäckchens": "Bäckchen",
    "Bäckereien": "Bäckerei",
    "Bäckern": "Bäcker",
    "Bäckers": "Bäcker",
    "Bäder": "Bad",
    "Bädern": "Bad",
    "Bähungen": "Bähung",
    "Bälkchens": "Bälkchen",
    "Bälle": "Ball",
    "Bällen": "Ball",
    "Bändigenden": "Bändigende",
    "Bändigenderen": "Bändigendere",
    "Bändigendsten": "Bändigendste",
    "Bändigens": "Bändigen",
    "Bändigungen": "Bändigung",
    "Bänkchens": "Bänkchen",
    "Bänke": "Bank",
    "Bänken": "Bank",
    "Bärbels": "Bärbel",
    "Bäre": "Bär",
    "Bären": "Bär",
    "Bärentrauben": "Bärentraube",
    "Bäres": "Bär",
    "Bärs": "Bär",
    "Bärte": "Bart",
    "Bärten": "Bart",
    "Bärtige": "bärtig",
    "Bärtigen": "Bärtige",
    "Bässe": "Baß",
    "Bässen": "Baß",
    "Bäuche": "Bauch",
    "Bäuchelchens": "Bäuchelchen",
    "Bäuchen": "Bauch",
    "Bäuerinnen": "Bäuerin",
    "Bäuerische": "bäuerisch",
    "Bäuerischen": "Bäuerische",
    "Bäuerischeren": "Bäuerischere",
    "Bäuerischsten": "Bäuerischste",
    "Bäuerlichen": "Bäuerliche",
    "Bäuerlicheren": "Bäuerlichere",
    "Bäuerlichsten": "Bäuerlichste",
    "Bäume": "bäumen",
    "Bäumen": "Baum",
    "Bäumenden": "Bäumende",
    "Bäumens": "Bäumen",
    "Bäusche": "Bausch",
    "Bäuschen": "Bausch",
    "Böckchens": "Böckchen",
    "Böcke": "Bock",
    "Böcken": "Bock",
    "Böcks": "Böck",
    "Böden": "Boden",
    "Böen": "Böe",
    "Böhmes": "Böhme",
    "Böhmische": "böhmisch",
    "Böhmischen": "Böhmische",
    "Böhms": "Böhm",
    "Böige": "böig",
    "Böigen": "Böige",
    "Böigeren": "Böigere",
    "Böigsten": "Böigste",
    "Bölkenden": "Bölkende",
    "Bölkenderen": "Bölkendere",
    "Bölkendsten": "Bölkendste",
    "Bölkens": "Bölken",
    "Böllernden": "Böllernde",
    "Böllernderen": "Böllerndere",
    "Böllerndsten": "Böllerndste",
    "Böllerns": "Böllern",
    "Börden": "Börde",
    "Börsen": "Börse",
    "Bösartige": "bösartig",
    "Bösartigen": "Bösartige",
    "Bösartigeren": "Bösartigere",
    "Bösartigsten": "Bösartigste",
    "Böschungen": "Böschung",
    "Böseren": "Bösere",
    "Bösesten": "Böseste",
    "Bösewichte": "Bösewicht",
    "Bösewichten": "Bösewicht",
    "Bösewichts": "Bösewicht",
    "Böswillige": "böswillig",
    "Böswilligen": "Böswillige",
    "Böswilligeren": "Böswilligere",
    "Böswilligsten": "Böswilligste",
    "Bübchens": "Bübchen",
    "Bübereien": "Büberei",
    "Bübinnen": "Bübin",
    "Bübische": "bübisch",
    "Bübischen": "Bübische",
    "Bübischeren": "Bübischere",
    "Bübischsten": "Bübischste",
    "Bübleins": "Büblein",
    "Bücher": "Buch",
    "Büchern": "Buch",
    "Büchleins": "Büchlein",
    "Büchners": "Büchner",
    "Büchsen": "Büchse",
    "Bücklinge": "Bückling",
    "Bücklingen": "Bückling",
    "Bücklinges": "Bückling",
    "Bücklings": "Bückling",
    "Büdesheims": "Büdesheim",
    "Büdingens": "Büdingen",
    "Büdingern": "Büdinger",
    "Büdingers": "Büdinger",
    "Büffel": "büffeln",
    "Büffeln": "Büffel",
    "Büffelnden": "Büffelnde",
    "Büffelnderen": "Büffelndere",
    "Büffelndsten": "Büffelndste",
    "Büffelns": "Büffeln",
    "Büffels": "Büffel",
    "Bügel": "bügeln",
    "Bügelbrette": "Bügelbrett",
    "Bügelbretter": "Bügelbrett",
    "Bügelbrettern": "Bügelbrett",
    "Bügelbrettes": "Bügelbrett",
    "Bügelbretts": "Bügelbrett",
    "Bügelfalten": "Bügelfalte",
    "Bügelfeste": "bügelfest",
    "Bügelfesten": "Bügelfeste",
    "Bügelfesteren": "Bügelfestere",
    "Bügelfestesten": "Bügelfesteste",
    "Bügeln": "Bügel",
    "Bügelnden": "Bügelnde",
    "Bügelns": "Bügeln",
    "Bügels": "Bügel",
    "Bügeltische": "Bügeltisch",
    "Bügeltischen": "Bügeltisch",
    "Bügeltischs": "Bügeltisch",
    "Bühnen": "Bühne",
    "Bühnenfähige": "bühnenfähig",
    "Bühnenfähigen": "Bühnenfähige",
    "Bühnenreifen": "Bühnenreife",
    "Bühnenreiferen": "Bühnenreifere",
    "Bühnenreifsten": "Bühnenreifste",
    "Bühnenwirksamen": "Bühnenwirksame",
    "Bühnenwirksameren": "Bühnenwirksamere",
    "Bühnenwirksamsten": "Bühnenwirksamste",
    "Bündchens": "Bündchen",
    "Bündel": "bündeln",
    "Bündeln": "Bündel",
    "Bündelnden": "Bündelnde",
    "Bündelnderen": "Bündelndere",
    "Bündelndsten": "Bündelndste",
    "Bündelns": "Bündeln",
    "Bündels": "Bündel",
    "Bündigen": "Bündige",
    "Bündigeren": "Bündigere",
    "Bündigsten": "Bündigste",
    "Bündnisse": "Bündnis",
    "Bündnissen": "Bündnis",
    "Bündnisses": "Bündnis",
    "Bürde": "bürden",
    "Bürden": "Bürde",
    "Bürdenden": "Bürdende",
    "Bürdens": "Bürden",
    "Bürge": "bürgen",
    "Bürgen": "Bürge",
    "Bürgenden": "Bürgende",
    "Bürgens": "Bürgen",
    "Bürger": "bürgern",
    "Bürgeraktive": "bürgeraktiv",
    "Bürgeraktiven": "Bürgeraktive",
    "Bürgeraktiveren": "Bürgeraktivere",
    "Bürgeraktivsten": "Bürgeraktivste",
    "Bürgerinnen": "Bürgerin",
    "Bürgerliche": "bürgerlich",
    "Bürgerlichen": "Bürgerliche",
    "Bürgerlicheren": "Bürgerlichere",
    "Bürgerlichsten": "Bürgerlichste",
    "Bürgermeistern": "Bürgermeister",
    "Bürgermeisters": "Bürgermeister",
    "Bürgern": "Bürger",
    "Bürgernden": "Bürgernde",
    "Bürgerns": "Bürgern",
    "Bürgerrechtliche": "bürgerrechtlich",
    "Bürgerrechtlichen": "Bürgerrechtliche",
    "Bürgers": "Bürger",
    "Bürgerschaften": "Bürgerschaft",
    "Bürgerschießens": "Bürgerschießen",
    "Bürgertums": "Bürgertum",
    "Bürokraten": "Bürokrat",
    "Bürokratien": "Bürokratie",
    "Bürokratische": "bürokratisch",
    "Bürokratischen": "Bürokratische",
    "Bürokratischeren": "Bürokratischere",
    "Bürokratischsten": "Bürokratischste",
    "Bürokratisierenden": "Bürokratisierende",
    "Bürokratisierenderen": "Bürokratisierendere",
    "Bürokratisierens": "Bürokratisieren",
    "Bürokratisierte": "bürokratisiert",
    "Bürokratisierten": "Bürokratisierte",
    "Bürokratisierteren": "Bürokratisiertere",
    "Büros": "Büro",
    "Bürschleins": "Bürschlein",
    "Bürstchens": "Bürstchen",
    "Bürste": "bürsten",
    "Bürsten": "Bürste",
    "Bürstenden": "Bürstende",
    "Bürstens": "Bürsten",
    "Büschchens": "Büschchen",
    "Büsche": "Busch",
    "Büschelchens": "Büschelchen",
    "Büschels": "Büschel",
    "Büschen": "Busch",
    "Büschleins": "Büschlein",
    "Büsten": "Büste",
    "Büstenhaltern": "Büstenhalter",
    "Büstenhalters": "Büstenhalter",
    "Büttelborns": "Büttelborn",
    "Bütteln": "Büttel",
    "Büttels": "Büttel",
    "Bütten": "Bütte",
    "Büttenreden": "Büttenrede",
    "Büxenden": "Büxende",
    "Büxens": "Büxen",
    "Büßenden": "Büßende",
    "Büßenderen": "Büßendere",
    "Büßendsten": "Büßendste",
    "Büßens": "Büßen",
    "CDs": "CD",
    "Cadmiums": "Cadmium",
    "Cafes": "Cafe",
    "Cages": "Cage",
    "Calciumcarbonate": "Calciumcarbonat",
    "Calciumcarbonaten": "Calciumcarbonat",
    "Calciumcarbonats": "Calciumcarbonat",
    "Calciumfluoride": "Calciumfluorid",
    "Calciumfluoriden": "Calciumfluorid",
    "Calciumfluorids": "Calciumfluorid",
    "Calciumoxide": "Calciumoxid",
    "Calciumoxiden": "Calciumoxid",
    "Calciumoxids": "Calciumoxid",
    "Calciumphosphate": "Calciumphosphat",
    "Calciumphosphaten": "Calciumphosphat",
    "Calciumphosphats": "Calciumphosphat",
    "Calciums": "Calcium",
    "Calciumsulfate": "Calciumsulfat",
    "Calciumsulfaten": "Calciumsulfat",
    "Calciumsulfats": "Calciumsulfat",
    "Calgons": "Calgon",
    "Calypsos": "Calypso",
    "Camcordern": "Camcorder",
    "Camcorders": "Camcorder",
    "Camemberts": "Camembert",
    "Camenberts": "Camenbert",
    "Campern": "Camper",
    "Campers": "Camper",
    "Campierenden": "Campierende",
    "Campierenderen": "Campierendere",
    "Campierendsten": "Campierendste",
    "Campierens": "Campieren",
    "Campierte": "campiert",
    "Campierten": "Campierte",
    "Campingplatze": "Campingplatz",
    "Campingplatzes": "Campingplatz",
    "Campingplätze": "Campingplatz",
    "Campingplätzen": "Campingplatz",
    "Campings": "Camping",
    "Camps": "Camp",
    "Cancans": "Cancan",
    "Capas": "Capa",
    "Capitols": "Capitol",
    "Capuccinos": "Capuccino",
    "Caravans": "Caravan",
    "Carbonate": "Carbonat",
    "Carbonaten": "Carbonat",
    "Carbonats": "Carbonat",
    "Carboneums": "Carboneum",
    "Carbonisiere": "carbonisieren",
    "Carbonisierenden": "Carbonisierende",
    "Carbonisierenderen": "Carbonisierendere",
    "Carbonisierens": "Carbonisieren",
    "Carbonisierte": "carbonisiert",
    "Carbonisierten": "Carbonisierte",
    "Carbonisierteren": "Carbonisiertere",
    "Carbonisiertesten": "Carbonisierteste",
    "Carinas": "Carina",
    "Carls": "Carl",
    "Carlssons": "Carlsson",
    "Carmens": "Carmen",
    "Carports": "Carport",
    "Carstens": "Carsten",
    "Cartoons": "Cartoon",
    "Casablancas": "Casablanca",
    "Casellas": "Casella",
    "Casinos": "Casino",
    "Cassetten": "Cassette",
    "Castros": "Castro",
    "Ceausescus": "Ceausescu",
    "Celles": "Celle",
    "Cellos": "Cello",
    "Cembalos": "Cembalo",
    "Centern": "Center",
    "Centers": "Center",
    "Ceresine": "Ceresin",
    "Ceresinen": "Ceresin",
    "Ceresins": "Ceresin",
    "Cesars": "Cesar",
    "Chachachas": "Chachacha",
    "Chaisen": "Chaise",
    "Champagnern": "Champagner",
    "Champagners": "Champagner",
    "Champignons": "Champignon",
    "Chamäleons": "Chamäleon",
    "Chancen": "Chance",
    "Chansons": "Chanson",
    "Chaplins": "Chaplin",
    "Charaktere": "Charakter",
    "Charakteren": "Charakter",
    "Charakterisierenden": "Charakterisierende",
    "Charakterisierens": "Charakterisieren",
    "Charakterisierte": "charakterisiert",
    "Charakterisierten": "Charakterisierte",
    "Charakterisierungen": "Charakterisierung",
    "Charakteristische": "charakteristisch",
    "Charakteristischen": "Charakteristische",
    "Charakteristischeren": "Charakteristischere",
    "Charakterlichen": "Charakterliche",
    "Charakters": "Charakter",
    "Charismas": "Charisma",
    "Charlestons": "Charleston",
    "Charlies": "Charlie",
    "Charlottenburgs": "Charlottenburg",
    "Charlottes": "Charlotte",
    "Charmante": "charmant",
    "Charmanten": "Charmante",
    "Charmanteren": "Charmantere",
    "Charmantesten": "Charmanteste",
    "Charmes": "Charme",
    "Chartas": "Charta",
    "Charters": "Charter",
    "Chausseen": "Chaussee",
    "Chauvinistische": "chauvinistisch",
    "Chauvinistischen": "Chauvinistische",
    "Chauvinistischeren": "Chauvinistischere",
    "Checkenden": "Checkende",
    "Checkens": "Checken",
    "Chefinnen": "Chefin",
    "Chefredakteurinnen": "Chefredakteurin",
    "Chefs": "Chef",
    "Chemiesierungen": "Chemiesierung",
    "Chemikalien": "Chemikalie",
    "Chemikern": "Chemiker",
    "Chemikers": "Chemiker",
    "Chemische": "chemisch",
    "Chemischen": "Chemische",
    "Chemisierungen": "Chemisierung",
    "Chemnitzern": "Chemnitzer",
    "Chemnitzers": "Chemnitzer",
    "Cherrys": "Cherry",
    "Chicagos": "Chicago",
    "Chice": "chic",
    "Chicen": "Chice",
    "Chiceren": "Chicere",
    "Chicsten": "Chicste",
    "Chiffren": "Chiffre",
    "Chiles": "Chile",
    "Chinas": "China",
    "Chinchillas": "Chinchilla",
    "Chinesen": "Chinese",
    "Chinesische": "chinesisch",
    "Chinesischen": "Chinesische",
    "Chips": "Chip",
    "Chirurgen": "Chirurg",
    "Chirurgische": "chirurgisch",
    "Chirurgischen": "Chirurgische",
    "Chlorite": "Chlorit",
    "Chloriten": "Chlorit",
    "Chlorits": "Chlorit",
    "Chlors": "Chlor",
    "Cholerikern": "Choleriker",
    "Cholerikers": "Choleriker",
    "Chore": "Chor",
    "Chores": "Chor",
    "Chors": "Chor",
    "Christen": "Christ",
    "Christi": "Christus",
    "Christians": "Christian",
    "Christines": "Christine",
    "Christinnen": "Christin",
    "Christliche": "christlich",
    "Christlichen": "Christliche",
    "Christlicheren": "Christlichere",
    "Christlichsten": "Christlichste",
    "Christophers": "Christopher",
    "Christophs": "Christoph",
    "Chroniken": "Chronik",
    "Chronische": "chronisch",
    "Chronischen": "Chronische",
    "Chronisten": "Chronist",
    "Chrysanthemen": "Chrysantheme",
    "Chöre": "Chor",
    "Chören": "Chor",
    "Cieskowskys": "Cieskowsky",
    "Cinemas": "Cinema",
    "Cinemascopen": "Cinemascope",
    "Cinemascopes": "Cinemascope",
    "Citys": "City",
    "Claras": "Clara",
    "Claudias": "Claudia",
    "Clementinen": "Clementine",
    "Clements": "Clement",
    "Clenbuterole": "Clenbuterol",
    "Clenbuterolen": "Clenbuterol",
    "Clenbuterols": "Clenbuterol",
    "Clintons": "Clinton",
    "Clips": "Clip",
    "Cliquen": "Clique",
    "Clonenden": "Clonende",
    "Clonenderen": "Clonendere",
    "Clonendsten": "Clonendste",
    "Clonens": "Clonen",
    "Clonings": "Cloning",
    "Clous": "Clou",
    "Clowns": "Clown",
    "Clubs": "Club",
    "Coachs": "Coach",
    "Cocaine": "Cocain",
    "Cocainen": "Cocain",
    "Cocains": "Cocain",
    "Cocas": "Coca",
    "Cockpits": "Cockpit",
    "Cocktails": "Cocktail",
    "Codas": "Coda",
    "Codierenden": "Codierende",
    "Codierens": "Codieren",
    "Codierte": "codiert",
    "Codierten": "Codierte",
    "Cohns": "Cohn",
    "Cokes": "Coke",
    "Collagen": "Collage",
    "Collies": "Collie",
    "Colmars": "Colmar",
    "Combos": "Combo",
    "Comebacks": "Comeback",
    "Comics": "Comic",
    "Comicstrips": "Comicstrip",
    "Commerzbanken": "Commerzbank",
    "Composern": "Composer",
    "Composers": "Composer",
    "Computern": "Computer",
    "Computers": "Computer",
    "Concordes": "Concorde",
    "Confiserien": "Confiserie",
    "Congas": "Conga",
    "Constantins": "Constantin",
    "Constanzes": "Constanze",
    "Containern": "Container",
    "Containers": "Container",
    "Contergans": "Contergan",
    "Coole": "cool",
    "Coolen": "Coole",
    "Cooleren": "Coolere",
    "Coolsten": "Coolste",
    "Cooperativen": "Cooperative",
    "Cooperativeren": "Cooperativere",
    "Cooperativsten": "Cooperativste",
    "Coopers": "Cooper",
    "Copiloten": "Copilot",
    "Cornelias": "Cornelia",
    "Countdowns": "Countdown",
    "Coupes": "Coupe",
    "Coups": "Coup",
    "Couriers": "Courier",
    "Cowboys": "Cowboy",
    "Coyoten": "Coyote",
    "Cracks": "Crack",
    "Credos": "Credo",
    "Creme": "cremen",
    "Cremenden": "Cremende",
    "Cremens": "Cremen",
    "Cremes": "Creme",
    "Cronenbergs": "Cronenberg",
    "Cups": "Cup",
    "Curriculare": "curricular",
    "Curricularen": "Curriculare",
    "Currys": "Curry",
    "Cuttern": "Cutter",
    "Cutters": "Cutter",
    "Cyane": "Cyan",
    "Cyanen": "Cyan",
    "Cyankalis": "Cyankali",
    "Cyans": "Cyan",
    "Cyrankiewiczs": "Cyrankiewicz",
    "Cäsarentums": "Cäsarentum",
    "Cäsars": "Cäsar",
    "Dabehaltenden": "Dabehaltende",
    "Dabehaltenen": "Dabehaltene",
    "Dabehaltens": "Dabehalten",
    "Dabeibleibenden": "Dabeibleibende",
    "Dabeibleibens": "Dabeibleiben",
    "Dabeigebliebenen": "Dabeigebliebene",
    "Dabeigesessenen": "Dabeigesessene",
    "Dabeisitzenden": "Dabeisitzende",
    "Dabeisitzens": "Dabeisitzen",
    "Dableibenden": "Dableibende",
    "Dableibens": "Dableiben",
    "Dach": "dachen",
    "Dachbalkens": "Dachbalken",
    "Dache": "dachen",
    "Dachenden": "Dachende",
    "Dachens": "Dachen",
    "Daches": "Dach",
    "Dachluken": "Dachluke",
    "Dachpappen": "Dachpappe",
    "Dachrinnen": "Dachrinne",
    "Dachs": "Dach",
    "Dackeln": "Dackel",
    "Dackels": "Dackel",
    "Dafürgehaltenen": "Dafürgehaltene",
    "Dafürgestandenen": "Dafürgestandene",
    "Dafürhaltenden": "Dafürhaltende",
    "Dafürhaltens": "Dafürhalten",
    "Dafürstehenden": "Dafürstehende",
    "Dafürstehens": "Dafürstehen",
    "Dagebliebenen": "Dagebliebene",
    "Dagegengehaltenen": "Dagegengehaltene",
    "Dagegengehandelten": "Dagegengehandelte",
    "Dagegengewirkten": "Dagegengewirkte",
    "Dagegenhaltenden": "Dagegenhaltende",
    "Dagegenhaltens": "Dagegenhalten",
    "Dagegenhandelnden": "Dagegenhandelnde",
    "Dagegenhandelns": "Dagegenhandeln",
    "Dagegenwirkenden": "Dagegenwirkende",
    "Dagegenwirkens": "Dagegenwirken",
    "Dagelassenen": "Dagelassene",
    "Dagelegenen": "Dagelegene",
    "Dagesessenen": "Dagesessene",
    "Dagestandenen": "Dagestandene",
    "Dagmars": "Dagmar",
    "Daherfliegenden": "Daherfliegende",
    "Daherfliegens": "Daherfliegen",
    "Dahergeflogenen": "Dahergeflogene",
    "Dahergekommenen": "Dahergekommene",
    "Dahergelaufenen": "Dahergelaufene",
    "Dahergeredeten": "Dahergeredete",
    "Daherkommenden": "Daherkommende",
    "Daherkommens": "Daherkommen",
    "Daherlaufenden": "Daherlaufende",
    "Daherlaufens": "Daherlaufen",
    "Daherredenden": "Daherredende",
    "Daherredens": "Daherreden",
    "Dahindämmernden": "Dahindämmernde",
    "Dahindämmerns": "Dahindämmern",
    "Dahineilenden": "Dahineilende",
    "Dahineilens": "Dahineilen",
    "Dahinfahrenden": "Dahinfahrende",
    "Dahinfahrens": "Dahinfahren",
    "Dahinfliegenden": "Dahinfliegende",
    "Dahinfliegens": "Dahinfliegen",
    "Dahingebenden": "Dahingebende",
    "Dahingebens": "Dahingeben",
    "Dahingedämmerten": "Dahingedämmerte",
    "Dahingeeilten": "Dahingeeilte",
    "Dahingefahrenen": "Dahingefahrene",
    "Dahingeflogenen": "Dahingeflogene",
    "Dahingegangenen": "Dahingegangene",
    "Dahingegebenen": "Dahingegebene",
    "Dahingehenden": "Dahingehende",
    "Dahingehens": "Dahingehen",
    "Dahingelebten": "Dahingelebte",
    "Dahingerafften": "Dahingeraffte",
    "Dahingeschiedenen": "Dahingeschiedene",
    "Dahingeschleppten": "Dahingeschleppte",
    "Dahingeschmolzenen": "Dahingeschmolzene",
    "Dahingeschmolzeneren": "Dahingeschmolzenere",
    "Dahingeschwundenen": "Dahingeschwundene",
    "Dahingesiechten": "Dahingesiechte",
    "Dahingesiechteren": "Dahingesiechtere",
    "Dahingestellten": "Dahingestellte",
    "Dahingesunkenen": "Dahingesunkene",
    "Dahingewelkten": "Dahingewelkte",
    "Dahingewelkteren": "Dahingewelktere",
    "Dahingewelktesten": "Dahingewelkteste",
    "Dahinlebenden": "Dahinlebende",
    "Dahinlebens": "Dahinleben",
    "Dahinraffenden": "Dahinraffende",
    "Dahinraffens": "Dahinraffen",
    "Dahinscheidenden": "Dahinscheidende",
    "Dahinscheidens": "Dahinscheiden",
    "Dahinschleppenden": "Dahinschleppende",
    "Dahinschleppens": "Dahinschleppen",
    "Dahinschmelzenden": "Dahinschmelzende",
    "Dahinschmelzenderen": "Dahinschmelzendere",
    "Dahinschmelzens": "Dahinschmelzen",
    "Dahinschwindenden": "Dahinschwindende",
    "Dahinschwindens": "Dahinschwinden",
    "Dahinsiechenden": "Dahinsiechende",
    "Dahinsiechenderen": "Dahinsiechendere",
    "Dahinsiechendsten": "Dahinsiechendste",
    "Dahinsiechens": "Dahinsiechen",
    "Dahinsinkenden": "Dahinsinkende",
    "Dahinsinkens": "Dahinsinken",
    "Dahinstellenden": "Dahinstellende",
    "Dahinstellens": "Dahinstellen",
    "Dahintergeklemmten": "Dahintergeklemmte",
    "Dahintergeknieten": "Dahintergekniete",
    "Dahintergekommenen": "Dahintergekommene",
    "Dahintergestandenen": "Dahintergestandene",
    "Dahinterklemmenden": "Dahinterklemmende",
    "Dahinterklemmenderen": "Dahinterklemmendere",
    "Dahinterklemmens": "Dahinterklemmen",
    "Dahinterknienden": "Dahinterkniende",
    "Dahinterkniens": "Dahinterknien",
    "Dahinterkommenden": "Dahinterkommende",
    "Dahinterkommens": "Dahinterkommen",
    "Dahinterstehenden": "Dahinterstehende",
    "Dahinterstehens": "Dahinterstehen",
    "Dahinwelkenden": "Dahinwelkende",
    "Dahinwelkenderen": "Dahinwelkendere",
    "Dahinwelkendsten": "Dahinwelkendste",
    "Dahinwelkens": "Dahinwelken",
    "Daimlers": "Daimler",
    "Daisys": "Daisy",
    "Daktylografinnen": "Daktylografin",
    "Daktylographinnen": "Daktylographin",
    "Daktylos": "Daktylo",
    "Dalassenden": "Dalassende",
    "Dalassens": "Dalassen",
    "Daliegenden": "Daliegende",
    "Daliegens": "Daliegen",
    "Dalmatinern": "Dalmatiner",
    "Dalmatiners": "Dalmatiner",
    "Damalige": "damalig",
    "Damaligen": "Damalige",
    "Damelnden": "Damelnde",
    "Damelnderen": "Damelndere",
    "Damelndsten": "Damelndste",
    "Damelns": "Dameln",
    "Damen": "Dame",
    "Damme": "Damm",
    "Dammes": "Damm",
    "Damms": "Damm",
    "Dampf": "dampfen",
    "Dampfe": "dampfen",
    "Dampfenden": "Dampfende",
    "Dampfenderen": "Dampfendere",
    "Dampfendsten": "Dampfendste",
    "Dampfens": "Dampfen",
    "Dampfern": "Dampfer",
    "Dampfers": "Dampfer",
    "Dampfs": "Dampf",
    "Danebenbenehmenden": "Danebenbenehmende",
    "Danebenbenehmenderen": "Danebenbenehmendere",
    "Danebenbenehmens": "Danebenbenehmen",
    "Danebenbenommenen": "Danebenbenommene",
    "Danebenbenommeneren": "Danebenbenommenere",
    "Danebenfallenden": "Danebenfallende",
    "Danebenfallens": "Danebenfallen",
    "Danebengefallenen": "Danebengefallene",
    "Danebengehauchten": "Danebengehauchte",
    "Danebengehauenen": "Danebengehauene",
    "Danebengelegenen": "Danebengelegene",
    "Danebengeschossenen": "Danebengeschossene",
    "Danebenhauchenden": "Danebenhauchende",
    "Danebenhauchens": "Danebenhauchen",
    "Danebenhauenden": "Danebenhauende",
    "Danebenhauens": "Danebenhauen",
    "Danebenliegenden": "Danebenliegende",
    "Danebenliegens": "Danebenliegen",
    "Danebenschießenden": "Danebenschießende",
    "Danebenschießens": "Danebenschießen",
    "Danielas": "Daniela",
    "Daniels": "Daniel",
    "Dankbare": "dankbar",
    "Dankbaren": "Dankbare",
    "Dankbareren": "Dankbarere",
    "Dankbarkeiten": "Dankbarkeit",
    "Dankbarste": "dankbar",
    "Dankbarsten": "Dankbarste",
    "Danke": "danken",
    "Dankenden": "Dankende",
    "Dankenderen": "Dankendere",
    "Dankendsten": "Dankendste",
    "Dankens": "Danken",
    "Dankenswerte": "dankenswert",
    "Dankenswerten": "Dankenswerte",
    "Dankes": "Dank",
    "Dankeschöns": "Dankeschön",
    "Danks": "Dank",
    "Darangeklebten": "Darangeklebte",
    "Darangesetzten": "Darangesetzte",
    "Daranklebenden": "Daranklebende",
    "Daranklebens": "Darankleben",
    "Daransetzenden": "Daransetzende",
    "Daransetzenderen": "Daransetzendere",
    "Daransetzendsten": "Daransetzendste",
    "Daransetzens": "Daransetzen",
    "Darauffolgenden": "Darauffolgende",
    "Darbenden": "Darbende",
    "Darbens": "Darben",
    "Darbietenden": "Darbietende",
    "Darbietens": "Darbieten",
    "Darbietungen": "Darbietung",
    "Darbringenden": "Darbringende",
    "Darbringens": "Darbringen",
    "Dargebotenen": "Dargebotene",
    "Dargebrachten": "Dargebrachte",
    "Dargelegten": "Dargelegte",
    "Dargereichten": "Dargereichte",
    "Dargestellten": "Dargestellte",
    "Daringesessenen": "Daringesessene",
    "Darinsitzenden": "Darinsitzende",
    "Darinsitzens": "Darinsitzen",
    "Darlegenden": "Darlegende",
    "Darlegens": "Darlegen",
    "Darlegungen": "Darlegung",
    "Darlehens": "Darlehen",
    "Darlehenskassen": "Darlehenskasse",
    "Darlings": "Darling",
    "Darme": "Darm",
    "Darmes": "Darm",
    "Darmkatarre": "Darmkatarr",
    "Darmkatarren": "Darmkatarr",
    "Darmkatarrs": "Darmkatarr",
    "Darms": "Darm",
    "Darmsaiten": "Darmsaite",
    "Darmstadts": "Darmstadt",
    "Darmstädtern": "Darmstädter",
    "Darmstädters": "Darmstädter",
    "Darreichenden": "Darreichende",
    "Darreichens": "Darreichen",
    "Darstellbaren": "Darstellbare",
    "Darstellbareren": "Darstellbarere",
    "Darstellbarsten": "Darstellbarste",
    "Darstellenden": "Darstellende",
    "Darstellens": "Darstellen",
    "Darstellerische": "darstellerisch",
    "Darstellerischen": "Darstellerische",
    "Darstellern": "Darsteller",
    "Darstellers": "Darsteller",
    "Darstellungen": "Darstellung",
    "Darunterbleibenden": "Darunterbleibende",
    "Darunterbleibens": "Darunterbleiben",
    "Darunterfallenden": "Darunterfallende",
    "Darunterfallens": "Darunterfallen",
    "Daruntergebliebenen": "Daruntergebliebene",
    "Daruntergefallenen": "Daruntergefallene",
    "Daruntergehobenen": "Daruntergehobene",
    "Daruntergeschriebenen": "Daruntergeschriebene",
    "Daruntergesetzten": "Daruntergesetzte",
    "Darunterhebenden": "Darunterhebende",
    "Darunterhebens": "Darunterheben",
    "Darunterschreibenden": "Darunterschreibende",
    "Darunterschreibens": "Darunterschreiben",
    "Daruntersetzenden": "Daruntersetzende",
    "Daruntersetzens": "Daruntersetzen",
    "Darwinisten": "Darwinist",
    "Darwinistische": "darwinistisch",
    "Darwinistischen": "Darwinistische",
    "Darüberfahrenden": "Darüberfahrende",
    "Darüberfahrens": "Darüberfahren",
    "Darübergefahrenen": "Darübergefahrene",
    "Darübergelegten": "Darübergelegte",
    "Darübergeschriebenen": "Darübergeschriebene",
    "Darübergestandenen": "Darübergestandene",
    "Darüberlegenden": "Darüberlegende",
    "Darüberlegens": "Darüberlegen",
    "Darüberschreibenden": "Darüberschreibende",
    "Darüberschreibens": "Darüberschreiben",
    "Darüberstehenden": "Darüberstehende",
    "Darüberstehens": "Darüberstehen",
    "Daseins": "Dasein",
    "Dasitzenden": "Dasitzende",
    "Dasitzens": "Dasitzen",
    "Dastehenden": "Dastehende",
    "Dastehens": "Dastehen",
    "Dateien": "Datei",
    "Daten": "Datum",
    "Datenverarbeitungen": "Datenverarbeitung",
    "Datierbare": "datierbar",
    "Datierbaren": "Datierbare",
    "Datierbareren": "Datierbarere",
    "Datierbarsten": "Datierbarste",
    "Datierenden": "Datierende",
    "Datierenderen": "Datierendere",
    "Datierendsten": "Datierendste",
    "Datierens": "Datieren",
    "Datierte": "datiert",
    "Datierten": "Datierte",
    "Datierungen": "Datierung",
    "Dative": "Dativ",
    "Dativen": "Dativ",
    "Dativs": "Dativ",
    "Datschen": "Datsche",
    "Datteln": "Dattel",
    "Datums": "Datum",
    "Dauer": "dauern",
    "Dauerbruche": "Dauerbruch",
    "Dauerbruchs": "Dauerbruch",
    "Dauerbrüche": "Dauerbruch",
    "Dauerbrüchen": "Dauerbruch",
    "Dauerhaften": "Dauerhafte",
    "Dauerhafteren": "Dauerhaftere",
    "Dauerhaftesten": "Dauerhafteste",
    "Dauermietern": "Dauermieter",
    "Dauermieters": "Dauermieter",
    "Dauernden": "Dauernde",
    "Dauerns": "Dauern",
    "Dauerparkern": "Dauerparker",
    "Dauerparkers": "Dauerparker",
    "Dauerrekorde": "Dauerrekord",
    "Dauerrekorden": "Dauerrekord",
    "Dauerrekords": "Dauerrekord",
    "Daumenbreiten": "Daumenbreite",
    "Daumens": "Daumen",
    "Daums": "Daum",
    "Daunen": "Daune",
    "Davids": "David",
    "Davonbleibenden": "Davonbleibende",
    "Davonbleibens": "Davonbleiben",
    "Davoneilenden": "Davoneilende",
    "Davoneilens": "Davoneilen",
    "Davonfahrenden": "Davonfahrende",
    "Davonfahrens": "Davonfahren",
    "Davonfliegenden": "Davonfliegende",
    "Davonfliegens": "Davonfliegen",
    "Davongebliebenen": "Davongebliebene",
    "Davongeeilten": "Davongeeilte",
    "Davongefahrenen": "Davongefahrene",
    "Davongeflogenen": "Davongeflogene",
    "Davongekommenen": "Davongekommene",
    "Davongelaufenen": "Davongelaufene",
    "Davongemachten": "Davongemachte",
    "Davongestohlenen": "Davongestohlene",
    "Davongestohleneren": "Davongestohlenere",
    "Davongetragenen": "Davongetragene",
    "Davongezogenen": "Davongezogene",
    "Davonkommenden": "Davonkommende",
    "Davonkommens": "Davonkommen",
    "Davonlaufenden": "Davonlaufende",
    "Davonlaufens": "Davonlaufen",
    "Davonmachenden": "Davonmachende",
    "Davonmachens": "Davonmachen",
    "Davonstehlenden": "Davonstehlende",
    "Davonstehlenderen": "Davonstehlendere",
    "Davonstehlendsten": "Davonstehlendste",
    "Davonstehlens": "Davonstehlen",
    "Davontragenden": "Davontragende",
    "Davontragens": "Davontragen",
    "Davonziehenden": "Davonziehende",
    "Davonziehens": "Davonziehen",
    "Davorgelegenen": "Davorgelegene",
    "Davorgelegten": "Davorgelegte",
    "Davorgestandenen": "Davorgestandene",
    "Davorgestellten": "Davorgestellte",
    "Davorlegenden": "Davorlegende",
    "Davorlegens": "Davorlegen",
    "Davorliegenden": "Davorliegende",
    "Davorliegens": "Davorliegen",
    "Davorstehenden": "Davorstehende",
    "Davorstehens": "Davorstehen",
    "Davorstellenden": "Davorstellende",
    "Davorstellens": "Davorstellen",
    "Dawns": "Dawn",
    "Dazugehörigen": "Dazugehörige",
    "Dazugekommenen": "Dazugekommene",
    "Dazugelernten": "Dazugelernte",
    "Dazugeschriebenen": "Dazugeschriebene",
    "Dazugesetzten": "Dazugesetzte",
    "Dazugezahlten": "Dazugezahlte",
    "Dazukommenden": "Dazukommende",
    "Dazukommens": "Dazukommen",
    "Dazulernenden": "Dazulernende",
    "Dazulernens": "Dazulernen",
    "Dazuschreibenden": "Dazuschreibende",
    "Dazuschreibens": "Dazuschreiben",
    "Dazusetzenden": "Dazusetzende",
    "Dazusetzens": "Dazusetzen",
    "Dazuzahlenden": "Dazuzahlende",
    "Dazuzahlens": "Dazuzahlen",
    "Dazwischenfahrenden": "Dazwischenfahrende",
    "Dazwischenfahrens": "Dazwischenfahren",
    "Dazwischenfunkenden": "Dazwischenfunkende",
    "Dazwischenfunkens": "Dazwischenfunken",
    "Dazwischengefahrenen": "Dazwischengefahrene",
    "Dazwischengefunkte": "dazwischengefunkt",
    "Dazwischengefunkten": "Dazwischengefunkte",
    "Dazwischengeredete": "dazwischengeredet",
    "Dazwischengeredeten": "Dazwischengeredete",
    "Dazwischengerufenen": "Dazwischengerufene",
    "Dazwischengestandenen": "Dazwischengestandene",
    "Dazwischengetretenen": "Dazwischengetretene",
    "Dazwischenredenden": "Dazwischenredende",
    "Dazwischenredens": "Dazwischenreden",
    "Dazwischenrufenden": "Dazwischenrufende",
    "Dazwischenrufens": "Dazwischenrufen",
    "Dazwischenstehenden": "Dazwischenstehende",
    "Dazwischenstehens": "Dazwischenstehen",
    "Dazwischentretenden": "Dazwischentretende",
    "Dazwischentretens": "Dazwischentreten",
    "Deale": "Deal",
    "Dealen": "Deal",
    "Dealern": "Dealer",
    "Dealers": "Dealer",
    "Deales": "Deal",
    "Deals": "Deal",
    "Debakeln": "Debakel",
    "Debakels": "Debakel",
    "Debatten": "Debatte",
    "Debattierenden": "Debattierende",
    "Debattierenderen": "Debattierendere",
    "Debattierendsten": "Debattierendste",
    "Debattierens": "Debattieren",
    "Debattierte": "debattiert",
    "Debattierten": "Debattierte",
    "Debattierteren": "Debattiertere",
    "Debattiertesten": "Debattierteste",
    "Debütanten": "Debütant",
    "Debütantinnen": "Debütantin",
    "Debütierenden": "Debütierende",
    "Debütierenderen": "Debütierendere",
    "Debütierendsten": "Debütierendste",
    "Debütierens": "Debütieren",
    "Debütierte": "debütiert",
    "Debütierten": "Debütierte",
    "Debüts": "Debüt",
    "Deckbette": "Deckbett",
    "Deckbetten": "Deckbett",
    "Deckbetts": "Deckbett",
    "Deckblatte": "Deckblatt",
    "Deckblattes": "Deckblatt",
    "Deckblatts": "Deckblatt",
    "Deckblätter": "Deckblatt",
    "Deckblättern": "Deckblatt",
    "Decke": "decken",
    "Deckeln": "Deckel",
    "Deckels": "Deckel",
    "Decken": "Decke",
    "Deckenden": "Deckende",
    "Deckens": "Decken",
    "Deckfarben": "Deckfarbe",
    "Deckhengste": "Deckhengst",
    "Deckhengsten": "Deckhengst",
    "Deckhengsts": "Deckhengst",
    "Decklasten": "Decklast",
    "Deckmantels": "Deckmantel",
    "Deckmäntel": "Deckmantel",
    "Deckmänteln": "Deckmantel",
    "Decknamen": "Deckname",
    "Deckplatten": "Deckplatte",
    "Deckungen": "Deckung",
    "Decodern": "Decoder",
    "Decoders": "Decoder",
    "Decodierenden": "Decodierende",
    "Decodierenderen": "Decodierendere",
    "Decodierendsten": "Decodierendste",
    "Decodierens": "Decodieren",
    "Decodierte": "decodiert",
    "Decodierten": "Decodierte",
    "Decodierteren": "Decodiertere",
    "Decodiertesten": "Decodierteste",
    "Decodings": "Decoding",
    "Deduktionen": "Deduktion",
    "Deduktive": "deduktiv",
    "Deduktiven": "Deduktive",
    "Deduzierenden": "Deduzierende",
    "Deduzierenderen": "Deduzierendere",
    "Deduzierendsten": "Deduzierendste",
    "Deduzierens": "Deduzieren",
    "Deduzierte": "deduziert",
    "Deduzierten": "Deduzierte",
    "Deerns": "Deern",
    "Deeskalierenden": "Deeskalierende",
    "Deeskalierenderen": "Deeskalierendere",
    "Deeskalierendsten": "Deeskalierendste",
    "Deeskalierens": "Deeskalieren",
    "Deeskalierte": "deeskaliert",
    "Deeskalierten": "Deeskalierte",
    "Deeskalierteren": "Deeskaliertere",
    "Deeskaliertesten": "Deeskalierteste",
    "Defekten": "Defekte",
    "Defekteren": "Defektere",
    "Defekteste": "defekt",
    "Defektesten": "Defekteste",
    "Defekts": "Defekt",
    "Defensive": "defensiv",
    "Defensiven": "Defensive",
    "Defensiveren": "Defensivere",
    "Defensivsten": "Defensivste",
    "Definierenden": "Definierende",
    "Definierens": "Definieren",
    "Definierte": "definiert",
    "Definierten": "Definierte",
    "Definiten": "Definite",
    "Definitionen": "Definition",
    "Definitive": "definitiv",
    "Definitiven": "Definitive",
    "Definitiveren": "Definitivere",
    "Definitivsten": "Definitivste",
    "Definitorischen": "Definitorische",
    "Definitorischeren": "Definitorischere",
    "Definitorischsten": "Definitorischste",
    "Defizite": "Defizit",
    "Defiziten": "Defizit",
    "Defizites": "Defizit",
    "Defizits": "Defizit",
    "Defizitären": "Defizitäre",
    "Defizitäreren": "Defizitärere",
    "Defizitärsten": "Defizitärste",
    "Deflationen": "Deflation",
    "Deflationäre": "deflationär",
    "Deflationären": "Deflationäre",
    "Deflationäreren": "Deflationärere",
    "Deflationärsten": "Deflationärste",
    "Deflektore": "Deflektor",
    "Deflektoren": "Deflektor",
    "Deflektors": "Deflektor",
    "Deformierenden": "Deformierende",
    "Deformierenderen": "Deformierendere",
    "Deformierendsten": "Deformierendste",
    "Deformierens": "Deformieren",
    "Deformierte": "deformiert",
    "Deformierten": "Deformierte",
    "Deformierteren": "Deformiertere",
    "Deformiertesten": "Deformierteste",
    "Deformierungen": "Deformierung",
    "Deformitäten": "Deformität",
    "Defrostern": "Defroster",
    "Defrosters": "Defroster",
    "Deftige": "deftig",
    "Deftigen": "Deftige",
    "Deftigeren": "Deftigere",
    "Deftigsten": "Deftigste",
    "Degens": "Degen",
    "Degershausens": "Degershausen",
    "Degradationen": "Degradation",
    "Degradierenden": "Degradierende",
    "Degradierens": "Degradieren",
    "Degradierte": "degradiert",
    "Degradierten": "Degradierte",
    "Degradierungen": "Degradierung",
    "Degressionen": "Degression",
    "Degressive": "degressiv",
    "Degressiven": "Degressive",
    "Dehnbaren": "Dehnbare",
    "Dehnenden": "Dehnende",
    "Dehnenderen": "Dehnendere",
    "Dehnendsten": "Dehnendste",
    "Dehnens": "Dehnen",
    "Dehnungen": "Dehnung",
    "Dehnungsfugen": "Dehnungsfuge",
    "Deich": "deichen",
    "Deiche": "deichen",
    "Deichen": "Deich",
    "Deichenden": "Deichende",
    "Deichens": "Deichen",
    "Deiches": "Deich",
    "Deichs": "Deich",
    "Deichselnden": "Deichselnde",
    "Deichselns": "Deichseln",
    "Dejustierenden": "Dejustierende",
    "Dejustierens": "Dejustieren",
    "Dejustierte": "dejustiert",
    "Dejustierten": "Dejustierte",
    "Dejustierteren": "Dejustiertere",
    "Dejustiertesten": "Dejustierteste",
    "Dekaden": "Dekade",
    "Dekadente": "dekadent",
    "Dekadenten": "Dekadente",
    "Dekadenteren": "Dekadentere",
    "Dekadentesten": "Dekadenteste",
    "Dekadenzen": "Dekadenz",
    "Dekadische": "dekadisch",
    "Dekadischen": "Dekadische",
    "Dekaedern": "Dekaeder",
    "Dekaeders": "Dekaeder",
    "Dekanate": "Dekanat",
    "Dekanaten": "Dekanat",
    "Dekanats": "Dekanat",
    "Dekane": "Dekan",
    "Dekanen": "Dekan",
    "Dekanes": "Dekan",
    "Dekans": "Dekan",
    "Dekartellierenden": "Dekartellierende",
    "Dekartellierenderen": "Dekartellierendere",
    "Dekartellierens": "Dekartellieren",
    "Dekartellierte": "dekartelliert",
    "Dekartellierten": "Dekartellierte",
    "Dekartellierteren": "Dekartelliertere",
    "Dekartellierteste": "dekartelliert",
    "Dekartellisierungen": "Dekartellisierung",
    "Deklamatore": "Deklamator",
    "Deklamatoren": "Deklamator",
    "Deklamators": "Deklamator",
    "Deklarationen": "Deklaration",
    "Deklarierenden": "Deklarierende",
    "Deklarierens": "Deklarieren",
    "Deklarierte": "deklariert",
    "Deklarierten": "Deklarierte",
    "Deklassierenden": "Deklassierende",
    "Deklassierenderen": "Deklassierendere",
    "Deklassierendsten": "Deklassierendste",
    "Deklassierens": "Deklassieren",
    "Deklassierte": "deklassiert",
    "Deklassierten": "Deklassierte",
    "Deklassierteren": "Deklassiertere",
    "Deklassiertesten": "Deklassierteste",
    "Deklassierungen": "Deklassierung",
    "Deklinabelste": "deklinabel",
    "Deklinabelsten": "Deklinabelste",
    "Deklinablen": "Deklinable",
    "Deklinableren": "Deklinablere",
    "Deklinationen": "Deklination",
    "Deklinatore": "Deklinator",
    "Deklinatoren": "Deklinator",
    "Deklinators": "Deklinator",
    "Deklinierenden": "Deklinierende",
    "Deklinierens": "Deklinieren",
    "Deklinierte": "dekliniert",
    "Deklinierten": "Deklinierte",
    "Dekolletes": "Dekollete",
    "Dekompensationen": "Dekompensation",
    "Dekontaminationen": "Dekontamination",
    "Dekontaminierungen": "Dekontaminierung",
    "Dekorationen": "Dekoration",
    "Dekorative": "dekorativ",
    "Dekorativen": "Dekorative",
    "Dekorativeren": "Dekorativere",
    "Dekorativsten": "Dekorativste",
    "Dekorierenden": "Dekorierende",
    "Dekorierens": "Dekorieren",
    "Dekorierte": "dekoriert",
    "Dekorierten": "Dekorierte",
    "Dekorierteren": "Dekoriertere",
    "Dekoriertesten": "Dekorierteste",
    "Dekorierungen": "Dekorierung",
    "Dekors": "Dekor",
    "Dekreditiere": "dekreditieren",
    "Dekreditierenden": "Dekreditierende",
    "Dekreditierenderen": "Dekreditierendere",
    "Dekreditierens": "Dekreditieren",
    "Dekreditierte": "dekreditiert",
    "Dekreditierten": "Dekreditierte",
    "Dekreditierteren": "Dekreditiertere",
    "Dekreditiertesten": "Dekreditierteste",
    "Dekrementierenden": "Dekrementierende",
    "Dekrementierens": "Dekrementieren",
    "Dekrementierte": "dekrementiert",
    "Dekrementierten": "Dekrementierte",
    "Dekrete": "Dekret",
    "Dekreten": "Dekret",
    "Dekrets": "Dekret",
    "Delegaten": "Delegat",
    "Delegationen": "Delegation",
    "Delegierenden": "Delegierende",
    "Delegierens": "Delegieren",
    "Delegierte": "delegiert",
    "Delegierten": "Delegierte",
    "Delernenden": "Delernende",
    "Delernten": "Delernte",
    "Deletionen": "Deletion",
    "Delikate": "delikat",
    "Delikaten": "Delikate",
    "Delikateren": "Delikatere",
    "Delikatessen": "Delikatesse",
    "Delikateste": "delikat",
    "Delikatesten": "Delikateste",
    "Delikte": "Delikt",
    "Delikten": "Delikt",
    "Deliktes": "Delikt",
    "Delikts": "Delikt",
    "Delinquente": "delinquent",
    "Delinquenten": "Delinquente",
    "Dellen": "Delle",
    "Dellenden": "Dellende",
    "Dellens": "Dellen",
    "Delokalisationen": "Delokalisation",
    "Delphine": "Delphin",
    "Delphinen": "Delphin",
    "Delphins": "Delphin",
    "Delphinschwimmens": "Delphinschwimmen",
    "Deltas": "Delta",
    "Demagogen": "Demagoge",
    "Demagoges": "Demagoge",
    "Demaskierenden": "Demaskierende",
    "Demaskierens": "Demaskieren",
    "Demaskierte": "demaskiert",
    "Demaskierten": "Demaskierte",
    "Demathematisierenden": "Demathematisierende",
    "Demathematisierens": "Demathematisieren",
    "Demathematisierte": "demathematisiert",
    "Demathematisierten": "Demathematisierte",
    "Dementierenden": "Dementierende",
    "Dementierenderen": "Dementierendere",
    "Dementierendsten": "Dementierendste",
    "Dementierens": "Dementieren",
    "Dementierte": "dementiert",
    "Dementierten": "Dementierte",
    "Dementierteren": "Dementiertere",
    "Dementiertesten": "Dementierteste",
    "Dementis": "Dementi",
    "Dementsprechende": "dementsprechend",
    "Dementsprechenden": "Dementsprechende",
    "Demilitarisierenden": "Demilitarisierende",
    "Demilitarisierenderen": "Demilitarisierendere",
    "Demilitarisierens": "Demilitarisieren",
    "Demilitarisierte": "demilitarisiert",
    "Demilitarisierten": "Demilitarisierte",
    "Demilitarisierteren": "Demilitarisiertere",
    "Deminutiven": "Deminutive",
    "Demissionierenden": "Demissionierende",
    "Demissionierenderen": "Demissionierendere",
    "Demissionierens": "Demissionieren",
    "Demissionierte": "demissioniert",
    "Demissionierten": "Demissionierte",
    "Demissionierteren": "Demissioniertere",
    "Demissionierteste": "demissioniert",
    "Demobilisationen": "Demobilisation",
    "Demodulationen": "Demodulation",
    "Demodulatore": "Demodulator",
    "Demodulatoren": "Demodulator",
    "Demodulators": "Demodulator",
    "Demodulierenden": "Demodulierende",
    "Demodulierens": "Demodulieren",
    "Demodulierte": "demoduliert",
    "Demodulierten": "Demodulierte",
    "Demografien": "Demografie",
    "Demographien": "Demographie",
    "Demographische": "demographisch",
    "Demographischen": "Demographische",
    "Demokraten": "Demokrat",
    "Demokratien": "Demokratie",
    "Demokratische": "demokratisch",
    "Demokratischen": "Demokratische",
    "Demokratischeren": "Demokratischere",
    "Demokratischsten": "Demokratischste",
    "Demokratisierenden": "Demokratisierende",
    "Demokratisierens": "Demokratisieren",
    "Demokratisierte": "demokratisiert",
    "Demokratisierten": "Demokratisierte",
    "Demokratisierteren": "Demokratisiertere",
    "Demokratisierungen": "Demokratisierung",
    "Demolierenden": "Demolierende",
    "Demolierenderen": "Demolierendere",
    "Demolierendsten": "Demolierendste",
    "Demolierens": "Demolieren",
    "Demolierte": "demoliert",
    "Demolierten": "Demolierte",
    "Demolierteren": "Demoliertere",
    "Demoliertesten": "Demolierteste",
    "Demonstranten": "Demonstrant",
    "Demonstrantinnen": "Demonstrantin",
    "Demonstrationen": "Demonstration",
    "Demonstrative": "demonstrativ",
    "Demonstrativen": "Demonstrative",
    "Demonstrativeren": "Demonstrativere",
    "Demonstrativsten": "Demonstrativste",
    "Demonstrierenden": "Demonstrierende",
    "Demonstrierenderen": "Demonstrierendere",
    "Demonstrierens": "Demonstrieren",
    "Demonstrierte": "demonstriert",
    "Demonstrierten": "Demonstrierte",
    "Demontierenden": "Demontierende",
    "Demontierenderen": "Demontierendere",
    "Demontierendsten": "Demontierendste",
    "Demontierens": "Demontieren",
    "Demontierte": "demontiert",
    "Demontierten": "Demontierte",
    "Demontierteren": "Demontiertere",
    "Demontiertesten": "Demontierteste",
    "Demoralisierenden": "Demoralisierende",
    "Demoralisierenderen": "Demoralisierendere",
    "Demoralisierens": "Demoralisieren",
    "Demoralisierte": "demoralisiert",
    "Demoralisierten": "Demoralisierte",
    "Demoralisierteren": "Demoralisiertere",
    "Demoralisierteste": "demoralisiert",
    "Demos": "Demo",
    "Demoskopien": "Demoskopie",
    "Demutsgebärden": "Demutsgebärde",
    "Demütigenden": "Demütigende",
    "Demütigenderen": "Demütigendere",
    "Demütigendsten": "Demütigendste",
    "Demütigens": "Demütigen",
    "Demütigungen": "Demütigung",
    "Denare": "Denar",
    "Denaren": "Denar",
    "Denars": "Denar",
    "Denaturierungen": "Denaturierung",
    "Denazifizierenden": "Denazifizierende",
    "Denazifizierens": "Denazifizieren",
    "Denazifizierte": "denazifiziert",
    "Denazifizierten": "Denazifizierte",
    "Dendrologen": "Dendrologe",
    "Denkarten": "Denkart",
    "Denkaufgaben": "Denkaufgabe",
    "Denkbare": "denkbar",
    "Denkbaren": "Denkbare",
    "Denkbareren": "Denkbarere",
    "Denkbarsten": "Denkbarste",
    "Denkblockaden": "Denkblockade",
    "Denkenden": "Denkende",
    "Denkenderen": "Denkendere",
    "Denkendsten": "Denkendste",
    "Denkens": "Denken",
    "Denkern": "Denker",
    "Denkers": "Denker",
    "Denkerstirnen": "Denkerstirn",
    "Denkfaulen": "Denkfaule",
    "Denkfauleren": "Denkfaulere",
    "Denkfaulsten": "Denkfaulste",
    "Denkfehlern": "Denkfehler",
    "Denkfehlers": "Denkfehler",
    "Denkfähigen": "Denkfähige",
    "Denkfähigeren": "Denkfähigere",
    "Denkfähigkeiten": "Denkfähigkeit",
    "Denkfähigste": "denkfähig",
    "Denkfähigsten": "Denkfähigste",
    "Denkhilfen": "Denkhilfe",
    "Denkmale": "Denkmal",
    "Denkmales": "Denkmal",
    "Denkmodelle": "Denkmodell",
    "Denkmodellen": "Denkmodell",
    "Denkmodells": "Denkmodell",
    "Denkmäler": "Denkmal",
    "Denkmälern": "Denkmal",
    "Denkmünzen": "Denkmünze",
    "Denkschwache": "denkschwach",
    "Denkschwachen": "Denkschwache",
    "Denkschwächeren": "Denkschwächere",
    "Denkschwächsten": "Denkschwächste",
    "Denksportaufgaben": "Denksportaufgabe",
    "Denksports": "Denksport",
    "Denkspruche": "Denkspruch",
    "Denkspruchs": "Denkspruch",
    "Denksprüche": "Denkspruch",
    "Denksprüchen": "Denkspruch",
    "Denksteine": "Denkstein",
    "Denksteinen": "Denkstein",
    "Denksteins": "Denkstein",
    "Denkverbote": "Denkverbot",
    "Denkverboten": "Denkverbot",
    "Denkverbots": "Denkverbot",
    "Denkvermögens": "Denkvermögen",
    "Denkweisen": "Denkweise",
    "Denkwürdige": "denkwürdig",
    "Denkwürdigen": "Denkwürdige",
    "Denkwürdigeren": "Denkwürdigere",
    "Denkwürdigkeiten": "Denkwürdigkeit",
    "Denkwürdigste": "denkwürdig",
    "Denkwürdigsten": "Denkwürdigste",
    "Denkzetteln": "Denkzettel",
    "Denkzettels": "Denkzettel",
    "Denkübungen": "Denkübung",
    "Dennys": "Denny",
    "Denotate": "Denotat",
    "Denotaten": "Denotat",
    "Denotationen": "Denotation",
    "Denotats": "Denotat",
    "Dentalen": "Dentale",
    "Dentisten": "Dentist",
    "Denunzianten": "Denunziant",
    "Denunziationen": "Denunziation",
    "Denunzierenden": "Denunzierende",
    "Denunzierens": "Denunzieren",
    "Denunzierte": "denunziert",
    "Denunzierten": "Denunzierte",
    "Deos": "Deo",
    "Depeschen": "Depesche",
    "Dephlegmatore": "Dephlegmator",
    "Dephlegmatoren": "Dephlegmator",
    "Dephlegmators": "Dephlegmator",
    "Depigmentierungen": "Depigmentierung",
    "Deplatzierungen": "Deplatzierung",
    "Deplazierenden": "Deplazierende",
    "Deplazierens": "Deplazieren",
    "Deplazierte": "deplaziert",
    "Deplazierten": "Deplazierte",
    "Deplazierteren": "Deplaziertere",
    "Deplaziertesten": "Deplazierteste",
    "Deplazierungen": "Deplazierung",
    "Depolarisatore": "Depolarisator",
    "Depolarisatoren": "Depolarisator",
    "Depolarisators": "Depolarisator",
    "Deponate": "Deponat",
    "Deponaten": "Deponat",
    "Deponats": "Deponat",
    "Deponenten": "Deponent",
    "Deponien": "Deponie",
    "Deponierenden": "Deponierende",
    "Deponierens": "Deponieren",
    "Deponierte": "deponiert",
    "Deponierten": "Deponierte",
    "Depopulationen": "Depopulation",
    "Deportationen": "Deportation",
    "Deportierenden": "Deportierende",
    "Deportierens": "Deportieren",
    "Deportierte": "deportiert",
    "Deportierten": "Deportierte",
    "Deportierungen": "Deportierung",
    "Depositionen": "Deposition",
    "Depots": "Depot",
    "Depressionen": "Depression",
    "Depressive": "depressiv",
    "Depressiven": "Depressive",
    "Depressiveren": "Depressivere",
    "Depressivsten": "Depressivste",
    "Deprimierenden": "Deprimierende",
    "Deprimierenderen": "Deprimierendere",
    "Deprimierendsten": "Deprimierendste",
    "Deprimierens": "Deprimieren",
    "Deprimierte": "deprimiert",
    "Deprimierten": "Deprimierte",
    "Deprimierteren": "Deprimiertere",
    "Deprimiertesten": "Deprimierteste",
    "Deputanten": "Deputant",
    "Deputate": "Deputat",
    "Deputaten": "Deputat",
    "Deputats": "Deputat",
    "Deputierenden": "Deputierende",
    "Deputierens": "Deputieren",
    "Deputierte": "deputiert",
    "Deputierten": "Deputierte",
    "Derartigen": "Derartige",
    "Derben": "Derbe",
    "Derberen": "Derbere",
    "Derbsten": "Derbste",
    "Derbys": "Derby",
    "Dereinstige": "dereinstig",
    "Dereinstigen": "Dereinstige",
    "Dermatologen": "Dermatologe",
    "Dermatologische": "dermatologisch",
    "Dermatologischen": "Dermatologische",
    "Derricks": "Derrick",
    "Derzeitigen": "Derzeitige",
    "Desastern": "Desaster",
    "Desasters": "Desaster",
    "Desertierenden": "Desertierende",
    "Desertierens": "Desertieren",
    "Desertierte": "desertiert",
    "Desertierten": "Desertierte",
    "Designern": "Designer",
    "Designers": "Designer",
    "Designs": "Design",
    "Desillusionen": "Desillusion",
    "Desillusionierenden": "Desillusionierende",
    "Desillusionierenderen": "Desillusionierendere",
    "Desillusionierens": "Desillusionieren",
    "Desillusionierte": "desillusioniert",
    "Desillusionierten": "Desillusionierte",
    "Desillusionierteren": "Desillusioniertere",
    "Desinfektionen": "Desinfektion",
    "Desinfektore": "Desinfektor",
    "Desinfektoren": "Desinfektor",
    "Desinfektors": "Desinfektor",
    "Desinfiziere": "desinfizieren",
    "Desinfizierenden": "Desinfizierende",
    "Desinfizierenderen": "Desinfizierendere",
    "Desinfizierens": "Desinfizieren",
    "Desinfizierte": "desinfiziert",
    "Desinfizierten": "Desinfizierte",
    "Desinfizierteren": "Desinfiziertere",
    "Desinfiziertesten": "Desinfizierteste",
    "Desinfizierungen": "Desinfizierung",
    "Desolaten": "Desolate",
    "Desolateren": "Desolatere",
    "Desolatesten": "Desolateste",
    "Desorptionen": "Desorption",
    "Desserts": "Dessert",
    "Dessins": "Dessin",
    "Destillen": "Destille",
    "Destinationen": "Destination",
    "Destruktionen": "Destruktion",
    "Destruktivkräfte": "Destruktivkraft",
    "Destruktivkräften": "Destruktivkraft",
    "Details": "Detail",
    "Detekteien": "Detektei",
    "Detektive": "Detektiv",
    "Detektiven": "Detektiv",
    "Detektivs": "Detektiv",
    "Detektore": "Detektor",
    "Detektoren": "Detektor",
    "Detektors": "Detektor",
    "Determiniere": "determinieren",
    "Determinierenden": "Determinierende",
    "Determinierenderen": "Determinierendere",
    "Determinierens": "Determinieren",
    "Determinierte": "determiniert",
    "Determinierten": "Determinierte",
    "Deterministen": "Determinist",
    "Deterministische": "deterministisch",
    "Deterministischen": "Deterministische",
    "Detlefs": "Detlef",
    "Detonationen": "Detonation",
    "Detonatore": "Detonator",
    "Detonatoren": "Detonator",
    "Detonators": "Detonator",
    "Detonierenden": "Detonierende",
    "Detonierenderen": "Detonierendere",
    "Detonierendsten": "Detonierendste",
    "Detonierens": "Detonieren",
    "Detonierte": "detoniert",
    "Detonierten": "Detonierte",
    "Detonierteren": "Detoniertere",
    "Detoniertesten": "Detonierteste",
    "Deubeln": "Deubel",
    "Deubels": "Deubel",
    "Deutelnden": "Deutelnde",
    "Deutelns": "Deuteln",
    "Deutenden": "Deutende",
    "Deutens": "Deuten",
    "Deutereien": "Deuterei",
    "Deutlichen": "Deutliche",
    "Deutlicheren": "Deutlichere",
    "Deutlichsten": "Deutlichste",
    "Deuts": "Deut",
    "Deutschamerikanischen": "Deutschamerikanische",
    "Deutsche": "deutschen",
    "Deutschen": "Deutsche",
    "Deutschenden": "Deutschende",
    "Deutschens": "Deutschen",
    "Deutschfeindlichen": "Deutschfeindliche",
    "Deutschfreundlichen": "Deutschfreundliche",
    "Deutschlandpolitischen": "Deutschlandpolitische",
    "Deutschlands": "Deutschland",
    "Deutschschweizerische": "deutschschweizerisch",
    "Deutschschweizerischen": "Deutschschweizerische",
    "Deutschsprachigen": "Deutschsprachige",
    "Deutschsprachlichen": "Deutschsprachliche",
    "Deutschsprechenden": "Deutschsprechende",
    "Deutschtums": "Deutschtum",
    "Deutungen": "Deutung",
    "Devilles": "Deville",
    "Devisen": "Devise",
    "Dezembern": "Dezember",
    "Dezembers": "Dezember",
    "Dezente": "dezent",
    "Dezenten": "Dezente",
    "Dezenteren": "Dezentere",
    "Dezentesten": "Dezenteste",
    "Dezentralisierenden": "Dezentralisierende",
    "Dezentralisierenderen": "Dezentralisierendere",
    "Dezentralisierens": "Dezentralisieren",
    "Dezentralisierte": "dezentralisiert",
    "Dezentralisierten": "Dezentralisierte",
    "Dezentralisierteren": "Dezentralisiertere",
    "Dezentralisierungen": "Dezentralisierung",
    "Dezernate": "Dezernat",
    "Dezernaten": "Dezernat",
    "Dezernats": "Dezernat",
    "Dezernenten": "Dezernent",
    "Dezernentinnen": "Dezernentin",
    "Dezidierenden": "Dezidierende",
    "Dezidierens": "Dezidieren",
    "Dezidierte": "dezidiert",
    "Dezidierten": "Dezidierte",
    "Dezimalen": "Dezimale",
    "Dezimalisierenden": "Dezimalisierende",
    "Dezimalisierens": "Dezimalisieren",
    "Dezimalisierte": "dezimalisiert",
    "Dezimalisierten": "Dezimalisierte",
    "Dezimalrechnungen": "Dezimalrechnung",
    "Dezimalstellen": "Dezimalstelle",
    "Dezimalsysteme": "Dezimalsystem",
    "Dezimalsystemen": "Dezimalsystem",
    "Dezimalsystems": "Dezimalsystem",
    "Dezimalwaagen": "Dezimalwaage",
    "Dezimalzahlen": "Dezimalzahl",
    "Dezimationen": "Dezimation",
    "Dezimen": "Dezime",
    "Dezimetern": "Dezimeter",
    "Dezimeters": "Dezimeter",
    "Dezimeterwellen": "Dezimeterwelle",
    "Dezimierenden": "Dezimierende",
    "Dezimierenderen": "Dezimierendere",
    "Dezimierendsten": "Dezimierendste",
    "Dezimierens": "Dezimieren",
    "Dezimierte": "dezimiert",
    "Dezimierten": "Dezimierte",
    "Dezimierteren": "Dezimiertere",
    "Dezimiertesten": "Dezimierteste",
    "Dezimierungen": "Dezimierung",
    "Diabetikern": "Diabetiker",
    "Diabetikers": "Diabetiker",
    "Diabetrachtern": "Diabetrachter",
    "Diabetrachters": "Diabetrachter",
    "Diabolische": "diabolisch",
    "Diabolischen": "Diabolische",
    "Diabolischeren": "Diabolischere",
    "Diabolischsten": "Diabolischste",
    "Diademe": "Diadem",
    "Diademen": "Diadem",
    "Diademes": "Diadem",
    "Diadems": "Diadem",
    "Diafonien": "Diafonie",
    "Diagnosen": "Diagnose",
    "Diagnostiken": "Diagnostik",
    "Diagnostische": "diagnostisch",
    "Diagnostischen": "Diagnostische",
    "Diagnostizierenden": "Diagnostizierende",
    "Diagnostizierens": "Diagnostizieren",
    "Diagnostizierte": "diagnostiziert",
    "Diagnostizierten": "Diagnostizierte",
    "Diagonalen": "Diagonale",
    "Diakone": "Diakon",
    "Diakonen": "Diakon",
    "Diakones": "Diakon",
    "Diakonien": "Diakonie",
    "Diakonische": "diakonisch",
    "Diakonischen": "Diakonische",
    "Diakonischeren": "Diakonischere",
    "Diakonischsten": "Diakonischste",
    "Diakonissinnen": "Diakonissin",
    "Diakons": "Diakon",
    "Dialekte": "Dialekt",
    "Dialekten": "Dialekt",
    "Dialektfreie": "dialektfrei",
    "Dialektfreien": "Dialektfreie",
    "Dialektfreieren": "Dialektfreiere",
    "Dialektfreisten": "Dialektfreiste",
    "Dialektikern": "Dialektiker",
    "Dialektikers": "Dialektiker",
    "Dialektische": "dialektisch",
    "Dialektischen": "Dialektische",
    "Dialekts": "Dialekt",
    "Dialoge": "Dialog",
    "Dialogen": "Dialog",
    "Dialogisierenden": "Dialogisierende",
    "Dialogisierens": "Dialogisieren",
    "Dialogisierte": "dialogisiert",
    "Dialogisierten": "Dialogisierte",
    "Dialogs": "Dialog",
    "Dialysierenden": "Dialysierende",
    "Dialysierens": "Dialysieren",
    "Dialysierte": "dialysiert",
    "Dialysierten": "Dialysierte",
    "Diamanten": "Diamant",
    "Diamantene": "diamanten",
    "Diamantenen": "Diamantene",
    "Dias": "Dia",
    "Dichotomisierungen": "Dichotomisierung",
    "Dichte": "dicht",
    "Dichten": "Dichte",
    "Dichtenden": "Dichtende",
    "Dichtens": "Dichten",
    "Dichter": "dicht",
    "Dichteren": "Dichtere",
    "Dichterinnen": "Dichterin",
    "Dichterische": "dichterisch",
    "Dichterischen": "Dichterische",
    "Dichtern": "Dichter",
    "Dichters": "Dichter",
    "Dichtesten": "Dichteste",
    "Dichtgedrängten": "Dichtgedrängte",
    "Dichtgedrängteren": "Dichtgedrängtere",
    "Dichtgemachten": "Dichtgemachte",
    "Dichtmachenden": "Dichtmachende",
    "Dichtmachens": "Dichtmachen",
    "Dichtungen": "Dichtung",
    "Dickbauche": "Dickbauch",
    "Dickbauchs": "Dickbauch",
    "Dickbäuche": "Dickbauch",
    "Dickbäuchen": "Dickbauch",
    "Dickbäuchige": "dickbäuchig",
    "Dickbäuchigen": "Dickbäuchige",
    "Dickbäuchigeren": "Dickbäuchigere",
    "Dickbäuchigsten": "Dickbäuchigste",
    "Dickdarme": "Dickdarm",
    "Dickdarms": "Dickdarm",
    "Dickdärme": "Dickdarm",
    "Dickdärmen": "Dickdarm",
    "Dicke": "dick",
    "Dicken": "Dicke",
    "Dickeren": "Dickere",
    "Dickfelligen": "Dickfellige",
    "Dickfelligeren": "Dickfelligere",
    "Dickfelligsten": "Dickfelligste",
    "Dickflüssigen": "Dickflüssige",
    "Dickflüssigeren": "Dickflüssigere",
    "Dickflüssigsten": "Dickflüssigste",
    "Dickhäutern": "Dickhäuter",
    "Dickhäuters": "Dickhäuter",
    "Dickkopfe": "Dickkopf",
    "Dickkopfs": "Dickkopf",
    "Dickköpfe": "Dickkopf",
    "Dickköpfen": "Dickkopf",
    "Dickköpfige": "dickköpfig",
    "Dickköpfigen": "Dickköpfige",
    "Dickköpfigeren": "Dickköpfigere",
    "Dickköpfigsten": "Dickköpfigste",
    "Dickleibige": "dickleibig",
    "Dickleibigen": "Dickleibige",
    "Dickleibigeren": "Dickleibigere",
    "Dickleibigsten": "Dickleibigste",
    "Dicklichen": "Dickliche",
    "Dicklicheren": "Dicklichere",
    "Dicklichsten": "Dicklichste",
    "Dickschädeln": "Dickschädel",
    "Dickschädels": "Dickschädel",
    "Dickste": "dick",
    "Dicksten": "Dickste",
    "Dickwandigen": "Dickwandige",
    "Dickwandigeren": "Dickwandigere",
    "Dickwandigsten": "Dickwandigste",
    "Didaktiken": "Didaktik",
    "Didaktikern": "Didaktiker",
    "Didaktikers": "Didaktiker",
    "Didaktische": "didaktisch",
    "Didaktischen": "Didaktische",
    "Diebe": "Dieb",
    "Dieben": "Dieb",
    "Diebereien": "Dieberei",
    "Diebes": "Dieb",
    "Diebesguts": "Diebesgut",
    "Diebs": "Dieb",
    "Dieburgs": "Dieburg",
    "Diehls": "Diehl",
    "Dielen": "Diele",
    "Dienenden": "Dienende",
    "Dienens": "Dienen",
    "Dienern": "Diener",
    "Dieners": "Diener",
    "Dienlichen": "Dienliche",
    "Dienlicheren": "Dienlichere",
    "Dienlichsten": "Dienlichste",
    "Dienstage": "Dienstag",
    "Dienstagen": "Dienstag",
    "Dienstags": "Dienstag",
    "Dienstbare": "dienstbar",
    "Dienstbaren": "Dienstbare",
    "Dienstbereiten": "Dienstbereite",
    "Dienstbereiteren": "Dienstbereitere",
    "Dienstbereitesten": "Dienstbereiteste",
    "Dienste": "Dienst",
    "Diensteifrige": "diensteifrig",
    "Diensteifrigen": "Diensteifrige",
    "Diensteifrigeren": "Diensteifrigere",
    "Diensteifrigsten": "Diensteifrigste",
    "Diensten": "Dienst",
    "Dienstes": "Dienst",
    "Dienstfähige": "dienstfähig",
    "Dienstfähigen": "Dienstfähige",
    "Dienstfähigeren": "Dienstfähigere",
    "Dienstfähigsten": "Dienstfähigste",
    "Diensthabenden": "Diensthabende",
    "Dienstlichen": "Dienstliche",
    "Diensts": "Dienst",
    "Dienstsachen": "Dienstsache",
    "Diensttaugliche": "diensttauglich",
    "Diensttauglichen": "Diensttaugliche",
    "Diensttauglicheren": "Diensttauglichere",
    "Diensttuenden": "Diensttuende",
    "Dienstunfähigen": "Dienstunfähige",
    "Dienstunfähigeren": "Dienstunfähigere",
    "Dienstunfähigsten": "Dienstunfähigste",
    "Dienstuntauglichen": "Dienstuntaugliche",
    "Dienstuntauglicheren": "Dienstuntauglichere",
    "Dienstwagens": "Dienstwagen",
    "Dienstwillige": "dienstwillig",
    "Dienstwilligen": "Dienstwillige",
    "Dienstwilligeren": "Dienstwilligere",
    "Dienstwilligsten": "Dienstwilligste",
    "Diepgens": "Diepgen",
    "Diesbezügliche": "diesbezüglich",
    "Diesbezüglichen": "Diesbezügliche",
    "Diesels": "Diesel",
    "Dieselöle": "Dieselöl",
    "Dieselölen": "Dieselöl",
    "Dieselöls": "Dieselöl",
    "Diesigen": "Diesige",
    "Diesigeren": "Diesigere",
    "Diesigsten": "Diesigste",
    "Diesjährigen": "Diesjährige",
    "Diesmaligen": "Diesmalige",
    "Diesseitigen": "Diesseitige",
    "Diestels": "Diestel",
    "Dieters": "Dieter",
    "Dietesheims": "Dietesheim",
    "Dietmars": "Dietmar",
    "Dietrichs": "Dietrich",
    "Dietzenbachern": "Dietzenbacher",
    "Dietzenbachers": "Dietzenbacher",
    "Dietzenbachs": "Dietzenbach",
    "Diffamien": "Diffamie",
    "Diffamierenden": "Diffamierende",
    "Diffamierenderen": "Diffamierendere",
    "Diffamierendsten": "Diffamierendste",
    "Diffamierens": "Diffamieren",
    "Diffamierte": "diffamiert",
    "Diffamierten": "Diffamierte",
    "Diffamierteren": "Diffamiertere",
    "Diffamiertesten": "Diffamierteste",
    "Diffamierungen": "Diffamierung",
    "Differentiale": "Differential",
    "Differentialen": "Differential",
    "Differentiales": "Differential",
    "Differentials": "Differential",
    "Differentiationen": "Differentiation",
    "Differentielle": "differentiell",
    "Differentiellen": "Differentielle",
    "Differenzen": "Differenz",
    "Differenziationen": "Differenziation",
    "Differenzierbare": "differenzierbar",
    "Differenzierbaren": "Differenzierbare",
    "Differenzierenden": "Differenzierende",
    "Differenzierens": "Differenzieren",
    "Differenzierte": "differenziert",
    "Differenzierten": "Differenzierte",
    "Differenzierteren": "Differenziertere",
    "Differenzierteste": "differenziert",
    "Differenzierungen": "Differenzierung",
    "Differierenden": "Differierende",
    "Differierenderen": "Differierendere",
    "Differierendsten": "Differierendste",
    "Differierens": "Differieren",
    "Differierte": "differiert",
    "Differierten": "Differierte",
    "Diffizilen": "Diffizile",
    "Diffizileren": "Diffizilere",
    "Diffizilsten": "Diffizilste",
    "Diffundierenden": "Diffundierende",
    "Diffundierens": "Diffundieren",
    "Diffundierte": "diffundiert",
    "Diffundierten": "Diffundierte",
    "Diffusen": "Diffuse",
    "Diffuseren": "Diffusere",
    "Diffusesten": "Diffuseste",
    "Diffusore": "Diffusor",
    "Diffusoren": "Diffusor",
    "Diffusors": "Diffusor",
    "Digitalaufnahmen": "Digitalaufnahme",
    "Digitale": "digital",
    "Digitalen": "Digitale",
    "Digitalrechnern": "Digitalrechner",
    "Digitalrechners": "Digitalrechner",
    "Diktate": "Diktat",
    "Diktaten": "Diktat",
    "Diktates": "Diktat",
    "Diktatore": "Diktator",
    "Diktatoren": "Diktator",
    "Diktatorische": "diktatorisch",
    "Diktatorischen": "Diktatorische",
    "Diktators": "Diktator",
    "Diktats": "Diktat",
    "Diktaturen": "Diktatur",
    "Diktierenden": "Diktierende",
    "Diktierens": "Diktieren",
    "Diktiergeräte": "Diktiergerät",
    "Diktiergeräten": "Diktiergerät",
    "Diktiergeräts": "Diktiergerät",
    "Diktierte": "diktiert",
    "Diktierten": "Diktierte",
    "Dilemmas": "Dilemma",
    "Dilettanten": "Dilettant",
    "Dilettantische": "dilettantisch",
    "Dilettantischen": "Dilettantische",
    "Dilettantischeren": "Dilettantischere",
    "Dilettantischsten": "Dilettantischste",
    "Dimensionalen": "Dimensionale",
    "Dimensionen": "Dimension",
    "Dimensionierenden": "Dimensionierende",
    "Dimensionierens": "Dimensionieren",
    "Dimensionierte": "dimensioniert",
    "Dimensionierten": "Dimensionierte",
    "Dimissionen": "Dimission",
    "Dimmern": "Dimmer",
    "Dimmers": "Dimmer",
    "Diners": "Diner",
    "Ding": "dingen",
    "Dinge": "dingen",
    "Dingen": "Ding",
    "Dingenden": "Dingende",
    "Dingens": "Dingen",
    "Dinges": "Ding",
    "Dings": "Ding",
    "Dinierenden": "Dinierende",
    "Dinierens": "Dinieren",
    "Dinierte": "diniert",
    "Dinierten": "Dinierte",
    "Dinkelsbühls": "Dinkelsbühl",
    "Dinnern": "Dinner",
    "Dinners": "Dinner",
    "Dinosauriern": "Dinosaurier",
    "Dinosauriers": "Dinosaurier",
    "Dioden": "Diode",
    "Diophantische": "diophantisch",
    "Diophantischen": "Diophantische",
    "Dioxine": "Dioxin",
    "Dioxinen": "Dioxin",
    "Dioxins": "Dioxin",
    "Diphtherien": "Diphtherie",
    "Diploma": "Diplom",
    "Diplomanden": "Diplomand",
    "Diplomaten": "Diplomat",
    "Diplomatikern": "Diplomatiker",
    "Diplomatikers": "Diplomatiker",
    "Diplomatische": "diplomatisch",
    "Diplomatischen": "Diplomatische",
    "Diplomatischeren": "Diplomatischere",
    "Diplomatischsten": "Diplomatischste",
    "Diplomatisierenden": "Diplomatisierende",
    "Diplomatisierens": "Diplomatisieren",
    "Diplomatisierte": "diplomatisiert",
    "Diplomatisierten": "Diplomatisierte",
    "Diplomierenden": "Diplomierende",
    "Diplomierens": "Diplomieren",
    "Diplomierte": "diplomiert",
    "Diplomierten": "Diplomierte",
    "Diploms": "Diplom",
    "Dippenden": "Dippende",
    "Dippens": "Dippen",
    "Direkteinleitern": "Direkteinleiter",
    "Direkteinleiters": "Direkteinleiter",
    "Direkten": "Direkte",
    "Direkteren": "Direktere",
    "Direktesten": "Direkteste",
    "Direktfluge": "Direktflug",
    "Direktflugs": "Direktflug",
    "Direktflüge": "Direktflug",
    "Direktflügen": "Direktflug",
    "Direktionen": "Direktion",
    "Direktive": "direktiv",
    "Direktiven": "Direktive",
    "Direktmandate": "Direktmandat",
    "Direktmandaten": "Direktmandat",
    "Direktmandats": "Direktmandat",
    "Direktorate": "Direktorat",
    "Direktoraten": "Direktorat",
    "Direktorats": "Direktorat",
    "Direktore": "Direktor",
    "Direktoren": "Direktor",
    "Direktorinnen": "Direktorin",
    "Direktors": "Direktor",
    "Direktübertragungen": "Direktübertragung",
    "Dirigate": "Dirigat",
    "Dirigaten": "Dirigat",
    "Dirigats": "Dirigat",
    "Dirigenten": "Dirigent",
    "Dirigierenden": "Dirigierende",
    "Dirigierens": "Dirigieren",
    "Dirigierte": "dirigiert",
    "Dirigierten": "Dirigierte",
    "Dirigistischen": "Dirigistische",
    "Dirks": "Dirk",
    "Dirnen": "Dirne",
    "Discos": "Disco",
    "Discotheken": "Discothek",
    "Discountern": "Discounter",
    "Discounters": "Discounter",
    "Disharmonien": "Disharmonie",
    "Disjunktionen": "Disjunktion",
    "Disketten": "Diskette",
    "Diskontgeschäfte": "Diskontgeschäft",
    "Diskontgeschäften": "Diskontgeschäft",
    "Diskontgeschäfts": "Diskontgeschäft",
    "Diskordanzen": "Diskordanz",
    "Diskos": "Disko",
    "Diskotheken": "Diskothek",
    "Diskreditierenden": "Diskreditierende",
    "Diskreditierens": "Diskreditieren",
    "Diskreditierte": "diskreditiert",
    "Diskreditierten": "Diskreditierte",
    "Diskredits": "Diskredit",
    "Diskrepanzen": "Diskrepanz",
    "Diskrete": "diskret",
    "Diskreten": "Diskrete",
    "Diskriminanten": "Diskriminante",
    "Diskriminationen": "Diskrimination",
    "Diskriminierenden": "Diskriminierende",
    "Diskriminierenderen": "Diskriminierendere",
    "Diskriminierens": "Diskriminieren",
    "Diskriminierte": "diskriminiert",
    "Diskriminierten": "Diskriminierte",
    "Diskriminierteren": "Diskriminiertere",
    "Diskriminierteste": "diskriminiert",
    "Diskriminierungen": "Diskriminierung",
    "Diskurse": "Diskurs",
    "Diskursen": "Diskurs",
    "Diskurses": "Diskurs",
    "Diskussionen": "Diskussion",
    "Diskutierenden": "Diskutierende",
    "Diskutierens": "Diskutieren",
    "Diskutierte": "diskutiert",
    "Diskutierten": "Diskutierte",
    "Diskutierteren": "Diskutiertere",
    "Diskutiertesten": "Diskutierteste",
    "Dispersionen": "Dispersion",
    "Disponenten": "Disponent",
    "Disponierenden": "Disponierende",
    "Disponierens": "Disponieren",
    "Disponierte": "disponiert",
    "Disponierten": "Disponierte",
    "Dispositionen": "Disposition",
    "Dispositionsfähige": "dispositionsfähig",
    "Dispositionsfähigen": "Dispositionsfähige",
    "Disproportionen": "Disproportion",
    "Disproportionierungen": "Disproportionierung",
    "Disputationen": "Disputation",
    "Dispute": "Disput",
    "Disputen": "Disput",
    "Disputes": "Disput",
    "Disputs": "Disput",
    "Disqualifikationen": "Disqualifikation",
    "Disqualifizierenden": "Disqualifizierende",
    "Disqualifizierens": "Disqualifizieren",
    "Disqualifizierte": "disqualifiziert",
    "Disqualifizierten": "Disqualifizierte",
    "Disqualifizierungen": "Disqualifizierung",
    "Dissertierenden": "Dissertierende",
    "Dissertierens": "Dissertieren",
    "Dissertierte": "dissertiert",
    "Dissertierten": "Dissertierte",
    "Dissidenten": "Dissident",
    "Dissidierenden": "Dissidierende",
    "Dissidierens": "Dissidieren",
    "Dissidierte": "dissidiert",
    "Dissidierten": "Dissidierte",
    "Dissimilationen": "Dissimilation",
    "Dissonante": "dissonant",
    "Dissonanten": "Dissonante",
    "Dissonanzen": "Dissonanz",
    "Distanzen": "Distanz",
    "Distanzierenden": "Distanzierende",
    "Distanzierenderen": "Distanzierendere",
    "Distanzierendsten": "Distanzierendste",
    "Distanzierens": "Distanzieren",
    "Distanzierte": "distanziert",
    "Distanzierten": "Distanzierte",
    "Distanzierteren": "Distanziertere",
    "Distanziertesten": "Distanzierteste",
    "Disteln": "Distel",
    "Distributionen": "Distribution",
    "Distrikte": "Distrikt",
    "Distrikten": "Distrikt",
    "Distriktes": "Distrikt",
    "Distrikts": "Distrikt",
    "Disziplinargerichte": "Disziplinargericht",
    "Disziplinargerichten": "Disziplinargericht",
    "Disziplinargerichts": "Disziplinargericht",
    "Disziplinargesetze": "Disziplinargesetz",
    "Disziplinargesetzen": "Disziplinargesetz",
    "Disziplinargesetzes": "Disziplinargesetz",
    "Disziplinarische": "disziplinarisch",
    "Disziplinarischen": "Disziplinarische",
    "Disziplinarischeren": "Disziplinarischere",
    "Disziplinarkammern": "Disziplinarkammer",
    "Disziplinarmaßnahmen": "Disziplinarmaßnahme",
    "Disziplinarverfahrens": "Disziplinarverfahren",
    "Disziplinen": "Disziplin",
    "Disziplinierte": "diszipliniert",
    "Disziplinierten": "Disziplinierte",
    "Disziplinierteren": "Diszipliniertere",
    "Disziplinlosen": "Disziplinlose",
    "Disziplinloseren": "Disziplinlosere",
    "Disziplinlosesten": "Disziplinloseste",
    "Disziplinäre": "disziplinär",
    "Disziplinären": "Disziplinäre",
    "Dittrichs": "Dittrich",
    "Divas": "Diva",
    "Divergente": "divergent",
    "Divergenten": "Divergente",
    "Divergenteren": "Divergentere",
    "Divergentesten": "Divergenteste",
    "Diversen": "Diverse",
    "Dividenden": "Dividende",
    "Divisionen": "Division",
    "Diäten": "Diät",
    "Diätistinnen": "Diätistin",
    "Diözesen": "Diözese",
    "Dochte": "Docht",
    "Dochten": "Docht",
    "Dochts": "Docht",
    "Dock": "docken",
    "Dockenden": "Dockende",
    "Dockens": "Docken",
    "Docks": "Dock",
    "Dodekaedern": "Dodekaeder",
    "Dodekaeders": "Dodekaeder",
    "Doggen": "Dogge",
    "Dogmas": "Dogma",
    "Dogmatikern": "Dogmatiker",
    "Dogmatikers": "Dogmatiker",
    "Dogmatische": "dogmatisch",
    "Dogmatischen": "Dogmatische",
    "Dogmatischeren": "Dogmatischere",
    "Dogmatischsten": "Dogmatischste",
    "Dogmatisierenden": "Dogmatisierende",
    "Dogmatisierens": "Dogmatisieren",
    "Dogmatisierte": "dogmatisiert",
    "Dogmatisierten": "Dogmatisierte",
    "Dogmen": "Dogma",
    "Dohlen": "Dohle",
    "Dohnen": "Dohne",
    "Dokternden": "Dokternde",
    "Dokternderen": "Dokterndere",
    "Dokterndsten": "Dokterndste",
    "Dokterns": "Doktern",
    "Doktoranden": "Doktorand",
    "Doktorate": "Doktorat",
    "Doktoraten": "Doktorat",
    "Doktorats": "Doktorat",
    "Doktorierenden": "Doktorierende",
    "Doktorierens": "Doktorieren",
    "Doktorierte": "doktoriert",
    "Doktorierten": "Doktorierte",
    "Doktors": "Doktor",
    "Dokumentarberichte": "Dokumentarbericht",
    "Dokumentarberichten": "Dokumentarbericht",
    "Dokumentarberichts": "Dokumentarbericht",
    "Dokumentarfilme": "Dokumentarfilm",
    "Dokumentarfilmen": "Dokumentarfilm",
    "Dokumentarfilmern": "Dokumentarfilmer",
    "Dokumentarfilmers": "Dokumentarfilmer",
    "Dokumentarfilms": "Dokumentarfilm",
    "Dokumentarische": "dokumentarisch",
    "Dokumentarischen": "Dokumentarische",
    "Dokumentationen": "Dokumentation",
    "Dokumente": "Dokument",
    "Dokumenten": "Dokument",
    "Dokumentes": "Dokument",
    "Dokumentierenden": "Dokumentierende",
    "Dokumentierens": "Dokumentieren",
    "Dokumentierte": "dokumentiert",
    "Dokumentierten": "Dokumentierte",
    "Dokumentierteren": "Dokumentiertere",
    "Dokumentiertesten": "Dokumentierteste",
    "Dokuments": "Dokument",
    "Dolans": "Dolan",
    "Dolche": "Dolch",
    "Dolchen": "Dolch",
    "Dolches": "Dolch",
    "Dolchs": "Dolch",
    "Dollars": "Dollar",
    "Dolle": "doll",
    "Dollen": "Dolle",
    "Dollerein": "Dollerei",
    "Dolleren": "Dollere",
    "Dolls": "Doll",
    "Dollste": "doll",
    "Dollsten": "Dollste",
    "Dolmetschenden": "Dolmetschende",
    "Dolmetschens": "Dolmetschen",
    "Dolmetschern": "Dolmetscher",
    "Dolmetschers": "Dolmetscher",
    "Dome": "Dom",
    "Domen": "Dom",
    "Domes": "Dom",
    "Domestikinnen": "Domestikin",
    "Domestizierenden": "Domestizierende",
    "Domestizierens": "Domestizieren",
    "Domestizierte": "domestiziert",
    "Domestizierten": "Domestizierte",
    "Dominanten": "Dominante",
    "Dominanteren": "Dominantere",
    "Dominantesten": "Dominanteste",
    "Dominierenden": "Dominierende",
    "Dominierenderen": "Dominierendere",
    "Dominierendsten": "Dominierendste",
    "Dominierens": "Dominieren",
    "Dominierte": "dominiert",
    "Dominierten": "Dominierte",
    "Dominierteren": "Dominiertere",
    "Dominiertesten": "Dominierteste",
    "Dominikanern": "Dominikaner",
    "Dominikaners": "Dominikaner",
    "Dominos": "Domino",
    "Domizile": "Domizil",
    "Domizilen": "Domizil",
    "Domiziles": "Domizil",
    "Domizils": "Domizil",
    "Doms": "Dom",
    "Domänen": "Domäne",
    "Donatore": "Donator",
    "Donatoren": "Donator",
    "Donators": "Donator",
    "Donjas": "Donja",
    "Donner": "donnern",
    "Donnern": "Donner",
    "Donnernden": "Donnernde",
    "Donnernderen": "Donnerndere",
    "Donnerndsten": "Donnerndste",
    "Donnerns": "Donnern",
    "Donners": "Donner",
    "Donnerstage": "Donnerstag",
    "Donnerstagen": "Donnerstag",
    "Donnerstages": "Donnerstag",
    "Donnerstags": "Donnerstag",
    "Dons": "Don",
    "Doofe": "doof",
    "Doofen": "Doofe",
    "Dooferen": "Doofere",
    "Doofsten": "Doofste",
    "Doohms": "Doohm",
    "Dopenden": "Dopende",
    "Dopens": "Dopen",
    "Dopings": "Doping",
    "Doppel": "doppeln",
    "Doppelbesteuerungen": "Doppelbesteuerung",
    "Doppeldeutige": "doppeldeutig",
    "Doppeldeutigen": "Doppeldeutige",
    "Doppeldeutigeren": "Doppeldeutigere",
    "Doppeldeutigkeiten": "Doppeldeutigkeit",
    "Doppeldeutigste": "doppeldeutig",
    "Doppeldeutigsten": "Doppeldeutigste",
    "Doppelfedern": "Doppelfeder",
    "Doppelhochzeiten": "Doppelhochzeit",
    "Doppellaufe": "Doppellauf",
    "Doppellaufs": "Doppellauf",
    "Doppellaute": "Doppellaut",
    "Doppellauten": "Doppellaut",
    "Doppellauts": "Doppellaut",
    "Doppellebens": "Doppelleben",
    "Doppelläufe": "Doppellauf",
    "Doppelläufen": "Doppellauf",
    "Doppelläufige": "doppelläufig",
    "Doppelläufigen": "Doppelläufige",
    "Doppeln": "Doppel",
    "Doppelnden": "Doppelnde",
    "Doppelnderen": "Doppelndere",
    "Doppelndsten": "Doppelndste",
    "Doppelns": "Doppeln",
    "Doppelnähte": "Doppelnaht",
    "Doppelnähten": "Doppelnaht",
    "Doppels": "Doppel",
    "Doppelschlage": "Doppelschlag",
    "Doppelschlags": "Doppelschlag",
    "Doppelschläge": "Doppelschlag",
    "Doppelschlägen": "Doppelschlag",
    "Doppelseitige": "doppelseitig",
    "Doppelseitigen": "Doppelseitige",
    "Doppelsinnigen": "Doppelsinnige",
    "Doppelstunden": "Doppelstunde",
    "Doppelte": "doppelt",
    "Doppelten": "Doppelte",
    "Doppelteren": "Doppeltere",
    "Doppeltesten": "Doppelteste",
    "Doppelwandigen": "Doppelwandige",
    "Doppelzentnern": "Doppelzentner",
    "Doppelzentners": "Doppelzentner",
    "Doppelzüngige": "doppelzüngig",
    "Doppelzüngigen": "Doppelzüngige",
    "Doppelzüngigeren": "Doppelzüngigere",
    "Doppelzüngigsten": "Doppelzüngigste",
    "Dorfe": "Dorf",
    "Dorfes": "Dorf",
    "Dorfgeschichten": "Dorfgeschichte",
    "Dorfs": "Dorf",
    "Dorfschänken": "Dorfschänke",
    "Dorfschönen": "Dorfschöne",
    "Dorfältesten": "Dorfälteste",
    "Dorne": "Dorn",
    "Dornen": "Dorn",
    "Dornenkronen": "Dornenkrone",
    "Dornes": "Dorn",
    "Dornige": "dornig",
    "Dornigen": "Dornige",
    "Dornigeren": "Dornigere",
    "Dornigste": "dornig",
    "Dornigsten": "Dornigste",
    "Dornröschens": "Dornröschen",
    "Dorns": "Dorn",
    "Dortigen": "Dortige",
    "Dortmundern": "Dortmunder",
    "Dortmunders": "Dortmunder",
    "Dortmunds": "Dortmund",
    "Dose": "dosen",
    "Dosen": "Dose",
    "Dosenden": "Dosende",
    "Dosens": "Dosen",
    "Dosierenden": "Dosierende",
    "Dosierenderen": "Dosierendere",
    "Dosierendsten": "Dosierendste",
    "Dosierens": "Dosieren",
    "Dosierte": "dosiert",
    "Dosierten": "Dosierte",
    "Dosierteren": "Dosiertere",
    "Dosiertesten": "Dosierteste",
    "Dosierungen": "Dosierung",
    "Dotierenden": "Dotierende",
    "Dotierens": "Dotieren",
    "Dotierte": "dotiert",
    "Dotierten": "Dotierte",
    "Dottern": "Dotter",
    "Dotters": "Dotter",
    "Doubelnden": "Doubelnde",
    "Doubelns": "Doubeln",
    "Doubles": "Double",
    "Dozenten": "Dozent",
    "Dozentinnen": "Dozentin",
    "Dozierenden": "Dozierende",
    "Dozierens": "Dozieren",
    "Dozierte": "doziert",
    "Dozierten": "Dozierte",
    "Drachen": "Drache",
    "Drachens": "Drachen",
    "Drachmen": "Drachme",
    "Dragees": "Dragee",
    "Dragomirs": "Dragomir",
    "Dragonern": "Dragoner",
    "Dragoners": "Dragoner",
    "Drahte": "drahten",
    "Drahtenden": "Drahtende",
    "Drahtens": "Drahten",
    "Drahtes": "Draht",
    "Drahtigen": "Drahtige",
    "Drahtigeren": "Drahtigere",
    "Drahtigsten": "Drahtigste",
    "Drahtkommoden": "Drahtkommode",
    "Drahtlose": "drahtlos",
    "Drahtlosen": "Drahtlose",
    "Drahtloseren": "Drahtlosere",
    "Drahtlosesten": "Drahtloseste",
    "Drahts": "Draht",
    "Drahtzangen": "Drahtzange",
    "Dralle": "Drall",
    "Drallen": "Drall",
    "Dralles": "Drall",
    "Dralls": "Drall",
    "Dramas": "Drama",
    "Dramatische": "dramatisch",
    "Dramatischen": "Dramatische",
    "Dramatischeren": "Dramatischere",
    "Dramatischsten": "Dramatischste",
    "Dramatisierenden": "Dramatisierende",
    "Dramatisierenderen": "Dramatisierendere",
    "Dramatisierens": "Dramatisieren",
    "Dramatisierte": "dramatisiert",
    "Dramatisierten": "Dramatisierte",
    "Dramatisierteren": "Dramatisiertere",
    "Dramatisiertesten": "Dramatisierteste",
    "Dramen": "Drama",
    "Dranbleibenden": "Dranbleibende",
    "Dranbleibens": "Dranbleiben",
    "Drangebenden": "Drangebende",
    "Drangebens": "Drangeben",
    "Drangebliebenen": "Drangebliebene",
    "Drangegebenen": "Drangegebene",
    "Drangeklebten": "Drangeklebte",
    "Drangekommenen": "Drangekommene",
    "Drangekriegten": "Drangekriegte",
    "Drangemachten": "Drangemachte",
    "Drangenommenen": "Drangenommene",
    "Drangesetzten": "Drangesetzte",
    "Drangs": "Drang",
    "Drangsaliere": "drangsalieren",
    "Drangsalierenden": "Drangsalierende",
    "Drangsalierenderen": "Drangsalierendere",
    "Drangsalierens": "Drangsalieren",
    "Drangsalierte": "drangsaliert",
    "Drangsalierten": "Drangsalierte",
    "Drangsalierteren": "Drangsaliertere",
    "Drangsaliertesten": "Drangsalierteste",
    "Drangvollen": "Drangvolle",
    "Drangvolleren": "Drangvollere",
    "Drangvollsten": "Drangvollste",
    "Dranklebenden": "Dranklebende",
    "Dranklebenderen": "Dranklebendere",
    "Dranklebendsten": "Dranklebendste",
    "Dranklebens": "Drankleben",
    "Drankommenden": "Drankommende",
    "Drankommens": "Drankommen",
    "Drankriegenden": "Drankriegende",
    "Drankriegens": "Drankriegen",
    "Dranmachenden": "Dranmachende",
    "Dranmachens": "Dranmachen",
    "Drannehmenden": "Drannehmende",
    "Drannehmens": "Drannehmen",
    "Dransetzenden": "Dransetzende",
    "Dransetzens": "Dransetzen",
    "Drastischen": "Drastische",
    "Drastischeren": "Drastischere",
    "Drastischsten": "Drastischste",
    "Draufgebenden": "Draufgebende",
    "Draufgebens": "Draufgeben",
    "Draufgegebenen": "Draufgegebene",
    "Draufgelegten": "Draufgelegte",
    "Draufgemachten": "Draufgemachte",
    "Draufgezahlten": "Draufgezahlte",
    "Draufgängerischen": "Draufgängerische",
    "Draufgängerischeren": "Draufgängerischere",
    "Draufgängern": "Draufgänger",
    "Draufgängers": "Draufgänger",
    "Drauflegenden": "Drauflegende",
    "Drauflegens": "Drauflegen",
    "Drauflosarbeitenden": "Drauflosarbeitende",
    "Drauflosarbeitens": "Drauflosarbeiten",
    "Drauflosgearbeiteten": "Drauflosgearbeitete",
    "Drauflosgelaufenen": "Drauflosgelaufene",
    "Draufloslaufenden": "Draufloslaufende",
    "Draufloslaufens": "Draufloslaufen",
    "Draufmachenden": "Draufmachende",
    "Draufmachens": "Draufmachen",
    "Draufschauen": "Draufschau",
    "Draufzahlenden": "Draufzahlende",
    "Draufzahlens": "Draufzahlen",
    "Drecke": "Dreck",
    "Drecken": "Dreck",
    "Dreckes": "Dreck",
    "Dreckfinken": "Dreckfink",
    "Dreckige": "dreckig",
    "Dreckigen": "Dreckige",
    "Dreckigeren": "Dreckigere",
    "Dreckigsten": "Dreckigste",
    "Drecks": "Dreck",
    "Drehbare": "drehbar",
    "Drehbaren": "Drehbare",
    "Drehbuche": "Drehbuch",
    "Drehbuches": "Drehbuch",
    "Drehbuchs": "Drehbuch",
    "Drehbücher": "Drehbuch",
    "Drehbüchern": "Drehbuch",
    "Drehbühnen": "Drehbühne",
    "Drehenden": "Drehende",
    "Drehenderen": "Drehendere",
    "Drehendsten": "Drehendste",
    "Drehens": "Drehen",
    "Drehern": "Dreher",
    "Drehers": "Dreher",
    "Drehfeuern": "Drehfeuer",
    "Drehfeuers": "Drehfeuer",
    "Drehleiern": "Drehleier",
    "Drehmomente": "Drehmoment",
    "Drehmomenten": "Drehmoment",
    "Drehmoments": "Drehmoment",
    "Drehorgeln": "Drehorgel",
    "Drehpunkte": "Drehpunkt",
    "Drehpunkten": "Drehpunkt",
    "Drehpunkts": "Drehpunkt",
    "Drehsaltos": "Drehsalto",
    "Drehscheiben": "Drehscheibe",
    "Drehsesseln": "Drehsessel",
    "Drehsessels": "Drehsessel",
    "Drehspiegelungen": "Drehspiegelung",
    "Drehspindeln": "Drehspindel",
    "Drehstrome": "Drehstrom",
    "Drehstroms": "Drehstrom",
    "Drehströme": "Drehstrom",
    "Drehströmen": "Drehstrom",
    "Drehstuhle": "Drehstuhl",
    "Drehstuhls": "Drehstuhl",
    "Drehstühle": "Drehstuhl",
    "Drehstühlen": "Drehstuhl",
    "Drehungen": "Drehung",
    "Drehungswaagen": "Drehungswaage",
    "Drehwurme": "Drehwurm",
    "Drehwurmes": "Drehwurm",
    "Drehwurms": "Drehwurm",
    "Drehwürmer": "Drehwurm",
    "Drehwürmern": "Drehwurm",
    "Drehzahlarme": "drehzahlarm",
    "Drehzahlarmen": "Drehzahlarme",
    "Drehzahlen": "Drehzahl",
    "Drehzahlärmeren": "Drehzahlärmere",
    "Drehzählern": "Drehzähler",
    "Drehzählers": "Drehzähler",
    "Dreiarmige": "dreiarmig",
    "Dreiarmigen": "Dreiarmige",
    "Dreibeine": "Dreibein",
    "Dreibeinen": "Dreibein",
    "Dreibeinige": "dreibeinig",
    "Dreibeinigen": "Dreibeinige",
    "Dreibeins": "Dreibein",
    "Dreidimensionale": "dreidimensional",
    "Dreidimensionalen": "Dreidimensionale",
    "Dreiecke": "Dreieck",
    "Dreiecken": "Dreieck",
    "Dreiecks": "Dreieck",
    "Dreiecksgeschichten": "Dreiecksgeschichte",
    "Dreieichenhains": "Dreieichenhain",
    "Dreieichs": "Dreieich",
    "Dreieinige": "dreieinig",
    "Dreieinigen": "Dreieinige",
    "Dreierreihen": "Dreierreihe",
    "Dreifache": "dreifach",
    "Dreifachen": "Dreifache",
    "Dreifingerregeln": "Dreifingerregel",
    "Dreiflammige": "dreiflammig",
    "Dreiflammigen": "Dreiflammige",
    "Dreifüßigen": "Dreifüßige",
    "Dreigespanne": "Dreigespann",
    "Dreigespannen": "Dreigespann",
    "Dreigespanns": "Dreigespann",
    "Dreigroschenromane": "Dreigroschenroman",
    "Dreigroschenromanen": "Dreigroschenroman",
    "Dreigroschenromans": "Dreigroschenroman",
    "Dreikantern": "Dreikanter",
    "Dreikanters": "Dreikanter",
    "Dreiklange": "Dreiklang",
    "Dreiklangs": "Dreiklang",
    "Dreiklänge": "Dreiklang",
    "Dreiklängen": "Dreiklang",
    "Dreikäsehochs": "Dreikäsehoch",
    "Dreikönigsfeste": "Dreikönigsfest",
    "Dreikönigsfesten": "Dreikönigsfest",
    "Dreikönigsfests": "Dreikönigsfest",
    "Dreimalige": "dreimalig",
    "Dreimaligen": "Dreimalige",
    "Dreimastern": "Dreimaster",
    "Dreimasters": "Dreimaster",
    "Dreimeilenzonen": "Dreimeilenzone",
    "Dreimonatige": "dreimonatig",
    "Dreimonatigen": "Dreimonatige",
    "Dreinfindenden": "Dreinfindende",
    "Dreinfindens": "Dreinfinden",
    "Dreingaben": "Dreingabe",
    "Dreingefundenen": "Dreingefundene",
    "Dreingeredeten": "Dreingeredete",
    "Dreingeschauten": "Dreingeschaute",
    "Dreinredenden": "Dreinredende",
    "Dreinredenderen": "Dreinredendere",
    "Dreinredendsten": "Dreinredendste",
    "Dreinredens": "Dreinreden",
    "Dreinschauenden": "Dreinschauende",
    "Dreinschauens": "Dreinschauen",
    "Dreirade": "Dreirad",
    "Dreirades": "Dreirad",
    "Dreirads": "Dreirad",
    "Dreiräder": "Dreirad",
    "Dreirädern": "Dreirad",
    "Dreispaltige": "dreispaltig",
    "Dreispaltigen": "Dreispaltige",
    "Dreisprachigen": "Dreisprachige",
    "Dreisprunge": "Dreisprung",
    "Dreisprungs": "Dreisprung",
    "Dreisprünge": "Dreisprung",
    "Dreisprüngen": "Dreisprung",
    "Dreisten": "Dreiste",
    "Dreisteren": "Dreistere",
    "Dreistesten": "Dreisteste",
    "Dreistigkeiten": "Dreistigkeit",
    "Dreistufenraketen": "Dreistufenrakete",
    "Dreitagefiebers": "Dreitagefieber",
    "Dreiteiligen": "Dreiteilige",
    "Dreiteilungen": "Dreiteilung",
    "Dreitägige": "dreitägig",
    "Dreitägigen": "Dreitägige",
    "Dreiviertelliterfasse": "Dreiviertelliterfaß",
    "Dreiviertelliterfasses": "Dreiviertelliterfaß",
    "Dreiviertelliterfässer": "Dreiviertelliterfaß",
    "Dreiviertelliterfässern": "Dreiviertelliterfaß",
    "Dreiviertelstunden": "Dreiviertelstunde",
    "Dreivierteltakte": "Dreivierteltakt",
    "Dreivierteltakten": "Dreivierteltakt",
    "Dreivierteltakts": "Dreivierteltakt",
    "Dreiwegekatalysatore": "Dreiwegekatalysator",
    "Dreiwegekatalysatoren": "Dreiwegekatalysator",
    "Dreiwegekatalysators": "Dreiwegekatalysator",
    "Dreizimmerwohnungen": "Dreizimmerwohnung",
    "Dreißigjährige": "dreißigjährig",
    "Dreißigjährigen": "Dreißigjährige",
    "Dresche": "dreschen",
    "Dreschenden": "Dreschende",
    "Dreschenderen": "Dreschendere",
    "Dreschendsten": "Dreschendste",
    "Dreschens": "Dreschen",
    "Dreschern": "Drescher",
    "Dreschers": "Drescher",
    "Dreschmaschinen": "Dreschmaschine",
    "Dresdens": "Dresden",
    "Dresdnern": "Dresdner",
    "Dresdners": "Dresdner",
    "Dressierenden": "Dressierende",
    "Dressierenderen": "Dressierendere",
    "Dressierendsten": "Dressierendste",
    "Dressierens": "Dressieren",
    "Dressierte": "dressiert",
    "Dressierten": "Dressierte",
    "Dressierteren": "Dressiertere",
    "Dressiertesten": "Dressierteste",
    "Dressings": "Dressing",
    "Dresslers": "Dressler",
    "Dressuren": "Dressur",
    "Dribbelnden": "Dribbelnde",
    "Dribbelns": "Dribbeln",
    "Driftenden": "Driftende",
    "Driftens": "Driften",
    "Drill": "drillen",
    "Drillenden": "Drillende",
    "Drillenderen": "Drillendere",
    "Drillendsten": "Drillendste",
    "Drillens": "Drillen",
    "Drillinge": "Drilling",
    "Drillingen": "Drilling",
    "Drillings": "Drilling",
    "Drillingsmotore": "Drillingsmotor",
    "Drillingsmotoren": "Drillingsmotor",
    "Drillingsmotors": "Drillingsmotor",
    "Drills": "Drill",
    "Drinbleibenden": "Drinbleibende",
    "Drinbleibens": "Drinbleiben",
    "Dringebliebenen": "Dringebliebene",
    "Dringenden": "Dringende",
    "Dringens": "Dringen",
    "Dringesessenen": "Dringesessene",
    "Dringlichen": "Dringliche",
    "Dringlicheren": "Dringlichere",
    "Dringlichsten": "Dringlichste",
    "Drinks": "Drink",
    "Drinsitzenden": "Drinsitzende",
    "Drinsitzens": "Drinsitzen",
    "Drittel": "dritteln",
    "Dritteln": "Drittel",
    "Drittelnden": "Drittelnde",
    "Drittelnderen": "Drittelndere",
    "Drittelndsten": "Drittelndste",
    "Drittelns": "Dritteln",
    "Drittels": "Drittel",
    "Dritten": "Dritte",
    "Drives": "Drive",
    "Drobs": "Drob",
    "Drogen": "Droge",
    "Drogenabhängigen": "Drogenabhängige",
    "Drogerien": "Drogerie",
    "Drohenden": "Drohende",
    "Drohens": "Drohen",
    "Drohgebärden": "Drohgebärde",
    "Drohnen": "Drohne",
    "Drohungen": "Drohung",
    "Drollige": "drollig",
    "Drolligen": "Drollige",
    "Drolligeren": "Drolligere",
    "Drolligsten": "Drolligste",
    "Dromedare": "Dromedar",
    "Dromedaren": "Dromedar",
    "Dromedares": "Dromedar",
    "Dromedars": "Dromedar",
    "Dropouts": "Dropout",
    "Droschken": "Droschke",
    "Drossel": "drosseln",
    "Drosseln": "Drossel",
    "Drosselnden": "Drosselnde",
    "Drosselnderen": "Drosselndere",
    "Drosselndsten": "Drosselndste",
    "Drosselns": "Drosseln",
    "Druck": "drucken",
    "Druckbogens": "Druckbogen",
    "Druckbuchstaben": "Druckbuchstabe",
    "Drucke": "drucken",
    "Druckempfindlichen": "Druckempfindliche",
    "Druckempfindlicheren": "Druckempfindlichere",
    "Drucken": "Druck",
    "Druckenden": "Druckende",
    "Druckens": "Drucken",
    "Druckereien": "Druckerei",
    "Druckern": "Drucker",
    "Druckers": "Drucker",
    "Druckes": "Druck",
    "Druckfarben": "Druckfarbe",
    "Druckfertige": "druckfertig",
    "Druckfertigen": "Druckfertige",
    "Druckfertigeren": "Druckfertigere",
    "Druckfertigsten": "Druckfertigste",
    "Drucklegungen": "Drucklegung",
    "Druckmaschinen": "Druckmaschine",
    "Druckplatten": "Druckplatte",
    "Druckreife": "druckreif",
    "Druckreifen": "Druckreife",
    "Druckreiferen": "Druckreifere",
    "Druckreifsten": "Druckreifste",
    "Drucks": "drucksen",
    "Drucksenden": "Drucksende",
    "Drucksenderen": "Drucksendere",
    "Drucksendsten": "Drucksendste",
    "Drucksens": "Drucksen",
    "Drucktechnischen": "Drucktechnische",
    "Drulaks": "Drulak",
    "Drähte": "Draht",
    "Drähten": "Draht",
    "Drängelnden": "Drängelnde",
    "Drängelnderen": "Drängelndere",
    "Drängelndsten": "Drängelndste",
    "Drängelns": "Drängeln",
    "Drängenden": "Drängende",
    "Drängenderen": "Drängendere",
    "Drängendsten": "Drängendste",
    "Drängens": "Drängen",
    "Drögen": "dröge",
    "Drögeren": "Drögere",
    "Drögesten": "Drögeste",
    "Dröhnenden": "Dröhnende",
    "Dröhnenderen": "Dröhnendere",
    "Dröhnendsten": "Dröhnendste",
    "Dröhnens": "Dröhnen",
    "Dröselnden": "Dröselnde",
    "Dröselnderen": "Dröselndere",
    "Dröselndsten": "Dröselndste",
    "Dröselns": "Dröseln",
    "Drückende": "drückend",
    "Drückenden": "Drückende",
    "Drückenderen": "Drückendere",
    "Drückendsten": "Drückendste",
    "Drückens": "Drücken",
    "Drüsen": "Drüse",
    "Dschungeln": "Dschungel",
    "Dschungels": "Dschungel",
    "Du": "ich",
    "Dualen": "Duale",
    "Dualsysteme": "Dualsystem",
    "Dualsystemen": "Dualsystem",
    "Dualsystems": "Dualsystem",
    "Dubiosen": "Dubiose",
    "Dubioseren": "Dubiosere",
    "Dubiosesten": "Dubioseste",
    "Dublins": "Dublin",
    "Duckenden": "Duckende",
    "Duckenderen": "Duckendere",
    "Duckendsten": "Duckendste",
    "Duckens": "Ducken",
    "Duckmäuserischen": "Duckmäuserische",
    "Duckmäuserischeren": "Duckmäuserischere",
    "Duckmäusern": "Duckmäuser",
    "Duckmäusers": "Duckmäuser",
    "Dudelnden": "Dudelnde",
    "Dudelnderen": "Dudelndere",
    "Dudelndsten": "Dudelndste",
    "Dudelns": "Dudeln",
    "Dudelsacke": "Dudelsack",
    "Dudelsacks": "Dudelsack",
    "Dudelsäcke": "Dudelsack",
    "Dudelsäcken": "Dudelsack",
    "Dudenhofens": "Dudenhofen",
    "Dudens": "Duden",
    "Duellanten": "Duellant",
    "Duelle": "Duell",
    "Duellen": "Duell",
    "Duelles": "Duell",
    "Duellierenden": "Duellierende",
    "Duellierens": "Duellieren",
    "Duellierte": "duelliert",
    "Duellierten": "Duellierte",
    "Duells": "Duell",
    "Duette": "Duett",
    "Duetten": "Duett",
    "Duetts": "Duett",
    "Duftdrüsen": "Duftdrüse",
    "Dufte": "duften",
    "Duftenden": "Duftende",
    "Duftenderen": "Duftendere",
    "Duftendsten": "Duftendste",
    "Duftens": "Duften",
    "Duftes": "Duft",
    "Duftigen": "Duftige",
    "Duftigeren": "Duftigere",
    "Duftigsten": "Duftigste",
    "Duftmarken": "Duftmarke",
    "Dufts": "Duft",
    "Duisburgs": "Duisburg",
    "Duldenden": "Duldende",
    "Duldenderen": "Duldendere",
    "Duldendsten": "Duldendste",
    "Duldens": "Dulden",
    "Duldsamen": "Duldsame",
    "Duldsameren": "Duldsamere",
    "Duldsamsten": "Duldsamste",
    "Dumas": "Duma",
    "Dummchens": "Dummchen",
    "Dumme": "dumm",
    "Dummen": "Dumme",
    "Dummerchens": "Dummerchen",
    "Dummheiten": "Dummheit",
    "Dummkopfe": "Dummkopf",
    "Dummkopfes": "Dummkopf",
    "Dummkopfs": "Dummkopf",
    "Dummköpfe": "Dummkopf",
    "Dummköpfen": "Dummkopf",
    "Dumpfen": "Dumpfe",
    "Dumpferen": "Dumpfere",
    "Dumpfsten": "Dumpfste",
    "Dunkelheiten": "Dunkelheit",
    "Dunkelkammern": "Dunkelkammer",
    "Dunkelmanne": "Dunkelmann",
    "Dunkelmannes": "Dunkelmann",
    "Dunkelmanns": "Dunkelmann",
    "Dunkelmänner": "Dunkelmann",
    "Dunkelmännern": "Dunkelmann",
    "Dunkeln": "Dunkel",
    "Dunkelnden": "Dunkelnde",
    "Dunkelnderen": "Dunkelndere",
    "Dunkelndsten": "Dunkelndste",
    "Dunkelns": "Dunkeln",
    "Dunkels": "Dunkel",
    "Dunkelsten": "Dunkelste",
    "Dunkelziffern": "Dunkelziffer",
    "Dunkle": "dunkeln",
    "Dunklen": "Dunkle",
    "Dunkleren": "Dunklere",
    "Dunstabzugshauben": "Dunstabzugshaube",
    "Dunste": "dunsten",
    "Dunstenden": "Dunstende",
    "Dunstenderen": "Dunstendere",
    "Dunstendsten": "Dunstendste",
    "Dunstens": "Dunsten",
    "Dunstes": "Dunst",
    "Dunstigen": "Dunstige",
    "Dunstigeren": "Dunstigere",
    "Dunstigsten": "Dunstigste",
    "Dunsts": "Dunst",
    "Duos": "Duo",
    "Duplikate": "Duplikat",
    "Duplikaten": "Duplikat",
    "Duplikates": "Duplikat",
    "Duplikats": "Duplikat",
    "Durcharbeitenden": "Durcharbeitende",
    "Durcharbeitens": "Durcharbeiten",
    "Durchatmenden": "Durchatmende",
    "Durchatmens": "Durchatmen",
    "Durchbeißenden": "Durchbeißende",
    "Durchbeißens": "Durchbeißen",
    "Durchbekommenden": "Durchbekommende",
    "Durchbekommenen": "Durchbekommene",
    "Durchbekommens": "Durchbekommen",
    "Durchbettelnden": "Durchbettelnde",
    "Durchbettelns": "Durchbetteln",
    "Durchbeutelnden": "Durchbeutelnde",
    "Durchbeutelns": "Durchbeuteln",
    "Durchbiegenden": "Durchbiegende",
    "Durchbiegenderen": "Durchbiegendere",
    "Durchbiegendsten": "Durchbiegendste",
    "Durchbiegens": "Durchbiegen",
    "Durchbildenden": "Durchbildende",
    "Durchbildens": "Durchbilden",
    "Durchblasenden": "Durchblasende",
    "Durchblasens": "Durchblasen",
    "Durchbleuenden": "Durchbleuende",
    "Durchbleuens": "Durchbleuen",
    "Durchblicke": "Durchblick",
    "Durchblicken": "Durchblick",
    "Durchblickes": "Durchblick",
    "Durchblicks": "Durchblick",
    "Durchblutenden": "Durchblutende",
    "Durchblutenderen": "Durchblutendere",
    "Durchblutendsten": "Durchblutendste",
    "Durchblutens": "Durchbluten",
    "Durchblutete": "durchblutet",
    "Durchbluteten": "Durchblutete",
    "Durchbluteteren": "Durchblutetere",
    "Durchblutetesten": "Durchbluteteste",
    "Durchblätternden": "Durchblätternde",
    "Durchblätterns": "Durchblättern",
    "Durchbläuenden": "Durchbläuende",
    "Durchbläuenderen": "Durchbläuendere",
    "Durchbläuendsten": "Durchbläuendste",
    "Durchbläuens": "Durchbläuen",
    "Durchbohrenden": "Durchbohrende",
    "Durchbohrenderen": "Durchbohrendere",
    "Durchbohrendsten": "Durchbohrendste",
    "Durchbohrens": "Durchbohren",
    "Durchbohrte": "durchbohrt",
    "Durchbohrten": "Durchbohrte",
    "Durchbohrteren": "Durchbohrtere",
    "Durchbohrtesten": "Durchbohrteste",
    "Durchboxenden": "Durchboxende",
    "Durchboxens": "Durchboxen",
    "Durchbratenden": "Durchbratende",
    "Durchbratens": "Durchbraten",
    "Durchbrausenden": "Durchbrausende",
    "Durchbrausenderen": "Durchbrausendere",
    "Durchbrausendsten": "Durchbrausendste",
    "Durchbrausens": "Durchbrausen",
    "Durchbrauste": "durchbraust",
    "Durchbrausten": "Durchbrauste",
    "Durchbrausteren": "Durchbraustere",
    "Durchbraustesten": "Durchbrausteste",
    "Durchbrechenden": "Durchbrechende",
    "Durchbrechenderen": "Durchbrechendere",
    "Durchbrechendsten": "Durchbrechendste",
    "Durchbrechens": "Durchbrechen",
    "Durchbrennenden": "Durchbrennende",
    "Durchbrennens": "Durchbrennen",
    "Durchbringenden": "Durchbringende",
    "Durchbringens": "Durchbringen",
    "Durchbrochenen": "Durchbrochene",
    "Durchbruche": "Durchbruch",
    "Durchbruches": "Durchbruch",
    "Durchbruchs": "Durchbruch",
    "Durchbrüche": "Durchbruch",
    "Durchbrüchen": "Durchbruch",
    "Durchbürstenden": "Durchbürstende",
    "Durchbürstens": "Durchbürsten",
    "Durchdenkenden": "Durchdenkende",
    "Durchdenkens": "Durchdenken",
    "Durchdiskutierenden": "Durchdiskutierende",
    "Durchdiskutierens": "Durchdiskutieren",
    "Durchdiskutierte": "durchdiskutiert",
    "Durchdiskutierten": "Durchdiskutierte",
    "Durchdrehenden": "Durchdrehende",
    "Durchdrehenderen": "Durchdrehendere",
    "Durchdrehendsten": "Durchdrehendste",
    "Durchdrehens": "Durchdrehen",
    "Durchdringenden": "Durchdringende",
    "Durchdringenderen": "Durchdringendere",
    "Durchdringendsten": "Durchdringendste",
    "Durchdringens": "Durchdringen",
    "Durchdrungenen": "Durchdrungene",
    "Durchdrungeneren": "Durchdrungenere",
    "Durchdrungensten": "Durchdrungenste",
    "Durchdrängenden": "Durchdrängende",
    "Durchdrängenderen": "Durchdrängendere",
    "Durchdrängendsten": "Durchdrängendste",
    "Durchdrängens": "Durchdrängen",
    "Durchdrückenden": "Durchdrückende",
    "Durchdrückens": "Durchdrücken",
    "Durcheilenden": "Durcheilende",
    "Durcheilens": "Durcheilen",
    "Durcheilte": "durcheilt",
    "Durcheilten": "Durcheilte",
    "Durchessenden": "Durchessende",
    "Durchessens": "Durchessen",
    "Durchfahrenden": "Durchfahrende",
    "Durchfahrenen": "Durchfahrene",
    "Durchfahrens": "Durchfahren",
    "Durchfahrtsstraßen": "Durchfahrtsstraße",
    "Durchfalle": "durchfallen",
    "Durchfallenden": "Durchfallende",
    "Durchfallens": "Durchfallen",
    "Durchfalles": "Durchfall",
    "Durchfalls": "Durchfall",
    "Durchfechtenden": "Durchfechtende",
    "Durchfechtens": "Durchfechten",
    "Durchfedernden": "Durchfedernde",
    "Durchfederns": "Durchfedern",
    "Durchfeiernden": "Durchfeiernde",
    "Durchfeierns": "Durchfeiern",
    "Durchfeilenden": "Durchfeilende",
    "Durchfeilens": "Durchfeilen",
    "Durchfindenden": "Durchfindende",
    "Durchfindens": "Durchfinden",
    "Durchflechtenden": "Durchflechtende",
    "Durchflechtens": "Durchflechten",
    "Durchfliegenden": "Durchfliegende",
    "Durchfliegens": "Durchfliegen",
    "Durchfließenden": "Durchfließende",
    "Durchfließens": "Durchfließen",
    "Durchflochtenen": "Durchflochtene",
    "Durchflochteneren": "Durchflochtenere",
    "Durchflochtensten": "Durchflochtenste",
    "Durchflogenen": "Durchflogene",
    "Durchflossenen": "Durchflossene",
    "Durchflusse": "Durchfluß",
    "Durchflusses": "Durchfluß",
    "Durchflutenden": "Durchflutende",
    "Durchflutenderen": "Durchflutendere",
    "Durchflutendsten": "Durchflutendste",
    "Durchflutens": "Durchfluten",
    "Durchflutete": "durchflutet",
    "Durchfluteten": "Durchflutete",
    "Durchfluteteren": "Durchflutetere",
    "Durchflutetesten": "Durchfluteteste",
    "Durchflutschenden": "Durchflutschende",
    "Durchflutschenderen": "Durchflutschendere",
    "Durchflutschens": "Durchflutschen",
    "Durchflüsse": "Durchfluß",
    "Durchflüssen": "Durchfluß",
    "Durchformenden": "Durchformende",
    "Durchformens": "Durchformen",
    "Durchformulierten": "Durchformulierte",
    "Durchformulierteren": "Durchformuliertere",
    "Durchforstenden": "Durchforstende",
    "Durchforstens": "Durchforsten",
    "Durchfragenden": "Durchfragende",
    "Durchfragens": "Durchfragen",
    "Durchfressenden": "Durchfressende",
    "Durchfressenderen": "Durchfressendere",
    "Durchfressendsten": "Durchfressendste",
    "Durchfressens": "Durchfressen",
    "Durchfrierenden": "Durchfrierende",
    "Durchfrierenderen": "Durchfrierendere",
    "Durchfrierendsten": "Durchfrierendste",
    "Durchfrierens": "Durchfrieren",
    "Durchfutternden": "Durchfutternde",
    "Durchfutterns": "Durchfuttern",
    "Durchfälle": "Durchfall",
    "Durchfällen": "Durchfall",
    "Durchfühlenden": "Durchfühlende",
    "Durchfühlens": "Durchfühlen",
    "Durchführbaren": "Durchführbare",
    "Durchführbareren": "Durchführbarere",
    "Durchführbarsten": "Durchführbarste",
    "Durchführenden": "Durchführende",
    "Durchführens": "Durchführen",
    "Durchführungen": "Durchführung",
    "Durchfütternde": "durchfütternd",
    "Durchfütternden": "Durchfütternde",
    "Durchfütterns": "Durchfüttern",
    "Durchgange": "Durchgang",
    "Durchganges": "Durchgang",
    "Durchgangs": "Durchgang",
    "Durchgangsstraßen": "Durchgangsstraße",
    "Durchgearbeiteten": "Durchgearbeitete",
    "Durchgeatmeten": "Durchgeatmete",
    "Durchgebenden": "Durchgebende",
    "Durchgebens": "Durchgeben",
    "Durchgebettelten": "Durchgebettelte",
    "Durchgebeutelten": "Durchgebeutelte",
    "Durchgebildeten": "Durchgebildete",
    "Durchgebissenen": "Durchgebissene",
    "Durchgebisseneren": "Durchgebissenere",
    "Durchgebissensten": "Durchgebissenste",
    "Durchgeblasenen": "Durchgeblasene",
    "Durchgebleuten": "Durchgebleute",
    "Durchgeblätterten": "Durchgeblätterte",
    "Durchgebläuten": "Durchgebläute",
    "Durchgebläuteren": "Durchgebläutere",
    "Durchgebläutesten": "Durchgebläuteste",
    "Durchgebogenen": "Durchgebogene",
    "Durchgebogeneren": "Durchgebogenere",
    "Durchgebogensten": "Durchgebogenste",
    "Durchgebohrten": "Durchgebohrte",
    "Durchgebohrteren": "Durchgebohrtere",
    "Durchgebohrtesten": "Durchgebohrteste",
    "Durchgeboxten": "Durchgeboxte",
    "Durchgebrachten": "Durchgebrachte",
    "Durchgebrannten": "Durchgebrannte",
    "Durchgebrannteren": "Durchgebranntere",
    "Durchgebratenen": "Durchgebratene",
    "Durchgebrateneren": "Durchgebratenere",
    "Durchgebratensten": "Durchgebratenste",
    "Durchgebrausten": "Durchgebrauste",
    "Durchgebrochenen": "Durchgebrochene",
    "Durchgebrocheneren": "Durchgebrochenere",
    "Durchgebürsteten": "Durchgebürstete",
    "Durchgedachten": "Durchgedachte",
    "Durchgedachteren": "Durchgedachtere",
    "Durchgedachtesten": "Durchgedachteste",
    "Durchgedrehten": "Durchgedrehte",
    "Durchgedrehteren": "Durchgedrehtere",
    "Durchgedrehtesten": "Durchgedrehteste",
    "Durchgedrungenen": "Durchgedrungene",
    "Durchgedrängten": "Durchgedrängte",
    "Durchgedrängteren": "Durchgedrängtere",
    "Durchgedrückten": "Durchgedrückte",
    "Durchgefahrenen": "Durchgefahrene",
    "Durchgefallenen": "Durchgefallene",
    "Durchgefederten": "Durchgefederte",
    "Durchgefeierten": "Durchgefeierte",
    "Durchgefeilten": "Durchgefeilte",
    "Durchgeflogenen": "Durchgeflogene",
    "Durchgeflossenen": "Durchgeflossene",
    "Durchgeflutschten": "Durchgeflutschte",
    "Durchgeflutschteren": "Durchgeflutschtere",
    "Durchgefochtenen": "Durchgefochtene",
    "Durchgeformten": "Durchgeformte",
    "Durchgeforsteten": "Durchgeforstete",
    "Durchgefragten": "Durchgefragte",
    "Durchgefressenen": "Durchgefressene",
    "Durchgefresseneren": "Durchgefressenere",
    "Durchgefrorenen": "Durchgefrorene",
    "Durchgefroreneren": "Durchgefrorenere",
    "Durchgefrorensten": "Durchgefrorenste",
    "Durchgefundenen": "Durchgefundene",
    "Durchgefutterten": "Durchgefutterte",
    "Durchgefühlten": "Durchgefühlte",
    "Durchgeführten": "Durchgeführte",
    "Durchgefütterte": "durchgefüttert",
    "Durchgefütterten": "Durchgefütterte",
    "Durchgegangenen": "Durchgegangene",
    "Durchgegebenen": "Durchgegebene",
    "Durchgegessenen": "Durchgegessene",
    "Durchgegliederten": "Durchgegliederte",
    "Durchgeglühten": "Durchgeglühte",
    "Durchgeglühteren": "Durchgeglühtere",
    "Durchgeglühtesten": "Durchgeglühteste",
    "Durchgegriffenen": "Durchgegriffene",
    "Durchgehaltenen": "Durchgehaltene",
    "Durchgehangenen": "Durchgehangene",
    "Durchgehauchten": "Durchgehauchte",
    "Durchgehauenen": "Durchgehauene",
    "Durchgehechelten": "Durchgehechelte",
    "Durchgehechelteren": "Durchgehecheltere",
    "Durchgeheizten": "Durchgeheizte",
    "Durchgeheizteren": "Durchgeheiztere",
    "Durchgeheiztesten": "Durchgeheizteste",
    "Durchgehenden": "Durchgehende",
    "Durchgehens": "Durchgehen",
    "Durchgeholfenen": "Durchgeholfene",
    "Durchgeholten": "Durchgeholte",
    "Durchgehungerten": "Durchgehungerte",
    "Durchgehungerteren": "Durchgehungertere",
    "Durchgehängten": "Durchgehängte",
    "Durchgehörten": "Durchgehörte",
    "Durchgejagten": "Durchgejagte",
    "Durchgekauten": "Durchgekaute",
    "Durchgekauteren": "Durchgekautere",
    "Durchgekautesten": "Durchgekauteste",
    "Durchgeklungenen": "Durchgeklungene",
    "Durchgekneteten": "Durchgeknetete",
    "Durchgekneteteren": "Durchgeknetetere",
    "Durchgekniffenen": "Durchgekniffene",
    "Durchgekniffeneren": "Durchgekniffenere",
    "Durchgeknöpften": "Durchgeknöpfte",
    "Durchgekommenen": "Durchgekommene",
    "Durchgekosteten": "Durchgekostete",
    "Durchgekreuzten": "Durchgekreuzte",
    "Durchgekriegten": "Durchgekriegte",
    "Durchgekrochenen": "Durchgekrochene",
    "Durchgekämmten": "Durchgekämmte",
    "Durchgekämpften": "Durchgekämpfte",
    "Durchgeladenen": "Durchgeladene",
    "Durchgelangten": "Durchgelangte",
    "Durchgelassenen": "Durchgelassene",
    "Durchgelaufenen": "Durchgelaufene",
    "Durchgelegenen": "Durchgelegene",
    "Durchgelegeneren": "Durchgelegenere",
    "Durchgelegensten": "Durchgelegenste",
    "Durchgelesenen": "Durchgelesene",
    "Durchgeleuchteten": "Durchgeleuchtete",
    "Durchgelogenen": "Durchgelogene",
    "Durchgelogeneren": "Durchgelogenere",
    "Durchgelogensten": "Durchgelogenste",
    "Durchgelüfteten": "Durchgelüftete",
    "Durchgelüfteteren": "Durchgelüftetere",
    "Durchgemachten": "Durchgemachte",
    "Durchgemessenen": "Durchgemessene",
    "Durchgenagten": "Durchgenagte",
    "Durchgenagteren": "Durchgenagtere",
    "Durchgenagtesten": "Durchgenagteste",
    "Durchgenommenen": "Durchgenommene",
    "Durchgepaukten": "Durchgepaukte",
    "Durchgepausten": "Durchgepauste",
    "Durchgepeitschten": "Durchgepeitschte",
    "Durchgepeitschteren": "Durchgepeitschtere",
    "Durchgeplumpsten": "Durchgeplumpste",
    "Durchgepreßten": "Durchgepreßte",
    "Durchgeprobten": "Durchgeprobte",
    "Durchgeprüften": "Durchgeprüfte",
    "Durchgeprügelten": "Durchgeprügelte",
    "Durchgerannten": "Durchgerannte",
    "Durchgerasselten": "Durchgerasselte",
    "Durchgerasten": "Durchgeraste",
    "Durchgerauschten": "Durchgerauschte",
    "Durchgerauschteren": "Durchgerauschtere",
    "Durchgerechneten": "Durchgerechnete",
    "Durchgeregneten": "Durchgeregnete",
    "Durchgereichten": "Durchgereichte",
    "Durchgereisten": "Durchgereiste",
    "Durchgeriebenen": "Durchgeriebene",
    "Durchgerieselten": "Durchgerieselte",
    "Durchgerissenen": "Durchgerissene",
    "Durchgerisseneren": "Durchgerissenere",
    "Durchgerissensten": "Durchgerissenste",
    "Durchgerittenen": "Durchgerittene",
    "Durchgerosteten": "Durchgerostete",
    "Durchgerosteteren": "Durchgerostetere",
    "Durchgerufenen": "Durchgerufene",
    "Durchgerungenen": "Durchgerungene",
    "Durchgerutschten": "Durchgerutschte",
    "Durchgerührten": "Durchgerührte",
    "Durchgerührteren": "Durchgerührtere",
    "Durchgerührtesten": "Durchgerührteste",
    "Durchgerüttelten": "Durchgerüttelte",
    "Durchgerüttelteren": "Durchgerütteltere",
    "Durchgesagten": "Durchgesagte",
    "Durchgesaugten": "Durchgesaugte",
    "Durchgesausten": "Durchgesauste",
    "Durchgeschabten": "Durchgeschabte",
    "Durchgeschabteren": "Durchgeschabtere",
    "Durchgeschallten": "Durchgeschallte",
    "Durchgeschauten": "Durchgeschaute",
    "Durchgescheuerten": "Durchgescheuerte",
    "Durchgescheuerteren": "Durchgescheuertere",
    "Durchgeschienenen": "Durchgeschienene",
    "Durchgeschimmerten": "Durchgeschimmerte",
    "Durchgeschimmerteren": "Durchgeschimmertere",
    "Durchgeschlafenen": "Durchgeschlafene",
    "Durchgeschlagenen": "Durchgeschlagene",
    "Durchgeschleppten": "Durchgeschleppte",
    "Durchgeschleusten": "Durchgeschleuste",
    "Durchgeschlichenen": "Durchgeschlichene",
    "Durchgeschlungenen": "Durchgeschlungene",
    "Durchgeschlängelten": "Durchgeschlängelte",
    "Durchgeschlüpften": "Durchgeschlüpfte",
    "Durchgeschmolzenen": "Durchgeschmolzene",
    "Durchgeschmuggelten": "Durchgeschmuggelte",
    "Durchgeschnittenen": "Durchgeschnittene",
    "Durchgeschnitteneren": "Durchgeschnittenere",
    "Durchgeschobenen": "Durchgeschobene",
    "Durchgeschossenen": "Durchgeschossene",
    "Durchgeschosseneren": "Durchgeschossenere",
    "Durchgeschriebenen": "Durchgeschriebene",
    "Durchgeschwindelten": "Durchgeschwindelte",
    "Durchgeschwitzten": "Durchgeschwitzte",
    "Durchgeschwitzteren": "Durchgeschwitztere",
    "Durchgeschwommenen": "Durchgeschwommene",
    "Durchgeschüttelten": "Durchgeschüttelte",
    "Durchgeschüttelteren": "Durchgeschütteltere",
    "Durchgesehenen": "Durchgesehene",
    "Durchgesessenen": "Durchgesessene",
    "Durchgesesseneren": "Durchgesessenere",
    "Durchgesessensten": "Durchgesessenste",
    "Durchgesetzten": "Durchgesetzte",
    "Durchgesiebten": "Durchgesiebte",
    "Durchgesiebteren": "Durchgesiebtere",
    "Durchgesiebtesten": "Durchgesiebteste",
    "Durchgesoffenen": "Durchgesoffene",
    "Durchgesogenen": "Durchgesogene",
    "Durchgespielten": "Durchgespielte",
    "Durchgesprochenen": "Durchgesprochene",
    "Durchgesprocheneren": "Durchgesprochenere",
    "Durchgesprungenen": "Durchgesprungene",
    "Durchgespülten": "Durchgespülte",
    "Durchgestandenen": "Durchgestandene",
    "Durchgestarteten": "Durchgestartete",
    "Durchgestellten": "Durchgestellte",
    "Durchgestiegenen": "Durchgestiegene",
    "Durchgestimmten": "Durchgestimmte",
    "Durchgestimmteren": "Durchgestimmtere",
    "Durchgestochenen": "Durchgestochene",
    "Durchgestoßenen": "Durchgestoßene",
    "Durchgestrichenen": "Durchgestrichene",
    "Durchgestürmten": "Durchgestürmte",
    "Durchgesuchten": "Durchgesuchte",
    "Durchgesungenen": "Durchgesungene",
    "Durchgesunkenen": "Durchgesunkene",
    "Durchgesägte": "durchgesägt",
    "Durchgesägten": "Durchgesägte",
    "Durchgetanzten": "Durchgetanzte",
    "Durchgetesteten": "Durchgetestete",
    "Durchgetesteteren": "Durchgetestetere",
    "Durchgetrennten": "Durchgetrennte",
    "Durchgetretenen": "Durchgetretene",
    "Durchgetriebenen": "Durchgetriebene",
    "Durchgewanderten": "Durchgewanderte",
    "Durchgewaschenen": "Durchgewaschene",
    "Durchgewebten": "Durchgewebte",
    "Durchgeweichten": "Durchgeweichte",
    "Durchgeweichteren": "Durchgeweichtere",
    "Durchgewetzten": "Durchgewetzte",
    "Durchgewetzteren": "Durchgewetztere",
    "Durchgewetztesten": "Durchgewetzteste",
    "Durchgewichenen": "Durchgewichene",
    "Durchgewicheneren": "Durchgewichenere",
    "Durchgewichensten": "Durchgewichenste",
    "Durchgewirkten": "Durchgewirkte",
    "Durchgewischten": "Durchgewischte",
    "Durchgewobenen": "Durchgewobene",
    "Durchgewundenen": "Durchgewundene",
    "Durchgewurstelten": "Durchgewurstelte",
    "Durchgewurstelteren": "Durchgewursteltere",
    "Durchgewählten": "Durchgewählte",
    "Durchgewärmten": "Durchgewärmte",
    "Durchgewärmteren": "Durchgewärmtere",
    "Durchgewärmtesten": "Durchgewärmteste",
    "Durchgewühlten": "Durchgewühlte",
    "Durchgewühlteren": "Durchgewühltere",
    "Durchgewühltesten": "Durchgewühlteste",
    "Durchgezechten": "Durchgezechte",
    "Durchgezechteren": "Durchgezechtere",
    "Durchgezechtesten": "Durchgezechteste",
    "Durchgezeichneten": "Durchgezeichnete",
    "Durchgezogenen": "Durchgezogene",
    "Durchgezogeneren": "Durchgezogenere",
    "Durchgezogensten": "Durchgezogenste",
    "Durchgezwängten": "Durchgezwängte",
    "Durchgezählten": "Durchgezählte",
    "Durchgliedernden": "Durchgliedernde",
    "Durchgliederns": "Durchgliedern",
    "Durchglühenden": "Durchglühende",
    "Durchglühenderen": "Durchglühendere",
    "Durchglühendsten": "Durchglühendste",
    "Durchglühens": "Durchglühen",
    "Durchgreifenden": "Durchgreifende",
    "Durchgreifens": "Durchgreifen",
    "Durchgänge": "Durchgang",
    "Durchgängen": "Durchgang",
    "Durchgängern": "Durchgänger",
    "Durchgängers": "Durchgänger",
    "Durchgängige": "durchgängig",
    "Durchgängigen": "Durchgängige",
    "Durchgängigeren": "Durchgängigere",
    "Durchgängigsten": "Durchgängigste",
    "Durchhaltenden": "Durchhaltende",
    "Durchhaltens": "Durchhalten",
    "Durchhauchenden": "Durchhauchende",
    "Durchhauchens": "Durchhauchen",
    "Durchhauenden": "Durchhauende",
    "Durchhauens": "Durchhauen",
    "Durchhechelnden": "Durchhechelnde",
    "Durchhechelnderen": "Durchhechelndere",
    "Durchhechelndsten": "Durchhechelndste",
    "Durchhechelns": "Durchhecheln",
    "Durchheizenden": "Durchheizende",
    "Durchheizenderen": "Durchheizendere",
    "Durchheizendsten": "Durchheizendste",
    "Durchheizens": "Durchheizen",
    "Durchhelfenden": "Durchhelfende",
    "Durchhelfens": "Durchhelfen",
    "Durchholenden": "Durchholende",
    "Durchholens": "Durchholen",
    "Durchhungernden": "Durchhungernde",
    "Durchhungernderen": "Durchhungerndere",
    "Durchhungerndsten": "Durchhungerndste",
    "Durchhungerns": "Durchhungern",
    "Durchhängenden": "Durchhängende",
    "Durchhängenderen": "Durchhängendere",
    "Durchhängendsten": "Durchhängendste",
    "Durchhängens": "Durchhängen",
    "Durchhörenden": "Durchhörende",
    "Durchhörens": "Durchhören",
    "Durchjagenden": "Durchjagende",
    "Durchjagens": "Durchjagen",
    "Durchkauenden": "Durchkauende",
    "Durchkauenderen": "Durchkauendere",
    "Durchkauendsten": "Durchkauendste",
    "Durchkauens": "Durchkauen",
    "Durchklingenden": "Durchklingende",
    "Durchklingens": "Durchklingen",
    "Durchkneifenden": "Durchkneifende",
    "Durchkneifens": "Durchkneifen",
    "Durchknetenden": "Durchknetende",
    "Durchknetenderen": "Durchknetendere",
    "Durchknetendsten": "Durchknetendste",
    "Durchknetens": "Durchkneten",
    "Durchknöpfenden": "Durchknöpfende",
    "Durchknöpfens": "Durchknöpfen",
    "Durchkommenden": "Durchkommende",
    "Durchkommens": "Durchkommen",
    "Durchkomponierenden": "Durchkomponierende",
    "Durchkomponierens": "Durchkomponieren",
    "Durchkomponierte": "durchkomponiert",
    "Durchkomponierten": "Durchkomponierte",
    "Durchkostenden": "Durchkostende",
    "Durchkostens": "Durchkosten",
    "Durchkreuzenden": "Durchkreuzende",
    "Durchkreuzens": "Durchkreuzen",
    "Durchkreuzte": "durchkreuzt",
    "Durchkreuzten": "Durchkreuzte",
    "Durchkriechenden": "Durchkriechende",
    "Durchkriechens": "Durchkriechen",
    "Durchkriegenden": "Durchkriegende",
    "Durchkriegens": "Durchkriegen",
    "Durchkämmenden": "Durchkämmende",
    "Durchkämmens": "Durchkämmen",
    "Durchkämmte": "durchkämmt",
    "Durchkämmten": "Durchkämmte",
    "Durchkämmteren": "Durchkämmtere",
    "Durchkämmtesten": "Durchkämmteste",
    "Durchkämpfenden": "Durchkämpfende",
    "Durchkämpfens": "Durchkämpfen",
    "Durchladenden": "Durchladende",
    "Durchladens": "Durchladen",
    "Durchlangenden": "Durchlangende",
    "Durchlangens": "Durchlangen",
    "Durchlassenden": "Durchlassende",
    "Durchlassens": "Durchlassen",
    "Durchlauchten": "Durchlaucht",
    "Durchlauf": "durchlaufen",
    "Durchlaufe": "durchlaufen",
    "Durchlaufenden": "Durchlaufende",
    "Durchlaufenen": "Durchlaufene",
    "Durchlaufens": "Durchlaufen",
    "Durchlauferhitzern": "Durchlauferhitzer",
    "Durchlauferhitzers": "Durchlauferhitzer",
    "Durchlaufes": "Durchlauf",
    "Durchlaufs": "Durchlauf",
    "Durchlebenden": "Durchlebende",
    "Durchlebens": "Durchleben",
    "Durchlebte": "durchlebt",
    "Durchlebten": "Durchlebte",
    "Durchlesenden": "Durchlesende",
    "Durchlesens": "Durchlesen",
    "Durchleuchtenden": "Durchleuchtende",
    "Durchleuchtenderen": "Durchleuchtendere",
    "Durchleuchtens": "Durchleuchten",
    "Durchleuchtete": "durchleuchtet",
    "Durchleuchteten": "Durchleuchtete",
    "Durchleuchteteren": "Durchleuchtetere",
    "Durchleuchteteste": "durchleuchtet",
    "Durchleuchtungen": "Durchleuchtung",
    "Durchliegenden": "Durchliegende",
    "Durchliegens": "Durchliegen",
    "Durchlässigen": "Durchlässige",
    "Durchlässigeren": "Durchlässigere",
    "Durchlässigsten": "Durchlässigste",
    "Durchläufe": "Durchlauf",
    "Durchläufen": "Durchlauf",
    "Durchlöchernden": "Durchlöchernde",
    "Durchlöchernderen": "Durchlöcherndere",
    "Durchlöcherndsten": "Durchlöcherndste",
    "Durchlöcherns": "Durchlöchern",
    "Durchlöcherte": "durchlöchert",
    "Durchlöcherten": "Durchlöcherte",
    "Durchlöcherteren": "Durchlöchertere",
    "Durchlöchertesten": "Durchlöcherteste",
    "Durchlüftenden": "Durchlüftende",
    "Durchlüftenderen": "Durchlüftendere",
    "Durchlüftendsten": "Durchlüftendste",
    "Durchlüftens": "Durchlüften",
    "Durchlügenden": "Durchlügende",
    "Durchlügenderen": "Durchlügendere",
    "Durchlügendsten": "Durchlügendste",
    "Durchlügens": "Durchlügen",
    "Durchmachenden": "Durchmachende",
    "Durchmachens": "Durchmachen",
    "Durchmarsche": "Durchmarsch",
    "Durchmarschierenden": "Durchmarschierende",
    "Durchmarschierens": "Durchmarschieren",
    "Durchmarschierte": "durchmarschiert",
    "Durchmarschierten": "Durchmarschierte",
    "Durchmarschs": "Durchmarsch",
    "Durchmessenden": "Durchmessende",
    "Durchmessens": "Durchmessen",
    "Durchmessern": "Durchmesser",
    "Durchmessers": "Durchmesser",
    "Durchmusterungen": "Durchmusterung",
    "Durchmärsche": "Durchmarsch",
    "Durchmärschen": "Durchmarsch",
    "Durchnagenden": "Durchnagende",
    "Durchnagenderen": "Durchnagendere",
    "Durchnagendsten": "Durchnagendste",
    "Durchnagens": "Durchnagen",
    "Durchnehmenden": "Durchnehmende",
    "Durchnehmens": "Durchnehmen",
    "Durchnumerierenden": "Durchnumerierende",
    "Durchnumerierens": "Durchnumerieren",
    "Durchnumerierte": "durchnumeriert",
    "Durchnumerierten": "Durchnumerierte",
    "Durchorganisierenden": "Durchorganisierende",
    "Durchorganisierenderen": "Durchorganisierendere",
    "Durchorganisierens": "Durchorganisieren",
    "Durchorganisierte": "durchorganisiert",
    "Durchorganisierten": "Durchorganisierte",
    "Durchorganisierteren": "Durchorganisiertere",
    "Durchpaukenden": "Durchpaukende",
    "Durchpaukens": "Durchpauken",
    "Durchpausenden": "Durchpausende",
    "Durchpausens": "Durchpausen",
    "Durchpeitschenden": "Durchpeitschende",
    "Durchpeitschenderen": "Durchpeitschendere",
    "Durchpeitschens": "Durchpeitschen",
    "Durchplumpsenden": "Durchplumpsende",
    "Durchplumpsens": "Durchplumpsen",
    "Durchpressenden": "Durchpressende",
    "Durchpressens": "Durchpressen",
    "Durchprobenden": "Durchprobende",
    "Durchprobens": "Durchproben",
    "Durchprobierenden": "Durchprobierende",
    "Durchprobierens": "Durchprobieren",
    "Durchprobierte": "durchprobiert",
    "Durchprobierten": "Durchprobierte",
    "Durchprüfenden": "Durchprüfende",
    "Durchprüfens": "Durchprüfen",
    "Durchprügelnden": "Durchprügelnde",
    "Durchprügelns": "Durchprügeln",
    "Durchquerenden": "Durchquerende",
    "Durchquerens": "Durchqueren",
    "Durchquerte": "durchquert",
    "Durchquerten": "Durchquerte",
    "Durchquerungen": "Durchquerung",
    "Durchrasenden": "Durchrasende",
    "Durchrasens": "Durchrasen",
    "Durchrasselnden": "Durchrasselnde",
    "Durchrasselns": "Durchrasseln",
    "Durchrauschenden": "Durchrauschende",
    "Durchrauschenderen": "Durchrauschendere",
    "Durchrauschens": "Durchrauschen",
    "Durchrechnenden": "Durchrechnende",
    "Durchrechnens": "Durchrechnen",
    "Durchregnenden": "Durchregnende",
    "Durchregnens": "Durchregnen",
    "Durchreibenden": "Durchreibende",
    "Durchreibens": "Durchreiben",
    "Durchreichen": "Durchreiche",
    "Durchreichenden": "Durchreichende",
    "Durchreichens": "Durchreichen",
    "Durchreisenden": "Durchreisende",
    "Durchreisens": "Durchreisen",
    "Durchreiste": "durchreist",
    "Durchreisten": "Durchreiste",
    "Durchreitenden": "Durchreitende",
    "Durchreitens": "Durchreiten",
    "Durchreißenden": "Durchreißende",
    "Durchreißens": "Durchreißen",
    "Durchrennenden": "Durchrennende",
    "Durchrennens": "Durchrennen",
    "Durchrieselnden": "Durchrieselnde",
    "Durchrieselns": "Durchrieseln",
    "Durchringenden": "Durchringende",
    "Durchringens": "Durchringen",
    "Durchrostenden": "Durchrostende",
    "Durchrostenderen": "Durchrostendere",
    "Durchrostendsten": "Durchrostendste",
    "Durchrostens": "Durchrosten",
    "Durchrufenden": "Durchrufende",
    "Durchrufens": "Durchrufen",
    "Durchrutschenden": "Durchrutschende",
    "Durchrutschens": "Durchrutschen",
    "Durchrührenden": "Durchrührende",
    "Durchrührenderen": "Durchrührendere",
    "Durchrührendsten": "Durchrührendste",
    "Durchrührens": "Durchrühren",
    "Durchrüttelnden": "Durchrüttelnde",
    "Durchrüttelnderen": "Durchrüttelndere",
    "Durchrüttelndsten": "Durchrüttelndste",
    "Durchrüttelns": "Durchrütteln",
    "Durchsagen": "Durchsage",
    "Durchsagenden": "Durchsagende",
    "Durchsagens": "Durchsagen",
    "Durchsaufenden": "Durchsaufende",
    "Durchsaufens": "Durchsaufen",
    "Durchsaugenden": "Durchsaugende",
    "Durchsaugens": "Durchsaugen",
    "Durchsausenden": "Durchsausende",
    "Durchsausens": "Durchsausen",
    "Durchschabenden": "Durchschabende",
    "Durchschabenderen": "Durchschabendere",
    "Durchschabendsten": "Durchschabendste",
    "Durchschabens": "Durchschaben",
    "Durchschallenden": "Durchschallende",
    "Durchschallens": "Durchschallen",
    "Durchschauenden": "Durchschauende",
    "Durchschauens": "Durchschauen",
    "Durchschaute": "durchschaut",
    "Durchschauten": "Durchschaute",
    "Durchscheinenden": "Durchscheinende",
    "Durchscheinens": "Durchscheinen",
    "Durchscheuernden": "Durchscheuernde",
    "Durchscheuernderen": "Durchscheuerndere",
    "Durchscheuerns": "Durchscheuern",
    "Durchschiebenden": "Durchschiebende",
    "Durchschiebens": "Durchschieben",
    "Durchschießenden": "Durchschießende",
    "Durchschießens": "Durchschießen",
    "Durchschimmernden": "Durchschimmernde",
    "Durchschimmernderen": "Durchschimmerndere",
    "Durchschimmerns": "Durchschimmern",
    "Durchschlafenden": "Durchschlafende",
    "Durchschlafens": "Durchschlafen",
    "Durchschlage": "durchschlagen",
    "Durchschlagenden": "Durchschlagende",
    "Durchschlagens": "Durchschlagen",
    "Durchschlags": "Durchschlag",
    "Durchschleichenden": "Durchschleichende",
    "Durchschleichens": "Durchschleichen",
    "Durchschleppenden": "Durchschleppende",
    "Durchschleppens": "Durchschleppen",
    "Durchschleusenden": "Durchschleusende",
    "Durchschleusens": "Durchschleusen",
    "Durchschlingenden": "Durchschlingende",
    "Durchschlingens": "Durchschlingen",
    "Durchschlupfe": "Durchschlupf",
    "Durchschlupfen": "Durchschlupf",
    "Durchschlupfs": "Durchschlupf",
    "Durchschläge": "Durchschlag",
    "Durchschlägen": "Durchschlag",
    "Durchschlängelnden": "Durchschlängelnde",
    "Durchschlängelns": "Durchschlängeln",
    "Durchschlüpfenden": "Durchschlüpfende",
    "Durchschlüpfens": "Durchschlüpfen",
    "Durchschmelzenden": "Durchschmelzende",
    "Durchschmelzens": "Durchschmelzen",
    "Durchschmuggelnden": "Durchschmuggelnde",
    "Durchschmuggelns": "Durchschmuggeln",
    "Durchschneidenden": "Durchschneidende",
    "Durchschneidens": "Durchschneiden",
    "Durchschnitte": "Durchschnitt",
    "Durchschnitten": "Durchschnitt",
    "Durchschnittes": "Durchschnitt",
    "Durchschnittlichen": "Durchschnittliche",
    "Durchschnittlicheren": "Durchschnittlichere",
    "Durchschnitts": "Durchschnitt",
    "Durchschreibeblocke": "Durchschreibeblock",
    "Durchschreibeblocks": "Durchschreibeblock",
    "Durchschreibeblöcke": "Durchschreibeblock",
    "Durchschreibeblöcken": "Durchschreibeblock",
    "Durchschreibenden": "Durchschreibende",
    "Durchschreibens": "Durchschreiben",
    "Durchschreitenden": "Durchschreitende",
    "Durchschreitens": "Durchschreiten",
    "Durchschrittenen": "Durchschrittene",
    "Durchschwimmenden": "Durchschwimmende",
    "Durchschwimmens": "Durchschwimmen",
    "Durchschwindelnden": "Durchschwindelnde",
    "Durchschwindelns": "Durchschwindeln",
    "Durchschwitzenden": "Durchschwitzende",
    "Durchschwitzenderen": "Durchschwitzendere",
    "Durchschwitzens": "Durchschwitzen",
    "Durchschwommenen": "Durchschwommene",
    "Durchschüttelnden": "Durchschüttelnde",
    "Durchschüttelnderen": "Durchschüttelndere",
    "Durchschüttelns": "Durchschütteln",
    "Durchsegelnden": "Durchsegelnde",
    "Durchsegelns": "Durchsegeln",
    "Durchsegelte": "durchsegelt",
    "Durchsegelten": "Durchsegelte",
    "Durchsehenden": "Durchsehende",
    "Durchsehens": "Durchsehen",
    "Durchsetzbaren": "Durchsetzbare",
    "Durchsetzbareren": "Durchsetzbarere",
    "Durchsetzbarsten": "Durchsetzbarste",
    "Durchsetzenden": "Durchsetzende",
    "Durchsetzenderen": "Durchsetzendere",
    "Durchsetzendsten": "Durchsetzendste",
    "Durchsetzens": "Durchsetzen",
    "Durchsetzungen": "Durchsetzung",
    "Durchsichtige": "durchsichtig",
    "Durchsichtigen": "Durchsichtige",
    "Durchsichtigeren": "Durchsichtigere",
    "Durchsichtigsten": "Durchsichtigste",
    "Durchsiebenden": "Durchsiebende",
    "Durchsiebenderen": "Durchsiebendere",
    "Durchsiebendsten": "Durchsiebendste",
    "Durchsiebens": "Durchsieben",
    "Durchsingenden": "Durchsingende",
    "Durchsingens": "Durchsingen",
    "Durchsinkenden": "Durchsinkende",
    "Durchsinkens": "Durchsinken",
    "Durchsitzenden": "Durchsitzende",
    "Durchsitzens": "Durchsitzen",
    "Durchspielenden": "Durchspielende",
    "Durchspielens": "Durchspielen",
    "Durchsprechenden": "Durchsprechende",
    "Durchsprechens": "Durchsprechen",
    "Durchspringenden": "Durchspringende",
    "Durchspringens": "Durchspringen",
    "Durchspülenden": "Durchspülende",
    "Durchspülens": "Durchspülen",
    "Durchstartenden": "Durchstartende",
    "Durchstartens": "Durchstarten",
    "Durchstechenden": "Durchstechende",
    "Durchstechenderen": "Durchstechendere",
    "Durchstechendsten": "Durchstechendste",
    "Durchstechens": "Durchstechen",
    "Durchstehenden": "Durchstehende",
    "Durchstehens": "Durchstehen",
    "Durchsteigenden": "Durchsteigende",
    "Durchsteigenderen": "Durchsteigendere",
    "Durchsteigendsten": "Durchsteigendste",
    "Durchsteigens": "Durchsteigen",
    "Durchstellenden": "Durchstellende",
    "Durchstellens": "Durchstellen",
    "Durchstimmenden": "Durchstimmende",
    "Durchstimmens": "Durchstimmen",
    "Durchstochenen": "Durchstochene",
    "Durchstocheneren": "Durchstochenere",
    "Durchstochensten": "Durchstochenste",
    "Durchstoßenden": "Durchstoßende",
    "Durchstoßens": "Durchstoßen",
    "Durchstreichenden": "Durchstreichende",
    "Durchstreichens": "Durchstreichen",
    "Durchstreifenden": "Durchstreifende",
    "Durchstreifens": "Durchstreifen",
    "Durchstreifte": "durchstreift",
    "Durchstreiften": "Durchstreifte",
    "Durchstrukturierenden": "Durchstrukturierende",
    "Durchstrukturierenderen": "Durchstrukturierendere",
    "Durchstrukturierens": "Durchstrukturieren",
    "Durchstrukturierte": "durchstrukturiert",
    "Durchstrukturierten": "Durchstrukturierte",
    "Durchstrukturierteren": "Durchstrukturiertere",
    "Durchströmenden": "Durchströmende",
    "Durchströmens": "Durchströmen",
    "Durchströmte": "durchströmt",
    "Durchströmten": "Durchströmte",
    "Durchstöbernden": "Durchstöbernde",
    "Durchstöbernderen": "Durchstöberndere",
    "Durchstöberndsten": "Durchstöberndste",
    "Durchstöberns": "Durchstöbern",
    "Durchstöberte": "durchstöbert",
    "Durchstöberten": "Durchstöberte",
    "Durchstöberteren": "Durchstöbertere",
    "Durchstöbertesten": "Durchstöberteste",
    "Durchstürmenden": "Durchstürmende",
    "Durchstürmens": "Durchstürmen",
    "Durchsuchenden": "Durchsuchende",
    "Durchsuchens": "Durchsuchen",
    "Durchsuchte": "durchsucht",
    "Durchsuchten": "Durchsuchte",
    "Durchsuchteren": "Durchsuchtere",
    "Durchsuchtesten": "Durchsuchteste",
    "Durchsägende": "durchsägend",
    "Durchsägenden": "Durchsägende",
    "Durchsägens": "Durchsägen",
    "Durchtanzenden": "Durchtanzende",
    "Durchtanzens": "Durchtanzen",
    "Durchtestenden": "Durchtestende",
    "Durchtestens": "Durchtesten",
    "Durchtreibenden": "Durchtreibende",
    "Durchtreibens": "Durchtreiben",
    "Durchtrennenden": "Durchtrennende",
    "Durchtrennens": "Durchtrennen",
    "Durchtrennte": "durchtrennt",
    "Durchtrennten": "Durchtrennte",
    "Durchtrennungen": "Durchtrennung",
    "Durchtretenden": "Durchtretende",
    "Durchtretens": "Durchtreten",
    "Durchwandernden": "Durchwandernde",
    "Durchwandernderen": "Durchwanderndere",
    "Durchwanderndsten": "Durchwanderndste",
    "Durchwanderns": "Durchwandern",
    "Durchwanderte": "durchwandert",
    "Durchwanderten": "Durchwanderte",
    "Durchwanderteren": "Durchwandertere",
    "Durchwandertesten": "Durchwanderteste",
    "Durchwaschenden": "Durchwaschende",
    "Durchwaschens": "Durchwaschen",
    "Durchwebenden": "Durchwebende",
    "Durchwebens": "Durchweben",
    "Durchweichenden": "Durchweichende",
    "Durchweichenderen": "Durchweichendere",
    "Durchweichendsten": "Durchweichendste",
    "Durchweichens": "Durchweichen",
    "Durchwetzenden": "Durchwetzende",
    "Durchwetzenderen": "Durchwetzendere",
    "Durchwetzendsten": "Durchwetzendste",
    "Durchwetzens": "Durchwetzen",
    "Durchwindenden": "Durchwindende",
    "Durchwindens": "Durchwinden",
    "Durchwirkenden": "Durchwirkende",
    "Durchwirkens": "Durchwirken",
    "Durchwischenden": "Durchwischende",
    "Durchwischens": "Durchwischen",
    "Durchwurfe": "Durchwurf",
    "Durchwurfs": "Durchwurf",
    "Durchwurstelnden": "Durchwurstelnde",
    "Durchwurstelnderen": "Durchwurstelndere",
    "Durchwurstelns": "Durchwursteln",
    "Durchwählenden": "Durchwählende",
    "Durchwählens": "Durchwählen",
    "Durchwärmenden": "Durchwärmende",
    "Durchwärmenderen": "Durchwärmendere",
    "Durchwärmendsten": "Durchwärmendste",
    "Durchwärmens": "Durchwärmen",
    "Durchwühlenden": "Durchwühlende",
    "Durchwühlenderen": "Durchwühlendere",
    "Durchwühlendsten": "Durchwühlendste",
    "Durchwühlens": "Durchwühlen",
    "Durchwühlte": "durchwühlt",
    "Durchwühlten": "Durchwühlte",
    "Durchwühlteren": "Durchwühltere",
    "Durchwühltesten": "Durchwühlteste",
    "Durchwürfe": "Durchwurf",
    "Durchwürfen": "Durchwurf",
    "Durchzechenden": "Durchzechende",
    "Durchzechens": "Durchzechen",
    "Durchzechte": "durchzecht",
    "Durchzechten": "Durchzechte",
    "Durchzeichnenden": "Durchzeichnende",
    "Durchzeichnens": "Durchzeichnen",
    "Durchziehenden": "Durchziehende",
    "Durchziehens": "Durchziehen",
    "Durchziehern": "Durchzieher",
    "Durchziehers": "Durchzieher",
    "Durchzuge": "Durchzug",
    "Durchzugs": "Durchzug",
    "Durchzwängenden": "Durchzwängende",
    "Durchzwängens": "Durchzwängen",
    "Durchzählenden": "Durchzählende",
    "Durchzählens": "Durchzählen",
    "Durchzüge": "Durchzug",
    "Durchzügen": "Durchzug",
    "Durstenden": "Durstende",
    "Durstenderen": "Durstendere",
    "Durstendsten": "Durstendste",
    "Durstens": "Dursten",
    "Durstigen": "Durstige",
    "Durstigeren": "Durstigere",
    "Durstigsten": "Durstigste",
    "Dursts": "Durst",
    "Duschbade": "Duschbad",
    "Duschbades": "Duschbad",
    "Duschbads": "Duschbad",
    "Duschbäder": "Duschbad",
    "Duschbädern": "Duschbad",
    "Dusche": "duschen",
    "Duschen": "Dusche",
    "Duschenden": "Duschende",
    "Duschens": "Duschen",
    "Duschkabinen": "Duschkabine",
    "Dusel": "duseln",
    "Duseleien": "Duselei",
    "Duseln": "Dusel",
    "Duselnden": "Duselnde",
    "Duselnderen": "Duselndere",
    "Duselndsten": "Duselndste",
    "Duselns": "Duseln",
    "Dusels": "Dusel",
    "Dusselige": "dusselig",
    "Dusseligen": "Dusselige",
    "Dusseligeren": "Dusseligere",
    "Dusseligsten": "Dusseligste",
    "Dusseln": "Dussel",
    "Dussels": "Dussel",
    "Dutte": "Dutt",
    "Dutten": "Dutt",
    "Dutts": "Dutt",
    "Dutzende": "Dutzend",
    "Dutzenden": "Dutzend",
    "Dutzends": "Dutzend",
    "Duzbruders": "Duzbruder",
    "Duzbrüder": "Duzbruder",
    "Duzbrüdern": "Duzbruder",
    "Duzenden": "Duzende",
    "Duzens": "Duzen",
    "Dynamischen": "Dynamische",
    "Dynamischeren": "Dynamischere",
    "Dynamischsten": "Dynamischste",
    "Dynamisierenden": "Dynamisierende",
    "Dynamisierens": "Dynamisieren",
    "Dynamisierte": "dynamisiert",
    "Dynamisierten": "Dynamisierte",
    "Dynamometern": "Dynamometer",
    "Dynamometers": "Dynamometer",
    "Dynamos": "Dynamo",
    "Dynastien": "Dynastie",
    "Dynastische": "dynastisch",
    "Dynastischen": "Dynastische",
    "Dysprosiums": "Dysprosium",
    "Dächelchens": "Dächelchen",
    "Dächer": "Dach",
    "Dächern": "Dach",
    "Dächleins": "Dächlein",
    "Dämchens": "Dämchen",
    "Dämeleien": "Dämelei",
    "Dämeln": "Dämel",
    "Dämels": "Dämel",
    "Dämlichen": "Dämliche",
    "Dämlicheren": "Dämlichere",
    "Dämlichsten": "Dämlichste",
    "Dämme": "dämmen",
    "Dämmen": "Damm",
    "Dämmenden": "Dämmende",
    "Dämmenderen": "Dämmendere",
    "Dämmendsten": "Dämmendste",
    "Dämmens": "Dämmen",
    "Dämmerigen": "Dämmerige",
    "Dämmerigeren": "Dämmerigere",
    "Dämmerigsten": "Dämmerigste",
    "Dämmerlichte": "Dämmerlicht",
    "Dämmerlichtes": "Dämmerlicht",
    "Dämmerlichts": "Dämmerlicht",
    "Dämmernden": "Dämmernde",
    "Dämmernderen": "Dämmerndere",
    "Dämmerndsten": "Dämmerndste",
    "Dämmerns": "Dämmern",
    "Dämmerschlafe": "Dämmerschlaf",
    "Dämmerschlafes": "Dämmerschlaf",
    "Dämmerschlafs": "Dämmerschlaf",
    "Dämmerschoppens": "Dämmerschoppen",
    "Dämmerungen": "Dämmerung",
    "Dämmerzustande": "Dämmerzustand",
    "Dämmerzustands": "Dämmerzustand",
    "Dämmerzustände": "Dämmerzustand",
    "Dämmerzuständen": "Dämmerzustand",
    "Dämmrigen": "Dämmrige",
    "Dämmrigeren": "Dämmrigere",
    "Dämmrigsten": "Dämmrigste",
    "Dämonenhaften": "Dämonenhafte",
    "Dämonenhafteren": "Dämonenhaftere",
    "Dämonenhaftesten": "Dämonenhafteste",
    "Dämpfe": "dämpfen",
    "Dämpfen": "Dampf",
    "Dämpfende": "dämpfend",
    "Dämpfenden": "Dämpfende",
    "Dämpfens": "Dämpfen",
    "Dänemarks": "Dänemark",
    "Dänen": "Däne",
    "Dänische": "dänisch",
    "Dänischen": "Dänische",
    "Därme": "Darm",
    "Därmen": "Darm",
    "Dörfer": "Dorf",
    "Dörfern": "Dorf",
    "Dörfische": "dörfisch",
    "Dörfischen": "Dörfische",
    "Dörfischeren": "Dörfischere",
    "Dörfischsten": "Dörfischste",
    "Dörfleins": "Dörflein",
    "Dörflern": "Dörfler",
    "Dörflers": "Dörfler",
    "Dörfliche": "dörflich",
    "Dörflichen": "Dörfliche",
    "Dörflicheren": "Dörflichere",
    "Dörflichsten": "Dörflichste",
    "Dörnigheimern": "Dörnigheimer",
    "Dörnigheimers": "Dörnigheimer",
    "Dörnigheims": "Dörnigheim",
    "Dörrenden": "Dörrende",
    "Dörrens": "Dörren",
    "Dörrfleische": "Dörrfleisch",
    "Dörrfleisches": "Dörrfleisch",
    "Dörrfleischs": "Dörrfleisch",
    "Dörrpflaumen": "Dörrpflaume",
    "Döschens": "Döschen",
    "Dösende": "dösend",
    "Dösenden": "Dösende",
    "Dösenderen": "Dösendere",
    "Dösendsten": "Dösendste",
    "Dösens": "Dösen",
    "Dübel": "dübeln",
    "Dübeln": "Dübel",
    "Dübelnden": "Dübelnde",
    "Dübelns": "Dübeln",
    "Dübels": "Dübel",
    "Düdelsheims": "Düdelsheim",
    "Düfte": "Duft",
    "Düften": "Duft",
    "Dümmere": "dumm",
    "Dümmeren": "Dümmere",
    "Dümmliche": "dümmlich",
    "Dümmlichen": "Dümmliche",
    "Dümmlicheren": "Dümmlichere",
    "Dümmlichsten": "Dümmlichste",
    "Dümmsten": "Dümmste",
    "Dümpelnden": "Dümpelnde",
    "Dümpelns": "Dümpeln",
    "Dünen": "Düne",
    "Düngemitteln": "Düngemittel",
    "Düngemittels": "Düngemittel",
    "Düngenden": "Düngende",
    "Düngens": "Düngen",
    "Dünkenden": "Dünkende",
    "Dünkens": "Dünken",
    "Dünne": "dünnen",
    "Dünnen": "Dünne",
    "Dünnenden": "Dünnende",
    "Dünnenderen": "Dünnendere",
    "Dünnendsten": "Dünnendste",
    "Dünnens": "Dünnen",
    "Dünneren": "Dünnere",
    "Dünnflüssigen": "Dünnflüssige",
    "Dünnflüssigeren": "Dünnflüssigere",
    "Dünnflüssigsten": "Dünnflüssigste",
    "Dünnsten": "Dünnste",
    "Dünnwandigen": "Dünnwandige",
    "Dünnwandigeren": "Dünnwandigere",
    "Dünnwandigsten": "Dünnwandigste",
    "Dünste": "dünsten",
    "Dünsten": "Dunst",
    "Dünstende": "dünstend",
    "Dünstenden": "Dünstende",
    "Dünstendere": "dünstend",
    "Dünstenderen": "Dünstendere",
    "Dünstendste": "dünstend",
    "Dünstendsten": "Dünstendste",
    "Dünstens": "Dünsten",
    "Düpierenden": "Düpierende",
    "Düpierens": "Düpieren",
    "Düpierte": "düpiert",
    "Düpierten": "Düpierte",
    "Düpierteren": "Düpiertere",
    "Düpiertesten": "Düpierteste",
    "Dürftigen": "Dürftige",
    "Dürftigeren": "Dürftigere",
    "Dürftigsten": "Dürftigste",
    "Dürren": "Dürre",
    "Dürreren": "Dürrere",
    "Dürrsten": "Dürrste",
    "Dürstende": "dürstend",
    "Dürstenden": "Dürstende",
    "Dürstendere": "dürstend",
    "Dürstenderen": "Dürstendere",
    "Dürstendste": "dürstend",
    "Dürstendsten": "Dürstendste",
    "Dürstens": "Dürsten",
    "Düsen": "Düse",
    "Düsenden": "Düsende",
    "Düsens": "Düsen",
    "Düsseldorfern": "Düsseldorfer",
    "Düsseldorfers": "Düsseldorfer",
    "Düsseldorfs": "Düsseldorf",
    "Düsseln": "Düssel",
    "Düssels": "Düssel",
    "Düsteren": "Düstere",
    "Düstereren": "Düsterere",
    "Düstersten": "Düsterste",
    "Ebbe": "ebben",
    "Ebben": "Ebbe",
    "Ebbenden": "Ebbende",
    "Ebbens": "Ebben",
    "Ebelings": "Ebeling",
    "Ebenbilde": "Ebenbild",
    "Ebenbilder": "Ebenbild",
    "Ebenbildern": "Ebenbild",
    "Ebenbildes": "Ebenbild",
    "Ebenbilds": "Ebenbild",
    "Ebenbürtige": "ebenbürtig",
    "Ebenbürtigen": "Ebenbürtige",
    "Ebenbürtigeren": "Ebenbürtigere",
    "Ebenbürtigsten": "Ebenbürtigste",
    "Ebenen": "Ebene",
    "Ebenerdigen": "Ebenerdige",
    "Ebenerdigeren": "Ebenerdigere",
    "Ebenerdigsten": "Ebenerdigste",
    "Ebeneren": "Ebenere",
    "Ebenholze": "Ebenholz",
    "Ebenholzes": "Ebenholz",
    "Ebenholzs": "Ebenholz",
    "Ebenste": "eben",
    "Ebensten": "Ebenste",
    "Ebereschen": "Eberesche",
    "Eberhards": "Eberhard",
    "Eberhardts": "Eberhardt",
    "Ebern": "Eber",
    "Ebers": "Eber",
    "Eberts": "Ebert",
    "Ebnenden": "Ebnende",
    "Ebnens": "Ebnen",
    "Echos": "Echo",
    "Echsen": "Echse",
    "Echte": "echt",
    "Echten": "Echte",
    "Echteren": "Echtere",
    "Echtesten": "Echteste",
    "Echzells": "Echzell",
    "Eckards": "Eckard",
    "Eckbeschlage": "Eckbeschlag",
    "Eckbeschlags": "Eckbeschlag",
    "Eckbeschläge": "Eckbeschlag",
    "Eckbeschlägen": "Eckbeschlag",
    "Eckbänke": "Eckbank",
    "Eckbänken": "Eckbank",
    "Eckchens": "Eckchen",
    "Ecken": "Ecke",
    "Eckenheimern": "Eckenheimer",
    "Eckenheimers": "Eckenheimer",
    "Eckfahnen": "Eckfahne",
    "Eckfenstern": "Eckfenster",
    "Eckfensters": "Eckfenster",
    "Eckflüglern": "Eckflügler",
    "Eckflüglers": "Eckflügler",
    "Eckhards": "Eckhard",
    "Eckige": "eckig",
    "Eckigen": "Eckige",
    "Eckigeren": "Eckigere",
    "Eckigsten": "Eckigste",
    "Ecks": "Eck",
    "Ecksäulen": "Ecksäule",
    "Edbergs": "Edberg",
    "Eddersheims": "Eddersheim",
    "Edelholze": "Edelholz",
    "Edelholzes": "Edelholz",
    "Edelhölzer": "Edelholz",
    "Edelhölzern": "Edelholz",
    "Edelkitsche": "Edelkitsch",
    "Edelkitsches": "Edelkitsch",
    "Edelkitschs": "Edelkitsch",
    "Edelknaben": "Edelknabe",
    "Edelknappen": "Edelknappe",
    "Edelkorallen": "Edelkoralle",
    "Edelmarken": "Edelmarke",
    "Edelmetalle": "Edelmetall",
    "Edelmetallen": "Edelmetall",
    "Edelmetalles": "Edelmetall",
    "Edelmetalls": "Edelmetall",
    "Edelmütige": "edelmütig",
    "Edelmütigen": "Edelmütige",
    "Edelmütigeren": "Edelmütigere",
    "Edelmütigsten": "Edelmütigste",
    "Edelrauten": "Edelraute",
    "Edelschnulzen": "Edelschnulze",
    "Edelstahls": "Edelstahl",
    "Edelste": "edel",
    "Edelsteine": "Edelstein",
    "Edelsteinen": "Edelstein",
    "Edelsteines": "Edelstein",
    "Edelsteins": "Edelstein",
    "Edelsten": "Edelste",
    "Edeltannen": "Edeltanne",
    "Edgars": "Edgar",
    "Ediths": "Edith",
    "Editionen": "Edition",
    "Editorische": "editorisch",
    "Editorischen": "Editorische",
    "Edlen": "Edle",
    "Edleren": "Edlere",
    "Edmunds": "Edmund",
    "Eduards": "Eduard",
    "Edukationen": "Edukation",
    "Effekte": "Effekt",
    "Effekten": "Effekt",
    "Effektes": "Effekt",
    "Effektive": "effektiv",
    "Effektiven": "Effektive",
    "Effektiveren": "Effektivere",
    "Effektivitäten": "Effektivität",
    "Effektivste": "effektiv",
    "Effektivsten": "Effektivste",
    "Effekts": "Effekt",
    "Effektvolle": "effektvoll",
    "Effektvollen": "Effektvolle",
    "Effektvolleren": "Effektvollere",
    "Effektvollsten": "Effektvollste",
    "Effets": "Effet",
    "Effiziente": "effizient",
    "Effizienten": "Effiziente",
    "Effizienteren": "Effizientere",
    "Effizientesten": "Effizienteste",
    "Effizienzen": "Effizienz",
    "Egalisierenden": "Egalisierende",
    "Egalisierens": "Egalisieren",
    "Egalisierte": "egalisiert",
    "Egalisierten": "Egalisierte",
    "Egeln": "Egel",
    "Egels": "Egel",
    "Egelsbachs": "Egelsbach",
    "Eggen": "Egge",
    "Egoisten": "Egoist",
    "Egons": "Egon",
    "Egotrips": "Egotrip",
    "Ehebrecherische": "ehebrecherisch",
    "Ehebrecherischen": "Ehebrecherische",
    "Ehebrechern": "Ehebrecher",
    "Ehebrechers": "Ehebrecher",
    "Ehebunds": "Ehebund",
    "Ehefrauen": "Ehefrau",
    "Ehefähige": "ehefähig",
    "Ehefähigen": "Ehefähige",
    "Ehefähigeren": "Ehefähigere",
    "Ehefähigsten": "Ehefähigste",
    "Ehegatten": "Ehegatte",
    "Ehelichenden": "Ehelichende",
    "Ehelichens": "Ehelichen",
    "Ehelosen": "Ehelose",
    "Ehemaligen": "Ehemalige",
    "Ehen": "Ehe",
    "Ehescheue": "ehescheu",
    "Ehescheuen": "Ehescheue",
    "Ehescheueren": "Ehescheuere",
    "Ehescheusten": "Ehescheuste",
    "Ehestiftern": "Ehestifter",
    "Ehestifters": "Ehestifter",
    "Ehrbare": "ehrbar",
    "Ehrbaren": "Ehrbare",
    "Ehrbareren": "Ehrbarere",
    "Ehrbarsten": "Ehrbarste",
    "Ehren": "Ehre",
    "Ehrenamte": "Ehrenamt",
    "Ehrenamtes": "Ehrenamt",
    "Ehrenamtliche": "ehrenamtlich",
    "Ehrenamtlichen": "Ehrenamtliche",
    "Ehrenamts": "Ehrenamt",
    "Ehrenden": "Ehrende",
    "Ehrenhaften": "Ehrenhafte",
    "Ehrenhafteren": "Ehrenhaftere",
    "Ehrenhaftesten": "Ehrenhafteste",
    "Ehrennamen": "Ehrenname",
    "Ehrens": "Ehren",
    "Ehrenvolle": "ehrenvoll",
    "Ehrenvollen": "Ehrenvolle",
    "Ehrenvolleren": "Ehrenvollere",
    "Ehrenvollsten": "Ehrenvollste",
    "Ehrenvorsitzenden": "Ehrenvorsitzende",
    "Ehrenwachen": "Ehrenwache",
    "Ehrenwerte": "ehrenwert",
    "Ehrenwerten": "Ehrenwerte",
    "Ehrenwerteren": "Ehrenwertere",
    "Ehrenwertesten": "Ehrenwerteste",
    "Ehrenämter": "Ehrenamt",
    "Ehrenämtern": "Ehrenamt",
    "Ehrerbietigen": "Ehrerbietige",
    "Ehrerbietigeren": "Ehrerbietigere",
    "Ehrerbietigsten": "Ehrerbietigste",
    "Ehrfürchtigen": "Ehrfürchtige",
    "Ehrfürchtigeren": "Ehrfürchtigere",
    "Ehrfürchtigsten": "Ehrfürchtigste",
    "Ehrgeize": "Ehrgeiz",
    "Ehrgeizes": "Ehrgeiz",
    "Ehrgeizige": "ehrgeizig",
    "Ehrgeizigen": "Ehrgeizige",
    "Ehrgeizigeren": "Ehrgeizigere",
    "Ehrgeizigsten": "Ehrgeizigste",
    "Ehrlichen": "Ehrliche",
    "Ehrlicheren": "Ehrlichere",
    "Ehrlichsten": "Ehrlichste",
    "Ehrliebenden": "Ehrliebende",
    "Ehrliebenderen": "Ehrliebendere",
    "Ehrliebendsten": "Ehrliebendste",
    "Ehrlosen": "Ehrlose",
    "Ehrloseren": "Ehrlosere",
    "Ehrlosesten": "Ehrloseste",
    "Ehrungen": "Ehrung",
    "Ehrverlusts": "Ehrverlust",
    "Ehrwürdige": "ehrwürdig",
    "Ehrwürdigen": "Ehrwürdige",
    "Ehrwürdigeren": "Ehrwürdigere",
    "Ehrwürdigsten": "Ehrwürdigste",
    "Eichamte": "Eichamt",
    "Eichamtes": "Eichamt",
    "Eichamts": "Eichamt",
    "Eichbaume": "Eichbaum",
    "Eichbaums": "Eichbaum",
    "Eichbäume": "Eichbaum",
    "Eichbäumen": "Eichbaum",
    "Eiche": "eichen",
    "Eicheln": "Eichel",
    "Eichelwurme": "Eichelwurm",
    "Eichelwurmes": "Eichelwurm",
    "Eichelwurms": "Eichelwurm",
    "Eichelwürmer": "Eichelwurm",
    "Eichelwürmern": "Eichelwurm",
    "Eichen": "Eiche",
    "Eichenden": "Eichende",
    "Eichenderen": "Eichendere",
    "Eichendsten": "Eichendste",
    "Eichens": "Eichen",
    "Eichhörnchens": "Eichhörnchen",
    "Eichstriche": "Eichstrich",
    "Eichstrichen": "Eichstrich",
    "Eichstrichs": "Eichstrich",
    "Eichungen": "Eichung",
    "Eichämter": "Eichamt",
    "Eichämtern": "Eichamt",
    "Eickmanns": "Eickmann",
    "Eidbrüchige": "eidbrüchig",
    "Eidbrüchigen": "Eidbrüchige",
    "Eidbrüchigeren": "Eidbrüchigere",
    "Eidbrüchigsten": "Eidbrüchigste",
    "Eide": "Eid",
    "Eidechsen": "Eidechse",
    "Eiden": "Eid",
    "Eiderdaunen": "Eiderdaune",
    "Eideshelfern": "Eideshelfer",
    "Eideshelfers": "Eideshelfer",
    "Eidespflichtige": "eidespflichtig",
    "Eidespflichtigen": "Eidespflichtige",
    "Eidespflichtigeren": "Eidespflichtigere",
    "Eidesstattlichen": "Eidesstattliche",
    "Eidgenossen": "Eidgenosse",
    "Eidgenössische": "eidgenössisch",
    "Eidgenössischen": "Eidgenössische",
    "Eidottern": "Eidotter",
    "Eidotters": "Eidotter",
    "Eids": "Eid",
    "Eie": "Ei",
    "Eier": "eiern",
    "Eierfarben": "Eierfarbe",
    "Eierhandgranaten": "Eierhandgranate",
    "Eiern": "Ei",
    "Eiernden": "Eiernde",
    "Eiernderen": "Eierndere",
    "Eierndsten": "Eierndste",
    "Eierns": "Eiern",
    "Eies": "Ei",
    "Eifer": "eifern",
    "Eifern": "Eifer",
    "Eifernden": "Eifernde",
    "Eifernderen": "Eiferndere",
    "Eiferndsten": "Eiferndste",
    "Eiferns": "Eifern",
    "Eifers": "Eifer",
    "Eifersüchtigen": "Eifersüchtige",
    "Eifersüchtigeren": "Eifersüchtigere",
    "Eifersüchtigsten": "Eifersüchtigste",
    "Eifrigen": "Eifrige",
    "Eifrigeren": "Eifrigere",
    "Eifrigsten": "Eifrigste",
    "Eiförmigen": "Eiförmige",
    "Eiförmigeren": "Eiförmigere",
    "Eiförmigsten": "Eiförmigste",
    "Eigenartigen": "Eigenartige",
    "Eigenartigeren": "Eigenartigere",
    "Eigenartigsten": "Eigenartigste",
    "Eigenbedarfe": "Eigenbedarf",
    "Eigenbedarfes": "Eigenbedarf",
    "Eigenbedarfs": "Eigenbedarf",
    "Eigenbrötlerische": "eigenbrötlerisch",
    "Eigenbrötlerischen": "Eigenbrötlerische",
    "Eigenbrötlerischeren": "Eigenbrötlerischere",
    "Eigenbrötlern": "Eigenbrötler",
    "Eigenbrötlers": "Eigenbrötler",
    "Eigene": "eigen",
    "Eigenen": "Eigene",
    "Eigeneren": "Eigenere",
    "Eigenfinanzierungen": "Eigenfinanzierung",
    "Eigenfunktionen": "Eigenfunktion",
    "Eigengeschwindigkeiten": "Eigengeschwindigkeit",
    "Eigengewichte": "Eigengewicht",
    "Eigengewichten": "Eigengewicht",
    "Eigengewichts": "Eigengewicht",
    "Eigenheime": "Eigenheim",
    "Eigenheimen": "Eigenheim",
    "Eigenheims": "Eigenheim",
    "Eigenheiten": "Eigenheit",
    "Eigenhändige": "eigenhändig",
    "Eigenhändigen": "Eigenhändige",
    "Eigeninitiativen": "Eigeninitiative",
    "Eigenkapitals": "Eigenkapital",
    "Eigenlebens": "Eigenleben",
    "Eigenlobe": "Eigenlob",
    "Eigenloben": "Eigenlob",
    "Eigenlobs": "Eigenlob",
    "Eigenmächtige": "eigenmächtig",
    "Eigenmächtigen": "Eigenmächtige",
    "Eigenmächtigeren": "Eigenmächtigere",
    "Eigenmächtigkeiten": "Eigenmächtigkeit",
    "Eigenmächtigste": "eigenmächtig",
    "Eigenmächtigsten": "Eigenmächtigste",
    "Eigennamen": "Eigenname",
    "Eigennützige": "eigennützig",
    "Eigennützigen": "Eigennützige",
    "Eigennützigeren": "Eigennützigere",
    "Eigennützigsten": "Eigennützigste",
    "Eigenproduktionen": "Eigenproduktion",
    "Eigenschaften": "Eigenschaft",
    "Eigenschwingungen": "Eigenschwingung",
    "Eigensinnige": "eigensinnig",
    "Eigensinnigen": "Eigensinnige",
    "Eigensinnigeren": "Eigensinnigere",
    "Eigensinnigsten": "Eigensinnigste",
    "Eigensinns": "Eigensinn",
    "Eigenspannungen": "Eigenspannung",
    "Eigensten": "Eigenste",
    "Eigenständige": "eigenständig",
    "Eigenständigen": "Eigenständige",
    "Eigenständigeren": "Eigenständigere",
    "Eigenständigsten": "Eigenständigste",
    "Eigentlichen": "Eigentliche",
    "Eigentore": "Eigentor",
    "Eigentoren": "Eigentor",
    "Eigentores": "Eigentor",
    "Eigentors": "Eigentor",
    "Eigentums": "Eigentum",
    "Eigentümerinnen": "Eigentümerin",
    "Eigentümliche": "eigentümlich",
    "Eigentümlichen": "Eigentümliche",
    "Eigentümlicheren": "Eigentümlichere",
    "Eigentümlichsten": "Eigentümlichste",
    "Eigenverantwortliche": "eigenverantwortlich",
    "Eigenverantwortlichen": "Eigenverantwortliche",
    "Eigenverantwortlicheren": "Eigenverantwortlichere",
    "Eigenverbrauchs": "Eigenverbrauch",
    "Eigenwerte": "Eigenwert",
    "Eigenwerten": "Eigenwert",
    "Eigenwerts": "Eigenwert",
    "Eigenwillen": "Eigenwille",
    "Eigenwillige": "eigenwillig",
    "Eigenwilligen": "Eigenwillige",
    "Eigenwilligeren": "Eigenwilligere",
    "Eigenwilligkeiten": "Eigenwilligkeit",
    "Eigenwilligste": "eigenwillig",
    "Eigenwilligsten": "Eigenwilligste",
    "Eignenden": "Eignende",
    "Eignens": "Eignen",
    "Eignungen": "Eignung",
    "Eilbestellungen": "Eilbestellung",
    "Eilboten": "Eilbote",
    "Eilbriefe": "Eilbrief",
    "Eilbriefen": "Eilbrief",
    "Eilbriefs": "Eilbrief",
    "Eile": "eilen",
    "Eileitern": "Eileiter",
    "Eileiters": "Eileiter",
    "Eilenden": "Eilende",
    "Eilenderen": "Eilendere",
    "Eilendsten": "Eilendste",
    "Eilens": "Eilen",
    "Eiligen": "Eilige",
    "Eiligeren": "Eiligere",
    "Eiligsten": "Eiligste",
    "Eilmarsche": "Eilmarsch",
    "Eilmarschs": "Eilmarsch",
    "Eilmärsche": "Eilmarsch",
    "Eilmärschen": "Eilmarsch",
    "Eilpäckchens": "Eilpäckchen",
    "Eilschritts": "Eilschritt",
    "Eimern": "Eimer",
    "Eimers": "Eimer",
    "Einaktern": "Einakter",
    "Einakters": "Einakter",
    "Einarbeitenden": "Einarbeitende",
    "Einarbeitens": "Einarbeiten",
    "Einarmigen": "Einarmige",
    "Einatmenden": "Einatmende",
    "Einatmens": "Einatmen",
    "Einatmungen": "Einatmung",
    "Einbahnstraßen": "Einbahnstraße",
    "Einbalsamierenden": "Einbalsamierende",
    "Einbalsamierens": "Einbalsamieren",
    "Einbalsamierte": "einbalsamiert",
    "Einbalsamierten": "Einbalsamierte",
    "Einbande": "Einband",
    "Einbands": "Einband",
    "Einbauenden": "Einbauende",
    "Einbauens": "Einbauen",
    "Einbaus": "Einbau",
    "Einbehaltenden": "Einbehaltende",
    "Einbehaltenen": "Einbehaltene",
    "Einbehaltens": "Einbehalten",
    "Einbeinigen": "Einbeinige",
    "Einbekannte": "einbekennen",
    "Einbekannten": "einbekennen",
    "Einbekennenden": "Einbekennende",
    "Einbekennens": "Einbekennen",
    "Einbekennungen": "Einbekennung",
    "Einberufenden": "Einberufende",
    "Einberufenen": "Einberufene",
    "Einberufens": "Einberufen",
    "Einbestellenden": "Einbestellende",
    "Einbestellens": "Einbestellen",
    "Einbestellte": "einbestellt",
    "Einbestellten": "Einbestellte",
    "Einbetonierenden": "Einbetonierende",
    "Einbetonierens": "Einbetonieren",
    "Einbetonierte": "einbetoniert",
    "Einbetonierten": "Einbetonierte",
    "Einbettenden": "Einbettende",
    "Einbettens": "Einbetten",
    "Einbettzimmern": "Einbettzimmer",
    "Einbettzimmers": "Einbettzimmer",
    "Einbeziehenden": "Einbeziehende",
    "Einbeziehenderen": "Einbeziehendere",
    "Einbeziehendsten": "Einbeziehendste",
    "Einbeziehens": "Einbeziehen",
    "Einbeziehungen": "Einbeziehung",
    "Einbezogenen": "Einbezogene",
    "Einbezogeneren": "Einbezogenere",
    "Einbezogensten": "Einbezogenste",
    "Einbiegenden": "Einbiegende",
    "Einbiegens": "Einbiegen",
    "Einbildenden": "Einbildende",
    "Einbildenderen": "Einbildendere",
    "Einbildendsten": "Einbildendste",
    "Einbildens": "Einbilden",
    "Einbindenden": "Einbindende",
    "Einbindens": "Einbinden",
    "Einbindungen": "Einbindung",
    "Einblasenden": "Einblasende",
    "Einblasens": "Einblasen",
    "Einblattdrucke": "Einblattdruck",
    "Einblattdrucken": "Einblattdruck",
    "Einblattdrucks": "Einblattdruck",
    "Einblendenden": "Einblendende",
    "Einblendens": "Einblenden",
    "Einbleuenden": "Einbleuende",
    "Einbleuenderen": "Einbleuendere",
    "Einbleuendsten": "Einbleuendste",
    "Einbleuens": "Einbleuen",
    "Einblicke": "Einblick",
    "Einblicken": "Einblick",
    "Einblicks": "Einblick",
    "Einbläuenden": "Einbläuende",
    "Einbläuenderen": "Einbläuendere",
    "Einbläuendsten": "Einbläuendste",
    "Einbläuens": "Einbläuen",
    "Einbootenden": "Einbootende",
    "Einbootens": "Einbooten",
    "Einbrechenden": "Einbrechende",
    "Einbrechens": "Einbrechen",
    "Einbrechern": "Einbrecher",
    "Einbrechers": "Einbrecher",
    "Einbrennenden": "Einbrennende",
    "Einbrennenderen": "Einbrennendere",
    "Einbrennendsten": "Einbrennendste",
    "Einbrennens": "Einbrennen",
    "Einbringenden": "Einbringende",
    "Einbringens": "Einbringen",
    "Einbruche": "Einbruch",
    "Einbruches": "Einbruch",
    "Einbruchs": "Einbruch",
    "Einbrüche": "Einbruch",
    "Einbrüchen": "Einbruch",
    "Einbuchtenden": "Einbuchtende",
    "Einbuchtens": "Einbuchten",
    "Einbuchtungen": "Einbuchtung",
    "Einbuddelnden": "Einbuddelnde",
    "Einbuddelns": "Einbuddeln",
    "Einbunkernden": "Einbunkernde",
    "Einbunkerns": "Einbunkern",
    "Einbußen": "Einbuße",
    "Einbände": "einbinden",
    "Einbänden": "einbinden",
    "Einbürgernden": "Einbürgernde",
    "Einbürgerns": "Einbürgern",
    "Einbüßenden": "Einbüßende",
    "Einbüßens": "Einbüßen",
    "Eincheckenden": "Eincheckende",
    "Eincheckens": "Einchecken",
    "Eincremenden": "Eincremende",
    "Eincremens": "Eincremen",
    "Eindampfenden": "Eindampfende",
    "Eindampfens": "Eindampfen",
    "Eindeichenden": "Eindeichende",
    "Eindeichens": "Eindeichen",
    "Eindellenden": "Eindellende",
    "Eindellenderen": "Eindellendere",
    "Eindellendsten": "Eindellendste",
    "Eindellens": "Eindellen",
    "Eindeutigen": "Eindeutige",
    "Eindeutigeren": "Eindeutigere",
    "Eindeutigkeiten": "Eindeutigkeit",
    "Eindeutigste": "eindeutig",
    "Eindeutigsten": "Eindeutigste",
    "Eindeutschenden": "Eindeutschende",
    "Eindeutschens": "Eindeutschen",
    "Eindimensionalen": "Eindimensionale",
    "Eindimensionalitäten": "Eindimensionalität",
    "Eindosenden": "Eindosende",
    "Eindosens": "Eindosen",
    "Eindrehenden": "Eindrehende",
    "Eindrehens": "Eindrehen",
    "Eindrillenden": "Eindrillende",
    "Eindrillenderen": "Eindrillendere",
    "Eindrillendsten": "Eindrillendste",
    "Eindrillens": "Eindrillen",
    "Eindringenden": "Eindringende",
    "Eindringens": "Eindringen",
    "Eindringlichen": "Eindringliche",
    "Eindringlicheren": "Eindringlichere",
    "Eindringlichkeiten": "Eindringlichkeit",
    "Eindringlichste": "eindringlich",
    "Eindringlichsten": "Eindringlichste",
    "Eindrucke": "Eindruck",
    "Eindrucken": "Eindruck",
    "Eindruckes": "Eindruck",
    "Eindrucks": "Eindruck",
    "Eindruckslose": "eindruckslos",
    "Eindruckslosen": "Eindruckslose",
    "Eindrucksloseren": "Eindruckslosere",
    "Eindruckslosesten": "Eindrucksloseste",
    "Eindrucksvollen": "Eindrucksvolle",
    "Eindrucksvolleren": "Eindrucksvollere",
    "Eindrucksvollsten": "Eindrucksvollste",
    "Eindrückenden": "Eindrückende",
    "Eindrückens": "Eindrücken",
    "Eindrücklichen": "Eindrückliche",
    "Eindämmenden": "Eindämmende",
    "Eindämmenderen": "Eindämmendere",
    "Eindämmendsten": "Eindämmendste",
    "Eindämmens": "Eindämmen",
    "Einebnenden": "Einebnende",
    "Einebnens": "Einebnen",
    "Eineindeutigen": "Eineindeutige",
    "Einen": "einer",
    "Einenden": "Einende",
    "Einengenden": "Einengende",
    "Einengenderen": "Einengendere",
    "Einengendsten": "Einengendste",
    "Einengens": "Einengen",
    "Einengungen": "Einengung",
    "Einens": "Einen",
    "Einer": "ein",
    "Einerleis": "Einerlei",
    "Einern": "Einer",
    "Einerntenden": "Einerntende",
    "Einerntens": "Einernten",
    "Einers": "Einer",
    "Einerstellen": "Einerstelle",
    "Einfachen": "Einfache",
    "Einfacheren": "Einfachere",
    "Einfachsten": "Einfachste",
    "Einfahrenden": "Einfahrende",
    "Einfahrens": "Einfahren",
    "Einfahrten": "Einfahrt",
    "Einfalle": "einfallen",
    "Einfallenden": "Einfallende",
    "Einfallens": "Einfallen",
    "Einfalls": "Einfall",
    "Einfallslose": "einfallslos",
    "Einfallslosen": "Einfallslose",
    "Einfallsloseren": "Einfallslosere",
    "Einfallslosesten": "Einfallsloseste",
    "Einfallsreichen": "Einfallsreiche",
    "Einfallsreicheren": "Einfallsreichere",
    "Einfallsreichsten": "Einfallsreichste",
    "Einfallstraßen": "Einfallstraße",
    "Einfaltspinseln": "Einfaltspinsel",
    "Einfaltspinsels": "Einfaltspinsel",
    "Einfamilienhause": "Einfamilienhaus",
    "Einfamilienhauses": "Einfamilienhaus",
    "Einfamilienhäuser": "Einfamilienhaus",
    "Einfamilienhäusern": "Einfamilienhaus",
    "Einfangenden": "Einfangende",
    "Einfangens": "Einfangen",
    "Einfarbigen": "Einfarbige",
    "Einfassenden": "Einfassende",
    "Einfassens": "Einfassen",
    "Einfassungen": "Einfassung",
    "Einfettenden": "Einfettende",
    "Einfettenderen": "Einfettendere",
    "Einfettendsten": "Einfettendste",
    "Einfettens": "Einfetten",
    "Einfeuernden": "Einfeuernde",
    "Einfeuerns": "Einfeuern",
    "Einfindenden": "Einfindende",
    "Einfindens": "Einfinden",
    "Einflechtenden": "Einflechtende",
    "Einflechtens": "Einflechten",
    "Einfliegenden": "Einfliegende",
    "Einfliegens": "Einfliegen",
    "Einfließenden": "Einfließende",
    "Einfließens": "Einfließen",
    "Einflippenden": "Einflippende",
    "Einflippens": "Einflippen",
    "Einfluge": "Einflug",
    "Einflugs": "Einflug",
    "Einflugschneisen": "Einflugschneise",
    "Einflusse": "Einfluß",
    "Einflusses": "Einfluß",
    "Einflußreiche": "einflußreich",
    "Einflußreichen": "Einflußreiche",
    "Einflußreicheren": "Einflußreichere",
    "Einflußreichsten": "Einflußreichste",
    "Einflößenden": "Einflößende",
    "Einflößens": "Einflößen",
    "Einflüge": "Einflug",
    "Einflügen": "Einflug",
    "Einflüsse": "Einfluß",
    "Einflüssen": "Einfluß",
    "Einflüsternden": "Einflüsternde",
    "Einflüsterns": "Einflüstern",
    "Einflüsterungen": "Einflüsterung",
    "Einfordernden": "Einfordernde",
    "Einforderns": "Einfordern",
    "Einfressenden": "Einfressende",
    "Einfressens": "Einfressen",
    "Einfrierenden": "Einfrierende",
    "Einfrierens": "Einfrieren",
    "Einfuhrwaren": "Einfuhrware",
    "Einfädelnden": "Einfädelnde",
    "Einfädelns": "Einfädeln",
    "Einfälle": "Einfall",
    "Einfällen": "Einfall",
    "Einfältigen": "Einfältige",
    "Einfältigeren": "Einfältigere",
    "Einfältigsten": "Einfältigste",
    "Einfärbenden": "Einfärbende",
    "Einfärbenderen": "Einfärbendere",
    "Einfärbendsten": "Einfärbendste",
    "Einfärbens": "Einfärben",
    "Einfügenden": "Einfügende",
    "Einfügens": "Einfügen",
    "Einfügungen": "Einfügung",
    "Einfühlenden": "Einfühlende",
    "Einfühlenderen": "Einfühlendere",
    "Einfühlendsten": "Einfühlendste",
    "Einfühlens": "Einfühlen",
    "Einfühlsamen": "Einfühlsame",
    "Einfühlsameren": "Einfühlsamere",
    "Einfühlsamsten": "Einfühlsamste",
    "Einführenden": "Einführende",
    "Einführens": "Einführen",
    "Einführungen": "Einführung",
    "Einfüllenden": "Einfüllende",
    "Einfüllens": "Einfüllen",
    "Eingaben": "eingeben",
    "Eingange": "Eingang",
    "Eingangs": "Eingang",
    "Eingearbeiteten": "Eingearbeitete",
    "Eingearbeiteteren": "Eingearbeitetere",
    "Eingeatmeten": "Eingeatmete",
    "Eingebauten": "Eingebaute",
    "Eingebenden": "Eingebende",
    "Eingebens": "Eingeben",
    "Eingebetteten": "Eingebettete",
    "Eingebildeten": "Eingebildete",
    "Eingebildeteren": "Eingebildetere",
    "Eingebildetesten": "Eingebildeteste",
    "Eingeblasenen": "Eingeblasene",
    "Eingeblendeten": "Eingeblendete",
    "Eingebleuten": "Eingebleute",
    "Eingebleuteren": "Eingebleutere",
    "Eingebleutesten": "Eingebleuteste",
    "Eingebläuten": "Eingebläute",
    "Eingebläuteren": "Eingebläutere",
    "Eingebläutesten": "Eingebläuteste",
    "Eingebogenen": "Eingebogene",
    "Eingebooteten": "Eingebootete",
    "Eingeborenen": "Eingeborene",
    "Eingeborenensprachen": "Eingeborenensprache",
    "Eingebrachten": "Eingebrachte",
    "Eingebrannten": "Eingebrannte",
    "Eingebrannteren": "Eingebranntere",
    "Eingebranntesten": "Eingebrannteste",
    "Eingebrochenen": "Eingebrochene",
    "Eingebuchteten": "Eingebuchtete",
    "Eingebuddelten": "Eingebuddelte",
    "Eingebundenen": "Eingebundene",
    "Eingebunkerten": "Eingebunkerte",
    "Eingebürgerten": "Eingebürgerte",
    "Eingebüßten": "Eingebüßte",
    "Eingecheckten": "Eingecheckte",
    "Eingecremten": "Eingecremte",
    "Eingedampften": "Eingedampfte",
    "Eingedeichten": "Eingedeichte",
    "Eingedellten": "Eingedellte",
    "Eingedellteren": "Eingedelltere",
    "Eingedelltesten": "Eingedellteste",
    "Eingedeutschten": "Eingedeutschte",
    "Eingedosten": "Eingedoste",
    "Eingedrehten": "Eingedrehte",
    "Eingedrillten": "Eingedrillte",
    "Eingedrillteren": "Eingedrilltere",
    "Eingedrilltesten": "Eingedrillteste",
    "Eingedrungenen": "Eingedrungene",
    "Eingedrungeneren": "Eingedrungenere",
    "Eingedrungensten": "Eingedrungenste",
    "Eingedrückten": "Eingedrückte",
    "Eingedrückteren": "Eingedrücktere",
    "Eingedrücktesten": "Eingedrückteste",
    "Eingedämmten": "Eingedämmte",
    "Eingedämmteren": "Eingedämmtere",
    "Eingedämmtesten": "Eingedämmteste",
    "Eingeebneten": "Eingeebnete",
    "Eingeebneteren": "Eingeebnetere",
    "Eingeebnetesten": "Eingeebneteste",
    "Eingeengten": "Eingeengte",
    "Eingeengteren": "Eingeengtere",
    "Eingeengtesten": "Eingeengteste",
    "Eingeernteten": "Eingeerntete",
    "Eingefahrenen": "Eingefahrene",
    "Eingefallenen": "Eingefallene",
    "Eingefangenen": "Eingefangene",
    "Eingefaßten": "Eingefaßte",
    "Eingefetteten": "Eingefettete",
    "Eingefetteteren": "Eingefettetere",
    "Eingefettetesten": "Eingefetteteste",
    "Eingefeuerten": "Eingefeuerte",
    "Eingefleischten": "Eingefleischte",
    "Eingefleischteren": "Eingefleischtere",
    "Eingeflippten": "Eingeflippte",
    "Eingeflochtenen": "Eingeflochtene",
    "Eingeflochteneren": "Eingeflochtenere",
    "Eingeflochtensten": "Eingeflochtenste",
    "Eingeflogenen": "Eingeflogene",
    "Eingeflossenen": "Eingeflossene",
    "Eingeflößten": "Eingeflößte",
    "Eingeflüsterten": "Eingeflüsterte",
    "Eingeforderten": "Eingeforderte",
    "Eingefressenen": "Eingefressene",
    "Eingefrorenen": "Eingefrorene",
    "Eingefundenen": "Eingefundene",
    "Eingefädelten": "Eingefädelte",
    "Eingefärbten": "Eingefärbte",
    "Eingefärbteren": "Eingefärbtere",
    "Eingefärbtesten": "Eingefärbteste",
    "Eingefügten": "Eingefügte",
    "Eingefühlten": "Eingefühlte",
    "Eingefühlteren": "Eingefühltere",
    "Eingefühltesten": "Eingefühlteste",
    "Eingeführten": "Eingeführte",
    "Eingefüllten": "Eingefüllte",
    "Eingegangenen": "Eingegangene",
    "Eingegebenen": "Eingegebene",
    "Eingegipsten": "Eingegipste",
    "Eingegitterten": "Eingegitterte",
    "Eingeglasten": "Eingeglaste",
    "Eingegleisten": "Eingegleiste",
    "Eingegliederten": "Eingegliederte",
    "Eingegossenen": "Eingegossene",
    "Eingegrabenen": "Eingegrabene",
    "Eingegrenzten": "Eingegrenzte",
    "Eingegriffenen": "Eingegriffene",
    "Eingehakten": "Eingehakte",
    "Eingehaltenen": "Eingehaltene",
    "Eingehandelten": "Eingehandelte",
    "Eingehangenen": "Eingehangene",
    "Eingehauenen": "Eingehauene",
    "Eingehefteten": "Eingeheftete",
    "Eingeheilten": "Eingeheilte",
    "Eingeheimsten": "Eingeheimste",
    "Eingeheimsteren": "Eingeheimstere",
    "Eingeheimstesten": "Eingeheimsteste",
    "Eingeheirateten": "Eingeheiratete",
    "Eingeheizten": "Eingeheizte",
    "Eingeheizteren": "Eingeheiztere",
    "Eingeheiztesten": "Eingeheizteste",
    "Eingehenden": "Eingehende",
    "Eingehens": "Eingehen",
    "Eingehievten": "Eingehievte",
    "Eingehobenen": "Eingehobene",
    "Eingeholfenen": "Eingeholfene",
    "Eingeholten": "Eingeholte",
    "Eingehändigten": "Eingehändigte",
    "Eingehängten": "Eingehängte",
    "Eingehüllten": "Eingehüllte",
    "Eingehüllteren": "Eingehülltere",
    "Eingehülltesten": "Eingehüllteste",
    "Eingehüteten": "Eingehütete",
    "Eingeigelten": "Eingeigelte",
    "Eingeigelteren": "Eingeigeltere",
    "Eingeigeltesten": "Eingeigelteste",
    "Eingeimpften": "Eingeimpfte",
    "Eingejagten": "Eingejagte",
    "Eingekachelten": "Eingekachelte",
    "Eingekapselten": "Eingekapselte",
    "Eingekapselteren": "Eingekapseltere",
    "Eingekapseltesten": "Eingekapselteste",
    "Eingekauften": "Eingekaufte",
    "Eingekehrten": "Eingekehrte",
    "Eingekeilten": "Eingekeilte",
    "Eingekeilteren": "Eingekeiltere",
    "Eingekeiltesten": "Eingekeilteste",
    "Eingekellerten": "Eingekellerte",
    "Eingekerbten": "Eingekerbte",
    "Eingekerkerten": "Eingekerkerte",
    "Eingekesselten": "Eingekesselte",
    "Eingekesselteren": "Eingekesseltere",
    "Eingekesseltesten": "Eingekesselteste",
    "Eingekitteten": "Eingekittete",
    "Eingeklagten": "Eingeklagte",
    "Eingeklammerten": "Eingeklammerte",
    "Eingeklebten": "Eingeklebte",
    "Eingekleideten": "Eingekleidete",
    "Eingekleideteren": "Eingekleidetere",
    "Eingekleidetesten": "Eingekleideteste",
    "Eingeklemmten": "Eingeklemmte",
    "Eingeklemmteren": "Eingeklemmtere",
    "Eingeklemmtesten": "Eingeklemmteste",
    "Eingeklinkten": "Eingeklinkte",
    "Eingeklopften": "Eingeklopfte",
    "Eingeknickten": "Eingeknickte",
    "Eingekniffenen": "Eingekniffene",
    "Eingekniffeneren": "Eingekniffenere",
    "Eingekniffensten": "Eingekniffenste",
    "Eingeknoteten": "Eingeknotete",
    "Eingeknöpften": "Eingeknöpfte",
    "Eingeknüpften": "Eingeknüpfte",
    "Eingekochten": "Eingekochte",
    "Eingekratzten": "Eingekratzte",
    "Eingekratzteren": "Eingekratztere",
    "Eingekratztesten": "Eingekratzteste",
    "Eingekreisten": "Eingekreiste",
    "Eingekreuzten": "Eingekreuzte",
    "Eingekriegten": "Eingekriegte",
    "Eingeladenen": "Eingeladene",
    "Eingelagerten": "Eingelagerte",
    "Eingelangten": "Eingelangte",
    "Eingelassenen": "Eingelassene",
    "Eingelaufenen": "Eingelaufene",
    "Eingelaufeneren": "Eingelaufenere",
    "Eingelaufensten": "Eingelaufenste",
    "Eingelebten": "Eingelebte",
    "Eingelebteren": "Eingelebtere",
    "Eingelebtesten": "Eingelebteste",
    "Eingelegenen": "Eingelegene",
    "Eingelegten": "Eingelegte",
    "Eingeleiteten": "Eingeleitete",
    "Eingelenkten": "Eingelenkte",
    "Eingelernten": "Eingelernte",
    "Eingelesenen": "Eingelesene",
    "Eingeleuchteten": "Eingeleuchtete",
    "Eingelieferten": "Eingelieferte",
    "Eingelochten": "Eingelochte",
    "Eingelullten": "Eingelullte",
    "Eingelullteren": "Eingelulltere",
    "Eingelulltesten": "Eingelullteste",
    "Eingeläuteten": "Eingeläutete",
    "Eingelösten": "Eingelöste",
    "Eingelöteten": "Eingelötete",
    "Eingemachten": "Eingemachte",
    "Eingemahnten": "Eingemahnte",
    "Eingemauerten": "Eingemauerte",
    "Eingemeindenden": "Eingemeindende",
    "Eingemeindens": "Eingemeinden",
    "Eingemeindete": "eingemeindet",
    "Eingemeindeten": "Eingemeindete",
    "Eingemeißelten": "Eingemeißelte",
    "Eingemengten": "Eingemengte",
    "Eingemieteten": "Eingemietete",
    "Eingemischten": "Eingemischte",
    "Eingemotteten": "Eingemottete",
    "Eingemümmelten": "Eingemümmelte",
    "Eingemümmelteren": "Eingemümmeltere",
    "Eingemümmeltesten": "Eingemümmelteste",
    "Eingemündeten": "Eingemündete",
    "Eingenebelten": "Eingenebelte",
    "Eingenebelteren": "Eingenebeltere",
    "Eingenebeltesten": "Eingenebelteste",
    "Eingenisteten": "Eingenistete",
    "Eingenommenen": "Eingenommene",
    "Eingenähten": "Eingenähte",
    "Eingenäßten": "Eingenäßte",
    "Eingenäßteren": "Eingenäßtere",
    "Eingenäßtesten": "Eingenäßteste",
    "Eingeordneten": "Eingeordnete",
    "Eingepackten": "Eingepackte",
    "Eingeparkten": "Eingeparkte",
    "Eingepaukten": "Eingepaukte",
    "Eingepaßten": "Eingepaßte",
    "Eingepaßteren": "Eingepaßtere",
    "Eingepaßtesten": "Eingepaßteste",
    "Eingependelten": "Eingependelte",
    "Eingependelteren": "Eingependeltere",
    "Eingependeltesten": "Eingependelteste",
    "Eingepferchten": "Eingepferchte",
    "Eingepferchteren": "Eingepferchtere",
    "Eingepferchtesten": "Eingepferchteste",
    "Eingepflanzten": "Eingepflanzte",
    "Eingepfropften": "Eingepfropfte",
    "Eingepfropfteren": "Eingepfropftere",
    "Eingepfropftesten": "Eingepfropfteste",
    "Eingepinselten": "Eingepinselte",
    "Eingepinselteren": "Eingepinseltere",
    "Eingepinseltesten": "Eingepinselteste",
    "Eingeplanten": "Eingeplante",
    "Eingepreßten": "Eingepreßte",
    "Eingeprägten": "Eingeprägte",
    "Eingepuderten": "Eingepuderte",
    "Eingepuderteren": "Eingepudertere",
    "Eingepudertesten": "Eingepuderteste",
    "Eingepumpten": "Eingepumpte",
    "Eingepökelten": "Eingepökelte",
    "Eingepökelteren": "Eingepökeltere",
    "Eingepökeltesten": "Eingepökelteste",
    "Eingerahmten": "Eingerahmte",
    "Eingerammten": "Eingerammte",
    "Eingerammteren": "Eingerammtere",
    "Eingerammtesten": "Eingerammteste",
    "Eingerannten": "Eingerannte",
    "Eingerasteten": "Eingerastete",
    "Eingerasteteren": "Eingerastetere",
    "Eingerastetesten": "Eingerasteteste",
    "Eingerechneten": "Eingerechnete",
    "Eingeredeten": "Eingeredete",
    "Eingeregneten": "Eingeregnete",
    "Eingereichten": "Eingereichte",
    "Eingereihten": "Eingereihte",
    "Eingereisten": "Eingereiste",
    "Eingerenkten": "Eingerenkte",
    "Eingerichteten": "Eingerichtete",
    "Eingeriebenen": "Eingeriebene",
    "Eingeriegelten": "Eingeriegelte",
    "Eingerissenen": "Eingerissene",
    "Eingerisseneren": "Eingerissenere",
    "Eingerissensten": "Eingerissenste",
    "Eingerittenen": "Eingerittene",
    "Eingeritzten": "Eingeritzte",
    "Eingerollten": "Eingerollte",
    "Eingerollteren": "Eingerolltere",
    "Eingerolltesten": "Eingerollteste",
    "Eingerosteten": "Eingerostete",
    "Eingerosteteren": "Eingerostetere",
    "Eingerostetesten": "Eingerosteteste",
    "Eingeräucherten": "Eingeräucherte",
    "Eingeräucherteren": "Eingeräuchertere",
    "Eingeräumten": "Eingeräumte",
    "Eingerückten": "Eingerückte",
    "Eingerührten": "Eingerührte",
    "Eingerüsteten": "Eingerüstete",
    "Eingesagten": "Eingesagte",
    "Eingesalbten": "Eingesalbte",
    "Eingesalzenen": "Eingesalzene",
    "Eingesalzeneren": "Eingesalzenere",
    "Eingesalzensten": "Eingesalzenste",
    "Eingesammelten": "Eingesammelte",
    "Eingesandten": "Eingesandte",
    "Eingesargten": "Eingesargte",
    "Eingesaugten": "Eingesaugte",
    "Eingesaugteren": "Eingesaugtere",
    "Eingesaugtesten": "Eingesaugteste",
    "Eingesauten": "Eingesaute",
    "Eingesauteren": "Eingesautere",
    "Eingesautesten": "Eingesauteste",
    "Eingeschachtelten": "Eingeschachtelte",
    "Eingeschachtelteren": "Eingeschachteltere",
    "Eingeschalteten": "Eingeschaltete",
    "Eingescharrten": "Eingescharrte",
    "Eingeschenkten": "Eingeschenkte",
    "Eingescherten": "Eingescherte",
    "Eingeschifften": "Eingeschiffte",
    "Eingeschlafenen": "Eingeschlafene",
    "Eingeschlagenen": "Eingeschlagene",
    "Eingeschleiften": "Eingeschleifte",
    "Eingeschleimten": "Eingeschleimte",
    "Eingeschleimteren": "Eingeschleimtere",
    "Eingeschleppten": "Eingeschleppte",
    "Eingeschleusten": "Eingeschleuste",
    "Eingeschlichenen": "Eingeschlichene",
    "Eingeschliffenen": "Eingeschliffene",
    "Eingeschlossenen": "Eingeschlossene",
    "Eingeschlummerten": "Eingeschlummerte",
    "Eingeschläferten": "Eingeschläferte",
    "Eingeschmeichelten": "Eingeschmeichelte",
    "Eingeschmeichelteren": "Eingeschmeicheltere",
    "Eingeschmierten": "Eingeschmierte",
    "Eingeschmissenen": "Eingeschmissene",
    "Eingeschmolzenen": "Eingeschmolzene",
    "Eingeschmuggelten": "Eingeschmuggelte",
    "Eingeschnappten": "Eingeschnappte",
    "Eingeschneiten": "Eingeschneite",
    "Eingeschneiteren": "Eingeschneitere",
    "Eingeschneitesten": "Eingeschneiteste",
    "Eingeschnittenen": "Eingeschnittene",
    "Eingeschnitzten": "Eingeschnitzte",
    "Eingeschnürten": "Eingeschnürte",
    "Eingeschnürteren": "Eingeschnürtere",
    "Eingeschnürtesten": "Eingeschnürteste",
    "Eingeschobenen": "Eingeschobene",
    "Eingeschorenen": "Eingeschorene",
    "Eingeschossenen": "Eingeschossene",
    "Eingeschosseneren": "Eingeschossenere",
    "Eingeschossensten": "Eingeschossenste",
    "Eingeschraubten": "Eingeschraubte",
    "Eingeschriebenen": "Eingeschriebene",
    "Eingeschrittenen": "Eingeschrittene",
    "Eingeschrumpften": "Eingeschrumpfte",
    "Eingeschrumpfteren": "Eingeschrumpftere",
    "Eingeschränkten": "Eingeschränkte",
    "Eingeschränkteren": "Eingeschränktere",
    "Eingeschulten": "Eingeschulte",
    "Eingeschwebten": "Eingeschwebte",
    "Eingeschwefelten": "Eingeschwefelte",
    "Eingeschwefelteren": "Eingeschwefeltere",
    "Eingeschwenkten": "Eingeschwenkte",
    "Eingeschwommenen": "Eingeschwommene",
    "Eingeschwommeneren": "Eingeschwommenere",
    "Eingeschworenen": "Eingeschworene",
    "Eingeschworeneren": "Eingeschworenere",
    "Eingeschworensten": "Eingeschworenste",
    "Eingeschwungenen": "Eingeschwungene",
    "Eingeschwärzten": "Eingeschwärzte",
    "Eingeschwärzteren": "Eingeschwärztere",
    "Eingeschärften": "Eingeschärfte",
    "Eingeschätzten": "Eingeschätzte",
    "Eingeschütteten": "Eingeschüttete",
    "Eingesegneten": "Eingesegnete",
    "Eingesehenen": "Eingesehene",
    "Eingeseiften": "Eingeseifte",
    "Eingeseifteren": "Eingeseiftere",
    "Eingeseiftesten": "Eingeseifteste",
    "Eingesendeten": "Eingesendete",
    "Eingesengten": "Eingesengte",
    "Eingesengteren": "Eingesengtere",
    "Eingesengtesten": "Eingesengteste",
    "Eingesessenen": "Eingesessene",
    "Eingesesseneren": "Eingesessenere",
    "Eingesessensten": "Eingesessenste",
    "Eingesetzten": "Eingesetzte",
    "Eingesogenen": "Eingesogene",
    "Eingesogeneren": "Eingesogenere",
    "Eingesogensten": "Eingesogenste",
    "Eingespannten": "Eingespannte",
    "Eingesparten": "Eingesparte",
    "Eingespeicherten": "Eingespeicherte",
    "Eingesperrten": "Eingesperrte",
    "Eingespielten": "Eingespielte",
    "Eingespielteren": "Eingespieltere",
    "Eingespieltesten": "Eingespielteste",
    "Eingesprengten": "Eingesprengte",
    "Eingespritzten": "Eingespritzte",
    "Eingesprochenen": "Eingesprochene",
    "Eingesprungenen": "Eingesprungene",
    "Eingesprühten": "Eingesprühte",
    "Eingestampften": "Eingestampfte",
    "Eingestandenen": "Eingestandene",
    "Eingestandeneren": "Eingestandenere",
    "Eingestandensten": "Eingestandenste",
    "Eingestaubten": "Eingestaubte",
    "Eingestaubteren": "Eingestaubtere",
    "Eingestaubtesten": "Eingestaubteste",
    "Eingesteckten": "Eingesteckte",
    "Eingestehenden": "Eingestehende",
    "Eingestehenderen": "Eingestehendere",
    "Eingestehendsten": "Eingestehendste",
    "Eingestehens": "Eingestehen",
    "Eingestellten": "Eingestellte",
    "Eingestiegenen": "Eingestiegene",
    "Eingestimmten": "Eingestimmte",
    "Eingestippten": "Eingestippte",
    "Eingestochenen": "Eingestochene",
    "Eingestrahlten": "Eingestrahlte",
    "Eingestreuten": "Eingestreute",
    "Eingestrichenen": "Eingestrichene",
    "Eingeströmten": "Eingeströmte",
    "Eingestuften": "Eingestufte",
    "Eingestülpten": "Eingestülpte",
    "Eingestürmten": "Eingestürmte",
    "Eingestürzten": "Eingestürzte",
    "Eingestürzteren": "Eingestürztere",
    "Eingestürztesten": "Eingestürzteste",
    "Eingesungenen": "Eingesungene",
    "Eingesunkenen": "Eingesunkene",
    "Eingesägte": "eingesägt",
    "Eingesägten": "Eingesägte",
    "Eingesäuerten": "Eingesäuerte",
    "Eingesäuerteren": "Eingesäuertere",
    "Eingesäuertesten": "Eingesäuerteste",
    "Eingesäumten": "Eingesäumte",
    "Eingetanzten": "Eingetanzte",
    "Eingetauchten": "Eingetauchte",
    "Eingetauschten": "Eingetauschte",
    "Eingeteilten": "Eingeteilte",
    "Eingetopften": "Eingetopfte",
    "Eingetragenen": "Eingetragene",
    "Eingetretenen": "Eingetretene",
    "Eingetrichterten": "Eingetrichterte",
    "Eingetriebenen": "Eingetriebene",
    "Eingetrockneten": "Eingetrocknete",
    "Eingetrockneteren": "Eingetrocknetere",
    "Eingetroffenen": "Eingetroffene",
    "Eingetrudelten": "Eingetrudelte",
    "Eingeträufelten": "Eingeträufelte",
    "Eingetrübten": "Eingetrübte",
    "Eingetunkten": "Eingetunkte",
    "Eingetüteten": "Eingetütete",
    "Eingewachsenen": "Eingewachsene",
    "Eingewachsten": "Eingewachste",
    "Eingewanderten": "Eingewanderte",
    "Eingewandten": "Eingewandte",
    "Eingewebten": "Eingewebte",
    "Eingewechselten": "Eingewechselte",
    "Eingeweichten": "Eingeweichte",
    "Eingeweiden": "Eingeweide",
    "Eingeweides": "Eingeweide",
    "Eingeweihten": "Eingeweihte",
    "Eingewendeten": "Eingewendete",
    "Eingewickelten": "Eingewickelte",
    "Eingewickelteren": "Eingewickeltere",
    "Eingewickeltesten": "Eingewickelteste",
    "Eingewiesenen": "Eingewiesene",
    "Eingewilligten": "Eingewilligte",
    "Eingewinkten": "Eingewinkte",
    "Eingewirkten": "Eingewirkte",
    "Eingewobenen": "Eingewobene",
    "Eingewogenen": "Eingewogene",
    "Eingewohnten": "Eingewohnte",
    "Eingeworfenen": "Eingeworfene",
    "Eingewurzelten": "Eingewurzelte",
    "Eingewöhnenden": "Eingewöhnende",
    "Eingewöhnenderen": "Eingewöhnendere",
    "Eingewöhnendsten": "Eingewöhnendste",
    "Eingewöhnens": "Eingewöhnen",
    "Eingewöhnte": "eingewöhnen",
    "Eingewöhnten": "Eingewöhnte",
    "Eingewöhnteren": "Eingewöhntere",
    "Eingewöhntesten": "Eingewöhnteste",
    "Eingezahlten": "Eingezahlte",
    "Eingezeichneten": "Eingezeichnete",
    "Eingezogenen": "Eingezogene",
    "Eingezwängten": "Eingezwängte",
    "Eingezäunten": "Eingezäunte",
    "Eingeäscherten": "Eingeäscherte",
    "Eingeölten": "Eingeölte",
    "Eingeölteren": "Eingeöltere",
    "Eingeöltesten": "Eingeölteste",
    "Eingeübten": "Eingeübte",
    "Eingeübteren": "Eingeübtere",
    "Eingeübtesten": "Eingeübteste",
    "Eingießenden": "Eingießende",
    "Eingießens": "Eingießen",
    "Eingipsenden": "Eingipsende",
    "Eingipsens": "Eingipsen",
    "Eingitternden": "Eingitternde",
    "Eingitterns": "Eingittern",
    "Einglasenden": "Einglasende",
    "Einglasens": "Einglasen",
    "Eingleisenden": "Eingleisende",
    "Eingleisens": "Eingleisen",
    "Eingleisigen": "Eingleisige",
    "Eingliedernden": "Eingliedernde",
    "Eingliederns": "Eingliedern",
    "Eingliederungen": "Eingliederung",
    "Eingrabenden": "Eingrabende",
    "Eingrabens": "Eingraben",
    "Eingreifenden": "Eingreifende",
    "Eingreifens": "Eingreifen",
    "Eingrenzenden": "Eingrenzende",
    "Eingrenzens": "Eingrenzen",
    "Eingriffe": "Eingriff",
    "Eingriffen": "Eingriff",
    "Eingriffes": "Eingriff",
    "Eingriffs": "Eingriff",
    "Eingruppierenden": "Eingruppierende",
    "Eingruppierens": "Eingruppieren",
    "Eingruppierte": "eingruppiert",
    "Eingruppierten": "Eingruppierte",
    "Eingänge": "Eingang",
    "Eingängen": "Eingang",
    "Eingängige": "eingängig",
    "Eingängigen": "Eingängige",
    "Eingängigeren": "Eingängigere",
    "Eingängigsten": "Eingängigste",
    "Einhakenden": "Einhakende",
    "Einhakens": "Einhaken",
    "Einhaltenden": "Einhaltende",
    "Einhaltens": "Einhalten",
    "Einhaltungen": "Einhaltung",
    "Einhandelnden": "Einhandelnde",
    "Einhandelns": "Einhandeln",
    "Einhauenden": "Einhauende",
    "Einhauens": "Einhauen",
    "Einhebenden": "Einhebende",
    "Einhebens": "Einheben",
    "Einheftenden": "Einheftende",
    "Einheftens": "Einheften",
    "Einhegungen": "Einhegung",
    "Einheilenden": "Einheilende",
    "Einheilens": "Einheilen",
    "Einheimischen": "Einheimische",
    "Einheimsenden": "Einheimsende",
    "Einheimsenderen": "Einheimsendere",
    "Einheimsendsten": "Einheimsendste",
    "Einheimsens": "Einheimsen",
    "Einheiratenden": "Einheiratende",
    "Einheiratens": "Einheiraten",
    "Einheiten": "Einheit",
    "Einheitliche": "einheitlich",
    "Einheitlichen": "Einheitliche",
    "Einheitlicheren": "Einheitlichere",
    "Einheitlichsten": "Einheitlichste",
    "Einheitsparteien": "Einheitspartei",
    "Einheitsschulen": "Einheitsschule",
    "Einheizenden": "Einheizende",
    "Einheizenderen": "Einheizendere",
    "Einheizendsten": "Einheizendste",
    "Einheizens": "Einheizen",
    "Einhelfenden": "Einhelfende",
    "Einhelfens": "Einhelfen",
    "Einhelligen": "Einhellige",
    "Einherbrausenden": "Einherbrausende",
    "Einherbrausens": "Einherbrausen",
    "Einhergebrausten": "Einhergebrauste",
    "Einhergegangenen": "Einhergegangene",
    "Einhergehenden": "Einhergehende",
    "Einhergehens": "Einhergehen",
    "Einhergejagten": "Einhergejagte",
    "Einhergerittenen": "Einhergerittene",
    "Einhergeschlenderten": "Einhergeschlenderte",
    "Einhergeschrittenen": "Einhergeschrittene",
    "Einherjagenden": "Einherjagende",
    "Einherjagens": "Einherjagen",
    "Einherreitenden": "Einherreitende",
    "Einherreitens": "Einherreiten",
    "Einherschlendernden": "Einherschlendernde",
    "Einherschlenderns": "Einherschlendern",
    "Einherschreitenden": "Einherschreitende",
    "Einherschreitens": "Einherschreiten",
    "Einhievenden": "Einhievende",
    "Einhievens": "Einhieven",
    "Einhilfen": "Einhilfe",
    "Einholenden": "Einholende",
    "Einholens": "Einholen",
    "Einhorne": "Einhorn",
    "Einhornes": "Einhorn",
    "Einhorns": "Einhorn",
    "Einhändige": "einhändigen",
    "Einhändigen": "Einhändige",
    "Einhändigenden": "Einhändigende",
    "Einhändigens": "Einhändigen",
    "Einhängenden": "Einhängende",
    "Einhängens": "Einhängen",
    "Einhörner": "Einhorn",
    "Einhörnern": "Einhorn",
    "Einhüllenden": "Einhüllende",
    "Einhüllenderen": "Einhüllendere",
    "Einhüllendsten": "Einhüllendste",
    "Einhüllens": "Einhüllen",
    "Einhütenden": "Einhütende",
    "Einhütens": "Einhüten",
    "Einige": "einigen",
    "Einigelnden": "Einigelnde",
    "Einigelnderen": "Einigelndere",
    "Einigelndsten": "Einigelndste",
    "Einigelns": "Einigeln",
    "Einigen": "Einige",
    "Einigenden": "Einigende",
    "Einigens": "Einigen",
    "Einigkeiten": "Einigkeit",
    "Einigungen": "Einigung",
    "Einimpfenden": "Einimpfende",
    "Einimpfens": "Einimpfen",
    "Einjagenden": "Einjagende",
    "Einjagens": "Einjagen",
    "Einjährigen": "Einjährige",
    "Einkachelnden": "Einkachelnde",
    "Einkachelnderen": "Einkachelndere",
    "Einkachelndsten": "Einkachelndste",
    "Einkachelns": "Einkacheln",
    "Einkalkulierenden": "Einkalkulierende",
    "Einkalkulierens": "Einkalkulieren",
    "Einkalkulierte": "einkalkuliert",
    "Einkalkulierten": "Einkalkulierte",
    "Einkapselnden": "Einkapselnde",
    "Einkapselnderen": "Einkapselndere",
    "Einkapselndsten": "Einkapselndste",
    "Einkapselns": "Einkapseln",
    "Einkassierenden": "Einkassierende",
    "Einkassierenderen": "Einkassierendere",
    "Einkassierendsten": "Einkassierendste",
    "Einkassierens": "Einkassieren",
    "Einkassierte": "einkassiert",
    "Einkassierten": "Einkassierte",
    "Einkassierteren": "Einkassiertere",
    "Einkassiertesten": "Einkassierteste",
    "Einkaufe": "einkaufen",
    "Einkaufenden": "Einkaufende",
    "Einkaufens": "Einkaufen",
    "Einkaufes": "Einkauf",
    "Einkaufs": "Einkauf",
    "Einkaufstaschen": "Einkaufstasche",
    "Einkehrenden": "Einkehrende",
    "Einkehrens": "Einkehren",
    "Einkeilenden": "Einkeilende",
    "Einkeilenderen": "Einkeilendere",
    "Einkeilendsten": "Einkeilendste",
    "Einkeilens": "Einkeilen",
    "Einkellernden": "Einkellernde",
    "Einkellernderen": "Einkellerndere",
    "Einkellerndsten": "Einkellerndste",
    "Einkellerns": "Einkellern",
    "Einkerbenden": "Einkerbende",
    "Einkerbenderen": "Einkerbendere",
    "Einkerbendsten": "Einkerbendste",
    "Einkerbens": "Einkerben",
    "Einkerbungen": "Einkerbung",
    "Einkerkernden": "Einkerkernde",
    "Einkerkerns": "Einkerkern",
    "Einkesselnden": "Einkesselnde",
    "Einkesselnderen": "Einkesselndere",
    "Einkesselndsten": "Einkesselndste",
    "Einkesselns": "Einkesseln",
    "Einkittenden": "Einkittende",
    "Einkittens": "Einkitten",
    "Einklagbaren": "Einklagbare",
    "Einklagenden": "Einklagende",
    "Einklagens": "Einklagen",
    "Einklammernden": "Einklammernde",
    "Einklammerns": "Einklammern",
    "Einklange": "Einklang",
    "Einklanges": "Einklang",
    "Einklangs": "Einklang",
    "Einklebenden": "Einklebende",
    "Einklebens": "Einkleben",
    "Einkleidenden": "Einkleidende",
    "Einkleidenderen": "Einkleidendere",
    "Einkleidendsten": "Einkleidendste",
    "Einkleidens": "Einkleiden",
    "Einklemmenden": "Einklemmende",
    "Einklemmenderen": "Einklemmendere",
    "Einklemmendsten": "Einklemmendste",
    "Einklemmens": "Einklemmen",
    "Einklinkenden": "Einklinkende",
    "Einklinkens": "Einklinken",
    "Einklopfenden": "Einklopfende",
    "Einklopfens": "Einklopfen",
    "Einklänge": "Einklang",
    "Einklängen": "Einklang",
    "Einkneifenden": "Einkneifende",
    "Einkneifenderen": "Einkneifendere",
    "Einkneifendsten": "Einkneifendste",
    "Einkneifens": "Einkneifen",
    "Einknickenden": "Einknickende",
    "Einknickens": "Einknicken",
    "Einknotenden": "Einknotende",
    "Einknotens": "Einknoten",
    "Einknöpfenden": "Einknöpfende",
    "Einknöpfens": "Einknöpfen",
    "Einknüpfenden": "Einknüpfende",
    "Einknüpfens": "Einknüpfen",
    "Einkochenden": "Einkochende",
    "Einkochens": "Einkochen",
    "Einkommens": "Einkommen",
    "Einkommensschwache": "einkommensschwach",
    "Einkommensschwachen": "Einkommensschwache",
    "Einkommensschwächeren": "Einkommensschwächere",
    "Einkommensstarken": "Einkommensstarke",
    "Einkommensstärkeren": "Einkommensstärkere",
    "Einkorns": "Einkorn",
    "Einkratzenden": "Einkratzende",
    "Einkratzenderen": "Einkratzendere",
    "Einkratzendsten": "Einkratzendste",
    "Einkratzens": "Einkratzen",
    "Einkreisenden": "Einkreisende",
    "Einkreisens": "Einkreisen",
    "Einkreuzenden": "Einkreuzende",
    "Einkreuzens": "Einkreuzen",
    "Einkriegenden": "Einkriegende",
    "Einkriegens": "Einkriegen",
    "Einkäufe": "Einkauf",
    "Einkäufen": "Einkauf",
    "Einkäufern": "Einkäufer",
    "Einkäufers": "Einkäufer",
    "Einkünfte": "Einkunft",
    "Einkünften": "Einkunft",
    "Einladenden": "Einladende",
    "Einladens": "Einladen",
    "Einladungen": "Einladung",
    "Einlagen": "einliegen",
    "Einlagernden": "Einlagernde",
    "Einlagerns": "Einlagern",
    "Einlangenden": "Einlangende",
    "Einlangens": "Einlangen",
    "Einlassenden": "Einlassende",
    "Einlassens": "Einlassen",
    "Einlassungen": "Einlassung",
    "Einlaufe": "einlaufen",
    "Einlaufenden": "Einlaufende",
    "Einlaufenderen": "Einlaufendere",
    "Einlaufendsten": "Einlaufendste",
    "Einlaufens": "Einlaufen",
    "Einlaufs": "Einlauf",
    "Einlebenden": "Einlebende",
    "Einlebens": "Einleben",
    "Einlegenden": "Einlegende",
    "Einlegens": "Einlegen",
    "Einlegesohlen": "Einlegesohle",
    "Einleitenden": "Einleitende",
    "Einleitens": "Einleiten",
    "Einleitern": "Einleiter",
    "Einleiters": "Einleiter",
    "Einleitungen": "Einleitung",
    "Einlenkenden": "Einlenkende",
    "Einlenkens": "Einlenken",
    "Einlernenden": "Einlernende",
    "Einlernens": "Einlernen",
    "Einlesenden": "Einlesende",
    "Einlesens": "Einlesen",
    "Einleuchtenden": "Einleuchtende",
    "Einleuchtens": "Einleuchten",
    "Einliefernden": "Einliefernde",
    "Einlieferns": "Einliefern",
    "Einliegenden": "Einliegende",
    "Einliegens": "Einliegen",
    "Einliegern": "Einlieger",
    "Einliegers": "Einlieger",
    "Einliegerwohnungen": "Einliegerwohnung",
    "Einlochenden": "Einlochende",
    "Einlochens": "Einlochen",
    "Einlullenden": "Einlullende",
    "Einlullenderen": "Einlullendere",
    "Einlullendsten": "Einlullendste",
    "Einlullens": "Einlullen",
    "Einläufe": "Einlauf",
    "Einläufen": "Einlauf",
    "Einläutenden": "Einläutende",
    "Einläutens": "Einläuten",
    "Einlösenden": "Einlösende",
    "Einlösens": "Einlösen",
    "Einlötenden": "Einlötende",
    "Einlötens": "Einlöten",
    "Einmachenden": "Einmachende",
    "Einmachens": "Einmachen",
    "Einmahnenden": "Einmahnende",
    "Einmahnens": "Einmahnen",
    "Einmaligen": "Einmalige",
    "Einmanngesellschaften": "Einmanngesellschaft",
    "Einmarkstücke": "Einmarkstück",
    "Einmarkstücken": "Einmarkstück",
    "Einmarkstücks": "Einmarkstück",
    "Einmarsche": "Einmarsch",
    "Einmarsches": "Einmarsch",
    "Einmarschierenden": "Einmarschierende",
    "Einmarschierens": "Einmarschieren",
    "Einmarschierte": "einmarschiert",
    "Einmarschierten": "Einmarschierte",
    "Einmarschs": "Einmarsch",
    "Einmastern": "Einmaster",
    "Einmasters": "Einmaster",
    "Einmauernden": "Einmauernde",
    "Einmauerns": "Einmauern",
    "Einmeißelnden": "Einmeißelnde",
    "Einmeißelns": "Einmeißeln",
    "Einmengenden": "Einmengende",
    "Einmengens": "Einmengen",
    "Einmietenden": "Einmietende",
    "Einmietens": "Einmieten",
    "Einmischenden": "Einmischende",
    "Einmischens": "Einmischen",
    "Einmischungen": "Einmischung",
    "Einmotorige": "einmotorig",
    "Einmotorigen": "Einmotorige",
    "Einmottenden": "Einmottende",
    "Einmottens": "Einmotten",
    "Einmärsche": "Einmarsch",
    "Einmärschen": "Einmarsch",
    "Einmümmelnden": "Einmümmelnde",
    "Einmümmelnderen": "Einmümmelndere",
    "Einmümmelndsten": "Einmümmelndste",
    "Einmümmelns": "Einmümmeln",
    "Einmündenden": "Einmündende",
    "Einmündens": "Einmünden",
    "Einmündungen": "Einmündung",
    "Einmütige": "einmütig",
    "Einmütigen": "Einmütige",
    "Einmütigeren": "Einmütigere",
    "Einmütigsten": "Einmütigste",
    "Einnahmen": "einnehmen",
    "Einnebelnden": "Einnebelnde",
    "Einnebelnderen": "Einnebelndere",
    "Einnebelndsten": "Einnebelndste",
    "Einnebelns": "Einnebeln",
    "Einnebelungen": "Einnebelung",
    "Einnehmenden": "Einnehmende",
    "Einnehmens": "Einnehmen",
    "Einnehmern": "Einnehmer",
    "Einnehmers": "Einnehmer",
    "Einnistenden": "Einnistende",
    "Einnistens": "Einnisten",
    "Einnähenden": "Einnähende",
    "Einnähens": "Einnähen",
    "Einnässenden": "Einnässende",
    "Einnässenderen": "Einnässendere",
    "Einnässendsten": "Einnässendste",
    "Einnässens": "Einnässen",
    "Einoperierenden": "Einoperierende",
    "Einoperierens": "Einoperieren",
    "Einoperierte": "einoperiert",
    "Einoperierten": "Einoperierte",
    "Einordnenden": "Einordnende",
    "Einordnenderen": "Einordnendere",
    "Einordnendsten": "Einordnendste",
    "Einordnens": "Einordnen",
    "Einordnungen": "Einordnung",
    "Einpackenden": "Einpackende",
    "Einpackens": "Einpacken",
    "Einparkenden": "Einparkende",
    "Einparkens": "Einparken",
    "Einpassenden": "Einpassende",
    "Einpassenderen": "Einpassendere",
    "Einpassendsten": "Einpassendste",
    "Einpassens": "Einpassen",
    "Einpaukenden": "Einpaukende",
    "Einpaukens": "Einpauken",
    "Einpaukern": "Einpauker",
    "Einpaukers": "Einpauker",
    "Einpendelnden": "Einpendelnde",
    "Einpendelnderen": "Einpendelndere",
    "Einpendelndsten": "Einpendelndste",
    "Einpendelns": "Einpendeln",
    "Einpferchenden": "Einpferchende",
    "Einpferchenderen": "Einpferchendere",
    "Einpferchendsten": "Einpferchendste",
    "Einpferchens": "Einpferchen",
    "Einpflanzenden": "Einpflanzende",
    "Einpflanzens": "Einpflanzen",
    "Einpfropfenden": "Einpfropfende",
    "Einpfropfenderen": "Einpfropfendere",
    "Einpfropfendsten": "Einpfropfendste",
    "Einpfropfens": "Einpfropfen",
    "Einpinselnden": "Einpinselnde",
    "Einpinselnderen": "Einpinselndere",
    "Einpinselndsten": "Einpinselndste",
    "Einpinselns": "Einpinseln",
    "Einplanenden": "Einplanende",
    "Einplanens": "Einplanen",
    "Einpoligen": "Einpolige",
    "Einpressenden": "Einpressende",
    "Einpressens": "Einpressen",
    "Einprogrammierenden": "Einprogrammierende",
    "Einprogrammierens": "Einprogrammieren",
    "Einprogrammierte": "einprogrammiert",
    "Einprogrammierten": "Einprogrammierte",
    "Einprägenden": "Einprägende",
    "Einprägenderen": "Einprägendere",
    "Einprägendsten": "Einprägendste",
    "Einprägens": "Einprägen",
    "Einprägsamen": "Einprägsame",
    "Einprägsameren": "Einprägsamere",
    "Einprägsamsten": "Einprägsamste",
    "Einprägungen": "Einprägung",
    "Einpudernden": "Einpudernde",
    "Einpudernderen": "Einpuderndere",
    "Einpuderndsten": "Einpuderndste",
    "Einpuderns": "Einpudern",
    "Einpumpenden": "Einpumpende",
    "Einpumpens": "Einpumpen",
    "Einpökelnden": "Einpökelnde",
    "Einpökelnderen": "Einpökelndere",
    "Einpökelndsten": "Einpökelndste",
    "Einpökelns": "Einpökeln",
    "Einquartierenden": "Einquartierende",
    "Einquartierens": "Einquartieren",
    "Einquartierte": "einquartiert",
    "Einquartierten": "Einquartierte",
    "Einquartierungen": "Einquartierung",
    "Einrahmenden": "Einrahmende",
    "Einrahmens": "Einrahmen",
    "Einrammenden": "Einrammende",
    "Einrammenderen": "Einrammendere",
    "Einrammendsten": "Einrammendste",
    "Einrammens": "Einrammen",
    "Einrastenden": "Einrastende",
    "Einrastenderen": "Einrastendere",
    "Einrastendsten": "Einrastendste",
    "Einrastens": "Einrasten",
    "Einrechnenden": "Einrechnende",
    "Einrechnens": "Einrechnen",
    "Einredenden": "Einredende",
    "Einredens": "Einreden",
    "Einregnenden": "Einregnende",
    "Einregnens": "Einregnen",
    "Einreibenden": "Einreibende",
    "Einreibens": "Einreiben",
    "Einreibern": "Einreiber",
    "Einreibers": "Einreiber",
    "Einreichenden": "Einreichende",
    "Einreichens": "Einreichen",
    "Einreihenden": "Einreihende",
    "Einreihens": "Einreihen",
    "Einreihern": "Einreiher",
    "Einreihers": "Einreiher",
    "Einreisen": "Einreise",
    "Einreisenden": "Einreisende",
    "Einreisens": "Einreisen",
    "Einreitenden": "Einreitende",
    "Einreitens": "Einreiten",
    "Einreißenden": "Einreißende",
    "Einreißenderen": "Einreißendere",
    "Einreißendsten": "Einreißendste",
    "Einreißens": "Einreißen",
    "Einrenkenden": "Einrenkende",
    "Einrenkens": "Einrenken",
    "Einrennenden": "Einrennende",
    "Einrennens": "Einrennen",
    "Einrichtenden": "Einrichtende",
    "Einrichtens": "Einrichten",
    "Einrichtern": "Einrichter",
    "Einrichters": "Einrichter",
    "Einrichtungen": "Einrichtung",
    "Einriegelnden": "Einriegelnde",
    "Einriegelns": "Einriegeln",
    "Einritts": "Einritt",
    "Einritzenden": "Einritzende",
    "Einritzens": "Einritzen",
    "Einrollenden": "Einrollende",
    "Einrollenderen": "Einrollendere",
    "Einrollendsten": "Einrollendste",
    "Einrollens": "Einrollen",
    "Einrostenden": "Einrostende",
    "Einrostenderen": "Einrostendere",
    "Einrostendsten": "Einrostendste",
    "Einrostens": "Einrosten",
    "Einräuchernden": "Einräuchernde",
    "Einräuchernderen": "Einräucherndere",
    "Einräucherndsten": "Einräucherndste",
    "Einräucherns": "Einräuchern",
    "Einräumenden": "Einräumende",
    "Einräumenderen": "Einräumendere",
    "Einräumendsten": "Einräumendste",
    "Einräumens": "Einräumen",
    "Einrückenden": "Einrückende",
    "Einrückens": "Einrücken",
    "Einrührenden": "Einrührende",
    "Einrührens": "Einrühren",
    "Einrüstenden": "Einrüstende",
    "Einrüstens": "Einrüsten",
    "Einsagenden": "Einsagende",
    "Einsagens": "Einsagen",
    "Einsalbenden": "Einsalbende",
    "Einsalbens": "Einsalben",
    "Einsalzenden": "Einsalzende",
    "Einsalzenderen": "Einsalzendere",
    "Einsalzendsten": "Einsalzendste",
    "Einsalzens": "Einsalzen",
    "Einsamen": "Einsame",
    "Einsameren": "Einsamere",
    "Einsammelnden": "Einsammelnde",
    "Einsammelns": "Einsammeln",
    "Einsamsten": "Einsamste",
    "Einsargenden": "Einsargende",
    "Einsargens": "Einsargen",
    "Einsatzbereiten": "Einsatzbereite",
    "Einsatzbereiteren": "Einsatzbereitere",
    "Einsatze": "Einsatz",
    "Einsatzes": "Einsatz",
    "Einsauenden": "Einsauende",
    "Einsauenderen": "Einsauendere",
    "Einsauendsten": "Einsauendste",
    "Einsauens": "Einsauen",
    "Einsaugenden": "Einsaugende",
    "Einsaugenderen": "Einsaugendere",
    "Einsaugendsten": "Einsaugendste",
    "Einsaugens": "Einsaugen",
    "Einschachtelnden": "Einschachtelnde",
    "Einschachtelnderen": "Einschachtelndere",
    "Einschachtelns": "Einschachteln",
    "Einschaltenden": "Einschaltende",
    "Einschaltens": "Einschalten",
    "Einschaltungen": "Einschaltung",
    "Einscharrenden": "Einscharrende",
    "Einscharrens": "Einscharren",
    "Einschenkenden": "Einschenkende",
    "Einschenkens": "Einschenken",
    "Einscherenden": "Einscherende",
    "Einscherens": "Einscheren",
    "Einschiebenden": "Einschiebende",
    "Einschiebens": "Einschieben",
    "Einschießenden": "Einschießende",
    "Einschießenderen": "Einschießendere",
    "Einschießendsten": "Einschießendste",
    "Einschießens": "Einschießen",
    "Einschiffenden": "Einschiffende",
    "Einschiffens": "Einschiffen",
    "Einschlafenden": "Einschlafende",
    "Einschlafens": "Einschlafen",
    "Einschlagenden": "Einschlagende",
    "Einschlagenderen": "Einschlagendere",
    "Einschlagendsten": "Einschlagendste",
    "Einschlagens": "Einschlagen",
    "Einschleichenden": "Einschleichende",
    "Einschleichens": "Einschleichen",
    "Einschleifenden": "Einschleifende",
    "Einschleifens": "Einschleifen",
    "Einschleimenden": "Einschleimende",
    "Einschleimenderen": "Einschleimendere",
    "Einschleimendsten": "Einschleimendste",
    "Einschleimens": "Einschleimen",
    "Einschleppenden": "Einschleppende",
    "Einschleppens": "Einschleppen",
    "Einschleusenden": "Einschleusende",
    "Einschleusens": "Einschleusen",
    "Einschließenden": "Einschließende",
    "Einschließens": "Einschließen",
    "Einschlummernden": "Einschlummernde",
    "Einschlummerns": "Einschlummern",
    "Einschläfernden": "Einschläfernde",
    "Einschläferns": "Einschläfern",
    "Einschlägigen": "Einschlägige",
    "Einschmeichelnden": "Einschmeichelnde",
    "Einschmeichelnderen": "Einschmeichelndere",
    "Einschmeichelns": "Einschmeicheln",
    "Einschmeißenden": "Einschmeißende",
    "Einschmeißens": "Einschmeißen",
    "Einschmelzenden": "Einschmelzende",
    "Einschmelzens": "Einschmelzen",
    "Einschmierenden": "Einschmierende",
    "Einschmierens": "Einschmieren",
    "Einschmuggelnden": "Einschmuggelnde",
    "Einschmuggelns": "Einschmuggeln",
    "Einschnappenden": "Einschnappende",
    "Einschnappens": "Einschnappen",
    "Einschneidenden": "Einschneidende",
    "Einschneidenderen": "Einschneidendere",
    "Einschneidendsten": "Einschneidendste",
    "Einschneidens": "Einschneiden",
    "Einschneienden": "Einschneiende",
    "Einschneienderen": "Einschneiendere",
    "Einschneiendsten": "Einschneiendste",
    "Einschneiens": "Einschneien",
    "Einschnitte": "Einschnitt",
    "Einschnitten": "Einschnitt",
    "Einschnitts": "Einschnitt",
    "Einschnitzenden": "Einschnitzende",
    "Einschnitzens": "Einschnitzen",
    "Einschnürenden": "Einschnürende",
    "Einschnürenderen": "Einschnürendere",
    "Einschnürendsten": "Einschnürendste",
    "Einschnürens": "Einschnüren",
    "Einschraubenden": "Einschraubende",
    "Einschraubens": "Einschrauben",
    "Einschreibegebühren": "Einschreibegebühr",
    "Einschreibenden": "Einschreibende",
    "Einschreibens": "Einschreiben",
    "Einschreibesendungen": "Einschreibesendung",
    "Einschreitenden": "Einschreitende",
    "Einschreitens": "Einschreiten",
    "Einschrumpfenden": "Einschrumpfende",
    "Einschrumpfenderen": "Einschrumpfendere",
    "Einschrumpfens": "Einschrumpfen",
    "Einschränkenden": "Einschränkende",
    "Einschränkenderen": "Einschränkendere",
    "Einschränkendsten": "Einschränkendste",
    "Einschränkens": "Einschränken",
    "Einschränkungen": "Einschränkung",
    "Einschulenden": "Einschulende",
    "Einschulens": "Einschulen",
    "Einschwebenden": "Einschwebende",
    "Einschwebens": "Einschweben",
    "Einschwefelnden": "Einschwefelnde",
    "Einschwefelnderen": "Einschwefelndere",
    "Einschwefelndsten": "Einschwefelndste",
    "Einschwefelns": "Einschwefeln",
    "Einschwenkenden": "Einschwenkende",
    "Einschwenkens": "Einschwenken",
    "Einschwimmenden": "Einschwimmende",
    "Einschwimmenderen": "Einschwimmendere",
    "Einschwimmendsten": "Einschwimmendste",
    "Einschwimmens": "Einschwimmen",
    "Einschwingenden": "Einschwingende",
    "Einschwingens": "Einschwingen",
    "Einschwärzenden": "Einschwärzende",
    "Einschwärzenderen": "Einschwärzendere",
    "Einschwärzendsten": "Einschwärzendste",
    "Einschwärzens": "Einschwärzen",
    "Einschwörenden": "Einschwörende",
    "Einschwörenderen": "Einschwörendere",
    "Einschwörendsten": "Einschwörendste",
    "Einschwörens": "Einschwören",
    "Einschärfenden": "Einschärfende",
    "Einschärfens": "Einschärfen",
    "Einschätzenden": "Einschätzende",
    "Einschätzens": "Einschätzen",
    "Einschätzungen": "Einschätzung",
    "Einschüttenden": "Einschüttende",
    "Einschüttens": "Einschütten",
    "Einsegnenden": "Einsegnende",
    "Einsegnens": "Einsegnen",
    "Einsegnungen": "Einsegnung",
    "Einsehenden": "Einsehende",
    "Einsehens": "Einsehen",
    "Einseifenden": "Einseifende",
    "Einseifenderen": "Einseifendere",
    "Einseifendsten": "Einseifendste",
    "Einseifens": "Einseifen",
    "Einseitigen": "Einseitige",
    "Einseitigeren": "Einseitigere",
    "Einseitigsten": "Einseitigste",
    "Einsen": "Eins",
    "Einsendenden": "Einsendende",
    "Einsendens": "Einsenden",
    "Einsendern": "Einsender",
    "Einsenders": "Einsender",
    "Einsendungen": "Einsendung",
    "Einsengenden": "Einsengende",
    "Einsengenderen": "Einsengendere",
    "Einsengendsten": "Einsengendste",
    "Einsengens": "Einsengen",
    "Einsenkungen": "Einsenkung",
    "Einsern": "Einser",
    "Einsers": "Einser",
    "Einsetzenden": "Einsetzende",
    "Einsetzens": "Einsetzen",
    "Einsetzungen": "Einsetzung",
    "Einsichtige": "einsichtig",
    "Einsichtigen": "Einsichtige",
    "Einsichtigeren": "Einsichtigere",
    "Einsichtigsten": "Einsichtigste",
    "Einsiedeleien": "Einsiedelei",
    "Einsiedlern": "Einsiedler",
    "Einsiedlers": "Einsiedler",
    "Einsilbern": "Einsilber",
    "Einsilbers": "Einsilber",
    "Einsilbige": "einsilbig",
    "Einsilbigen": "Einsilbige",
    "Einsilbigeren": "Einsilbigere",
    "Einsilbigsten": "Einsilbigste",
    "Einsingenden": "Einsingende",
    "Einsingens": "Einsingen",
    "Einsinkenden": "Einsinkende",
    "Einsinkens": "Einsinken",
    "Einsitzenden": "Einsitzende",
    "Einsitzenderen": "Einsitzendere",
    "Einsitzendsten": "Einsitzendste",
    "Einsitzens": "Einsitzen",
    "Einsitzern": "Einsitzer",
    "Einsitzers": "Einsitzer",
    "Einsortierenden": "Einsortierende",
    "Einsortierenderen": "Einsortierendere",
    "Einsortierendsten": "Einsortierendste",
    "Einsortierens": "Einsortieren",
    "Einsortierte": "einsortiert",
    "Einsortierten": "Einsortierte",
    "Einsortierteren": "Einsortiertere",
    "Einsortiertesten": "Einsortierteste",
    "Einspannenden": "Einspannende",
    "Einspannens": "Einspannen",
    "Einsparenden": "Einsparende",
    "Einsparenderen": "Einsparendere",
    "Einsparendsten": "Einsparendste",
    "Einsparens": "Einsparen",
    "Einsparungen": "Einsparung",
    "Einspeichernden": "Einspeichernde",
    "Einspeicherns": "Einspeichern",
    "Einsperrenden": "Einsperrende",
    "Einsperrens": "Einsperren",
    "Einspielenden": "Einspielende",
    "Einspielenderen": "Einspielendere",
    "Einspielendsten": "Einspielendste",
    "Einspielens": "Einspielen",
    "Einsprachigen": "Einsprachige",
    "Einsprechenden": "Einsprechende",
    "Einsprechens": "Einsprechen",
    "Einsprengenden": "Einsprengende",
    "Einsprengens": "Einsprengen",
    "Einspringenden": "Einspringende",
    "Einspringens": "Einspringen",
    "Einspritzenden": "Einspritzende",
    "Einspritzens": "Einspritzen",
    "Einspritzpumpen": "Einspritzpumpe",
    "Einspritzungen": "Einspritzung",
    "Einspruche": "Einspruch",
    "Einspruchs": "Einspruch",
    "Einsprüche": "Einspruch",
    "Einsprüchen": "Einspruch",
    "Einsprühenden": "Einsprühende",
    "Einsprühens": "Einsprühen",
    "Einspurigen": "Einspurige",
    "Einstampfenden": "Einstampfende",
    "Einstampfens": "Einstampfen",
    "Einstande": "Einstand",
    "Einstands": "Einstand",
    "Einstaubenden": "Einstaubende",
    "Einstaubenderen": "Einstaubendere",
    "Einstaubendsten": "Einstaubendste",
    "Einstaubens": "Einstauben",
    "Einstechenden": "Einstechende",
    "Einstechens": "Einstechen",
    "Einsteckenden": "Einsteckende",
    "Einsteckens": "Einstecken",
    "Einstehenden": "Einstehende",
    "Einstehens": "Einstehen",
    "Einsteigenden": "Einsteigende",
    "Einsteigens": "Einsteigen",
    "Einstellbaren": "Einstellbare",
    "Einstellenden": "Einstellende",
    "Einstellens": "Einstellen",
    "Einstelligen": "Einstellige",
    "Einstellungen": "Einstellung",
    "Einstiche": "Einstich",
    "Einstichen": "Einstich",
    "Einstichs": "Einstich",
    "Einstiege": "Einstieg",
    "Einstiegen": "Einstieg",
    "Einstiegs": "Einstieg",
    "Einstigen": "Einstige",
    "Einstimmenden": "Einstimmende",
    "Einstimmens": "Einstimmen",
    "Einstimmigen": "Einstimmige",
    "Einstippenden": "Einstippende",
    "Einstippens": "Einstippen",
    "Einstrahlenden": "Einstrahlende",
    "Einstrahlens": "Einstrahlen",
    "Einstreichenden": "Einstreichende",
    "Einstreichens": "Einstreichen",
    "Einstreuenden": "Einstreuende",
    "Einstreuens": "Einstreuen",
    "Einströmenden": "Einströmende",
    "Einströmens": "Einströmen",
    "Einstudierenden": "Einstudierende",
    "Einstudierens": "Einstudieren",
    "Einstudierte": "einstudiert",
    "Einstudierten": "Einstudierte",
    "Einstudierungen": "Einstudierung",
    "Einstufenden": "Einstufende",
    "Einstufens": "Einstufen",
    "Einstufungen": "Einstufung",
    "Einstweiligen": "Einstweilige",
    "Einstände": "Einstand",
    "Einständen": "Einstand",
    "Einstülpenden": "Einstülpende",
    "Einstülpens": "Einstülpen",
    "Einstürmenden": "Einstürmende",
    "Einstürmens": "Einstürmen",
    "Einstürzenden": "Einstürzende",
    "Einstürzenderen": "Einstürzendere",
    "Einstürzendsten": "Einstürzendste",
    "Einstürzens": "Einstürzen",
    "Einsägende": "einsägend",
    "Einsägenden": "Einsägende",
    "Einsägens": "Einsägen",
    "Einsätze": "Einsatz",
    "Einsätzen": "Einsatz",
    "Einsäuernden": "Einsäuernde",
    "Einsäuernderen": "Einsäuerndere",
    "Einsäuerndsten": "Einsäuerndste",
    "Einsäuerns": "Einsäuern",
    "Einsäumenden": "Einsäumende",
    "Einsäumens": "Einsäumen",
    "Eintagsfiebers": "Eintagsfieber",
    "Eintagsfliegen": "Eintagsfliege",
    "Eintanzenden": "Eintanzende",
    "Eintanzens": "Eintanzen",
    "Eintauchenden": "Eintauchende",
    "Eintauchens": "Eintauchen",
    "Eintauschenden": "Eintauschende",
    "Eintauschens": "Eintauschen",
    "Einteilenden": "Einteilende",
    "Einteilens": "Einteilen",
    "Einteiligen": "Einteilige",
    "Einteilungen": "Einteilung",
    "Eintopfe": "eintopfen",
    "Eintopfenden": "Eintopfende",
    "Eintopfens": "Eintopfen",
    "Eintopfes": "Eintopf",
    "Eintopfs": "Eintopf",
    "Eintrage": "eintragen",
    "Eintragenden": "Eintragende",
    "Eintragens": "Eintragen",
    "Eintrags": "Eintrag",
    "Eintragungen": "Eintragung",
    "Eintreffenden": "Eintreffende",
    "Eintreffens": "Eintreffen",
    "Eintreibbaren": "Eintreibbare",
    "Eintreibenden": "Eintreibende",
    "Eintreibens": "Eintreiben",
    "Eintretenden": "Eintretende",
    "Eintretens": "Eintreten",
    "Eintrichternden": "Eintrichternde",
    "Eintrichterns": "Eintrichtern",
    "Eintritte": "Eintritt",
    "Eintritten": "Eintritt",
    "Eintrittes": "Eintritt",
    "Eintritts": "Eintritt",
    "Eintrittskarten": "Eintrittskarte",
    "Eintrocknenden": "Eintrocknende",
    "Eintrocknenderen": "Eintrocknendere",
    "Eintrocknendsten": "Eintrocknendste",
    "Eintrocknens": "Eintrocknen",
    "Eintrudelnden": "Eintrudelnde",
    "Eintrudelns": "Eintrudeln",
    "Einträchtigen": "Einträchtige",
    "Einträchtigeren": "Einträchtigere",
    "Einträchtigsten": "Einträchtigste",
    "Einträge": "Eintrag",
    "Einträgen": "Eintrag",
    "Einträglichen": "Einträgliche",
    "Einträufelnden": "Einträufelnde",
    "Einträufelns": "Einträufeln",
    "Eintrübenden": "Eintrübende",
    "Eintrübens": "Eintrüben",
    "Eintunkenden": "Eintunkende",
    "Eintunkens": "Eintunken",
    "Eintägigen": "Eintägige",
    "Eintönigen": "Eintönige",
    "Eintönigeren": "Eintönigere",
    "Eintönigsten": "Eintönigste",
    "Eintöpfe": "Eintopf",
    "Eintöpfen": "Eintopf",
    "Eintütenden": "Eintütende",
    "Eintütens": "Eintüten",
    "Einverleibenden": "Einverleibende",
    "Einverleibens": "Einverleiben",
    "Einverleibte": "einverleibt",
    "Einverleibten": "Einverleibte",
    "Einvernahmen": "Einvernahme",
    "Einvernehmens": "Einvernehmen",
    "Einvernehmliche": "einvernehmlich",
    "Einvernehmlichen": "Einvernehmliche",
    "Einverstandenen": "Einverstandene",
    "Einwachsenden": "Einwachsende",
    "Einwachsens": "Einwachsen",
    "Einwanderern": "Einwanderer",
    "Einwanderers": "Einwanderer",
    "Einwandernden": "Einwandernde",
    "Einwanderns": "Einwandern",
    "Einwanderungen": "Einwanderung",
    "Einwandfreie": "einwandfrei",
    "Einwandfreien": "Einwandfreie",
    "Einwebenden": "Einwebende",
    "Einwebens": "Einweben",
    "Einwechselnden": "Einwechselnde",
    "Einwechselns": "Einwechseln",
    "Einwegflaschen": "Einwegflasche",
    "Einweghahne": "Einweghahn",
    "Einweghahns": "Einweghahn",
    "Einweghähne": "Einweghahn",
    "Einweghähnen": "Einweghahn",
    "Einwegscheiben": "Einwegscheibe",
    "Einweichenden": "Einweichende",
    "Einweichens": "Einweichen",
    "Einweihenden": "Einweihende",
    "Einweihens": "Einweihen",
    "Einweihungen": "Einweihung",
    "Einweisenden": "Einweisende",
    "Einweisens": "Einweisen",
    "Einwendenden": "Einwendende",
    "Einwendens": "Einwenden",
    "Einwerfenden": "Einwerfende",
    "Einwerfens": "Einwerfen",
    "Einwickelnden": "Einwickelnde",
    "Einwickelnderen": "Einwickelndere",
    "Einwickelndsten": "Einwickelndste",
    "Einwickelns": "Einwickeln",
    "Einwiegenden": "Einwiegende",
    "Einwiegens": "Einwiegen",
    "Einwilligenden": "Einwilligende",
    "Einwilligens": "Einwilligen",
    "Einwilligungen": "Einwilligung",
    "Einwinkenden": "Einwinkende",
    "Einwinkens": "Einwinken",
    "Einwirkenden": "Einwirkende",
    "Einwirkens": "Einwirken",
    "Einwirkungen": "Einwirkung",
    "Einwohnenden": "Einwohnende",
    "Einwohnens": "Einwohnen",
    "Einwohnern": "Einwohner",
    "Einwohners": "Einwohner",
    "Einwurfe": "Einwurf",
    "Einwurfs": "Einwurf",
    "Einwurzelnden": "Einwurzelnde",
    "Einwurzelns": "Einwurzeln",
    "Einwände": "Einwand",
    "Einwänden": "Einwand",
    "Einwürfe": "Einwurf",
    "Einwürfen": "Einwurf",
    "Einzahlenden": "Einzahlende",
    "Einzahlens": "Einzahlen",
    "Einzahlern": "Einzahler",
    "Einzahlers": "Einzahler",
    "Einzahlungen": "Einzahlung",
    "Einzeichnenden": "Einzeichnende",
    "Einzeichnens": "Einzeichnen",
    "Einzeiligen": "Einzeilige",
    "Einzelabkommens": "Einzelabkommen",
    "Einzelabteile": "Einzelabteil",
    "Einzelabteilen": "Einzelabteil",
    "Einzelabteils": "Einzelabteil",
    "Einzelausgaben": "Einzelausgabe",
    "Einzeldarstellungen": "Einzeldarstellung",
    "Einzelfalle": "Einzelfall",
    "Einzelfalles": "Einzelfall",
    "Einzelfalls": "Einzelfall",
    "Einzelfälle": "Einzelfall",
    "Einzelfällen": "Einzelfall",
    "Einzelheiten": "Einzelheit",
    "Einzellige": "einzellig",
    "Einzelligen": "Einzellige",
    "Einzeln": "Einzel",
    "Einzelne": "einzeln",
    "Einzelnen": "Einzelne",
    "Einzels": "Einzel",
    "Einzelverkaufe": "Einzelverkauf",
    "Einzelverkaufs": "Einzelverkauf",
    "Einzelverkäufe": "Einzelverkauf",
    "Einzelverkäufen": "Einzelverkauf",
    "Einzelzimmern": "Einzelzimmer",
    "Einzelzimmers": "Einzelzimmer",
    "Einziehenden": "Einziehende",
    "Einziehens": "Einziehen",
    "Einzigartigen": "Einzigartige",
    "Einzigartigeren": "Einzigartigere",
    "Einzigartigsten": "Einzigartigste",
    "Einzigen": "Einzige",
    "Einzuge": "Einzug",
    "Einzuges": "Einzug",
    "Einzugs": "Einzug",
    "Einzwängenden": "Einzwängende",
    "Einzwängens": "Einzwängen",
    "Einzäunenden": "Einzäunende",
    "Einzäunens": "Einzäunen",
    "Einzüge": "Einzug",
    "Einzügen": "Einzug",
    "Einäschernden": "Einäschernde",
    "Einäscherns": "Einäschern",
    "Einäscherungen": "Einäscherung",
    "Einöden": "Einöde",
    "Einölenden": "Einölende",
    "Einölenderen": "Einölendere",
    "Einölendsten": "Einölendste",
    "Einölens": "Einölen",
    "Einübenden": "Einübende",
    "Einübenderen": "Einübendere",
    "Einübendsten": "Einübendste",
    "Einübens": "Einüben",
    "Eis": "eisen",
    "Eisenden": "Eisende",
    "Eisenharten": "Eisenharte",
    "Eisenhärteren": "Eisenhärtere",
    "Eisenhärtesten": "Eisenhärteste",
    "Eisens": "Eisen",
    "Eiserne": "eisern",
    "Eisernen": "Eiserne",
    "Eiserneren": "Eisernere",
    "Eisernsten": "Eisernste",
    "Eisfreien": "Eisfreie",
    "Eisgekühlten": "Eisgekühlte",
    "Eisgekühlteren": "Eisgekühltere",
    "Eisgekühltesten": "Eisgekühlteste",
    "Eisigen": "Eisige",
    "Eisigeren": "Eisigere",
    "Eisigsten": "Eisigste",
    "Eiskalten": "Eiskalte",
    "Eiskunstläufern": "Eiskunstläufer",
    "Eiskunstläufers": "Eiskunstläufer",
    "Eisprunge": "Eisprung",
    "Eisprungs": "Eisprung",
    "Eisprünge": "Eisprung",
    "Eisprüngen": "Eisprung",
    "Eisse": "Eis",
    "Eisses": "Eis",
    "Eitelkeiten": "Eitelkeit",
    "Eitelste": "eitel",
    "Eitelsten": "Eitelste",
    "Eiter": "eitern",
    "Eiterigen": "Eiterige",
    "Eiterigeren": "Eiterigere",
    "Eiterigsten": "Eiterigste",
    "Eitern": "Eiter",
    "Eiternden": "Eiternde",
    "Eiternderen": "Eiterndere",
    "Eiterndsten": "Eiterndste",
    "Eiterns": "Eitern",
    "Eiters": "Eiter",
    "Eitlen": "Eitle",
    "Eitleren": "Eitlere",
    "Eitrigen": "Eitrige",
    "Eitrigeren": "Eitrigere",
    "Eitrigsten": "Eitrigste",
    "Eizellen": "Eizelle",
    "Ejakulierenden": "Ejakulierende",
    "Ejakulierens": "Ejakulieren",
    "Ejakulierte": "ejakuliert",
    "Ejakulierten": "Ejakulierte",
    "Ejektionen": "Ejektion",
    "Ekel": "ekeln",
    "Ekelhaften": "Ekelhafte",
    "Ekelhafteren": "Ekelhaftere",
    "Ekelhaftesten": "Ekelhafteste",
    "Ekeligen": "Ekelige",
    "Ekeligeren": "Ekeligere",
    "Ekeligsten": "Ekeligste",
    "Ekeln": "Ekel",
    "Ekelnden": "Ekelnde",
    "Ekelnderen": "Ekelndere",
    "Ekelndsten": "Ekelndste",
    "Ekelns": "Ekeln",
    "Ekels": "Ekel",
    "Ekligen": "Eklige",
    "Ekligeren": "Ekligere",
    "Ekligsten": "Ekligste",
    "Ekstasen": "Ekstase",
    "Ekzematikern": "Ekzematiker",
    "Ekzematikers": "Ekzematiker",
    "Ekzeme": "Ekzem",
    "Ekzemen": "Ekzem",
    "Ekzems": "Ekzem",
    "Elaborate": "Elaborat",
    "Elaboraten": "Elaborat",
    "Elaborats": "Elaborat",
    "Elaborierenden": "Elaborierende",
    "Elaborierens": "Elaborieren",
    "Elaborierte": "elaboriert",
    "Elaborierten": "Elaborierte",
    "Elastiken": "Elastik",
    "Elastische": "elastisch",
    "Elastischen": "Elastische",
    "Elastischeren": "Elastischere",
    "Elastischsten": "Elastischste",
    "Elative": "Elativ",
    "Elativen": "Elativ",
    "Elativs": "Elativ",
    "Elche": "Elch",
    "Elchen": "Elch",
    "Elches": "Elch",
    "Elchs": "Elch",
    "Eldorados": "Eldorado",
    "Electroflashs": "Electroflash",
    "Elefanten": "Elefant",
    "Elegante": "elegant",
    "Eleganten": "Elegante",
    "Eleganteren": "Elegantere",
    "Elegantesten": "Eleganteste",
    "Elektrifizierenden": "Elektrifizierende",
    "Elektrifizierenderen": "Elektrifizierendere",
    "Elektrifizierens": "Elektrifizieren",
    "Elektrifizierte": "elektrifiziert",
    "Elektrifizierten": "Elektrifizierte",
    "Elektrifizierteren": "Elektrifiziertere",
    "Elektrikern": "Elektriker",
    "Elektrikers": "Elektriker",
    "Elektrische": "elektrisch",
    "Elektrischen": "Elektrische",
    "Elektrisierenden": "Elektrisierende",
    "Elektrisierenderen": "Elektrisierendere",
    "Elektrisierens": "Elektrisieren",
    "Elektrisierte": "elektrisiert",
    "Elektrisierten": "Elektrisierte",
    "Elektrisierteren": "Elektrisiertere",
    "Elektrisiertesten": "Elektrisierteste",
    "Elektroden": "Elektrode",
    "Elektrodynamische": "elektrodynamisch",
    "Elektrodynamischen": "Elektrodynamische",
    "Elektroflashs": "Elektroflash",
    "Elektrolysen": "Elektrolyse",
    "Elektrolyten": "Elektrolyt",
    "Elektrolytische": "elektrolytisch",
    "Elektrolytischen": "Elektrolytische",
    "Elektromechanischen": "Elektromechanische",
    "Elektrometern": "Elektrometer",
    "Elektrometers": "Elektrometer",
    "Elektrone": "Elektron",
    "Elektronen": "Elektron",
    "Elektronenhüllen": "Elektronenhülle",
    "Elektronenröhren": "Elektronenröhre",
    "Elektrones": "Elektron",
    "Elektronische": "elektronisch",
    "Elektronischen": "Elektronische",
    "Elektrons": "Elektron",
    "Elektrostatische": "elektrostatisch",
    "Elektrostatischen": "Elektrostatische",
    "Elektrotechnikern": "Elektrotechniker",
    "Elektrotechnikers": "Elektrotechniker",
    "Elektrotechnische": "elektrotechnisch",
    "Elektrotechnischen": "Elektrotechnische",
    "Elementaranalysen": "Elementaranalyse",
    "Elementare": "elementar",
    "Elementaren": "Elementare",
    "Elementareren": "Elementarere",
    "Elementargewalten": "Elementargewalt",
    "Elementarkenntnisse": "Elementarkenntnis",
    "Elementarkenntnissen": "Elementarkenntnis",
    "Elementarklassen": "Elementarklasse",
    "Elementarkräfte": "Elementarkraft",
    "Elementarkräften": "Elementarkraft",
    "Elementarladungen": "Elementarladung",
    "Elementarlehrern": "Elementarlehrer",
    "Elementarlehrers": "Elementarlehrer",
    "Elementarste": "elementar",
    "Elementarsten": "Elementarste",
    "Elementarteilchens": "Elementarteilchen",
    "Elementarunterrichts": "Elementarunterricht",
    "Elemente": "Element",
    "Elementen": "Element",
    "Elementes": "Element",
    "Elements": "Element",
    "Elende": "Elend",
    "Elenden": "Elende",
    "Elenderen": "Elendere",
    "Elendesten": "Elendeste",
    "Elendigen": "Elendige",
    "Elendigeren": "Elendigere",
    "Elendigsten": "Elendigste",
    "Elends": "Elend",
    "Elfen": "Elfe",
    "Elfenbeine": "Elfenbein",
    "Elfenbeinen": "Elfenbein",
    "Elfenbeins": "Elfenbein",
    "Elferwetten": "Elferwette",
    "Elfmetern": "Elfmeter",
    "Elfmeters": "Elfmeter",
    "Eliminierenden": "Eliminierende",
    "Eliminierens": "Eliminieren",
    "Eliminierte": "eliminiert",
    "Eliminierten": "Eliminierte",
    "Elisabeths": "Elisabeth",
    "Eliten": "Elite",
    "Elitäre": "elitär",
    "Elitären": "Elitäre",
    "Elitäreren": "Elitärere",
    "Elitärsten": "Elitärste",
    "Elkes": "Elke",
    "Ellbogens": "Ellbogen",
    "Ellen": "Elle",
    "Ellenbeugen": "Ellenbeuge",
    "Ellenlange": "ellenlang",
    "Ellenlangen": "Ellenlange",
    "Ellipsen": "Ellipse",
    "Elliptische": "elliptisch",
    "Elliptischen": "Elliptische",
    "Elmars": "Elmar",
    "Eloises": "Eloise",
    "Eloquente": "eloquent",
    "Eloquenten": "Eloquente",
    "Elsasse": "Elsaß",
    "Elsasses": "Elsaß",
    "Elses": "Else",
    "Elsässische": "elsässisch",
    "Elsässischen": "Elsässische",
    "Elterliche": "elterlich",
    "Elterlichen": "Elterliche",
    "Elternlosen": "Elternlose",
    "Emanzipationen": "Emanzipation",
    "Emanzipierenden": "Emanzipierende",
    "Emanzipierenderen": "Emanzipierendere",
    "Emanzipierendsten": "Emanzipierendste",
    "Emanzipierens": "Emanzipieren",
    "Emanzipierte": "emanzipiert",
    "Emanzipierten": "Emanzipierte",
    "Emanzipierteren": "Emanzipiertere",
    "Emanzipiertesten": "Emanzipierteste",
    "Embargos": "Embargo",
    "Embolien": "Embolie",
    "Embryonale": "embryonal",
    "Embryonalen": "Embryonale",
    "Embryos": "Embryo",
    "Emeritierenden": "Emeritierende",
    "Emeritierens": "Emeritieren",
    "Emeritierte": "emeritiert",
    "Emeritierten": "Emeritierte",
    "Emigranten": "Emigrant",
    "Emils": "Emil",
    "Eminente": "eminent",
    "Eminenten": "Eminente",
    "Eminenzen": "Eminenz",
    "Emirate": "Emirat",
    "Emiraten": "Emirat",
    "Emirats": "Emirat",
    "Emissionen": "Emission",
    "Emmas": "Emma",
    "Emmentalern": "Emmentaler",
    "Emmentalers": "Emmentaler",
    "Emmerichs": "Emmerich",
    "Emotionale": "emotional",
    "Emotionalen": "Emotionale",
    "Emotionaleren": "Emotionalere",
    "Emotionalisierenden": "Emotionalisierende",
    "Emotionalisierenderen": "Emotionalisierendere",
    "Emotionalisierens": "Emotionalisieren",
    "Emotionalisierte": "emotionalisiert",
    "Emotionalisierten": "Emotionalisierte",
    "Emotionalisierteren": "Emotionalisiertere",
    "Emotionalsten": "Emotionalste",
    "Emotionellen": "Emotionelle",
    "Emotionelleren": "Emotionellere",
    "Emotionellsten": "Emotionellste",
    "Emotionen": "Emotion",
    "Emotionsfreie": "emotionsfrei",
    "Emotionsfreien": "Emotionsfreie",
    "Emotionsfreieren": "Emotionsfreiere",
    "Emotionsfreisten": "Emotionsfreiste",
    "Emotionsgeladenen": "Emotionsgeladene",
    "Emotionsgeladeneren": "Emotionsgeladenere",
    "Empfang": "empfangen",
    "Empfange": "empfangen",
    "Empfangenden": "Empfangende",
    "Empfangenen": "Empfangene",
    "Empfangens": "Empfangen",
    "Empfanges": "Empfang",
    "Empfangs": "Empfang",
    "Empfangsantennen": "Empfangsantenne",
    "Empfangsberechtigte": "empfangsberechtigt",
    "Empfangsberechtigten": "Empfangsberechtigte",
    "Empfehlenden": "Empfehlende",
    "Empfehlens": "Empfehlen",
    "Empfehlenswerte": "empfehlenswert",
    "Empfehlenswerten": "Empfehlenswerte",
    "Empfehlenswerteren": "Empfehlenswertere",
    "Empfehlungen": "Empfehlung",
    "Empfindenden": "Empfindende",
    "Empfindenderen": "Empfindendere",
    "Empfindendsten": "Empfindendste",
    "Empfindens": "Empfinden",
    "Empfindlichen": "Empfindliche",
    "Empfindlicheren": "Empfindlichere",
    "Empfindlichkeiten": "Empfindlichkeit",
    "Empfindlichste": "empfindlich",
    "Empfindlichsten": "Empfindlichste",
    "Empfindsamen": "Empfindsame",
    "Empfindsameren": "Empfindsamere",
    "Empfindsamkeiten": "Empfindsamkeit",
    "Empfindsamste": "empfindsam",
    "Empfindsamsten": "Empfindsamste",
    "Empfindungen": "Empfindung",
    "Empfindungsfähige": "empfindungsfähig",
    "Empfindungsfähigen": "Empfindungsfähige",
    "Empfindungsfähigeren": "Empfindungsfähigere",
    "Empfindungslosen": "Empfindungslose",
    "Empfindungsloseren": "Empfindungslosere",
    "Empfohlenen": "Empfohlene",
    "Empfundenen": "Empfundene",
    "Empfänge": "Empfang",
    "Empfängen": "Empfang",
    "Empfängern": "Empfänger",
    "Empfängers": "Empfänger",
    "Empfängnisse": "Empfängnis",
    "Empfängnissen": "Empfängnis",
    "Empfängnisverhütende": "empfängnisverhütend",
    "Empfängnisverhütenden": "Empfängnisverhütende",
    "Emphasen": "Emphase",
    "Empirische": "empirisch",
    "Empirischen": "Empirische",
    "Empirischeren": "Empirischere",
    "Empirischsten": "Empirischste",
    "Emporarbeitenden": "Emporarbeitende",
    "Emporarbeitenderen": "Emporarbeitendere",
    "Emporarbeitens": "Emporarbeiten",
    "Empordringenden": "Empordringende",
    "Empordringens": "Empordringen",
    "Emporfliegenden": "Emporfliegende",
    "Emporfliegens": "Emporfliegen",
    "Emporgearbeiteten": "Emporgearbeitete",
    "Emporgearbeiteteren": "Emporgearbeitetere",
    "Emporgedrungenen": "Emporgedrungene",
    "Emporgeflogenen": "Emporgeflogene",
    "Emporgehobenen": "Emporgehobene",
    "Emporgehobeneren": "Emporgehobenere",
    "Emporgehobensten": "Emporgehobenste",
    "Emporgeholfenen": "Emporgeholfene",
    "Emporgeragten": "Emporgeragte",
    "Emporgerichteten": "Emporgerichtete",
    "Emporgeschauten": "Emporgeschaute",
    "Emporgeschnellten": "Emporgeschnellte",
    "Emporgeschwebten": "Emporgeschwebte",
    "Emporgeschwungenen": "Emporgeschwungene",
    "Emporgesprungenen": "Emporgesprungene",
    "Emporgestiegenen": "Emporgestiegene",
    "Emporgestiegeneren": "Emporgestiegenere",
    "Emporgestrebten": "Emporgestrebte",
    "Emporgestrebteren": "Emporgestrebtere",
    "Emporgewundenen": "Emporgewundene",
    "Emporhebenden": "Emporhebende",
    "Emporhebenderen": "Emporhebendere",
    "Emporhebendsten": "Emporhebendste",
    "Emporhebens": "Emporheben",
    "Emporhelfenden": "Emporhelfende",
    "Emporhelfens": "Emporhelfen",
    "Emporragenden": "Emporragende",
    "Emporragens": "Emporragen",
    "Emporrichtenden": "Emporrichtende",
    "Emporrichtens": "Emporrichten",
    "Emporschauenden": "Emporschauende",
    "Emporschauens": "Emporschauen",
    "Emporschnellenden": "Emporschnellende",
    "Emporschnellens": "Emporschnellen",
    "Emporschwebenden": "Emporschwebende",
    "Emporschwebens": "Emporschweben",
    "Emporschwingenden": "Emporschwingende",
    "Emporschwingens": "Emporschwingen",
    "Emporspringenden": "Emporspringende",
    "Emporspringens": "Emporspringen",
    "Emporsteigenden": "Emporsteigende",
    "Emporsteigenderen": "Emporsteigendere",
    "Emporsteigendsten": "Emporsteigendste",
    "Emporsteigens": "Emporsteigen",
    "Emporstrebenden": "Emporstrebende",
    "Emporstrebenderen": "Emporstrebendere",
    "Emporstrebendsten": "Emporstrebendste",
    "Emporstrebens": "Emporstreben",
    "Emporwindenden": "Emporwindende",
    "Emporwindens": "Emporwinden",
    "Empörenden": "Empörende",
    "Empörenderen": "Empörendere",
    "Empörendsten": "Empörendste",
    "Empörens": "Empören",
    "Empörte": "empört",
    "Empörten": "Empörte",
    "Empörteren": "Empörtere",
    "Empörtesten": "Empörteste",
    "Empörungen": "Empörung",
    "Emsigen": "Emsige",
    "Emsigeren": "Emsigere",
    "Emsigsten": "Emsigste",
    "Emulgatore": "Emulgator",
    "Emulgatoren": "Emulgator",
    "Emulgators": "Emulgator",
    "Emulgierenden": "Emulgierende",
    "Emulgierens": "Emulgieren",
    "Emulgierte": "emulgiert",
    "Emulgierten": "Emulgierte",
    "Emulsionen": "Emulsion",
    "Encodierungen": "Encodierung",
    "Endbahnhofe": "Endbahnhof",
    "Endbahnhofs": "Endbahnhof",
    "Endbahnhöfe": "Endbahnhof",
    "Endbahnhöfen": "Endbahnhof",
    "Endbescheide": "Endbescheid",
    "Endbescheiden": "Endbescheid",
    "Endbescheids": "Endbescheid",
    "Endbestimmungen": "Endbestimmung",
    "Endbuchstaben": "Endbuchstabe",
    "Endchens": "Endchen",
    "Enddarme": "Enddarm",
    "Enddarms": "Enddarm",
    "Enddärme": "Enddarm",
    "Enddärmen": "Enddarm",
    "Ende": "enden",
    "Endeffekte": "Endeffekt",
    "Endeffekten": "Endeffekt",
    "Endeffekts": "Endeffekt",
    "Enden": "Ende",
    "Endenden": "Endende",
    "Endens": "Enden",
    "Endes": "Ende",
    "Endgültigen": "Endgültige",
    "Endkampfe": "Endkampf",
    "Endkampfs": "Endkampf",
    "Endkämpfe": "Endkampf",
    "Endkämpfen": "Endkampf",
    "Endlagern": "Endlager",
    "Endlagers": "Endlager",
    "Endlagerungen": "Endlagerung",
    "Endlaufe": "Endlauf",
    "Endlaufs": "Endlauf",
    "Endliche": "endlich",
    "Endlichen": "Endliche",
    "Endlosen": "Endlose",
    "Endloseren": "Endlosere",
    "Endlosesten": "Endloseste",
    "Endlospapiere": "Endlospapier",
    "Endlospapieren": "Endlospapier",
    "Endlospapiers": "Endlospapier",
    "Endläufe": "Endlauf",
    "Endläufen": "Endlauf",
    "Endlösungen": "Endlösung",
    "Endpunkte": "Endpunkt",
    "Endpunkten": "Endpunkt",
    "Endpunkts": "Endpunkt",
    "Endreime": "Endreim",
    "Endreimen": "Endreim",
    "Endreims": "Endreim",
    "Endrunden": "Endrunde",
    "Endsiege": "Endsieg",
    "Endsiegen": "Endsieg",
    "Endsiegs": "Endsieg",
    "Endsilben": "Endsilbe",
    "Endspiele": "Endspiel",
    "Endspielen": "Endspiel",
    "Endspiels": "Endspiel",
    "Endstationen": "Endstation",
    "Endstücke": "Endstück",
    "Endstücken": "Endstück",
    "Endstücks": "Endstück",
    "Endungen": "Endung",
    "Endurteile": "Endurteil",
    "Endurteilen": "Endurteil",
    "Endurteils": "Endurteil",
    "Endverbrauchern": "Endverbraucher",
    "Endverbrauchers": "Endverbraucher",
    "Endziele": "Endziel",
    "Endzielen": "Endziel",
    "Endziels": "Endziel",
    "Endziffern": "Endziffer",
    "Energien": "Energie",
    "Energiereiche": "energiereich",
    "Energiereichen": "Energiereiche",
    "Energiereicheren": "Energiereichere",
    "Energiereichsten": "Energiereichste",
    "Energischen": "Energische",
    "Energischeren": "Energischere",
    "Energischsten": "Energischste",
    "Engagements": "Engagement",
    "Engagierenden": "Engagierende",
    "Engagierens": "Engagieren",
    "Engagierte": "engagiert",
    "Engagierten": "Engagierte",
    "Engagierteren": "Engagiertere",
    "Engagiertesten": "Engagierteste",
    "Engbrüstigen": "Engbrüstige",
    "Engbrüstigeren": "Engbrüstigere",
    "Engbrüstigsten": "Engbrüstigste",
    "Enge": "engen",
    "Engelchens": "Engelchen",
    "Engelhardts": "Engelhardt",
    "Engeln": "Engel",
    "Engels": "Engel",
    "Engelszungen": "Engelszunge",
    "Engen": "Enge",
    "Engenden": "Engende",
    "Engenderen": "Engendere",
    "Engendsten": "Engendste",
    "Engens": "Engen",
    "Engeren": "Engere",
    "Enggesetzten": "Enggesetzte",
    "Enggesetzteren": "Enggesetztere",
    "Enggesetztesten": "Enggesetzteste",
    "Engherzigen": "Engherzige",
    "Engherzigeren": "Engherzigere",
    "Engherzigsten": "Engherzigste",
    "Engholms": "Engholm",
    "Englands": "England",
    "Engleins": "Englein",
    "Englers": "Engler",
    "Englische": "englisch",
    "Englischen": "Englische",
    "Englischeren": "Englischere",
    "Englischlehrerinnen": "Englischlehrerin",
    "Englischsprachige": "englischsprachig",
    "Englischsprachigen": "Englischsprachige",
    "Englischsten": "Englischste",
    "Engländerinnen": "Engländerin",
    "Engländern": "Engländer",
    "Engländers": "Engländer",
    "Engmaschigen": "Engmaschige",
    "Engmaschigeren": "Engmaschigere",
    "Engmaschigsten": "Engmaschigste",
    "Engsetzenden": "Engsetzende",
    "Engsetzens": "Engsetzen",
    "Engsten": "Engste",
    "Engstirnigen": "Engstirnige",
    "Engstirnigeren": "Engstirnigere",
    "Engstirnigsten": "Engstirnigste",
    "Engzeiligen": "Engzeilige",
    "Engzeiligeren": "Engzeiligere",
    "Engzeiligsten": "Engzeiligste",
    "Enkelinnen": "Enkelin",
    "Enkeln": "Enkel",
    "Enkels": "Enkel",
    "Enkheimern": "Enkheimer",
    "Enkheimers": "Enkheimer",
    "Enkheims": "Enkheim",
    "Enkodierungen": "Enkodierung",
    "Enorme": "enorm",
    "Enormen": "Enorme",
    "Enormeren": "Enormere",
    "Enormsten": "Enormste",
    "Ensembles": "Ensemble",
    "Entalkoholisierenden": "Entalkoholisierende",
    "Entalkoholisierens": "Entalkoholisieren",
    "Entalkoholisierte": "entalkoholisiert",
    "Entalkoholisierten": "Entalkoholisierte",
    "Entartenden": "Entartende",
    "Entartenderen": "Entartendere",
    "Entartendsten": "Entartendste",
    "Entartens": "Entarten",
    "Entartete": "entartet",
    "Entarteten": "Entartete",
    "Entarteteren": "Entartetere",
    "Entartetesten": "Entarteteste",
    "Entartungen": "Entartung",
    "Entautomatisierenden": "Entautomatisierende",
    "Entautomatisierens": "Entautomatisieren",
    "Entautomatisierte": "entautomatisiert",
    "Entautomatisierten": "Entautomatisierte",
    "Entbalkanisierenden": "Entbalkanisierende",
    "Entbalkanisierens": "Entbalkanisieren",
    "Entbalkanisierte": "entbalkanisiert",
    "Entbalkanisierten": "Entbalkanisierte",
    "Entbehrenden": "Entbehrende",
    "Entbehrens": "Entbehren",
    "Entbehrlichen": "Entbehrliche",
    "Entbehrlicheren": "Entbehrlichere",
    "Entbehrlichsten": "Entbehrlichste",
    "Entbehrte": "entbehrt",
    "Entbehrten": "Entbehrte",
    "Entbehrungen": "Entbehrung",
    "Entbindenden": "Entbindende",
    "Entbindens": "Entbinden",
    "Entbindungen": "Entbindung",
    "Entblätternden": "Entblätternde",
    "Entblätterns": "Entblättern",
    "Entblätterte": "entblättert",
    "Entblätterten": "Entblätterte",
    "Entblößenden": "Entblößende",
    "Entblößenderen": "Entblößendere",
    "Entblößendsten": "Entblößendste",
    "Entblößens": "Entblößen",
    "Entblößte": "entblößt",
    "Entblößten": "Entblößte",
    "Entblößteren": "Entblößtere",
    "Entblößtesten": "Entblößteste",
    "Entbrannte": "entbrennen",
    "Entbrannten": "entbrennen",
    "Entbrennenden": "Entbrennende",
    "Entbrennens": "Entbrennen",
    "Entbundenen": "Entbundene",
    "Entbürokratisierenden": "Entbürokratisierende",
    "Entbürokratisierenderen": "Entbürokratisierendere",
    "Entbürokratisierens": "Entbürokratisieren",
    "Entbürokratisierte": "entbürokratisiert",
    "Entbürokratisierten": "Entbürokratisierte",
    "Entbürokratisierteren": "Entbürokratisiertere",
    "Entcarbonisierenden": "Entcarbonisierende",
    "Entcarbonisierenderen": "Entcarbonisierendere",
    "Entcarbonisierens": "Entcarbonisieren",
    "Entcarbonisierte": "entcarbonisiert",
    "Entcarbonisierten": "Entcarbonisierte",
    "Entcarbonisierteren": "Entcarbonisiertere",
    "Entchens": "Entchen",
    "Entdeckenden": "Entdeckende",
    "Entdeckens": "Entdecken",
    "Entdeckern": "Entdecker",
    "Entdeckers": "Entdecker",
    "Entdeckte": "entdeckt",
    "Entdeckten": "Entdeckte",
    "Entdeckungen": "Entdeckung",
    "Entehrenden": "Entehrende",
    "Entehrens": "Entehren",
    "Entehrte": "entehrt",
    "Entehrten": "Entehrte",
    "Entehrteren": "Entehrtere",
    "Entehrtesten": "Entehrteste",
    "Enteignenden": "Enteignende",
    "Enteignens": "Enteignen",
    "Enteignete": "enteignet",
    "Enteigneten": "Enteignete",
    "Enteignungen": "Enteignung",
    "Enteilenden": "Enteilende",
    "Enteilens": "Enteilen",
    "Enteilte": "enteilt",
    "Enteilten": "Enteilte",
    "Enteisenden": "Enteisende",
    "Enteisens": "Enteisen",
    "Enteisente": "enteisent",
    "Enteisenten": "Enteisente",
    "Enteiste": "enteist",
    "Enteisten": "Enteiste",
    "Enten": "Ente",
    "Enterbenden": "Enterbende",
    "Enterbens": "Enterben",
    "Enterbte": "enterbt",
    "Enterbten": "Enterbte",
    "Enterhakens": "Enterhaken",
    "Entfachenden": "Entfachende",
    "Entfachens": "Entfachen",
    "Entfachte": "entfacht",
    "Entfachten": "Entfachte",
    "Entfallenden": "Entfallende",
    "Entfallenen": "Entfallene",
    "Entfalleneren": "Entfallenere",
    "Entfallens": "Entfallen",
    "Entfallenste": "entfallen",
    "Entfallensten": "Entfallenste",
    "Entfaltenden": "Entfaltende",
    "Entfaltens": "Entfalten",
    "Entfaltete": "entfaltet",
    "Entfalteten": "Entfaltete",
    "Entfaltungen": "Entfaltung",
    "Entfernenden": "Entfernende",
    "Entfernens": "Entfernen",
    "Entfernte": "entfernt",
    "Entfernten": "Entfernte",
    "Entfernteren": "Entferntere",
    "Entferntesten": "Entfernteste",
    "Entfernungen": "Entfernung",
    "Entfesselnden": "Entfesselnde",
    "Entfesselnderen": "Entfesselndere",
    "Entfesselndsten": "Entfesselndste",
    "Entfesselns": "Entfesseln",
    "Entfesselte": "entfesselt",
    "Entfesselten": "Entfesselte",
    "Entfesselteren": "Entfesseltere",
    "Entfesseltesten": "Entfesselteste",
    "Entfettenden": "Entfettende",
    "Entfettenderen": "Entfettendere",
    "Entfettendsten": "Entfettendste",
    "Entfettens": "Entfetten",
    "Entfettete": "entfettet",
    "Entfetteten": "Entfettete",
    "Entfetteteren": "Entfettetere",
    "Entfettetesten": "Entfetteteste",
    "Entfilzenden": "Entfilzende",
    "Entfilzenderen": "Entfilzendere",
    "Entfilzendsten": "Entfilzendste",
    "Entfilzens": "Entfilzen",
    "Entfilzte": "entfilzt",
    "Entfilzten": "Entfilzte",
    "Entfilzteren": "Entfilztere",
    "Entfilztesten": "Entfilzteste",
    "Entflaggenden": "Entflaggende",
    "Entflaggenderen": "Entflaggendere",
    "Entflaggendsten": "Entflaggendste",
    "Entflaggens": "Entflaggen",
    "Entflaggte": "entflaggt",
    "Entflaggten": "Entflaggte",
    "Entflaggteren": "Entflaggtere",
    "Entflaggtesten": "Entflaggteste",
    "Entflammenden": "Entflammende",
    "Entflammenderen": "Entflammendere",
    "Entflammendsten": "Entflammendste",
    "Entflammens": "Entflammen",
    "Entflammte": "entflammt",
    "Entflammten": "Entflammte",
    "Entflammteren": "Entflammtere",
    "Entflammtesten": "Entflammteste",
    "Entflatternden": "Entflatternde",
    "Entflatterns": "Entflattern",
    "Entflatterte": "entflattert",
    "Entflatterten": "Entflatterte",
    "Entflechtungen": "Entflechtung",
    "Entfliegenden": "Entfliegende",
    "Entfliegens": "Entfliegen",
    "Entfliehenden": "Entfliehende",
    "Entfliehens": "Entfliehen",
    "Entflogenen": "Entflogene",
    "Entflogeneren": "Entflogenere",
    "Entflogensten": "Entflogenste",
    "Entflohenen": "Entflohene",
    "Entflutschenden": "Entflutschende",
    "Entflutschenderen": "Entflutschendere",
    "Entflutschendsten": "Entflutschendste",
    "Entflutschens": "Entflutschen",
    "Entflutschte": "entflutscht",
    "Entflutschten": "Entflutschte",
    "Entflutschteren": "Entflutschtere",
    "Entflutschtesten": "Entflutschteste",
    "Entformalisierenden": "Entformalisierende",
    "Entformalisierenderen": "Entformalisierendere",
    "Entformalisierens": "Entformalisieren",
    "Entformalisierte": "entformalisiert",
    "Entformalisierten": "Entformalisierte",
    "Entformalisierteren": "Entformalisiertere",
    "Entfrachtenden": "Entfrachtende",
    "Entfrachtenderen": "Entfrachtendere",
    "Entfrachtendsten": "Entfrachtendste",
    "Entfrachtens": "Entfrachten",
    "Entfrachtete": "entfrachtet",
    "Entfrachteten": "Entfrachtete",
    "Entfrachteteren": "Entfrachtetere",
    "Entfrachtetesten": "Entfrachteteste",
    "Entfremdenden": "Entfremdende",
    "Entfremdenderen": "Entfremdendere",
    "Entfremdendsten": "Entfremdendste",
    "Entfremdens": "Entfremden",
    "Entfremdete": "entfremdet",
    "Entfremdeten": "Entfremdete",
    "Entfremdungen": "Entfremdung",
    "Entfrostenden": "Entfrostende",
    "Entfrostens": "Entfrosten",
    "Entfrostern": "Entfroster",
    "Entfrosters": "Entfroster",
    "Entfrostete": "entfrostet",
    "Entfrosteten": "Entfrostete",
    "Entfugenden": "Entfugende",
    "Entfugenderen": "Entfugendere",
    "Entfugendsten": "Entfugendste",
    "Entfugens": "Entfugen",
    "Entfugte": "entfugt",
    "Entfugten": "Entfugte",
    "Entfugteren": "Entfugtere",
    "Entfugtesten": "Entfugteste",
    "Entfärbenden": "Entfärbende",
    "Entfärbenderen": "Entfärbendere",
    "Entfärbendsten": "Entfärbendste",
    "Entfärbens": "Entfärben",
    "Entfärbte": "entfärbt",
    "Entfärbten": "Entfärbte",
    "Entfärbteren": "Entfärbtere",
    "Entfärbtesten": "Entfärbteste",
    "Entführenden": "Entführende",
    "Entführens": "Entführen",
    "Entführte": "entführt",
    "Entführten": "Entführte",
    "Entführungen": "Entführung",
    "Entgangenen": "Entgangene",
    "Entgegenarbeitenden": "Entgegenarbeitende",
    "Entgegenarbeitens": "Entgegenarbeiten",
    "Entgegenbringenden": "Entgegenbringende",
    "Entgegenbringens": "Entgegenbringen",
    "Entgegeneilenden": "Entgegeneilende",
    "Entgegeneilens": "Entgegeneilen",
    "Entgegenfahrenden": "Entgegenfahrende",
    "Entgegenfahrens": "Entgegenfahren",
    "Entgegenfiebernden": "Entgegenfiebernde",
    "Entgegenfieberns": "Entgegenfiebern",
    "Entgegenführenden": "Entgegenführende",
    "Entgegenführens": "Entgegenführen",
    "Entgegengearbeiteten": "Entgegengearbeitete",
    "Entgegengebrachten": "Entgegengebrachte",
    "Entgegengeeilten": "Entgegengeeilte",
    "Entgegengefahrenen": "Entgegengefahrene",
    "Entgegengefieberten": "Entgegengefieberte",
    "Entgegengeführten": "Entgegengeführte",
    "Entgegengehaltenen": "Entgegengehaltene",
    "Entgegengehandelten": "Entgegengehandelte",
    "Entgegengekommenen": "Entgegengekommene",
    "Entgegengelaufenen": "Entgegengelaufene",
    "Entgegengenommenen": "Entgegengenommene",
    "Entgegengeschallten": "Entgegengeschallte",
    "Entgegengesehenen": "Entgegengesehene",
    "Entgegengesetzten": "Entgegengesetzte",
    "Entgegengestandenen": "Entgegengestandene",
    "Entgegengestellten": "Entgegengestellte",
    "Entgegengestürzten": "Entgegengestürzte",
    "Entgegengetragenen": "Entgegengetragene",
    "Entgegengetretenen": "Entgegengetretene",
    "Entgegengetriebenen": "Entgegengetriebene",
    "Entgegengewirkten": "Entgegengewirkte",
    "Entgegenhaltenden": "Entgegenhaltende",
    "Entgegenhaltens": "Entgegenhalten",
    "Entgegenhandelnden": "Entgegenhandelnde",
    "Entgegenhandelns": "Entgegenhandeln",
    "Entgegenkommenden": "Entgegenkommende",
    "Entgegenkommens": "Entgegenkommen",
    "Entgegenlaufenden": "Entgegenlaufende",
    "Entgegenlaufens": "Entgegenlaufen",
    "Entgegennahmen": "entgegennehmen",
    "Entgegennehmenden": "Entgegennehmende",
    "Entgegennehmens": "Entgegennehmen",
    "Entgegenschallenden": "Entgegenschallende",
    "Entgegenschallens": "Entgegenschallen",
    "Entgegensehenden": "Entgegensehende",
    "Entgegensehens": "Entgegensehen",
    "Entgegensetzenden": "Entgegensetzende",
    "Entgegensetzens": "Entgegensetzen",
    "Entgegenstehenden": "Entgegenstehende",
    "Entgegenstehens": "Entgegenstehen",
    "Entgegenstellenden": "Entgegenstellende",
    "Entgegenstellens": "Entgegenstellen",
    "Entgegenstürzenden": "Entgegenstürzende",
    "Entgegenstürzens": "Entgegenstürzen",
    "Entgegentragenden": "Entgegentragende",
    "Entgegentragens": "Entgegentragen",
    "Entgegentreibenden": "Entgegentreibende",
    "Entgegentreibens": "Entgegentreiben",
    "Entgegentretenden": "Entgegentretende",
    "Entgegentretens": "Entgegentreten",
    "Entgegenwirkenden": "Entgegenwirkende",
    "Entgegenwirkens": "Entgegenwirken",
    "Entgegnenden": "Entgegnende",
    "Entgegnens": "Entgegnen",
    "Entgegnete": "entgegnet",
    "Entgegneten": "Entgegnete",
    "Entgegnungen": "Entgegnung",
    "Entgehenden": "Entgehende",
    "Entgehens": "Entgehen",
    "Entgeisterten": "Entgeisterte",
    "Entgeisterteren": "Entgeistertere",
    "Entgeistertesten": "Entgeisterteste",
    "Entgelde": "Entgeld",
    "Entgelder": "Entgeld",
    "Entgeldern": "Entgeld",
    "Entgeldes": "Entgeld",
    "Entgelds": "Entgeld",
    "Entgelte": "Entgelt",
    "Entgelten": "Entgelt",
    "Entgeltliche": "entgeltlich",
    "Entgeltlichen": "Entgeltliche",
    "Entgelts": "Entgelt",
    "Entgiftenden": "Entgiftende",
    "Entgiftens": "Entgiften",
    "Entgiftete": "entgiftet",
    "Entgifteten": "Entgiftete",
    "Entgiftungen": "Entgiftung",
    "Entgleisenden": "Entgleisende",
    "Entgleisens": "Entgleisen",
    "Entgleiste": "entgleist",
    "Entgleisten": "Entgleiste",
    "Entgleitenden": "Entgleitende",
    "Entgleitens": "Entgleiten",
    "Entglittenen": "Entglittene",
    "Entglitteneren": "Entglittenere",
    "Entglittensten": "Entglittenste",
    "Entgrätenden": "Entgrätende",
    "Entgrätenderen": "Entgrätendere",
    "Entgrätendsten": "Entgrätendste",
    "Entgrätens": "Entgräten",
    "Entgrätete": "entgrätet",
    "Entgräteten": "Entgrätete",
    "Entgräteteren": "Entgrätetere",
    "Entgrätetesten": "Entgräteteste",
    "Enthaarenden": "Enthaarende",
    "Enthaarenderen": "Enthaarendere",
    "Enthaarendsten": "Enthaarendste",
    "Enthaarens": "Enthaaren",
    "Enthaarte": "enthaart",
    "Enthaarten": "Enthaarte",
    "Enthaarteren": "Enthaartere",
    "Enthaartesten": "Enthaarteste",
    "Enthaltenden": "Enthaltende",
    "Enthaltenen": "Enthaltene",
    "Enthaltens": "Enthalten",
    "Enthaltsamen": "Enthaltsame",
    "Enthaltsameren": "Enthaltsamere",
    "Enthaltsamsten": "Enthaltsamste",
    "Enthaltungen": "Enthaltung",
    "Enthauptenden": "Enthauptende",
    "Enthauptens": "Enthaupten",
    "Enthauptete": "enthauptet",
    "Enthaupteten": "Enthauptete",
    "Enthauptungen": "Enthauptung",
    "Enthebenden": "Enthebende",
    "Enthebens": "Entheben",
    "Enthebungen": "Enthebung",
    "Enthemmenden": "Enthemmende",
    "Enthemmens": "Enthemmen",
    "Enthemmte": "enthemmt",
    "Enthemmten": "Enthemmte",
    "Enthemmteren": "Enthemmtere",
    "Enthemmtesten": "Enthemmteste",
    "Enthobenen": "Enthobene",
    "Entholzenden": "Entholzende",
    "Entholzens": "Entholzen",
    "Entholzte": "entholzt",
    "Entholzten": "Entholzte",
    "Enthusiasten": "Enthusiast",
    "Enthärtenden": "Enthärtende",
    "Enthärtenderen": "Enthärtendere",
    "Enthärtendsten": "Enthärtendste",
    "Enthärtens": "Enthärten",
    "Enthärtete": "enthärtet",
    "Enthärteten": "Enthärtete",
    "Enthärteteren": "Enthärtetere",
    "Enthärtetesten": "Enthärteteste",
    "Enthäutenden": "Enthäutende",
    "Enthäutens": "Enthäuten",
    "Enthäutete": "enthäutet",
    "Enthäuteten": "Enthäutete",
    "Enthüllenden": "Enthüllende",
    "Enthüllens": "Enthüllen",
    "Enthüllte": "enthüllt",
    "Enthüllten": "Enthüllte",
    "Enthüllteren": "Enthülltere",
    "Enthülltesten": "Enthüllteste",
    "Enthüllungen": "Enthüllung",
    "Entitäten": "Entität",
    "Entjungfernden": "Entjungfernde",
    "Entjungferns": "Entjungfern",
    "Entjungferte": "entjungfert",
    "Entjungferten": "Entjungferte",
    "Entkalkenden": "Entkalkende",
    "Entkalkenderen": "Entkalkendere",
    "Entkalkendsten": "Entkalkendste",
    "Entkalkens": "Entkalken",
    "Entkalkte": "entkalkt",
    "Entkalkten": "Entkalkte",
    "Entkalkteren": "Entkalktere",
    "Entkalktesten": "Entkalkteste",
    "Entkernenden": "Entkernende",
    "Entkernens": "Entkernen",
    "Entkernern": "Entkerner",
    "Entkerners": "Entkerner",
    "Entkernte": "entkernt",
    "Entkernten": "Entkernte",
    "Entkernteren": "Entkerntere",
    "Entkerntesten": "Entkernteste",
    "Entklammernden": "Entklammernde",
    "Entklammernderen": "Entklammerndere",
    "Entklammerndsten": "Entklammerndste",
    "Entklammerns": "Entklammern",
    "Entklammerte": "entklammert",
    "Entklammerten": "Entklammerte",
    "Entklammerteren": "Entklammertere",
    "Entklammertesten": "Entklammerteste",
    "Entkleidenden": "Entkleidende",
    "Entkleidenderen": "Entkleidendere",
    "Entkleidendsten": "Entkleidendste",
    "Entkleidens": "Entkleiden",
    "Entkleidete": "entkleidet",
    "Entkleideten": "Entkleidete",
    "Entkleideteren": "Entkleidetere",
    "Entkleidetesten": "Entkleideteste",
    "Entklumpenden": "Entklumpende",
    "Entklumpenderen": "Entklumpendere",
    "Entklumpendsten": "Entklumpendste",
    "Entklumpens": "Entklumpen",
    "Entklumpte": "entklumpt",
    "Entklumpten": "Entklumpte",
    "Entklumpteren": "Entklumptere",
    "Entklumptesten": "Entklumpteste",
    "Entkolonialisierenden": "Entkolonialisierende",
    "Entkolonialisierens": "Entkolonialisieren",
    "Entkolonialisierte": "entkolonialisiert",
    "Entkolonialisierten": "Entkolonialisierte",
    "Entkommenden": "Entkommende",
    "Entkommenen": "Entkommene",
    "Entkommens": "Entkommen",
    "Entkommerzialisierens": "Entkommerzialisieren",
    "Entkommerzialisierte": "entkommerzialisiert",
    "Entkommerzialisierten": "Entkommerzialisierte",
    "Entkommerzialisierteren": "Entkommerzialisiertere",
    "Entkommunalisierenden": "Entkommunalisierende",
    "Entkommunalisierenderen": "Entkommunalisierendere",
    "Entkommunalisierens": "Entkommunalisieren",
    "Entkommunalisierte": "entkommunalisiert",
    "Entkommunalisierten": "Entkommunalisierte",
    "Entkommunalisierteren": "Entkommunalisiertere",
    "Entkomplizierenden": "Entkomplizierende",
    "Entkomplizierenderen": "Entkomplizierendere",
    "Entkomplizierens": "Entkomplizieren",
    "Entkomplizierte": "entkompliziert",
    "Entkomplizierten": "Entkomplizierte",
    "Entkomplizierteren": "Entkompliziertere",
    "Entkomprimierenden": "Entkomprimierende",
    "Entkomprimierenderen": "Entkomprimierendere",
    "Entkomprimierens": "Entkomprimieren",
    "Entkomprimierte": "entkomprimiert",
    "Entkomprimierten": "Entkomprimierte",
    "Entkomprimierteren": "Entkomprimiertere",
    "Entkoppelnden": "Entkoppelnde",
    "Entkoppelns": "Entkoppeln",
    "Entkoppelte": "entkoppelt",
    "Entkoppelten": "Entkoppelte",
    "Entkorkenden": "Entkorkende",
    "Entkorkens": "Entkorken",
    "Entkorkte": "entkorkt",
    "Entkorkten": "Entkorkte",
    "Entkrampfenden": "Entkrampfende",
    "Entkrampfens": "Entkrampfen",
    "Entkrampfte": "entkrampft",
    "Entkrampften": "Entkrampfte",
    "Entkriminalisierenden": "Entkriminalisierende",
    "Entkriminalisierenderen": "Entkriminalisierendere",
    "Entkriminalisierens": "Entkriminalisieren",
    "Entkriminalisierte": "entkriminalisiert",
    "Entkriminalisierten": "Entkriminalisierte",
    "Entkriminalisierteren": "Entkriminalisiertere",
    "Entkräftenden": "Entkräftende",
    "Entkräftens": "Entkräften",
    "Entkräftete": "entkräftet",
    "Entkräfteten": "Entkräftete",
    "Entkrümelnden": "Entkrümelnde",
    "Entkrümelnderen": "Entkrümelndere",
    "Entkrümelndsten": "Entkrümelndste",
    "Entkrümelns": "Entkrümeln",
    "Entkrümelte": "entkrümelt",
    "Entkrümelten": "Entkrümelte",
    "Entkrümelteren": "Entkrümeltere",
    "Entkrümeltesten": "Entkrümelteste",
    "Entkuppelnden": "Entkuppelnde",
    "Entkuppelns": "Entkuppeln",
    "Entkuppelte": "entkuppelt",
    "Entkuppelten": "Entkuppelte",
    "Entladenden": "Entladende",
    "Entladenen": "Entladene",
    "Entladens": "Entladen",
    "Entlangfahrenden": "Entlangfahrende",
    "Entlangfahrens": "Entlangfahren",
    "Entlanggefahrenen": "Entlanggefahrene",
    "Entlanggegangenen": "Entlanggegangene",
    "Entlanggehenden": "Entlanggehende",
    "Entlanggehens": "Entlanggehen",
    "Entlanggelaufenen": "Entlanggelaufene",
    "Entlanglaufenden": "Entlanglaufende",
    "Entlanglaufens": "Entlanglaufen",
    "Entlarvenden": "Entlarvende",
    "Entlarvens": "Entlarven",
    "Entlarvte": "entlarvt",
    "Entlarvten": "Entlarvte",
    "Entlarvungen": "Entlarvung",
    "Entlassenden": "Entlassende",
    "Entlassenen": "Entlassene",
    "Entlassens": "Entlassen",
    "Entlassungen": "Entlassung",
    "Entlassungsgesuche": "Entlassungsgesuch",
    "Entlassungsgesuchen": "Entlassungsgesuch",
    "Entlassungsgesuchs": "Entlassungsgesuch",
    "Entlastenden": "Entlastende",
    "Entlastens": "Entlasten",
    "Entlastete": "entlastet",
    "Entlasteten": "Entlastete",
    "Entlastungen": "Entlastung",
    "Entlaubungen": "Entlaubung",
    "Entlaufenden": "Entlaufende",
    "Entlaufenen": "Entlaufene",
    "Entlaufens": "Entlaufen",
    "Entlausenden": "Entlausende",
    "Entlausenderen": "Entlausendere",
    "Entlausendsten": "Entlausendste",
    "Entlausens": "Entlausen",
    "Entlauste": "entlaust",
    "Entlausten": "Entlauste",
    "Entlausteren": "Entlaustere",
    "Entlaustesten": "Entlausteste",
    "Entlausungen": "Entlausung",
    "Entledigenden": "Entledigende",
    "Entledigens": "Entledigen",
    "Entledigte": "entledigt",
    "Entledigten": "Entledigte",
    "Entleerenden": "Entleerende",
    "Entleerens": "Entleeren",
    "Entleerte": "entleert",
    "Entleerten": "Entleerte",
    "Entleerteren": "Entleertere",
    "Entleertesten": "Entleerteste",
    "Entlegenen": "Entlegene",
    "Entlegeneren": "Entlegenere",
    "Entlegensten": "Entlegenste",
    "Entleihenden": "Entleihende",
    "Entleihens": "Entleihen",
    "Entliberalisierenden": "Entliberalisierende",
    "Entliberalisierenderen": "Entliberalisierendere",
    "Entliberalisierens": "Entliberalisieren",
    "Entliberalisierte": "entliberalisiert",
    "Entliberalisierten": "Entliberalisierte",
    "Entliberalisierteren": "Entliberalisiertere",
    "Entliehenen": "Entliehene",
    "Entlobenden": "Entlobende",
    "Entlobens": "Entloben",
    "Entlobte": "entlobt",
    "Entlobten": "Entlobte",
    "Entlohnenden": "Entlohnende",
    "Entlohnens": "Entlohnen",
    "Entlohnte": "entlohnt",
    "Entlohnten": "Entlohnte",
    "Entlohnungen": "Entlohnung",
    "Entlüftenden": "Entlüftende",
    "Entlüftenderen": "Entlüftendere",
    "Entlüftendsten": "Entlüftendste",
    "Entlüftens": "Entlüften",
    "Entlüftete": "entlüftet",
    "Entlüfteten": "Entlüftete",
    "Entlüfteteren": "Entlüftetere",
    "Entlüftetesten": "Entlüfteteste",
    "Entmachtenden": "Entmachtende",
    "Entmachtens": "Entmachten",
    "Entmachtete": "entmachtet",
    "Entmachteten": "Entmachtete",
    "Entmetallisierenden": "Entmetallisierende",
    "Entmetallisierenderen": "Entmetallisierendere",
    "Entmetallisierens": "Entmetallisieren",
    "Entmetallisierte": "entmetallisiert",
    "Entmetallisierten": "Entmetallisierte",
    "Entmetallisierteren": "Entmetallisiertere",
    "Entmiefenden": "Entmiefende",
    "Entmiefenderen": "Entmiefendere",
    "Entmiefendsten": "Entmiefendste",
    "Entmiefens": "Entmiefen",
    "Entmiefte": "entmieft",
    "Entmieften": "Entmiefte",
    "Entmiefteren": "Entmieftere",
    "Entmieftesten": "Entmiefteste",
    "Entmilitarisierenden": "Entmilitarisierende",
    "Entmilitarisierens": "Entmilitarisieren",
    "Entmilitarisierte": "entmilitarisiert",
    "Entmilitarisierten": "Entmilitarisierte",
    "Entmistenden": "Entmistende",
    "Entmistenderen": "Entmistendere",
    "Entmistendsten": "Entmistendste",
    "Entmistens": "Entmisten",
    "Entmistete": "entmistet",
    "Entmisteten": "Entmistete",
    "Entmisteteren": "Entmistetere",
    "Entmistetesten": "Entmisteteste",
    "Entmistungsanlagen": "Entmistungsanlage",
    "Entmonopolisierenden": "Entmonopolisierende",
    "Entmonopolisierenderen": "Entmonopolisierendere",
    "Entmonopolisierens": "Entmonopolisieren",
    "Entmonopolisierte": "entmonopolisiert",
    "Entmonopolisierten": "Entmonopolisierte",
    "Entmonopolisierteren": "Entmonopolisiertere",
    "Entmutigenden": "Entmutigende",
    "Entmutigenderen": "Entmutigendere",
    "Entmutigendsten": "Entmutigendste",
    "Entmutigens": "Entmutigen",
    "Entmutigte": "entmutigt",
    "Entmutigten": "Entmutigte",
    "Entmutigteren": "Entmutigtere",
    "Entmutigtesten": "Entmutigteste",
    "Entmystifizierenden": "Entmystifizierende",
    "Entmystifizierenderen": "Entmystifizierendere",
    "Entmystifizierens": "Entmystifizieren",
    "Entmystifizierte": "entmystifiziert",
    "Entmystifizierten": "Entmystifizierte",
    "Entmystifizierteren": "Entmystifiziertere",
    "Entmündigenden": "Entmündigende",
    "Entmündigenderen": "Entmündigendere",
    "Entmündigendsten": "Entmündigendste",
    "Entmündigens": "Entmündigen",
    "Entmündigte": "entmündigt",
    "Entmündigten": "Entmündigte",
    "Entmündigteren": "Entmündigtere",
    "Entmündigtesten": "Entmündigteste",
    "Entmündigungen": "Entmündigung",
    "Entnahmen": "entnehmen",
    "Entnaturalisierenden": "Entnaturalisierende",
    "Entnaturalisierens": "Entnaturalisieren",
    "Entnaturalisierte": "entnaturalisiert",
    "Entnaturalisierten": "Entnaturalisierte",
    "Entnazifizierenden": "Entnazifizierende",
    "Entnazifizierens": "Entnazifizieren",
    "Entnazifizierte": "entnazifiziert",
    "Entnazifizierten": "Entnazifizierte",
    "Entnazifizierteren": "Entnazifiziertere",
    "Entnazifizierungen": "Entnazifizierung",
    "Entnehmenden": "Entnehmende",
    "Entnehmens": "Entnehmen",
    "Entnervenden": "Entnervende",
    "Entnervenderen": "Entnervendere",
    "Entnervendsten": "Entnervendste",
    "Entnervens": "Entnerven",
    "Entnervte": "entnervt",
    "Entnervten": "Entnervte",
    "Entnervteren": "Entnervtere",
    "Entnervtesten": "Entnervteste",
    "Entnommenen": "Entnommene",
    "Entnässenden": "Entnässende",
    "Entnässens": "Entnässen",
    "Entnäßte": "entnäßt",
    "Entnäßten": "Entnäßte",
    "Entomologen": "Entomologe",
    "Entomologische": "entomologisch",
    "Entomologischen": "Entomologische",
    "Entpackenden": "Entpackende",
    "Entpackens": "Entpacken",
    "Entpackte": "entpackt",
    "Entpackten": "Entpackte",
    "Entpellenden": "Entpellende",
    "Entpellenderen": "Entpellendere",
    "Entpellendsten": "Entpellendste",
    "Entpellens": "Entpellen",
    "Entpellte": "entpellt",
    "Entpellten": "Entpellte",
    "Entpellteren": "Entpelltere",
    "Entpelltesten": "Entpellteste",
    "Entpolitisierenden": "Entpolitisierende",
    "Entpolitisierenderen": "Entpolitisierendere",
    "Entpolitisierens": "Entpolitisieren",
    "Entpolitisierte": "entpolitisiert",
    "Entpolitisierten": "Entpolitisierte",
    "Entpolitisierteren": "Entpolitisiertere",
    "Entpudernden": "Entpudernde",
    "Entpudernderen": "Entpuderndere",
    "Entpuderndsten": "Entpuderndste",
    "Entpuderns": "Entpudern",
    "Entpuderte": "entpudert",
    "Entpuderten": "Entpuderte",
    "Entpuderteren": "Entpudertere",
    "Entpudertesten": "Entpuderteste",
    "Entpuppenden": "Entpuppende",
    "Entpuppens": "Entpuppen",
    "Entpuppte": "entpuppt",
    "Entpuppten": "Entpuppte",
    "Entrahmern": "Entrahmer",
    "Entrahmers": "Entrahmer",
    "Entrauschenden": "Entrauschende",
    "Entrauschens": "Entrauschen",
    "Entrauschte": "entrauscht",
    "Entrauschten": "Entrauschte",
    "Entreißenden": "Entreißende",
    "Entreißens": "Entreißen",
    "Entrichtenden": "Entrichtende",
    "Entrichtens": "Entrichten",
    "Entrichtete": "entrichtet",
    "Entrichteten": "Entrichtete",
    "Entrichtungen": "Entrichtung",
    "Entriegelnden": "Entriegelnde",
    "Entriegelnderen": "Entriegelndere",
    "Entriegelndsten": "Entriegelndste",
    "Entriegelns": "Entriegeln",
    "Entriegelte": "entriegelt",
    "Entriegelten": "Entriegelte",
    "Entriegelteren": "Entriegeltere",
    "Entriegeltesten": "Entriegelteste",
    "Entrinnenden": "Entrinnende",
    "Entrinnens": "Entrinnen",
    "Entrissenen": "Entrissene",
    "Entronnenen": "Entronnene",
    "Entronneneren": "Entronnenere",
    "Entronnensten": "Entronnenste",
    "Entropien": "Entropie",
    "Entrostenden": "Entrostende",
    "Entrostenderen": "Entrostendere",
    "Entrostendsten": "Entrostendste",
    "Entrostens": "Entrosten",
    "Entrostete": "entrostet",
    "Entrosteten": "Entrostete",
    "Entrosteteren": "Entrostetere",
    "Entrostetesten": "Entrosteteste",
    "Enträtselnden": "Enträtselnde",
    "Enträtselns": "Enträtseln",
    "Enträtselte": "enträtselt",
    "Enträtselten": "Enträtselte",
    "Entrückenden": "Entrückende",
    "Entrückens": "Entrücken",
    "Entrückte": "entrückt",
    "Entrückten": "Entrückte",
    "Entrümpelnden": "Entrümpelnde",
    "Entrümpelnderen": "Entrümpelndere",
    "Entrümpelndsten": "Entrümpelndste",
    "Entrümpelns": "Entrümpeln",
    "Entrümpelte": "entrümpelt",
    "Entrümpelten": "Entrümpelte",
    "Entrümpelteren": "Entrümpeltere",
    "Entrümpeltesten": "Entrümpelteste",
    "Entrümpelungen": "Entrümpelung",
    "Entrüstenden": "Entrüstende",
    "Entrüstens": "Entrüsten",
    "Entrüstete": "entrüstet",
    "Entrüsteten": "Entrüstete",
    "Entrüsteteren": "Entrüstetere",
    "Entrüstetesten": "Entrüsteteste",
    "Entsaftenden": "Entsaftende",
    "Entsaftens": "Entsaften",
    "Entsaftern": "Entsafter",
    "Entsafters": "Entsafter",
    "Entsaftete": "entsaftet",
    "Entsafteten": "Entsaftete",
    "Entsagenden": "Entsagende",
    "Entsagens": "Entsagen",
    "Entsagte": "entsagt",
    "Entsagten": "Entsagte",
    "Entsagungsvollen": "Entsagungsvolle",
    "Entsagungsvolleren": "Entsagungsvollere",
    "Entsandte": "entsenden",
    "Entsandten": "entsenden",
    "Entscheid": "entscheiden",
    "Entscheide": "entscheiden",
    "Entscheiden": "Entscheid",
    "Entscheidenden": "Entscheidende",
    "Entscheidenderen": "Entscheidendere",
    "Entscheidendsten": "Entscheidendste",
    "Entscheidens": "Entscheiden",
    "Entscheides": "Entscheid",
    "Entscheids": "Entscheid",
    "Entscheidungen": "Entscheidung",
    "Entscheidungsstunden": "Entscheidungsstunde",
    "Entschiedenen": "Entschiedene",
    "Entschiedeneren": "Entschiedenere",
    "Entschiedensten": "Entschiedenste",
    "Entschlafenden": "Entschlafende",
    "Entschlafenen": "Entschlafene",
    "Entschlafens": "Entschlafen",
    "Entschleichenden": "Entschleichende",
    "Entschleichens": "Entschleichen",
    "Entschleimenden": "Entschleimende",
    "Entschleimenderen": "Entschleimendere",
    "Entschleimendsten": "Entschleimendste",
    "Entschleimens": "Entschleimen",
    "Entschleimte": "entschleimt",
    "Entschleimten": "Entschleimte",
    "Entschleimteren": "Entschleimtere",
    "Entschleimtesten": "Entschleimteste",
    "Entschlichenen": "Entschlichene",
    "Entschließenden": "Entschließende",
    "Entschließens": "Entschließen",
    "Entschlossenen": "Entschlossene",
    "Entschlosseneren": "Entschlossenere",
    "Entschlossensten": "Entschlossenste",
    "Entschlummernden": "Entschlummernde",
    "Entschlummerns": "Entschlummern",
    "Entschlummerte": "entschlummert",
    "Entschlummerten": "Entschlummerte",
    "Entschlusse": "Entschluß",
    "Entschlusses": "Entschluß",
    "Entschlüpfenden": "Entschlüpfende",
    "Entschlüpfens": "Entschlüpfen",
    "Entschlüpfte": "entschlüpft",
    "Entschlüpften": "Entschlüpfte",
    "Entschlüsse": "Entschluß",
    "Entschlüsselnden": "Entschlüsselnde",
    "Entschlüsselns": "Entschlüsseln",
    "Entschlüsselte": "entschlüsselt",
    "Entschlüsselten": "Entschlüsselte",
    "Entschlüssen": "Entschluß",
    "Entschuldbaren": "Entschuldbare",
    "Entschuldenden": "Entschuldende",
    "Entschuldenderen": "Entschuldendere",
    "Entschuldendsten": "Entschuldendste",
    "Entschuldens": "Entschulden",
    "Entschuldete": "entschuldet",
    "Entschuldeten": "Entschuldete",
    "Entschuldeteren": "Entschuldetere",
    "Entschuldetesten": "Entschuldeteste",
    "Entschuldigenden": "Entschuldigende",
    "Entschuldigens": "Entschuldigen",
    "Entschuldigte": "entschuldigt",
    "Entschuldigten": "Entschuldigte",
    "Entschuldigungen": "Entschuldigung",
    "Entschwindenden": "Entschwindende",
    "Entschwindens": "Entschwinden",
    "Entschwirrenden": "Entschwirrende",
    "Entschwirrens": "Entschwirren",
    "Entschwirrte": "entschwirrt",
    "Entschwirrten": "Entschwirrte",
    "Entschwundenen": "Entschwundene",
    "Entschädigenden": "Entschädigende",
    "Entschädigens": "Entschädigen",
    "Entschädigte": "entschädigt",
    "Entschädigten": "Entschädigte",
    "Entschädigteren": "Entschädigtere",
    "Entschädigtesten": "Entschädigteste",
    "Entschädigungen": "Entschädigung",
    "Entschädigungssummen": "Entschädigungssumme",
    "Entschärfenden": "Entschärfende",
    "Entschärfens": "Entschärfen",
    "Entschärfte": "entschärft",
    "Entschärften": "Entschärfte",
    "Entsendenden": "Entsendende",
    "Entsendens": "Entsenden",
    "Entsendete": "entsendet",
    "Entsendeten": "Entsendete",
    "Entsetzens": "Entsetzen",
    "Entsetzliche": "entsetzlich",
    "Entsetzlichen": "Entsetzliche",
    "Entsetzlicheren": "Entsetzlichere",
    "Entsetzlichsten": "Entsetzlichste",
    "Entsetzten": "Entsetzte",
    "Entseuchenden": "Entseuchende",
    "Entseuchenderen": "Entseuchendere",
    "Entseuchendsten": "Entseuchendste",
    "Entseuchens": "Entseuchen",
    "Entseuchte": "entseucht",
    "Entseuchten": "Entseuchte",
    "Entseuchteren": "Entseuchtere",
    "Entseuchtesten": "Entseuchteste",
    "Entsichernden": "Entsichernde",
    "Entsicherns": "Entsichern",
    "Entsicherte": "entsichert",
    "Entsicherten": "Entsicherte",
    "Entsinkenden": "Entsinkende",
    "Entsinkenderen": "Entsinkendere",
    "Entsinkendsten": "Entsinkendste",
    "Entsinkens": "Entsinken",
    "Entsinnenden": "Entsinnende",
    "Entsinnens": "Entsinnen",
    "Entsonnenen": "Entsonnene",
    "Entsorgenden": "Entsorgende",
    "Entsorgens": "Entsorgen",
    "Entsorgte": "entsorgt",
    "Entsorgten": "Entsorgte",
    "Entsorgungen": "Entsorgung",
    "Entspannenden": "Entspannende",
    "Entspannenderen": "Entspannendere",
    "Entspannendsten": "Entspannendste",
    "Entspannens": "Entspannen",
    "Entspannnungen": "Entspannnung",
    "Entspannte": "entspannt",
    "Entspannten": "Entspannte",
    "Entspannteren": "Entspanntere",
    "Entspanntesten": "Entspannteste",
    "Entspiegelnden": "Entspiegelnde",
    "Entspiegelnderen": "Entspiegelndere",
    "Entspiegelndsten": "Entspiegelndste",
    "Entspiegelns": "Entspiegeln",
    "Entspiegelte": "entspiegelt",
    "Entspiegelten": "Entspiegelte",
    "Entspiegelteren": "Entspiegeltere",
    "Entspiegeltesten": "Entspiegelteste",
    "Entsprechenden": "Entsprechende",
    "Entsprechenderen": "Entsprechendere",
    "Entsprechendsten": "Entsprechendste",
    "Entsprechens": "Entsprechen",
    "Entsprechungen": "Entsprechung",
    "Entspringenden": "Entspringende",
    "Entspringens": "Entspringen",
    "Entsprochenen": "Entsprochene",
    "Entsprocheneren": "Entsprochenere",
    "Entsprochensten": "Entsprochenste",
    "Entsprungenen": "Entsprungene",
    "Entstachelnden": "Entstachelnde",
    "Entstachelns": "Entstacheln",
    "Entstachelte": "entstachelt",
    "Entstachelten": "Entstachelte",
    "Entstammenden": "Entstammende",
    "Entstammens": "Entstammen",
    "Entstammte": "entstammt",
    "Entstammten": "Entstammte",
    "Entstandenen": "Entstandene",
    "Entstaubenden": "Entstaubende",
    "Entstaubenderen": "Entstaubendere",
    "Entstaubendsten": "Entstaubendste",
    "Entstaubens": "Entstauben",
    "Entstaubte": "entstaubt",
    "Entstaubten": "Entstaubte",
    "Entstaubteren": "Entstaubtere",
    "Entstaubtesten": "Entstaubteste",
    "Entstehenden": "Entstehende",
    "Entstehens": "Entstehen",
    "Entstehungen": "Entstehung",
    "Entsteigenden": "Entsteigende",
    "Entsteigens": "Entsteigen",
    "Entsteinenden": "Entsteinende",
    "Entsteinens": "Entsteinen",
    "Entsteinte": "entsteint",
    "Entsteinten": "Entsteinte",
    "Entstellenden": "Entstellende",
    "Entstellens": "Entstellen",
    "Entstellte": "entstellt",
    "Entstellten": "Entstellte",
    "Entstellteren": "Entstelltere",
    "Entstelltesten": "Entstellteste",
    "Entstellungen": "Entstellung",
    "Entstiegenen": "Entstiegene",
    "Entströmenden": "Entströmende",
    "Entströmens": "Entströmen",
    "Entströmte": "entströmt",
    "Entströmten": "Entströmte",
    "Entstörenden": "Entstörende",
    "Entstörens": "Entstören",
    "Entstörte": "entstört",
    "Entstörten": "Entstörte",
    "Entstörteren": "Entstörtere",
    "Entstörtesten": "Entstörteste",
    "Entsunkenen": "Entsunkene",
    "Entsunkeneren": "Entsunkenere",
    "Entsunkensten": "Entsunkenste",
    "Enttabuierenden": "Enttabuierende",
    "Enttabuierenderen": "Enttabuierendere",
    "Enttabuierendsten": "Enttabuierendste",
    "Enttabuierens": "Enttabuieren",
    "Enttabuierte": "enttabuiert",
    "Enttabuierten": "Enttabuierte",
    "Enttabuierteren": "Enttabuiertere",
    "Enttabuiertesten": "Enttabuierteste",
    "Enttarnenden": "Enttarnende",
    "Enttarnenderen": "Enttarnendere",
    "Enttarnendsten": "Enttarnendste",
    "Enttarnens": "Enttarnen",
    "Enttarnte": "enttarnt",
    "Enttarnten": "Enttarnte",
    "Enttarnteren": "Enttarntere",
    "Enttarntesten": "Enttarnteste",
    "Enttarnungen": "Enttarnung",
    "Enttechnisierenden": "Enttechnisierende",
    "Enttechnisierenderen": "Enttechnisierendere",
    "Enttechnisierens": "Enttechnisieren",
    "Enttechnisierte": "enttechnisiert",
    "Enttechnisierten": "Enttechnisierte",
    "Enttechnisierteren": "Enttechnisiertere",
    "Entthronenden": "Entthronende",
    "Entthronens": "Entthronen",
    "Entthronte": "entthront",
    "Entthronten": "Entthronte",
    "Entthronungen": "Entthronung",
    "Enttäuschenden": "Enttäuschende",
    "Enttäuschenderen": "Enttäuschendere",
    "Enttäuschendsten": "Enttäuschendste",
    "Enttäuschens": "Enttäuschen",
    "Enttäuschte": "enttäuscht",
    "Enttäuschten": "Enttäuschte",
    "Enttäuschteren": "Enttäuschtere",
    "Enttäuschtesten": "Enttäuschteste",
    "Enttäuschungen": "Enttäuschung",
    "Entwaffnenden": "Entwaffnende",
    "Entwaffnens": "Entwaffnen",
    "Entwaffnete": "entwaffnet",
    "Entwaffneten": "Entwaffnete",
    "Entwandte": "entwenden",
    "Entwandten": "entwenden",
    "Entwarnenden": "Entwarnende",
    "Entwarnens": "Entwarnen",
    "Entwarnte": "entwarnt",
    "Entwarnten": "Entwarnte",
    "Entwarnungen": "Entwarnung",
    "Entweichenden": "Entweichende",
    "Entweichens": "Entweichen",
    "Entwendenden": "Entwendende",
    "Entwendens": "Entwenden",
    "Entwendete": "entwendet",
    "Entwendeten": "Entwendete",
    "Entwendungen": "Entwendung",
    "Entwerfenden": "Entwerfende",
    "Entwerfens": "Entwerfen",
    "Entwertenden": "Entwertende",
    "Entwertens": "Entwerten",
    "Entwertete": "entwertet",
    "Entwerteten": "Entwertete",
    "Entwertungen": "Entwertung",
    "Entwichenen": "Entwichene",
    "Entwickelnden": "Entwickelnde",
    "Entwickelns": "Entwickeln",
    "Entwickelte": "entwickelt",
    "Entwickelten": "Entwickelte",
    "Entwickelteren": "Entwickeltere",
    "Entwickeltesten": "Entwickelteste",
    "Entwicklern": "Entwickler",
    "Entwicklers": "Entwickler",
    "Entwicklungen": "Entwicklung",
    "Entwicklungsfähige": "entwicklungsfähig",
    "Entwicklungsfähigen": "Entwicklungsfähige",
    "Entwicklungsfähigeren": "Entwicklungsfähigere",
    "Entwirrenden": "Entwirrende",
    "Entwirrenderen": "Entwirrendere",
    "Entwirrendsten": "Entwirrendste",
    "Entwirrens": "Entwirren",
    "Entwirrte": "entwirrt",
    "Entwirrten": "Entwirrte",
    "Entwirrteren": "Entwirrtere",
    "Entwirrtesten": "Entwirrteste",
    "Entwischenden": "Entwischende",
    "Entwischens": "Entwischen",
    "Entwischte": "entwischt",
    "Entwischten": "Entwischte",
    "Entworfenen": "Entworfene",
    "Entwurfe": "Entwurf",
    "Entwurfes": "Entwurf",
    "Entwurfs": "Entwurf",
    "Entwurzelnden": "Entwurzelnde",
    "Entwurzelns": "Entwurzeln",
    "Entwurzelte": "entwurzelt",
    "Entwurzelten": "Entwurzelte",
    "Entwurzelungen": "Entwurzelung",
    "Entwöhnenden": "Entwöhnende",
    "Entwöhnenderen": "Entwöhnendere",
    "Entwöhnendsten": "Entwöhnendste",
    "Entwöhnens": "Entwöhnen",
    "Entwöhnte": "entwöhnt",
    "Entwöhnten": "Entwöhnte",
    "Entwöhnteren": "Entwöhntere",
    "Entwöhntesten": "Entwöhnteste",
    "Entwürdigenden": "Entwürdigende",
    "Entwürdigenderen": "Entwürdigendere",
    "Entwürdigendsten": "Entwürdigendste",
    "Entwürfe": "Entwurf",
    "Entwürfen": "Entwurf",
    "Entzaubernden": "Entzaubernde",
    "Entzaubernderen": "Entzauberndere",
    "Entzauberndsten": "Entzauberndste",
    "Entzauberns": "Entzaubern",
    "Entzauberte": "entzaubert",
    "Entzauberten": "Entzauberte",
    "Entzauberteren": "Entzaubertere",
    "Entzaubertesten": "Entzauberteste",
    "Entzerrenden": "Entzerrende",
    "Entzerrenderen": "Entzerrendere",
    "Entzerrendsten": "Entzerrendste",
    "Entzerrens": "Entzerren",
    "Entzerrern": "Entzerrer",
    "Entzerrers": "Entzerrer",
    "Entzerrte": "entzerrt",
    "Entzerrten": "Entzerrte",
    "Entzerrteren": "Entzerrtere",
    "Entzerrtesten": "Entzerrteste",
    "Entziehenden": "Entziehende",
    "Entziehens": "Entziehen",
    "Entzifferbaren": "Entzifferbare",
    "Entzifferbareren": "Entzifferbarere",
    "Entzifferbarsten": "Entzifferbarste",
    "Entziffernden": "Entziffernde",
    "Entzifferns": "Entziffern",
    "Entzifferte": "entziffert",
    "Entzifferten": "Entzifferte",
    "Entzogenen": "Entzogene",
    "Entzugs": "Entzug",
    "Entzweibeißenden": "Entzweibeißende",
    "Entzweibeißens": "Entzweibeißen",
    "Entzweibrechenden": "Entzweibrechende",
    "Entzweibrechens": "Entzweibrechen",
    "Entzweigebissenen": "Entzweigebissene",
    "Entzweigebrochenen": "Entzweigebrochene",
    "Entzweigehauchten": "Entzweigehauchte",
    "Entzweigehauenen": "Entzweigehauene",
    "Entzweigemachten": "Entzweigemachte",
    "Entzweigerissenen": "Entzweigerissene",
    "Entzweigerisseneren": "Entzweigerissenere",
    "Entzweigeschlagenen": "Entzweigeschlagene",
    "Entzweigeschlageneren": "Entzweigeschlagenere",
    "Entzweigeschnittenen": "Entzweigeschnittene",
    "Entzweihauchenden": "Entzweihauchende",
    "Entzweihauchens": "Entzweihauchen",
    "Entzweihauenden": "Entzweihauende",
    "Entzweihauens": "Entzweihauen",
    "Entzweimachenden": "Entzweimachende",
    "Entzweimachens": "Entzweimachen",
    "Entzweireißenden": "Entzweireißende",
    "Entzweireißenderen": "Entzweireißendere",
    "Entzweireißens": "Entzweireißen",
    "Entzweischlagenden": "Entzweischlagende",
    "Entzweischlagenderen": "Entzweischlagendere",
    "Entzweischlagens": "Entzweischlagen",
    "Entzweischneidenden": "Entzweischneidende",
    "Entzweischneidens": "Entzweischneiden",
    "Entzückenden": "Entzückende",
    "Entzückenderen": "Entzückendere",
    "Entzückendsten": "Entzückendste",
    "Entzündbare": "entzündbar",
    "Entzündbaren": "Entzündbare",
    "Entzündbareren": "Entzündbarere",
    "Entzündbarsten": "Entzündbarste",
    "Entzündenden": "Entzündende",
    "Entzündens": "Entzünden",
    "Entzündete": "entzündet",
    "Entzündeten": "Entzündete",
    "Entzündlichen": "Entzündliche",
    "Entzündlicheren": "Entzündlichere",
    "Entzündlichsten": "Entzündlichste",
    "Entzündungen": "Entzündung",
    "Enumerationen": "Enumeration",
    "Enunziationen": "Enunziation",
    "Enziane": "Enzian",
    "Enzianen": "Enzian",
    "Enzians": "Enzian",
    "Enzyklopädien": "Enzyklopädie",
    "Enzyme": "Enzym",
    "Enzymen": "Enzym",
    "Enzyms": "Enzym",
    "Epidemien": "Epidemie",
    "Epidemiologische": "epidemiologisch",
    "Epidemiologischen": "Epidemiologische",
    "Epigramme": "Epigramm",
    "Epigrammen": "Epigramm",
    "Epigramms": "Epigramm",
    "Epikern": "Epiker",
    "Epikers": "Epiker",
    "Epilepsien": "Epilepsie",
    "Epileptikern": "Epileptiker",
    "Epileptikers": "Epileptiker",
    "Epileptische": "epileptisch",
    "Epileptischen": "Epileptische",
    "Epiloge": "Epilog",
    "Epilogen": "Epilog",
    "Epiloges": "Epilog",
    "Epilogs": "Epilog",
    "Epiphysen": "Epiphyse",
    "Episoden": "Episode",
    "Epithesen": "Epithese",
    "Epitomatore": "Epitomator",
    "Epitomatoren": "Epitomator",
    "Epitomators": "Epitomator",
    "Epochen": "Epoche",
    "Eppelmanns": "Eppelmann",
    "Eppsteins": "Eppstein",
    "Epsilons": "Epsilon",
    "Equipen": "Equipe",
    "Erachtenden": "Erachtende",
    "Erachtens": "Erachten",
    "Erachtete": "erachtet",
    "Erachteten": "Erachtete",
    "Erahnenden": "Erahnende",
    "Erahnens": "Erahnen",
    "Erahnte": "erahnt",
    "Erahnten": "Erahnte",
    "Erarbeitenden": "Erarbeitende",
    "Erarbeitens": "Erarbeiten",
    "Erarbeitete": "erarbeitet",
    "Erarbeiteten": "Erarbeitete",
    "Erarbeitungen": "Erarbeitung",
    "Erbadeln": "Erbadel",
    "Erbadels": "Erbadel",
    "Erbanlagen": "Erbanlage",
    "Erbarmenden": "Erbarmende",
    "Erbarmens": "Erbarmen",
    "Erbarmenswerte": "erbarmenswert",
    "Erbarmenswerten": "Erbarmenswerte",
    "Erbarmenswerteren": "Erbarmenswertere",
    "Erbarmte": "erbarmt",
    "Erbarmten": "Erbarmte",
    "Erbarmungslosen": "Erbarmungslose",
    "Erbarmungsloseren": "Erbarmungslosere",
    "Erbarmungsvollen": "Erbarmungsvolle",
    "Erbarmungsvolleren": "Erbarmungsvollere",
    "Erbauenden": "Erbauende",
    "Erbauens": "Erbauen",
    "Erbauern": "Erbauer",
    "Erbauers": "Erbauer",
    "Erbaulichen": "Erbauliche",
    "Erbaulicheren": "Erbaulichere",
    "Erbaulichsten": "Erbaulichste",
    "Erbaute": "erbaut",
    "Erbauten": "Erbaute",
    "Erbberechtigten": "Erbberechtigte",
    "Erbebenden": "Erbebende",
    "Erbebenderen": "Erbebendere",
    "Erbebendsten": "Erbebendste",
    "Erbebens": "Erbeben",
    "Erbebte": "erbebt",
    "Erbebten": "Erbebte",
    "Erbeigentums": "Erbeigentum",
    "Erben": "Erbe",
    "Erbenden": "Erbende",
    "Erbens": "Erben",
    "Erbes": "Erbe",
    "Erbetenden": "Erbetende",
    "Erbetenen": "Erbetene",
    "Erbetens": "Erbeten",
    "Erbetete": "erbetet",
    "Erbeteten": "Erbetete",
    "Erbettelnden": "Erbettelnde",
    "Erbettelns": "Erbetteln",
    "Erbettelte": "erbettelt",
    "Erbettelten": "Erbettelte",
    "Erbeutenden": "Erbeutende",
    "Erbeutens": "Erbeuten",
    "Erbeutete": "erbeutet",
    "Erbeuteten": "Erbeutete",
    "Erbfaktore": "Erbfaktor",
    "Erbfaktoren": "Erbfaktor",
    "Erbfaktors": "Erbfaktor",
    "Erbfolgern": "Erbfolger",
    "Erbfolgers": "Erbfolger",
    "Erbgangs": "Erbgang",
    "Erbhofe": "Erbhof",
    "Erbhofs": "Erbhof",
    "Erbhöfe": "Erbhof",
    "Erbhöfen": "Erbhof",
    "Erbinnen": "Erbin",
    "Erbittenden": "Erbittende",
    "Erbittens": "Erbitten",
    "Erblassenden": "Erblassende",
    "Erblassenderen": "Erblassendere",
    "Erblassendsten": "Erblassendste",
    "Erblassens": "Erblassen",
    "Erblassern": "Erblasser",
    "Erblassers": "Erblasser",
    "Erblaßte": "erblaßt",
    "Erblaßten": "Erblaßte",
    "Erblaßteren": "Erblaßtere",
    "Erblaßtesten": "Erblaßteste",
    "Erblehens": "Erblehen",
    "Erbleichenden": "Erbleichende",
    "Erbleichenderen": "Erbleichendere",
    "Erbleichendsten": "Erbleichendste",
    "Erbleichens": "Erbleichen",
    "Erblichenen": "Erblichene",
    "Erblicheneren": "Erblichenere",
    "Erblichensten": "Erblichenste",
    "Erblickenden": "Erblickende",
    "Erblickens": "Erblicken",
    "Erblickte": "erblickt",
    "Erblickten": "Erblickte",
    "Erblindenden": "Erblindende",
    "Erblindens": "Erblinden",
    "Erblindete": "erblindet",
    "Erblindeten": "Erblindete",
    "Erblühenden": "Erblühende",
    "Erblühenderen": "Erblühendere",
    "Erblühendsten": "Erblühendste",
    "Erblühens": "Erblühen",
    "Erblühte": "erblüht",
    "Erblühten": "Erblühte",
    "Erbmassen": "Erbmasse",
    "Erbonkeln": "Erbonkel",
    "Erbonkels": "Erbonkel",
    "Erbpächtern": "Erbpächter",
    "Erbpächters": "Erbpächter",
    "Erbrachte": "erbringen",
    "Erbrachten": "erbringen",
    "Erbrechenden": "Erbrechende",
    "Erbrechens": "Erbrechen",
    "Erbrechte": "Erbrecht",
    "Erbrechten": "Erbrecht",
    "Erbrechts": "Erbrecht",
    "Erbringenden": "Erbringende",
    "Erbringens": "Erbringen",
    "Erbrochenen": "Erbrochene",
    "Erbschadens": "Erbschaden",
    "Erbschaften": "Erbschaft",
    "Erbschaftsmassen": "Erbschaftsmasse",
    "Erbschleichern": "Erbschleicher",
    "Erbschleichers": "Erbschleicher",
    "Erbschäden": "Erbschaden",
    "Erbsen": "Erbse",
    "Erbteile": "Erbteil",
    "Erbteilen": "Erbteil",
    "Erbteiles": "Erbteil",
    "Erbteils": "Erbteil",
    "Erbärmlichen": "Erbärmliche",
    "Erbärmlicheren": "Erbärmlichere",
    "Erbärmlichsten": "Erbärmlichste",
    "Ercans": "Ercan",
    "Erdachte": "erdenken",
    "Erdachten": "erdenken",
    "Erdarbeiten": "Erdarbeit",
    "Erdbebens": "Erdbeben",
    "Erdbebenwarten": "Erdbebenwarte",
    "Erdbeeren": "Erdbeere",
    "Erde": "erden",
    "Erden": "Erde",
    "Erdenden": "Erdende",
    "Erdenkenden": "Erdenkende",
    "Erdenkens": "Erdenken",
    "Erdenklichen": "Erdenkliche",
    "Erdens": "Erden",
    "Erderbsen": "Erderbse",
    "Erdfarbenen": "Erdfarbene",
    "Erdgase": "Erdgas",
    "Erdgasen": "Erdgas",
    "Erdgases": "Erdgas",
    "Erdgeschossen": "Erdgeschoße",
    "Erdgeschosses": "Erdgeschoße",
    "Erdichtungen": "Erdichtung",
    "Erdige": "erdig",
    "Erdigen": "Erdige",
    "Erdkarten": "Erdkarte",
    "Erdkröten": "Erdkröte",
    "Erdkundlern": "Erdkundler",
    "Erdkundlers": "Erdkundler",
    "Erdnüsse": "Erdnuß",
    "Erdnüssen": "Erdnuß",
    "Erdolchenden": "Erdolchende",
    "Erdolchens": "Erdolchen",
    "Erdolchte": "erdolcht",
    "Erdolchten": "Erdolchte",
    "Erdpyramiden": "Erdpyramide",
    "Erdreiche": "Erdreich",
    "Erdreichen": "Erdreich",
    "Erdreiches": "Erdreich",
    "Erdreichs": "Erdreich",
    "Erdreistenden": "Erdreistende",
    "Erdreistens": "Erdreisten",
    "Erdreistete": "erdreistet",
    "Erdreisteten": "Erdreistete",
    "Erdreisteteren": "Erdreistetere",
    "Erdreistetesten": "Erdreisteteste",
    "Erdrosselnden": "Erdrosselnde",
    "Erdrosselns": "Erdrosseln",
    "Erdrosselte": "erdrosselt",
    "Erdrosselten": "Erdrosselte",
    "Erdrutschartigen": "Erdrutschartige",
    "Erdteile": "Erdteil",
    "Erdteilen": "Erdteil",
    "Erdteils": "Erdteil",
    "Erduldenden": "Erduldende",
    "Erduldenderen": "Erduldendere",
    "Erduldendsten": "Erduldendste",
    "Erduldens": "Erdulden",
    "Erduldete": "erduldet",
    "Erduldeten": "Erduldete",
    "Erduldeteren": "Erduldetere",
    "Erduldetesten": "Erduldeteste",
    "Erdumseglern": "Erdumsegler",
    "Erdumseglers": "Erdumsegler",
    "Erdumspannende": "erdumspannend",
    "Erdumspannenden": "Erdumspannende",
    "Erdungen": "Erdung",
    "Erdverbundene": "erdverbunden",
    "Erdverbundenen": "Erdverbundene",
    "Erdverbundeneren": "Erdverbundenere",
    "Erdverbundensten": "Erdverbundenste",
    "Erdöle": "Erdöl",
    "Erdölen": "Erdöl",
    "Erdöls": "Erdöl",
    "Ereifernden": "Ereifernde",
    "Ereifernderen": "Ereiferndere",
    "Ereiferndsten": "Ereiferndste",
    "Ereiferns": "Ereifern",
    "Ereiferte": "ereifert",
    "Ereiferten": "Ereiferte",
    "Ereiferteren": "Ereifertere",
    "Ereifertesten": "Ereiferteste",
    "Ereignenden": "Ereignende",
    "Ereignens": "Ereignen",
    "Ereignete": "ereignet",
    "Ereigneten": "Ereignete",
    "Ereignislosen": "Ereignislose",
    "Ereignisloseren": "Ereignislosere",
    "Ereignislosesten": "Ereignisloseste",
    "Ereignisreichen": "Ereignisreiche",
    "Ereignisreicheren": "Ereignisreichere",
    "Ereignisreichsten": "Ereignisreichste",
    "Ereignisse": "Ereignis",
    "Ereignissen": "Ereignis",
    "Ereignisses": "Ereignis",
    "Ereilenden": "Ereilende",
    "Ereilens": "Ereilen",
    "Ereilte": "ereilt",
    "Ereilten": "Ereilte",
    "Erektionen": "Erektion",
    "Eremiten": "Eremit",
    "Erfahrenden": "Erfahrende",
    "Erfahrenen": "Erfahrene",
    "Erfahreneren": "Erfahrenere",
    "Erfahrens": "Erfahren",
    "Erfahrenste": "erfahren",
    "Erfahrensten": "Erfahrenste",
    "Erfahrungen": "Erfahrung",
    "Erfahrungsgemäße": "erfahrungsgemäß",
    "Erfahrungsgemäßen": "Erfahrungsgemäße",
    "Erfassenden": "Erfassende",
    "Erfassens": "Erfassen",
    "Erfassungen": "Erfassung",
    "Erfaßte": "erfaßt",
    "Erfaßten": "Erfaßte",
    "Erfindenden": "Erfindende",
    "Erfindenderen": "Erfindendere",
    "Erfindendsten": "Erfindendste",
    "Erfindens": "Erfinden",
    "Erfinderische": "erfinderisch",
    "Erfinderischen": "Erfinderische",
    "Erfinderischeren": "Erfinderischere",
    "Erfinderischsten": "Erfinderischste",
    "Erfindern": "Erfinder",
    "Erfinders": "Erfinder",
    "Erfindungen": "Erfindung",
    "Erfindungsreiche": "erfindungsreich",
    "Erfindungsreichen": "Erfindungsreiche",
    "Erfindungsreicheren": "Erfindungsreichere",
    "Erfolg": "erfolgen",
    "Erfolge": "erfolgen",
    "Erfolgen": "Erfolg",
    "Erfolgenden": "Erfolgende",
    "Erfolgens": "Erfolgen",
    "Erfolges": "Erfolg",
    "Erfolglosen": "Erfolglose",
    "Erfolgloseren": "Erfolglosere",
    "Erfolglosesten": "Erfolgloseste",
    "Erfolgreichen": "Erfolgreiche",
    "Erfolgreicheren": "Erfolgreichere",
    "Erfolgreichsten": "Erfolgreichste",
    "Erfolgs": "Erfolg",
    "Erfolgssichere": "erfolgssicher",
    "Erfolgssicheren": "Erfolgssichere",
    "Erfolgsverwöhnten": "Erfolgsverwöhnte",
    "Erfolgsverwöhnteren": "Erfolgsverwöhntere",
    "Erfolgte": "erfolgt",
    "Erfolgten": "Erfolgte",
    "Erfolgversprechenden": "Erfolgversprechende",
    "Erfolgversprechenderen": "Erfolgversprechendere",
    "Erforderlichen": "Erforderliche",
    "Erfordernden": "Erfordernde",
    "Erfordernisse": "Erfordernis",
    "Erfordernissen": "Erfordernis",
    "Erfordernisses": "Erfordernis",
    "Erforderns": "Erfordern",
    "Erforderte": "erfordert",
    "Erforderten": "Erforderte",
    "Erforschenden": "Erforschende",
    "Erforschenderen": "Erforschendere",
    "Erforschendsten": "Erforschendste",
    "Erforschens": "Erforschen",
    "Erforschte": "erforscht",
    "Erforschten": "Erforschte",
    "Erforschteren": "Erforschtere",
    "Erforschtesten": "Erforschteste",
    "Erforschungen": "Erforschung",
    "Erfragenden": "Erfragende",
    "Erfragens": "Erfragen",
    "Erfragte": "erfragt",
    "Erfragten": "Erfragte",
    "Erfreuenden": "Erfreuende",
    "Erfreuenderen": "Erfreuendere",
    "Erfreuendsten": "Erfreuendste",
    "Erfreuens": "Erfreuen",
    "Erfreulichen": "Erfreuliche",
    "Erfreulicheren": "Erfreulichere",
    "Erfreulichsten": "Erfreulichste",
    "Erfreute": "erfreut",
    "Erfreuten": "Erfreute",
    "Erfreuteren": "Erfreutere",
    "Erfreutesten": "Erfreuteste",
    "Erfrischenden": "Erfrischende",
    "Erfrischenderen": "Erfrischendere",
    "Erfrischendsten": "Erfrischendste",
    "Erfrischens": "Erfrischen",
    "Erfrischte": "erfrischt",
    "Erfrischten": "Erfrischte",
    "Erfrischteren": "Erfrischtere",
    "Erfrischtesten": "Erfrischteste",
    "Erfundenen": "Erfundene",
    "Erfurts": "Erfurt",
    "Erfüllenden": "Erfüllende",
    "Erfüllens": "Erfüllen",
    "Erfüllte": "erfüllt",
    "Erfüllten": "Erfüllte",
    "Erfüllteren": "Erfülltere",
    "Erfülltesten": "Erfüllteste",
    "Erfüllungen": "Erfüllung",
    "Ergaunernden": "Ergaunernde",
    "Ergaunerns": "Ergaunern",
    "Ergaunerte": "ergaunert",
    "Ergaunerten": "Ergaunerte",
    "Ergebenden": "Ergebende",
    "Ergebenderen": "Ergebendere",
    "Ergebendsten": "Ergebendste",
    "Ergebenen": "Ergebene",
    "Ergebeneren": "Ergebenere",
    "Ergebens": "Ergeben",
    "Ergebenste": "ergeben",
    "Ergebensten": "Ergebenste",
    "Ergebnislosen": "Ergebnislose",
    "Ergebnisloseren": "Ergebnislosere",
    "Ergebnislosesten": "Ergebnisloseste",
    "Ergebnisse": "Ergebnis",
    "Ergebnissen": "Ergebnis",
    "Ergebnisses": "Ergebnis",
    "Ergiebigen": "Ergiebige",
    "Ergiebigeren": "Ergiebigere",
    "Ergiebigsten": "Ergiebigste",
    "Ergießenden": "Ergießende",
    "Ergießens": "Ergießen",
    "Ergonomischen": "Ergonomische",
    "Ergonomischeren": "Ergonomischere",
    "Ergonomischsten": "Ergonomischste",
    "Ergossenen": "Ergossene",
    "Ergreifenden": "Ergreifende",
    "Ergreifens": "Ergreifen",
    "Ergreifungen": "Ergreifung",
    "Ergriffenen": "Ergriffene",
    "Ergriffeneren": "Ergriffenere",
    "Ergriffensten": "Ergriffenste",
    "Ergründenden": "Ergründende",
    "Ergründens": "Ergründen",
    "Ergründete": "ergründet",
    "Ergründeten": "Ergründete",
    "Ergänzenden": "Ergänzende",
    "Ergänzens": "Ergänzen",
    "Ergänzte": "ergänzt",
    "Ergänzten": "Ergänzte",
    "Ergänzungen": "Ergänzung",
    "Ergänzungswinkeln": "Ergänzungswinkel",
    "Ergänzungswinkels": "Ergänzungswinkel",
    "Erhallenden": "Erhallende",
    "Erhallenderen": "Erhallendere",
    "Erhallendsten": "Erhallendste",
    "Erhallens": "Erhallen",
    "Erhallte": "erhallt",
    "Erhallten": "Erhallte",
    "Erhallteren": "Erhalltere",
    "Erhalltesten": "Erhallteste",
    "Erhalt": "erhalten",
    "Erhaltenden": "Erhaltende",
    "Erhaltenen": "Erhaltene",
    "Erhalteneren": "Erhaltenere",
    "Erhaltens": "Erhalten",
    "Erhaltenste": "erhalten",
    "Erhaltensten": "Erhaltenste",
    "Erhaltern": "Erhalter",
    "Erhalters": "Erhalter",
    "Erhalts": "Erhalt",
    "Erhaltungen": "Erhaltung",
    "Erhards": "Erhard",
    "Erhaschenden": "Erhaschende",
    "Erhaschens": "Erhaschen",
    "Erhaschte": "erhascht",
    "Erhaschten": "Erhaschte",
    "Erhebenden": "Erhebende",
    "Erhebens": "Erheben",
    "Erheblichen": "Erhebliche",
    "Erheblicheren": "Erheblichere",
    "Erheblichsten": "Erheblichste",
    "Erhebungen": "Erhebung",
    "Erheiternden": "Erheiternde",
    "Erheiternderen": "Erheiterndere",
    "Erheiterndsten": "Erheiterndste",
    "Erheiterns": "Erheitern",
    "Erheiterte": "erheitert",
    "Erheiterten": "Erheiterte",
    "Erheiterteren": "Erheitertere",
    "Erheitertesten": "Erheiterteste",
    "Erhellenden": "Erhellende",
    "Erhellenderen": "Erhellendere",
    "Erhellendsten": "Erhellendste",
    "Erhellens": "Erhellen",
    "Erhellte": "erhellt",
    "Erhellten": "Erhellte",
    "Erhellteren": "Erhelltere",
    "Erhelltesten": "Erhellteste",
    "Erhitzenden": "Erhitzende",
    "Erhitzenderen": "Erhitzendere",
    "Erhitzendsten": "Erhitzendste",
    "Erhitzens": "Erhitzen",
    "Erhitzte": "erhitzt",
    "Erhitzten": "Erhitzte",
    "Erhitzteren": "Erhitztere",
    "Erhitztesten": "Erhitzteste",
    "Erhobenen": "Erhobene",
    "Erhobeneren": "Erhobenere",
    "Erhobensten": "Erhobenste",
    "Erhoffenden": "Erhoffende",
    "Erhoffens": "Erhoffen",
    "Erhoffte": "erhofft",
    "Erhofften": "Erhoffte",
    "Erholenden": "Erholende",
    "Erholens": "Erholen",
    "Erholsamen": "Erholsame",
    "Erholsameren": "Erholsamere",
    "Erholsamsten": "Erholsamste",
    "Erholte": "erholt",
    "Erholten": "Erholte",
    "Erholteren": "Erholtere",
    "Erholtesten": "Erholteste",
    "Erholungsbedürftigen": "Erholungsbedürftige",
    "Erholungsbedürftigeren": "Erholungsbedürftigere",
    "Erhältlichen": "Erhältliche",
    "Erhängenden": "Erhängende",
    "Erhängens": "Erhängen",
    "Erhängte": "erhängt",
    "Erhängten": "Erhängte",
    "Erhärtenden": "Erhärtende",
    "Erhärtenderen": "Erhärtendere",
    "Erhärtendsten": "Erhärtendste",
    "Erhärtens": "Erhärten",
    "Erhärtete": "erhärtet",
    "Erhärteten": "Erhärtete",
    "Erhärteteren": "Erhärtetere",
    "Erhärtetesten": "Erhärteteste",
    "Erhärtungen": "Erhärtung",
    "Erhöhenden": "Erhöhende",
    "Erhöhens": "Erhöhen",
    "Erhöhte": "erhöht",
    "Erhöhten": "Erhöhte",
    "Erhöhungen": "Erhöhung",
    "Erhörenden": "Erhörende",
    "Erhörens": "Erhören",
    "Erhörte": "erhört",
    "Erhörten": "Erhörte",
    "Erichs": "Erich",
    "Erics": "Eric",
    "Erikas": "Erika",
    "Erinnernden": "Erinnernde",
    "Erinnerns": "Erinnern",
    "Erinnerte": "erinnert",
    "Erinnerten": "Erinnerte",
    "Erinnerungen": "Erinnerung",
    "Erkaltenden": "Erkaltende",
    "Erkaltenderen": "Erkaltendere",
    "Erkaltendsten": "Erkaltendste",
    "Erkaltens": "Erkalten",
    "Erkaltete": "erkaltet",
    "Erkalteten": "Erkaltete",
    "Erkalteteren": "Erkaltetere",
    "Erkaltetesten": "Erkalteteste",
    "Erkannte": "erkennen",
    "Erkannten": "erkennen",
    "Erkennbaren": "Erkennbare",
    "Erkennbareren": "Erkennbarere",
    "Erkennbarsten": "Erkennbarste",
    "Erkennenden": "Erkennende",
    "Erkennens": "Erkennen",
    "Erkenntnisse": "Erkenntnis",
    "Erkenntnissen": "Erkenntnis",
    "Erkennungen": "Erkennung",
    "Erkiesenden": "Erkiesende",
    "Erkiesens": "Erkiesen",
    "Erklimmenden": "Erklimmende",
    "Erklimmenderen": "Erklimmendere",
    "Erklimmendsten": "Erklimmendste",
    "Erklimmens": "Erklimmen",
    "Erklingenden": "Erklingende",
    "Erklingens": "Erklingen",
    "Erklommenen": "Erklommene",
    "Erklommeneren": "Erklommenere",
    "Erklommensten": "Erklommenste",
    "Erklungenen": "Erklungene",
    "Erklärbaren": "Erklärbare",
    "Erklärenden": "Erklärende",
    "Erklärens": "Erklären",
    "Erklärlichen": "Erklärliche",
    "Erklärte": "erklärt",
    "Erklärten": "Erklärte",
    "Erklärungen": "Erklärung",
    "Erkorenen": "Erkorene",
    "Erkoreneren": "Erkorenere",
    "Erkorensten": "Erkorenste",
    "Erkrankenden": "Erkrankende",
    "Erkrankenderen": "Erkrankendere",
    "Erkrankendsten": "Erkrankendste",
    "Erkrankens": "Erkranken",
    "Erkrankte": "erkrankt",
    "Erkrankten": "Erkrankte",
    "Erkrankteren": "Erkranktere",
    "Erkranktesten": "Erkrankteste",
    "Erkrankungen": "Erkrankung",
    "Erkundenden": "Erkundende",
    "Erkundens": "Erkunden",
    "Erkundete": "erkundet",
    "Erkundeten": "Erkundete",
    "Erkundeteren": "Erkundetere",
    "Erkundetesten": "Erkundeteste",
    "Erkundigenden": "Erkundigende",
    "Erkundigens": "Erkundigen",
    "Erkundigte": "erkundigt",
    "Erkundigten": "Erkundigte",
    "Erkältende": "erkältend",
    "Erkältenden": "Erkältende",
    "Erkältens": "Erkälten",
    "Erkältete": "erkältet",
    "Erkälteten": "Erkältete",
    "Erkältungen": "Erkältung",
    "Erkämpfenden": "Erkämpfende",
    "Erkämpfens": "Erkämpfen",
    "Erkämpfte": "erkämpft",
    "Erkämpften": "Erkämpfte",
    "Erlahmenden": "Erlahmende",
    "Erlahmenderen": "Erlahmendere",
    "Erlahmendsten": "Erlahmendste",
    "Erlahmens": "Erlahmen",
    "Erlahmte": "erlahmt",
    "Erlahmten": "Erlahmte",
    "Erlangenden": "Erlangende",
    "Erlangens": "Erlangen",
    "Erlangte": "erlangt",
    "Erlangten": "Erlangte",
    "Erlassenden": "Erlassende",
    "Erlassenen": "Erlassene",
    "Erlassens": "Erlassen",
    "Erlaubenden": "Erlaubende",
    "Erlaubens": "Erlauben",
    "Erlaubnisse": "Erlaubnis",
    "Erlaubnissen": "Erlaubnis",
    "Erlaubte": "erlaubt",
    "Erlaubten": "Erlaubte",
    "Erlauchten": "Erlauchte",
    "Erlaufenden": "Erlaufende",
    "Erlaufenen": "Erlaufene",
    "Erlaufens": "Erlaufen",
    "Erlebenden": "Erlebende",
    "Erlebens": "Erleben",
    "Erlebnisse": "Erlebnis",
    "Erlebnissen": "Erlebnis",
    "Erlebnisses": "Erlebnis",
    "Erlebte": "erlebt",
    "Erlebten": "Erlebte",
    "Erledigenden": "Erledigende",
    "Erledigens": "Erledigen",
    "Erledigte": "erledigt",
    "Erledigten": "Erledigte",
    "Erlegenden": "Erlegende",
    "Erlegenen": "Erlegene",
    "Erlegens": "Erlegen",
    "Erlegte": "erlegt",
    "Erlegten": "Erlegte",
    "Erleichternden": "Erleichternde",
    "Erleichternderen": "Erleichterndere",
    "Erleichterndsten": "Erleichterndste",
    "Erleichterns": "Erleichtern",
    "Erleichterte": "erleichtert",
    "Erleichterten": "Erleichterte",
    "Erleichterteren": "Erleichtertere",
    "Erleichtertesten": "Erleichterteste",
    "Erleichterungen": "Erleichterung",
    "Erleidenden": "Erleidende",
    "Erleidens": "Erleiden",
    "Erlen": "Erle",
    "Erlenbachs": "Erlenbach",
    "Erlensees": "Erlensee",
    "Erlernbare": "erlernbar",
    "Erlernbaren": "Erlernbare",
    "Erlernenden": "Erlernende",
    "Erlernens": "Erlernen",
    "Erlernte": "erlernt",
    "Erlernten": "Erlernte",
    "Erlesenen": "Erlesene",
    "Erleseneren": "Erlesenere",
    "Erlesensten": "Erlesenste",
    "Erliegenden": "Erliegende",
    "Erliegens": "Erliegen",
    "Erlittenen": "Erlittene",
    "Erloschenen": "Erloschene",
    "Erloscheneren": "Erloschenere",
    "Erloschenste": "erloschen",
    "Erloschensten": "Erloschenste",
    "Erläuternden": "Erläuternde",
    "Erläuterns": "Erläutern",
    "Erläuterte": "erläutert",
    "Erläuterten": "Erläuterte",
    "Erläuterteren": "Erläutertere",
    "Erläutertesten": "Erläuterteste",
    "Erläuterungen": "Erläuterung",
    "Erlös": "erlösen",
    "Erlöschenden": "Erlöschende",
    "Erlöschens": "Erlöschen",
    "Erlöse": "erlösen",
    "Erlösen": "Erlös",
    "Erlösenden": "Erlösende",
    "Erlösenderen": "Erlösendere",
    "Erlösendsten": "Erlösendste",
    "Erlösens": "Erlösen",
    "Erlösern": "Erlöser",
    "Erlösers": "Erlöser",
    "Erlöses": "Erlös",
    "Erlöste": "erlöst",
    "Erlösten": "Erlöste",
    "Ermahnenden": "Ermahnende",
    "Ermahnenderen": "Ermahnendere",
    "Ermahnendsten": "Ermahnendste",
    "Ermahnens": "Ermahnen",
    "Ermahnte": "ermahnt",
    "Ermahnten": "Ermahnte",
    "Ermahnungen": "Ermahnung",
    "Ermattenden": "Ermattende",
    "Ermattenderen": "Ermattendere",
    "Ermattendsten": "Ermattendste",
    "Ermattens": "Ermatten",
    "Ermattete": "ermattet",
    "Ermatteten": "Ermattete",
    "Ermatteteren": "Ermattetere",
    "Ermattetesten": "Ermatteteste",
    "Ermessensfragen": "Ermessensfrage",
    "Ermittelnden": "Ermittelnde",
    "Ermittelns": "Ermitteln",
    "Ermittelte": "ermittelt",
    "Ermittelten": "Ermittelte",
    "Ermittlern": "Ermittler",
    "Ermittlers": "Ermittler",
    "Ermittlungen": "Ermittlung",
    "Ermordenden": "Ermordende",
    "Ermordens": "Ermorden",
    "Ermordete": "ermordet",
    "Ermordeten": "Ermordete",
    "Ermordungen": "Ermordung",
    "Ermunterungen": "Ermunterung",
    "Ermutigenden": "Ermutigende",
    "Ermutigenderen": "Ermutigendere",
    "Ermutigendsten": "Ermutigendste",
    "Ermutigens": "Ermutigen",
    "Ermutigte": "ermutigt",
    "Ermutigten": "Ermutigte",
    "Ermutigteren": "Ermutigtere",
    "Ermutigtesten": "Ermutigteste",
    "Ermutigungen": "Ermutigung",
    "Ermächtigenden": "Ermächtigende",
    "Ermächtigens": "Ermächtigen",
    "Ermächtigte": "ermächtigt",
    "Ermächtigten": "Ermächtigte",
    "Ermöglichenden": "Ermöglichende",
    "Ermöglichens": "Ermöglichen",
    "Ermöglichte": "ermöglicht",
    "Ermöglichten": "Ermöglichte",
    "Ermüdenden": "Ermüdende",
    "Ermüdenderen": "Ermüdendere",
    "Ermüdendsten": "Ermüdendste",
    "Ermüdens": "Ermüden",
    "Ermüdete": "ermüdet",
    "Ermüdeten": "Ermüdete",
    "Ernannte": "ernennen",
    "Ernannten": "ernennen",
    "Ernennenden": "Ernennende",
    "Ernennens": "Ernennen",
    "Ernennungen": "Ernennung",
    "Erneuerern": "Erneuerer",
    "Erneuerers": "Erneuerer",
    "Erneuernden": "Erneuernde",
    "Erneuerns": "Erneuern",
    "Erneuerte": "erneuert",
    "Erneuerten": "Erneuerte",
    "Erneuerteren": "Erneuertere",
    "Erneuertesten": "Erneuerteste",
    "Erneuerungen": "Erneuerung",
    "Erneute": "erneut",
    "Erneuten": "Erneute",
    "Erniedrigenden": "Erniedrigende",
    "Erniedrigenderen": "Erniedrigendere",
    "Erniedrigendsten": "Erniedrigendste",
    "Erniedrigens": "Erniedrigen",
    "Erniedrigte": "erniedrigt",
    "Erniedrigten": "Erniedrigte",
    "Erniedrigteren": "Erniedrigtere",
    "Erniedrigtesten": "Erniedrigteste",
    "Ernsten": "Ernste",
    "Ernsteren": "Ernstere",
    "Ernsteste": "ernst",
    "Ernstesten": "Ernsteste",
    "Ernstgemeinten": "Ernstgemeinte",
    "Ernsthaften": "Ernsthafte",
    "Ernsthafteren": "Ernsthaftere",
    "Ernsthaftesten": "Ernsthafteste",
    "Ernstlichen": "Ernstliche",
    "Ernstlicheren": "Ernstlichere",
    "Ernstlichsten": "Ernstlichste",
    "Ernsts": "Ernst",
    "Ernte": "ernten",
    "Erntedankfeste": "Erntedankfest",
    "Erntedankfesten": "Erntedankfest",
    "Erntedankfests": "Erntedankfest",
    "Ernten": "Ernte",
    "Erntenden": "Erntende",
    "Erntens": "Ernten",
    "Ernährenden": "Ernährende",
    "Ernährens": "Ernähren",
    "Ernährern": "Ernährer",
    "Ernährers": "Ernährer",
    "Ernährte": "ernährt",
    "Ernährten": "Ernährte",
    "Ernährungen": "Ernährung",
    "Erobernden": "Erobernde",
    "Eroberns": "Erobern",
    "Eroberte": "erobert",
    "Eroberten": "Eroberte",
    "Eroberungen": "Eroberung",
    "Erogene": "erogen",
    "Erogenen": "Erogene",
    "Erosionen": "Erosion",
    "Erotische": "erotisch",
    "Erotischen": "Erotische",
    "Erotischeren": "Erotischere",
    "Erotischsten": "Erotischste",
    "Erotisierenden": "Erotisierende",
    "Erotisierenderen": "Erotisierendere",
    "Erotisierendsten": "Erotisierendste",
    "Erotisierens": "Erotisieren",
    "Erotisierte": "erotisiert",
    "Erotisierten": "Erotisierte",
    "Erotisierteren": "Erotisiertere",
    "Erotisiertesten": "Erotisierteste",
    "Erpichenden": "Erpichende",
    "Erpichenderen": "Erpichendere",
    "Erpichendsten": "Erpichendste",
    "Erpichens": "Erpichen",
    "Erpichte": "erpicht",
    "Erpichten": "Erpichte",
    "Erpichteren": "Erpichtere",
    "Erpichtesten": "Erpichteste",
    "Erpressenden": "Erpressende",
    "Erpressens": "Erpressen",
    "Erpresserische": "erpresserisch",
    "Erpresserischen": "Erpresserische",
    "Erpressungen": "Erpressung",
    "Erpreßte": "erpreßt",
    "Erpreßten": "Erpreßte",
    "Erprobenden": "Erprobende",
    "Erprobens": "Erproben",
    "Erprobte": "erprobt",
    "Erprobten": "Erprobte",
    "Erprobteren": "Erprobtere",
    "Erprobtesten": "Erprobteste",
    "Erprobungen": "Erprobung",
    "Erquickliche": "erquicklich",
    "Erquicklichen": "Erquickliche",
    "Erquicklicheren": "Erquicklichere",
    "Erquicklichsten": "Erquicklichste",
    "Erratenden": "Erratende",
    "Erratenen": "Erratene",
    "Erratens": "Erraten",
    "Errechnenden": "Errechnende",
    "Errechnens": "Errechnen",
    "Errechnete": "errechnet",
    "Errechneten": "Errechnete",
    "Erregbaren": "Erregbare",
    "Erregbareren": "Erregbarere",
    "Erregbarsten": "Erregbarste",
    "Erregenden": "Erregende",
    "Erregenderen": "Erregendere",
    "Erregendsten": "Erregendste",
    "Erregens": "Erregen",
    "Erregern": "Erreger",
    "Erregers": "Erreger",
    "Erregte": "erregt",
    "Erregten": "Erregte",
    "Erregteren": "Erregtere",
    "Erregtesten": "Erregteste",
    "Erregungen": "Erregung",
    "Erreichbare": "erreichbar",
    "Erreichbaren": "Erreichbare",
    "Erreichbareren": "Erreichbarere",
    "Erreichbarsten": "Erreichbarste",
    "Erreichenden": "Erreichende",
    "Erreichens": "Erreichen",
    "Erreichte": "erreicht",
    "Erreichten": "Erreichte",
    "Errettungen": "Errettung",
    "Errichtenden": "Errichtende",
    "Errichtens": "Errichten",
    "Errichtete": "errichtet",
    "Errichteten": "Errichtete",
    "Errichtungen": "Errichtung",
    "Erringenden": "Erringende",
    "Erringens": "Erringen",
    "Errungenen": "Errungene",
    "Errungenschaften": "Errungenschaft",
    "Errötenden": "Errötende",
    "Errötenderen": "Errötendere",
    "Errötendsten": "Errötendste",
    "Errötens": "Erröten",
    "Errötete": "errötet",
    "Erröteten": "Errötete",
    "Erröteteren": "Errötetere",
    "Errötetesten": "Erröteteste",
    "Ersatze": "Ersatz",
    "Ersatzes": "Ersatz",
    "Ersatzlose": "ersatzlos",
    "Ersatzlosen": "Ersatzlose",
    "Ersatzmanne": "Ersatzmann",
    "Ersatzmannes": "Ersatzmann",
    "Ersatzmanns": "Ersatzmann",
    "Ersatzmänner": "Ersatzmann",
    "Ersatzmännern": "Ersatzmann",
    "Ersatzpflichtige": "ersatzpflichtig",
    "Ersatzpflichtigen": "Ersatzpflichtige",
    "Ersaufenden": "Ersaufende",
    "Ersaufens": "Ersaufen",
    "Erschaffenden": "Erschaffende",
    "Erschaffenen": "Erschaffene",
    "Erschaffens": "Erschaffen",
    "Erschafften": "Erschaffte",
    "Erschaffungen": "Erschaffung",
    "Erschallenden": "Erschallende",
    "Erschallens": "Erschallen",
    "Erschallte": "erschallt",
    "Erschallten": "Erschallte",
    "Erscheinenden": "Erscheinende",
    "Erscheinens": "Erscheinen",
    "Erscheinigungen": "Erscheinigung",
    "Erscheinungen": "Erscheinung",
    "Erschienenen": "Erschienene",
    "Erschießenden": "Erschießende",
    "Erschießens": "Erschießen",
    "Erschlaffenden": "Erschlaffende",
    "Erschlaffenderen": "Erschlaffendere",
    "Erschlaffendsten": "Erschlaffendste",
    "Erschlaffens": "Erschlaffen",
    "Erschlaffte": "erschlafft",
    "Erschlafften": "Erschlaffte",
    "Erschlaffteren": "Erschlafftere",
    "Erschlafftesten": "Erschlaffteste",
    "Erschlagenden": "Erschlagende",
    "Erschlagenen": "Erschlagene",
    "Erschlageneren": "Erschlagenere",
    "Erschlagens": "Erschlagen",
    "Erschlagenste": "erschlagen",
    "Erschlagensten": "Erschlagenste",
    "Erschleichenden": "Erschleichende",
    "Erschleichens": "Erschleichen",
    "Erschlichenen": "Erschlichene",
    "Erschließenden": "Erschließende",
    "Erschließens": "Erschließen",
    "Erschließungen": "Erschließung",
    "Erschlossenen": "Erschlossene",
    "Erschlosseneren": "Erschlossenere",
    "Erschlossensten": "Erschlossenste",
    "Erschossenen": "Erschossene",
    "Erschreckenden": "Erschreckende",
    "Erschreckenderen": "Erschreckendere",
    "Erschreckendsten": "Erschreckendste",
    "Erschreckens": "Erschrecken",
    "Erschreckte": "erschreckt",
    "Erschreckten": "Erschreckte",
    "Erschreckteren": "Erschrecktere",
    "Erschrecktesten": "Erschreckteste",
    "Erschrockenen": "Erschrockene",
    "Erschrockeneren": "Erschrockenere",
    "Erschrockensten": "Erschrockenste",
    "Erschwerenden": "Erschwerende",
    "Erschwerenderen": "Erschwerendere",
    "Erschwerendsten": "Erschwerendste",
    "Erschwerens": "Erschweren",
    "Erschwerte": "erschwert",
    "Erschwerten": "Erschwerte",
    "Erschwindelnden": "Erschwindelnde",
    "Erschwindelns": "Erschwindeln",
    "Erschwindelte": "erschwindelt",
    "Erschwindelten": "Erschwindelte",
    "Erschwinglichen": "Erschwingliche",
    "Erschwinglicheren": "Erschwinglichere",
    "Erschwinglichsten": "Erschwinglichste",
    "Erschöpfenden": "Erschöpfende",
    "Erschöpfenderen": "Erschöpfendere",
    "Erschöpfendsten": "Erschöpfendste",
    "Erschöpfens": "Erschöpfen",
    "Erschöpfte": "erschöpft",
    "Erschöpften": "Erschöpfte",
    "Erschöpfteren": "Erschöpftere",
    "Erschöpftesten": "Erschöpfteste",
    "Erschöpfungen": "Erschöpfung",
    "Erschütternden": "Erschütternde",
    "Erschütternderen": "Erschütterndere",
    "Erschütterndsten": "Erschütterndste",
    "Erschütterns": "Erschüttern",
    "Erschütterte": "erschüttert",
    "Erschütterten": "Erschütterte",
    "Erschütterteren": "Erschüttertere",
    "Erschüttertesten": "Erschütterteste",
    "Ersehenden": "Ersehende",
    "Ersehenen": "Ersehene",
    "Ersehens": "Ersehen",
    "Ersehnenden": "Ersehnende",
    "Ersehnenderen": "Ersehnendere",
    "Ersehnendsten": "Ersehnendste",
    "Ersehnens": "Ersehnen",
    "Ersehnte": "ersehnt",
    "Ersehnten": "Ersehnte",
    "Ersehnteren": "Ersehntere",
    "Ersehntesten": "Ersehnteste",
    "Ersetzbaren": "Ersetzbare",
    "Ersetzenden": "Ersetzende",
    "Ersetzens": "Ersetzen",
    "Ersetzte": "ersetzt",
    "Ersetzten": "Ersetzte",
    "Ersetzungen": "Ersetzung",
    "Ersichtliche": "ersichtlich",
    "Ersichtlichen": "Ersichtliche",
    "Ersinnenden": "Ersinnende",
    "Ersinnenderen": "Ersinnendere",
    "Ersinnendsten": "Ersinnendste",
    "Ersinnens": "Ersinnen",
    "Ersoffenen": "Ersoffene",
    "Ersonnenen": "Ersonnene",
    "Ersonneneren": "Ersonnenere",
    "Ersonnensten": "Ersonnenste",
    "Ersparenden": "Ersparende",
    "Ersparens": "Ersparen",
    "Ersparnisse": "Ersparnis",
    "Ersparnissen": "Ersparnis",
    "Ersparte": "erspart",
    "Ersparten": "Ersparte",
    "Erspielenden": "Erspielende",
    "Erspielens": "Erspielen",
    "Erspielte": "erspielt",
    "Erspielten": "Erspielte",
    "Erspähenden": "Erspähende",
    "Erspähens": "Erspähen",
    "Erspähte": "erspäht",
    "Erspähten": "Erspähte",
    "Erstandenen": "Erstandene",
    "Erstarkenden": "Erstarkende",
    "Erstarkenderen": "Erstarkendere",
    "Erstarkendsten": "Erstarkendste",
    "Erstarkens": "Erstarken",
    "Erstarkte": "erstarkt",
    "Erstarkten": "Erstarkte",
    "Erstarkteren": "Erstarktere",
    "Erstarktesten": "Erstarkteste",
    "Erstarrenden": "Erstarrende",
    "Erstarrenderen": "Erstarrendere",
    "Erstarrendsten": "Erstarrendste",
    "Erstarrens": "Erstarren",
    "Erstarrte": "erstarrt",
    "Erstarrten": "Erstarrte",
    "Erstarrteren": "Erstarrtere",
    "Erstarrtesten": "Erstarrteste",
    "Erstattenden": "Erstattende",
    "Erstattens": "Erstatten",
    "Erstattete": "erstattet",
    "Erstatteten": "Erstattete",
    "Erstattungen": "Erstattung",
    "Erstaufführungen": "Erstaufführung",
    "Erstauflagen": "Erstauflage",
    "Erstaunenden": "Erstaunende",
    "Erstaunens": "Erstaunen",
    "Erstaunlichen": "Erstaunliche",
    "Erstaunlicheren": "Erstaunlichere",
    "Erstaunlichsten": "Erstaunlichste",
    "Erstaunte": "erstaunt",
    "Erstaunten": "Erstaunte",
    "Erstausgaben": "Erstausgabe",
    "Erstausstattungen": "Erstausstattung",
    "Erstbezuge": "Erstbezug",
    "Erstbezugs": "Erstbezug",
    "Erstbezüge": "Erstbezug",
    "Erstbezügen": "Erstbezug",
    "Erstdrucke": "Erstdruck",
    "Erstdrucken": "Erstdruck",
    "Erstdruckes": "Erstdruck",
    "Erstdrucks": "Erstdruck",
    "Erste": "erst",
    "Erstehenden": "Erstehende",
    "Erstehens": "Erstehen",
    "Ersteigernden": "Ersteigernde",
    "Ersteigerns": "Ersteigern",
    "Ersteigerte": "ersteigert",
    "Ersteigerten": "Ersteigerte",
    "Erstellenden": "Erstellende",
    "Erstellens": "Erstellen",
    "Erstellte": "erstellt",
    "Erstellten": "Erstellte",
    "Ersten": "Erste",
    "Erstgeborene": "erstgeboren",
    "Erstgeborenen": "Erstgeborene",
    "Erstgebärenden": "Erstgebärende",
    "Erstgenannten": "Erstgenannte",
    "Erstinkenden": "Erstinkende",
    "Erstinkens": "Erstinken",
    "Erstklassigen": "Erstklassige",
    "Erstklassigeren": "Erstklassigere",
    "Erstklassigsten": "Erstklassigste",
    "Erstkommunionen": "Erstkommunion",
    "Erstligisten": "Erstligist",
    "Erstmalige": "erstmalig",
    "Erstmaligen": "Erstmalige",
    "Erstplatzierten": "Erstplatzierte",
    "Erstplazierten": "Erstplazierte",
    "Erstrebenden": "Erstrebende",
    "Erstrebens": "Erstreben",
    "Erstrebenswerte": "erstrebenswert",
    "Erstrebenswerten": "Erstrebenswerte",
    "Erstrebenswerteren": "Erstrebenswertere",
    "Erstrebte": "erstrebt",
    "Erstrebten": "Erstrebte",
    "Erstreckenden": "Erstreckende",
    "Erstreckens": "Erstrecken",
    "Erstreckte": "erstreckt",
    "Erstreckten": "Erstreckte",
    "Erstreikenden": "Erstreikende",
    "Erstreikens": "Erstreiken",
    "Erstreikte": "erstreikt",
    "Erstreikten": "Erstreikte",
    "Erstsendungen": "Erstsendung",
    "Erststimmen": "Erststimme",
    "Erstunkenen": "Erstunkene",
    "Erstunkeneren": "Erstunkenere",
    "Erstunkensten": "Erstunkenste",
    "Erstveröffentlichungen": "Erstveröffentlichung",
    "Erstwählern": "Erstwähler",
    "Erstwählers": "Erstwähler",
    "Erstzulassungen": "Erstzulassung",
    "Erstürmungen": "Erstürmung",
    "Ersuchenden": "Ersuchende",
    "Ersuchens": "Ersuchen",
    "Ersuchte": "ersucht",
    "Ersuchten": "Ersuchte",
    "Ertappenden": "Ertappende",
    "Ertappens": "Ertappen",
    "Ertappte": "ertappt",
    "Ertappten": "Ertappte",
    "Ertastenden": "Ertastende",
    "Ertastens": "Ertasten",
    "Ertastete": "ertastet",
    "Ertasteten": "Ertastete",
    "Erteilenden": "Erteilende",
    "Erteilens": "Erteilen",
    "Erteilte": "erteilt",
    "Erteilten": "Erteilte",
    "Ertrag": "ertragen",
    "Ertragbare": "ertragbar",
    "Ertragbaren": "Ertragbare",
    "Ertragbareren": "Ertragbarere",
    "Ertragbarsten": "Ertragbarste",
    "Ertrage": "ertragen",
    "Ertragenden": "Ertragende",
    "Ertragenderen": "Ertragendere",
    "Ertragendsten": "Ertragendste",
    "Ertragenen": "Ertragene",
    "Ertragens": "Ertragen",
    "Ertragfähigen": "Ertragfähige",
    "Ertragfähigeren": "Ertragfähigere",
    "Ertragfähigsten": "Ertragfähigste",
    "Ertraglosen": "Ertraglose",
    "Ertragloseren": "Ertraglosere",
    "Ertraglosesten": "Ertragloseste",
    "Ertragreichen": "Ertragreiche",
    "Ertragreicheren": "Ertragreichere",
    "Ertragreichsten": "Ertragreichste",
    "Ertrags": "Ertrag",
    "Ertrinkenden": "Ertrinkende",
    "Ertrinkens": "Ertrinken",
    "Ertrunkenen": "Ertrunkene",
    "Erträge": "Ertrag",
    "Erträgen": "Ertrag",
    "Erträglichen": "Erträgliche",
    "Erträglicheren": "Erträglichere",
    "Erträglichsten": "Erträglichste",
    "Erträumbaren": "Erträumbare",
    "Erträumenden": "Erträumende",
    "Erträumens": "Erträumen",
    "Erträumte": "erträumt",
    "Erträumten": "Erträumte",
    "Ertüchtigungen": "Ertüchtigung",
    "Eruierenden": "Eruierende",
    "Eruierens": "Eruieren",
    "Eruierte": "eruiert",
    "Eruierten": "Eruierte",
    "Eruptionen": "Eruption",
    "Erwachenden": "Erwachende",
    "Erwachens": "Erwachen",
    "Erwachsenden": "Erwachsende",
    "Erwachsenen": "Erwachsene",
    "Erwachseneren": "Erwachsenere",
    "Erwachsensten": "Erwachsenste",
    "Erwachte": "erwacht",
    "Erwachten": "Erwachte",
    "Erwartenden": "Erwartende",
    "Erwartens": "Erwarten",
    "Erwartete": "erwartet",
    "Erwarteten": "Erwartete",
    "Erwartungen": "Erwartung",
    "Erwartungsgemäße": "erwartungsgemäß",
    "Erwartungsgemäßen": "Erwartungsgemäße",
    "Erwartungsvollen": "Erwartungsvolle",
    "Erwartungsvolleren": "Erwartungsvollere",
    "Erweckenden": "Erweckende",
    "Erweckens": "Erwecken",
    "Erweckte": "erweckt",
    "Erweckten": "Erweckte",
    "Erweichungen": "Erweichung",
    "Erweisenden": "Erweisende",
    "Erweisens": "Erweisen",
    "Erweiternden": "Erweiternde",
    "Erweiterns": "Erweitern",
    "Erweiterte": "erweitert",
    "Erweiterten": "Erweiterte",
    "Erweiterteren": "Erweitertere",
    "Erweitertesten": "Erweiterteste",
    "Erweiterungen": "Erweiterung",
    "Erwerbe": "erwerben",
    "Erwerben": "Erwerb",
    "Erwerbenden": "Erwerbende",
    "Erwerbens": "Erwerben",
    "Erwerbs": "Erwerb",
    "Erwerbsfähige": "erwerbsfähig",
    "Erwerbsfähigen": "Erwerbsfähige",
    "Erwerbsfähigeren": "Erwerbsfähigere",
    "Erwerbsfähigsten": "Erwerbsfähigste",
    "Erwerbslosen": "Erwerbslose",
    "Erwerbsloseren": "Erwerbslosere",
    "Erwerbslosesten": "Erwerbsloseste",
    "Erwerbsquellen": "Erwerbsquelle",
    "Erwerbstätige": "erwerbstätig",
    "Erwerbstätigen": "Erwerbstätige",
    "Erwerbsunfähigen": "Erwerbsunfähige",
    "Erwerbsunfähigeren": "Erwerbsunfähigere",
    "Erwerbungen": "Erwerbung",
    "Erwidernden": "Erwidernde",
    "Erwiderns": "Erwidern",
    "Erwiderte": "erwidert",
    "Erwiderten": "Erwiderte",
    "Erwiesenen": "Erwiesene",
    "Erwieseneren": "Erwiesenere",
    "Erwiesensten": "Erwiesenste",
    "Erwins": "Erwin",
    "Erwirkenden": "Erwirkende",
    "Erwirkens": "Erwirken",
    "Erwirkte": "erwirkt",
    "Erwirkten": "Erwirkte",
    "Erwirtschaftenden": "Erwirtschaftende",
    "Erwirtschaftens": "Erwirtschaften",
    "Erwirtschaftete": "erwirtschaftet",
    "Erwirtschafteten": "Erwirtschaftete",
    "Erwischenden": "Erwischende",
    "Erwischens": "Erwischen",
    "Erwischte": "erwischt",
    "Erwischten": "Erwischte",
    "Erwogenen": "Erwogene",
    "Erwogeneren": "Erwogenere",
    "Erwogensten": "Erwogenste",
    "Erworbenen": "Erworbene",
    "Erwägenden": "Erwägende",
    "Erwägens": "Erwägen",
    "Erwägenswerte": "erwägenswert",
    "Erwägenswerten": "Erwägenswerte",
    "Erwägungen": "Erwägung",
    "Erwählenden": "Erwählende",
    "Erwählens": "Erwählen",
    "Erwählte": "erwählt",
    "Erwählten": "Erwählte",
    "Erwähnenden": "Erwähnende",
    "Erwähnens": "Erwähnen",
    "Erwähnenswerte": "erwähnenswert",
    "Erwähnenswerten": "Erwähnenswerte",
    "Erwähnte": "erwähnt",
    "Erwähnten": "Erwähnte",
    "Erwärmenden": "Erwärmende",
    "Erwärmens": "Erwärmen",
    "Erwärmte": "erwärmt",
    "Erwärmten": "Erwärmte",
    "Erwärmteren": "Erwärmtere",
    "Erwärmtesten": "Erwärmteste",
    "Erwärmungen": "Erwärmung",
    "Erwünschten": "Erwünschte",
    "Erwünschteren": "Erwünschtere",
    "Erwünschtesten": "Erwünschteste",
    "Erwürgenden": "Erwürgende",
    "Erwürgenderen": "Erwürgendere",
    "Erwürgendsten": "Erwürgendste",
    "Erwürgens": "Erwürgen",
    "Erwürgte": "erwürgt",
    "Erwürgten": "Erwürgte",
    "Erwürgteren": "Erwürgtere",
    "Erwürgtesten": "Erwürgteste",
    "Erzbischofe": "Erzbischof",
    "Erzbischofs": "Erzbischof",
    "Erzbischöfe": "Erzbischof",
    "Erzbischöfen": "Erzbischof",
    "Erzbischöfliche": "erzbischöflich",
    "Erzbischöflichen": "Erzbischöfliche",
    "Erzbistume": "Erzbistum",
    "Erzbistumes": "Erzbistum",
    "Erzbistums": "Erzbistum",
    "Erzbistümer": "Erzbistum",
    "Erzbistümern": "Erzbistum",
    "Erzdiakone": "Erzdiakon",
    "Erzdiakonen": "Erzdiakon",
    "Erzdiakons": "Erzdiakon",
    "Erzdiözesen": "Erzdiözese",
    "Erzengeln": "Erzengel",
    "Erzengels": "Erzengel",
    "Erzeugenden": "Erzeugende",
    "Erzeugens": "Erzeugen",
    "Erzeugern": "Erzeuger",
    "Erzeugers": "Erzeuger",
    "Erzeugnisse": "Erzeugnis",
    "Erzeugnissen": "Erzeugnis",
    "Erzeugnisses": "Erzeugnis",
    "Erzeugte": "erzeugt",
    "Erzeugten": "Erzeugte",
    "Erzgaunern": "Erzgauner",
    "Erzgauners": "Erzgauner",
    "Erzgießereien": "Erzgießerei",
    "Erziehenden": "Erziehende",
    "Erziehens": "Erziehen",
    "Erzieherinnen": "Erzieherin",
    "Erzieherische": "erzieherisch",
    "Erzieherischen": "Erzieherische",
    "Erziehern": "Erzieher",
    "Erziehers": "Erzieher",
    "Erziehungen": "Erziehung",
    "Erzielenden": "Erzielende",
    "Erzielens": "Erzielen",
    "Erzielte": "erzielt",
    "Erzielten": "Erzielte",
    "Erzogenen": "Erzogene",
    "Erzschleichen": "Erzschleiche",
    "Erzschurken": "Erzschurke",
    "Erzvaters": "Erzvater",
    "Erzväter": "Erzvater",
    "Erzvätern": "Erzvater",
    "Erzwespen": "Erzwespe",
    "Erzwingenden": "Erzwingende",
    "Erzwingens": "Erzwingen",
    "Erzwungenen": "Erzwungene",
    "Erzwungeneren": "Erzwungenere",
    "Erzwungensten": "Erzwungenste",
    "Erzählbande": "Erzählband",
    "Erzählbandes": "Erzählband",
    "Erzählbands": "Erzählband",
    "Erzählbände": "Erzählband",
    "Erzählbänden": "Erzählband",
    "Erzählenden": "Erzählende",
    "Erzählenderen": "Erzählendere",
    "Erzählendsten": "Erzählendste",
    "Erzählens": "Erzählen",
    "Erzählenswerte": "erzählenswert",
    "Erzählenswerten": "Erzählenswerte",
    "Erzählenswerteren": "Erzählenswertere",
    "Erzählerischen": "Erzählerische",
    "Erzählern": "Erzähler",
    "Erzählers": "Erzähler",
    "Erzählspiele": "Erzählspiel",
    "Erzählspielen": "Erzählspiel",
    "Erzählspieles": "Erzählspiel",
    "Erzählspiels": "Erzählspiel",
    "Erzählte": "erzählt",
    "Erzähltechnischen": "Erzähltechnische",
    "Erzählten": "Erzählte",
    "Erzähltypen": "Erzähltyp",
    "Erzählungen": "Erzählung",
    "Erzübeln": "Erzübel",
    "Erzübels": "Erzübel",
    "Erzürnenden": "Erzürnende",
    "Erzürnenderen": "Erzürnendere",
    "Erzürnendsten": "Erzürnendste",
    "Erzürnens": "Erzürnen",
    "Erzürnte": "erzürnt",
    "Erzürnten": "Erzürnte",
    "Erzürnteren": "Erzürntere",
    "Erzürntesten": "Erzürnteste",
    "Eröffnenden": "Eröffnende",
    "Eröffnens": "Eröffnen",
    "Eröffnete": "eröffnet",
    "Eröffneten": "Eröffnete",
    "Eröffnungen": "Eröffnung",
    "Erörternden": "Erörternde",
    "Erörterns": "Erörtern",
    "Erörternswerte": "erörternswert",
    "Erörternswerten": "Erörternswerte",
    "Erörternswerteren": "Erörternswertere",
    "Erörterte": "erörtert",
    "Erörterten": "Erörterte",
    "Erörterungen": "Erörterung",
    "Erübrigenden": "Erübrigende",
    "Erübrigens": "Erübrigen",
    "Erübrigte": "erübrigt",
    "Erübrigten": "Erübrigte",
    "Eschbachern": "Eschbacher",
    "Eschbachers": "Eschbacher",
    "Eschbachs": "Eschbach",
    "Eschbornern": "Eschborner",
    "Eschborners": "Eschborner",
    "Eschborns": "Eschborn",
    "Eschen": "Esche",
    "Eschenheimern": "Eschenheimer",
    "Eschenheimers": "Eschenheimer",
    "Eschersheimern": "Eschersheimer",
    "Eschersheimers": "Eschersheimer",
    "Eschersheims": "Eschersheim",
    "Eschweges": "Eschwege",
    "Esebecks": "Esebeck",
    "Eseleien": "Eselei",
    "Eseln": "Esel",
    "Esels": "Esel",
    "Eskalationen": "Eskalation",
    "Eskalierenden": "Eskalierende",
    "Eskalierenderen": "Eskalierendere",
    "Eskalierendsten": "Eskalierendste",
    "Eskalierens": "Eskalieren",
    "Eskalierte": "eskaliert",
    "Eskalierten": "Eskalierte",
    "Eskalierteren": "Eskaliertere",
    "Eskaliertesten": "Eskalierteste",
    "Eskapaden": "Eskapade",
    "Eskimos": "Eskimo",
    "Eskorten": "Eskorte",
    "Eskortierenden": "Eskortierende",
    "Eskortierens": "Eskortieren",
    "Eskortierte": "eskortiert",
    "Eskortierten": "Eskortierte",
    "Esoterischen": "Esoterische",
    "Esotrips": "Esotrip",
    "Espen": "Espe",
    "Espressos": "Espresso",
    "Essays": "Essay",
    "Essenden": "Essende",
    "Essens": "Essen",
    "Essensmarken": "Essensmarke",
    "Essenszeiten": "Essenszeit",
    "Essenzen": "Essenz",
    "Essenzielle": "essenziell",
    "Essenziellen": "Essenzielle",
    "Essereien": "Esserei",
    "Essern": "Esser",
    "Essers": "Esser",
    "Essiggurken": "Essiggurke",
    "Essigs": "Essig",
    "Establishments": "Establishment",
    "Estlands": "Estland",
    "Estländerinnen": "Estländerin",
    "Estländern": "Estländer",
    "Estländers": "Estländer",
    "Estriche": "Estrich",
    "Estrichen": "Estrich",
    "Estrichs": "Estrich",
    "Etablierenden": "Etablierende",
    "Etablierens": "Etablieren",
    "Etablierte": "etabliert",
    "Etablierten": "Etablierte",
    "Etablierteren": "Etabliertere",
    "Etabliertesten": "Etablierteste",
    "Etablierungen": "Etablierung",
    "Etagen": "Etage",
    "Etappen": "Etappe",
    "Etats": "Etat",
    "Ethanols": "Ethanol",
    "Ethers": "Ether",
    "Ethikern": "Ethiker",
    "Ethikers": "Ethiker",
    "Ethische": "ethisch",
    "Ethischen": "Ethische",
    "Ethischeren": "Ethischere",
    "Ethischsten": "Ethischste",
    "Ethnischen": "Ethnische",
    "Ethnografien": "Ethnografie",
    "Ethnographen": "Ethnograph",
    "Ethnographien": "Ethnographie",
    "Ethnographische": "ethnographisch",
    "Ethnographischen": "Ethnographische",
    "Ethnologen": "Ethnologe",
    "Ethnologische": "ethnologisch",
    "Ethnologischen": "Ethnologische",
    "Etikette": "Etikett",
    "Etiketten": "Etikette",
    "Etikettes": "Etikett",
    "Etikettierenden": "Etikettierende",
    "Etikettierens": "Etikettieren",
    "Etikettierte": "etikettiert",
    "Etikettierten": "Etikettierte",
    "Etiketts": "Etikett",
    "Etuis": "Etui",
    "Etwaige": "etwaig",
    "Etwaigen": "Etwaige",
    "Etymologien": "Etymologie",
    "Eucharistien": "Eucharistie",
    "Euckens": "Eucken",
    "Eugens": "Eugen",
    "Eulen": "Eule",
    "Eulenspiegeleien": "Eulenspiegelei",
    "Eunuchen": "Eunuch",
    "Euphemistische": "euphemistisch",
    "Euphemistischen": "Euphemistische",
    "Euphorischen": "Euphorische",
    "Euphorischeren": "Euphorischere",
    "Euphorischsten": "Euphorischste",
    "Eurasischen": "Eurasische",
    "Europameistern": "Europameister",
    "Europameisters": "Europameister",
    "Europas": "Europa",
    "Europastraßen": "Europastraße",
    "Europiums": "Europium",
    "Europäern": "Europäer",
    "Europäers": "Europäer",
    "Europäische": "europäisch",
    "Europäischen": "Europäische",
    "Europäischeren": "Europäischere",
    "Europäischsten": "Europäischste",
    "Europäisierenden": "Europäisierende",
    "Europäisierenderen": "Europäisierendere",
    "Europäisierens": "Europäisieren",
    "Europäisierte": "europäisiert",
    "Europäisierten": "Europäisierte",
    "Europäisierteren": "Europäisiertere",
    "Europäisiertesten": "Europäisierteste",
    "Euros": "Euro",
    "Euroschecks": "Euroscheck",
    "Eutern": "Euter",
    "Euters": "Euter",
    "Evakuierenden": "Evakuierende",
    "Evakuierens": "Evakuieren",
    "Evakuierte": "evakuiert",
    "Evakuierten": "Evakuierte",
    "Evakuierungen": "Evakuierung",
    "Evangelische": "evangelisch",
    "Evangelischen": "Evangelische",
    "Evangelischeren": "Evangelischere",
    "Evangelischsten": "Evangelischste",
    "Evangelistischen": "Evangelistische",
    "Evas": "Eva",
    "Eventuelle": "eventuell",
    "Eventuellen": "Eventuelle",
    "Evergreens": "Evergreen",
    "Evidenzen": "Evidenz",
    "Evolutionen": "Evolution",
    "Ewige": "ewig",
    "Ewigen": "Ewige",
    "Ewigkeiten": "Ewigkeit",
    "Ewigliche": "ewiglich",
    "Ewiglichen": "Ewigliche",
    "Exakten": "Exakte",
    "Exakteren": "Exaktere",
    "Exaktesten": "Exakteste",
    "Examens": "Examen",
    "Exegesen": "Exegese",
    "Exekutierenden": "Exekutierende",
    "Exekutierens": "Exekutieren",
    "Exekutierte": "exekutiert",
    "Exekutierten": "Exekutierte",
    "Exekutionen": "Exekution",
    "Exekutive": "exekutiv",
    "Exekutiven": "Exekutive",
    "Exekutore": "Exekutor",
    "Exekutoren": "Exekutor",
    "Exekutors": "Exekutor",
    "Exempeln": "Exempel",
    "Exempels": "Exempel",
    "Exemplare": "Exemplar",
    "Exemplaren": "Exemplar",
    "Exemplares": "Exemplar",
    "Exemplarische": "exemplarisch",
    "Exemplarischen": "Exemplarische",
    "Exemplars": "Exemplar",
    "Exerzierenden": "Exerzierende",
    "Exerzierens": "Exerzieren",
    "Exerzierte": "exerziert",
    "Exerzierten": "Exerzierte",
    "Exhibierenden": "Exhibierende",
    "Exhibierens": "Exhibieren",
    "Exhibierte": "exhibiert",
    "Exhibierten": "Exhibierte",
    "Exhibitionen": "Exhibition",
    "Exhibitionisten": "Exhibitionist",
    "Exhumierenden": "Exhumierende",
    "Exhumierens": "Exhumieren",
    "Exhumierte": "exhumiert",
    "Exhumierten": "Exhumierte",
    "Exhumierungen": "Exhumierung",
    "Exile": "Exil",
    "Exilen": "Exil",
    "Exils": "Exil",
    "Existentialisten": "Existentialist",
    "Existentielle": "existentiell",
    "Existentiellen": "Existentielle",
    "Existentielleren": "Existentiellere",
    "Existentiellsten": "Existentiellste",
    "Existenzbedrohenden": "Existenzbedrohende",
    "Existenzbedrohenderen": "Existenzbedrohendere",
    "Existenzen": "Existenz",
    "Existenzfähige": "existenzfähig",
    "Existenzfähigen": "Existenzfähige",
    "Existenzfähigeren": "Existenzfähigere",
    "Existenzfähigsten": "Existenzfähigste",
    "Existenziellen": "Existenzielle",
    "Existierenden": "Existierende",
    "Existierens": "Existieren",
    "Existierte": "existiert",
    "Existierten": "Existierte",
    "Exklusivberichte": "Exklusivbericht",
    "Exklusivberichten": "Exklusivbericht",
    "Exklusivberichts": "Exklusivbericht",
    "Exklusive": "exklusiv",
    "Exklusiven": "Exklusive",
    "Exklusiveren": "Exklusivere",
    "Exklusivsten": "Exklusivste",
    "Exklusivvertrage": "Exklusivvertrag",
    "Exklusivvertrags": "Exklusivvertrag",
    "Exklusivverträge": "Exklusivvertrag",
    "Exklusivverträgen": "Exklusivvertrag",
    "Exkurse": "Exkurs",
    "Exkursen": "Exkurs",
    "Exkurses": "Exkurs",
    "Exkursionen": "Exkursion",
    "Exministern": "Exminister",
    "Exministers": "Exminister",
    "Exmissionen": "Exmission",
    "Exners": "Exner",
    "Exorbitante": "exorbitant",
    "Exorbitanten": "Exorbitante",
    "Exorbitanzen": "Exorbitanz",
    "Exotische": "exotisch",
    "Exotischen": "Exotische",
    "Exotischeren": "Exotischere",
    "Exotischsten": "Exotischste",
    "Expandern": "Expander",
    "Expanders": "Expander",
    "Expandierenden": "Expandierende",
    "Expandierenderen": "Expandierendere",
    "Expandierendsten": "Expandierendste",
    "Expandierens": "Expandieren",
    "Expandierte": "expandiert",
    "Expandierten": "Expandierte",
    "Expandierteren": "Expandiertere",
    "Expandiertesten": "Expandierteste",
    "Expansionen": "Expansion",
    "Expansive": "expansiv",
    "Expansiven": "Expansive",
    "Expeditionen": "Expedition",
    "Expeditore": "Expeditor",
    "Expeditoren": "Expeditor",
    "Expeditors": "Expeditor",
    "Expensive": "expensiv",
    "Expensiven": "Expensive",
    "Expensiveren": "Expensivere",
    "Expensivsten": "Expensivste",
    "Experimentatore": "Experimentator",
    "Experimentatoren": "Experimentator",
    "Experimentators": "Experimentator",
    "Experimente": "Experiment",
    "Experimentelle": "experimentell",
    "Experimentellen": "Experimentelle",
    "Experimenten": "Experiment",
    "Experimentierenden": "Experimentierende",
    "Experimentierens": "Experimentieren",
    "Experimentierte": "experimentiert",
    "Experimentierten": "Experimentierte",
    "Experiments": "Experiment",
    "Experten": "Experte",
    "Expertisen": "Expertise",
    "Explanationen": "Explanation",
    "Explanierenden": "Explanierende",
    "Explanierenderen": "Explanierendere",
    "Explanierendsten": "Explanierendste",
    "Explanierens": "Explanieren",
    "Explanierte": "explaniert",
    "Explanierten": "Explanierte",
    "Explanierteren": "Explaniertere",
    "Explaniertesten": "Explanierteste",
    "Explantationen": "Explantation",
    "Explizierenden": "Explizierende",
    "Explizierens": "Explizieren",
    "Explizierte": "expliziert",
    "Explizierten": "Explizierte",
    "Expliziten": "Explizite",
    "Explodierenden": "Explodierende",
    "Explodierenderen": "Explodierendere",
    "Explodierendsten": "Explodierendste",
    "Explodierens": "Explodieren",
    "Explodierte": "explodiert",
    "Explodierten": "Explodierte",
    "Explodierteren": "Explodiertere",
    "Explodiertesten": "Explodierteste",
    "Explorationen": "Exploration",
    "Explorierenden": "Explorierende",
    "Explorierenderen": "Explorierendere",
    "Explorierendsten": "Explorierendste",
    "Explorierens": "Explorieren",
    "Explorierte": "exploriert",
    "Explorierten": "Explorierte",
    "Explorierteren": "Exploriertere",
    "Exploriertesten": "Explorierteste",
    "Explosionen": "Explosion",
    "Explosive": "explosiv",
    "Explosiven": "Explosive",
    "Explosiveren": "Explosivere",
    "Explosivsten": "Explosivste",
    "Exponate": "Exponat",
    "Exponaten": "Exponat",
    "Exponates": "Exponat",
    "Exponats": "Exponat",
    "Exponenten": "Exponent",
    "Exponentialgleichungen": "Exponentialgleichung",
    "Exponentialreihen": "Exponentialreihe",
    "Exponentielle": "exponentiell",
    "Exponentiellen": "Exponentielle",
    "Exponierenden": "Exponierende",
    "Exponierens": "Exponieren",
    "Exponierte": "exponiert",
    "Exponierten": "Exponierte",
    "Exporte": "Export",
    "Exporten": "Export",
    "Exportes": "Export",
    "Exportierenden": "Exportierende",
    "Exportierenderen": "Exportierendere",
    "Exportierendsten": "Exportierendste",
    "Exportierens": "Exportieren",
    "Exportierte": "exportiert",
    "Exportierten": "Exportierte",
    "Exportierteren": "Exportiertere",
    "Exportiertesten": "Exportierteste",
    "Exports": "Export",
    "Expressionistische": "expressionistisch",
    "Expressionistischen": "Expressionistische",
    "Expressiven": "Expressive",
    "Expressiveren": "Expressivere",
    "Expressivsten": "Expressivste",
    "Expreßgute": "Expreßgut",
    "Expreßgutes": "Expreßgut",
    "Expreßguts": "Expreßgut",
    "Expreßgüter": "Expreßgut",
    "Expreßgütern": "Expreßgut",
    "Exquisiten": "Exquisite",
    "Exquisiteren": "Exquisitere",
    "Exquisitesten": "Exquisiteste",
    "Exsikkatore": "Exsikkator",
    "Exsikkatoren": "Exsikkator",
    "Exsikkators": "Exsikkator",
    "Extensionen": "Extension",
    "Extensive": "extensiv",
    "Extensiven": "Extensive",
    "Extensiveren": "Extensivere",
    "Extensivsten": "Extensivste",
    "Extensore": "Extensor",
    "Extensoren": "Extensor",
    "Extensors": "Extensor",
    "Externalisierungen": "Externalisierung",
    "Externe": "extern",
    "Externen": "Externe",
    "Externisten": "Externist",
    "Exterritoriale": "exterritorial",
    "Exterritorialen": "Exterritoriale",
    "Extorsionen": "Extorsion",
    "Extrablatte": "Extrablatt",
    "Extrablattes": "Extrablatt",
    "Extrablatts": "Extrablatt",
    "Extrablätter": "Extrablatt",
    "Extrablättern": "Extrablatt",
    "Extrafeine": "extrafein",
    "Extrafeinen": "Extrafeine",
    "Extragalaktischen": "Extragalaktische",
    "Extrahenten": "Extrahent",
    "Extrahierenden": "Extrahierende",
    "Extrahierens": "Extrahieren",
    "Extrahierte": "extrahiert",
    "Extrahierten": "Extrahierte",
    "Extrakte": "Extrakt",
    "Extrakten": "Extrakt",
    "Extrakts": "Extrakt",
    "Extrapolationen": "Extrapolation",
    "Extrapoliere": "extrapolieren",
    "Extrapolierenden": "Extrapolierende",
    "Extrapolierenderen": "Extrapolierendere",
    "Extrapolierens": "Extrapolieren",
    "Extrapolierte": "extrapoliert",
    "Extrapolierten": "Extrapolierte",
    "Extrapolierteren": "Extrapoliertere",
    "Extrapoliertesten": "Extrapolierteste",
    "Extrapositionen": "Extraposition",
    "Extras": "Extra",
    "Extrema": "Extremum",
    "Extreme": "Extrem",
    "Extremen": "Extreme",
    "Extremeren": "Extremere",
    "Extremfalle": "Extremfall",
    "Extremfalls": "Extremfall",
    "Extremfälle": "Extremfall",
    "Extremfällen": "Extremfall",
    "Extremisten": "Extremist",
    "Extremistische": "extremistisch",
    "Extremistischen": "Extremistische",
    "Extremistischeren": "Extremistischere",
    "Extremistischsten": "Extremistischste",
    "Extremitäten": "Extremität",
    "Extremste": "extrem",
    "Extremsten": "Extremste",
    "Extremums": "Extremum",
    "Extremwerte": "Extremwert",
    "Extremwerten": "Extremwert",
    "Extremwerts": "Extremwert",
    "Extrinsische": "extrinsisch",
    "Extrinsischen": "Extrinsische",
    "Exzellenten": "Exzellente",
    "Exzellenteren": "Exzellentere",
    "Exzellentesten": "Exzellenteste",
    "Exzellenzen": "Exzellenz",
    "Exzeptionen": "Exzeption",
    "Exzessive": "exzessiv",
    "Exzessiven": "Exzessive",
    "Exzessiveren": "Exzessivere",
    "Exzessivsten": "Exzessivste",
    "Eylmanns": "Eylmann",
    "Eßbare": "eßbar",
    "Eßbaren": "Eßbare",
    "Eßbareren": "Eßbarere",
    "Eßbarsten": "Eßbarste",
    "Eßgeschirre": "Eßgeschirr",
    "Eßgeschirren": "Eßgeschirr",
    "Eßgeschirrs": "Eßgeschirr",
    "Eßgestörte": "eßgestört",
    "Eßgestörten": "Eßgestörte",
    "Eßgestörteren": "Eßgestörtere",
    "Eßgestörtesten": "Eßgestörteste",
    "Eßprobleme": "Eßproblem",
    "Eßproblemen": "Eßproblem",
    "Eßproblems": "Eßproblem",
    "Eßstörungen": "Eßstörung",
    "Eßsüchtige": "eßsüchtig",
    "Eßsüchtigen": "Eßsüchtige",
    "Eßsüchtigeren": "Eßsüchtigere",
    "Eßsüchtigsten": "Eßsüchtigste",
    "Eßverhaltens": "Eßverhalten",
    "Eßzimmern": "Eßzimmer",
    "Eßzimmers": "Eßzimmer",
    "FUs": "FU",
    "Fabeleien": "Fabelei",
    "Fabelhafte": "fabelhaft",
    "Fabelhaften": "Fabelhafte",
    "Fabelhafteren": "Fabelhaftere",
    "Fabelhaftesten": "Fabelhafteste",
    "Fabeln": "Fabel",
    "Fabrikanten": "Fabrikant",
    "Fabriken": "Fabrik",
    "Fabulanten": "Fabulant",
    "Fabulisten": "Fabulist",
    "Fabulöse": "fabulös",
    "Fabulösen": "Fabulöse",
    "Fach": "fachen",
    "Fachbereiche": "Fachbereich",
    "Fachbereichen": "Fachbereich",
    "Fachbereichs": "Fachbereich",
    "Fachbüchereien": "Fachbücherei",
    "Fache": "fachen",
    "Fachenden": "Fachende",
    "Fachenderen": "Fachendere",
    "Fachendsten": "Fachendste",
    "Fachens": "Fachen",
    "Faches": "Fach",
    "Fachfremden": "Fachfremde",
    "Fachgemäßen": "Fachgemäße",
    "Fachgenossen": "Fachgenosse",
    "Fachgerechte": "fachgerecht",
    "Fachgerechten": "Fachgerechte",
    "Fachgerechteren": "Fachgerechtere",
    "Fachgerechtesten": "Fachgerechteste",
    "Fachkundigen": "Fachkundige",
    "Fachkundigeren": "Fachkundigere",
    "Fachkundigsten": "Fachkundigste",
    "Fachleuten": "Fachleute",
    "Fachliche": "fachlich",
    "Fachlichen": "Fachliche",
    "Fachmännischen": "Fachmännische",
    "Fachmännischeren": "Fachmännischere",
    "Fachmännischsten": "Fachmännischste",
    "Fachs": "Fach",
    "Fachschaften": "Fachschaft",
    "Fachschulen": "Fachschule",
    "Fachwissenschaften": "Fachwissenschaft",
    "Fachärztliche": "fachärztlich",
    "Fachärztlichen": "Fachärztliche",
    "Fackeln": "Fackel",
    "Fade": "fad",
    "Faden": "Fade",
    "Fadens": "Faden",
    "Fadenscheinige": "fadenscheinig",
    "Fadenscheinigen": "Fadenscheinige",
    "Fadenscheinigeren": "Fadenscheinigere",
    "Fadenscheinigsten": "Fadenscheinigste",
    "Faderen": "Fadere",
    "Fadesten": "Fadeste",
    "Fahlen": "Fahle",
    "Fahleren": "Fahlere",
    "Fahlsten": "Fahlste",
    "Fahndenden": "Fahndende",
    "Fahndens": "Fahnden",
    "Fahndungen": "Fahndung",
    "Fahnen": "Fahne",
    "Fahnenflüchtige": "fahnenflüchtig",
    "Fahnenflüchtigen": "Fahnenflüchtige",
    "Fahnenjunkern": "Fahnenjunker",
    "Fahnenjunkers": "Fahnenjunker",
    "Fahrbahnen": "Fahrbahn",
    "Fahrbare": "fahrbar",
    "Fahrbaren": "Fahrbare",
    "Fahrbareren": "Fahrbarere",
    "Fahrbarsten": "Fahrbarste",
    "Fahrbereiten": "Fahrbereite",
    "Fahrbühnen": "Fahrbühne",
    "Fahreigenschaften": "Fahreigenschaft",
    "Fahrenden": "Fahrende",
    "Fahrens": "Fahren",
    "Fahrerinnen": "Fahrerin",
    "Fahrerlaubnisse": "Fahrerlaubnis",
    "Fahrerlaubnissen": "Fahrerlaubnis",
    "Fahrern": "Fahrer",
    "Fahrers": "Fahrer",
    "Fahrgaste": "Fahrgast",
    "Fahrgastes": "Fahrgast",
    "Fahrgasts": "Fahrgast",
    "Fahrgemeinschaften": "Fahrgemeinschaft",
    "Fahrgestelle": "Fahrgestell",
    "Fahrgestellen": "Fahrgestell",
    "Fahrgestells": "Fahrgestell",
    "Fahrgäste": "Fahrgast",
    "Fahrgästen": "Fahrgast",
    "Fahrkarten": "Fahrkarte",
    "Fahrkilometern": "Fahrkilometer",
    "Fahrkilometers": "Fahrkilometer",
    "Fahrkorbe": "Fahrkorb",
    "Fahrkorbs": "Fahrkorb",
    "Fahrkörbe": "Fahrkorb",
    "Fahrkörben": "Fahrkorb",
    "Fahrkünste": "Fahrkunst",
    "Fahrkünsten": "Fahrkunst",
    "Fahrlehrern": "Fahrlehrer",
    "Fahrlehrers": "Fahrlehrer",
    "Fahrlässige": "fahrlässig",
    "Fahrlässigen": "Fahrlässige",
    "Fahrlässigeren": "Fahrlässigere",
    "Fahrlässigsten": "Fahrlässigste",
    "Fahrplane": "Fahrplan",
    "Fahrplanes": "Fahrplan",
    "Fahrplanmäßige": "fahrplanmäßig",
    "Fahrplanmäßigen": "Fahrplanmäßige",
    "Fahrplans": "Fahrplan",
    "Fahrpläne": "Fahrplan",
    "Fahrplänen": "Fahrplan",
    "Fahrpreise": "Fahrpreis",
    "Fahrpreisen": "Fahrpreis",
    "Fahrpreises": "Fahrpreis",
    "Fahrprüfungen": "Fahrprüfung",
    "Fahrrade": "Fahrrad",
    "Fahrrades": "Fahrrad",
    "Fahrrads": "Fahrrad",
    "Fahrrinnen": "Fahrrinne",
    "Fahrräder": "Fahrrad",
    "Fahrrädern": "Fahrrad",
    "Fahrscheine": "Fahrschein",
    "Fahrscheinen": "Fahrschein",
    "Fahrscheins": "Fahrschein",
    "Fahrschulen": "Fahrschule",
    "Fahrspuren": "Fahrspur",
    "Fahrstuhle": "Fahrstuhl",
    "Fahrstuhles": "Fahrstuhl",
    "Fahrstuhls": "Fahrstuhl",
    "Fahrstühle": "Fahrstuhl",
    "Fahrstühlen": "Fahrstuhl",
    "Fahrt": "fahren",
    "Fahrten": "Fahrt",
    "Fahrtenschwimmern": "Fahrtenschwimmer",
    "Fahrtenschwimmers": "Fahrtenschwimmer",
    "Fahrtüchtige": "fahrtüchtig",
    "Fahrtüchtigen": "Fahrtüchtige",
    "Fahrtüchtigeren": "Fahrtüchtigere",
    "Fahrtüchtigsten": "Fahrtüchtigste",
    "Fahruntüchtigen": "Fahruntüchtige",
    "Fahruntüchtigeren": "Fahruntüchtigere",
    "Fahruntüchtigsten": "Fahruntüchtigste",
    "Fahrverhaltens": "Fahrverhalten",
    "Fahrwege": "Fahrweg",
    "Fahrwegen": "Fahrweg",
    "Fahrwegs": "Fahrweg",
    "Fahrwinds": "Fahrwind",
    "Fahrzeiten": "Fahrzeit",
    "Fahrzeuge": "Fahrzeug",
    "Fahrzeugen": "Fahrzeug",
    "Fahrzeuges": "Fahrzeug",
    "Fahrzeugs": "Fahrzeug",
    "Faire": "fair",
    "Fairen": "Faire",
    "Faireren": "Fairere",
    "Fairsten": "Fairste",
    "Fakten": "Faktum",
    "Faktische": "faktisch",
    "Faktischen": "Faktische",
    "Faktore": "Faktor",
    "Faktoren": "Faktor",
    "Faktors": "Faktor",
    "Faktums": "Faktum",
    "Fakturierenden": "Fakturierende",
    "Fakturierens": "Fakturieren",
    "Fakturiermaschinen": "Fakturiermaschine",
    "Fakturierte": "fakturiert",
    "Fakturierten": "Fakturierte",
    "Fakultative": "fakultativ",
    "Fakultativen": "Fakultative",
    "Fakultäten": "Fakultät",
    "Falken": "Falke",
    "Falkensteins": "Falkenstein",
    "Falkstraßen": "Falkstraße",
    "Falle": "fallen",
    "Fallen": "Falle",
    "Fallenden": "Fallende",
    "Fallens": "Fallen",
    "Falles": "Fall",
    "Fallgruben": "Fallgrube",
    "Falls": "Fall",
    "Fallschirmtruppen": "Fallschirmtruppe",
    "Falschen": "Falsche",
    "Falscheren": "Falschere",
    "Falschesten": "Falscheste",
    "Falschfahrern": "Falschfahrer",
    "Falschfahrers": "Falschfahrer",
    "Falschgelde": "Falschgeld",
    "Falschgelder": "Falschgeld",
    "Falschgeldern": "Falschgeld",
    "Falschgeldes": "Falschgeld",
    "Falschgelds": "Falschgeld",
    "Falschgläubige": "falschgläubig",
    "Falschgläubigen": "Falschgläubige",
    "Falschmünzern": "Falschmünzer",
    "Falschmünzers": "Falschmünzer",
    "Falschparkern": "Falschparker",
    "Falschparkers": "Falschparker",
    "Falschspielern": "Falschspieler",
    "Falschspielers": "Falschspieler",
    "Falsifikate": "Falsifikat",
    "Falsifikaten": "Falsifikat",
    "Falsifikationen": "Falsifikation",
    "Falsifikats": "Falsifikat",
    "Falsifizierenden": "Falsifizierende",
    "Falsifizierens": "Falsifizieren",
    "Falsifizierte": "falsifiziert",
    "Falsifizierten": "Falsifizierte",
    "Faltblatte": "Faltblatt",
    "Faltblattes": "Faltblatt",
    "Faltblatts": "Faltblatt",
    "Faltblätter": "Faltblatt",
    "Faltblättern": "Faltblatt",
    "Faltboote": "Faltboot",
    "Faltbooten": "Faltboot",
    "Faltboots": "Faltboot",
    "Falte": "falten",
    "Falten": "Falte",
    "Faltenden": "Faltende",
    "Faltenlosen": "Faltenlose",
    "Faltenloseren": "Faltenlosere",
    "Faltenlosesten": "Faltenloseste",
    "Faltenreichen": "Faltenreiche",
    "Faltenreicheren": "Faltenreichere",
    "Faltenreichsten": "Faltenreichste",
    "Faltens": "Falten",
    "Faltern": "Falter",
    "Falters": "Falter",
    "Faltigen": "Faltige",
    "Faltigeren": "Faltigere",
    "Faltigsten": "Faltigste",
    "Falzenden": "Falzende",
    "Falzens": "Falzen",
    "Falzigen": "Falzige",
    "Falzigeren": "Falzigere",
    "Falzigsten": "Falzigste",
    "Familien": "Familie",
    "Familiengerechte": "familiengerecht",
    "Familiengerechten": "Familiengerechte",
    "Familiengerechteren": "Familiengerechtere",
    "Familiären": "Familiäre",
    "Familiäreren": "Familiärere",
    "Familiärsten": "Familiärste",
    "Famosen": "Famose",
    "Famoseren": "Famosere",
    "Famosesten": "Famoseste",
    "Fanatikern": "Fanatiker",
    "Fanatikers": "Fanatiker",
    "Fanatische": "fanatisch",
    "Fanatischen": "Fanatische",
    "Fanatischeren": "Fanatischere",
    "Fanatischsten": "Fanatischste",
    "Fanfaren": "Fanfare",
    "Fang": "fangen",
    "Fange": "fangen",
    "Fangeisens": "Fangeisen",
    "Fangenden": "Fangende",
    "Fangens": "Fangen",
    "Fanges": "Fang",
    "Fangfragen": "Fangfrage",
    "Fanggarne": "Fanggarn",
    "Fanggarnen": "Fanggarn",
    "Fanggarns": "Fanggarn",
    "Fangs": "Fang",
    "Fangschaltungen": "Fangschaltung",
    "Fans": "Fan",
    "Fantasien": "Fantasie",
    "Fantastereien": "Fantasterei",
    "Fantastische": "fantastisch",
    "Fantastischen": "Fantastische",
    "Fantastischeren": "Fantastischere",
    "Fantastischsten": "Fantastischste",
    "Farbbande": "Farbband",
    "Farbbandes": "Farbband",
    "Farbbands": "Farbband",
    "Farbbuche": "Farbbuch",
    "Farbbuches": "Farbbuch",
    "Farbbuchs": "Farbbuch",
    "Farbbänder": "Farbband",
    "Farbbändern": "Farbband",
    "Farbbücher": "Farbbuch",
    "Farbbüchern": "Farbbuch",
    "Farbechten": "Farbechte",
    "Farbechteren": "Farbechtere",
    "Farbechtesten": "Farbechteste",
    "Farbempfindlichen": "Farbempfindliche",
    "Farbempfindlicheren": "Farbempfindlichere",
    "Farben": "Farbe",
    "Farbenblinde": "farbenblind",
    "Farbenblinden": "Farbenblinde",
    "Farbenfreudigen": "Farbenfreudige",
    "Farbenfreudigeren": "Farbenfreudigere",
    "Farbenfreudigsten": "Farbenfreudigste",
    "Farbenfrohen": "Farbenfrohe",
    "Farbenfroheren": "Farbenfrohere",
    "Farbenfrohsten": "Farbenfrohste",
    "Farbenprächtigen": "Farbenprächtige",
    "Farbenprächtigeren": "Farbenprächtigere",
    "Farbenreichen": "Farbenreiche",
    "Farbenreicheren": "Farbenreichere",
    "Farbenreichsten": "Farbenreichste",
    "Farbfotografien": "Farbfotografie",
    "Farbige": "farbig",
    "Farbigen": "Farbige",
    "Farbigeren": "Farbigere",
    "Farbigsten": "Farbigste",
    "Farbkissens": "Farbkissen",
    "Farblose": "farblos",
    "Farblosen": "Farblose",
    "Farbloseren": "Farblosere",
    "Farblosesten": "Farbloseste",
    "Farbmitteln": "Farbmittel",
    "Farbmittels": "Farbmittel",
    "Farbnegative": "Farbnegativ",
    "Farbnegativen": "Farbnegativ",
    "Farbnegatives": "Farbnegativ",
    "Farbnegativs": "Farbnegativ",
    "Farbpulvern": "Farbpulver",
    "Farbpulvers": "Farbpulver",
    "Farbtopfe": "Farbtopf",
    "Farbtopfes": "Farbtopf",
    "Farbtopfs": "Farbtopf",
    "Farbtöpfe": "Farbtopf",
    "Farbtöpfen": "Farbtopf",
    "Farbwahlen": "Farbwahl",
    "Farbwerke": "Farbwerk",
    "Farbwerken": "Farbwerk",
    "Farbwerks": "Farbwerk",
    "Farmen": "Farm",
    "Farmern": "Farmer",
    "Farmers": "Farmer",
    "Farne": "Farn",
    "Farnen": "Farn",
    "Farns": "Farn",
    "Fasanen": "Fasan",
    "Fasanerien": "Fasanerie",
    "Faschinen": "Faschine",
    "Faschisten": "Faschist",
    "Faschistische": "faschistisch",
    "Faschistischen": "Faschistische",
    "Faschistoiden": "Faschistoide",
    "Faschistoideren": "Faschistoidere",
    "Faschistoidesten": "Faschistoideste",
    "Faschos": "Fascho",
    "Faseleien": "Faselei",
    "Faselnden": "Faselnde",
    "Faselnderen": "Faselndere",
    "Faselndsten": "Faselndste",
    "Faselns": "Faseln",
    "Faser": "fasern",
    "Faserigen": "Faserige",
    "Faserigeren": "Faserigere",
    "Faserigsten": "Faserigste",
    "Fasern": "Faser",
    "Fasernackte": "fasernackt",
    "Fasernackten": "Fasernackte",
    "Fasernden": "Fasernde",
    "Fasernderen": "Faserndere",
    "Faserndsten": "Faserndste",
    "Faserns": "Fasern",
    "Faserplatten": "Faserplatte",
    "Fassaden": "Fassade",
    "Fassadenkletterern": "Fassadenkletterer",
    "Fassadenkletterers": "Fassadenkletterer",
    "Fasse": "fassen",
    "Fassenden": "Fassende",
    "Fassens": "Fassen",
    "Fasses": "Faß",
    "Fassetten": "Fassette",
    "Fassungen": "Fassung",
    "Fassungslose": "fassungslos",
    "Fassungslosen": "Fassungslose",
    "Fassungsloseren": "Fassungslosere",
    "Fassungslosesten": "Fassungsloseste",
    "Fastenden": "Fastende",
    "Fastenderen": "Fastendere",
    "Fastendsten": "Fastendste",
    "Fastens": "Fasten",
    "Faszinationen": "Faszination",
    "Faszinierenden": "Faszinierende",
    "Faszinierenderen": "Faszinierendere",
    "Faszinierendsten": "Faszinierendste",
    "Faszinierens": "Faszinieren",
    "Faszinierte": "fasziniert",
    "Faszinierten": "Faszinierte",
    "Faszinierteren": "Fasziniertere",
    "Fasziniertesten": "Faszinierteste",
    "Fatalen": "Fatale",
    "Fataleren": "Fatalere",
    "Fatalisten": "Fatalist",
    "Fatalste": "fatal",
    "Fatalsten": "Fatalste",
    "Fatimidischen": "Fatimidische",
    "Fatimidischeren": "Fatimidischere",
    "Fatimidischsten": "Fatimidischste",
    "Fatzken": "Fatzke",
    "Fauchenden": "Fauchende",
    "Fauchenderen": "Fauchendere",
    "Fauchendsten": "Fauchendste",
    "Fauchens": "Fauchen",
    "Fauerbachs": "Fauerbach",
    "Faule": "faulen",
    "Faulen": "Faule",
    "Faulenden": "Faulende",
    "Faulenderen": "Faulendere",
    "Faulendsten": "Faulendste",
    "Faulens": "Faulen",
    "Faulenzenden": "Faulenzende",
    "Faulenzenderen": "Faulenzendere",
    "Faulenzendsten": "Faulenzendste",
    "Faulenzens": "Faulenzen",
    "Fauleren": "Faulere",
    "Faulfiebers": "Faulfieber",
    "Faulsten": "Faulste",
    "Faultiere": "Faultier",
    "Faultieren": "Faultier",
    "Faultiers": "Faultier",
    "Faunisten": "Faunist",
    "Faustdicke": "faustdick",
    "Faustdicken": "Faustdicke",
    "Faustenden": "Faustende",
    "Faustens": "Fausten",
    "Favoriten": "Favorit",
    "Fax": "faxen",
    "Faxe": "faxen",
    "Faxen": "Faxe",
    "Faxenden": "Faxende",
    "Faxens": "Faxen",
    "Fazilitäten": "Fazilität",
    "Fazite": "Fazit",
    "Faziten": "Fazit",
    "Fazits": "Fazit",
    "Faß": "fassen",
    "Faßbare": "faßbar",
    "Faßbaren": "Faßbare",
    "Faßbareren": "Faßbarere",
    "Faßbarsten": "Faßbarste",
    "Features": "Feature",
    "Februars": "Februar",
    "Fechenheimern": "Fechenheimer",
    "Fechenheimers": "Fechenheimer",
    "Fechenheims": "Fechenheim",
    "Fechtenden": "Fechtende",
    "Fechtens": "Fechten",
    "Feder": "federn",
    "Federführenden": "Federführende",
    "Federführenderen": "Federführendere",
    "Federführendsten": "Federführendste",
    "Federgewichtlern": "Federgewichtler",
    "Federgewichtlers": "Federgewichtler",
    "Federklemmen": "Federklemme",
    "Federleichte": "federleicht",
    "Federleichten": "Federleichte",
    "Federleichteren": "Federleichtere",
    "Federleichtesten": "Federleichteste",
    "Federn": "Feder",
    "Federnden": "Federnde",
    "Federnderen": "Federndere",
    "Federndsten": "Federndste",
    "Federns": "Federn",
    "Federungen": "Federung",
    "Feedbacks": "Feedback",
    "Feen": "Fee",
    "Fegefeuers": "Fegefeuer",
    "Fegenden": "Fegende",
    "Fegens": "Fegen",
    "Fehden": "Fehde",
    "Fehlbetrage": "Fehlbetrag",
    "Fehlbetrages": "Fehlbetrag",
    "Fehlbetrags": "Fehlbetrag",
    "Fehlbeträge": "Fehlbetrag",
    "Fehlbeträgen": "Fehlbetrag",
    "Fehlbitte": "fehlbitten",
    "Fehlbitten": "Fehlbitte",
    "Fehlbittenden": "Fehlbittende",
    "Fehlbittens": "Fehlbitten",
    "Fehlbrande": "Fehlbrand",
    "Fehlbrandes": "Fehlbrand",
    "Fehlbrands": "Fehlbrand",
    "Fehlbrände": "Fehlbrand",
    "Fehlbränden": "Fehlbrand",
    "Fehldrucke": "Fehldruck",
    "Fehldrucken": "Fehldruck",
    "Fehldrucks": "Fehldruck",
    "Fehleinschätzungen": "Fehleinschätzung",
    "Fehlenden": "Fehlende",
    "Fehlenderen": "Fehlendere",
    "Fehlendsten": "Fehlendste",
    "Fehlens": "Fehlen",
    "Fehlentscheidungen": "Fehlentscheidung",
    "Fehlerdeutungen": "Fehlerdeutung",
    "Fehlerfreie": "fehlerfrei",
    "Fehlerfreien": "Fehlerfreie",
    "Fehlerhaften": "Fehlerhafte",
    "Fehlerhafteren": "Fehlerhaftere",
    "Fehlerhaftesten": "Fehlerhafteste",
    "Fehlerlosen": "Fehlerlose",
    "Fehlern": "Fehler",
    "Fehlers": "Fehler",
    "Fehlfarben": "Fehlfarbe",
    "Fehlgebetenen": "Fehlgebetene",
    "Fehlgegriffenen": "Fehlgegriffene",
    "Fehlgegriffeneren": "Fehlgegriffenere",
    "Fehlgegriffensten": "Fehlgegriffenste",
    "Fehlgeleiteten": "Fehlgeleitete",
    "Fehlgeschlagenen": "Fehlgeschlagene",
    "Fehlgeschossenen": "Fehlgeschossene",
    "Fehlgewichte": "Fehlgewicht",
    "Fehlgewichten": "Fehlgewicht",
    "Fehlgewichts": "Fehlgewicht",
    "Fehlgreifenden": "Fehlgreifende",
    "Fehlgreifenderen": "Fehlgreifendere",
    "Fehlgreifendsten": "Fehlgreifendste",
    "Fehlgreifens": "Fehlgreifen",
    "Fehlgriffe": "Fehlgriff",
    "Fehlgriffen": "Fehlgriff",
    "Fehlgriffs": "Fehlgriff",
    "Fehlhandlungen": "Fehlhandlung",
    "Fehlhiebe": "Fehlhieb",
    "Fehlhieben": "Fehlhieb",
    "Fehlhiebs": "Fehlhieb",
    "Fehlinvestierenden": "Fehlinvestierende",
    "Fehlinvestierens": "Fehlinvestieren",
    "Fehlinvestierte": "fehlinvestiert",
    "Fehlinvestierten": "Fehlinvestierte",
    "Fehlleitenden": "Fehlleitende",
    "Fehlleitens": "Fehlleiten",
    "Fehlschießenden": "Fehlschießende",
    "Fehlschießens": "Fehlschießen",
    "Fehlschlage": "fehlschlagen",
    "Fehlschlagenden": "Fehlschlagende",
    "Fehlschlagens": "Fehlschlagen",
    "Fehlschlags": "Fehlschlag",
    "Fehlschläge": "Fehlschlag",
    "Fehlschlägen": "Fehlschlag",
    "Fehlsichtigkeiten": "Fehlsichtigkeit",
    "Fehlstarts": "Fehlstart",
    "Fehlstellen": "Fehlstelle",
    "Fehltritte": "Fehltritt",
    "Fehltritten": "Fehltritt",
    "Fehltritts": "Fehltritt",
    "Fehlurteile": "Fehlurteil",
    "Fehlurteilen": "Fehlurteil",
    "Fehlurteils": "Fehlurteil",
    "Fehlverhaltens": "Fehlverhalten",
    "Fehlwurfe": "Fehlwurf",
    "Fehlwurfs": "Fehlwurf",
    "Fehlwürfe": "Fehlwurf",
    "Fehlwürfen": "Fehlwurf",
    "Fehlzündungen": "Fehlzündung",
    "Feidmans": "Feidman",
    "Feienden": "Feiende",
    "Feienderen": "Feiendere",
    "Feiendsten": "Feiendste",
    "Feiens": "Feien",
    "Feier": "feiern",
    "Feierabende": "Feierabend",
    "Feierabenden": "Feierabend",
    "Feierabends": "Feierabend",
    "Feierlichen": "Feierliche",
    "Feierlicheren": "Feierlichere",
    "Feierlichkeiten": "Feierlichkeit",
    "Feierlichste": "feierlich",
    "Feierlichsten": "Feierlichste",
    "Feiern": "Feier",
    "Feiernden": "Feiernde",
    "Feierns": "Feiern",
    "Feierstunden": "Feierstunde",
    "Feigeren": "Feigere",
    "Feigesten": "Feigeste",
    "Feiglinge": "Feigling",
    "Feiglingen": "Feigling",
    "Feiglings": "Feigling",
    "Feilbietenden": "Feilbietende",
    "Feilbietens": "Feilbieten",
    "Feilen": "Feile",
    "Feilenden": "Feilende",
    "Feilens": "Feilen",
    "Feilgebotenen": "Feilgebotene",
    "Feilschenden": "Feilschende",
    "Feilschenderen": "Feilschendere",
    "Feilschendsten": "Feilschendste",
    "Feilschens": "Feilschen",
    "Feinabstimmungen": "Feinabstimmung",
    "Feinbleche": "Feinblech",
    "Feinblechen": "Feinblech",
    "Feinblechs": "Feinblech",
    "Feinde": "feinden",
    "Feinden": "Feind",
    "Feindenden": "Feindende",
    "Feindens": "Feinden",
    "Feindes": "Feind",
    "Feindlichen": "Feindliche",
    "Feindlicheren": "Feindlichere",
    "Feindlichkeiten": "Feindlichkeit",
    "Feindlichste": "feindlich",
    "Feindlichsten": "Feindlichste",
    "Feinds": "Feind",
    "Feindschaften": "Feindschaft",
    "Feindselige": "feindselig",
    "Feindseligen": "Feindselige",
    "Feindseligeren": "Feindseligere",
    "Feindseligkeiten": "Feindseligkeit",
    "Feindseligste": "feindselig",
    "Feindseligsten": "Feindseligste",
    "Feineinstellungen": "Feineinstellung",
    "Feinen": "Feine",
    "Feineren": "Feinere",
    "Feinfühligen": "Feinfühlige",
    "Feinfühligeren": "Feinfühligere",
    "Feinfühligsten": "Feinfühligste",
    "Feingebäcke": "Feingebäck",
    "Feingebäcken": "Feingebäck",
    "Feingebäcks": "Feingebäck",
    "Feingeschleiften": "Feingeschleifte",
    "Feingeschliffenen": "Feingeschliffene",
    "Feingeschliffeneren": "Feingeschliffenere",
    "Feinkörnigen": "Feinkörnige",
    "Feinkörnigeren": "Feinkörnigere",
    "Feinkörnigsten": "Feinkörnigste",
    "Feinmaschigen": "Feinmaschige",
    "Feinmaschigeren": "Feinmaschigere",
    "Feinmaschigsten": "Feinmaschigste",
    "Feinmechanikern": "Feinmechaniker",
    "Feinmechanikers": "Feinmechaniker",
    "Feinmessungen": "Feinmessung",
    "Feinschleifenden": "Feinschleifende",
    "Feinschleifens": "Feinschleifen",
    "Feinschnitts": "Feinschnitt",
    "Feinsilbers": "Feinsilber",
    "Feinste": "fein",
    "Feinsten": "Feinste",
    "Feinstrukturen": "Feinstruktur",
    "Feinsägen": "Feinsäge",
    "Feinunzen": "Feinunze",
    "Feinwaschmitteln": "Feinwaschmittel",
    "Feinwaschmittels": "Feinwaschmittel",
    "Feistoße": "Feistoß",
    "Feistoßes": "Feistoß",
    "Feistöße": "Feistoß",
    "Feistößen": "Feistoß",
    "Felde": "Feld",
    "Felder": "Feld",
    "Feldern": "Feld",
    "Feldes": "Feld",
    "Felds": "Feld",
    "Feldschlangen": "Feldschlange",
    "Feldwebeln": "Feldwebel",
    "Feldwebels": "Feldwebel",
    "Felgen": "Felge",
    "Felipianos": "Felipiano",
    "Felle": "Fell",
    "Fellen": "Fell",
    "Felles": "Fell",
    "Fells": "Fell",
    "Felsen": "Fels",
    "Felsenfeste": "felsenfest",
    "Felsenfesten": "Felsenfeste",
    "Felsens": "Felsen",
    "Felsige": "felsig",
    "Felsigen": "Felsige",
    "Felsigeren": "Felsigere",
    "Felsigsten": "Felsigste",
    "Femininen": "Feminine",
    "Feministinnen": "Feministin",
    "Feministische": "feministisch",
    "Feministischen": "Feministische",
    "Feministischeren": "Feministischere",
    "Feministischsten": "Feministischste",
    "Fencheltees": "Fencheltee",
    "Fenstern": "Fenster",
    "Fensters": "Fenster",
    "Ferdinands": "Ferdinand",
    "Feriensachen": "Feriensache",
    "Ferkel": "ferkeln",
    "Ferkeln": "Ferkel",
    "Ferkelnden": "Ferkelnde",
    "Ferkelnderen": "Ferkelndere",
    "Ferkelndsten": "Ferkelndste",
    "Ferkelns": "Ferkeln",
    "Ferkels": "Ferkel",
    "Fernandos": "Fernando",
    "Fernbebens": "Fernbeben",
    "Fernbleibenden": "Fernbleibende",
    "Fernbleibens": "Fernbleiben",
    "Fernblicke": "Fernblick",
    "Fernblicken": "Fernblick",
    "Fernblicks": "Fernblick",
    "Fernen": "Ferne",
    "Ferneren": "Fernere",
    "Fernfahrern": "Fernfahrer",
    "Fernfahrers": "Fernfahrer",
    "Fernfluge": "Fernflug",
    "Fernflugs": "Fernflug",
    "Fernflüge": "Fernflug",
    "Fernflügen": "Fernflug",
    "Ferngase": "Ferngas",
    "Ferngasen": "Ferngas",
    "Ferngass": "Ferngas",
    "Ferngebliebenen": "Ferngebliebene",
    "Ferngelenkten": "Ferngelenkte",
    "Ferngesehenen": "Ferngesehene",
    "Ferngesprochenen": "Ferngesprochene",
    "Ferngespräche": "Ferngespräch",
    "Ferngesprächen": "Ferngespräch",
    "Ferngesprächs": "Ferngespräch",
    "Ferngesteuerten": "Ferngesteuerte",
    "Fernheizungen": "Fernheizung",
    "Fernheizwerke": "Fernheizwerk",
    "Fernheizwerken": "Fernheizwerk",
    "Fernheizwerks": "Fernheizwerk",
    "Fernkopien": "Fernkopie",
    "Fernlastfahrern": "Fernlastfahrer",
    "Fernlastfahrers": "Fernlastfahrer",
    "Fernlenkenden": "Fernlenkende",
    "Fernlenkens": "Fernlenken",
    "Fernlenkungen": "Fernlenkung",
    "Fernlenkwaffen": "Fernlenkwaffe",
    "Fernlichte": "Fernlicht",
    "Fernlichtes": "Fernlicht",
    "Fernlichts": "Fernlicht",
    "Fernmeldeamte": "Fernmeldeamt",
    "Fernmeldeamtes": "Fernmeldeamt",
    "Fernmeldeamts": "Fernmeldeamt",
    "Fernmeldeanlagen": "Fernmeldeanlage",
    "Fernmeldeapparate": "Fernmeldeapparat",
    "Fernmeldeapparaten": "Fernmeldeapparat",
    "Fernmeldeapparats": "Fernmeldeapparat",
    "Fernmeldediensts": "Fernmeldedienst",
    "Fernmeldesatelliten": "Fernmeldesatellit",
    "Fernmeldetruppen": "Fernmeldetruppe",
    "Fernmeldeämter": "Fernmeldeamt",
    "Fernmeldeämtern": "Fernmeldeamt",
    "Fernmessungen": "Fernmessung",
    "Fernmündliche": "fernmündlich",
    "Fernmündlichen": "Fernmündliche",
    "Fernobjektive": "Fernobjektiv",
    "Fernobjektiven": "Fernobjektiv",
    "Fernobjektivs": "Fernobjektiv",
    "Fernrohre": "Fernrohr",
    "Fernrohren": "Fernrohr",
    "Fernrohres": "Fernrohr",
    "Fernrohrs": "Fernrohr",
    "Fernrufe": "Fernruf",
    "Fernrufen": "Fernruf",
    "Fernrufs": "Fernruf",
    "Fernschachs": "Fernschach",
    "Fernschreibern": "Fernschreiber",
    "Fernschreibers": "Fernschreiber",
    "Fernschulungen": "Fernschulung",
    "Fernsehansagern": "Fernsehansager",
    "Fernsehansagers": "Fernsehansager",
    "Fernsehantennen": "Fernsehantenne",
    "Fernsehapparate": "Fernsehapparat",
    "Fernsehapparaten": "Fernsehapparat",
    "Fernsehapparats": "Fernsehapparat",
    "Fernsehenden": "Fernsehende",
    "Fernsehens": "Fernsehen",
    "Fernsehern": "Fernseher",
    "Fernsehers": "Fernseher",
    "Fernsehfilme": "Fernsehfilm",
    "Fernsehfilmen": "Fernsehfilm",
    "Fernsehfilms": "Fernsehfilm",
    "Fernsehgerechte": "fernsehgerecht",
    "Fernsehgerechten": "Fernsehgerechte",
    "Fernsehgerechteren": "Fernsehgerechtere",
    "Fernsehgeräte": "Fernsehgerät",
    "Fernsehgeräten": "Fernsehgerät",
    "Fernsehgeräts": "Fernsehgerät",
    "Fernsehkameras": "Fernsehkamera",
    "Fernsehmuffeln": "Fernsehmuffel",
    "Fernsehmuffels": "Fernsehmuffel",
    "Fernsehschirme": "Fernsehschirm",
    "Fernsehschirmen": "Fernsehschirm",
    "Fernsehschirms": "Fernsehschirm",
    "Fernsehsendern": "Fernsehsender",
    "Fernsehsenders": "Fernsehsender",
    "Fernsehteilnehmern": "Fernsehteilnehmer",
    "Fernsehteilnehmers": "Fernsehteilnehmer",
    "Fernsehwerbungen": "Fernsehwerbung",
    "Fernsichtige": "fernsichtig",
    "Fernsichtigen": "Fernsichtige",
    "Fernsichtigeren": "Fernsichtigere",
    "Fernsichtigsten": "Fernsichtigste",
    "Fernsprechamte": "Fernsprechamt",
    "Fernsprechamtes": "Fernsprechamt",
    "Fernsprechamts": "Fernsprechamt",
    "Fernsprechapparate": "Fernsprechapparat",
    "Fernsprechapparaten": "Fernsprechapparat",
    "Fernsprechapparats": "Fernsprechapparat",
    "Fernsprechautomaten": "Fernsprechautomat",
    "Fernsprechbuche": "Fernsprechbuch",
    "Fernsprechbuches": "Fernsprechbuch",
    "Fernsprechbuchs": "Fernsprechbuch",
    "Fernsprechbücher": "Fernsprechbuch",
    "Fernsprechbüchern": "Fernsprechbuch",
    "Fernsprechenden": "Fernsprechende",
    "Fernsprechens": "Fernsprechen",
    "Fernsprechern": "Fernsprecher",
    "Fernsprechers": "Fernsprecher",
    "Fernsprechteilnehmern": "Fernsprechteilnehmer",
    "Fernsprechteilnehmers": "Fernsprechteilnehmer",
    "Fernsprechämter": "Fernsprechamt",
    "Fernsprechämtern": "Fernsprechamt",
    "Fernspruche": "Fernspruch",
    "Fernspruchs": "Fernspruch",
    "Fernsprüche": "Fernspruch",
    "Fernsprüchen": "Fernspruch",
    "Fernste": "fern",
    "Fernsten": "Fernste",
    "Fernsteuernden": "Fernsteuernde",
    "Fernsteuerns": "Fernsteuern",
    "Fernsteuerungen": "Fernsteuerung",
    "Fernstraßen": "Fernstraße",
    "Fernstudenten": "Fernstudent",
    "Fernstudiums": "Fernstudium",
    "Fernthermometern": "Fernthermometer",
    "Fernthermometers": "Fernthermometer",
    "Ferntrauungen": "Ferntrauung",
    "Fernunterrichts": "Fernunterricht",
    "Fernverbindungen": "Fernverbindung",
    "Fernverkehrs": "Fernverkehr",
    "Fernverkehrsstraßen": "Fernverkehrsstraße",
    "Fernwehs": "Fernweh",
    "Fernwirkungen": "Fernwirkung",
    "Fernziele": "Fernziel",
    "Fernzielen": "Fernziel",
    "Fernziels": "Fernziel",
    "Fernzuge": "Fernzug",
    "Fernzugs": "Fernzug",
    "Fernzüge": "Fernzug",
    "Fernzügen": "Fernzug",
    "Fernzündungen": "Fernzündung",
    "Fernöstliche": "fernöstlich",
    "Fernöstlichen": "Fernöstliche",
    "Ferritantennen": "Ferritantenne",
    "Ferrums": "Ferrum",
    "Fersen": "Ferse",
    "Fersengelde": "Fersengeld",
    "Fersengeldes": "Fersengeld",
    "Fersengelds": "Fersengeld",
    "Fertigbekommenden": "Fertigbekommende",
    "Fertigbekommenen": "Fertigbekommene",
    "Fertigbekommens": "Fertigbekommen",
    "Fertigbringenden": "Fertigbringende",
    "Fertigbringens": "Fertigbringen",
    "Fertige": "fertigen",
    "Fertigen": "Fertige",
    "Fertigenden": "Fertigende",
    "Fertigens": "Fertigen",
    "Fertiggebrachten": "Fertiggebrachte",
    "Fertiggekochten": "Fertiggekochte",
    "Fertiggemachten": "Fertiggemachte",
    "Fertiggerichte": "Fertiggericht",
    "Fertiggerichten": "Fertiggericht",
    "Fertiggerichts": "Fertiggericht",
    "Fertiggestellten": "Fertiggestellte",
    "Fertigkeiten": "Fertigkeit",
    "Fertigkochenden": "Fertigkochende",
    "Fertigkochens": "Fertigkochen",
    "Fertigmachenden": "Fertigmachende",
    "Fertigmachens": "Fertigmachen",
    "Fertigstellenden": "Fertigstellende",
    "Fertigstellens": "Fertigstellen",
    "Fertigstellungen": "Fertigstellung",
    "Fertigteile": "Fertigteil",
    "Fertigteilen": "Fertigteil",
    "Fertigteils": "Fertigteil",
    "Fertigungen": "Fertigung",
    "Fertigwaren": "Fertigware",
    "Fertilisationen": "Fertilisation",
    "Fessel": "fesseln",
    "Fesseln": "Fessel",
    "Fesselnden": "Fesselnde",
    "Fesselnderen": "Fesselndere",
    "Fesselndsten": "Fesselndste",
    "Fesselns": "Fesseln",
    "Festakte": "Festakt",
    "Festakten": "Festakt",
    "Festaktes": "Festakt",
    "Festakts": "Festakt",
    "Festangestellte": "festangestellt",
    "Festangestellten": "Festangestellte",
    "Festbeißenden": "Festbeißende",
    "Festbeißens": "Festbeißen",
    "Festcampern": "Festcamper",
    "Festcampers": "Festcamper",
    "Feste": "Fest",
    "Festen": "Feste",
    "Festeren": "Festere",
    "Festesfreuden": "Festesfreude",
    "Festeste": "fest",
    "Festesten": "Festeste",
    "Festfahrenden": "Festfahrende",
    "Festfahrenderen": "Festfahrendere",
    "Festfahrendsten": "Festfahrendste",
    "Festfahrens": "Festfahren",
    "Festfressenden": "Festfressende",
    "Festfressens": "Festfressen",
    "Festgebissenen": "Festgebissene",
    "Festgefahrenen": "Festgefahrene",
    "Festgefahreneren": "Festgefahrenere",
    "Festgefahrensten": "Festgefahrenste",
    "Festgefressenen": "Festgefressene",
    "Festgehakten": "Festgehakte",
    "Festgehaltenen": "Festgehaltene",
    "Festgehefteten": "Festgeheftete",
    "Festgekeilten": "Festgekeilte",
    "Festgekeilteren": "Festgekeiltere",
    "Festgekeiltesten": "Festgekeilteste",
    "Festgeklammerten": "Festgeklammerte",
    "Festgeklammerteren": "Festgeklammertere",
    "Festgeklebten": "Festgeklebte",
    "Festgeklebteren": "Festgeklebtere",
    "Festgeklebtesten": "Festgeklebteste",
    "Festgeklemmten": "Festgeklemmte",
    "Festgeklemmteren": "Festgeklemmtere",
    "Festgeklemmtesten": "Festgeklemmteste",
    "Festgeklopften": "Festgeklopfte",
    "Festgeklopfteren": "Festgeklopftere",
    "Festgeklopftesten": "Festgeklopfteste",
    "Festgelaufenen": "Festgelaufene",
    "Festgelaufeneren": "Festgelaufenere",
    "Festgelaufensten": "Festgelaufenste",
    "Festgelegenen": "Festgelegene",
    "Festgelegten": "Festgelegte",
    "Festgelegteren": "Festgelegtere",
    "Festgelegtesten": "Festgelegteste",
    "Festgelesenen": "Festgelesene",
    "Festgemachten": "Festgemachte",
    "Festgenagelten": "Festgenagelte",
    "Festgenommenen": "Festgenommene",
    "Festgeschraubten": "Festgeschraubte",
    "Festgeschraubteren": "Festgeschraubtere",
    "Festgeschriebenen": "Festgeschriebene",
    "Festgesessenen": "Festgesessene",
    "Festgesetzten": "Festgesetzte",
    "Festgestandenen": "Festgestandene",
    "Festgesteckten": "Festgesteckte",
    "Festgesteckteren": "Festgestecktere",
    "Festgestecktesten": "Festgesteckteste",
    "Festgestellten": "Festgestellte",
    "Festgetretenen": "Festgetretene",
    "Festgetreteneren": "Festgetretenere",
    "Festgetretensten": "Festgetretenste",
    "Festgewurzelten": "Festgewurzelte",
    "Festgewurzelteren": "Festgewurzeltere",
    "Festhakenden": "Festhakende",
    "Festhakens": "Festhaken",
    "Festhaltenden": "Festhaltende",
    "Festhaltens": "Festhalten",
    "Festheftenden": "Festheftende",
    "Festheftens": "Festheften",
    "Festigenden": "Festigende",
    "Festigenderen": "Festigendere",
    "Festigendsten": "Festigendste",
    "Festigens": "Festigen",
    "Festivals": "Festival",
    "Festkeilenden": "Festkeilende",
    "Festkeilenderen": "Festkeilendere",
    "Festkeilendsten": "Festkeilendste",
    "Festkeilens": "Festkeilen",
    "Festklammernden": "Festklammernde",
    "Festklammernderen": "Festklammerndere",
    "Festklammerndsten": "Festklammerndste",
    "Festklammerns": "Festklammern",
    "Festklebenden": "Festklebende",
    "Festklebenderen": "Festklebendere",
    "Festklebendsten": "Festklebendste",
    "Festklebens": "Festkleben",
    "Festklemmenden": "Festklemmende",
    "Festklemmenderen": "Festklemmendere",
    "Festklemmendsten": "Festklemmendste",
    "Festklemmens": "Festklemmen",
    "Festklopfenden": "Festklopfende",
    "Festklopfenderen": "Festklopfendere",
    "Festklopfendsten": "Festklopfendste",
    "Festklopfens": "Festklopfen",
    "Festlaufenden": "Festlaufende",
    "Festlaufenderen": "Festlaufendere",
    "Festlaufendsten": "Festlaufendste",
    "Festlaufens": "Festlaufen",
    "Festlegenden": "Festlegende",
    "Festlegens": "Festlegen",
    "Festlegungen": "Festlegung",
    "Festlesenden": "Festlesende",
    "Festlesens": "Festlesen",
    "Festlichen": "Festliche",
    "Festlicheren": "Festlichere",
    "Festlichsten": "Festlichste",
    "Festliegenden": "Festliegende",
    "Festliegens": "Festliegen",
    "Festmachenden": "Festmachende",
    "Festmachens": "Festmachen",
    "Festnagelnden": "Festnagelnde",
    "Festnagelns": "Festnageln",
    "Festnahmen": "festnehmen",
    "Festnehmenden": "Festnehmende",
    "Festnehmens": "Festnehmen",
    "Festplatten": "Festplatte",
    "Fests": "Fest",
    "Festschraubenden": "Festschraubende",
    "Festschraubenderen": "Festschraubendere",
    "Festschraubens": "Festschrauben",
    "Festschreibenden": "Festschreibende",
    "Festschreibens": "Festschreiben",
    "Festsetzenden": "Festsetzende",
    "Festsetzens": "Festsetzen",
    "Festsitzenden": "Festsitzende",
    "Festsitzens": "Festsitzen",
    "Feststeckenden": "Feststeckende",
    "Feststeckenderen": "Feststeckendere",
    "Feststeckendsten": "Feststeckendste",
    "Feststeckens": "Feststecken",
    "Feststehenden": "Feststehende",
    "Feststehens": "Feststehen",
    "Feststellenden": "Feststellende",
    "Feststellenderen": "Feststellendere",
    "Feststellendsten": "Feststellendste",
    "Feststellens": "Feststellen",
    "Feststellungen": "Feststellung",
    "Festtretenden": "Festtretende",
    "Festtretenderen": "Festtretendere",
    "Festtretendsten": "Festtretendste",
    "Festtretens": "Festtreten",
    "Festungen": "Festung",
    "Festverzinsliche": "festverzinslich",
    "Festverzinslichen": "Festverzinsliche",
    "Festwurzelnden": "Festwurzelnde",
    "Festwurzelnderen": "Festwurzelndere",
    "Festwurzelndsten": "Festwurzelndste",
    "Festwurzelns": "Festwurzeln",
    "Feten": "Fete",
    "Fetischisierenden": "Fetischisierende",
    "Fetischisierenderen": "Fetischisierendere",
    "Fetischisierens": "Fetischisieren",
    "Fetischisierte": "fetischisiert",
    "Fetischisierten": "Fetischisierte",
    "Fetischisierteren": "Fetischisiertere",
    "Fetischisierteste": "fetischisiert",
    "Fetischistischen": "Fetischistische",
    "Fettarmen": "Fettarme",
    "Fettbäuchigen": "Fettbäuchige",
    "Fettbäuchigeren": "Fettbäuchigere",
    "Fettbäuchigsten": "Fettbäuchigste",
    "Fette": "fetten",
    "Fettembolien": "Fettembolie",
    "Fetten": "Fette",
    "Fettenden": "Fettende",
    "Fettenderen": "Fettendere",
    "Fettendsten": "Fettendste",
    "Fettens": "Fetten",
    "Fetteren": "Fettere",
    "Fettesten": "Fetteste",
    "Fettfarben": "Fettfarbe",
    "Fettgedruckte": "fettgedruckt",
    "Fettgedruckten": "Fettgedruckte",
    "Fettgedruckteren": "Fettgedrucktere",
    "Fettgedrucktesten": "Fettgedruckteste",
    "Fettigen": "Fettige",
    "Fettigeren": "Fettigere",
    "Fettigsten": "Fettigste",
    "Fettleibigen": "Fettleibige",
    "Fettleibigeren": "Fettleibigere",
    "Fettleibigsten": "Fettleibigste",
    "Fettlöslichen": "Fettlösliche",
    "Fettlöslicheren": "Fettlöslichere",
    "Fettlöslichsten": "Fettlöslichste",
    "Fettreichen": "Fettreiche",
    "Fettreicheren": "Fettreichere",
    "Fettreichsten": "Fettreichste",
    "Fetts": "Fett",
    "Fettstifte": "Fettstift",
    "Fettstiften": "Fettstift",
    "Fettstifts": "Fettstift",
    "Fetttriefende": "fetttriefend",
    "Fetttriefenden": "Fetttriefende",
    "Fetttriefenderen": "Fetttriefendere",
    "Fetttriefendsten": "Fetttriefendste",
    "Fettärmeren": "Fettärmere",
    "Fettärmsten": "Fettärmste",
    "Fetzenden": "Fetzende",
    "Fetzenderen": "Fetzendere",
    "Fetzendsten": "Fetzendste",
    "Fetzens": "Fetzen",
    "Fetzigen": "Fetzige",
    "Fetzigeren": "Fetzigere",
    "Fetzigsten": "Fetzigste",
    "Feuchte": "feuchten",
    "Feuchten": "Feuchte",
    "Feuchtenden": "Feuchtende",
    "Feuchtenderen": "Feuchtendere",
    "Feuchtendsten": "Feuchtendste",
    "Feuchtens": "Feuchten",
    "Feuchteren": "Feuchtere",
    "Feuchtesten": "Feuchteste",
    "Feuchtfröhlichen": "Feuchtfröhliche",
    "Feuchtfröhlicheren": "Feuchtfröhlichere",
    "Feuchtgebiete": "Feuchtgebiet",
    "Feuchtgebieten": "Feuchtgebiet",
    "Feuchtgebietes": "Feuchtgebiet",
    "Feuchtgebiets": "Feuchtgebiet",
    "Feuchtigkeiten": "Feuchtigkeit",
    "Feuchtwarme": "feuchtwarm",
    "Feuchtwarmen": "Feuchtwarme",
    "Feudalen": "Feudale",
    "Feudaleren": "Feudalere",
    "Feudalistischen": "Feudalistische",
    "Feudalistischeren": "Feudalistischere",
    "Feudalistischsten": "Feudalistischste",
    "Feudalstaate": "Feudalstaat",
    "Feudalstaaten": "Feudalstaat",
    "Feudalstaats": "Feudalstaat",
    "Feudalste": "feudal",
    "Feudalsten": "Feudalste",
    "Feudalsysteme": "Feudalsystem",
    "Feudalsystemen": "Feudalsystem",
    "Feudalsystems": "Feudalsystem",
    "Feudeln": "Feudel",
    "Feudels": "Feudel",
    "Feuer": "feuern",
    "Feuerbeständige": "feuerbeständig",
    "Feuerbeständigen": "Feuerbeständige",
    "Feuerbeständigeren": "Feuerbeständigere",
    "Feuerfesten": "Feuerfeste",
    "Feuerfesteren": "Feuerfestere",
    "Feuerfestesten": "Feuerfesteste",
    "Feuerlöschboote": "Feuerlöschboot",
    "Feuerlöschbooten": "Feuerlöschboot",
    "Feuerlöschbootes": "Feuerlöschboot",
    "Feuerlöschboots": "Feuerlöschboot",
    "Feuern": "Feuer",
    "Feuernden": "Feuernde",
    "Feuernderen": "Feuerndere",
    "Feuerndsten": "Feuerndste",
    "Feuerns": "Feuern",
    "Feuers": "Feuer",
    "Feuerspeiende": "feuerspeiend",
    "Feuerspeienden": "Feuerspeiende",
    "Feuerwehren": "Feuerwehr",
    "Feuerzangen": "Feuerzange",
    "Feuilletons": "Feuilleton",
    "Feurige": "feurig",
    "Feurigen": "Feurige",
    "Feurigeren": "Feurigere",
    "Feurigsten": "Feurigste",
    "Fiats": "Fiat",
    "Fibeln": "Fibel",
    "Fichten": "Fichte",
    "Fichtene": "fichten",
    "Fichtenen": "Fichtene",
    "Fickmühlen": "Fickmühle",
    "Fickrige": "fickrig",
    "Fickrigen": "Fickrige",
    "Fickrigeren": "Fickrigere",
    "Fickrigsten": "Fickrigste",
    "Fideln": "Fidel",
    "Fieberfreien": "Fieberfreie",
    "Fieberhaften": "Fieberhafte",
    "Fieberhafteren": "Fieberhaftere",
    "Fieberhaftesten": "Fieberhafteste",
    "Fieberigen": "Fieberige",
    "Fieberigeren": "Fieberigere",
    "Fieberigsten": "Fieberigste",
    "Fiebernden": "Fiebernde",
    "Fiebernderen": "Fieberndere",
    "Fieberndsten": "Fieberndste",
    "Fieberns": "Fiebern",
    "Fiebrigen": "Fiebrige",
    "Fiebrigeren": "Fiebrigere",
    "Fiebrigsten": "Fiebrigste",
    "Fiedel": "fiedeln",
    "Fiedeln": "Fiedel",
    "Fiedelnden": "Fiedelnde",
    "Fiedelnderen": "Fiedelndere",
    "Fiedelndsten": "Fiedelndste",
    "Fiedelns": "Fiedeln",
    "Fiedernden": "Fiedernde",
    "Fiedernderen": "Fiederndere",
    "Fiederndsten": "Fiederndste",
    "Fiederns": "Fiedern",
    "Fiedlern": "Fiedler",
    "Fiedlers": "Fiedler",
    "Fiesen": "Fiese",
    "Fieseren": "Fiesere",
    "Fiesesten": "Fieseste",
    "Figaros": "Figaro",
    "Figurale": "figural",
    "Figuralen": "Figurale",
    "Figuranten": "Figurant",
    "Figurationen": "Figuration",
    "Figuren": "Figur",
    "Figurierungen": "Figurierung",
    "Figürchens": "Figürchen",
    "Fiktionale": "fiktional",
    "Fiktionalen": "Fiktionale",
    "Fiktionen": "Fiktion",
    "Fiktive": "fiktiv",
    "Fiktiven": "Fiktive",
    "Fiktiveren": "Fiktivere",
    "Fiktivsten": "Fiktivste",
    "Filetierenden": "Filetierende",
    "Filetierens": "Filetieren",
    "Filetierte": "filetiert",
    "Filetierten": "Filetierte",
    "Filets": "Filet",
    "Filialen": "Filiale",
    "Film": "filmen",
    "Filmabtastern": "Filmabtaster",
    "Filmabtasters": "Filmabtaster",
    "Filme": "filmen",
    "Filmemachern": "Filmemacher",
    "Filmemachers": "Filmemacher",
    "Filmen": "Film",
    "Filmenden": "Filmende",
    "Filmens": "Filmen",
    "Filmes": "Film",
    "Filmgrößen": "Filmgröße",
    "Filmische": "filmisch",
    "Filmischen": "Filmische",
    "Films": "Film",
    "Filter": "filtern",
    "Filtern": "Filter",
    "Filternden": "Filternde",
    "Filterns": "Filtern",
    "Filters": "Filter",
    "Filtrate": "Filtrat",
    "Filtraten": "Filtrat",
    "Filtrates": "Filtrat",
    "Filtrats": "Filtrat",
    "Filzenden": "Filzende",
    "Filzenderen": "Filzendere",
    "Filzendsten": "Filzendste",
    "Filzens": "Filzen",
    "Filzigen": "Filzige",
    "Filzigeren": "Filzigere",
    "Filzigsten": "Filzigste",
    "Fimmeligen": "Fimmelige",
    "Fimmeligeren": "Fimmeligere",
    "Fimmeligsten": "Fimmeligste",
    "Fimmeln": "Fimmel",
    "Fimmels": "Fimmel",
    "Finale": "final",
    "Finalen": "Finale",
    "Finales": "Finale",
    "Finalisten": "Finalist",
    "Finalproduzenten": "Finalproduzent",
    "Finanzamte": "Finanzamt",
    "Finanzamtes": "Finanzamt",
    "Finanzamts": "Finanzamt",
    "Finanzausschusse": "Finanzausschuß",
    "Finanzausschusses": "Finanzausschuß",
    "Finanzausschüsse": "Finanzausschuß",
    "Finanzausschüssen": "Finanzausschuß",
    "Finanzen": "Finanz",
    "Finanzielle": "finanziell",
    "Finanziellen": "Finanzielle",
    "Finanzierenden": "Finanzierende",
    "Finanzierens": "Finanzieren",
    "Finanzierte": "finanziert",
    "Finanzierten": "Finanzierte",
    "Finanzierungen": "Finanzierung",
    "Finanzkräftige": "finanzkräftig",
    "Finanzkräftigen": "Finanzkräftige",
    "Finanzkräftigeren": "Finanzkräftigere",
    "Finanzkräftigsten": "Finanzkräftigste",
    "Finanzlagen": "Finanzlage",
    "Finanzministern": "Finanzminister",
    "Finanzministers": "Finanzminister",
    "Finanzmonopole": "Finanzmonopol",
    "Finanzmonopolen": "Finanzmonopol",
    "Finanzmonopols": "Finanzmonopol",
    "Finanzvermögens": "Finanzvermögen",
    "Finanzwesens": "Finanzwesen",
    "Finanzämter": "Finanzamt",
    "Finanzämtern": "Finanzamt",
    "Findelkinde": "Findelkind",
    "Findelkinder": "Findelkind",
    "Findelkindern": "Findelkind",
    "Findelkindes": "Findelkind",
    "Findelkinds": "Findelkind",
    "Findenden": "Findende",
    "Findens": "Finden",
    "Finderlohne": "Finderlohn",
    "Finderlohns": "Finderlohn",
    "Finderlöhne": "Finderlohn",
    "Finderlöhnen": "Finderlohn",
    "Findigen": "Findige",
    "Findigeren": "Findigere",
    "Findigsten": "Findigste",
    "Findlinge": "Findling",
    "Findlingen": "Findling",
    "Findlings": "Findling",
    "Finessen": "Finesse",
    "Fingerfertigen": "Fingerfertige",
    "Fingerfertigeren": "Fingerfertigere",
    "Fingerfertigsten": "Fingerfertigste",
    "Fingern": "Finger",
    "Fingerprints": "Fingerprint",
    "Fingerringe": "Fingerring",
    "Fingerringen": "Fingerring",
    "Fingerringes": "Fingerring",
    "Fingerrings": "Fingerring",
    "Fingers": "Finger",
    "Fingierenden": "Fingierende",
    "Fingierenderen": "Fingierendere",
    "Fingierendsten": "Fingierendste",
    "Fingierens": "Fingieren",
    "Fingierte": "fingiert",
    "Fingierten": "Fingierte",
    "Fingierteren": "Fingiertere",
    "Fingiertesten": "Fingierteste",
    "Finiten": "Finite",
    "Finken": "Finke",
    "Finks": "Fink",
    "Finnen": "Finne",
    "Finnische": "finnisch",
    "Finnischen": "Finnische",
    "Finnlands": "Finnland",
    "Finnlappen": "Finnlappe",
    "Finnländerinnen": "Finnländerin",
    "Finnländern": "Finnländer",
    "Finnländers": "Finnländer",
    "Finstere": "finster",
    "Finsteren": "Finstere",
    "Finstereren": "Finsterere",
    "Finsterlinge": "Finsterling",
    "Finsterlingen": "Finsterling",
    "Finsterlings": "Finsterling",
    "Finsternisse": "Finsternis",
    "Finsternissen": "Finsternis",
    "Finsterste": "finster",
    "Finstersten": "Finsterste",
    "Finten": "Finte",
    "Firmamente": "Firmament",
    "Firmamenten": "Firmament",
    "Firmaments": "Firmament",
    "Firmen": "Firma",
    "Firmenden": "Firmende",
    "Firmens": "Firmen",
    "Firmlinge": "Firmling",
    "Firmlingen": "Firmling",
    "Firmlings": "Firmling",
    "Firmpaten": "Firmpate",
    "Firste": "First",
    "Firsten": "First",
    "Firsts": "First",
    "Fisch": "fischen",
    "Fischchens": "Fischchen",
    "Fische": "fischen",
    "Fischen": "Fisch",
    "Fischenden": "Fischende",
    "Fischens": "Fischen",
    "Fischerinnen": "Fischerin",
    "Fischern": "Fischer",
    "Fischers": "Fischer",
    "Fisches": "Fisch",
    "Fischreichen": "Fischreiche",
    "Fischreicheren": "Fischreichere",
    "Fischreichsten": "Fischreichste",
    "Fischs": "Fisch",
    "Fisteln": "Fistel",
    "Fite": "fit",
    "Fiten": "Fite",
    "Fiteren": "Fitere",
    "Fitesten": "Fiteste",
    "Fitzelchens": "Fitzelchen",
    "Fixe": "fixen",
    "Fixen": "Fixe",
    "Fixenden": "Fixende",
    "Fixens": "Fixen",
    "Fixer": "fix",
    "Fixeren": "Fixere",
    "Fixern": "Fixer",
    "Fixers": "Fixer",
    "Fixesten": "Fixeste",
    "Fixierenden": "Fixierende",
    "Fixierenderen": "Fixierendere",
    "Fixierendsten": "Fixierendste",
    "Fixierens": "Fixieren",
    "Fixierte": "fixiert",
    "Fixierten": "Fixierte",
    "Fixierteren": "Fixiertere",
    "Fixiertesten": "Fixierteste",
    "Fixierungen": "Fixierung",
    "Fixings": "Fixing",
    "Fixpunkte": "Fixpunkt",
    "Fixpunkten": "Fixpunkt",
    "Fixpunkts": "Fixpunkt",
    "Fjorde": "Fjord",
    "Fjorden": "Fjord",
    "Fjords": "Fjord",
    "Flachbogens": "Flachbogen",
    "Flachbohrungen": "Flachbohrung",
    "Flachdache": "Flachdach",
    "Flachdaches": "Flachdach",
    "Flachdachs": "Flachdach",
    "Flachdrucke": "Flachdruck",
    "Flachdrucken": "Flachdruck",
    "Flachdrucks": "Flachdruck",
    "Flachdrückenden": "Flachdrückende",
    "Flachdrückenderen": "Flachdrückendere",
    "Flachdrückendsten": "Flachdrückendste",
    "Flachdrückens": "Flachdrücken",
    "Flachdächer": "Flachdach",
    "Flachdächern": "Flachdach",
    "Flache": "flachen",
    "Flacheisens": "Flacheisen",
    "Flachen": "Flache",
    "Flachenden": "Flachende",
    "Flachens": "Flachen",
    "Flacheren": "Flachere",
    "Flachfallenden": "Flachfallende",
    "Flachfallens": "Flachfallen",
    "Flachfische": "Flachfisch",
    "Flachfischen": "Flachfisch",
    "Flachfischs": "Flachfisch",
    "Flachgedrückten": "Flachgedrückte",
    "Flachgedrückteren": "Flachgedrücktere",
    "Flachgefallenen": "Flachgefallene",
    "Flachgewinden": "Flachgewinde",
    "Flachgewindes": "Flachgewinde",
    "Flachmeißeln": "Flachmeißel",
    "Flachmeißels": "Flachmeißel",
    "Flachreliefs": "Flachrelief",
    "Flachrennens": "Flachrennen",
    "Flachsten": "Flachste",
    "Flachzangen": "Flachzange",
    "Flachziegeln": "Flachziegel",
    "Flachziegels": "Flachziegel",
    "Flackernden": "Flackernde",
    "Flackernderen": "Flackerndere",
    "Flackerndsten": "Flackerndste",
    "Flackerns": "Flackern",
    "Fladens": "Fladen",
    "Flagellanten": "Flagellant",
    "Flagge": "flaggen",
    "Flaggen": "Flagge",
    "Flaggenden": "Flaggende",
    "Flaggenderen": "Flaggendere",
    "Flaggendsten": "Flaggendste",
    "Flaggens": "Flaggen",
    "Flaggschiffe": "Flaggschiff",
    "Flaggschiffen": "Flaggschiff",
    "Flaggschiffs": "Flaggschiff",
    "Flambierenden": "Flambierende",
    "Flambierens": "Flambieren",
    "Flambierte": "flambiert",
    "Flambierten": "Flambierte",
    "Flamencos": "Flamenco",
    "Flamingos": "Flamingo",
    "Flamme": "flammen",
    "Flammen": "Flamme",
    "Flammenden": "Flammende",
    "Flammenderen": "Flammendere",
    "Flammendsten": "Flammendste",
    "Flammens": "Flammen",
    "Flammigen": "Flammige",
    "Flanderns": "Flandern",
    "Flanierenden": "Flanierende",
    "Flanierenderen": "Flanierendere",
    "Flanierendsten": "Flanierendste",
    "Flanierens": "Flanieren",
    "Flanierte": "flaniert",
    "Flanierten": "Flanierte",
    "Flanierteren": "Flaniertere",
    "Flaniertesten": "Flanierteste",
    "Flanken": "Flanke",
    "Flankenden": "Flankende",
    "Flankenderen": "Flankendere",
    "Flankendsten": "Flankendste",
    "Flankens": "Flanken",
    "Flankierenden": "Flankierende",
    "Flankierenderen": "Flankierendere",
    "Flankierendsten": "Flankierendste",
    "Flankierens": "Flankieren",
    "Flankierte": "flankiert",
    "Flankierten": "Flankierte",
    "Flankierteren": "Flankiertere",
    "Flankiertesten": "Flankierteste",
    "Flanschenden": "Flanschende",
    "Flanschens": "Flanschen",
    "Flappen": "Flappe",
    "Flapsige": "flapsig",
    "Flapsigen": "Flapsige",
    "Flapsigeren": "Flapsigere",
    "Flapsigsten": "Flapsigste",
    "Flaschen": "Flasche",
    "Flattergeiste": "Flattergeist",
    "Flattergeister": "Flattergeist",
    "Flattergeistern": "Flattergeist",
    "Flattergeistes": "Flattergeist",
    "Flattergeists": "Flattergeist",
    "Flatterhafte": "flatterhaft",
    "Flatterhaften": "Flatterhafte",
    "Flatterhafteren": "Flatterhaftere",
    "Flatterhaftesten": "Flatterhafteste",
    "Flatterigen": "Flatterige",
    "Flatterigeren": "Flatterigere",
    "Flatterigsten": "Flatterigste",
    "Flatternden": "Flatternde",
    "Flatterns": "Flattern",
    "Flauenden": "Flauende",
    "Flauens": "Flauen",
    "Flaums": "Flaum",
    "Flaumweiche": "flaumweich",
    "Flaumweichen": "Flaumweiche",
    "Flaumweicheren": "Flaumweichere",
    "Flaumweichsten": "Flaumweichste",
    "Flauten": "Flaute",
    "Flechtenden": "Flechtende",
    "Flechtens": "Flechten",
    "Flechtwerke": "Flechtwerk",
    "Flechtwerken": "Flechtwerk",
    "Flechtwerks": "Flechtwerk",
    "Fleck": "flecken",
    "Fleckchens": "Fleckchen",
    "Flecke": "flecken",
    "Flecken": "Fleck",
    "Fleckenden": "Fleckende",
    "Fleckenderen": "Fleckendere",
    "Fleckendsten": "Fleckendste",
    "Fleckens": "Flecken",
    "Fleckes": "Fleck",
    "Fleckfiebers": "Fleckfieber",
    "Flecks": "Fleck",
    "Fleddernden": "Fleddernde",
    "Fleddernderen": "Fledderndere",
    "Fledderndsten": "Fledderndste",
    "Fledderns": "Fleddern",
    "Flegel": "flegeln",
    "Flegeleien": "Flegelei",
    "Flegeln": "Flegel",
    "Flegelnden": "Flegelnde",
    "Flegelnderen": "Flegelndere",
    "Flegelndsten": "Flegelndste",
    "Flegelns": "Flegeln",
    "Flegels": "Flegel",
    "Flehenden": "Flehende",
    "Flehenderen": "Flehendere",
    "Flehendsten": "Flehendste",
    "Flehens": "Flehen",
    "Fleische": "Fleisch",
    "Fleischereien": "Fleischerei",
    "Fleischern": "Fleischer",
    "Fleischerne": "fleischern",
    "Fleischernen": "Fleischerne",
    "Fleischers": "Fleischer",
    "Fleisches": "Fleisch",
    "Fleischessern": "Fleischesser",
    "Fleischessers": "Fleischesser",
    "Fleischfarbene": "fleischfarben",
    "Fleischfarbenen": "Fleischfarbene",
    "Fleischhauern": "Fleischhauer",
    "Fleischhauers": "Fleischhauer",
    "Fleischige": "fleischig",
    "Fleischigen": "Fleischige",
    "Fleischlosen": "Fleischlose",
    "Fleischloseren": "Fleischlosere",
    "Fleischlosesten": "Fleischloseste",
    "Fleischs": "Fleisch",
    "Fleischwaren": "Fleischware",
    "Fleißige": "fleißig",
    "Fleißigen": "Fleißige",
    "Fleißigeren": "Fleißigere",
    "Fleißigsten": "Fleißigste",
    "Flektierbaren": "Flektierbare",
    "Flektierenden": "Flektierende",
    "Flektierens": "Flektieren",
    "Flektierte": "flektiert",
    "Flektierten": "Flektierte",
    "Flennenden": "Flennende",
    "Flennenderen": "Flennendere",
    "Flennendsten": "Flennendste",
    "Flennens": "Flennen",
    "Fletschenden": "Fletschende",
    "Fletschenderen": "Fletschendere",
    "Fletschendsten": "Fletschendste",
    "Fletschens": "Fletschen",
    "Flexibelsten": "Flexibelste",
    "Flexibilitäten": "Flexibilität",
    "Flexible": "flexibel",
    "Flexiblen": "Flexible",
    "Flexibleren": "Flexiblere",
    "Flexionen": "Flexion",
    "Flicks": "Flick",
    "Flickschneidern": "Flickschneider",
    "Flickschneiders": "Flickschneider",
    "Flickschustereien": "Flickschusterei",
    "Flickschustern": "Flickschuster",
    "Flickschusters": "Flickschuster",
    "Fliederfarbene": "fliederfarben",
    "Fliederfarbenen": "Fliederfarbene",
    "Fliedern": "Flieder",
    "Flieders": "Flieder",
    "Fliege": "fliegen",
    "Fliegen": "Fliege",
    "Fliegenden": "Fliegende",
    "Fliegenfallen": "Fliegenfalle",
    "Fliegenfängern": "Fliegenfänger",
    "Fliegenfängers": "Fliegenfänger",
    "Fliegens": "Fliegen",
    "Fliegern": "Flieger",
    "Fliegers": "Flieger",
    "Fliehenden": "Fliehende",
    "Fliehens": "Fliehen",
    "Fliesen": "Fliese",
    "Fliesenden": "Fliesende",
    "Fliesens": "Fliesen",
    "Fließenden": "Fließende",
    "Fließens": "Fließen",
    "Flimmerkisten": "Flimmerkiste",
    "Flimmernden": "Flimmernde",
    "Flimmernderen": "Flimmerndere",
    "Flimmerndsten": "Flimmerndste",
    "Flimmerns": "Flimmern",
    "Flinken": "Flinke",
    "Flinkeren": "Flinkere",
    "Flinksten": "Flinkste",
    "Flinten": "Flinte",
    "Flippenden": "Flippende",
    "Flippens": "Flippen",
    "Flippernden": "Flippernde",
    "Flippernderen": "Flipperndere",
    "Flipperndsten": "Flipperndste",
    "Flipperns": "Flippern",
    "Flippigen": "Flippige",
    "Flippigeren": "Flippigere",
    "Flippigsten": "Flippigste",
    "Flirts": "Flirt",
    "Flittchens": "Flittchen",
    "Flitternden": "Flitternde",
    "Flitterns": "Flittern",
    "Flitzenden": "Flitzende",
    "Flitzenderen": "Flitzendere",
    "Flitzendsten": "Flitzendste",
    "Flitzens": "Flitzen",
    "Flitzern": "Flitzer",
    "Flitzers": "Flitzer",
    "Flockenden": "Flockende",
    "Flockens": "Flocken",
    "Flohe": "Floh",
    "Flohs": "Floh",
    "Floppenden": "Floppende",
    "Floppenderen": "Floppendere",
    "Floppendsten": "Floppendste",
    "Floppens": "Floppen",
    "Floppys": "Floppy",
    "Flops": "Flop",
    "Flore": "Flor",
    "Floren": "Flor",
    "Floreszenzen": "Floreszenz",
    "Florette": "Florett",
    "Floretten": "Florett",
    "Floretts": "Florett",
    "Florians": "Florian",
    "Floridas": "Florida",
    "Florierenden": "Florierende",
    "Florierenderen": "Florierendere",
    "Florierendsten": "Florierendste",
    "Florierens": "Florieren",
    "Florierte": "floriert",
    "Florierten": "Florierte",
    "Florierteren": "Floriertere",
    "Floriertesten": "Florierteste",
    "Floristinnen": "Floristin",
    "Floristische": "floristisch",
    "Floristischen": "Floristische",
    "Flors": "Flor",
    "Florstadts": "Florstadt",
    "Floskeln": "Floskel",
    "Flossen": "Flosse",
    "Flottbekommenden": "Flottbekommende",
    "Flottbekommenen": "Flottbekommene",
    "Flottbekommens": "Flottbekommen",
    "Flotten": "Flotte",
    "Flotteren": "Flottere",
    "Flottesten": "Flotteste",
    "Flottgekriegten": "Flottgekriegte",
    "Flottkriegenden": "Flottkriegende",
    "Flottkriegens": "Flottkriegen",
    "Fluch": "fluchen",
    "Fluche": "fluchen",
    "Fluchenden": "Fluchende",
    "Fluchenderen": "Fluchendere",
    "Fluchendsten": "Fluchendste",
    "Fluchens": "Fluchen",
    "Fluches": "Fluch",
    "Fluchs": "Fluch",
    "Fluchtartige": "fluchtartig",
    "Fluchtartigen": "Fluchtartige",
    "Fluchten": "Flucht",
    "Fluchtenden": "Fluchtende",
    "Fluchtens": "Fluchten",
    "Fluchthelfern": "Fluchthelfer",
    "Fluchthelfers": "Fluchthelfer",
    "Fluchtverdächtige": "fluchtverdächtig",
    "Fluchtverdächtigen": "Fluchtverdächtige",
    "Flugabwehrraketen": "Flugabwehrrakete",
    "Flugblatte": "Flugblatt",
    "Flugblattes": "Flugblatt",
    "Flugblatts": "Flugblatt",
    "Flugblätter": "Flugblatt",
    "Flugblättern": "Flugblatt",
    "Fluge": "Flug",
    "Fluges": "Flug",
    "Flughafens": "Flughafen",
    "Flughäfen": "Flughafen",
    "Flugs": "Flug",
    "Flugunfähige": "flugunfähig",
    "Flugunfähigen": "Flugunfähige",
    "Flugunfähigeren": "Flugunfähigere",
    "Flugunfähigsten": "Flugunfähigste",
    "Flugzeuge": "Flugzeug",
    "Flugzeugen": "Flugzeug",
    "Flugzeugs": "Flugzeug",
    "Fluktuierenden": "Fluktuierende",
    "Fluktuierenderen": "Fluktuierendere",
    "Fluktuierendsten": "Fluktuierendste",
    "Fluktuierens": "Fluktuieren",
    "Fluktuierte": "fluktuiert",
    "Fluktuierten": "Fluktuierte",
    "Fluktuierteren": "Fluktuiertere",
    "Fluktuiertesten": "Fluktuierteste",
    "Flunkernden": "Flunkernde",
    "Flunkernderen": "Flunkerndere",
    "Flunkerndsten": "Flunkerndste",
    "Flunkerns": "Flunkern",
    "Fluoride": "Fluorid",
    "Fluoriden": "Fluorid",
    "Fluorids": "Fluorid",
    "Fluorierungen": "Fluorierung",
    "Fluppenden": "Fluppende",
    "Fluppenderen": "Fluppendere",
    "Fluppendsten": "Fluppendste",
    "Fluppens": "Fluppen",
    "Flure": "Flur",
    "Fluren": "Flur",
    "Flures": "Flur",
    "Flurnamen": "Flurname",
    "Flurs": "Flur",
    "Flurschadens": "Flurschaden",
    "Flurschäden": "Flurschaden",
    "Flusen": "Fluse",
    "Flusse": "Fluß",
    "Flusses": "Fluß",
    "Fluten": "Flut",
    "Flutenden": "Flutende",
    "Flutens": "Fluten",
    "Flutlichte": "Flutlicht",
    "Flutlichtes": "Flutlicht",
    "Flutlichts": "Flutlicht",
    "Flutschenden": "Flutschende",
    "Flutschenderen": "Flutschendere",
    "Flutschendsten": "Flutschendste",
    "Flutschens": "Flutschen",
    "Flächen": "Fläche",
    "Flämische": "flämisch",
    "Flämischen": "Flämische",
    "Flämmchens": "Flämmchen",
    "Flämmende": "flämmend",
    "Flämmenden": "Flämmende",
    "Flämmendere": "flämmend",
    "Flämmenderen": "Flämmendere",
    "Flämmendste": "flämmend",
    "Flämmendsten": "Flämmendste",
    "Flämmens": "Flämmen",
    "Fläschchens": "Fläschchen",
    "Fläzenden": "Fläzende",
    "Fläzenderen": "Fläzendere",
    "Fläzendsten": "Fläzendste",
    "Fläzens": "Fläzen",
    "Flöhe": "Floh",
    "Flöhen": "Floh",
    "Flörsheims": "Flörsheim",
    "Flöten": "Flöte",
    "Flötenden": "Flötende",
    "Flötenderen": "Flötendere",
    "Flötendsten": "Flötendste",
    "Flötengegangenen": "Flötengegangene",
    "Flötengehenden": "Flötengehende",
    "Flötengehens": "Flötengehen",
    "Flötens": "Flöten",
    "Flötisten": "Flötist",
    "Flötistinnen": "Flötistin",
    "Flößenden": "Flößende",
    "Flößens": "Flößen",
    "Flüche": "Fluch",
    "Flüchen": "Fluch",
    "Flüchte": "flüchten",
    "Flüchten": "Flucht",
    "Flüchtende": "flüchtend",
    "Flüchtenden": "Flüchtende",
    "Flüchtens": "Flüchten",
    "Flüchtige": "flüchtig",
    "Flüchtigen": "Flüchtige",
    "Flüchtlinge": "Flüchtling",
    "Flüchtlingen": "Flüchtling",
    "Flüchtlinges": "Flüchtling",
    "Flüchtlings": "Flüchtling",
    "Flüge": "Flug",
    "Flügellahme": "flügellahm",
    "Flügellahmen": "Flügellahme",
    "Flügellahmeren": "Flügellahmere",
    "Flügellahmsten": "Flügellahmste",
    "Flügeln": "Flügel",
    "Flügels": "Flügel",
    "Flügelstürmern": "Flügelstürmer",
    "Flügelstürmers": "Flügelstürmer",
    "Flügen": "Flug",
    "Flüsse": "Fluß",
    "Flüssen": "Fluß",
    "Flüssige": "flüssig",
    "Flüssigen": "Flüssige",
    "Flüssigeren": "Flüssigere",
    "Flüssigkeiten": "Flüssigkeit",
    "Flüssigste": "flüssig",
    "Flüssigsten": "Flüssigste",
    "Flüstergewölben": "Flüstergewölbe",
    "Flüstergewölbes": "Flüstergewölbe",
    "Flüsternden": "Flüsternde",
    "Flüsterns": "Flüstern",
    "Flüstertone": "Flüsterton",
    "Flüstertons": "Flüsterton",
    "Flüstertöne": "Flüsterton",
    "Flüstertönen": "Flüsterton",
    "Fohlens": "Fohlen",
    "Fokussierenden": "Fokussierende",
    "Fokussierenderen": "Fokussierendere",
    "Fokussierendsten": "Fokussierendste",
    "Fokussierens": "Fokussieren",
    "Fokussierte": "fokussiert",
    "Fokussierten": "Fokussierte",
    "Fokussierteren": "Fokussiertere",
    "Fokussiertesten": "Fokussierteste",
    "Folgen": "Folge",
    "Folgenden": "Folgende",
    "Folgenlosen": "Folgenlose",
    "Folgenloseren": "Folgenlosere",
    "Folgenlosesten": "Folgenloseste",
    "Folgens": "Folgen",
    "Folgenschwere": "folgenschwer",
    "Folgenschweren": "Folgenschwere",
    "Folgenschwereren": "Folgenschwerere",
    "Folgenschwersten": "Folgenschwerste",
    "Folgerichtigen": "Folgerichtige",
    "Folgernden": "Folgernde",
    "Folgerns": "Folgern",
    "Folgerungen": "Folgerung",
    "Folgeschadens": "Folgeschaden",
    "Folgeschäden": "Folgeschaden",
    "Folgsamen": "Folgsame",
    "Folien": "Folie",
    "Folter": "foltern",
    "Foltern": "Folter",
    "Folternden": "Folternde",
    "Folternderen": "Folterndere",
    "Folterndsten": "Folterndste",
    "Folterns": "Foltern",
    "Folterungen": "Folterung",
    "Fonds": "Fond",
    "Fonotypistinnen": "Fonotypistin",
    "Fontanellen": "Fontanelle",
    "Fontänen": "Fontäne",
    "Foppenden": "Foppende",
    "Foppenderen": "Foppendere",
    "Foppendsten": "Foppendste",
    "Foppens": "Foppen",
    "Foppereien": "Fopperei",
    "Forcierenden": "Forcierende",
    "Forcierenderen": "Forcierendere",
    "Forcierendsten": "Forcierendste",
    "Forcierens": "Forcieren",
    "Forcierte": "forciert",
    "Forcierten": "Forcierte",
    "Forcierteren": "Forciertere",
    "Forciertesten": "Forcierteste",
    "Fordernden": "Fordernde",
    "Fordernderen": "Forderndere",
    "Forderndsten": "Forderndste",
    "Forderns": "Fordern",
    "Forderungen": "Forderung",
    "Fords": "Ford",
    "Forellen": "Forelle",
    "Foren": "Forum",
    "Forensische": "forensisch",
    "Forensischen": "Forensische",
    "Forken": "Forke",
    "Form": "formen",
    "Formale": "formal",
    "Formalen": "Formale",
    "Formaleren": "Formalere",
    "Formalisierenden": "Formalisierende",
    "Formalisierenderen": "Formalisierendere",
    "Formalisierens": "Formalisieren",
    "Formalisierte": "formalisiert",
    "Formalisierten": "Formalisierte",
    "Formalisierteren": "Formalisiertere",
    "Formalisiertesten": "Formalisierteste",
    "Formalisten": "Formalist",
    "Formalitäten": "Formalität",
    "Formalste": "formal",
    "Formalsten": "Formalste",
    "Formate": "Format",
    "Formaten": "Format",
    "Formates": "Format",
    "Formatierenden": "Formatierende",
    "Formatierenderen": "Formatierendere",
    "Formatierendsten": "Formatierendste",
    "Formatierens": "Formatieren",
    "Formatierte": "formatiert",
    "Formatierten": "Formatierte",
    "Formatierteren": "Formatiertere",
    "Formatiertesten": "Formatierteste",
    "Formatierungen": "Formatierung",
    "Formationen": "Formation",
    "Formative": "formativ",
    "Formativen": "Formative",
    "Formats": "Format",
    "Formbare": "formbar",
    "Formbaren": "Formbare",
    "Formbareren": "Formbarere",
    "Formbarsten": "Formbarste",
    "Formbeständigen": "Formbeständige",
    "Formbeständigeren": "Formbeständigere",
    "Formbeständigsten": "Formbeständigste",
    "Formblatte": "Formblatt",
    "Formblattes": "Formblatt",
    "Formblatts": "Formblatt",
    "Formblätter": "Formblatt",
    "Formblättern": "Formblatt",
    "Formelhaften": "Formelhafte",
    "Formelhafteren": "Formelhaftere",
    "Formelhaftesten": "Formelhafteste",
    "Formellen": "Formelle",
    "Formelleren": "Formellere",
    "Formellsten": "Formellste",
    "Formeln": "Formel",
    "Formen": "Form",
    "Formenden": "Formende",
    "Formenlehren": "Formenlehre",
    "Formens": "Formen",
    "Formern": "Former",
    "Formers": "Former",
    "Formierenden": "Formierende",
    "Formierens": "Formieren",
    "Formierte": "formiert",
    "Formierten": "Formierte",
    "Formierungen": "Formierung",
    "Formlosen": "Formlose",
    "Formschönen": "Formschöne",
    "Formschöneren": "Formschönere",
    "Formschönsten": "Formschönste",
    "Formulare": "Formular",
    "Formularen": "Formular",
    "Formulars": "Formular",
    "Formulierenden": "Formulierende",
    "Formulierens": "Formulieren",
    "Formulierte": "formuliert",
    "Formulierten": "Formulierte",
    "Formulierungen": "Formulierung",
    "Formvollendete": "formvollendet",
    "Formvollendeten": "Formvollendete",
    "Forschenden": "Forschende",
    "Forschenderen": "Forschendere",
    "Forschendsten": "Forschendste",
    "Forschens": "Forschen",
    "Forschern": "Forscher",
    "Forschers": "Forscher",
    "Forschungen": "Forschung",
    "Forstamte": "Forstamt",
    "Forstamtes": "Forstamt",
    "Forstamts": "Forstamt",
    "Forste": "forsten",
    "Forsten": "Forst",
    "Forstenden": "Forstende",
    "Forstens": "Forsten",
    "Forstes": "Forst",
    "Forstrechtlichen": "Forstrechtliche",
    "Forsttechnischen": "Forsttechnische",
    "Forstämter": "Forstamt",
    "Forstämtern": "Forstamt",
    "Fortbegebenden": "Fortbegebende",
    "Fortbegebenen": "Fortbegebene",
    "Fortbegebens": "Fortbegeben",
    "Fortbestandenen": "Fortbestandene",
    "Fortbestehenden": "Fortbestehende",
    "Fortbestehens": "Fortbestehen",
    "Fortbewegenden": "Fortbewegende",
    "Fortbewegens": "Fortbewegen",
    "Fortbewegte": "fortbewegt",
    "Fortbewegten": "Fortbewegte",
    "Fortbewogenen": "Fortbewogene",
    "Fortbildenden": "Fortbildende",
    "Fortbildens": "Fortbilden",
    "Fortbildungen": "Fortbildung",
    "Fortblasenden": "Fortblasende",
    "Fortblasens": "Fortblasen",
    "Fortbleibenden": "Fortbleibende",
    "Fortbleibens": "Fortbleiben",
    "Fortbringenden": "Fortbringende",
    "Fortbringens": "Fortbringen",
    "Fortdauernden": "Fortdauernde",
    "Fortdauerns": "Fortdauern",
    "Fortdenkenden": "Fortdenkende",
    "Fortdenkens": "Fortdenken",
    "Fortdrängenden": "Fortdrängende",
    "Fortdrängens": "Fortdrängen",
    "Forteilenden": "Forteilende",
    "Forteilens": "Forteilen",
    "Fortfallenden": "Fortfallende",
    "Fortfallens": "Fortfallen",
    "Fortfliegenden": "Fortfliegende",
    "Fortfliegens": "Fortfliegen",
    "Fortführenden": "Fortführende",
    "Fortführens": "Fortführen",
    "Fortgange": "Fortgang",
    "Fortganges": "Fortgang",
    "Fortgangs": "Fortgang",
    "Fortgebenden": "Fortgebende",
    "Fortgebens": "Fortgeben",
    "Fortgebildeten": "Fortgebildete",
    "Fortgeblasenen": "Fortgeblasene",
    "Fortgebliebenen": "Fortgebliebene",
    "Fortgebrachten": "Fortgebrachte",
    "Fortgedachten": "Fortgedachte",
    "Fortgedauerten": "Fortgedauerte",
    "Fortgedrängten": "Fortgedrängte",
    "Fortgeeilten": "Fortgeeilte",
    "Fortgefallenen": "Fortgefallene",
    "Fortgeflogenen": "Fortgeflogene",
    "Fortgeführten": "Fortgeführte",
    "Fortgegebenen": "Fortgegebene",
    "Fortgegossenen": "Fortgegossene",
    "Fortgejagten": "Fortgejagte",
    "Fortgekommenen": "Fortgekommene",
    "Fortgekrochenen": "Fortgekrochene",
    "Fortgelassenen": "Fortgelassene",
    "Fortgelebten": "Fortgelebte",
    "Fortgemachten": "Fortgemachte",
    "Fortgenommenen": "Fortgenommene",
    "Fortgepflanzten": "Fortgepflanzte",
    "Fortgerannten": "Fortgerannte",
    "Fortgereisten": "Fortgereiste",
    "Fortgerissenen": "Fortgerissene",
    "Fortgerittenen": "Fortgerittene",
    "Fortgeräumten": "Fortgeräumte",
    "Fortgescherten": "Fortgescherte",
    "Fortgescheuchten": "Fortgescheuchte",
    "Fortgeschleppten": "Fortgeschleppte",
    "Fortgeschleuderten": "Fortgeschleuderte",
    "Fortgeschlichenen": "Fortgeschlichene",
    "Fortgeschnellten": "Fortgeschnellte",
    "Fortgeschobenen": "Fortgeschobene",
    "Fortgeschorenen": "Fortgeschorene",
    "Fortgeschriebenen": "Fortgeschriebene",
    "Fortgeschrittenen": "Fortgeschrittene",
    "Fortgeschritteneren": "Fortgeschrittenere",
    "Fortgeschwommenen": "Fortgeschwommene",
    "Fortgesehnten": "Fortgesehnte",
    "Fortgesehnteren": "Fortgesehntere",
    "Fortgesehntesten": "Fortgesehnteste",
    "Fortgesetzten": "Fortgesetzte",
    "Fortgesprungenen": "Fortgesprungene",
    "Fortgestohlenen": "Fortgestohlene",
    "Fortgestohleneren": "Fortgestohlenere",
    "Fortgestohlensten": "Fortgestohlenste",
    "Fortgestürmten": "Fortgestürmte",
    "Fortgestürzten": "Fortgestürzte",
    "Fortgetragenen": "Fortgetragene",
    "Fortgetriebenen": "Fortgetriebene",
    "Fortgewirkten": "Fortgewirkte",
    "Fortgewischten": "Fortgewischte",
    "Fortgeworfenen": "Fortgeworfene",
    "Fortgewährten": "Fortgewährte",
    "Fortgewälzten": "Fortgewälzte",
    "Fortgewünschten": "Fortgewünschte",
    "Fortgezahlten": "Fortgezahlte",
    "Fortgezerrten": "Fortgezerrte",
    "Fortgießenden": "Fortgießende",
    "Fortgießens": "Fortgießen",
    "Fortgänge": "Fortgang",
    "Fortgängen": "Fortgang",
    "Fortjagenden": "Fortjagende",
    "Fortjagens": "Fortjagen",
    "Fortkommenden": "Fortkommende",
    "Fortkommens": "Fortkommen",
    "Fortkriechenden": "Fortkriechende",
    "Fortkriechens": "Fortkriechen",
    "Fortlassenden": "Fortlassende",
    "Fortlassens": "Fortlassen",
    "Fortlaufenden": "Fortlaufende",
    "Fortlebenden": "Fortlebende",
    "Fortlebens": "Fortleben",
    "Fortmachenden": "Fortmachende",
    "Fortmachens": "Fortmachen",
    "Fortmarschierenden": "Fortmarschierende",
    "Fortmarschierens": "Fortmarschieren",
    "Fortmarschierte": "fortmarschiert",
    "Fortmarschierten": "Fortmarschierte",
    "Fortnehmenden": "Fortnehmende",
    "Fortnehmens": "Fortnehmen",
    "Fortpflanzenden": "Fortpflanzende",
    "Fortpflanzens": "Fortpflanzen",
    "Fortreisenden": "Fortreisende",
    "Fortreisens": "Fortreisen",
    "Fortreitenden": "Fortreitende",
    "Fortreitens": "Fortreiten",
    "Fortreißenden": "Fortreißende",
    "Fortreißens": "Fortreißen",
    "Fortrennenden": "Fortrennende",
    "Fortrennens": "Fortrennen",
    "Forträumenden": "Forträumende",
    "Forträumens": "Forträumen",
    "Fortscherenden": "Fortscherende",
    "Fortscherens": "Fortscheren",
    "Fortscheuchenden": "Fortscheuchende",
    "Fortscheuchens": "Fortscheuchen",
    "Fortschiebenden": "Fortschiebende",
    "Fortschiebens": "Fortschieben",
    "Fortschleichenden": "Fortschleichende",
    "Fortschleichens": "Fortschleichen",
    "Fortschleppenden": "Fortschleppende",
    "Fortschleppens": "Fortschleppen",
    "Fortschleudernden": "Fortschleudernde",
    "Fortschleuderns": "Fortschleudern",
    "Fortschnellenden": "Fortschnellende",
    "Fortschnellens": "Fortschnellen",
    "Fortschreibenden": "Fortschreibende",
    "Fortschreibens": "Fortschreiben",
    "Fortschreite": "fortschreiten",
    "Fortschreitenden": "Fortschreitende",
    "Fortschreitenderen": "Fortschreitendere",
    "Fortschreitens": "Fortschreiten",
    "Fortschritt": "fortschreiten",
    "Fortschritte": "Fortschritt",
    "Fortschritten": "Fortschritt",
    "Fortschrittlern": "Fortschrittler",
    "Fortschrittlers": "Fortschrittler",
    "Fortschrittliche": "fortschrittlich",
    "Fortschrittlichen": "Fortschrittliche",
    "Fortschrittlicheren": "Fortschrittlichere",
    "Fortschritts": "Fortschritt",
    "Fortschrittsgläubige": "fortschrittsgläubig",
    "Fortschrittsgläubigen": "Fortschrittsgläubige",
    "Fortschrittsgläubigeren": "Fortschrittsgläubigere",
    "Fortschwimmenden": "Fortschwimmende",
    "Fortschwimmens": "Fortschwimmen",
    "Fortsehnenden": "Fortsehnende",
    "Fortsehnenderen": "Fortsehnendere",
    "Fortsehnendsten": "Fortsehnendste",
    "Fortsehnens": "Fortsehnen",
    "Fortsetzenden": "Fortsetzende",
    "Fortsetzens": "Fortsetzen",
    "Fortsetzungen": "Fortsetzung",
    "Fortspringenden": "Fortspringende",
    "Fortspringens": "Fortspringen",
    "Fortstehlenden": "Fortstehlende",
    "Fortstehlenderen": "Fortstehlendere",
    "Fortstehlendsten": "Fortstehlendste",
    "Fortstehlens": "Fortstehlen",
    "Fortstürmenden": "Fortstürmende",
    "Fortstürmens": "Fortstürmen",
    "Fortstürzenden": "Fortstürzende",
    "Fortstürzens": "Fortstürzen",
    "Forttragenden": "Forttragende",
    "Forttragens": "Forttragen",
    "Forttreibenden": "Forttreibende",
    "Forttreibens": "Forttreiben",
    "Fortwerfenden": "Fortwerfende",
    "Fortwerfens": "Fortwerfen",
    "Fortwirkenden": "Fortwirkende",
    "Fortwirkens": "Fortwirken",
    "Fortwischenden": "Fortwischende",
    "Fortwischens": "Fortwischen",
    "Fortwährenden": "Fortwährende",
    "Fortwährens": "Fortwähren",
    "Fortwälzenden": "Fortwälzende",
    "Fortwälzens": "Fortwälzen",
    "Fortwünschenden": "Fortwünschende",
    "Fortwünschens": "Fortwünschen",
    "Fortzahlenden": "Fortzahlende",
    "Fortzahlens": "Fortzahlen",
    "Fortzahlungen": "Fortzahlung",
    "Fortzerrenden": "Fortzerrende",
    "Fortzerrens": "Fortzerren",
    "Forums": "Forum",
    "Fossile": "Fossil",
    "Fossilen": "Fossile",
    "Fossils": "Fossil",
    "Fotografen": "Fotograf",
    "Fotografien": "Fotografie",
    "Fotografierenden": "Fotografierende",
    "Fotografierens": "Fotografieren",
    "Fotografierte": "fotografiert",
    "Fotografierten": "Fotografierte",
    "Fotografierteren": "Fotografiertere",
    "Fotografiertesten": "Fotografierteste",
    "Fotographien": "Fotographie",
    "Fotokopierenden": "Fotokopierende",
    "Fotokopierens": "Fotokopieren",
    "Fotokopierte": "fotokopiert",
    "Fotokopierten": "Fotokopierte",
    "Fotolaboranten": "Fotolaborant",
    "Fotos": "Foto",
    "Fototherapien": "Fototherapie",
    "Fotzen": "Fotze",
    "Foul": "foulen",
    "Foulenden": "Foulende",
    "Foulenderen": "Foulendere",
    "Foulendsten": "Foulendste",
    "Foulens": "Foulen",
    "Fouls": "Foul",
    "Fouriers": "Fourier",
    "Foyers": "Foyer",
    "Frachten": "Fracht",
    "Frachtenden": "Frachtende",
    "Frachtenderen": "Frachtendere",
    "Frachtendsten": "Frachtendste",
    "Frachtens": "Frachten",
    "Frachtern": "Frachter",
    "Frachters": "Frachter",
    "Frachtfreien": "Frachtfreie",
    "Fragebogens": "Fragebogen",
    "Fragebögen": "Fragebogen",
    "Fragen": "Frage",
    "Fragenden": "Fragende",
    "Fragenderen": "Fragendere",
    "Fragendsten": "Fragendste",
    "Fragens": "Fragen",
    "Fragern": "Frager",
    "Fragers": "Frager",
    "Fragilen": "Fragile",
    "Fragileren": "Fragilere",
    "Fragilsten": "Fragilste",
    "Fraglichen": "Fragliche",
    "Fraglicheren": "Fraglichere",
    "Fraglichsten": "Fraglichste",
    "Fraglosen": "Fraglose",
    "Fragloseren": "Fraglosere",
    "Fraglosesten": "Fragloseste",
    "Fragmentarischen": "Fragmentarische",
    "Fragmente": "Fragment",
    "Fragmenten": "Fragment",
    "Fragments": "Fragment",
    "Fragwürdigen": "Fragwürdige",
    "Fragwürdigeren": "Fragwürdigere",
    "Fragwürdigsten": "Fragwürdigste",
    "Fraktalen": "Fraktale",
    "Fraktals": "Fraktal",
    "Fraktionen": "Fraktion",
    "Fraktionierenden": "Fraktionierende",
    "Fraktionierens": "Fraktionieren",
    "Fraktionierte": "fraktioniert",
    "Fraktionierten": "Fraktionierte",
    "Fraktionsvorsitzenden": "Fraktionsvorsitzende",
    "Frakturen": "Fraktur",
    "Franken": "Franke",
    "Frankens": "Franken",
    "Frankfurterinnen": "Frankfurterin",
    "Frankfurtern": "Frankfurter",
    "Frankfurters": "Frankfurter",
    "Frankfurts": "Frankfurt",
    "Frankierenden": "Frankierende",
    "Frankierens": "Frankieren",
    "Frankiermaschinen": "Frankiermaschine",
    "Frankierte": "frankiert",
    "Frankierten": "Frankierte",
    "Frankreichs": "Frankreich",
    "Franks": "Frank",
    "Franse": "fransen",
    "Fransen": "Franse",
    "Fransenden": "Fransende",
    "Fransenderen": "Fransendere",
    "Fransendsten": "Fransendste",
    "Fransens": "Fransen",
    "Fransigen": "Fransige",
    "Fransigeren": "Fransigere",
    "Fransigsten": "Fransigste",
    "Franz": "franzen",
    "Franzenden": "Franzende",
    "Franzenderen": "Franzendere",
    "Franzendsten": "Franzendste",
    "Franzens": "Franzen",
    "Franzensbads": "Franzensbad",
    "Franziskanern": "Franziskaner",
    "Franziskaners": "Franziskaner",
    "Franzosen": "Franzose",
    "Französische": "französisch",
    "Französischen": "Französische",
    "Frappierenden": "Frappierende",
    "Frappierenderen": "Frappierendere",
    "Frappierendsten": "Frappierendste",
    "Frappierens": "Frappieren",
    "Frappierte": "frappiert",
    "Frappierten": "Frappierte",
    "Frappierteren": "Frappiertere",
    "Frappiertesten": "Frappierteste",
    "Fraternisierenden": "Fraternisierende",
    "Fraternisierenderen": "Fraternisierendere",
    "Fraternisierens": "Fraternisieren",
    "Fraternisierte": "fraternisiert",
    "Fraternisierten": "Fraternisierte",
    "Fraternisierteren": "Fraternisiertere",
    "Fraternisierteste": "fraternisiert",
    "Fratzen": "Fratze",
    "Fratzenhafte": "fratzenhaft",
    "Fratzenhaften": "Fratzenhafte",
    "Fratzenhafteren": "Fratzenhaftere",
    "Fratzenhaftesten": "Fratzenhafteste",
    "Frauchens": "Frauchen",
    "Frauen": "Frau",
    "Frauenhafte": "frauenhaft",
    "Frauenhaften": "Frauenhafte",
    "Frauenhafteren": "Frauenhaftere",
    "Frauenhaftesten": "Frauenhafteste",
    "Frauenpolitischen": "Frauenpolitische",
    "Frauenpolitischeren": "Frauenpolitischere",
    "Frauenrechtlerinnen": "Frauenrechtlerin",
    "Frauliche": "fraulich",
    "Fraulichen": "Frauliche",
    "Fraulicheren": "Fraulichere",
    "Fraulichsten": "Fraulichste",
    "Frechen": "Freche",
    "Frechenheims": "Frechenheim",
    "Frecheren": "Frechere",
    "Frechheiten": "Frechheit",
    "Frechste": "frech",
    "Frechsten": "Frechste",
    "Freds": "Fred",
    "Fregatten": "Fregatte",
    "Freibade": "Freibad",
    "Freibades": "Freibad",
    "Freibads": "Freibad",
    "Freiberufliche": "freiberuflich",
    "Freiberuflichen": "Freiberufliche",
    "Freibetrage": "Freibetrag",
    "Freibetrages": "Freibetrag",
    "Freibetrags": "Freibetrag",
    "Freibeträge": "Freibetrag",
    "Freibeträgen": "Freibetrag",
    "Freibewegliche": "freibeweglich",
    "Freibeweglichen": "Freibewegliche",
    "Freibleibenden": "Freibleibende",
    "Freibriefe": "Freibrief",
    "Freibriefen": "Freibrief",
    "Freibriefs": "Freibrief",
    "Freiburgern": "Freiburger",
    "Freiburgers": "Freiburger",
    "Freiburgs": "Freiburg",
    "Freibäder": "Freibad",
    "Freibädern": "Freibad",
    "Freidemokraten": "Freidemokrat",
    "Freie": "frei",
    "Freien": "Freie",
    "Freier": "frei",
    "Freieren": "Freiere",
    "Freiern": "Freier",
    "Freiers": "Freier",
    "Freiesten": "Freieste",
    "Freifahrkarten": "Freifahrkarte",
    "Freiflächen": "Freifläche",
    "Freigaben": "freigeben",
    "Freigebenden": "Freigebende",
    "Freigebens": "Freigeben",
    "Freigegebenen": "Freigegebene",
    "Freigehaltenen": "Freigehaltene",
    "Freigehegen": "Freigehege",
    "Freigeheges": "Freigehege",
    "Freigeiste": "Freigeist",
    "Freigeister": "Freigeist",
    "Freigeistern": "Freigeist",
    "Freigeistes": "Freigeist",
    "Freigeists": "Freigeist",
    "Freigekauften": "Freigekaufte",
    "Freigelassenen": "Freigelassene",
    "Freigelegten": "Freigelegte",
    "Freigelegteren": "Freigelegtere",
    "Freigelegtesten": "Freigelegteste",
    "Freigemachten": "Freigemachte",
    "Freigemachteren": "Freigemachtere",
    "Freigemachtesten": "Freigemachteste",
    "Freigepreßten": "Freigepreßte",
    "Freigepäcke": "Freigepäck",
    "Freigepäcken": "Freigepäck",
    "Freigepäcks": "Freigepäck",
    "Freigeschwommenen": "Freigeschwommene",
    "Freigeschwommeneren": "Freigeschwommenere",
    "Freigesetzten": "Freigesetzte",
    "Freigespielten": "Freigespielte",
    "Freigespielteren": "Freigespieltere",
    "Freigespieltesten": "Freigespielteste",
    "Freigesprochenen": "Freigesprochene",
    "Freigestandenen": "Freigestandene",
    "Freigestellten": "Freigestellte",
    "Freigestempelten": "Freigestempelte",
    "Freigiebigen": "Freigiebige",
    "Freigiebigeren": "Freigiebigere",
    "Freigiebigsten": "Freigiebigste",
    "Freigute": "Freigut",
    "Freiguts": "Freigut",
    "Freigängern": "Freigänger",
    "Freigängers": "Freigänger",
    "Freigüter": "Freigut",
    "Freigütern": "Freigut",
    "Freihafens": "Freihafen",
    "Freihaltenden": "Freihaltende",
    "Freihaltens": "Freihalten",
    "Freiheiten": "Freiheit",
    "Freiheitliche": "freiheitlich",
    "Freiheitlichen": "Freiheitliche",
    "Freiheitlicheren": "Freiheitlichere",
    "Freiheitlichsten": "Freiheitlichste",
    "Freiheitsliebenden": "Freiheitsliebende",
    "Freiheitsliebenderen": "Freiheitsliebendere",
    "Freiherren": "Freiherr",
    "Freihofe": "Freihof",
    "Freihofs": "Freihof",
    "Freihäfen": "Freihafen",
    "Freihändigen": "Freihändige",
    "Freihöfe": "Freihof",
    "Freihöfen": "Freihof",
    "Freikaufenden": "Freikaufende",
    "Freikaufens": "Freikaufen",
    "Freilassenden": "Freilassende",
    "Freilassens": "Freilassen",
    "Freilassungen": "Freilassung",
    "Freilebende": "freilebend",
    "Freilebenden": "Freilebende",
    "Freilegenden": "Freilegende",
    "Freilegenderen": "Freilegendere",
    "Freilegendsten": "Freilegendste",
    "Freilegens": "Freilegen",
    "Freileitungen": "Freileitung",
    "Freilichtbühnen": "Freilichtbühne",
    "Freilichtkinos": "Freilichtkino",
    "Freilichttheatern": "Freilichttheater",
    "Freilichttheaters": "Freilichttheater",
    "Freimachenden": "Freimachende",
    "Freimachenderen": "Freimachendere",
    "Freimachendsten": "Freimachendste",
    "Freimachens": "Freimachen",
    "Freimachungen": "Freimachung",
    "Freimarken": "Freimarke",
    "Freimaurern": "Freimaurer",
    "Freimaurers": "Freimaurer",
    "Freimütige": "freimütig",
    "Freimütigen": "Freimütige",
    "Freimütigeren": "Freimütigere",
    "Freimütigsten": "Freimütigste",
    "Freipressenden": "Freipressende",
    "Freipressens": "Freipressen",
    "Freiraume": "Freiraum",
    "Freiraums": "Freiraum",
    "Freiräume": "Freiraum",
    "Freiräumen": "Freiraum",
    "Freischaffende": "freischaffend",
    "Freischaffenden": "Freischaffende",
    "Freischaren": "Freischar",
    "Freischlage": "Freischlag",
    "Freischlags": "Freischlag",
    "Freischläge": "Freischlag",
    "Freischlägen": "Freischlag",
    "Freischwimmenden": "Freischwimmende",
    "Freischwimmenderen": "Freischwimmendere",
    "Freischwimmens": "Freischwimmen",
    "Freischwimmern": "Freischwimmer",
    "Freischwimmers": "Freischwimmer",
    "Freischärlern": "Freischärler",
    "Freischärlers": "Freischärler",
    "Freischülern": "Freischüler",
    "Freischülers": "Freischüler",
    "Freischützen": "Freischütz",
    "Freisetzenden": "Freisetzende",
    "Freisetzens": "Freisetzen",
    "Freispielenden": "Freispielende",
    "Freispielenderen": "Freispielendere",
    "Freispielendsten": "Freispielendste",
    "Freispielens": "Freispielen",
    "Freisprechenden": "Freisprechende",
    "Freisprechens": "Freisprechen",
    "Freisprechungen": "Freisprechung",
    "Freispruche": "Freispruch",
    "Freispruchs": "Freispruch",
    "Freisprüche": "Freispruch",
    "Freisprüchen": "Freispruch",
    "Freistaate": "Freistaat",
    "Freistaaten": "Freistaat",
    "Freistaats": "Freistaat",
    "Freistehenden": "Freistehende",
    "Freistehenderen": "Freistehendere",
    "Freistehendsten": "Freistehendste",
    "Freistehens": "Freistehen",
    "Freistellenden": "Freistellende",
    "Freistellens": "Freistellen",
    "Freistempelnden": "Freistempelnde",
    "Freistempelns": "Freistempeln",
    "Freistemplern": "Freistempler",
    "Freistemplers": "Freistempler",
    "Freistils": "Freistil",
    "Freitagabende": "Freitagabend",
    "Freitagabenden": "Freitagabend",
    "Freitagabends": "Freitagabend",
    "Freitage": "Freitag",
    "Freitagen": "Freitag",
    "Freitages": "Freitag",
    "Freitags": "Freitag",
    "Freitods": "Freitod",
    "Freitragende": "freitragend",
    "Freitragenden": "Freitragende",
    "Freitragenderen": "Freitragendere",
    "Freitragendsten": "Freitragendste",
    "Freiumschlage": "Freiumschlag",
    "Freiumschlags": "Freiumschlag",
    "Freiumschläge": "Freiumschlag",
    "Freiumschlägen": "Freiumschlag",
    "Freiverkehrs": "Freiverkehr",
    "Freiwerbern": "Freiwerber",
    "Freiwerbers": "Freiwerber",
    "Freiwilde": "Freiwild",
    "Freiwildes": "Freiwild",
    "Freiwilds": "Freiwild",
    "Freiwillige": "freiwillig",
    "Freiwilligen": "Freiwillige",
    "Freiwilligeren": "Freiwilligere",
    "Freiwilligsten": "Freiwilligste",
    "Freiwurfe": "Freiwurf",
    "Freiwurfs": "Freiwurf",
    "Freiwürfe": "Freiwurf",
    "Freiwürfen": "Freiwurf",
    "Freizeiten": "Freizeit",
    "Freizügigen": "Freizügige",
    "Freizügigeren": "Freizügigere",
    "Freizügigsten": "Freizügigste",
    "Freiübungen": "Freiübung",
    "Fremdarbeitern": "Fremdarbeiter",
    "Fremdarbeiters": "Fremdarbeiter",
    "Fremdartige": "fremdartig",
    "Fremdartigen": "Fremdartige",
    "Fremdelnden": "Fremdelnde",
    "Fremdelnderen": "Fremdelndere",
    "Fremdelndsten": "Fremdelndste",
    "Fremdelns": "Fremdeln",
    "Fremden": "Fremde",
    "Fremdenbuche": "Fremdenbuch",
    "Fremdenbuches": "Fremdenbuch",
    "Fremdenbuchs": "Fremdenbuch",
    "Fremdenbücher": "Fremdenbuch",
    "Fremdenbüchern": "Fremdenbuch",
    "Fremdenführern": "Fremdenführer",
    "Fremdenführers": "Fremdenführer",
    "Fremdenzimmern": "Fremdenzimmer",
    "Fremdenzimmers": "Fremdenzimmer",
    "Fremdgegangenen": "Fremdgegangene",
    "Fremdgehenden": "Fremdgehende",
    "Fremdgehens": "Fremdgehen",
    "Fremdheiten": "Fremdheit",
    "Fremdländische": "fremdländisch",
    "Fremdländischen": "Fremdländische",
    "Fremdsprachigen": "Fremdsprachige",
    "Fremdsprachlichen": "Fremdsprachliche",
    "Fremdstämmigen": "Fremdstämmige",
    "Fremdworte": "Fremdwort",
    "Fremdwortes": "Fremdwort",
    "Fremdwortfreie": "fremdwortfrei",
    "Fremdwortfreien": "Fremdwortfreie",
    "Fremdworts": "Fremdwort",
    "Fremdwörter": "Fremdwort",
    "Fremdwörtern": "Fremdwort",
    "Frenetischen": "Frenetische",
    "Frenetischeren": "Frenetischere",
    "Frenetischsten": "Frenetischste",
    "Frequentationen": "Frequentation",
    "Frequente": "frequent",
    "Frequenten": "Frequente",
    "Frequentierenden": "Frequentierende",
    "Frequentierenderen": "Frequentierendere",
    "Frequentierens": "Frequentieren",
    "Frequentierte": "frequentiert",
    "Frequentierten": "Frequentierte",
    "Frequentierteren": "Frequentiertere",
    "Frequentiertesten": "Frequentierteste",
    "Frequenzen": "Frequenz",
    "Fresse": "fressen",
    "Fressen": "Fresse",
    "Fressenden": "Fressende",
    "Fressens": "Fressen",
    "Fressereien": "Fresserei",
    "Fressern": "Fresser",
    "Fressers": "Fresser",
    "Freuden": "Freude",
    "Freudenrufe": "Freudenruf",
    "Freudenrufen": "Freudenruf",
    "Freudenrufs": "Freudenruf",
    "Freudentage": "Freudentag",
    "Freudentagen": "Freudentag",
    "Freudentags": "Freudentag",
    "Freudestrahlende": "freudestrahlend",
    "Freudestrahlenden": "Freudestrahlende",
    "Freudestrahlenderen": "Freudestrahlendere",
    "Freudigen": "Freudige",
    "Freudigeren": "Freudigere",
    "Freudigsten": "Freudigste",
    "Freuds": "Freud",
    "Freudvolle": "freudvoll",
    "Freudvollen": "Freudvolle",
    "Freudvolleren": "Freudvollere",
    "Freudvollsten": "Freudvollste",
    "Freuenden": "Freuende",
    "Freuenderen": "Freuendere",
    "Freuendsten": "Freuendste",
    "Freuens": "Freuen",
    "Freunde": "freunden",
    "Freunden": "Freund",
    "Freundenden": "Freundende",
    "Freundens": "Freunden",
    "Freundes": "Freund",
    "Freundinnen": "Freundin",
    "Freundliche": "freundlich",
    "Freundlichen": "Freundliche",
    "Freundlicheren": "Freundlichere",
    "Freundlichsten": "Freundlichste",
    "Freunds": "Freund",
    "Freundschaften": "Freundschaft",
    "Freundschaftliche": "freundschaftlich",
    "Freundschaftlichen": "Freundschaftliche",
    "Freundschaftlicheren": "Freundschaftlichere",
    "Frevelhaften": "Frevelhafte",
    "Frevelhafteren": "Frevelhaftere",
    "Frevelhaftesten": "Frevelhafteste",
    "Frevelnden": "Frevelnde",
    "Frevelnderen": "Frevelndere",
    "Frevelndsten": "Frevelndste",
    "Frevelns": "Freveln",
    "Freveltaten": "Freveltat",
    "Frevlerischen": "Frevlerische",
    "Frevlerischeren": "Frevlerischere",
    "Frevlerischsten": "Frevlerischste",
    "Freys": "Frey",
    "Freßkorbe": "Freßkorb",
    "Freßkorbs": "Freßkorb",
    "Freßkörbe": "Freßkorb",
    "Freßkörben": "Freßkorb",
    "Freßsüchte": "Freßsucht",
    "Freßsüchten": "Freßsucht",
    "Freßsüchtige": "freßsüchtig",
    "Freßsüchtigen": "Freßsüchtige",
    "Freßsüchtigeren": "Freßsüchtigere",
    "Freßsüchtigsten": "Freßsüchtigste",
    "Friedbergern": "Friedberger",
    "Friedbergers": "Friedberger",
    "Friedbergs": "Friedberg",
    "Frieden": "Friede",
    "Friedens": "Frieden",
    "Friedfertige": "friedfertig",
    "Friedfertigen": "Friedfertige",
    "Friedfertigeren": "Friedfertigere",
    "Friedfertigsten": "Friedfertigste",
    "Friedhofe": "Friedhof",
    "Friedhofes": "Friedhof",
    "Friedhofs": "Friedhof",
    "Friedhöfe": "Friedhof",
    "Friedhöfen": "Friedhof",
    "Friedliche": "friedlich",
    "Friedlichen": "Friedliche",
    "Friedlicheren": "Friedlichere",
    "Friedlichsten": "Friedlichste",
    "Friedliebenden": "Friedliebende",
    "Friedliebenderen": "Friedliebendere",
    "Friedliebendsten": "Friedliebendste",
    "Friedrichs": "Friedrich",
    "Friedrichsdorfern": "Friedrichsdorfer",
    "Friedrichsdorfers": "Friedrichsdorfer",
    "Friedrichsdorfs": "Friedrichsdorf",
    "Friedrichshains": "Friedrichshain",
    "Friedsame": "friedsam",
    "Friedsamen": "Friedsame",
    "Friedsameren": "Friedsamere",
    "Friedsamsten": "Friedsamste",
    "Frierenden": "Frierende",
    "Frierens": "Frieren",
    "Friesen": "Friese",
    "Friesländische": "friesländisch",
    "Friesländischen": "Friesländische",
    "Frigiden": "Frigide",
    "Frigideren": "Frigidere",
    "Frigidesten": "Frigideste",
    "Frikadellen": "Frikadelle",
    "Frikassees": "Frikassee",
    "Friktionen": "Friktion",
    "Frische": "frischen",
    "Frischeisens": "Frischeisen",
    "Frischen": "Frische",
    "Frischenden": "Frischende",
    "Frischens": "Frischen",
    "Frischeren": "Frischere",
    "Frischfleische": "Frischfleisch",
    "Frischfleischen": "Frischfleisch",
    "Frischfleischs": "Frischfleisch",
    "Frischgemüsen": "Frischgemüse",
    "Frischgemüses": "Frischgemüse",
    "Frischhaltebeuteln": "Frischhaltebeutel",
    "Frischhaltebeutels": "Frischhaltebeutel",
    "Frischkäsen": "Frischkäse",
    "Frischkäses": "Frischkäse",
    "Frischsten": "Frischste",
    "Frischwassers": "Frischwasser",
    "Friseure": "Friseur",
    "Friseuren": "Friseur",
    "Friseures": "Friseur",
    "Friseurs": "Friseur",
    "Frisierenden": "Frisierende",
    "Frisierens": "Frisieren",
    "Frisierhauben": "Frisierhaube",
    "Frisierstabe": "Frisierstab",
    "Frisierstabs": "Frisierstab",
    "Frisierstäbe": "Frisierstab",
    "Frisierstäben": "Frisierstab",
    "Frisierte": "frisiert",
    "Frisierten": "Frisierte",
    "Frisierteren": "Frisiertere",
    "Frisiertesten": "Frisierteste",
    "Frisierumhange": "Frisierumhang",
    "Frisierumhangs": "Frisierumhang",
    "Frisierumhänge": "Frisierumhang",
    "Frisierumhängen": "Frisierumhang",
    "Fristen": "Frist",
    "Fristenden": "Fristende",
    "Fristens": "Fristen",
    "Fristgerechten": "Fristgerechte",
    "Fristlosen": "Fristlose",
    "Frisuren": "Frisur",
    "Frisöre": "Frisör",
    "Frisören": "Frisör",
    "Frisörs": "Frisör",
    "Frisösen": "Frisöse",
    "Fritierenden": "Fritierende",
    "Fritierenderen": "Fritierendere",
    "Fritierendsten": "Fritierendste",
    "Fritierens": "Fritieren",
    "Fritierte": "fritiert",
    "Fritierten": "Fritierte",
    "Fritierteren": "Fritiertere",
    "Fritiertesten": "Fritierteste",
    "Fritten": "Fritte",
    "Frittierenden": "Frittierende",
    "Frittierenderen": "Frittierendere",
    "Frittierendsten": "Frittierendste",
    "Frittierens": "Frittieren",
    "Frittierte": "frittiert",
    "Frittierten": "Frittierte",
    "Frittierteren": "Frittiertere",
    "Frittiertesten": "Frittierteste",
    "Frittüren": "Frittüre",
    "Fritüren": "Fritüre",
    "Frohe": "froh",
    "Frohen": "Frohe",
    "Froheren": "Frohere",
    "Frohesten": "Froheste",
    "Frohmütigen": "Frohmütige",
    "Frohmütigeren": "Frohmütigere",
    "Frohmütigsten": "Frohmütigste",
    "Frohsinne": "Frohsinn",
    "Frohsinnen": "Frohsinn",
    "Frohsinns": "Frohsinn",
    "Fromme": "fromm",
    "Frommen": "Fromme",
    "Frommeren": "Frommere",
    "Frommsten": "Frommste",
    "Fronleichnams": "Fronleichnam",
    "Frontalangriffe": "Frontalangriff",
    "Frontalangriffen": "Frontalangriff",
    "Frontalangriffs": "Frontalangriff",
    "Frontalansichten": "Frontalansicht",
    "Frontale": "frontal",
    "Frontalen": "Frontale",
    "Frontaleren": "Frontalere",
    "Frontalsten": "Frontalste",
    "Frontalunterrichts": "Frontalunterricht",
    "Frontantriebs": "Frontantrieb",
    "Fronten": "Front",
    "Frontladern": "Frontlader",
    "Frontladers": "Frontlader",
    "Frontmotore": "Frontmotor",
    "Frontmotoren": "Frontmotor",
    "Frontmotors": "Frontmotor",
    "Frontscheiben": "Frontscheibe",
    "Frosche": "Frosch",
    "Froschs": "Frosch",
    "Frostbeständige": "frostbeständig",
    "Frostbeständigen": "Frostbeständige",
    "Frostbeständigeren": "Frostbeständigere",
    "Froste": "Frost",
    "Frostern": "Froster",
    "Frosters": "Froster",
    "Frostes": "Frost",
    "Frostige": "frostig",
    "Frostigen": "Frostige",
    "Frostigeren": "Frostigere",
    "Frostigsten": "Frostigste",
    "Frosts": "Frost",
    "Frotteetuche": "Frotteetuch",
    "Frotteetuches": "Frotteetuch",
    "Frotteetuchs": "Frotteetuch",
    "Frotteetücher": "Frotteetuch",
    "Frotteetüchern": "Frotteetuch",
    "Frottiertuche": "Frottiertuch",
    "Frottiertuches": "Frottiertuch",
    "Frottiertuchs": "Frottiertuch",
    "Frottiertücher": "Frottiertuch",
    "Frottiertüchern": "Frottiertuch",
    "Frotzeleien": "Frotzelei",
    "Frotzelnden": "Frotzelnde",
    "Frotzelnderen": "Frotzelndere",
    "Frotzelndsten": "Frotzelndste",
    "Frotzelns": "Frotzeln",
    "Fruchtbaren": "Fruchtbare",
    "Fruchtbareren": "Fruchtbarere",
    "Fruchtbarsten": "Fruchtbarste",
    "Fruchtblasen": "Fruchtblase",
    "Fruchtenden": "Fruchtende",
    "Fruchtenderen": "Fruchtendere",
    "Fruchtendsten": "Fruchtendste",
    "Fruchtens": "Fruchten",
    "Fruchtigen": "Fruchtige",
    "Fruchtigeren": "Fruchtigere",
    "Fruchtigsten": "Fruchtigste",
    "Fruchtlosen": "Fruchtlose",
    "Fruchtloseren": "Fruchtlosere",
    "Fruchtlosesten": "Fruchtloseste",
    "Fruste": "frusten",
    "Frusten": "Frust",
    "Frustenden": "Frustende",
    "Frustenderen": "Frustendere",
    "Frustendsten": "Frustendste",
    "Frustens": "Frusten",
    "Frusts": "Frust",
    "Fränkinnen": "Fränkin",
    "Fränkische": "fränkisch",
    "Fränkischen": "Fränkische",
    "Fräsen": "Fräse",
    "Fräsenden": "Fräsende",
    "Fräsens": "Fräsen",
    "Fräsmaschinen": "Fräsmaschine",
    "Fräsmessern": "Fräsmesser",
    "Fräsmessers": "Fräsmesser",
    "Frätzchens": "Frätzchen",
    "Fräuleins": "Fräulein",
    "Fröhlichen": "Fröhliche",
    "Fröhlicheren": "Fröhlichere",
    "Fröhlichsten": "Fröhlichste",
    "Fröschchens": "Fröschchen",
    "Frösche": "Frosch",
    "Fröschen": "Frosch",
    "Fröschleins": "Fröschlein",
    "Fröste": "Frost",
    "Frösteligen": "Fröstelige",
    "Frösteligeren": "Frösteligere",
    "Frösteligsten": "Frösteligste",
    "Fröstelnden": "Fröstelnde",
    "Fröstelnderen": "Fröstelndere",
    "Fröstelndsten": "Fröstelndste",
    "Fröstelns": "Frösteln",
    "Frösten": "Frost",
    "Fröstligen": "Fröstlige",
    "Fröstligeren": "Fröstligere",
    "Fröstligsten": "Fröstligste",
    "Früchtchens": "Früchtchen",
    "Früchte": "Frucht",
    "Früchten": "Frucht",
    "Frühbeete": "Frühbeet",
    "Frühbeeten": "Frühbeet",
    "Frühbeets": "Frühbeet",
    "Frühe": "früh",
    "Frühen": "Frühe",
    "Früheren": "Frühere",
    "Früherkennungen": "Früherkennung",
    "Frühesten": "Früheste",
    "Frühgeburten": "Frühgeburt",
    "Frühgeschichten": "Frühgeschichte",
    "Frühjahre": "Frühjahr",
    "Frühjahren": "Frühjahr",
    "Frühjahres": "Frühjahr",
    "Frühjahrs": "Frühjahr",
    "Frühkindliche": "frühkindlich",
    "Frühkindlichen": "Frühkindliche",
    "Frühkulturen": "Frühkultur",
    "Frühlinge": "Frühling",
    "Frühlingen": "Frühling",
    "Frühlings": "Frühling",
    "Frühlingsrollen": "Frühlingsrolle",
    "Frühmessen": "Frühmesse",
    "Frühreife": "frühreif",
    "Frühreifen": "Frühreife",
    "Frühreiferen": "Frühreifere",
    "Frühreifsten": "Frühreifste",
    "Frühschoppens": "Frühschoppen",
    "Frühsozialistische": "frühsozialistisch",
    "Frühsozialistischen": "Frühsozialistische",
    "Frühsozialistischeren": "Frühsozialistischere",
    "Frühstücke": "Frühstück",
    "Frühstücken": "Frühstück",
    "Frühstückes": "Frühstück",
    "Frühstücks": "Frühstück",
    "Frühzeitige": "frühzeitig",
    "Frühzeitigen": "Frühzeitige",
    "Frühzeitigeren": "Frühzeitigere",
    "Frühzeitigsten": "Frühzeitigste",
    "Frühzündungen": "Frühzündung",
    "Fuchse": "Fuchs",
    "Fuchses": "Fuchs",
    "Fuchtelnden": "Fuchtelnde",
    "Fuchtelnderen": "Fuchtelndere",
    "Fuchtelndsten": "Fuchtelndste",
    "Fuchtelns": "Fuchteln",
    "Fuffzigern": "Fuffziger",
    "Fuffzigers": "Fuffziger",
    "Fuge": "fugen",
    "Fugen": "Fuge",
    "Fugenden": "Fugende",
    "Fugens": "Fugen",
    "Fuhrbetriebe": "Fuhrbetrieb",
    "Fuhrbetrieben": "Fuhrbetrieb",
    "Fuhrbetriebs": "Fuhrbetrieb",
    "Fuhrgelde": "Fuhrgeld",
    "Fuhrgelder": "Fuhrgeld",
    "Fuhrgeldern": "Fuhrgeld",
    "Fuhrgeldes": "Fuhrgeld",
    "Fuhrgelds": "Fuhrgeld",
    "Fuhrgeschäfte": "Fuhrgeschäft",
    "Fuhrgeschäften": "Fuhrgeschäft",
    "Fuhrgeschäfts": "Fuhrgeschäft",
    "Fuhrparks": "Fuhrpark",
    "Fuhrunternehmern": "Fuhrunternehmer",
    "Fuhrunternehmers": "Fuhrunternehmer",
    "Fuhrwerke": "Fuhrwerk",
    "Fuhrwerken": "Fuhrwerk",
    "Fuhrwerks": "Fuhrwerk",
    "Fuldas": "Fulda",
    "Fulminante": "fulminant",
    "Fulminanten": "Fulminante",
    "Fulminanteren": "Fulminantere",
    "Fulminantesten": "Fulminanteste",
    "Fulminsäuren": "Fulminsäure",
    "Fummel": "fummeln",
    "Fummeln": "Fummel",
    "Fummelnden": "Fummelnde",
    "Fummelnderen": "Fummelndere",
    "Fummelndsten": "Fummelndste",
    "Fummelns": "Fummeln",
    "Fummels": "Fummel",
    "Fundamentalen": "Fundamentale",
    "Fundamentaleren": "Fundamentalere",
    "Fundamentalisten": "Fundamentalist",
    "Fundamentalistische": "fundamentalistisch",
    "Fundamentalistischen": "Fundamentalistische",
    "Fundamentalsten": "Fundamentalste",
    "Fundamente": "Fundament",
    "Fundamenten": "Fundament",
    "Fundaments": "Fundament",
    "Funde": "Fund",
    "Funden": "Fund",
    "Fundes": "Fund",
    "Fundgruben": "Fundgrube",
    "Fundierenden": "Fundierende",
    "Fundierenderen": "Fundierendere",
    "Fundierendsten": "Fundierendste",
    "Fundierens": "Fundieren",
    "Fundierte": "fundiert",
    "Fundierten": "Fundierte",
    "Fundierteren": "Fundiertere",
    "Fundiertesten": "Fundierteste",
    "Fundis": "Fundi",
    "Funds": "Fund",
    "Fundsachen": "Fundsache",
    "Fungierenden": "Fungierende",
    "Fungierens": "Fungieren",
    "Fungierte": "fungiert",
    "Fungierten": "Fungierte",
    "Funk": "funken",
    "Funkbojen": "Funkboje",
    "Funke": "funken",
    "Funkel": "funkeln",
    "Funkelnagelneuen": "Funkelnagelneue",
    "Funkelnden": "Funkelnde",
    "Funkelnderen": "Funkelndere",
    "Funkelndsten": "Funkelndste",
    "Funkelns": "Funkeln",
    "Funkels": "Funkel",
    "Funken": "Funke",
    "Funkenden": "Funkende",
    "Funkens": "Funken",
    "Funkern": "Funker",
    "Funkers": "Funker",
    "Funks": "Funk",
    "Funktionalen": "Funktionale",
    "Funktionaleren": "Funktionalere",
    "Funktionalisierenden": "Funktionalisierende",
    "Funktionalisierens": "Funktionalisieren",
    "Funktionalisierte": "funktionalisiert",
    "Funktionalisierten": "Funktionalisierte",
    "Funktionalsten": "Funktionalste",
    "Funktionelle": "funktionell",
    "Funktionellen": "Funktionelle",
    "Funktionelleren": "Funktionellere",
    "Funktionellsten": "Funktionellste",
    "Funktionen": "Funktion",
    "Funktioniere": "funktionieren",
    "Funktionierenden": "Funktionierende",
    "Funktionierenderen": "Funktionierendere",
    "Funktionierens": "Funktionieren",
    "Funktionierte": "funktioniert",
    "Funktionierten": "Funktionierte",
    "Funktionsfähigen": "Funktionsfähige",
    "Funktionsfähigeren": "Funktionsfähigere",
    "Funktionstüchtigen": "Funktionstüchtige",
    "Funktionstüchtigeren": "Funktionstüchtigere",
    "Funktionäre": "Funktionär",
    "Funktionären": "Funktionär",
    "Funktionärs": "Funktionär",
    "Furchen": "Furche",
    "Furchige": "furchig",
    "Furchigen": "Furchige",
    "Furchigeren": "Furchigere",
    "Furchigsten": "Furchigste",
    "Furchtbaren": "Furchtbare",
    "Furchtbareren": "Furchtbarere",
    "Furchtbarsten": "Furchtbarste",
    "Furchtlosen": "Furchtlose",
    "Furchtloseren": "Furchtlosere",
    "Furchtlosesten": "Furchtloseste",
    "Furchtsamen": "Furchtsame",
    "Furchtsameren": "Furchtsamere",
    "Furchtsamsten": "Furchtsamste",
    "Furetis": "Fureti",
    "Furien": "Furie",
    "Furiose": "furios",
    "Furiosen": "Furiose",
    "Furioseren": "Furiosere",
    "Furiosesten": "Furioseste",
    "Furnier": "furnieren",
    "Furniere": "furnieren",
    "Furnieren": "Furnier",
    "Furnierenden": "Furnierende",
    "Furnierens": "Furnieren",
    "Furnieres": "Furnier",
    "Furniers": "Furnier",
    "Furnierte": "furniert",
    "Furnierten": "Furnierte",
    "Furnierungen": "Furnierung",
    "Furoren": "Furore",
    "Furten": "Furt",
    "Furunkeln": "Furunkel",
    "Furunkels": "Furunkel",
    "Furzenden": "Furzende",
    "Furzens": "Furzen",
    "Fusionen": "Fusion",
    "Fusionierenden": "Fusionierende",
    "Fusionierens": "Fusionieren",
    "Fusionierte": "fusioniert",
    "Fusionierten": "Fusionierte",
    "Fusionierungen": "Fusionierung",
    "Fusseligen": "Fusselige",
    "Fusseligeren": "Fusseligere",
    "Fusseligsten": "Fusseligste",
    "Fusselnden": "Fusselnde",
    "Fusselnderen": "Fusselndere",
    "Fusselndsten": "Fusselndste",
    "Fusselns": "Fusseln",
    "Futter": "futtern",
    "Futtern": "Futter",
    "Futternden": "Futternde",
    "Futternderen": "Futterndere",
    "Futterndsten": "Futterndste",
    "Futterns": "Futtern",
    "Futters": "Futter",
    "Futurischen": "Futurische",
    "Futurischeren": "Futurischere",
    "Futurischsten": "Futurischste",
    "Futuristischen": "Futuristische",
    "Futuristischeren": "Futuristischere",
    "Futuristischsten": "Futuristischste",
    "Fuß": "fußen",
    "Fußballerische": "fußballerisch",
    "Fußballerischen": "Fußballerische",
    "Fußballern": "Fußballer",
    "Fußballers": "Fußballer",
    "Fuße": "fußen",
    "Fußenden": "Fußende",
    "Fußenderen": "Fußendere",
    "Fußendsten": "Fußendste",
    "Fußens": "Fußen",
    "Fußes": "Fuß",
    "Fußfreien": "Fußfreie",
    "Fußgängerinnen": "Fußgängerin",
    "Fußgängern": "Fußgänger",
    "Fußgängers": "Fußgänger",
    "Fächelnden": "Fächelnde",
    "Fächelns": "Fächeln",
    "Fächer": "fächern",
    "Fächern": "Fach",
    "Fächernden": "Fächernde",
    "Fächernderen": "Fächerndere",
    "Fächerndsten": "Fächerndste",
    "Fächerns": "Fächern",
    "Fächerübergreifenden": "Fächerübergreifende",
    "Fädelnden": "Fädelnde",
    "Fädelns": "Fädeln",
    "Fäden": "Faden",
    "Fähigen": "Fähige",
    "Fähigeren": "Fähigere",
    "Fähigkeiten": "Fähigkeit",
    "Fähigste": "fähig",
    "Fähigsten": "Fähigste",
    "Fähren": "Fähre",
    "Fährmanne": "Fährmann",
    "Fährmannes": "Fährmann",
    "Fährmanns": "Fährmann",
    "Fährmänner": "Fährmann",
    "Fährmännern": "Fährmann",
    "Fährschiffe": "Fährschiff",
    "Fährschiffen": "Fährschiff",
    "Fährschiffs": "Fährschiff",
    "Fährten": "Fährte",
    "Fäkaldüngern": "Fäkaldünger",
    "Fäkaldüngers": "Fäkaldünger",
    "Fäkale": "fäkal",
    "Fäkalen": "Fäkale",
    "Fälle": "fällen",
    "Fällen": "Fall",
    "Fällende": "fällend",
    "Fällenden": "Fällende",
    "Fällens": "Fällen",
    "Fällige": "fällig",
    "Fälligen": "Fällige",
    "Fälschenden": "Fälschende",
    "Fälschens": "Fälschen",
    "Fälschlichen": "Fälschliche",
    "Fältchens": "Fältchen",
    "Fänge": "Fang",
    "Fängen": "Fang",
    "Färbenden": "Färbende",
    "Färbenderen": "Färbendere",
    "Färbendsten": "Färbendste",
    "Färbens": "Färben",
    "Färbungen": "Färbung",
    "Färsen": "Färse",
    "Fäserchens": "Fäserchen",
    "Fässer": "Faß",
    "Fässern": "Faß",
    "Fäustchens": "Fäustchen",
    "Fäuste": "Faust",
    "Fäusten": "Faust",
    "Fäustleins": "Fäustlein",
    "Fäustlinge": "Fäustling",
    "Fäustlingen": "Fäustling",
    "Fäustlings": "Fäustling",
    "Fäßchens": "Fäßchen",
    "Föderalen": "Föderale",
    "Föderalisierenden": "Föderalisierende",
    "Föderalisierenderen": "Föderalisierendere",
    "Föderalisierens": "Föderalisieren",
    "Föderalisierte": "föderalisiert",
    "Föderalisierten": "Föderalisierte",
    "Föderalisierteren": "Föderalisiertere",
    "Föderalisierteste": "föderalisiert",
    "Föderalistischen": "Föderalistische",
    "Föderationen": "Föderation",
    "Föderierenden": "Föderierende",
    "Föderierenderen": "Föderierendere",
    "Föderierendsten": "Föderierendste",
    "Föderierens": "Föderieren",
    "Föderierte": "föderiert",
    "Föderierten": "Föderierte",
    "Föhn": "föhnen",
    "Föhne": "föhnen",
    "Föhnen": "Föhn",
    "Föhnenden": "Föhnende",
    "Föhnens": "Föhnen",
    "Föhnes": "Föhn",
    "Föhns": "Föhn",
    "Föhrden": "Föhrde",
    "Fön": "fönen",
    "Föne": "fönen",
    "Fönen": "Fön",
    "Fönenden": "Fönende",
    "Fönens": "Fönen",
    "Föns": "Fön",
    "Förden": "Förde",
    "Förderbande": "Förderband",
    "Förderbandes": "Förderband",
    "Förderbands": "Förderband",
    "Förderbänder": "Förderband",
    "Förderbändern": "Förderband",
    "Fördereimern": "Fördereimer",
    "Fördereimers": "Fördereimer",
    "Förderklassen": "Förderklasse",
    "Förderkorbe": "Förderkorb",
    "Förderkorbs": "Förderkorb",
    "Förderkörbe": "Förderkorb",
    "Förderkörben": "Förderkorb",
    "Förderliche": "förderlich",
    "Förderlichen": "Förderliche",
    "Fördermaschinen": "Fördermaschine",
    "Fördernde": "fördernd",
    "Fördernden": "Fördernde",
    "Förderndere": "fördernd",
    "Fördernderen": "Förderndere",
    "Förderndste": "fördernd",
    "Förderndsten": "Förderndste",
    "Förderns": "Fördern",
    "Förderprogramme": "Förderprogramm",
    "Förderprogrammen": "Förderprogramm",
    "Förderprogrammes": "Förderprogramm",
    "Förderprogramms": "Förderprogramm",
    "Förderseile": "Förderseil",
    "Förderseilen": "Förderseil",
    "Förderseils": "Förderseil",
    "Förderstufen": "Förderstufe",
    "Förderturme": "Förderturm",
    "Förderturms": "Förderturm",
    "Fördertürme": "Förderturm",
    "Fördertürmen": "Förderturm",
    "Fördervereine": "Förderverein",
    "Fördervereinen": "Förderverein",
    "Fördervereines": "Förderverein",
    "Fördervereins": "Förderverein",
    "Förderwagens": "Förderwagen",
    "Förderwerke": "Förderwerk",
    "Förderwerken": "Förderwerk",
    "Förderwerks": "Förderwerk",
    "Förmige": "förmig",
    "Förmigen": "Förmige",
    "Förmigeren": "Förmigere",
    "Förmigsten": "Förmigste",
    "Förmlichen": "Förmliche",
    "Förmlicheren": "Förmlichere",
    "Förmlichsten": "Förmlichste",
    "Förstern": "Förster",
    "Försters": "Förster",
    "Füchse": "Fuchs",
    "Füchsen": "Fuchs",
    "Fügende": "fügend",
    "Fügenden": "Fügende",
    "Fügens": "Fügen",
    "Fügungen": "Fügung",
    "Fühlbare": "fühlbar",
    "Fühlbaren": "Fühlbare",
    "Fühlenden": "Fühlende",
    "Fühlens": "Fühlen",
    "Führenden": "Führende",
    "Führenderen": "Führendere",
    "Führendsten": "Führendste",
    "Führens": "Führen",
    "Führerinnen": "Führerin",
    "Führern": "Führer",
    "Führers": "Führer",
    "Führerscheine": "Führerschein",
    "Führerscheinen": "Führerschein",
    "Führerscheins": "Führerschein",
    "Führerstande": "Führerstand",
    "Führerstands": "Führerstand",
    "Führerstände": "Führerstand",
    "Führerständen": "Führerstand",
    "Führungen": "Führung",
    "Füllenden": "Füllende",
    "Füllens": "Füllen",
    "Füllern": "Füller",
    "Füllers": "Füller",
    "Füllhorne": "Füllhorn",
    "Füllhornes": "Füllhorn",
    "Füllhorns": "Füllhorn",
    "Füllhörner": "Füllhorn",
    "Füllhörnern": "Füllhorn",
    "Füllmauern": "Füllmauer",
    "Füllmengen": "Füllmenge",
    "Füllmitteln": "Füllmittel",
    "Füllmittels": "Füllmittel",
    "Füllungen": "Füllung",
    "Fünfern": "Fünfer",
    "Fünfers": "Fünfer",
    "Fünfkampfs": "Fünfkampf",
    "Fünfprozentklauseln": "Fünfprozentklausel",
    "Fünftagefiebers": "Fünftagefieber",
    "Fünfte": "fünft",
    "Fünften": "Fünfte",
    "Fünftürern": "Fünftürer",
    "Fünftürers": "Fünftürer",
    "Fünfzigern": "Fünfziger",
    "Fünfzigers": "Fünfziger",
    "Fünkchens": "Fünkchen",
    "Fürbitten": "Fürbitte",
    "Fürchtenden": "Fürchtende",
    "Fürchtenderen": "Fürchtendere",
    "Fürchtendsten": "Fürchtendste",
    "Fürchtens": "Fürchten",
    "Fürchterliche": "fürchterlich",
    "Fürchterlichen": "Fürchterliche",
    "Fürchterlicheren": "Fürchterlichere",
    "Fürchterlichsten": "Fürchterlichste",
    "Fürsorgliche": "fürsorglich",
    "Fürsorglichen": "Fürsorgliche",
    "Fürsorglicheren": "Fürsorglichere",
    "Fürsorglichsten": "Fürsorglichste",
    "Fürsprachen": "Fürsprache",
    "Fürsprechern": "Fürsprecher",
    "Fürsprechers": "Fürsprecher",
    "Fürsten": "Fürst",
    "Fürstinnen": "Fürstin",
    "Fürstliche": "fürstlich",
    "Fürstlichen": "Fürstliche",
    "Fürstlicheren": "Fürstlichere",
    "Fürstlichsten": "Fürstlichste",
    "Fürworte": "Fürwort",
    "Fürwortes": "Fürwort",
    "Fürworts": "Fürwort",
    "Fürwörter": "Fürwort",
    "Fürwörtern": "Fürwort",
    "Fütternde": "fütternd",
    "Fütternden": "Fütternde",
    "Fütterndere": "fütternd",
    "Fütternderen": "Fütterndere",
    "Fütterndste": "fütternd",
    "Fütterndsten": "Fütterndste",
    "Fütterns": "Füttern",
    "Füße": "Fuß",
    "Füßen": "Fuß",
    "Gabel": "gabeln",
    "Gabelförmigen": "Gabelförmige",
    "Gabeln": "Gabel",
    "Gabelnden": "Gabelnde",
    "Gabelns": "Gabeln",
    "Gabelstaplern": "Gabelstapler",
    "Gabelstaplers": "Gabelstapler",
    "Gaben": "geben",
    "Gabis": "Gabi",
    "Gabrieles": "Gabriele",
    "Gaffenden": "Gaffende",
    "Gaffens": "Gaffen",
    "Gagen": "Gage",
    "Gags": "Gag",
    "Galaktischen": "Galaktische",
    "Galanten": "Galante",
    "Galanteren": "Galantere",
    "Galantesten": "Galanteste",
    "Galatern": "Galater",
    "Galaters": "Galater",
    "Galaxien": "Galaxie",
    "Galeeren": "Galeere",
    "Galerien": "Galerie",
    "Galeristen": "Galerist",
    "Galgens": "Galgen",
    "Gallen": "Galle",
    "Gallonen": "Gallone",
    "Galoppern": "Galopper",
    "Galoppers": "Galopper",
    "Galoppierenden": "Galoppierende",
    "Galoppierens": "Galoppieren",
    "Galoppierte": "galoppiert",
    "Galoppierten": "Galoppierte",
    "Galopprennens": "Galopprennen",
    "Galoschen": "Galosche",
    "Gamaschen": "Gamasche",
    "Gamben": "Gambe",
    "Gambisten": "Gambist",
    "Games": "Game",
    "Gammeligen": "Gammelige",
    "Gammeligeren": "Gammeligere",
    "Gammeligsten": "Gammeligste",
    "Gammelnden": "Gammelnde",
    "Gammelnderen": "Gammelndere",
    "Gammelndsten": "Gammelndste",
    "Gammelns": "Gammeln",
    "Gammlern": "Gammler",
    "Gammlers": "Gammler",
    "Gamsachurdias": "Gamsachurdia",
    "Ganaschen": "Ganasche",
    "Gangarten": "Gangart",
    "Gangbare": "gangbar",
    "Gangbaren": "Gangbare",
    "Gange": "Gang",
    "Ganges": "Gang",
    "Gangs": "Gang",
    "Ganoven": "Ganove",
    "Ganze": "ganz",
    "Ganzen": "Ganze",
    "Ganzheitlichen": "Ganzheitliche",
    "Ganzheitspsychologien": "Ganzheitspsychologie",
    "Ganzjährige": "ganzjährig",
    "Ganzjährigen": "Ganzjährige",
    "Ganztone": "Ganzton",
    "Ganztons": "Ganzton",
    "Ganztägigen": "Ganztägige",
    "Ganztätigen": "Ganztätige",
    "Ganztöne": "Ganzton",
    "Ganztönen": "Ganzton",
    "Garagen": "Garage",
    "Garantien": "Garantie",
    "Garantierenden": "Garantierende",
    "Garantierens": "Garantieren",
    "Garantierte": "garantiert",
    "Garantierten": "Garantierte",
    "Garben": "Garbe",
    "Garden": "Garde",
    "Gardenpartys": "Gardenparty",
    "Garderoben": "Garderobe",
    "Gardinen": "Gardine",
    "Gardisten": "Gardist",
    "Garenden": "Garende",
    "Garenderen": "Garendere",
    "Garendsten": "Garendste",
    "Garens": "Garen",
    "Gargekochten": "Gargekochte",
    "Gargekochteren": "Gargekochtere",
    "Gargekochtesten": "Gargekochteste",
    "Garkochenden": "Garkochende",
    "Garkochenderen": "Garkochendere",
    "Garkochendsten": "Garkochendste",
    "Garkochens": "Garkochen",
    "Garmischs": "Garmisch",
    "Garne": "Garn",
    "Garnelen": "Garnele",
    "Garnen": "Garn",
    "Garnes": "Garn",
    "Garnierenden": "Garnierende",
    "Garnierenderen": "Garnierendere",
    "Garnierendsten": "Garnierendste",
    "Garnierens": "Garnieren",
    "Garnierte": "garniert",
    "Garnierten": "Garnierte",
    "Garnierteren": "Garniertere",
    "Garniertesten": "Garnierteste",
    "Garnisonen": "Garnison",
    "Garnituren": "Garnitur",
    "Garns": "Garn",
    "Gartens": "Garten",
    "Gas": "gasen",
    "Gase": "gasen",
    "Gasen": "Gas",
    "Gasenden": "Gasende",
    "Gasens": "Gasen",
    "Gases": "Gas",
    "Gasflaschen": "Gasflasche",
    "Gasförmige": "gasförmig",
    "Gasförmigen": "Gasförmige",
    "Gassen": "Gasse",
    "Gast": "gasen",
    "Gaste": "Gast",
    "Gastechnische": "gastechnisch",
    "Gastechnischen": "Gastechnische",
    "Gastes": "Gast",
    "Gastfreundlichen": "Gastfreundliche",
    "Gastfreundlicheren": "Gastfreundlichere",
    "Gastgebern": "Gastgeber",
    "Gastgebers": "Gastgeber",
    "Gasthörern": "Gasthörer",
    "Gasthörers": "Gasthörer",
    "Gastierenden": "Gastierende",
    "Gastierens": "Gastieren",
    "Gastierte": "gastiert",
    "Gastierten": "Gastierte",
    "Gastronomischen": "Gastronomische",
    "Gasts": "Gast",
    "Gaststätten": "Gaststätte",
    "Gattern": "Gatter",
    "Gatters": "Gatter",
    "Gattinnen": "Gattin",
    "Gattungen": "Gattung",
    "Gauchos": "Gaucho",
    "Gaucks": "Gauck",
    "Gaukelnden": "Gaukelnde",
    "Gaukelns": "Gaukeln",
    "Gaule": "Gaul",
    "Gaules": "Gaul",
    "Gaulles": "Gaulle",
    "Gauls": "Gaul",
    "Gaumens": "Gaumen",
    "Gauner": "gaunern",
    "Gaunereien": "Gaunerei",
    "Gaunern": "Gauner",
    "Gaunernden": "Gaunernde",
    "Gaunernderen": "Gaunerndere",
    "Gaunerndsten": "Gaunerndste",
    "Gaunerns": "Gaunern",
    "Gauners": "Gauner",
    "Gauweilers": "Gauweiler",
    "Gazas": "Gaza",
    "Gazellen": "Gazelle",
    "Geaalten": "Geaalte",
    "Geachteten": "Geachtete",
    "Geachteteren": "Geachtetere",
    "Geachtetesten": "Geachteteste",
    "Geadelten": "Geadelte",
    "Geahmten": "Geahmte",
    "Geahndeten": "Geahndete",
    "Geahndeteren": "Geahndetere",
    "Geahndetesten": "Geahndeteste",
    "Geahnten": "Geahnte",
    "Gealberten": "Gealberte",
    "Gealterten": "Gealterte",
    "Gealterteren": "Gealtertere",
    "Gealtertesten": "Gealterteste",
    "Geangelten": "Geangelte",
    "Geankerten": "Geankerte",
    "Geantworteten": "Geantwortete",
    "Gearbeiteten": "Gearbeitete",
    "Geargwöhnten": "Geargwöhnte",
    "Gearteten": "Geartete",
    "Geatmeten": "Geatmete",
    "Gebackene": "gebacken",
    "Gebackenen": "Gebackene",
    "Gebadeten": "Gebadete",
    "Gebaggerten": "Gebaggerte",
    "Gebahnten": "Gebahnte",
    "Gebahrten": "Gebahrte",
    "Gebalgten": "Gebalgte",
    "Geballerten": "Geballerte",
    "Geballten": "Geballte",
    "Geballteren": "Geballtere",
    "Geballtesten": "Geballteste",
    "Gebalzten": "Gebalzte",
    "Gebandelten": "Gebandelte",
    "Gebangten": "Gebangte",
    "Gebannten": "Gebannte",
    "Gebannteren": "Gebanntere",
    "Gebanntesten": "Gebannteste",
    "Gebarens": "Gebaren",
    "Gebarrten": "Gebarrte",
    "Gebarrteren": "Gebarrtere",
    "Gebarrtesten": "Gebarrteste",
    "Gebastelten": "Gebastelte",
    "Gebauchredeten": "Gebauchredete",
    "Gebauchten": "Gebauchte",
    "Gebauchteren": "Gebauchtere",
    "Gebauchtesten": "Gebauchteste",
    "Gebaumelten": "Gebaumelte",
    "Gebauschten": "Gebauschte",
    "Gebausparten": "Gebausparte",
    "Gebauten": "Gebaute",
    "Gebebten": "Gebebte",
    "Gebecherten": "Gebecherte",
    "Gebeichteten": "Gebeichtete",
    "Gebeine": "Gebein",
    "Gebeinen": "Gebein",
    "Gebeins": "Gebein",
    "Gebeizten": "Gebeizte",
    "Gebells": "Gebell",
    "Gebellten": "Gebellte",
    "Gebenden": "Gebende",
    "Gebens": "Geben",
    "Gebern": "Geber",
    "Gebers": "Geber",
    "Gebesserten": "Gebesserte",
    "Gebete": "Gebet",
    "Gebeten": "Gebet",
    "Gebetene": "gebeten",
    "Gebetenen": "Gebetene",
    "Gebeteneren": "Gebetenere",
    "Gebetensten": "Gebetenste",
    "Gebetes": "Gebet",
    "Gebeteten": "Gebetete",
    "Gebets": "Gebet",
    "Gebettelten": "Gebettelte",
    "Gebetteten": "Gebettete",
    "Gebeugten": "Gebeugte",
    "Gebeugteren": "Gebeugtere",
    "Gebeugtesten": "Gebeugteste",
    "Gebeulten": "Gebeulte",
    "Gebeutelten": "Gebeutelte",
    "Gebeuteten": "Gebeutete",
    "Gebibberten": "Gebibberte",
    "Gebiederten": "Gebiederte",
    "Gebiet": "gebieten",
    "Gebiete": "gebieten",
    "Gebieten": "Gebiet",
    "Gebietenden": "Gebietende",
    "Gebietens": "Gebieten",
    "Gebieterische": "gebieterisch",
    "Gebieterischen": "Gebieterische",
    "Gebietern": "Gebieter",
    "Gebieters": "Gebieter",
    "Gebiets": "Gebiet",
    "Gebilden": "Gebilde",
    "Gebildes": "Gebilde",
    "Gebildeten": "Gebildete",
    "Gebildeteren": "Gebildetere",
    "Gebildetesten": "Gebildeteste",
    "Gebildhauerten": "Gebildhauerte",
    "Gebilligten": "Gebilligte",
    "Gebimmels": "Gebimmel",
    "Gebimmelten": "Gebimmelte",
    "Gebimsten": "Gebimste",
    "Gebimsteren": "Gebimstere",
    "Gebimstesten": "Gebimsteste",
    "Gebirgen": "Gebirge",
    "Gebirges": "Gebirge",
    "Gebirgige": "gebirgig",
    "Gebirgigen": "Gebirgige",
    "Gebirgigeren": "Gebirgigere",
    "Gebirgigsten": "Gebirgigste",
    "Gebissen": "Gebiße",
    "Gebissene": "gebissen",
    "Gebissenen": "Gebissene",
    "Gebisseneren": "Gebissenere",
    "Gebissensten": "Gebissenste",
    "Gebisses": "Gebiße",
    "Geblafften": "Geblaffte",
    "Geblasene": "geblasen",
    "Geblasenen": "Geblasene",
    "Geblaßten": "Geblaßte",
    "Geblechten": "Geblechte",
    "Geblendeten": "Geblendete",
    "Geblendeteren": "Geblendetere",
    "Geblendetesten": "Geblendeteste",
    "Gebleuten": "Gebleute",
    "Geblichenen": "Geblichene",
    "Geblicheneren": "Geblichenere",
    "Geblichensten": "Geblichenste",
    "Geblickten": "Geblickte",
    "Gebliebenen": "Gebliebene",
    "Geblinkten": "Geblinkte",
    "Geblinzelten": "Geblinzelte",
    "Geblitzten": "Geblitzte",
    "Geblubberten": "Geblubberte",
    "Gebluteten": "Geblutete",
    "Geblähten": "Geblähte",
    "Geblähteren": "Geblähtere",
    "Geblähtesten": "Geblähteste",
    "Gebläsen": "Gebläse",
    "Gebläses": "Gebläse",
    "Geblätterten": "Geblätterte",
    "Gebläuten": "Gebläute",
    "Geblödelten": "Geblödelte",
    "Geblöks": "Geblök",
    "Geblökten": "Geblökte",
    "Geblühten": "Geblühte",
    "Geblümten": "Geblümte",
    "Geblümteren": "Geblümtere",
    "Geblümtesten": "Geblümteste",
    "Gebogenen": "Gebogene",
    "Gebogeneren": "Gebogenere",
    "Gebogensten": "Gebogenste",
    "Gebohnerten": "Gebohnerte",
    "Gebohnerteren": "Gebohnertere",
    "Gebohnertesten": "Gebohnerteste",
    "Gebohrten": "Gebohrte",
    "Gebolzten": "Gebolzte",
    "Gebombten": "Gebombte",
    "Geboomten": "Geboomte",
    "Gebooteten": "Gebootete",
    "Geborenen": "Geborene",
    "Geborgenen": "Geborgene",
    "Geborgeneren": "Geborgenere",
    "Geborgensten": "Geborgenste",
    "Geborgten": "Geborgte",
    "Geborstenen": "Geborstene",
    "Gebote": "Gebot",
    "Geboten": "Gebot",
    "Gebotenen": "Gebotene",
    "Gebotes": "Gebot",
    "Gebots": "Gebot",
    "Geboxten": "Geboxte",
    "Gebrabbelten": "Gebrabbelte",
    "Gebrachten": "Gebrachte",
    "Gebrandeten": "Gebrandete",
    "Gebrandmarkten": "Gebrandmarkte",
    "Gebrandmarkteren": "Gebrandmarktere",
    "Gebrandmarktesten": "Gebrandmarkteste",
    "Gebrannten": "Gebrannte",
    "Gebratenen": "Gebratene",
    "Gebrateneren": "Gebratenere",
    "Gebratensten": "Gebratenste",
    "Gebrauch": "gebrauchen",
    "Gebrauchenden": "Gebrauchende",
    "Gebrauchens": "Gebrauchen",
    "Gebrauchs": "Gebrauch",
    "Gebrauchsfertigen": "Gebrauchsfertige",
    "Gebrauchsfertigeren": "Gebrauchsfertigere",
    "Gebrauchsfähige": "gebrauchsfähig",
    "Gebrauchsfähigen": "Gebrauchsfähige",
    "Gebrauchsfähigeren": "Gebrauchsfähigere",
    "Gebrauchte": "gebraucht",
    "Gebrauchten": "Gebrauchte",
    "Gebrauchtwagens": "Gebrauchtwagen",
    "Gebrausten": "Gebrauste",
    "Gebrauten": "Gebraute",
    "Gebrechens": "Gebrechen",
    "Gebrechliche": "gebrechlich",
    "Gebrechlichen": "Gebrechliche",
    "Gebrechlicheren": "Gebrechlichere",
    "Gebrechlichsten": "Gebrechlichste",
    "Gebreiteten": "Gebreitete",
    "Gebremsten": "Gebremste",
    "Gebrochenen": "Gebrochene",
    "Gebrocheneren": "Gebrochenere",
    "Gebrochensten": "Gebrochenste",
    "Gebrodelten": "Gebrodelte",
    "Gebrummten": "Gebrummte",
    "Gebrutzelten": "Gebrutzelte",
    "Gebräuchlichen": "Gebräuchliche",
    "Gebräuchlicheren": "Gebräuchlichere",
    "Gebräuchlichsten": "Gebräuchlichste",
    "Gebräue": "Gebräu",
    "Gebräuen": "Gebräu",
    "Gebräus": "Gebräu",
    "Gebröckelten": "Gebröckelte",
    "Gebröckelteren": "Gebröckeltere",
    "Gebröckeltesten": "Gebröckelteste",
    "Gebrühten": "Gebrühte",
    "Gebrühteren": "Gebrühtere",
    "Gebrühtesten": "Gebrühteste",
    "Gebrüllten": "Gebrüllte",
    "Gebrüsteten": "Gebrüstete",
    "Gebrüteten": "Gebrütete",
    "Gebrüteteren": "Gebrütetere",
    "Gebrütetesten": "Gebrüteteste",
    "Gebuchten": "Gebuchte",
    "Gebuchteten": "Gebuchtete",
    "Gebuddelten": "Gebuddelte",
    "Gebuhlten": "Gebuhlte",
    "Gebuhten": "Gebuhte",
    "Gebullerten": "Gebullerte",
    "Gebummelten": "Gebummelte",
    "Gebumsten": "Gebumste",
    "Gebundenen": "Gebundene",
    "Gebundeneren": "Gebundenere",
    "Gebundensten": "Gebundenste",
    "Gebunkerten": "Gebunkerte",
    "Gebunkerteren": "Gebunkertere",
    "Gebunkertesten": "Gebunkerteste",
    "Geburten": "Geburt",
    "Geburtenschwache": "geburtenschwach",
    "Geburtenschwachen": "Geburtenschwache",
    "Geburtenschwächeren": "Geburtenschwächere",
    "Geburtenstarken": "Geburtenstarke",
    "Geburtenstärkeren": "Geburtenstärkere",
    "Geburtshelferinnen": "Geburtshelferin",
    "Geburtshelfern": "Geburtshelfer",
    "Geburtshelfers": "Geburtshelfer",
    "Geburtstage": "Geburtstag",
    "Geburtstagen": "Geburtstag",
    "Geburtstages": "Geburtstag",
    "Geburtstags": "Geburtstag",
    "Gebutterten": "Gebutterte",
    "Gebäcke": "Gebäck",
    "Gebäcken": "Gebäck",
    "Gebäckes": "Gebäck",
    "Gebäcks": "Gebäck",
    "Gebändigten": "Gebändigte",
    "Gebärdenden": "Gebärdende",
    "Gebärdens": "Gebärden",
    "Gebärdensprachen": "Gebärdensprache",
    "Gebärdete": "gebärdet",
    "Gebärdeten": "Gebärdete",
    "Gebärenden": "Gebärende",
    "Gebärenderen": "Gebärendere",
    "Gebärendsten": "Gebärendste",
    "Gebärens": "Gebären",
    "Gebärfreudigen": "Gebärfreudige",
    "Gebärfreudigeren": "Gebärfreudigere",
    "Gebärfreudigsten": "Gebärfreudigste",
    "Gebärfähigen": "Gebärfähige",
    "Gebärfähigeren": "Gebärfähigere",
    "Gebärfähigsten": "Gebärfähigste",
    "Gebärstuhle": "Gebärstuhl",
    "Gebärstuhls": "Gebärstuhl",
    "Gebärstühle": "Gebärstuhl",
    "Gebärstühlen": "Gebärstuhl",
    "Gebäuden": "Gebäude",
    "Gebäudes": "Gebäude",
    "Gebäumten": "Gebäumte",
    "Gebölkten": "Gebölkte",
    "Geböllerten": "Geböllerte",
    "Gebüffelten": "Gebüffelte",
    "Gebügelten": "Gebügelte",
    "Gebühr": "gebühren",
    "Gebühren": "Gebühr",
    "Gebührenden": "Gebührende",
    "Gebührenfreien": "Gebührenfreie",
    "Gebührenpflichtigen": "Gebührenpflichtige",
    "Gebührens": "Gebühren",
    "Gebührte": "gebührt",
    "Gebührten": "Gebührte",
    "Gebündeln": "Gebündel",
    "Gebündels": "Gebündel",
    "Gebündelten": "Gebündelte",
    "Gebündelteren": "Gebündeltere",
    "Gebündeltesten": "Gebündelteste",
    "Gebürdeten": "Gebürdete",
    "Gebürgerten": "Gebürgerte",
    "Gebürgten": "Gebürgte",
    "Gebürsteten": "Gebürstete",
    "Gebürtigen": "Gebürtige",
    "Gebüsche": "Gebüsch",
    "Gebüschen": "Gebüsch",
    "Gebüschs": "Gebüsch",
    "Gebüxten": "Gebüxte",
    "Gebüßten": "Gebüßte",
    "Gecheckten": "Gecheckte",
    "Geclonten": "Geclonte",
    "Geclonteren": "Geclontere",
    "Geclontesten": "Geclonteste",
    "Gecremten": "Gecremte",
    "Gedachte": "gedenken",
    "Gedachten": "gedenken",
    "Gedachteren": "Gedachtere",
    "Gedachtesten": "Gedachteste",
    "Gedamelten": "Gedamelte",
    "Gedampften": "Gedampfte",
    "Gedanken": "Gedanke",
    "Gedankenlose": "gedankenlos",
    "Gedankenlosen": "Gedankenlose",
    "Gedankenloseren": "Gedankenlosere",
    "Gedankenlosesten": "Gedankenloseste",
    "Gedankens": "Gedanken",
    "Gedankliche": "gedanklich",
    "Gedanklichen": "Gedankliche",
    "Gedankten": "Gedankte",
    "Gedarbten": "Gedarbte",
    "Gedauerten": "Gedauerte",
    "Gedeckten": "Gedeckte",
    "Gedehnten": "Gedehnte",
    "Gedehnteren": "Gedehntere",
    "Gedehntesten": "Gedehnteste",
    "Gedeichselten": "Gedeichselte",
    "Gedeichten": "Gedeichte",
    "Gedeihenden": "Gedeihende",
    "Gedeihenderen": "Gedeihendere",
    "Gedeihendsten": "Gedeihendste",
    "Gedeihens": "Gedeihen",
    "Gedellten": "Gedellte",
    "Gedemütigten": "Gedemütigte",
    "Gedemütigteren": "Gedemütigtere",
    "Gedemütigtesten": "Gedemütigteste",
    "Gedenkenden": "Gedenkende",
    "Gedenkens": "Gedenken",
    "Gedenkstunden": "Gedenkstunde",
    "Gedenkstätten": "Gedenkstätte",
    "Gedenktafeln": "Gedenktafel",
    "Gedeuchten": "Gedeuchte",
    "Gedeutelten": "Gedeutelte",
    "Gedeuteten": "Gedeutete",
    "Gedeutschten": "Gedeutschte",
    "Gedichte": "Gedicht",
    "Gedichten": "Gedicht",
    "Gedichtes": "Gedicht",
    "Gedichteten": "Gedichtete",
    "Gedichts": "Gedicht",
    "Gediegene": "gediegen",
    "Gediegenen": "Gediegene",
    "Gediegeneren": "Gediegenere",
    "Gediegensten": "Gediegenste",
    "Gediehenen": "Gediehene",
    "Gedieheneren": "Gediehenere",
    "Gediehensten": "Gediehenste",
    "Gedienten": "Gediente",
    "Gedippten": "Gedippte",
    "Gedockten": "Gedockte",
    "Gedokterten": "Gedokterte",
    "Gedolmetschten": "Gedolmetschte",
    "Gedonnerten": "Gedonnerte",
    "Gedoppelten": "Gedoppelte",
    "Gedoppelteren": "Gedoppeltere",
    "Gedoppeltesten": "Gedoppelteste",
    "Gedopten": "Gedopte",
    "Gedopteren": "Gedoptere",
    "Gedoptesten": "Gedopteste",
    "Gedosten": "Gedoste",
    "Gedoubelten": "Gedoubelte",
    "Gedrahteten": "Gedrahtete",
    "Gedrehten": "Gedrehte",
    "Gedrehteren": "Gedrehtere",
    "Gedrehtesten": "Gedrehteste",
    "Gedribbelten": "Gedribbelte",
    "Gedrifteten": "Gedriftete",
    "Gedrillten": "Gedrillte",
    "Gedrillteren": "Gedrilltere",
    "Gedrilltesten": "Gedrillteste",
    "Gedrittelten": "Gedrittelte",
    "Gedrohten": "Gedrohte",
    "Gedroschenen": "Gedroschene",
    "Gedroscheneren": "Gedroschenere",
    "Gedroschensten": "Gedroschenste",
    "Gedrosselten": "Gedrosselte",
    "Gedrosselteren": "Gedrosseltere",
    "Gedrosseltesten": "Gedrosselteste",
    "Gedrucksten": "Gedruckste",
    "Gedruckten": "Gedruckte",
    "Gedrungenen": "Gedrungene",
    "Gedrungeneren": "Gedrungenere",
    "Gedrungensten": "Gedrungenste",
    "Gedrängelten": "Gedrängelte",
    "Gedrängelteren": "Gedrängeltere",
    "Gedrängeltesten": "Gedrängelteste",
    "Gedränges": "Gedränge",
    "Gedrängten": "Gedrängte",
    "Gedröhns": "Gedröhn",
    "Gedröhnten": "Gedröhnte",
    "Gedröselten": "Gedröselte",
    "Gedröselteren": "Gedröseltere",
    "Gedröseltesten": "Gedröselteste",
    "Gedrückte": "gedrückt",
    "Gedrückten": "Gedrückte",
    "Gedrückteren": "Gedrücktere",
    "Gedrücktesten": "Gedrückteste",
    "Geduckten": "Geduckte",
    "Geduckteren": "Geducktere",
    "Geducktesten": "Geduckteste",
    "Gedudelten": "Gedudelte",
    "Gedufteten": "Geduftete",
    "Geduldenden": "Geduldende",
    "Geduldenderen": "Geduldendere",
    "Geduldendsten": "Geduldendste",
    "Geduldens": "Gedulden",
    "Geduldete": "geduldet",
    "Geduldeten": "Geduldete",
    "Geduldeteren": "Geduldetere",
    "Geduldetesten": "Geduldeteste",
    "Geduldigen": "Geduldige",
    "Geduldigeren": "Geduldigere",
    "Geduldigsten": "Geduldigste",
    "Gedungenen": "Gedungene",
    "Gedungeneren": "Gedungenere",
    "Gedungensten": "Gedungenste",
    "Gedunkelten": "Gedunkelte",
    "Gedunkelteren": "Gedunkeltere",
    "Gedunkeltesten": "Gedunkelteste",
    "Gedunsenen": "Gedunsene",
    "Gedunseneren": "Gedunsenere",
    "Gedunsensten": "Gedunsenste",
    "Gedunsteten": "Gedunstete",
    "Gedunsteteren": "Gedunstetere",
    "Gedunstetesten": "Gedunsteteste",
    "Gedursteten": "Gedurstete",
    "Geduschten": "Geduschte",
    "Geduselten": "Geduselte",
    "Geduselteren": "Geduseltere",
    "Geduseltesten": "Geduselteste",
    "Geduzten": "Geduzte",
    "Gedächtnisschwachen": "Gedächtnisschwache",
    "Gedächtnisschwächeren": "Gedächtnisschwächere",
    "Gedächtnisse": "Gedächtnis",
    "Gedächtnissen": "Gedächtnis",
    "Gedächtnisses": "Gedächtnis",
    "Gedämmerten": "Gedämmerte",
    "Gedämmten": "Gedämmte",
    "Gedämpfte": "gedämpft",
    "Gedämpften": "Gedämpfte",
    "Gedörrten": "Gedörrte",
    "Gedöste": "gedöst",
    "Gedösten": "Gedöste",
    "Gedübelten": "Gedübelte",
    "Gedümpelten": "Gedümpelte",
    "Gedüngten": "Gedüngte",
    "Gedüngteren": "Gedüngtere",
    "Gedüngtesten": "Gedüngteste",
    "Gedünkten": "Gedünkte",
    "Gedünnten": "Gedünnte",
    "Gedünstete": "gedünstet",
    "Gedünsteten": "Gedünstete",
    "Gedünstetere": "gedünstet",
    "Gedünsteteren": "Gedünstetere",
    "Gedünsteteste": "gedünstet",
    "Gedünstetesten": "Gedünsteteste",
    "Gedürstete": "gedürstet",
    "Gedürsteten": "Gedürstete",
    "Gedüsten": "Gedüste",
    "Geebbten": "Geebbte",
    "Geebneten": "Geebnete",
    "Geehelichten": "Geehelichte",
    "Geehrten": "Geehrte",
    "Geehrteren": "Geehrtere",
    "Geehrtesten": "Geehrteste",
    "Geeichten": "Geeichte",
    "Geeichteren": "Geeichtere",
    "Geeichtesten": "Geeichteste",
    "Geeierten": "Geeierte",
    "Geeiferten": "Geeiferte",
    "Geeigneten": "Geeignete",
    "Geeigneteren": "Geeignetere",
    "Geeignetesten": "Geeigneteste",
    "Geeilten": "Geeilte",
    "Geeinigten": "Geeinigte",
    "Geeinten": "Geeinte",
    "Geeisten": "Geeiste",
    "Geeiterten": "Geeiterte",
    "Geeiterteren": "Geeitertere",
    "Geeitertesten": "Geeiterteste",
    "Geekelten": "Geekelte",
    "Geekelteren": "Geekeltere",
    "Geekeltesten": "Geekelteste",
    "Geendeten": "Geendete",
    "Geengten": "Geengte",
    "Geerbten": "Geerbte",
    "Geerdeten": "Geerdete",
    "Geernteten": "Geerntete",
    "Gefachten": "Gefachte",
    "Gefachteren": "Gefachtere",
    "Gefachtesten": "Gefachteste",
    "Gefahndeten": "Gefahndete",
    "Gefahren": "Gefahr",
    "Gefahrene": "gefahren",
    "Gefahrenen": "Gefahrene",
    "Gefahreneren": "Gefahrenere",
    "Gefahrensten": "Gefahrenste",
    "Gefahrlosen": "Gefahrlose",
    "Gefahrloseren": "Gefahrlosere",
    "Gefahrlosesten": "Gefahrloseste",
    "Gefahrvollen": "Gefahrvolle",
    "Gefahrvolleren": "Gefahrvollere",
    "Gefahrvollsten": "Gefahrvollste",
    "Gefallenden": "Gefallende",
    "Gefallenderen": "Gefallendere",
    "Gefallendsten": "Gefallendste",
    "Gefallenen": "Gefallene",
    "Gefalleneren": "Gefallenere",
    "Gefallens": "Gefallen",
    "Gefallenste": "gefallen",
    "Gefallensten": "Gefallenste",
    "Gefalteten": "Gefaltete",
    "Gefalteteren": "Gefaltetere",
    "Gefaltetesten": "Gefalteteste",
    "Gefalzten": "Gefalzte",
    "Gefangenen": "Gefangene",
    "Gefangeneren": "Gefangenere",
    "Gefangengehaltenen": "Gefangengehaltene",
    "Gefangenhaltenden": "Gefangenhaltende",
    "Gefangenhaltens": "Gefangenhalten",
    "Gefangenschaften": "Gefangenschaft",
    "Gefangenste": "gefangen",
    "Gefangensten": "Gefangenste",
    "Gefasels": "Gefasel",
    "Gefaselten": "Gefaselte",
    "Gefaselteren": "Gefaseltere",
    "Gefaseltesten": "Gefaselteste",
    "Gefaserten": "Gefaserte",
    "Gefaserteren": "Gefasertere",
    "Gefasertesten": "Gefaserteste",
    "Gefasteten": "Gefastete",
    "Gefauchten": "Gefauchte",
    "Gefaulenzten": "Gefaulenzte",
    "Gefaulten": "Gefaulte",
    "Gefaulteren": "Gefaultere",
    "Gefaultesten": "Gefaulteste",
    "Gefausteten": "Gefaustete",
    "Gefaxten": "Gefaxte",
    "Gefaßten": "Gefaßte",
    "Gefaßteren": "Gefaßtere",
    "Gefaßtesten": "Gefaßteste",
    "Gefechte": "Gefecht",
    "Gefechten": "Gefecht",
    "Gefechtes": "Gefecht",
    "Gefechts": "Gefecht",
    "Gefechtsbereite": "gefechtsbereit",
    "Gefechtsbereiten": "Gefechtsbereite",
    "Gefederten": "Gefederte",
    "Gefederteren": "Gefedertere",
    "Gefedertesten": "Gefederteste",
    "Gefegen": "Gefege",
    "Gefeges": "Gefege",
    "Gefegten": "Gefegte",
    "Gefehlten": "Gefehlte",
    "Gefeierten": "Gefeierte",
    "Gefeierteren": "Gefeiertere",
    "Gefeiertesten": "Gefeierteste",
    "Gefeilschten": "Gefeilschte",
    "Gefeilten": "Gefeilte",
    "Gefeindeten": "Gefeindete",
    "Gefeiten": "Gefeite",
    "Gefeiteren": "Gefeitere",
    "Gefeitesten": "Gefeiteste",
    "Geferkelten": "Geferkelte",
    "Gefertigten": "Gefertigte",
    "Gefesselten": "Gefesselte",
    "Gefesselteren": "Gefesseltere",
    "Gefesseltesten": "Gefesselteste",
    "Gefestigten": "Gefestigte",
    "Gefestigteren": "Gefestigtere",
    "Gefestigtesten": "Gefestigteste",
    "Gefetteten": "Gefettete",
    "Gefetteteren": "Gefettetere",
    "Gefettetesten": "Gefetteteste",
    "Gefetzten": "Gefetzte",
    "Gefetzteren": "Gefetztere",
    "Gefetztesten": "Gefetzteste",
    "Gefeuchteten": "Gefeuchtete",
    "Gefeuchteteren": "Gefeuchtetere",
    "Gefeuchtetesten": "Gefeuchteteste",
    "Gefeuerten": "Gefeuerte",
    "Gefieberten": "Gefieberte",
    "Gefiedelten": "Gefiedelte",
    "Gefieders": "Gefieder",
    "Gefiederten": "Gefiederte",
    "Gefiederteren": "Gefiedertere",
    "Gefiedertesten": "Gefiederteste",
    "Gefilmten": "Gefilmte",
    "Gefilterten": "Gefilterte",
    "Gefilzten": "Gefilzte",
    "Gefirmten": "Gefirmte",
    "Gefischten": "Gefischte",
    "Gefixten": "Gefixte",
    "Geflachten": "Geflachte",
    "Geflackerten": "Geflackerte",
    "Geflaggten": "Geflaggte",
    "Geflaggteren": "Geflaggtere",
    "Geflaggtesten": "Geflaggteste",
    "Geflammten": "Geflammte",
    "Geflammteren": "Geflammtere",
    "Geflammtesten": "Geflammteste",
    "Geflankten": "Geflankte",
    "Geflanschten": "Geflanschte",
    "Geflatterten": "Geflatterte",
    "Geflauten": "Geflaute",
    "Geflechte": "Geflecht",
    "Geflechten": "Geflecht",
    "Geflechtes": "Geflecht",
    "Geflechts": "Geflecht",
    "Gefleckten": "Gefleckte",
    "Gefleckteren": "Geflecktere",
    "Geflecktesten": "Gefleckteste",
    "Gefledderten": "Gefledderte",
    "Gefledderteren": "Gefleddertere",
    "Gefleddertesten": "Gefledderteste",
    "Geflegelten": "Geflegelte",
    "Geflegelteren": "Geflegeltere",
    "Geflegeltesten": "Geflegelteste",
    "Geflehten": "Geflehte",
    "Geflennten": "Geflennte",
    "Gefletschten": "Gefletschte",
    "Gefliesten": "Geflieste",
    "Geflimmerten": "Geflimmerte",
    "Geflipperten": "Geflipperte",
    "Geflippten": "Geflippte",
    "Geflitterten": "Geflitterte",
    "Geflitzten": "Geflitzte",
    "Geflochtenen": "Geflochtene",
    "Geflochteneren": "Geflochtenere",
    "Geflochtensten": "Geflochtenste",
    "Geflockten": "Geflockte",
    "Geflogenen": "Geflogene",
    "Geflohenen": "Geflohene",
    "Gefloppten": "Gefloppte",
    "Geflossenen": "Geflossene",
    "Gefluchten": "Gefluchte",
    "Gefluchteten": "Gefluchtete",
    "Geflunkerten": "Geflunkerte",
    "Gefluppten": "Gefluppte",
    "Gefluteten": "Geflutete",
    "Geflutschten": "Geflutschte",
    "Geflutschteren": "Geflutschtere",
    "Geflutschtesten": "Geflutschteste",
    "Geflämmte": "geflämmt",
    "Geflämmten": "Geflämmte",
    "Geflämmtere": "geflämmt",
    "Geflämmteren": "Geflämmtere",
    "Geflämmteste": "geflämmt",
    "Geflämmtesten": "Geflämmteste",
    "Gefläzten": "Gefläzte",
    "Geflöteten": "Geflötete",
    "Geflößten": "Geflößte",
    "Geflüchtete": "geflüchtet",
    "Geflüchteten": "Geflüchtete",
    "Geflügels": "Geflügel",
    "Geflügelte": "geflügelt",
    "Geflügelten": "Geflügelte",
    "Geflüsterten": "Geflüsterte",
    "Gefochtenen": "Gefochtene",
    "Gefolgerten": "Gefolgerte",
    "Gefolges": "Gefolge",
    "Gefolgsmanne": "Gefolgsmann",
    "Gefolgsmannes": "Gefolgsmann",
    "Gefolgsmanns": "Gefolgsmann",
    "Gefolgsmänner": "Gefolgsmann",
    "Gefolgsmännern": "Gefolgsmann",
    "Gefolgten": "Gefolgte",
    "Gefolgteren": "Gefolgtere",
    "Gefolgtesten": "Gefolgteste",
    "Gefolterten": "Gefolterte",
    "Gefolterteren": "Gefoltertere",
    "Gefoltertesten": "Gefolterteste",
    "Gefoppten": "Gefoppte",
    "Gefoppteren": "Gefopptere",
    "Gefopptesten": "Gefoppteste",
    "Geforderten": "Geforderte",
    "Geforderteren": "Gefordertere",
    "Gefordertesten": "Geforderteste",
    "Geformten": "Geformte",
    "Geformteren": "Geformtere",
    "Geformtesten": "Geformteste",
    "Geforschten": "Geforschte",
    "Geforsteten": "Geforstete",
    "Gefoulten": "Gefoulte",
    "Gefoulteren": "Gefoultere",
    "Gefoultesten": "Gefoulteste",
    "Gefrachteten": "Gefrachtete",
    "Gefrachteteren": "Gefrachtetere",
    "Gefrachtetesten": "Gefrachteteste",
    "Gefragten": "Gefragte",
    "Gefragteren": "Gefragtere",
    "Gefragtesten": "Gefragteste",
    "Gefransten": "Gefranste",
    "Gefransteren": "Gefranstere",
    "Gefranstesten": "Gefransteste",
    "Gefranzten": "Gefranzte",
    "Gefranzteren": "Gefranztere",
    "Gefranztesten": "Gefranzteste",
    "Gefreiten": "Gefreite",
    "Gefremdelten": "Gefremdelte",
    "Gefressenen": "Gefressene",
    "Gefreundeten": "Gefreundete",
    "Gefreuten": "Gefreute",
    "Gefrevelten": "Gefrevelte",
    "Gefrevelteren": "Gefreveltere",
    "Gefreveltesten": "Gefrevelteste",
    "Gefrieranlagen": "Gefrieranlage",
    "Gefrierenden": "Gefrierende",
    "Gefrierens": "Gefrieren",
    "Gefrierfache": "Gefrierfach",
    "Gefrierfaches": "Gefrierfach",
    "Gefrierfachs": "Gefrierfach",
    "Gefrierfleische": "Gefrierfleisch",
    "Gefrierfleischen": "Gefrierfleisch",
    "Gefrierfleischs": "Gefrierfleisch",
    "Gefrierfächer": "Gefrierfach",
    "Gefrierfächern": "Gefrierfach",
    "Gefrierschutzmitteln": "Gefrierschutzmittel",
    "Gefrierschutzmittels": "Gefrierschutzmittel",
    "Gefrischten": "Gefrischte",
    "Gefristeten": "Gefristete",
    "Gefrorenen": "Gefrorene",
    "Gefroreneren": "Gefrorenere",
    "Gefrorensten": "Gefrorenste",
    "Gefrotzelten": "Gefrotzelte",
    "Gefrotzelteren": "Gefrotzeltere",
    "Gefrotzeltesten": "Gefrotzelteste",
    "Gefruchteten": "Gefruchtete",
    "Gefruchteteren": "Gefruchtetere",
    "Gefruchtetesten": "Gefruchteteste",
    "Gefrusteten": "Gefrustete",
    "Gefrusteteren": "Gefrustetere",
    "Gefrustetesten": "Gefrusteteste",
    "Gefrästen": "Gefräste",
    "Gefröstelten": "Gefröstelte",
    "Gefröstelteren": "Gefrösteltere",
    "Gefrösteltesten": "Gefröstelteste",
    "Gefuchtelten": "Gefuchtelte",
    "Gefugten": "Gefugte",
    "Gefugteren": "Gefugtere",
    "Gefugtesten": "Gefugteste",
    "Gefummelten": "Gefummelte",
    "Gefummelteren": "Gefummeltere",
    "Gefummeltesten": "Gefummelteste",
    "Gefundenen": "Gefundene",
    "Gefundeneren": "Gefundenere",
    "Gefundensten": "Gefundenste",
    "Gefunkels": "Gefunkel",
    "Gefunkelten": "Gefunkelte",
    "Gefunkten": "Gefunkte",
    "Gefurzten": "Gefurzte",
    "Gefusselten": "Gefusselte",
    "Gefutterten": "Gefutterte",
    "Gefußten": "Gefußte",
    "Gefächelten": "Gefächelte",
    "Gefächerten": "Gefächerte",
    "Gefädelten": "Gefädelte",
    "Gefährdenden": "Gefährdende",
    "Gefährdenderen": "Gefährdendere",
    "Gefährdendsten": "Gefährdendste",
    "Gefährdens": "Gefährden",
    "Gefährdete": "gefährdet",
    "Gefährdeten": "Gefährdete",
    "Gefährdeteren": "Gefährdetere",
    "Gefährdetesten": "Gefährdeteste",
    "Gefährdungen": "Gefährdung",
    "Gefährlichen": "Gefährliche",
    "Gefährlicheren": "Gefährlichere",
    "Gefährlichsten": "Gefährlichste",
    "Gefälles": "Gefälle",
    "Gefälligen": "Gefällige",
    "Gefälligeren": "Gefälligere",
    "Gefälligkeiten": "Gefälligkeit",
    "Gefälligste": "gefällig",
    "Gefälligsten": "Gefälligste",
    "Gefällten": "Gefällte",
    "Gefälschten": "Gefälschte",
    "Gefängnisse": "Gefängnis",
    "Gefängnissen": "Gefängnis",
    "Gefängnisses": "Gefängnis",
    "Gefärbten": "Gefärbte",
    "Gefärbteren": "Gefärbtere",
    "Gefärbtesten": "Gefärbteste",
    "Gefäße": "Gefäß",
    "Gefäßen": "Gefäß",
    "Gefäßes": "Gefäß",
    "Geföhnten": "Geföhnte",
    "Gefönten": "Gefönte",
    "Geförderte": "gefördert",
    "Geförderten": "Geförderte",
    "Gefördertere": "gefördert",
    "Geförderteren": "Gefördertere",
    "Geförderteste": "gefördert",
    "Gefördertesten": "Geförderteste",
    "Gefügen": "Gefüge",
    "Gefüges": "Gefüge",
    "Gefügige": "gefügig",
    "Gefügigen": "Gefügige",
    "Gefügigeren": "Gefügigere",
    "Gefügigsten": "Gefügigste",
    "Gefügte": "gefügt",
    "Gefügten": "Gefügte",
    "Gefühle": "Gefühl",
    "Gefühlen": "Gefühl",
    "Gefühles": "Gefühl",
    "Gefühllose": "gefühllos",
    "Gefühllosen": "Gefühllose",
    "Gefühlloseren": "Gefühllosere",
    "Gefühllosesten": "Gefühlloseste",
    "Gefühls": "Gefühl",
    "Gefühlsbetonte": "gefühlsbetont",
    "Gefühlsbetonten": "Gefühlsbetonte",
    "Gefühlsbetonteren": "Gefühlsbetontere",
    "Gefühlskalten": "Gefühlskalte",
    "Gefühlskälteren": "Gefühlskältere",
    "Gefühlskältesten": "Gefühlskälteste",
    "Gefühlsmäßigen": "Gefühlsmäßige",
    "Gefühlten": "Gefühlte",
    "Gefühlvollen": "Gefühlvolle",
    "Gefühlvolleren": "Gefühlvollere",
    "Gefühlvollsten": "Gefühlvollste",
    "Geführten": "Geführte",
    "Geführteren": "Geführtere",
    "Geführtesten": "Geführteste",
    "Gefüllten": "Gefüllte",
    "Gefüllteren": "Gefülltere",
    "Gefülltesten": "Gefüllteste",
    "Gefürchteten": "Gefürchtete",
    "Gefürchteteren": "Gefürchtetere",
    "Gefürchtetesten": "Gefürchteteste",
    "Gefütterte": "gefüttert",
    "Gefütterten": "Gefütterte",
    "Gegabelten": "Gegabelte",
    "Gegafften": "Gegaffte",
    "Gegammelten": "Gegammelte",
    "Gegangenen": "Gegangene",
    "Gegarten": "Gegarte",
    "Gegarteren": "Gegartere",
    "Gegartesten": "Gegarteste",
    "Gegasten": "Gegaste",
    "Gegaukelten": "Gegaukelte",
    "Gegaunerten": "Gegaunerte",
    "Gegebenen": "Gegebene",
    "Gegebenheiten": "Gegebenheit",
    "Gegehrten": "Gegehrte",
    "Gegeigten": "Gegeigte",
    "Gegeilten": "Gegeilte",
    "Gegeisterten": "Gegeisterte",
    "Gegeizten": "Gegeizte",
    "Gegeißelten": "Gegeißelte",
    "Gegeißelteren": "Gegeißeltere",
    "Gegeißeltesten": "Gegeißelteste",
    "Gegenangebote": "Gegenangebot",
    "Gegenangeboten": "Gegenangebot",
    "Gegenangebots": "Gegenangebot",
    "Gegenantrage": "Gegenantrag",
    "Gegenantrags": "Gegenantrag",
    "Gegenanträge": "Gegenantrag",
    "Gegenanträgen": "Gegenantrag",
    "Gegenbuchenden": "Gegenbuchende",
    "Gegenbuchens": "Gegenbuchen",
    "Gegendarstellungen": "Gegendarstellung",
    "Gegenden": "Gegend",
    "Gegendienste": "Gegendienst",
    "Gegendiensten": "Gegendienst",
    "Gegendiensts": "Gegendienst",
    "Gegenentwurfe": "Gegenentwurf",
    "Gegenentwurfs": "Gegenentwurf",
    "Gegenentwürfe": "Gegenentwurf",
    "Gegenentwürfen": "Gegenentwurf",
    "Gegenfahrbahnen": "Gegenfahrbahn",
    "Gegenfeuern": "Gegenfeuer",
    "Gegenfeuers": "Gegenfeuer",
    "Gegenforderungen": "Gegenforderung",
    "Gegenfragen": "Gegenfrage",
    "Gegenfugen": "Gegenfuge",
    "Gegengaben": "Gegengabe",
    "Gegengebuchten": "Gegengebuchte",
    "Gegengelenkten": "Gegengelenkte",
    "Gegengelesenen": "Gegengelesene",
    "Gegengeraden": "Gegengerade",
    "Gegengeschenke": "Gegengeschenk",
    "Gegengeschenken": "Gegengeschenk",
    "Gegengeschenks": "Gegengeschenk",
    "Gegengesteuerten": "Gegengesteuerte",
    "Gegengezeichneten": "Gegengezeichnete",
    "Gegengifte": "Gegengift",
    "Gegengiften": "Gegengift",
    "Gegengifts": "Gegengift",
    "Gegengrunde": "Gegengrund",
    "Gegengrunds": "Gegengrund",
    "Gegengründe": "Gegengrund",
    "Gegengründen": "Gegengrund",
    "Gegenhiebe": "Gegenhieb",
    "Gegenhieben": "Gegenhieb",
    "Gegenhiebs": "Gegenhieb",
    "Gegenkathoden": "Gegenkathode",
    "Gegenklagen": "Gegenklage",
    "Gegenklägern": "Gegenkläger",
    "Gegenklägers": "Gegenkläger",
    "Gegenkräfte": "Gegenkraft",
    "Gegenkräften": "Gegenkraft",
    "Gegenkurse": "Gegenkurs",
    "Gegenkursen": "Gegenkurs",
    "Gegenkurss": "Gegenkurs",
    "Gegenkönige": "Gegenkönig",
    "Gegenkönigen": "Gegenkönig",
    "Gegenkönigs": "Gegenkönig",
    "Gegenlasten": "Gegenlast",
    "Gegenleistungen": "Gegenleistung",
    "Gegenlenkenden": "Gegenlenkende",
    "Gegenlenkens": "Gegenlenken",
    "Gegenlesenden": "Gegenlesende",
    "Gegenlesens": "Gegenlesen",
    "Gegenlichte": "Gegenlicht",
    "Gegenlichter": "Gegenlicht",
    "Gegenlichtern": "Gegenlicht",
    "Gegenlichtes": "Gegenlicht",
    "Gegenlichts": "Gegenlicht",
    "Gegenlisten": "Gegenliste",
    "Gegenläufige": "gegenläufig",
    "Gegenläufigen": "Gegenläufige",
    "Gegenmaßnahmen": "Gegenmaßnahme",
    "Gegenmeinungen": "Gegenmeinung",
    "Gegenmitteln": "Gegenmittel",
    "Gegenmittels": "Gegenmittel",
    "Gegenmuttern": "Gegenmutter",
    "Gegenoffensiven": "Gegenoffensive",
    "Gegenpapste": "Gegenpapst",
    "Gegenpapsts": "Gegenpapst",
    "Gegenparteien": "Gegenpartei",
    "Gegenphasen": "Gegenphase",
    "Gegenpole": "Gegenpol",
    "Gegenpolen": "Gegenpol",
    "Gegenpols": "Gegenpol",
    "Gegenproben": "Gegenprobe",
    "Gegenpäpste": "Gegenpapst",
    "Gegenpäpsten": "Gegenpapst",
    "Gegenrechnungen": "Gegenrechnung",
    "Gegenreden": "Gegenrede",
    "Gegenregierungen": "Gegenregierung",
    "Gegenrudern": "Gegenruder",
    "Gegenruders": "Gegenruder",
    "Gegensatze": "Gegensatz",
    "Gegensatzes": "Gegensatz",
    "Gegenschlage": "Gegenschlag",
    "Gegenschlags": "Gegenschlag",
    "Gegenschläge": "Gegenschlag",
    "Gegenschlägen": "Gegenschlag",
    "Gegenschriften": "Gegenschrift",
    "Gegenschulden": "Gegenschuld",
    "Gegenseiten": "Gegenseite",
    "Gegenseitige": "gegenseitig",
    "Gegenseitigen": "Gegenseitige",
    "Gegensonnen": "Gegensonne",
    "Gegenspielern": "Gegenspieler",
    "Gegenspielers": "Gegenspieler",
    "Gegensprechanlagen": "Gegensprechanlage",
    "Gegenstande": "Gegenstand",
    "Gegenstandes": "Gegenstand",
    "Gegenstandpunkte": "Gegenstandpunkt",
    "Gegenstandpunkten": "Gegenstandpunkt",
    "Gegenstandpunkts": "Gegenstandpunkt",
    "Gegenstands": "Gegenstand",
    "Gegensteuernden": "Gegensteuernde",
    "Gegensteuerns": "Gegensteuern",
    "Gegenströmungen": "Gegenströmung",
    "Gegenstände": "Gegenstand",
    "Gegenständen": "Gegenstand",
    "Gegenständige": "gegenständig",
    "Gegenständigen": "Gegenständige",
    "Gegenständlichen": "Gegenständliche",
    "Gegenstücke": "Gegenstück",
    "Gegenstücken": "Gegenstück",
    "Gegenstücks": "Gegenstück",
    "Gegensätze": "Gegensatz",
    "Gegensätzen": "Gegensatz",
    "Gegensätzliche": "gegensätzlich",
    "Gegensätzlichen": "Gegensätzliche",
    "Gegenteile": "Gegenteil",
    "Gegenteilen": "Gegenteil",
    "Gegenteiles": "Gegenteil",
    "Gegenteilige": "gegenteilig",
    "Gegenteiligen": "Gegenteilige",
    "Gegenteils": "Gegenteil",
    "Gegentore": "Gegentor",
    "Gegentoren": "Gegentor",
    "Gegentors": "Gegentor",
    "Gegenverpflichtungen": "Gegenverpflichtung",
    "Gegenvorschlage": "Gegenvorschlag",
    "Gegenvorschlags": "Gegenvorschlag",
    "Gegenvorschläge": "Gegenvorschlag",
    "Gegenvorschlägen": "Gegenvorschlag",
    "Gegenvorwurfe": "Gegenvorwurf",
    "Gegenvorwurfs": "Gegenvorwurf",
    "Gegenvorwürfe": "Gegenvorwurf",
    "Gegenvorwürfen": "Gegenvorwurf",
    "Gegenwartsaufgaben": "Gegenwartsaufgabe",
    "Gegenwartskinos": "Gegenwartskino",
    "Gegenwerte": "Gegenwert",
    "Gegenwerten": "Gegenwert",
    "Gegenwerts": "Gegenwert",
    "Gegenwinds": "Gegenwind",
    "Gegenwinkeln": "Gegenwinkel",
    "Gegenwinkels": "Gegenwinkel",
    "Gegenwirkungen": "Gegenwirkung",
    "Gegenwärtige": "gegenwärtig",
    "Gegenwärtigen": "Gegenwärtige",
    "Gegenzeichnenden": "Gegenzeichnende",
    "Gegenzeichnens": "Gegenzeichnen",
    "Gegenzuge": "Gegenzug",
    "Gegenzugs": "Gegenzug",
    "Gegenzüge": "Gegenzug",
    "Gegenzügen": "Gegenzug",
    "Gegenübergestandenen": "Gegenübergestandene",
    "Gegenübergestellten": "Gegenübergestellte",
    "Gegenübergetretenen": "Gegenübergetretene",
    "Gegenüberstehenden": "Gegenüberstehende",
    "Gegenüberstehens": "Gegenüberstehen",
    "Gegenüberstellenden": "Gegenüberstellende",
    "Gegenüberstellens": "Gegenüberstellen",
    "Gegenüberstellungen": "Gegenüberstellung",
    "Gegenübertretenden": "Gegenübertretende",
    "Gegenübertretens": "Gegenübertreten",
    "Gegerbten": "Gegerbte",
    "Gegerbteren": "Gegerbtere",
    "Gegerbtesten": "Gegerbteste",
    "Gegessenen": "Gegessene",
    "Gegierten": "Gegierte",
    "Gegifteten": "Gegiftete",
    "Gegipfelten": "Gegipfelte",
    "Gegipsten": "Gegipste",
    "Gegitterten": "Gegitterte",
    "Geglasten": "Geglaste",
    "Geglaubten": "Geglaubte",
    "Gegleisten": "Gegleiste",
    "Geglibberten": "Geglibberte",
    "Geglichenen": "Geglichene",
    "Gegliederten": "Gegliederte",
    "Geglimmerten": "Geglimmerte",
    "Geglimmerteren": "Geglimmertere",
    "Geglimmertesten": "Geglimmerteste",
    "Geglitschten": "Geglitschte",
    "Geglittenen": "Geglittene",
    "Geglommenen": "Geglommene",
    "Geglotzten": "Geglotzte",
    "Geglucksten": "Gegluckste",
    "Geglupschten": "Geglupschte",
    "Geglänzten": "Geglänzte",
    "Geglätteten": "Geglättete",
    "Geglätteteren": "Geglättetere",
    "Geglättetesten": "Geglätteteste",
    "Geglückten": "Geglückte",
    "Geglückteren": "Geglücktere",
    "Geglücktesten": "Geglückteste",
    "Geglühten": "Geglühte",
    "Gegnerinnen": "Gegnerin",
    "Gegnerische": "gegnerisch",
    "Gegnerischen": "Gegnerische",
    "Gegnern": "Gegner",
    "Gegners": "Gegner",
    "Gegolften": "Gegolfte",
    "Gegoltenen": "Gegoltene",
    "Gegondelten": "Gegondelte",
    "Gegongten": "Gegongte",
    "Gegorenen": "Gegorene",
    "Gegoreneren": "Gegorenere",
    "Gegorensten": "Gegorenste",
    "Gegossenen": "Gegossene",
    "Gegrabenen": "Gegrabene",
    "Gegrabschten": "Gegrabschte",
    "Gegrasten": "Gegraste",
    "Gegraulten": "Gegraulte",
    "Gegraupelten": "Gegraupelte",
    "Gegraupelteren": "Gegraupeltere",
    "Gegraupeltesten": "Gegraupelteste",
    "Gegrausten": "Gegrauste",
    "Gegrenzten": "Gegrenzte",
    "Gegriffenen": "Gegriffene",
    "Gegrillten": "Gegrillte",
    "Gegrinses": "Gegrinse",
    "Gegrinsten": "Gegrinste",
    "Gegrummelten": "Gegrummelte",
    "Gegrunzten": "Gegrunzte",
    "Gegruselten": "Gegruselte",
    "Gegrämten": "Gegrämte",
    "Gegrätschten": "Gegrätschte",
    "Gegröles": "Gegröle",
    "Gegrölten": "Gegrölte",
    "Gegrölteren": "Gegröltere",
    "Gegröltesten": "Gegrölteste",
    "Gegrübelten": "Gegrübelte",
    "Gegründeten": "Gegründete",
    "Gegrüßten": "Gegrüßte",
    "Geguckten": "Geguckte",
    "Gegurgelten": "Gegurgelte",
    "Gegurrten": "Gegurrte",
    "Gegurteten": "Gegurtete",
    "Gegähnten": "Gegähnte",
    "Gegängelten": "Gegängelte",
    "Gegängelteren": "Gegängeltere",
    "Gegängeltesten": "Gegängelteste",
    "Gegärtnerten": "Gegärtnerte",
    "Gegönnten": "Gegönnte",
    "Gehaarten": "Gehaarte",
    "Gehabes": "Gehabe",
    "Gehabten": "Gehabte",
    "Gehackten": "Gehackte",
    "Gehaderten": "Gehaderte",
    "Gehafteten": "Gehaftete",
    "Gehagelten": "Gehagelte",
    "Gehakten": "Gehakte",
    "Gehalfterten": "Gehalfterte",
    "Gehallten": "Gehallte",
    "Gehalsten": "Gehalste",
    "Gehalte": "Gehalt",
    "Gehaltenen": "Gehaltene",
    "Gehaltes": "Gehalt",
    "Gehalts": "Gehalt",
    "Gehaltvolle": "gehaltvoll",
    "Gehaltvollen": "Gehaltvolle",
    "Gehaltvolleren": "Gehaltvollere",
    "Gehaltvollsten": "Gehaltvollste",
    "Gehampelten": "Gehampelte",
    "Gehamsterten": "Gehamsterte",
    "Gehandelten": "Gehandelte",
    "Gehandhabten": "Gehandhabte",
    "Gehangelten": "Gehangelte",
    "Gehangene": "gehangen",
    "Gehangenen": "Gehangene",
    "Gehaperten": "Gehaperte",
    "Geharrten": "Geharrte",
    "Geharzten": "Geharzte",
    "Gehaschten": "Gehaschte",
    "Gehaspelten": "Gehaspelte",
    "Gehasteten": "Gehastete",
    "Gehauchten": "Gehauchte",
    "Gehauenen": "Gehauene",
    "Gehausten": "Gehauste",
    "Gehaßten": "Gehaßte",
    "Gehaßteren": "Gehaßtere",
    "Gehaßtesten": "Gehaßteste",
    "Gehbehinderten": "Gehbehinderte",
    "Gehechelten": "Gehechelte",
    "Gehechteten": "Gehechtete",
    "Gehefteten": "Geheftete",
    "Gehegen": "Gehege",
    "Geheges": "Gehege",
    "Gehegten": "Gehegte",
    "Gehegteren": "Gehegtere",
    "Gehegtesten": "Gehegteste",
    "Geheilten": "Geheilte",
    "Geheimagenten": "Geheimagent",
    "Geheimbunde": "Geheimbund",
    "Geheimbunds": "Geheimbund",
    "Geheimbünde": "Geheimbund",
    "Geheimbünden": "Geheimbund",
    "Geheimbündlern": "Geheimbündler",
    "Geheimbündlers": "Geheimbündler",
    "Geheimdienste": "Geheimdienst",
    "Geheimdiensten": "Geheimdienst",
    "Geheimdienstlern": "Geheimdienstler",
    "Geheimdienstlers": "Geheimdienstler",
    "Geheimdiensts": "Geheimdienst",
    "Geheime": "geheim",
    "Geheimelten": "Geheimelte",
    "Geheimen": "Geheime",
    "Geheimeren": "Geheimere",
    "Geheimgehaltenen": "Geheimgehaltene",
    "Geheimgehalteneren": "Geheimgehaltenere",
    "Geheimhaltenden": "Geheimhaltende",
    "Geheimhaltenderen": "Geheimhaltendere",
    "Geheimhaltendsten": "Geheimhaltendste",
    "Geheimhaltens": "Geheimhalten",
    "Geheimniskrämern": "Geheimniskrämer",
    "Geheimniskrämers": "Geheimniskrämer",
    "Geheimnisse": "Geheimnis",
    "Geheimnissen": "Geheimnis",
    "Geheimnisses": "Geheimnis",
    "Geheimnisvolle": "geheimnisvoll",
    "Geheimnisvollen": "Geheimnisvolle",
    "Geheimnisvolleren": "Geheimnisvollere",
    "Geheimnisvollsten": "Geheimnisvollste",
    "Geheimnummern": "Geheimnummer",
    "Geheimpolizisten": "Geheimpolizist",
    "Geheimrate": "Geheimrat",
    "Geheimrats": "Geheimrat",
    "Geheimräte": "Geheimrat",
    "Geheimräten": "Geheimrat",
    "Geheimschriften": "Geheimschrift",
    "Geheimsprachen": "Geheimsprache",
    "Geheimsten": "Geheimste",
    "Geheimtinten": "Geheimtinte",
    "Geheimtips": "Geheimtip",
    "Geheimtüren": "Geheimtür",
    "Geheirateten": "Geheiratete",
    "Geheiterten": "Geheiterte",
    "Geheizten": "Geheizte",
    "Geheizteren": "Geheiztere",
    "Geheiztesten": "Geheizteste",
    "Geheißenen": "Geheißene",
    "Gehellten": "Gehellte",
    "Gehemmten": "Gehemmte",
    "Gehemmteren": "Gehemmtere",
    "Gehemmtesten": "Gehemmteste",
    "Gehenden": "Gehende",
    "Gehens": "Gehen",
    "Gehern": "Geher",
    "Geherrschten": "Geherrschte",
    "Gehers": "Geher",
    "Geherzten": "Geherzte",
    "Geherzteren": "Geherztere",
    "Geherztesten": "Geherzteste",
    "Gehetzten": "Gehetzte",
    "Gehetzteren": "Gehetztere",
    "Gehetztesten": "Gehetzteste",
    "Geheuchelten": "Geheuchelte",
    "Geheuerten": "Geheuerte",
    "Geheuls": "Geheul",
    "Geheulten": "Geheulte",
    "Gehexten": "Gehexte",
    "Gehievten": "Gehievte",
    "Gehilfen": "Gehilfe",
    "Gehilfinnen": "Gehilfin",
    "Gehimmelten": "Gehimmelte",
    "Gehinderten": "Gehinderte",
    "Gehinkten": "Gehinkte",
    "Gehirne": "Gehirn",
    "Gehirnen": "Gehirn",
    "Gehirnes": "Gehirn",
    "Gehirns": "Gehirn",
    "Gehirnwäschen": "Gehirnwäsche",
    "Gehobelten": "Gehobelte",
    "Gehobenen": "Gehobene",
    "Gehobeneren": "Gehobenere",
    "Gehobensten": "Gehobenste",
    "Gehockten": "Gehockte",
    "Gehockteren": "Gehocktere",
    "Gehocktesten": "Gehockteste",
    "Gehofften": "Gehoffte",
    "Geholfenen": "Geholfene",
    "Geholfeneren": "Geholfenere",
    "Geholfensten": "Geholfenste",
    "Geholperten": "Geholperte",
    "Geholperteren": "Geholpertere",
    "Geholpertesten": "Geholperteste",
    "Geholten": "Geholte",
    "Geholzten": "Geholzte",
    "Gehoppelten": "Gehoppelte",
    "Gehoppelteren": "Gehoppeltere",
    "Gehoppeltesten": "Gehoppelteste",
    "Gehoppten": "Gehoppte",
    "Gehopsten": "Gehopste",
    "Gehorchenden": "Gehorchende",
    "Gehorchenderen": "Gehorchendere",
    "Gehorchendsten": "Gehorchendste",
    "Gehorchens": "Gehorchen",
    "Gehorchte": "gehorcht",
    "Gehorchten": "Gehorchte",
    "Gehorsame": "gehorsam",
    "Gehorsamen": "Gehorsame",
    "Gehorsameren": "Gehorsamere",
    "Gehorsamsten": "Gehorsamste",
    "Gehorteten": "Gehortete",
    "Gehorteteren": "Gehortetere",
    "Gehortetesten": "Gehorteteste",
    "Gehren": "Gehre",
    "Gehrenden": "Gehrende",
    "Gehrenderen": "Gehrendere",
    "Gehrendsten": "Gehrendste",
    "Gehrens": "Gehren",
    "Gehsteige": "Gehsteig",
    "Gehsteigen": "Gehsteig",
    "Gehsteigs": "Gehsteig",
    "Gehuldigten": "Gehuldigte",
    "Gehungerten": "Gehungerte",
    "Gehupten": "Gehupte",
    "Gehuschten": "Gehuschte",
    "Gehusteten": "Gehustete",
    "Gehversuche": "Gehversuch",
    "Gehversuchen": "Gehversuch",
    "Gehversuches": "Gehversuch",
    "Gehversuchs": "Gehversuch",
    "Gehwege": "Gehweg",
    "Gehwegen": "Gehweg",
    "Gehweges": "Gehweg",
    "Gehwegs": "Gehweg",
    "Gehäckselten": "Gehäckselte",
    "Gehäkelten": "Gehäkelte",
    "Gehälter": "Gehalt",
    "Gehältern": "Gehalt",
    "Gehämmerten": "Gehämmerte",
    "Gehämmerteren": "Gehämmertere",
    "Gehämmertesten": "Gehämmerteste",
    "Gehändigten": "Gehändigte",
    "Gehängen": "Gehänge",
    "Gehänges": "Gehänge",
    "Gehängten": "Gehängte",
    "Gehänselten": "Gehänselte",
    "Gehänselteren": "Gehänseltere",
    "Gehänseltesten": "Gehänselteste",
    "Gehärteten": "Gehärtete",
    "Gehärteteren": "Gehärtetere",
    "Gehärtetesten": "Gehärteteste",
    "Gehässigen": "Gehässige",
    "Gehässigeren": "Gehässigere",
    "Gehässigsten": "Gehässigste",
    "Gehätschelten": "Gehätschelte",
    "Gehätschelteren": "Gehätscheltere",
    "Gehätscheltesten": "Gehätschelteste",
    "Gehäuften": "Gehäufte",
    "Gehäufteren": "Gehäuftere",
    "Gehäuftesten": "Gehäufteste",
    "Gehäusen": "Gehäuse",
    "Gehäuses": "Gehäuse",
    "Gehäuteten": "Gehäutete",
    "Gehöhlten": "Gehöhlte",
    "Gehölzkundlichen": "Gehölzkundliche",
    "Gehör": "gehören",
    "Gehörenden": "Gehörende",
    "Gehörens": "Gehören",
    "Gehörigen": "Gehörige",
    "Gehörne": "Gehörn",
    "Gehörnen": "Gehörn",
    "Gehörns": "Gehörn",
    "Gehörnte": "gehörnt",
    "Gehörnten": "Gehörnte",
    "Gehörnteren": "Gehörntere",
    "Gehörntesten": "Gehörnteste",
    "Gehörs": "Gehör",
    "Gehörte": "gehört",
    "Gehörten": "Gehörte",
    "Gehüllten": "Gehüllte",
    "Gehülsten": "Gehülste",
    "Gehüpften": "Gehüpfte",
    "Gehüteten": "Gehütete",
    "Gehüteteren": "Gehütetere",
    "Gehütetesten": "Gehüteteste",
    "Geiern": "Geier",
    "Geiers": "Geier",
    "Geige": "geigen",
    "Geigelten": "Geigelte",
    "Geigen": "Geige",
    "Geigenden": "Geigende",
    "Geigens": "Geigen",
    "Geigern": "Geiger",
    "Geigers": "Geiger",
    "Geilenden": "Geilende",
    "Geilenderen": "Geilendere",
    "Geilendsten": "Geilendste",
    "Geilens": "Geilen",
    "Geilheiten": "Geilheit",
    "Geimkerten": "Geimkerte",
    "Geimpften": "Geimpfte",
    "Geirrten": "Geirrte",
    "Geiseln": "Geisel",
    "Geiselnahmen": "Geiselnahme",
    "Geisenheims": "Geisenheim",
    "Geiste": "Geist",
    "Geister": "geistern",
    "Geisterfahrern": "Geisterfahrer",
    "Geisterfahrers": "Geisterfahrer",
    "Geisterhafte": "geisterhaft",
    "Geisterhaften": "Geisterhafte",
    "Geisterhafteren": "Geisterhaftere",
    "Geisterhaftesten": "Geisterhafteste",
    "Geistern": "Geist",
    "Geisternden": "Geisternde",
    "Geisterns": "Geistern",
    "Geistes": "Geist",
    "Geistesgegenwärtige": "geistesgegenwärtig",
    "Geistesgegenwärtigen": "Geistesgegenwärtige",
    "Geistesgestörten": "Geistesgestörte",
    "Geisteskranken": "Geisteskranke",
    "Geistesschwachen": "Geistesschwache",
    "Geistesschwächeren": "Geistesschwächere",
    "Geistigen": "Geistige",
    "Geistlichen": "Geistliche",
    "Geistlicheren": "Geistlichere",
    "Geistlichsten": "Geistlichste",
    "Geistlosen": "Geistlose",
    "Geistloseren": "Geistlosere",
    "Geistlosesten": "Geistloseste",
    "Geistlosigkeiten": "Geistlosigkeit",
    "Geistreiche": "geistreich",
    "Geistreichen": "Geistreiche",
    "Geistreicheren": "Geistreichere",
    "Geistreichsten": "Geistreichste",
    "Geiz": "geizen",
    "Geize": "geizen",
    "Geizenden": "Geizende",
    "Geizenderen": "Geizendere",
    "Geizendsten": "Geizendste",
    "Geizens": "Geizen",
    "Geizes": "Geiz",
    "Geizigen": "Geizige",
    "Geizigeren": "Geizigere",
    "Geizigsten": "Geizigste",
    "Geißelnden": "Geißelnde",
    "Geißelnderen": "Geißelndere",
    "Geißelndsten": "Geißelndste",
    "Geißelns": "Geißeln",
    "Geißleins": "Geißlein",
    "Geißlers": "Geißler",
    "Gejagten": "Gejagte",
    "Gejagteren": "Gejagtere",
    "Gejagtesten": "Gejagteste",
    "Gejammerten": "Gejammerte",
    "Gejapsten": "Gejapste",
    "Gejauchzten": "Gejauchzte",
    "Gejaulten": "Gejaulte",
    "Gejobbten": "Gejobbte",
    "Gejodelten": "Gejodelte",
    "Gejohlten": "Gejohlte",
    "Gejubelten": "Gejubelte",
    "Gejubelteren": "Gejubeltere",
    "Gejubeltesten": "Gejubelteste",
    "Gejuchzes": "Gejuchze",
    "Gejuchzten": "Gejuchzte",
    "Gejäteten": "Gejätete",
    "Gekachelten": "Gekachelte",
    "Gekachelteren": "Gekacheltere",
    "Gekacheltesten": "Gekachelteste",
    "Gekakelten": "Gekakelte",
    "Gekakelteren": "Gekakeltere",
    "Gekakeltesten": "Gekakelteste",
    "Gekalbten": "Gekalbte",
    "Gekalkten": "Gekalkte",
    "Gekannten": "Gekannte",
    "Gekanteten": "Gekantete",
    "Gekanteteren": "Gekantetere",
    "Gekantetesten": "Gekanteteste",
    "Gekanzelten": "Gekanzelte",
    "Gekaperten": "Gekaperte",
    "Gekappten": "Gekappte",
    "Gekapselten": "Gekapselte",
    "Gekarrten": "Gekarrte",
    "Gekarteten": "Gekartete",
    "Gekasperten": "Gekasperte",
    "Gekauerten": "Gekauerte",
    "Gekauften": "Gekaufte",
    "Gekauten": "Gekaute",
    "Gekegelten": "Gekegelte",
    "Gekegelteren": "Gekegeltere",
    "Gekegeltesten": "Gekegelteste",
    "Gekehrten": "Gekehrte",
    "Gekeifes": "Gekeife",
    "Gekeiften": "Gekeifte",
    "Gekeilten": "Gekeilte",
    "Gekeimten": "Gekeimte",
    "Gekellerten": "Gekellerte",
    "Gekellnerten": "Gekellnerte",
    "Gekelterten": "Gekelterte",
    "Gekennzeichneten": "Gekennzeichnete",
    "Gekenterten": "Gekenterte",
    "Gekerbten": "Gekerbte",
    "Gekerkerten": "Gekerkerte",
    "Gekernten": "Gekernte",
    "Gekesselten": "Gekesselte",
    "Geketteten": "Gekettete",
    "Gekeuchten": "Gekeuchte",
    "Gekicherten": "Gekicherte",
    "Gekickten": "Gekickte",
    "Gekiekten": "Gekiekte",
    "Gekifften": "Gekiffte",
    "Gekillten": "Gekillte",
    "Gekippten": "Gekippte",
    "Gekitteten": "Gekittete",
    "Gekitteteren": "Gekittetere",
    "Gekittetesten": "Gekitteteste",
    "Gekitzelten": "Gekitzelte",
    "Gekitzelteren": "Gekitzeltere",
    "Gekitzeltesten": "Gekitzelteste",
    "Geklackerten": "Geklackerte",
    "Geklafften": "Geklaffte",
    "Geklagten": "Geklagte",
    "Geklammerten": "Geklammerte",
    "Geklammerteren": "Geklammertere",
    "Geklammertesten": "Geklammerteste",
    "Geklapperten": "Geklapperte",
    "Geklappten": "Geklappte",
    "Geklarten": "Geklarte",
    "Geklatschten": "Geklatschte",
    "Geklatschteren": "Geklatschtere",
    "Geklatschtesten": "Geklatschteste",
    "Geklaubten": "Geklaubte",
    "Geklauten": "Geklaute",
    "Geklebten": "Geklebte",
    "Geklebteren": "Geklebtere",
    "Geklebtesten": "Geklebteste",
    "Gekleckerten": "Gekleckerte",
    "Geklecksten": "Gekleckste",
    "Gekleideten": "Gekleidete",
    "Gekleideteren": "Gekleidetere",
    "Gekleidetesten": "Gekleideteste",
    "Gekleisterten": "Gekleisterte",
    "Geklemmten": "Geklemmte",
    "Geklempnerten": "Geklempnerte",
    "Gekletterten": "Gekletterte",
    "Geklimperten": "Geklimperte",
    "Geklingels": "Geklingel",
    "Geklingelten": "Geklingelte",
    "Geklinkten": "Geklinkte",
    "Geklirrs": "Geklirr",
    "Geklirrten": "Geklirrte",
    "Geklommenen": "Geklommene",
    "Geklonten": "Geklonte",
    "Geklopften": "Geklopfte",
    "Gekloppten": "Gekloppte",
    "Geklotzten": "Geklotzte",
    "Geklotzteren": "Geklotztere",
    "Geklotztesten": "Geklotzteste",
    "Geklumpten": "Geklumpte",
    "Geklumpteren": "Geklumptere",
    "Geklumptesten": "Geklumpteste",
    "Geklungenen": "Geklungene",
    "Geklungeneren": "Geklungenere",
    "Geklungensten": "Geklungenste",
    "Gekläffte": "gekläfft",
    "Gekläfften": "Gekläffte",
    "Geklärte": "geklärt",
    "Geklärten": "Geklärte",
    "Geklärteren": "Geklärtere",
    "Geklärtesten": "Geklärteste",
    "Geklöhnten": "Geklöhnte",
    "Geklönte": "geklönt",
    "Geklönten": "Geklönte",
    "Geklügelten": "Geklügelte",
    "Geklüngelten": "Geklüngelte",
    "Geknabberten": "Geknabberte",
    "Geknacksten": "Geknackste",
    "Geknacksteren": "Geknackstere",
    "Geknackstesten": "Geknacksteste",
    "Geknackten": "Geknackte",
    "Geknackteren": "Geknacktere",
    "Geknacktesten": "Geknackteste",
    "Geknallten": "Geknallte",
    "Geknapsten": "Geknapste",
    "Geknarrten": "Geknarrte",
    "Geknarzten": "Geknarzte",
    "Geknarzteren": "Geknarztere",
    "Geknarztesten": "Geknarzteste",
    "Geknatters": "Geknatter",
    "Geknatterten": "Geknatterte",
    "Geknauserten": "Geknauserte",
    "Geknautschten": "Geknautschte",
    "Geknautschteren": "Geknautschtere",
    "Geknautschtesten": "Geknautschteste",
    "Geknebelten": "Geknebelte",
    "Geknebelteren": "Geknebeltere",
    "Geknebeltesten": "Geknebelteste",
    "Geknechteten": "Geknechtete",
    "Gekneteten": "Geknetete",
    "Geknicksten": "Geknickste",
    "Geknickten": "Geknickte",
    "Geknickteren": "Geknicktere",
    "Geknicktesten": "Geknickteste",
    "Geknieten": "Gekniete",
    "Gekniffenen": "Gekniffene",
    "Geknipsten": "Geknipste",
    "Geknirschten": "Geknirschte",
    "Geknisterten": "Geknisterte",
    "Geknitterten": "Geknitterte",
    "Geknitterteren": "Geknittertere",
    "Geknittertesten": "Geknitterteste",
    "Geknobelten": "Geknobelte",
    "Geknoteten": "Geknotete",
    "Geknufften": "Geknuffte",
    "Geknurrten": "Geknurrte",
    "Geknusperten": "Geknusperte",
    "Geknutschten": "Geknutschte",
    "Geknöpften": "Geknöpfte",
    "Geknüllten": "Geknüllte",
    "Geknüllteren": "Geknülltere",
    "Geknülltesten": "Geknüllteste",
    "Geknüpften": "Geknüpfte",
    "Geknüppelten": "Geknüppelte",
    "Geknüppelteren": "Geknüppeltere",
    "Geknüppeltesten": "Geknüppelteste",
    "Gekochten": "Gekochte",
    "Gekochteren": "Gekochtere",
    "Gekochtesten": "Gekochteste",
    "Gekohlten": "Gekohlte",
    "Gekokelten": "Gekokelte",
    "Gekoksten": "Gekokste",
    "Gekommenen": "Gekommene",
    "Gekonterten": "Gekonterte",
    "Gekonterteren": "Gekontertere",
    "Gekontertesten": "Gekonterteste",
    "Gekoppelten": "Gekoppelte",
    "Gekorkten": "Gekorkte",
    "Gekosteten": "Gekostete",
    "Gekotzten": "Gekotzte",
    "Gekrabbelten": "Gekrabbelte",
    "Gekrachten": "Gekrachte",
    "Gekrallten": "Gekrallte",
    "Gekrallteren": "Gekralltere",
    "Gekralltesten": "Gekrallteste",
    "Gekrampften": "Gekrampfte",
    "Gekramten": "Gekramte",
    "Gekrankten": "Gekrankte",
    "Gekratzten": "Gekratzte",
    "Gekraulten": "Gekraulte",
    "Gekrausten": "Gekrauste",
    "Gekrausteren": "Gekraustere",
    "Gekraustesten": "Gekrausteste",
    "Gekreideten": "Gekreidete",
    "Gekreisches": "Gekreische",
    "Gekreischten": "Gekreischte",
    "Gekreisten": "Gekreiste",
    "Gekrempelten": "Gekrempelte",
    "Gekreuzigten": "Gekreuzigte",
    "Gekreuzten": "Gekreuzte",
    "Gekribbelten": "Gekribbelte",
    "Gekriegten": "Gekriegte",
    "Gekringelten": "Gekringelte",
    "Gekringelteren": "Gekringeltere",
    "Gekringeltesten": "Gekringelteste",
    "Gekriselten": "Gekriselte",
    "Gekritzels": "Gekritzel",
    "Gekritzelten": "Gekritzelte",
    "Gekrochenen": "Gekrochene",
    "Gekrächzten": "Gekrächzte",
    "Gekrächzteren": "Gekrächztere",
    "Gekrächztesten": "Gekrächzteste",
    "Gekräftigten": "Gekräftigte",
    "Gekrähten": "Gekrähte",
    "Gekränzten": "Gekränzte",
    "Gekräuselten": "Gekräuselte",
    "Gekräuselteren": "Gekräuseltere",
    "Gekräuseltesten": "Gekräuselteste",
    "Gekrönten": "Gekrönte",
    "Gekrümelten": "Gekrümelte",
    "Gekrümelteren": "Gekrümeltere",
    "Gekrümeltesten": "Gekrümelteste",
    "Gekrümmten": "Gekrümmte",
    "Gekrümmteren": "Gekrümmtere",
    "Gekrümmtesten": "Gekrümmteste",
    "Gekugelten": "Gekugelte",
    "Gekundschafteten": "Gekundschaftete",
    "Gekungelten": "Gekungelte",
    "Gekungelteren": "Gekungeltere",
    "Gekungeltesten": "Gekungelteste",
    "Gekuppelten": "Gekuppelte",
    "Gekurbelten": "Gekurbelte",
    "Gekurvten": "Gekurvte",
    "Gekuschelten": "Gekuschelte",
    "Gekuschelteren": "Gekuscheltere",
    "Gekuscheltesten": "Gekuschelteste",
    "Gekuschten": "Gekuschte",
    "Gekämmten": "Gekämmte",
    "Gekämpften": "Gekämpfte",
    "Gekäute": "gekäut",
    "Gekäuten": "Gekäute",
    "Geköderten": "Geköderte",
    "Geköpften": "Geköpfte",
    "Gekübelten": "Gekübelte",
    "Gekühlten": "Gekühlte",
    "Gekühlteren": "Gekühltere",
    "Gekühltesten": "Gekühlteste",
    "Gekümmerten": "Gekümmerte",
    "Gekündigten": "Gekündigte",
    "Gekürten": "Gekürte",
    "Gekürzten": "Gekürzte",
    "Gekürzteren": "Gekürztere",
    "Gekürztesten": "Gekürzteste",
    "Geküßten": "Geküßte",
    "Gelabbers": "Gelabber",
    "Gelabberten": "Gelabberte",
    "Gelabers": "Gelaber",
    "Gelaberten": "Gelaberte",
    "Gelabten": "Gelabte",
    "Gelabteren": "Gelabtere",
    "Gelabtesten": "Gelabteste",
    "Gelachten": "Gelachte",
    "Gelackmeierten": "Gelackmeierte",
    "Geladenen": "Geladene",
    "Gelagen": "Gelage",
    "Gelagerten": "Gelagerte",
    "Gelages": "Gelage",
    "Gelahmten": "Gelahmte",
    "Gelallten": "Gelallte",
    "Gelallteren": "Gelalltere",
    "Gelalltesten": "Gelallteste",
    "Gelandeten": "Gelandete",
    "Gelangten": "Gelangte",
    "Gelangweilten": "Gelangweilte",
    "Gelangweilteren": "Gelangweiltere",
    "Gelangweiltesten": "Gelangweilteste",
    "Gelappten": "Gelappte",
    "Gelassenen": "Gelassene",
    "Gelasteten": "Gelastete",
    "Gelatschten": "Gelatschte",
    "Gelauerten": "Gelauerte",
    "Gelaufenen": "Gelaufene",
    "Gelaufes": "Gelaufe",
    "Gelaugten": "Gelaugte",
    "Gelaunten": "Gelaunte",
    "Gelaunteren": "Gelauntere",
    "Gelauntesten": "Gelaunteste",
    "Gelauschten": "Gelauschte",
    "Gelausten": "Gelauste",
    "Gelausteren": "Gelaustere",
    "Gelaustesten": "Gelausteste",
    "Gelauteten": "Gelautete",
    "Gelbe": "gelb",
    "Gelben": "Gelbe",
    "Gelbs": "Gelb",
    "Gelde": "Geld",
    "Gelder": "Geld",
    "Geldern": "Geld",
    "Geldes": "Geld",
    "Geldgebern": "Geldgeber",
    "Geldgebers": "Geldgeber",
    "Gelds": "Geld",
    "Gele": "Gel",
    "Gelebten": "Gelebte",
    "Gelederten": "Gelederte",
    "Geleerten": "Geleerte",
    "Geleerteren": "Geleertere",
    "Geleertesten": "Geleerteste",
    "Gelees": "Gelee",
    "Gelegen": "liegen",
    "Gelegenen": "Gelegene",
    "Gelegeneren": "Gelegenere",
    "Gelegenheiten": "Gelegenheit",
    "Gelegenste": "gelegen",
    "Gelegensten": "Gelegenste",
    "Gelegentlichen": "Gelegentliche",
    "Geleges": "Gelege",
    "Gelegten": "Gelegte",
    "Gelehnten": "Gelehnte",
    "Gelehrigen": "Gelehrige",
    "Gelehrigeren": "Gelehrigere",
    "Gelehrigsten": "Gelehrigste",
    "Gelehrten": "Gelehrte",
    "Gelehrteren": "Gelehrtere",
    "Gelehrtesten": "Gelehrteste",
    "Geleibten": "Geleibte",
    "Geleiers": "Geleier",
    "Geleierten": "Geleierte",
    "Geleimten": "Geleimte",
    "Geleinten": "Geleinte",
    "Geleisteten": "Geleistete",
    "Geleitenden": "Geleitende",
    "Geleitens": "Geleiten",
    "Geleitete": "geleitet",
    "Geleiteten": "Geleitete",
    "Gelen": "Gel",
    "Gelenke": "Gelenk",
    "Gelenken": "Gelenk",
    "Gelenkes": "Gelenk",
    "Gelenkige": "gelenkig",
    "Gelenkigen": "Gelenkige",
    "Gelenkigeren": "Gelenkigere",
    "Gelenkigsten": "Gelenkigste",
    "Gelenks": "Gelenk",
    "Gelenkten": "Gelenkte",
    "Gelernten": "Gelernte",
    "Geles": "Gel",
    "Gelesenen": "Gelesene",
    "Geleuchteten": "Geleuchtete",
    "Geleugneten": "Geleugnete",
    "Gelichteten": "Gelichtete",
    "Geliebten": "Geliebte",
    "Geliebteren": "Geliebtere",
    "Geliebtesten": "Geliebteste",
    "Geliebäugelten": "Geliebäugelte",
    "Gelieferten": "Gelieferte",
    "Geliehenen": "Geliehene",
    "Gelifteten": "Geliftete",
    "Gelifteteren": "Geliftetere",
    "Geliftetesten": "Gelifteteste",
    "Gelinderten": "Gelinderte",
    "Gelinderteren": "Gelindertere",
    "Gelindertesten": "Gelinderteste",
    "Gelingenden": "Gelingende",
    "Gelingens": "Gelingen",
    "Gelispelten": "Gelispelte",
    "Gelisteten": "Gelistete",
    "Gelittenen": "Gelittene",
    "Gelnhausens": "Gelnhausen",
    "Gelnhäusern": "Gelnhäuser",
    "Gelnhäusers": "Gelnhäuser",
    "Gelobenden": "Gelobende",
    "Gelobens": "Geloben",
    "Gelobte": "gelobt",
    "Gelobten": "Gelobte",
    "Gelobteren": "Gelobtere",
    "Gelobtesten": "Gelobteste",
    "Gelochten": "Gelochte",
    "Gelockerten": "Gelockerte",
    "Gelockten": "Gelockte",
    "Geloderten": "Geloderte",
    "Gelogenen": "Gelogene",
    "Gelogeneren": "Gelogenere",
    "Gelogensten": "Gelogenste",
    "Geloggten": "Geloggte",
    "Gelohnten": "Gelohnte",
    "Geloschenen": "Geloschene",
    "Gelosten": "Geloste",
    "Geloteten": "Gelotete",
    "Gelotsten": "Gelotste",
    "Gelotterten": "Gelotterte",
    "Gelotterteren": "Gelottertere",
    "Gelottertesten": "Gelotterteste",
    "Gels": "Gel",
    "Geltenden": "Geltende",
    "Geltenderen": "Geltendere",
    "Geltendsten": "Geltendste",
    "Geltens": "Gelten",
    "Gelugten": "Gelugte",
    "Gelullten": "Gelullte",
    "Gelumpes": "Gelumpe",
    "Gelungenen": "Gelungene",
    "Gelungeneren": "Gelungenere",
    "Gelungensten": "Gelungenste",
    "Gelungerten": "Gelungerte",
    "Gelupften": "Gelupfte",
    "Gelutschten": "Gelutschte",
    "Gelächelten": "Gelächelte",
    "Gelächtern": "Gelächter",
    "Gelächters": "Gelächter",
    "Gelähmte": "gelähmt",
    "Gelähmten": "Gelähmte",
    "Geländegängigen": "Geländegängige",
    "Geländegängigeren": "Geländegängigere",
    "Geländegängigsten": "Geländegängigste",
    "Geländen": "Gelände",
    "Geländern": "Geländer",
    "Geländers": "Geländer",
    "Geländes": "Gelände",
    "Geläpperten": "Geläpperte",
    "Gelärmten": "Gelärmte",
    "Gelästerten": "Gelästerte",
    "Gelästerteren": "Gelästertere",
    "Gelästertesten": "Gelästerteste",
    "Geläufige": "geläufig",
    "Geläufigen": "Geläufige",
    "Geläufigeren": "Geläufigere",
    "Geläufigsten": "Geläufigste",
    "Geläute": "Geläut",
    "Geläuten": "Geläut",
    "Geläutes": "Geläute",
    "Geläutete": "geläutet",
    "Geläuteten": "Geläutete",
    "Geläuts": "Geläut",
    "Gelöcherten": "Gelöcherte",
    "Gelöffelten": "Gelöffelte",
    "Gelöhnte": "gelöhnt",
    "Gelöhnten": "Gelöhnte",
    "Gelöschten": "Gelöschte",
    "Gelöste": "gelöst",
    "Gelösten": "Gelöste",
    "Gelösteren": "Gelöstere",
    "Gelöstesten": "Gelösteste",
    "Gelötete": "gelötet",
    "Gelöteten": "Gelötete",
    "Gelübden": "Gelübde",
    "Gelübdes": "Gelübde",
    "Gelüfteten": "Gelüftete",
    "Gelüfteteren": "Gelüftetere",
    "Gelüftetesten": "Gelüfteteste",
    "Gelümmelten": "Gelümmelte",
    "Gelüstenden": "Gelüstende",
    "Gelüstenderen": "Gelüstendere",
    "Gelüstendsten": "Gelüstendste",
    "Gelüstens": "Gelüsten",
    "Gelüstete": "gelüstet",
    "Gelüsteten": "Gelüstete",
    "Gelüsteteren": "Gelüstetere",
    "Gelüstetesten": "Gelüsteteste",
    "Gemachten": "Gemachte",
    "Gemagerten": "Gemagerte",
    "Gemahle": "Gemahl",
    "Gemahlen": "mahlen",
    "Gemahlenen": "Gemahlene",
    "Gemahleneren": "Gemahlenere",
    "Gemahlensten": "Gemahlenste",
    "Gemahlinnen": "Gemahlin",
    "Gemahls": "Gemahl",
    "Gemahnten": "Gemahnte",
    "Gemalten": "Gemalte",
    "Gemampften": "Gemampfte",
    "Gemanagten": "Gemanagte",
    "Gemangelten": "Gemangelte",
    "Gemarterten": "Gemarterte",
    "Gemarterteren": "Gemartertere",
    "Gemartertesten": "Gemarterteste",
    "Gemaserten": "Gemaserte",
    "Gemauerten": "Gemauerte",
    "Gemaulten": "Gemaulte",
    "Gemauschels": "Gemauschel",
    "Gemauschelten": "Gemauschelte",
    "Gemauschelteren": "Gemauscheltere",
    "Gemauscheltesten": "Gemauschelteste",
    "Gemauserten": "Gemauserte",
    "Gemauserteren": "Gemausertere",
    "Gemausertesten": "Gemauserteste",
    "Gemaßten": "Gemaßte",
    "Gemeckerten": "Gemeckerte",
    "Gemehrten": "Gemehrte",
    "Gemeinden": "Gemeinde",
    "Gemeindenden": "Gemeindende",
    "Gemeindens": "Gemeinden",
    "Gemeindete": "gemeindet",
    "Gemeindeten": "Gemeindete",
    "Gemeinen": "Gemeine",
    "Gemeineren": "Gemeinere",
    "Gemeingefährlichen": "Gemeingefährliche",
    "Gemeingefährlicheren": "Gemeingefährlichere",
    "Gemeinnützigen": "Gemeinnützige",
    "Gemeinsamen": "Gemeinsame",
    "Gemeinsameren": "Gemeinsamere",
    "Gemeinsamkeiten": "Gemeinsamkeit",
    "Gemeinsamste": "gemeinsam",
    "Gemeinsamsten": "Gemeinsamste",
    "Gemeinschaften": "Gemeinschaft",
    "Gemeinschaftliche": "gemeinschaftlich",
    "Gemeinschaftlichen": "Gemeinschaftliche",
    "Gemeinsinns": "Gemeinsinn",
    "Gemeinste": "gemein",
    "Gemeinsten": "Gemeinste",
    "Gemeinten": "Gemeinte",
    "Gemeinwesens": "Gemeinwesen",
    "Gemeisterten": "Gemeisterte",
    "Gemeisterteren": "Gemeistertere",
    "Gemeistertesten": "Gemeisterteste",
    "Gemeißelten": "Gemeißelte",
    "Gemeldeten": "Gemeldete",
    "Gemelkten": "Gemelkte",
    "Gemengten": "Gemengte",
    "Gemerkten": "Gemerkte",
    "Gemerzten": "Gemerzte",
    "Gemessenen": "Gemessene",
    "Gemetzelten": "Gemetzelte",
    "Gemetzelteren": "Gemetzeltere",
    "Gemetzeltesten": "Gemetzelteste",
    "Gemeuterten": "Gemeuterte",
    "Gemiedenen": "Gemiedene",
    "Gemiedeneren": "Gemiedenere",
    "Gemiedensten": "Gemiedenste",
    "Gemieften": "Gemiefte",
    "Gemieteten": "Gemietete",
    "Gemilderten": "Gemilderte",
    "Gemilderteren": "Gemildertere",
    "Gemildertesten": "Gemilderteste",
    "Gemimten": "Gemimte",
    "Geminderten": "Geminderte",
    "Geminderteren": "Gemindertere",
    "Gemindertesten": "Geminderteste",
    "Gemische": "Gemisch",
    "Gemischen": "Gemisch",
    "Gemisches": "Gemisch",
    "Gemischs": "Gemisch",
    "Gemischten": "Gemischte",
    "Gemischteren": "Gemischtere",
    "Gemischtesten": "Gemischteste",
    "Gemisteten": "Gemistete",
    "Gemittelten": "Gemittelte",
    "Gemixten": "Gemixte",
    "Gemißten": "Gemißte",
    "Gemodelten": "Gemodelte",
    "Gemogelten": "Gemogelte",
    "Gemolkenen": "Gemolkene",
    "Gemopsten": "Gemopste",
    "Gemordeten": "Gemordete",
    "Gemorsten": "Gemorste",
    "Gemoserten": "Gemoserte",
    "Gemotteten": "Gemottete",
    "Gemotzten": "Gemotzte",
    "Gemsen": "Gemse",
    "Gemucksten": "Gemuckste",
    "Gemuffelten": "Gemuffelte",
    "Gemufften": "Gemuffte",
    "Gemundeten": "Gemundete",
    "Gemunkels": "Gemunkel",
    "Gemunkelten": "Gemunkelte",
    "Gemunterten": "Gemunterte",
    "Gemurksten": "Gemurkste",
    "Gemurmelten": "Gemurmelte",
    "Gemurrten": "Gemurrte",
    "Gemusterten": "Gemusterte",
    "Gemusterteren": "Gemustertere",
    "Gemustertesten": "Gemusterteste",
    "Gemuteten": "Gemutete",
    "Gemutmaßten": "Gemutmaßte",
    "Gemächlichen": "Gemächliche",
    "Gemächlicheren": "Gemächlichere",
    "Gemächlichsten": "Gemächlichste",
    "Gemähdreschten": "Gemähdreschte",
    "Gemähten": "Gemähte",
    "Gemäkelten": "Gemäkelte",
    "Gemäkelteren": "Gemäkeltere",
    "Gemäkeltesten": "Gemäkelteste",
    "Gemälden": "Gemälde",
    "Gemäldes": "Gemälde",
    "Gemästeten": "Gemästete",
    "Gemästeteren": "Gemästetere",
    "Gemästetesten": "Gemästeteste",
    "Gemäuern": "Gemäuer",
    "Gemäuers": "Gemäuer",
    "Gemäßigten": "Gemäßigte",
    "Gemäßigteren": "Gemäßigtere",
    "Gemäßigtesten": "Gemäßigteste",
    "Gemöbelten": "Gemöbelte",
    "Gemörtelten": "Gemörtelte",
    "Gemühten": "Gemühte",
    "Gemümmelten": "Gemümmelte",
    "Gemümmelteren": "Gemümmeltere",
    "Gemümmeltesten": "Gemümmelteste",
    "Gemündete": "gemündet",
    "Gemündeten": "Gemündete",
    "Gemünzten": "Gemünzte",
    "Gemüses": "Gemüse",
    "Gemüte": "Gemüt",
    "Gemüter": "Gemüt",
    "Gemütern": "Gemüt",
    "Gemütes": "Gemüt",
    "Gemütlichen": "Gemütliche",
    "Gemütlicheren": "Gemütlichere",
    "Gemütlichsten": "Gemütlichste",
    "Gemüts": "Gemüt",
    "Gemütserfreuliche": "gemütserfreulich",
    "Gemütserfreulichen": "Gemütserfreuliche",
    "Gemütserfreulicheren": "Gemütserfreulichere",
    "Genabelten": "Genabelte",
    "Genagelten": "Genagelte",
    "Genagten": "Genagte",
    "Genagteren": "Genagtere",
    "Genagtesten": "Genagteste",
    "Genannten": "Genannte",
    "Genannteren": "Genanntere",
    "Genanntesten": "Genannteste",
    "Genarrten": "Genarrte",
    "Genarrteren": "Genarrtere",
    "Genarrtesten": "Genarrteste",
    "Genaschten": "Genaschte",
    "Genauen": "Genaue",
    "Genaueren": "Genauere",
    "Genauesten": "Genaueste",
    "Genauigkeiten": "Genauigkeit",
    "Gene": "Gen",
    "Genebelten": "Genebelte",
    "Genehmigenden": "Genehmigende",
    "Genehmigens": "Genehmigen",
    "Genehmigte": "genehmigt",
    "Genehmigten": "Genehmigte",
    "Genehmigungen": "Genehmigung",
    "Geneideten": "Geneidete",
    "Geneigten": "Geneigte",
    "Geneigteren": "Geneigtere",
    "Geneigtesten": "Geneigteste",
    "Genen": "Gen",
    "Geneppten": "Geneppte",
    "Generale": "General",
    "Generales": "General",
    "Generalisierenden": "Generalisierende",
    "Generalisierenderen": "Generalisierendere",
    "Generalisierens": "Generalisieren",
    "Generalisierte": "generalisiert",
    "Generalisierten": "Generalisierte",
    "Generalisierteren": "Generalisiertere",
    "Generalisierteste": "generalisiert",
    "Generals": "General",
    "Generalsekretäre": "Generalsekretär",
    "Generalsekretären": "Generalsekretär",
    "Generalsekretärs": "Generalsekretär",
    "Generalstabskarten": "Generalstabskarte",
    "Generalvertretern": "Generalvertreter",
    "Generalvertreters": "Generalvertreter",
    "Generationen": "Generation",
    "Generatore": "Generator",
    "Generatoren": "Generator",
    "Generators": "Generator",
    "Generelle": "generell",
    "Generellen": "Generelle",
    "Generelleren": "Generellere",
    "Generellsten": "Generellste",
    "Generierenden": "Generierende",
    "Generierens": "Generieren",
    "Generierte": "generiert",
    "Generierten": "Generierte",
    "Generierungen": "Generierung",
    "Generische": "generisch",
    "Generischen": "Generische",
    "Genervten": "Genervte",
    "Genervteren": "Genervtere",
    "Genervtesten": "Genervteste",
    "Generäle": "General",
    "Generälen": "General",
    "Generösen": "Generöse",
    "Generöseren": "Generösere",
    "Generösesten": "Generöseste",
    "Genes": "genesen",
    "Genesenden": "Genesende",
    "Genesenderen": "Genesendere",
    "Genesendsten": "Genesendste",
    "Genesenen": "Genesene",
    "Geneseneren": "Genesenere",
    "Genesens": "Genesen",
    "Genesenste": "genesen",
    "Genesensten": "Genesenste",
    "Genestelten": "Genestelte",
    "Genestelteren": "Genesteltere",
    "Genesteltesten": "Genestelteste",
    "Genetischen": "Genetische",
    "Genfern": "Genfer",
    "Genfers": "Genfer",
    "Genfs": "Genf",
    "Geniale": "genial",
    "Genialen": "Geniale",
    "Genialeren": "Genialere",
    "Genialsten": "Genialste",
    "Genicke": "Genick",
    "Genicken": "Genick",
    "Genickes": "Genick",
    "Genicks": "Genick",
    "Genickten": "Genickte",
    "Genierenden": "Genierende",
    "Genierenderen": "Genierendere",
    "Genierendsten": "Genierendste",
    "Genierens": "Genieren",
    "Genierte": "geniert",
    "Genierten": "Genierte",
    "Genies": "Genie",
    "Genieselten": "Genieselte",
    "Geniesten": "Genieste",
    "Genieteten": "Genietete",
    "Genießbaren": "Genießbare",
    "Genießenden": "Genießende",
    "Genießenderen": "Genießendere",
    "Genießendsten": "Genießendste",
    "Genießens": "Genießen",
    "Genießerische": "genießerisch",
    "Genießerischen": "Genießerische",
    "Genießerischeren": "Genießerischere",
    "Genießerischsten": "Genießerischste",
    "Genießern": "Genießer",
    "Genießers": "Genießer",
    "Genippten": "Genippte",
    "Genisteten": "Genistete",
    "Genitalapparate": "Genitalapparat",
    "Genitalapparaten": "Genitalapparat",
    "Genitalapparates": "Genitalapparat",
    "Genitalapparats": "Genitalapparat",
    "Genitale": "genital",
    "Genitalen": "Genitale",
    "Genitalischen": "Genitalische",
    "Genitive": "Genitiv",
    "Genitiven": "Genitiv",
    "Genitives": "Genitiv",
    "Genitivs": "Genitiv",
    "Genommenen": "Genommene",
    "Genommeneren": "Genommenere",
    "Genommensten": "Genommenste",
    "Genordeten": "Genordete",
    "Genormten": "Genormte",
    "Genormteren": "Genormtere",
    "Genormtesten": "Genormteste",
    "Genossen": "Genosse",
    "Genossenen": "Genossene",
    "Genosseneren": "Genossenere",
    "Genossenschaften": "Genossenschaft",
    "Genossenschaftliche": "genossenschaftlich",
    "Genossenschaftlichen": "Genossenschaftliche",
    "Genossensten": "Genossenste",
    "Genossinnen": "Genossin",
    "Genres": "Genre",
    "Gens": "Gen",
    "Genschers": "Genscher",
    "Genudelten": "Genudelte",
    "Genugtuungen": "Genugtuung",
    "Genullten": "Genullte",
    "Genuschelten": "Genuschelte",
    "Genusse": "Genuß",
    "Genusses": "Genuß",
    "Genutzten": "Genutzte",
    "Genutzteren": "Genutztere",
    "Genutztesten": "Genutzteste",
    "Genußreichen": "Genußreiche",
    "Genußreicheren": "Genußreichere",
    "Genußreichsten": "Genußreichste",
    "Genächtigten": "Genächtigte",
    "Genäherten": "Genäherte",
    "Genährten": "Genährte",
    "Genährteren": "Genährtere",
    "Genährtesten": "Genährteste",
    "Genähten": "Genähte",
    "Genäselten": "Genäselte",
    "Genässelten": "Genässelte",
    "Genäßten": "Genäßte",
    "Genölten": "Genölte",
    "Genörgelten": "Genörgelte",
    "Genötigten": "Genötigte",
    "Genügenden": "Genügende",
    "Genügenderen": "Genügendere",
    "Genügendsten": "Genügendste",
    "Genügens": "Genügen",
    "Genügsamen": "Genügsame",
    "Genügsameren": "Genügsamere",
    "Genügsamsten": "Genügsamste",
    "Genügte": "genügt",
    "Genügten": "Genügte",
    "Genüsse": "Genuß",
    "Genüssen": "Genuß",
    "Genützte": "genützt",
    "Genützten": "Genützte",
    "Genüßliche": "genüßlich",
    "Genüßlichen": "Genüßliche",
    "Genüßlicheren": "Genüßlichere",
    "Genüßlichsten": "Genüßlichste",
    "Geodreiecke": "Geodreieck",
    "Geodreiecken": "Geodreieck",
    "Geodreiecks": "Geodreieck",
    "Geodätischen": "Geodätische",
    "Geographischen": "Geographische",
    "Geohrfeigten": "Geohrfeigte",
    "Geologen": "Geologe",
    "Geologische": "geologisch",
    "Geologischen": "Geologische",
    "Geometern": "Geometer",
    "Geometers": "Geometer",
    "Geopferten": "Geopferte",
    "Geophysikalischen": "Geophysikalische",
    "Geophysikern": "Geophysiker",
    "Geophysikers": "Geophysiker",
    "Georderten": "Georderte",
    "Georderteren": "Geordertere",
    "Geordertesten": "Georderteste",
    "Geordneten": "Geordnete",
    "Geordneteren": "Geordnetere",
    "Geordnetesten": "Geordneteste",
    "Georgelten": "Georgelte",
    "Georges": "George",
    "Georgiens": "Georgien",
    "Georgiern": "Georgier",
    "Georgiers": "Georgier",
    "Georgische": "georgisch",
    "Georgischen": "Georgische",
    "Georgs": "Georg",
    "Georteten": "Geortete",
    "Gepaarten": "Gepaarte",
    "Gepachteten": "Gepachtete",
    "Gepackten": "Gepackte",
    "Gepaddelten": "Gepaddelte",
    "Gepafften": "Gepaffte",
    "Gepanschten": "Gepanschte",
    "Gepanschteren": "Gepanschtere",
    "Gepanschtesten": "Gepanschteste",
    "Gepantschten": "Gepantschte",
    "Gepanzerten": "Gepanzerte",
    "Gepanzerteren": "Gepanzertere",
    "Gepanzertesten": "Gepanzerteste",
    "Gepappten": "Gepappte",
    "Geparde": "Gepard",
    "Geparden": "Gepard",
    "Gepards": "Gepard",
    "Geparkten": "Geparkte",
    "Geparsten": "Geparste",
    "Gepatschten": "Gepatschte",
    "Gepatzten": "Gepatzte",
    "Gepaukten": "Gepaukte",
    "Gepausten": "Gepauste",
    "Gepaßten": "Gepaßte",
    "Gepeilten": "Gepeilte",
    "Gepeinigten": "Gepeinigte",
    "Gepeinigteren": "Gepeinigtere",
    "Gepeinigtesten": "Gepeinigteste",
    "Gepeitschten": "Gepeitschte",
    "Gepellten": "Gepellte",
    "Gepellteren": "Gepelltere",
    "Gepelltesten": "Gepellteste",
    "Gependelten": "Gependelte",
    "Gepennten": "Gepennte",
    "Geperlten": "Geperlte",
    "Gepesten": "Gepeste",
    "Gepetzten": "Gepetzte",
    "Gepfefferten": "Gepfefferte",
    "Gepfefferteren": "Gepfeffertere",
    "Gepfeffertesten": "Gepfefferteste",
    "Gepferchten": "Gepferchte",
    "Gepferchteren": "Gepferchtere",
    "Gepferchtesten": "Gepferchteste",
    "Gepfiffenen": "Gepfiffene",
    "Gepflanzten": "Gepflanzte",
    "Gepflaumten": "Gepflaumte",
    "Gepflegten": "Gepflegte",
    "Gepflegteren": "Gepflegtere",
    "Gepflegtesten": "Gepflegteste",
    "Gepflichteten": "Gepflichtete",
    "Gepflogenheiten": "Gepflogenheit",
    "Gepflückten": "Gepflückte",
    "Gepflügten": "Gepflügte",
    "Gepfropften": "Gepfropfte",
    "Gepfuschten": "Gepfuschte",
    "Gepfuschteren": "Gepfuschtere",
    "Gepfuschtesten": "Gepfuschteste",
    "Gepfändeten": "Gepfändete",
    "Gepichelten": "Gepichelte",
    "Gepickten": "Gepickte",
    "Gepiepsten": "Gepiepste",
    "Gepiepten": "Gepiepte",
    "Gepieselten": "Gepieselte",
    "Gepilgerten": "Gepilgerte",
    "Gepinkelten": "Gepinkelte",
    "Gepinnten": "Gepinnte",
    "Gepinselten": "Gepinselte",
    "Gepirschten": "Gepirschte",
    "Gepißten": "Gepißte",
    "Geplagten": "Geplagte",
    "Geplagteren": "Geplagtere",
    "Geplagtesten": "Geplagteste",
    "Geplanschten": "Geplanschte",
    "Geplanten": "Geplante",
    "Geplanteren": "Geplantere",
    "Geplantesten": "Geplanteste",
    "Geplapperten": "Geplapperte",
    "Geplatschten": "Geplatschte",
    "Geplatzten": "Geplatzte",
    "Geplauderten": "Geplauderte",
    "Geplauschten": "Geplauschte",
    "Geplemperten": "Geplemperte",
    "Geplotteten": "Geplottete",
    "Geplumpsten": "Geplumpste",
    "Geplusterten": "Geplusterte",
    "Geplärrs": "Geplärr",
    "Geplätscherten": "Geplätscherte",
    "Geplätteten": "Geplättete",
    "Geplätteteren": "Geplättetere",
    "Geplättetesten": "Geplätteteste",
    "Geplünderten": "Geplünderte",
    "Geplünderteren": "Geplündertere",
    "Geplündertesten": "Geplünderteste",
    "Gepochten": "Gepochte",
    "Gepokerten": "Gepokerte",
    "Gepolsterten": "Gepolsterte",
    "Gepolsterteren": "Gepolstertere",
    "Gepolstertesten": "Gepolsterteste",
    "Gepolten": "Gepolte",
    "Gepolterten": "Gepolterte",
    "Gepopelten": "Gepopelte",
    "Gepoppten": "Gepoppte",
    "Gepowerten": "Gepowerte",
    "Gepowerteren": "Gepowertere",
    "Gepowertesten": "Gepowerteste",
    "Geprahlten": "Geprahlte",
    "Geprallten": "Geprallte",
    "Geprangerten": "Geprangerte",
    "Geprangerteren": "Geprangertere",
    "Geprangertesten": "Geprangerteste",
    "Geprangten": "Geprangte",
    "Geprasselten": "Geprasselte",
    "Gepredigten": "Gepredigte",
    "Geprellten": "Geprellte",
    "Geprellteren": "Geprelltere",
    "Geprelltesten": "Geprellteste",
    "Gepreschten": "Gepreschte",
    "Gepreßten": "Gepreßte",
    "Gepriesenen": "Gepriesene",
    "Geprieseneren": "Gepriesenere",
    "Gepriesensten": "Gepriesenste",
    "Gepritschten": "Gepritschte",
    "Geprobten": "Geprobte",
    "Geprobteren": "Geprobtere",
    "Geprobtesten": "Geprobteste",
    "Geprosteten": "Geprostete",
    "Geprotzten": "Geprotzte",
    "Geprotzteren": "Geprotztere",
    "Geprotztesten": "Geprotzteste",
    "Geprusteten": "Geprustete",
    "Geprägten": "Geprägte",
    "Geprägteren": "Geprägtere",
    "Geprägtesten": "Geprägteste",
    "Geprüften": "Geprüfte",
    "Geprüfteren": "Geprüftere",
    "Geprüftesten": "Geprüfteste",
    "Geprügelten": "Geprügelte",
    "Gepuderten": "Gepuderte",
    "Gepuderteren": "Gepudertere",
    "Gepudertesten": "Gepuderteste",
    "Gepufften": "Gepuffte",
    "Gepulten": "Gepulte",
    "Gepulverten": "Gepulverte",
    "Gepumpten": "Gepumpte",
    "Gepunkteten": "Gepunktete",
    "Gepupten": "Gepupte",
    "Gepurzelten": "Gepurzelte",
    "Gepuschten": "Gepuschte",
    "Gepuschteren": "Gepuschtere",
    "Gepuschtesten": "Gepuschteste",
    "Gepusteten": "Gepustete",
    "Geputschten": "Geputschte",
    "Geputteten": "Geputtete",
    "Geputzten": "Geputzte",
    "Geputzteren": "Geputztere",
    "Geputztesten": "Geputzteste",
    "Gepäcke": "Gepäck",
    "Gepäcken": "Gepäck",
    "Gepäcks": "Gepäck",
    "Gepäppelten": "Gepäppelte",
    "Gepöbelten": "Gepöbelte",
    "Gepökelten": "Gepökelte",
    "Gequakten": "Gequakte",
    "Gequalmten": "Gequalmte",
    "Gequarzten": "Gequarzte",
    "Gequasselten": "Gequasselte",
    "Gequatschten": "Gequatschte",
    "Gequellten": "Gequellte",
    "Gequengelten": "Gequengelte",
    "Gequetschten": "Gequetschte",
    "Gequetschteren": "Gequetschtere",
    "Gequetschtesten": "Gequetschteste",
    "Gequieckten": "Gequieckte",
    "Gequietschten": "Gequietschte",
    "Gequirlten": "Gequirlte",
    "Gequollenen": "Gequollene",
    "Gequolleneren": "Gequollenere",
    "Gequollensten": "Gequollenste",
    "Gequälten": "Gequälte",
    "Gequälteren": "Gequältere",
    "Gequältesten": "Gequälteste",
    "Geradebiegenden": "Geradebiegende",
    "Geradebiegens": "Geradebiegen",
    "Geradegebogenen": "Geradegebogene",
    "Geradegebogeneren": "Geradegebogenere",
    "Geradegebogensten": "Geradegebogenste",
    "Geradegerichteten": "Geradegerichtete",
    "Geradegesessenen": "Geradegesessene",
    "Geradegesetzten": "Geradegesetzte",
    "Geradelten": "Geradelte",
    "Geraderen": "Geradere",
    "Geraderichtenden": "Geraderichtende",
    "Geraderichtens": "Geraderichten",
    "Geradesetzenden": "Geradesetzende",
    "Geradesetzens": "Geradesetzen",
    "Geradesitzenden": "Geradesitzende",
    "Geradesitzens": "Geradesitzen",
    "Geradesten": "Geradeste",
    "Gerafften": "Geraffte",
    "Geraffteren": "Gerafftere",
    "Gerafftesten": "Geraffteste",
    "Geragten": "Geragte",
    "Gerahmten": "Gerahmte",
    "Gerammelten": "Gerammelte",
    "Gerammten": "Gerammte",
    "Geramschten": "Geramschte",
    "Gerangels": "Gerangel",
    "Geranien": "Geranie",
    "Gerankten": "Gerankte",
    "Gerannten": "Gerannte",
    "Geranzten": "Geranzte",
    "Gerappelten": "Gerappelte",
    "Geraschelten": "Geraschelte",
    "Geraspelten": "Geraspelte",
    "Gerassels": "Gerassel",
    "Gerasselten": "Gerasselte",
    "Gerasten": "Geraste",
    "Gerasterten": "Gerasterte",
    "Gerasteten": "Gerastete",
    "Gerasteteren": "Gerastetere",
    "Gerastetesten": "Gerasteteste",
    "Geraten": "raten",
    "Geratenden": "Geratende",
    "Geratenen": "Geratene",
    "Geratens": "Geraten",
    "Geratters": "Geratter",
    "Geratterten": "Geratterte",
    "Geratzten": "Geratzte",
    "Geraubten": "Geraubte",
    "Gerauchten": "Gerauchte",
    "Gerauften": "Geraufte",
    "Gerauhten": "Gerauhte",
    "Geraumen": "Geraume",
    "Geraunten": "Geraunte",
    "Geraus": "Gerau",
    "Gerauschten": "Gerauschte",
    "Gerauten": "Geraute",
    "Gerbenden": "Gerbende",
    "Gerbenderen": "Gerbendere",
    "Gerbendsten": "Gerbendste",
    "Gerbens": "Gerben",
    "Gerds": "Gerd",
    "Gerechneten": "Gerechnete",
    "Gerechten": "Gerechte",
    "Gerechteren": "Gerechtere",
    "Gerechtesten": "Gerechteste",
    "Gerechtfertigten": "Gerechtfertigte",
    "Gerechtfertigteren": "Gerechtfertigtere",
    "Gerechtigkeiten": "Gerechtigkeit",
    "Gerechtsamen": "Gerechtsame",
    "Geredes": "Gerede",
    "Geredeten": "Geredete",
    "Geregelten": "Geregelte",
    "Geregelteren": "Geregeltere",
    "Geregeltesten": "Geregelteste",
    "Geregneten": "Geregnete",
    "Geregten": "Geregte",
    "Gereichenden": "Gereichende",
    "Gereichens": "Gereichen",
    "Gereicherten": "Gereicherte",
    "Gereichte": "gereicht",
    "Gereichten": "Gereichte",
    "Gereiften": "Gereifte",
    "Gereifteren": "Gereiftere",
    "Gereiftesten": "Gereifteste",
    "Gereiherten": "Gereiherte",
    "Gereihten": "Gereihte",
    "Gereimten": "Gereimte",
    "Gereimteren": "Gereimtere",
    "Gereimtesten": "Gereimteste",
    "Gereinigten": "Gereinigte",
    "Gereinigteren": "Gereinigtere",
    "Gereinigtesten": "Gereinigteste",
    "Gereisten": "Gereiste",
    "Gereizten": "Gereizte",
    "Gerempelten": "Gerempelte",
    "Gerenkten": "Gerenkte",
    "Gerennes": "Gerenne",
    "Geres": "Gere",
    "Geretteten": "Gerettete",
    "Gerhards": "Gerhard",
    "Gerhardts": "Gerhardt",
    "Gerholds": "Gerhold",
    "Geribbelten": "Geribbelte",
    "Gerichte": "Gericht",
    "Gerichten": "Gericht",
    "Gerichteten": "Gerichtete",
    "Gerichteteren": "Gerichtetere",
    "Gerichtetesten": "Gerichteteste",
    "Gerichtlichen": "Gerichtliche",
    "Gerichts": "Gericht",
    "Gerichtsvollziehern": "Gerichtsvollzieher",
    "Gerichtsvollziehers": "Gerichtsvollzieher",
    "Geriebenen": "Geriebene",
    "Geriebeneren": "Geriebenere",
    "Geriebensten": "Geriebenste",
    "Geriegelten": "Geriegelte",
    "Gerieselten": "Gerieselte",
    "Geriffelten": "Geriffelte",
    "Geriffelteren": "Geriffeltere",
    "Geriffeltesten": "Geriffelteste",
    "Gerillten": "Gerillte",
    "Gerillteren": "Gerilltere",
    "Gerilltesten": "Gerillteste",
    "Gerindeten": "Gerindete",
    "Geringachtenden": "Geringachtende",
    "Geringachtenderen": "Geringachtendere",
    "Geringachtendsten": "Geringachtendste",
    "Geringachtens": "Geringachten",
    "Geringelten": "Geringelte",
    "Geringelteren": "Geringeltere",
    "Geringeltesten": "Geringelteste",
    "Geringen": "Geringe",
    "Geringeren": "Geringere",
    "Geringfügigen": "Geringfügige",
    "Geringgeachteten": "Geringgeachtete",
    "Geringgeachteteren": "Geringgeachtetere",
    "Geringgeschätzten": "Geringgeschätzte",
    "Geringgeschätzteren": "Geringgeschätztere",
    "Geringschätzenden": "Geringschätzende",
    "Geringschätzenderen": "Geringschätzendere",
    "Geringschätzens": "Geringschätzen",
    "Geringschätzigen": "Geringschätzige",
    "Geringschätzigeren": "Geringschätzigere",
    "Geringsten": "Geringste",
    "Geringwertigen": "Geringwertige",
    "Geringwertigeren": "Geringwertigere",
    "Geringwertigsten": "Geringwertigste",
    "Gerinnenden": "Gerinnende",
    "Gerinnens": "Gerinnen",
    "Gerinnungsfähigen": "Gerinnungsfähige",
    "Gerinnungsfähigeren": "Gerinnungsfähigere",
    "Gerippten": "Gerippte",
    "Gerippteren": "Geripptere",
    "Geripptesten": "Gerippteste",
    "Gerissenen": "Gerissene",
    "Gerisseneren": "Gerissenere",
    "Gerissensten": "Gerissenste",
    "Gerittenen": "Gerittene",
    "Geritzten": "Geritzte",
    "Gerlachs": "Gerlach",
    "Gerlingens": "Gerlingen",
    "Germanias": "Germania",
    "Germanische": "germanisch",
    "Germanischen": "Germanische",
    "Germanisierenden": "Germanisierende",
    "Germanisierenderen": "Germanisierendere",
    "Germanisierens": "Germanisieren",
    "Germanisierte": "germanisiert",
    "Germanisierten": "Germanisierte",
    "Germanisierteren": "Germanisiertere",
    "Germanisiertesten": "Germanisierteste",
    "Germanistischen": "Germanistische",
    "Germaniums": "Germanium",
    "Gernhardts": "Gernhardt",
    "Gerobbten": "Gerobbte",
    "Gerochenen": "Gerochene",
    "Gerodelten": "Gerodelte",
    "Gerodeten": "Gerodete",
    "Gerodeteren": "Gerodetere",
    "Gerodetesten": "Gerodeteste",
    "Gerollten": "Gerollte",
    "Gerollteren": "Gerolltere",
    "Gerolltesten": "Gerollteste",
    "Geronnenen": "Geronnene",
    "Geronneneren": "Geronnenere",
    "Geronnensten": "Geronnenste",
    "Gerosteten": "Gerostete",
    "Gerosteteren": "Gerostetere",
    "Gerostetesten": "Gerosteteste",
    "Gerotteten": "Gerottete",
    "Gerotzten": "Gerotzte",
    "Gerstengraupen": "Gerstengraupe",
    "Gerstenkorne": "Gerstenkorn",
    "Gerstenkornes": "Gerstenkorn",
    "Gerstenkorns": "Gerstenkorn",
    "Gerstenkörner": "Gerstenkorn",
    "Gerstenkörnern": "Gerstenkorn",
    "Gertenschlanke": "gertenschlank",
    "Gertenschlanken": "Gertenschlanke",
    "Gertenschlankeren": "Gertenschlankere",
    "Gertruds": "Gertrud",
    "Gerts": "Gert",
    "Gerubbelten": "Gerubbelte",
    "Geruche": "Geruch",
    "Geruches": "Geruch",
    "Geruchlose": "geruchlos",
    "Geruchlosen": "Geruchlose",
    "Geruchloseren": "Geruchlosere",
    "Geruchlosesten": "Geruchloseste",
    "Geruchs": "Geruch",
    "Geruckelten": "Geruckelte",
    "Geruderten": "Geruderte",
    "Gerufenen": "Gerufene",
    "Geruhsamen": "Geruhsame",
    "Geruhsameren": "Geruhsamere",
    "Geruhsamsten": "Geruhsamste",
    "Geruhten": "Geruhte",
    "Gerumpels": "Gerumpel",
    "Gerundeten": "Gerundete",
    "Gerungenen": "Gerungene",
    "Gerunzelten": "Gerunzelte",
    "Gerupften": "Gerupfte",
    "Gerupfteren": "Gerupftere",
    "Gerupftesten": "Gerupfteste",
    "Gerutschten": "Gerutschte",
    "Gerächten": "Gerächte",
    "Geräderten": "Geräderte",
    "Geräderteren": "Gerädertere",
    "Gerädertesten": "Geräderteste",
    "Geräkelten": "Geräkelte",
    "Geräte": "Gerät",
    "Geräten": "Gerät",
    "Geräts": "Gerät",
    "Gerätschaften": "Gerätschaft",
    "Gerätselten": "Gerätselte",
    "Geräucherten": "Geräucherte",
    "Geräumigen": "Geräumige",
    "Geräumigeren": "Geräumigere",
    "Geräumigsten": "Geräumigste",
    "Geräumten": "Geräumte",
    "Geräusche": "Geräusch",
    "Geräuschen": "Geräusch",
    "Geräusches": "Geräusch",
    "Geräuschkulissen": "Geräuschkulisse",
    "Geräuschlose": "geräuschlos",
    "Geräuschlosen": "Geräuschlose",
    "Geräuschloseren": "Geräuschlosere",
    "Geräuschlosesten": "Geräuschloseste",
    "Geräuschs": "Geräusch",
    "Geräuschvollen": "Geräuschvolle",
    "Geräuschvolleren": "Geräuschvollere",
    "Geräuschvollsten": "Geräuschvollste",
    "Geräusperten": "Geräusperte",
    "Geröchels": "Geröchel",
    "Geröchelten": "Geröchelte",
    "Gerölle": "Geröll",
    "Geröllen": "Geröll",
    "Gerölls": "Geröll",
    "Geröntgten": "Geröntgte",
    "Geröstete": "geröstet",
    "Gerösteten": "Geröstete",
    "Geröstetere": "geröstet",
    "Gerösteteren": "Geröstetere",
    "Gerösteteste": "geröstet",
    "Geröstetesten": "Gerösteteste",
    "Geröteten": "Gerötete",
    "Geröteteren": "Gerötetere",
    "Gerötetesten": "Geröteteste",
    "Gerüche": "Geruch",
    "Gerüchen": "Geruch",
    "Gerüchte": "Gerücht",
    "Gerüchten": "Gerücht",
    "Gerüchts": "Gerücht",
    "Gerückten": "Gerückte",
    "Gerügten": "Gerügte",
    "Gerügteren": "Gerügtere",
    "Gerügtesten": "Gerügteste",
    "Gerühmten": "Gerühmte",
    "Gerühmteren": "Gerühmtere",
    "Gerühmtesten": "Gerühmteste",
    "Gerührten": "Gerührte",
    "Gerülpsten": "Gerülpste",
    "Gerümpels": "Gerümpel",
    "Gerümpften": "Gerümpfte",
    "Gerüste": "Gerüst",
    "Gerüsten": "Gerüst",
    "Gerüstes": "Gerüst",
    "Gerüsteten": "Gerüstete",
    "Gerüsts": "Gerüst",
    "Gerüttels": "Gerüttel",
    "Gerüttelten": "Gerüttelte",
    "Gesabbelten": "Gesabbelte",
    "Gesabberten": "Gesabberte",
    "Gesafteten": "Gesaftete",
    "Gesagten": "Gesagte",
    "Gesahnten": "Gesahnte",
    "Gesalbten": "Gesalbte",
    "Gesalzenen": "Gesalzene",
    "Gesalzeneren": "Gesalzenere",
    "Gesalzensten": "Gesalzenste",
    "Gesammelten": "Gesammelte",
    "Gesamtdeutschen": "Gesamtdeutsche",
    "Gesamten": "Gesamte",
    "Gesamtentwicklungen": "Gesamtentwicklung",
    "Gesamtgesellschaften": "Gesamtgesellschaft",
    "Gesamtgewichte": "Gesamtgewicht",
    "Gesamtgewichten": "Gesamtgewicht",
    "Gesamtgewichts": "Gesamtgewicht",
    "Gesamtgute": "Gesamtgut",
    "Gesamtgutes": "Gesamtgut",
    "Gesamtguts": "Gesamtgut",
    "Gesamtgüter": "Gesamtgut",
    "Gesamtgütern": "Gesamtgut",
    "Gesamthafte": "gesamthaft",
    "Gesamthaften": "Gesamthafte",
    "Gesamthochschulen": "Gesamthochschule",
    "Gesamtinteressen": "Gesamtinteresse",
    "Gesamtinteresses": "Gesamtinteresse",
    "Gesamtkataloge": "Gesamtkatalog",
    "Gesamtkatalogen": "Gesamtkatalog",
    "Gesamtkatalogs": "Gesamtkatalog",
    "Gesamtkonzepte": "Gesamtkonzept",
    "Gesamtkonzepten": "Gesamtkonzept",
    "Gesamtkonzeptes": "Gesamtkonzept",
    "Gesamtkonzepts": "Gesamtkonzept",
    "Gesamtkunstwerke": "Gesamtkunstwerk",
    "Gesamtkunstwerken": "Gesamtkunstwerk",
    "Gesamtkunstwerks": "Gesamtkunstwerk",
    "Gesamtmengen": "Gesamtmenge",
    "Gesamtschnitte": "Gesamtschnitt",
    "Gesamtschnitten": "Gesamtschnitt",
    "Gesamtschnittes": "Gesamtschnitt",
    "Gesamtschnitts": "Gesamtschnitt",
    "Gesamtschuldnern": "Gesamtschuldner",
    "Gesamtschuldners": "Gesamtschuldner",
    "Gesamtschulen": "Gesamtschule",
    "Gesamtstrafen": "Gesamtstrafe",
    "Gesamtsummen": "Gesamtsumme",
    "Gesamturteile": "Gesamturteil",
    "Gesamturteilen": "Gesamturteil",
    "Gesamturteils": "Gesamturteil",
    "Gesamtverbande": "Gesamtverband",
    "Gesamtverbands": "Gesamtverband",
    "Gesamtverbände": "Gesamtverband",
    "Gesamtverbänden": "Gesamtverband",
    "Gesamtvereinbarungen": "Gesamtvereinbarung",
    "Gesamtverhaltens": "Gesamtverhalten",
    "Gesamtwerke": "Gesamtwerk",
    "Gesamtwerken": "Gesamtwerk",
    "Gesamtwerks": "Gesamtwerk",
    "Gesamtwerte": "Gesamtwert",
    "Gesamtwerten": "Gesamtwert",
    "Gesamtwerts": "Gesamtwert",
    "Gesamtwohle": "Gesamtwohl",
    "Gesamtwohlen": "Gesamtwohl",
    "Gesamtwohls": "Gesamtwohl",
    "Gesandten": "Gesandte",
    "Gesandtinnen": "Gesandtin",
    "Gesangbuche": "Gesangbuch",
    "Gesangbuches": "Gesangbuch",
    "Gesangbuchs": "Gesangbuch",
    "Gesangbücher": "Gesangbuch",
    "Gesangbüchern": "Gesangbuch",
    "Gesange": "Gesang",
    "Gesanges": "Gesang",
    "Gesangliche": "gesanglich",
    "Gesanglichen": "Gesangliche",
    "Gesangs": "Gesang",
    "Gesargten": "Gesargte",
    "Gesattelten": "Gesattelte",
    "Gesauerten": "Gesauerte",
    "Gesauerteren": "Gesauertere",
    "Gesauertesten": "Gesauerteste",
    "Gesaugbohnerten": "Gesaugbohnerte",
    "Gesaugten": "Gesaugte",
    "Gesaugteren": "Gesaugtere",
    "Gesaugtesten": "Gesaugteste",
    "Gesaunten": "Gesaunte",
    "Gesausten": "Gesauste",
    "Gesauten": "Gesaute",
    "Geschabten": "Geschabte",
    "Geschacherten": "Geschacherte",
    "Geschachtelten": "Geschachtelte",
    "Geschachtelteren": "Geschachteltere",
    "Geschachteltesten": "Geschachtelteste",
    "Geschachteten": "Geschachtete",
    "Geschadeten": "Geschadete",
    "Geschaffenen": "Geschaffene",
    "Geschafften": "Geschaffte",
    "Geschaffteren": "Geschafftere",
    "Geschafftesten": "Geschaffteste",
    "Geschallten": "Geschallte",
    "Geschalten": "Geschalte",
    "Geschalteten": "Geschaltete",
    "Geschanzten": "Geschanzte",
    "Gescharrten": "Gescharrte",
    "Gescharten": "Gescharte",
    "Geschauderten": "Geschauderte",
    "Geschaufelten": "Geschaufelte",
    "Geschaukelten": "Geschaukelte",
    "Geschauspielerten": "Geschauspielerte",
    "Geschauten": "Geschaute",
    "Gescheffelten": "Gescheffelte",
    "Geschehenden": "Geschehende",
    "Geschehenen": "Geschehene",
    "Geschehens": "Geschehen",
    "Geschehnisse": "Geschehnis",
    "Geschehnissen": "Geschehnis",
    "Geschehnisses": "Geschehnis",
    "Gescheiten": "Gescheite",
    "Gescheiteren": "Gescheitere",
    "Gescheiterten": "Gescheiterte",
    "Gescheiterteren": "Gescheitertere",
    "Gescheitertesten": "Gescheiterteste",
    "Gescheitesten": "Gescheiteste",
    "Geschellten": "Geschellte",
    "Geschenke": "Geschenk",
    "Geschenken": "Geschenk",
    "Geschenkes": "Geschenk",
    "Geschenks": "Geschenk",
    "Geschenkten": "Geschenkte",
    "Geschepperten": "Geschepperte",
    "Gescherten": "Gescherte",
    "Gescherzten": "Gescherzte",
    "Gescheuchten": "Gescheuchte",
    "Gescheuerten": "Gescheuerte",
    "Gescheuten": "Gescheute",
    "Geschichten": "Geschichte",
    "Geschichteten": "Geschichtete",
    "Geschichteteren": "Geschichtetere",
    "Geschichtetesten": "Geschichteteste",
    "Geschichtlichen": "Geschichtliche",
    "Geschichtsklitterungen": "Geschichtsklitterung",
    "Geschichtsträchtige": "geschichtsträchtig",
    "Geschichtsträchtigen": "Geschichtsträchtige",
    "Geschichtsträchtigeren": "Geschichtsträchtigere",
    "Geschichtsvereine": "Geschichtsverein",
    "Geschichtsvereinen": "Geschichtsverein",
    "Geschichtsvereines": "Geschichtsverein",
    "Geschichtsvereins": "Geschichtsverein",
    "Geschichtsverlaufe": "Geschichtsverlauf",
    "Geschichtsverlaufs": "Geschichtsverlauf",
    "Geschichtsverläufe": "Geschichtsverlauf",
    "Geschichtsverläufen": "Geschichtsverlauf",
    "Geschicke": "Geschick",
    "Geschicken": "Geschick",
    "Geschickes": "Geschick",
    "Geschicks": "Geschick",
    "Geschickten": "Geschickte",
    "Geschickteren": "Geschicktere",
    "Geschicktesten": "Geschickteste",
    "Geschiebes": "Geschiebe",
    "Geschiedenen": "Geschiedene",
    "Geschiedeneren": "Geschiedenere",
    "Geschiedensten": "Geschiedenste",
    "Geschieferten": "Geschieferte",
    "Geschielten": "Geschielte",
    "Geschienenen": "Geschienene",
    "Geschifften": "Geschiffte",
    "Geschilderten": "Geschilderte",
    "Geschillerten": "Geschillerte",
    "Geschimmelten": "Geschimmelte",
    "Geschimmerten": "Geschimmerte",
    "Geschimpfes": "Geschimpfe",
    "Geschimpften": "Geschimpfte",
    "Geschirmten": "Geschirmte",
    "Geschirre": "Geschirr",
    "Geschirren": "Geschirr",
    "Geschirrs": "Geschirr",
    "Geschirrten": "Geschirrte",
    "Geschissenen": "Geschissene",
    "Geschlabberten": "Geschlabberte",
    "Geschlachteten": "Geschlachtete",
    "Geschlafenen": "Geschlafene",
    "Geschlafften": "Geschlaffte",
    "Geschlafwandelten": "Geschlafwandelte",
    "Geschlagenen": "Geschlagene",
    "Geschlageneren": "Geschlagenere",
    "Geschlagensten": "Geschlagenste",
    "Geschlampten": "Geschlampte",
    "Geschlampteren": "Geschlamptere",
    "Geschlamptesten": "Geschlampteste",
    "Geschlappten": "Geschlappte",
    "Geschlauchten": "Geschlauchte",
    "Geschlechte": "Geschlecht",
    "Geschlechter": "Geschlecht",
    "Geschlechtern": "Geschlecht",
    "Geschlechtes": "Geschlecht",
    "Geschlechtliche": "geschlechtlich",
    "Geschlechtlichen": "Geschlechtliche",
    "Geschlechts": "Geschlecht",
    "Geschlechtskranke": "geschlechtskrank",
    "Geschlechtskranken": "Geschlechtskranke",
    "Geschlechtsreifen": "Geschlechtsreife",
    "Geschlechtsreiferen": "Geschlechtsreifere",
    "Geschleckerten": "Geschleckerte",
    "Geschleiften": "Geschleifte",
    "Geschleimten": "Geschleimte",
    "Geschleimteren": "Geschleimtere",
    "Geschleimtesten": "Geschleimteste",
    "Geschleißten": "Geschleißte",
    "Geschlemmten": "Geschlemmte",
    "Geschlenderten": "Geschlenderte",
    "Geschlenkerten": "Geschlenkerte",
    "Geschlenzten": "Geschlenzte",
    "Geschleppten": "Geschleppte",
    "Geschleuderten": "Geschleuderte",
    "Geschleuderteren": "Geschleudertere",
    "Geschleudertesten": "Geschleuderteste",
    "Geschleusten": "Geschleuste",
    "Geschlichenen": "Geschlichene",
    "Geschlicheneren": "Geschlichenere",
    "Geschlichensten": "Geschlichenste",
    "Geschliffenen": "Geschliffene",
    "Geschliffeneren": "Geschliffenere",
    "Geschliffensten": "Geschliffenste",
    "Geschlingerten": "Geschlingerte",
    "Geschlissenen": "Geschlissene",
    "Geschlisseneren": "Geschlissenere",
    "Geschlissensten": "Geschlissenste",
    "Geschlitterten": "Geschlitterte",
    "Geschlitzten": "Geschlitzte",
    "Geschlossenen": "Geschlossene",
    "Geschlosseneren": "Geschlossenere",
    "Geschlossensten": "Geschlossenste",
    "Geschlosserten": "Geschlosserte",
    "Geschlotterten": "Geschlotterte",
    "Geschluchzten": "Geschluchzte",
    "Geschluckten": "Geschluckte",
    "Geschluderten": "Geschluderte",
    "Geschlummerten": "Geschlummerte",
    "Geschlungenen": "Geschlungene",
    "Geschlungeneren": "Geschlungenere",
    "Geschlungensten": "Geschlungenste",
    "Geschläferten": "Geschläferte",
    "Geschlämmten": "Geschlämmte",
    "Geschlängelten": "Geschlängelte",
    "Geschlüpften": "Geschlüpfte",
    "Geschlürften": "Geschlürfte",
    "Geschlüsselten": "Geschlüsselte",
    "Geschmachteten": "Geschmachtete",
    "Geschmachteteren": "Geschmachtetere",
    "Geschmachtetesten": "Geschmachteteste",
    "Geschmacke": "Geschmack",
    "Geschmackes": "Geschmack",
    "Geschmackliche": "geschmacklich",
    "Geschmacklichen": "Geschmackliche",
    "Geschmacklosen": "Geschmacklose",
    "Geschmackloseren": "Geschmacklosere",
    "Geschmacklosesten": "Geschmackloseste",
    "Geschmacks": "Geschmack",
    "Geschmackvolle": "geschmackvoll",
    "Geschmackvollen": "Geschmackvolle",
    "Geschmackvolleren": "Geschmackvollere",
    "Geschmackvollsten": "Geschmackvollste",
    "Geschmatzten": "Geschmatzte",
    "Geschmeckten": "Geschmeckte",
    "Geschmeichelten": "Geschmeichelte",
    "Geschmeidigen": "Geschmeidige",
    "Geschmeidigeren": "Geschmeidigere",
    "Geschmeidigsten": "Geschmeidigste",
    "Geschmerzten": "Geschmerzte",
    "Geschmetters": "Geschmetter",
    "Geschmetterten": "Geschmetterte",
    "Geschmiedeten": "Geschmiedete",
    "Geschmiegten": "Geschmiegte",
    "Geschmiers": "Geschmier",
    "Geschmierten": "Geschmierte",
    "Geschminkten": "Geschminkte",
    "Geschmirgelten": "Geschmirgelte",
    "Geschmissenen": "Geschmissene",
    "Geschmollten": "Geschmollte",
    "Geschmolzenen": "Geschmolzene",
    "Geschmolzeneren": "Geschmolzenere",
    "Geschmolzensten": "Geschmolzenste",
    "Geschmorten": "Geschmorte",
    "Geschmuddelten": "Geschmuddelte",
    "Geschmuggelten": "Geschmuggelte",
    "Geschmunzelten": "Geschmunzelte",
    "Geschmuses": "Geschmuse",
    "Geschmusten": "Geschmuste",
    "Geschmäcker": "Geschmack",
    "Geschmäckern": "Geschmack",
    "Geschmälerten": "Geschmälerte",
    "Geschmökerten": "Geschmökerte",
    "Geschmückten": "Geschmückte",
    "Geschmückteren": "Geschmücktere",
    "Geschmücktesten": "Geschmückteste",
    "Geschnallten": "Geschnallte",
    "Geschnalzten": "Geschnalzte",
    "Geschnappten": "Geschnappte",
    "Geschnarchten": "Geschnarchte",
    "Geschnatterten": "Geschnatterte",
    "Geschnaubten": "Geschnaubte",
    "Geschnauften": "Geschnaufte",
    "Geschnauzten": "Geschnauzte",
    "Geschneiderten": "Geschneiderte",
    "Geschneiten": "Geschneite",
    "Geschnellten": "Geschnellte",
    "Geschneuzten": "Geschneuzte",
    "Geschnieften": "Geschniefte",
    "Geschniegelten": "Geschniegelte",
    "Geschniegelteren": "Geschniegeltere",
    "Geschniegeltesten": "Geschniegelteste",
    "Geschnippten": "Geschnippte",
    "Geschnipselten": "Geschnipselte",
    "Geschnittenen": "Geschnittene",
    "Geschnitzten": "Geschnitzte",
    "Geschnorchelten": "Geschnorchelte",
    "Geschnorrten": "Geschnorrte",
    "Geschnupperten": "Geschnupperte",
    "Geschnurrten": "Geschnurrte",
    "Geschnäuzte": "geschnäuzt",
    "Geschnäuzten": "Geschnäuzte",
    "Geschnüffelten": "Geschnüffelte",
    "Geschnürten": "Geschnürte",
    "Geschobenen": "Geschobene",
    "Geschobeneren": "Geschobenere",
    "Geschobensten": "Geschobenste",
    "Geschockten": "Geschockte",
    "Geschockteren": "Geschocktere",
    "Geschocktesten": "Geschockteste",
    "Gescholtenen": "Gescholtene",
    "Gescholteneren": "Gescholtenere",
    "Gescholtensten": "Gescholtenste",
    "Geschonten": "Geschonte",
    "Geschonteren": "Geschontere",
    "Geschontesten": "Geschonteste",
    "Geschoppten": "Geschoppte",
    "Geschorenen": "Geschorene",
    "Geschoreneren": "Geschorenere",
    "Geschorensten": "Geschorenste",
    "Geschossenen": "Geschossene",
    "Geschotterten": "Geschotterte",
    "Geschrammten": "Geschrammte",
    "Geschraubten": "Geschraubte",
    "Geschreckten": "Geschreckte",
    "Geschreinerten": "Geschreinerte",
    "Geschreis": "Geschrei",
    "Geschriebenen": "Geschriebene",
    "Geschrienen": "Geschriene",
    "Geschrittenen": "Geschrittene",
    "Geschrockenen": "Geschrockene",
    "Geschrubbten": "Geschrubbte",
    "Geschrumpelten": "Geschrumpelte",
    "Geschrumpelteren": "Geschrumpeltere",
    "Geschrumpeltesten": "Geschrumpelteste",
    "Geschrumpften": "Geschrumpfte",
    "Geschrägten": "Geschrägte",
    "Geschränkten": "Geschränkte",
    "Geschröpften": "Geschröpfte",
    "Geschröpfteren": "Geschröpftere",
    "Geschröpftesten": "Geschröpfteste",
    "Geschubsten": "Geschubste",
    "Geschuckelten": "Geschuckelte",
    "Geschufteten": "Geschuftete",
    "Geschuldeten": "Geschuldete",
    "Geschulten": "Geschulte",
    "Geschulteren": "Geschultere",
    "Geschulterten": "Geschulterte",
    "Geschultesten": "Geschulteste",
    "Geschummelten": "Geschummelte",
    "Geschundenen": "Geschundene",
    "Geschundeneren": "Geschundenere",
    "Geschundensten": "Geschundenste",
    "Geschunkelten": "Geschunkelte",
    "Geschusterten": "Geschusterte",
    "Geschwabbelten": "Geschwabbelte",
    "Geschwadern": "Geschwader",
    "Geschwaders": "Geschwader",
    "Geschwafels": "Geschwafel",
    "Geschwafelten": "Geschwafelte",
    "Geschwankten": "Geschwankte",
    "Geschwanten": "Geschwante",
    "Geschwappten": "Geschwappte",
    "Geschwatzes": "Geschwatze",
    "Geschwatzten": "Geschwatzte",
    "Geschwebten": "Geschwebte",
    "Geschwefelten": "Geschwefelte",
    "Geschweiften": "Geschweifte",
    "Geschweißten": "Geschweißte",
    "Geschwelgten": "Geschwelgte",
    "Geschwellten": "Geschwellte",
    "Geschwelten": "Geschwelte",
    "Geschwemmten": "Geschwemmte",
    "Geschwenkten": "Geschwenkte",
    "Geschwiegenen": "Geschwiegene",
    "Geschwindelten": "Geschwindelte",
    "Geschwinden": "Geschwinde",
    "Geschwindigkeiten": "Geschwindigkeit",
    "Geschwirrten": "Geschwirrte",
    "Geschwisterchens": "Geschwisterchen",
    "Geschwisterliche": "geschwisterlich",
    "Geschwisterlichen": "Geschwisterliche",
    "Geschwistern": "Geschwister",
    "Geschwitzten": "Geschwitzte",
    "Geschwollenen": "Geschwollene",
    "Geschwolleneren": "Geschwollenere",
    "Geschwollensten": "Geschwollenste",
    "Geschwommenen": "Geschwommene",
    "Geschworenen": "Geschworene",
    "Geschwundenen": "Geschwundene",
    "Geschwundeneren": "Geschwundenere",
    "Geschwundensten": "Geschwundenste",
    "Geschwungenen": "Geschwungene",
    "Geschwäbelten": "Geschwäbelte",
    "Geschwächten": "Geschwächte",
    "Geschwächteren": "Geschwächtere",
    "Geschwächtesten": "Geschwächteste",
    "Geschwängerten": "Geschwängerte",
    "Geschwänzten": "Geschwänzte",
    "Geschwärmten": "Geschwärmte",
    "Geschwärzten": "Geschwärzte",
    "Geschwärzteren": "Geschwärztere",
    "Geschwärztesten": "Geschwärzteste",
    "Geschwätzige": "geschwätzig",
    "Geschwätzigen": "Geschwätzige",
    "Geschwätzigeren": "Geschwätzigere",
    "Geschwätzigsten": "Geschwätzigste",
    "Geschwüre": "Geschwür",
    "Geschwüren": "Geschwür",
    "Geschwüres": "Geschwür",
    "Geschwürs": "Geschwür",
    "Geschädigten": "Geschädigte",
    "Geschäftchens": "Geschäftchen",
    "Geschäfte": "Geschäft",
    "Geschäften": "Geschäft",
    "Geschäftige": "geschäftig",
    "Geschäftigen": "Geschäftige",
    "Geschäftigeren": "Geschäftigere",
    "Geschäftigsten": "Geschäftigste",
    "Geschäftlichen": "Geschäftliche",
    "Geschäfts": "Geschäft",
    "Geschäftsfähige": "geschäftsfähig",
    "Geschäftsfähigen": "Geschäftsfähige",
    "Geschäftsführenden": "Geschäftsführende",
    "Geschäftsmäßigen": "Geschäftsmäßige",
    "Geschäftsschädigenden": "Geschäftsschädigende",
    "Geschäftsschädigenderen": "Geschäftsschädigendere",
    "Geschäftstüchtigen": "Geschäftstüchtige",
    "Geschäftstüchtigeren": "Geschäftstüchtigere",
    "Geschäftsunfähigen": "Geschäftsunfähige",
    "Geschäftsunfähigeren": "Geschäftsunfähigere",
    "Geschälte": "geschält",
    "Geschälten": "Geschälte",
    "Geschämten": "Geschämte",
    "Geschändeten": "Geschändete",
    "Geschändeteren": "Geschändetere",
    "Geschändetesten": "Geschändeteste",
    "Geschärften": "Geschärfte",
    "Geschärfteren": "Geschärftere",
    "Geschärftesten": "Geschärfteste",
    "Geschätzten": "Geschätzte",
    "Geschätzteren": "Geschätztere",
    "Geschätztesten": "Geschätzteste",
    "Geschäumten": "Geschäumte",
    "Geschäumteren": "Geschäumtere",
    "Geschäumtesten": "Geschäumteste",
    "Geschöpften": "Geschöpfte",
    "Geschürften": "Geschürfte",
    "Geschürten": "Geschürte",
    "Geschüttelten": "Geschüttelte",
    "Geschüttelteren": "Geschütteltere",
    "Geschütteltesten": "Geschüttelteste",
    "Geschütterten": "Geschütterte",
    "Geschütteten": "Geschüttete",
    "Geschützten": "Geschützte",
    "Geschützteren": "Geschütztere",
    "Geschütztesten": "Geschützteste",
    "Gesegelten": "Gesegelte",
    "Gesegneten": "Gesegnete",
    "Gesehenen": "Gesehene",
    "Gesehnten": "Gesehnte",
    "Geseiften": "Geseifte",
    "Geseilten": "Geseilte",
    "Gesellen": "Geselle",
    "Gesellenden": "Gesellende",
    "Gesellens": "Gesellen",
    "Geselligen": "Gesellige",
    "Geselligeren": "Geselligere",
    "Geselligkeiten": "Geselligkeit",
    "Geselligste": "gesellig",
    "Geselligsten": "Geselligste",
    "Gesellschaften": "Gesellschaft",
    "Gesellschaftern": "Gesellschafter",
    "Gesellschafters": "Gesellschafter",
    "Gesellschaftliche": "gesellschaftlich",
    "Gesellschaftlichen": "Gesellschaftliche",
    "Gesellschaftlicheren": "Gesellschaftlichere",
    "Gesellschaftsfähigen": "Gesellschaftsfähige",
    "Gesellschaftsfähigeren": "Gesellschaftsfähigere",
    "Gesellte": "gesellt",
    "Gesellten": "Gesellte",
    "Gesendeten": "Gesendete",
    "Gesengten": "Gesengte",
    "Gesenkten": "Gesenkte",
    "Gesenkteren": "Gesenktere",
    "Gesenktesten": "Gesenkteste",
    "Gesessenen": "Gesessene",
    "Gesetze": "Gesetz",
    "Gesetzen": "Gesetz",
    "Gesetzes": "Gesetz",
    "Gesetzgebungen": "Gesetzgebung",
    "Gesetzliche": "gesetzlich",
    "Gesetzlichen": "Gesetzliche",
    "Gesetzlosen": "Gesetzlose",
    "Gesetzloseren": "Gesetzlosere",
    "Gesetzlosesten": "Gesetzloseste",
    "Gesetzmäßigen": "Gesetzmäßige",
    "Gesetzmäßigeren": "Gesetzmäßigere",
    "Gesetzmäßigsten": "Gesetzmäßigste",
    "Gesetzten": "Gesetzte",
    "Gesetzteren": "Gesetztere",
    "Gesetztesten": "Gesetzteste",
    "Gesetzwidrigen": "Gesetzwidrige",
    "Gesetzwidrigeren": "Gesetzwidrigere",
    "Gesetzwidrigsten": "Gesetzwidrigste",
    "Geseufzten": "Geseufzte",
    "Gesicherten": "Gesicherte",
    "Gesicherteren": "Gesichertere",
    "Gesichertesten": "Gesicherteste",
    "Gesichte": "Gesicht",
    "Gesichter": "Gesicht",
    "Gesichtern": "Gesicht",
    "Gesichtes": "Gesicht",
    "Gesichteten": "Gesichtete",
    "Gesichts": "Gesicht",
    "Gesichtspunkte": "Gesichtspunkt",
    "Gesichtspunkten": "Gesichtspunkt",
    "Gesichtspunkts": "Gesichtspunkt",
    "Gesiebten": "Gesiebte",
    "Gesiechten": "Gesiechte",
    "Gesiedelten": "Gesiedelte",
    "Gesiedeten": "Gesiedete",
    "Gesiegelten": "Gesiegelte",
    "Gesiegten": "Gesiegte",
    "Gesiezten": "Gesiezte",
    "Gesindels": "Gesindel",
    "Gesinnungen": "Gesinnung",
    "Gesinnungslose": "gesinnungslos",
    "Gesinnungslosen": "Gesinnungslose",
    "Gesinnungstreuen": "Gesinnungstreue",
    "Gesinnungstreueren": "Gesinnungstreuere",
    "Gesitteten": "Gesittete",
    "Gesitteteren": "Gesittetere",
    "Gesittetesten": "Gesitteteste",
    "Gesoffenen": "Gesoffene",
    "Gesoffeneren": "Gesoffenere",
    "Gesoffensten": "Gesoffenste",
    "Gesogenen": "Gesogene",
    "Gesohlten": "Gesohlte",
    "Gesonderten": "Gesonderte",
    "Gesonnenen": "Gesonnene",
    "Gesonnten": "Gesonnte",
    "Gesorgten": "Gesorgte",
    "Gesottenen": "Gesottene",
    "Gespachtelten": "Gespachtelte",
    "Gespaltenen": "Gespaltene",
    "Gespalteneren": "Gespaltenere",
    "Gespaltensten": "Gespaltenste",
    "Gespannten": "Gespannte",
    "Gespannteren": "Gespanntere",
    "Gespanntesten": "Gespannteste",
    "Gesparten": "Gesparte",
    "Gespaßten": "Gespaßte",
    "Gespeicherten": "Gespeicherte",
    "Gespeisten": "Gespeiste",
    "Gespendeten": "Gespendete",
    "Gespenste": "Gespenst",
    "Gespenster": "Gespenst",
    "Gespenstern": "Gespenst",
    "Gespenstes": "Gespenst",
    "Gespenstige": "gespenstig",
    "Gespenstigen": "Gespenstige",
    "Gespenstigeren": "Gespenstigere",
    "Gespenstigsten": "Gespenstigste",
    "Gespenstischen": "Gespenstische",
    "Gespenstischeren": "Gespenstischere",
    "Gespenstischsten": "Gespenstischste",
    "Gesperrten": "Gesperrte",
    "Gespickten": "Gespickte",
    "Gespiegelten": "Gespiegelte",
    "Gespiegelteren": "Gespiegeltere",
    "Gespiegeltesten": "Gespiegelteste",
    "Gespielen": "Gespiele",
    "Gespielinnen": "Gespielin",
    "Gespielten": "Gespielte",
    "Gespienen": "Gespiene",
    "Gespießten": "Gespießte",
    "Gespitzelten": "Gespitzelte",
    "Gespitzten": "Gespitzte",
    "Gespitzteren": "Gespitztere",
    "Gespitztesten": "Gespitzteste",
    "Gesplissenen": "Gesplissene",
    "Gesplitterten": "Gesplitterte",
    "Gesponnenen": "Gesponnene",
    "Gesponneneren": "Gesponnenere",
    "Gesponnensten": "Gesponnenste",
    "Gesponserten": "Gesponserte",
    "Gesponserteren": "Gesponsertere",
    "Gesponsertesten": "Gesponserteste",
    "Gespornten": "Gespornte",
    "Gespotteten": "Gespottete",
    "Gespreizten": "Gespreizte",
    "Gesprengten": "Gesprengte",
    "Gesprenkelten": "Gesprenkelte",
    "Gesprenkelteren": "Gesprenkeltere",
    "Gesprenkeltesten": "Gesprenkelteste",
    "Gesprinteten": "Gesprintete",
    "Gespritzten": "Gespritzte",
    "Gespritzteren": "Gespritztere",
    "Gespritztesten": "Gespritzteste",
    "Gesprochenen": "Gesprochene",
    "Gesprocheneren": "Gesprochenere",
    "Gesprochensten": "Gesprochenste",
    "Gesprossenen": "Gesprossene",
    "Gesprosseneren": "Gesprossenere",
    "Gesprossensten": "Gesprossenste",
    "Gesprudelten": "Gesprudelte",
    "Gesprungenen": "Gesprungene",
    "Gespräche": "Gespräch",
    "Gesprächen": "Gespräch",
    "Gespräches": "Gespräch",
    "Gesprächige": "gesprächig",
    "Gesprächigen": "Gesprächige",
    "Gesprächigeren": "Gesprächigere",
    "Gesprächigsten": "Gesprächigste",
    "Gesprächs": "Gespräch",
    "Gesprühten": "Gesprühte",
    "Gespuckten": "Gespuckte",
    "Gespukten": "Gespukte",
    "Gespulten": "Gespulte",
    "Gespurten": "Gespurte",
    "Gespurteten": "Gespurtete",
    "Gespurteteren": "Gespurtetere",
    "Gespurtetesten": "Gespurteteste",
    "Gesputeten": "Gesputete",
    "Gespähten": "Gespähte",
    "Gespötte": "Gespött",
    "Gespötten": "Gespött",
    "Gespötts": "Gespött",
    "Gespülte": "gespült",
    "Gespülten": "Gespülte",
    "Gespüre": "Gespür",
    "Gespüren": "Gespür",
    "Gespürs": "Gespür",
    "Gespürte": "gespürt",
    "Gespürten": "Gespürte",
    "Gestachelten": "Gestachelte",
    "Gestaden": "Gestade",
    "Gestades": "Gestade",
    "Gestaffelten": "Gestaffelte",
    "Gestalten": "Gestalt",
    "Gestaltenden": "Gestaltende",
    "Gestaltens": "Gestalten",
    "Gestalterische": "gestalterisch",
    "Gestalterischen": "Gestalterische",
    "Gestaltern": "Gestalter",
    "Gestalters": "Gestalter",
    "Gestaltete": "gestaltet",
    "Gestalteten": "Gestaltete",
    "Gestaltlehren": "Gestaltlehre",
    "Gestaltlose": "gestaltlos",
    "Gestaltlosen": "Gestaltlose",
    "Gestaltmäßigen": "Gestaltmäßige",
    "Gestaltungen": "Gestaltung",
    "Gestammels": "Gestammel",
    "Gestammelten": "Gestammelte",
    "Gestammelteren": "Gestammeltere",
    "Gestammeltesten": "Gestammelteste",
    "Gestammten": "Gestammte",
    "Gestampften": "Gestampfte",
    "Gestampfteren": "Gestampftere",
    "Gestampftesten": "Gestampfteste",
    "Gestandenen": "Gestandene",
    "Gestanke": "Gestank",
    "Gestankes": "Gestank",
    "Gestanks": "Gestank",
    "Gestanzten": "Gestanzte",
    "Gestapelten": "Gestapelte",
    "Gestapelteren": "Gestapeltere",
    "Gestapeltesten": "Gestapelteste",
    "Gestapften": "Gestapfte",
    "Gestarrten": "Gestarrte",
    "Gestarteten": "Gestartete",
    "Gestattenden": "Gestattende",
    "Gestattens": "Gestatten",
    "Gestattete": "gestattet",
    "Gestatteten": "Gestattete",
    "Gestaubten": "Gestaubte",
    "Gestaubteren": "Gestaubtere",
    "Gestaubtesten": "Gestaubteste",
    "Gestauchten": "Gestauchte",
    "Gestauchteren": "Gestauchtere",
    "Gestauchtesten": "Gestauchteste",
    "Gestaunten": "Gestaunte",
    "Gestauten": "Gestaute",
    "Gestauteren": "Gestautere",
    "Gestautesten": "Gestauteste",
    "Gesteckten": "Gesteckte",
    "Gestehenden": "Gestehende",
    "Gestehens": "Gestehen",
    "Gesteiften": "Gesteifte",
    "Gesteifteren": "Gesteiftere",
    "Gesteiftesten": "Gesteifteste",
    "Gesteigerten": "Gesteigerte",
    "Gesteine": "Gestein",
    "Gesteinen": "Gestein",
    "Gesteinigten": "Gesteinigte",
    "Gesteins": "Gestein",
    "Gestellten": "Gestellte",
    "Gestellteren": "Gestelltere",
    "Gestelltesten": "Gestellteste",
    "Gestemmten": "Gestemmte",
    "Gestempelten": "Gestempelte",
    "Gesten": "Geste",
    "Gestenreiche": "gestenreich",
    "Gestenreichen": "Gestenreiche",
    "Gestenreicheren": "Gestenreichere",
    "Gestenreichsten": "Gestenreichste",
    "Gesteppten": "Gesteppte",
    "Gesteuerten": "Gesteuerte",
    "Gestichelten": "Gestichelte",
    "Gestiefelten": "Gestiefelte",
    "Gestiegenen": "Gestiegene",
    "Gestielten": "Gestielte",
    "Gestierten": "Gestierte",
    "Gestifteten": "Gestiftete",
    "Gestikulierenden": "Gestikulierende",
    "Gestikulierenderen": "Gestikulierendere",
    "Gestikulierens": "Gestikulieren",
    "Gestikulierte": "gestikuliert",
    "Gestikulierten": "Gestikulierte",
    "Gestillten": "Gestillte",
    "Gestimmten": "Gestimmte",
    "Gestimmteren": "Gestimmtere",
    "Gestimmtesten": "Gestimmteste",
    "Gestippten": "Gestippte",
    "Gestobenen": "Gestobene",
    "Gestobeneren": "Gestobenere",
    "Gestobensten": "Gestobenste",
    "Gestochenen": "Gestochene",
    "Gestocheneren": "Gestochenere",
    "Gestochensten": "Gestochenste",
    "Gestocherten": "Gestocherte",
    "Gestockten": "Gestockte",
    "Gestohlenen": "Gestohlene",
    "Gestolperten": "Gestolperte",
    "Gestopften": "Gestopfte",
    "Gestopfteren": "Gestopftere",
    "Gestopftesten": "Gestopfteste",
    "Gestoppelten": "Gestoppelte",
    "Gestoppten": "Gestoppte",
    "Gestorbenen": "Gestorbene",
    "Gestotterten": "Gestotterte",
    "Gestoßenen": "Gestoßene",
    "Gestraften": "Gestrafte",
    "Gestrafteren": "Gestraftere",
    "Gestraftesten": "Gestrafteste",
    "Gestrahlten": "Gestrahlte",
    "Gestrampelten": "Gestrampelte",
    "Gestrandeten": "Gestrandete",
    "Gestrauchelten": "Gestrauchelte",
    "Gestrauchelteren": "Gestraucheltere",
    "Gestraucheltesten": "Gestrauchelteste",
    "Gestrebten": "Gestrebte",
    "Gestreckten": "Gestreckte",
    "Gestreckteren": "Gestrecktere",
    "Gestrecktesten": "Gestreckteste",
    "Gestreichelten": "Gestreichelte",
    "Gestreiften": "Gestreifte",
    "Gestreikten": "Gestreikte",
    "Gestreunten": "Gestreunte",
    "Gestreuselten": "Gestreuselte",
    "Gestreuten": "Gestreute",
    "Gestreßten": "Gestreßte",
    "Gestreßteren": "Gestreßtere",
    "Gestreßtesten": "Gestreßteste",
    "Gestrichenen": "Gestrichene",
    "Gestricks": "Gestrick",
    "Gestriegelten": "Gestriegelte",
    "Gestriegelteren": "Gestriegeltere",
    "Gestriegeltesten": "Gestriegelteste",
    "Gestrigen": "Gestrige",
    "Gestrippten": "Gestrippte",
    "Gestrittenen": "Gestrittene",
    "Gestrolchten": "Gestrolchte",
    "Gestromerten": "Gestromerte",
    "Gestrotzten": "Gestrotzte",
    "Gestrudelten": "Gestrudelte",
    "Gestrullten": "Gestrullte",
    "Gesträubten": "Gesträubte",
    "Gesträuche": "Gesträuch",
    "Gesträucher": "Gesträuch",
    "Gesträuchern": "Gesträuch",
    "Gesträuchs": "Gesträuch",
    "Geströmten": "Geströmte",
    "Gestrüppe": "Gestrüpp",
    "Gestrüppen": "Gestrüpp",
    "Gestrüpps": "Gestrüpp",
    "Gestuften": "Gestufte",
    "Gestumpften": "Gestumpfte",
    "Gestundeten": "Gestundete",
    "Gestunkenen": "Gestunkene",
    "Gestutzten": "Gestutzte",
    "Gestutzteren": "Gestutztere",
    "Gestutztesten": "Gestutzteste",
    "Geständigen": "Geständige",
    "Geständnisse": "Geständnis",
    "Geständnissen": "Geständnis",
    "Geständnisses": "Geständnis",
    "Gestängen": "Gestänge",
    "Gestänges": "Gestänge",
    "Gestänkerten": "Gestänkerte",
    "Gestärkten": "Gestärkte",
    "Gestärkteren": "Gestärktere",
    "Gestärktesten": "Gestärkteste",
    "Gestöbern": "Gestöber",
    "Gestöbers": "Gestöber",
    "Gestöberten": "Gestöberte",
    "Gestöhnten": "Gestöhnte",
    "Gestöpselten": "Gestöpselte",
    "Gestörten": "Gestörte",
    "Gestörteren": "Gestörtere",
    "Gestörtesten": "Gestörteste",
    "Gestückelten": "Gestückelte",
    "Gestückelteren": "Gestückeltere",
    "Gestückeltesten": "Gestückelteste",
    "Gestülpten": "Gestülpte",
    "Gestümmelten": "Gestümmelte",
    "Gestümpers": "Gestümper",
    "Gestümperten": "Gestümperte",
    "Gestümperteren": "Gestümpertere",
    "Gestümpertesten": "Gestümperteste",
    "Gestürmten": "Gestürmte",
    "Gestürzten": "Gestürzte",
    "Gestüte": "Gestüt",
    "Gestüten": "Gestüt",
    "Gestüts": "Gestüt",
    "Gestützte": "gestützt",
    "Gestützten": "Gestützte",
    "Gesuche": "Gesuch",
    "Gesuchen": "Gesuch",
    "Gesuches": "Gesuch",
    "Gesuchs": "Gesuch",
    "Gesuchten": "Gesuchte",
    "Gesuchteren": "Gesuchtere",
    "Gesuchtesten": "Gesuchteste",
    "Gesudels": "Gesudel",
    "Gesudelten": "Gesudelte",
    "Gesudelteren": "Gesudeltere",
    "Gesudeltesten": "Gesudelteste",
    "Gesuhlten": "Gesuhlte",
    "Gesumms": "Gesumm",
    "Gesumpften": "Gesumpfte",
    "Gesundbetenden": "Gesundbetende",
    "Gesundbetens": "Gesundbeten",
    "Gesundbrunnens": "Gesundbrunnen",
    "Gesunde": "gesund",
    "Gesunden": "Gesunde",
    "Gesundenden": "Gesundende",
    "Gesundenderen": "Gesundendere",
    "Gesundendsten": "Gesundendste",
    "Gesundens": "Gesunden",
    "Gesunderen": "Gesundere",
    "Gesundesten": "Gesundeste",
    "Gesundete": "gesundet",
    "Gesundeten": "Gesundete",
    "Gesundgebeteten": "Gesundgebetete",
    "Gesundgepflegten": "Gesundgepflegte",
    "Gesundgepflegteren": "Gesundgepflegtere",
    "Gesundgeschriebenen": "Gesundgeschriebene",
    "Gesundgeschrumpften": "Gesundgeschrumpfte",
    "Gesundgeschrumpfteren": "Gesundgeschrumpftere",
    "Gesundgestoßenen": "Gesundgestoßene",
    "Gesundgestoßeneren": "Gesundgestoßenere",
    "Gesundheiten": "Gesundheit",
    "Gesundheitliche": "gesundheitlich",
    "Gesundheitlichen": "Gesundheitliche",
    "Gesundheitsschädlichen": "Gesundheitsschädliche",
    "Gesundheitsschädlicheren": "Gesundheitsschädlichere",
    "Gesundpflegenden": "Gesundpflegende",
    "Gesundpflegenderen": "Gesundpflegendere",
    "Gesundpflegens": "Gesundpflegen",
    "Gesundschreibenden": "Gesundschreibende",
    "Gesundschreibens": "Gesundschreiben",
    "Gesundschrumpfenden": "Gesundschrumpfende",
    "Gesundschrumpfenderen": "Gesundschrumpfendere",
    "Gesundschrumpfens": "Gesundschrumpfen",
    "Gesundstoßenden": "Gesundstoßende",
    "Gesundstoßenderen": "Gesundstoßendere",
    "Gesundstoßendsten": "Gesundstoßendste",
    "Gesundstoßens": "Gesundstoßen",
    "Gesungenen": "Gesungene",
    "Gesungeneren": "Gesungenere",
    "Gesungensten": "Gesungenste",
    "Gesunkenen": "Gesunkene",
    "Gesunkeneren": "Gesunkenere",
    "Gesunkensten": "Gesunkenste",
    "Gesurrten": "Gesurrte",
    "Geswingten": "Geswingte",
    "Geswingteren": "Geswingtere",
    "Geswingtesten": "Geswingteste",
    "Gesäbelten": "Gesäbelte",
    "Gesägte": "gesägt",
    "Gesägten": "Gesägte",
    "Gesähten": "Gesähte",
    "Gesänftigten": "Gesänftigte",
    "Gesänftigteren": "Gesänftigtere",
    "Gesänftigtesten": "Gesänftigteste",
    "Gesänge": "Gesang",
    "Gesängen": "Gesang",
    "Gesäten": "Gesäte",
    "Gesättigten": "Gesättigte",
    "Gesättigteren": "Gesättigtere",
    "Gesättigtesten": "Gesättigteste",
    "Gesäuberten": "Gesäuberte",
    "Gesäuberteren": "Gesäubertere",
    "Gesäubertesten": "Gesäuberteste",
    "Gesäuerte": "gesäuert",
    "Gesäuerten": "Gesäuerte",
    "Gesäuertere": "gesäuert",
    "Gesäuerteren": "Gesäuertere",
    "Gesäuerteste": "gesäuert",
    "Gesäuertesten": "Gesäuerteste",
    "Gesäumten": "Gesäumte",
    "Gesäuselten": "Gesäuselte",
    "Gesöhnten": "Gesöhnte",
    "Gesüffelten": "Gesüffelte",
    "Gesühnten": "Gesühnte",
    "Gesülzes": "Gesülze",
    "Gesülzten": "Gesülzte",
    "Gesündigten": "Gesündigte",
    "Gesündigteren": "Gesündigtere",
    "Gesündigtesten": "Gesündigteste",
    "Gesüßten": "Gesüßte",
    "Gesüßteren": "Gesüßtere",
    "Gesüßtesten": "Gesüßteste",
    "Getadelten": "Getadelte",
    "Getadelteren": "Getadeltere",
    "Getadeltesten": "Getadelteste",
    "Getagten": "Getagte",
    "Getakelten": "Getakelte",
    "Getanen": "Getane",
    "Getankten": "Getankte",
    "Getanzten": "Getanzte",
    "Getaperten": "Getaperte",
    "Getappten": "Getappte",
    "Getapsten": "Getapste",
    "Getarnten": "Getarnte",
    "Getarnteren": "Getarntere",
    "Getarntesten": "Getarnteste",
    "Getasteten": "Getastete",
    "Getatschten": "Getatschte",
    "Getauchten": "Getauchte",
    "Getauften": "Getaufte",
    "Getaugten": "Getaugte",
    "Getaumelten": "Getaumelte",
    "Getauschten": "Getauschte",
    "Getauten": "Getaute",
    "Geteerten": "Geteerte",
    "Geteerteren": "Geteertere",
    "Geteertesten": "Geteerteste",
    "Geteilten": "Geteilte",
    "Getesteten": "Getestete",
    "Getesteteren": "Getestetere",
    "Getestetesten": "Getesteteste",
    "Getexteten": "Getextete",
    "Gethronten": "Gethronte",
    "Getiers": "Getier",
    "Getigerten": "Getigerte",
    "Getilgten": "Getilgte",
    "Getingelten": "Getingelte",
    "Getippelten": "Getippelte",
    "Getippten": "Getippte",
    "Getischlerten": "Getischlerte",
    "Getischten": "Getischte",
    "Getitschten": "Getitschte",
    "Getoasteten": "Getoastete",
    "Getobes": "Getobe",
    "Getobten": "Getobte",
    "Getollten": "Getollte",
    "Getopften": "Getopfte",
    "Getoppten": "Getoppte",
    "Getoppteren": "Getopptere",
    "Getopptesten": "Getoppteste",
    "Getorkelten": "Getorkelte",
    "Getosten": "Getoste",
    "Getrabten": "Getrabte",
    "Getrachteten": "Getrachtete",
    "Getragenen": "Getragene",
    "Getrampelten": "Getrampelte",
    "Getrappten": "Getrappte",
    "Getrapsten": "Getrapste",
    "Getrauerten": "Getrauerte",
    "Getraumwandelten": "Getraumwandelte",
    "Getrauten": "Getraute",
    "Getreiden": "Getreide",
    "Getreides": "Getreide",
    "Getrennten": "Getrennte",
    "Getretenen": "Getretene",
    "Getreteneren": "Getretenere",
    "Getretensten": "Getretenste",
    "Getrichterten": "Getrichterte",
    "Getricksten": "Getrickste",
    "Getricksteren": "Getrickstere",
    "Getrickstesten": "Getricksteste",
    "Getrieben": "treiben",
    "Getriebenen": "Getriebene",
    "Getriebes": "Getriebe",
    "Getrieften": "Getriefte",
    "Getriezten": "Getriezte",
    "Getriezteren": "Getrieztere",
    "Getrieztesten": "Getriezteste",
    "Getrillerten": "Getrillerte",
    "Getrimmten": "Getrimmte",
    "Getrimmteren": "Getrimmtere",
    "Getrimmtesten": "Getrimmteste",
    "Getrippelten": "Getrippelte",
    "Getrockneten": "Getrocknete",
    "Getrockneteren": "Getrocknetere",
    "Getrocknetesten": "Getrockneteste",
    "Getroffenen": "Getroffene",
    "Getroffeneren": "Getroffenere",
    "Getroffensten": "Getroffenste",
    "Getrogenen": "Getrogene",
    "Getrommelten": "Getrommelte",
    "Getropften": "Getropfte",
    "Getrotteten": "Getrottete",
    "Getrotzten": "Getrotzte",
    "Getrudelten": "Getrudelte",
    "Getrumpften": "Getrumpfte",
    "Getrunkenen": "Getrunkene",
    "Geträllerten": "Geträllerte",
    "Getränke": "Getränk",
    "Getränken": "Getränk",
    "Getränkes": "Getränk",
    "Getränks": "Getränk",
    "Getränten": "Getränte",
    "Geträufelten": "Geträufelte",
    "Geträufelteren": "Geträufeltere",
    "Geträufeltesten": "Geträufelteste",
    "Geträuften": "Geträufte",
    "Geträufteren": "Geträuftere",
    "Geträuftesten": "Geträufteste",
    "Geträumten": "Geträumte",
    "Getrödelten": "Getrödelte",
    "Getröpfelten": "Getröpfelte",
    "Getrösteten": "Getröstete",
    "Getrösteteren": "Getröstetere",
    "Getröstetesten": "Getrösteteste",
    "Getrübten": "Getrübte",
    "Getrübteren": "Getrübtere",
    "Getrübtesten": "Getrübteste",
    "Gettos": "Getto",
    "Getummelten": "Getummelte",
    "Getunkten": "Getunkte",
    "Getupften": "Getupfte",
    "Geturnten": "Geturnte",
    "Geturtelten": "Geturtelte",
    "Getuschelten": "Getuschelte",
    "Getuteten": "Getutete",
    "Getäfels": "Getäfel",
    "Getäfelten": "Getäfelte",
    "Getändels": "Getändel",
    "Getändelten": "Getändelte",
    "Getänzelten": "Getänzelte",
    "Getätigten": "Getätigte",
    "Getätschelten": "Getätschelte",
    "Getäuschte": "getäuscht",
    "Getäuschten": "Getäuschte",
    "Getäuschteren": "Getäuschtere",
    "Getäuschtesten": "Getäuschteste",
    "Getönten": "Getönte",
    "Getönteren": "Getöntere",
    "Getöntesten": "Getönteste",
    "Getöpferten": "Getöpferte",
    "Getörnten": "Getörnte",
    "Getöteten": "Getötete",
    "Getüftelten": "Getüftelte",
    "Getünchten": "Getünchte",
    "Getürkten": "Getürkte",
    "Getürkteren": "Getürktere",
    "Getürktesten": "Getürkteste",
    "Getürmten": "Getürmte",
    "Getütete": "getütet",
    "Getüteten": "Getütete",
    "Geuferten": "Geuferte",
    "Geulkten": "Geulkte",
    "Geunkten": "Geunkte",
    "Geurteilten": "Geurteilte",
    "Gevierteilten": "Gevierteilte",
    "Geviertelten": "Geviertelte",
    "Gevögelten": "Gevögelte",
    "Gewabbelten": "Gewabbelte",
    "Gewachsene": "gewachsen",
    "Gewachsenen": "Gewachsene",
    "Gewachseneren": "Gewachsenere",
    "Gewachsensten": "Gewachsenste",
    "Gewachsten": "Gewachste",
    "Gewachsteren": "Gewachstere",
    "Gewachstesten": "Gewachsteste",
    "Gewachten": "Gewachte",
    "Gewaffneten": "Gewaffnete",
    "Gewagten": "Gewagte",
    "Gewagteren": "Gewagtere",
    "Gewagtesten": "Gewagteste",
    "Gewahrten": "Gewahrte",
    "Gewallten": "Gewallte",
    "Gewalten": "Gewalt",
    "Gewalteten": "Gewaltete",
    "Gewaltigen": "Gewaltige",
    "Gewaltigeren": "Gewaltigere",
    "Gewaltigsten": "Gewaltigste",
    "Gewaltlosen": "Gewaltlose",
    "Gewaltloseren": "Gewaltlosere",
    "Gewaltlosesten": "Gewaltloseste",
    "Gewaltsamen": "Gewaltsame",
    "Gewalttätigen": "Gewalttätige",
    "Gewalttätigeren": "Gewalttätigere",
    "Gewalttätigsten": "Gewalttätigste",
    "Gewalzten": "Gewalzte",
    "Gewalzteren": "Gewalztere",
    "Gewalztesten": "Gewalzteste",
    "Gewandelten": "Gewandelte",
    "Gewandelteren": "Gewandeltere",
    "Gewandeltesten": "Gewandelteste",
    "Gewanderten": "Gewanderte",
    "Gewandten": "Gewandte",
    "Gewandteren": "Gewandtere",
    "Gewandtesten": "Gewandteste",
    "Gewankten": "Gewankte",
    "Gewappneten": "Gewappnete",
    "Gewarnten": "Gewarnte",
    "Gewarteten": "Gewartete",
    "Gewarteteren": "Gewartetere",
    "Gewartetesten": "Gewarteteste",
    "Gewaschenen": "Gewaschene",
    "Gewascheneren": "Gewaschenere",
    "Gewaschensten": "Gewaschenste",
    "Gewateten": "Gewatete",
    "Gewatschelten": "Gewatschelte",
    "Geweben": "Gewebe",
    "Gewebes": "Gewebe",
    "Gewebten": "Gewebte",
    "Gewechselten": "Gewechselte",
    "Geweckten": "Geweckte",
    "Gewedelten": "Gewedelte",
    "Gewehre": "Gewehr",
    "Gewehren": "Gewehr",
    "Gewehres": "Gewehr",
    "Gewehrs": "Gewehr",
    "Gewehrten": "Gewehrte",
    "Gewehten": "Gewehte",
    "Geweichten": "Geweichte",
    "Geweideten": "Geweidete",
    "Geweigerten": "Geweigerte",
    "Geweihe": "Geweih",
    "Geweihen": "Geweih",
    "Geweihnachteten": "Geweihnachtete",
    "Geweihs": "Geweih",
    "Geweihten": "Geweihte",
    "Geweihteren": "Geweihtere",
    "Geweihtesten": "Geweihteste",
    "Geweilten": "Geweilte",
    "Geweinten": "Geweinte",
    "Geweiteten": "Geweitete",
    "Geweiteteren": "Geweitetere",
    "Geweitetesten": "Geweiteteste",
    "Gewelkten": "Gewelkte",
    "Gewellten": "Gewellte",
    "Gewendeten": "Gewendete",
    "Gewerben": "Gewerbe",
    "Gewerbes": "Gewerbe",
    "Gewerbetreibende": "gewerbetreibend",
    "Gewerbetreibenden": "Gewerbetreibende",
    "Gewerblichen": "Gewerbliche",
    "Gewerkelten": "Gewerkelte",
    "Gewerkschaften": "Gewerkschaft",
    "Gewerkschafterinnen": "Gewerkschafterin",
    "Gewerkschaftern": "Gewerkschafter",
    "Gewerkschafters": "Gewerkschafter",
    "Gewerkschaftliche": "gewerkschaftlich",
    "Gewerkschaftlichen": "Gewerkschaftliche",
    "Gewerkten": "Gewerkte",
    "Gewerteten": "Gewertete",
    "Gewetterten": "Gewetterte",
    "Gewetteten": "Gewettete",
    "Gewetzten": "Gewetzte",
    "Gewichenen": "Gewichene",
    "Gewichte": "gewichten",
    "Gewichtelten": "Gewichtelte",
    "Gewichten": "Gewicht",
    "Gewichtenden": "Gewichtende",
    "Gewichtens": "Gewichten",
    "Gewichtes": "Gewicht",
    "Gewichtete": "gewichtet",
    "Gewichteten": "Gewichtete",
    "Gewichtigen": "Gewichtige",
    "Gewichtigeren": "Gewichtigere",
    "Gewichtigsten": "Gewichtigste",
    "Gewichts": "Gewicht",
    "Gewichtsklassen": "Gewichtsklasse",
    "Gewichtungen": "Gewichtung",
    "Gewickelten": "Gewickelte",
    "Gewiderten": "Gewiderte",
    "Gewidmeten": "Gewidmete",
    "Gewieften": "Gewiefte",
    "Gewiefteren": "Gewieftere",
    "Gewieftesten": "Gewiefteste",
    "Gewiegelten": "Gewiegelte",
    "Gewieherten": "Gewieherte",
    "Gewienerten": "Gewienerte",
    "Gewiesenen": "Gewiesene",
    "Gewilderten": "Gewilderte",
    "Gewilligten": "Gewilligte",
    "Gewillten": "Gewillte",
    "Gewillteren": "Gewilltere",
    "Gewilltesten": "Gewillteste",
    "Gewimmelten": "Gewimmelte",
    "Gewimmers": "Gewimmer",
    "Gewimmerten": "Gewimmerte",
    "Gewinden": "Gewinde",
    "Gewindes": "Gewinde",
    "Gewinkelten": "Gewinkelte",
    "Gewinkten": "Gewinkte",
    "Gewinn": "gewinnen",
    "Gewinne": "gewinnen",
    "Gewinnen": "Gewinn",
    "Gewinnenden": "Gewinnende",
    "Gewinnens": "Gewinnen",
    "Gewinnern": "Gewinner",
    "Gewinners": "Gewinner",
    "Gewinnes": "Gewinn",
    "Gewinns": "Gewinn",
    "Gewinnsüchtigen": "Gewinnsüchtige",
    "Gewinnsüchtigeren": "Gewinnsüchtigere",
    "Gewinnsüchtigsten": "Gewinnsüchtigste",
    "Gewinnungen": "Gewinnung",
    "Gewinselten": "Gewinselte",
    "Gewippten": "Gewippte",
    "Gewirbelten": "Gewirbelte",
    "Gewirkten": "Gewirkte",
    "Gewirre": "Gewirr",
    "Gewirren": "Gewirr",
    "Gewirrs": "Gewirr",
    "Gewirteten": "Gewirtete",
    "Gewirtschafteten": "Gewirtschaftete",
    "Gewischten": "Gewischte",
    "Gewisperten": "Gewisperte",
    "Gewissen": "Gewisse",
    "Gewissenhafte": "gewissenhaft",
    "Gewissenhaften": "Gewissenhafte",
    "Gewissenhafteren": "Gewissenhaftere",
    "Gewissenhaftesten": "Gewissenhafteste",
    "Gewissenlosen": "Gewissenlose",
    "Gewissenloseren": "Gewissenlosere",
    "Gewissenlosesten": "Gewissenloseste",
    "Gewissens": "Gewissen",
    "Gewitter": "gewittern",
    "Gewitterhexen": "Gewitterhexe",
    "Gewitterige": "gewitterig",
    "Gewitterigen": "Gewitterige",
    "Gewittern": "Gewitter",
    "Gewitternden": "Gewitternde",
    "Gewitternderen": "Gewitterndere",
    "Gewitterndsten": "Gewitterndste",
    "Gewitterns": "Gewittern",
    "Gewitters": "Gewitter",
    "Gewitterte": "gewittert",
    "Gewitterten": "Gewitterte",
    "Gewittrigen": "Gewittrige",
    "Gewittrigeren": "Gewittrigere",
    "Gewittrigsten": "Gewittrigste",
    "Gewitzelten": "Gewitzelte",
    "Gewitzten": "Gewitzte",
    "Gewitzteren": "Gewitztere",
    "Gewitztesten": "Gewitzteste",
    "Gewißheiten": "Gewißheit",
    "Gewobenen": "Gewobene",
    "Gewogenen": "Gewogene",
    "Gewohnheiten": "Gewohnheit",
    "Gewohnheitsgemäße": "gewohnheitsgemäß",
    "Gewohnheitsgemäßen": "Gewohnheitsgemäße",
    "Gewohnheitsmäßigen": "Gewohnheitsmäßige",
    "Gewohnten": "Gewohnte",
    "Gewonnenen": "Gewonnene",
    "Geworbenen": "Geworbene",
    "Gewordenen": "Gewordene",
    "Geworfenen": "Geworfene",
    "Gewrungenen": "Gewrungene",
    "Gewucherten": "Gewucherte",
    "Gewuchteten": "Gewuchtete",
    "Gewuchteteren": "Gewuchtetere",
    "Gewuchtetesten": "Gewuchteteste",
    "Gewundenen": "Gewundene",
    "Gewunderten": "Gewunderte",
    "Gewurmten": "Gewurmte",
    "Gewurstelten": "Gewurstelte",
    "Gewursteten": "Gewurstete",
    "Gewurzelten": "Gewurzelte",
    "Gewuselten": "Gewuselte",
    "Gewußten": "Gewußte",
    "Gewächsen": "Gewächse",
    "Gewächses": "Gewächse",
    "Gewählten": "Gewählte",
    "Gewählteren": "Gewähltere",
    "Gewähltesten": "Gewählteste",
    "Gewähnten": "Gewähnte",
    "Gewähr": "gewähren",
    "Gewähren": "Gewähr",
    "Gewährenden": "Gewährende",
    "Gewährens": "Gewähren",
    "Gewährleistenden": "Gewährleistende",
    "Gewährleistens": "Gewährleisten",
    "Gewährleistete": "gewährleistet",
    "Gewährleisteten": "Gewährleistete",
    "Gewährleistungen": "Gewährleistung",
    "Gewährschaften": "Gewährschaft",
    "Gewährte": "gewähren",
    "Gewährten": "Gewährte",
    "Gewährungen": "Gewährung",
    "Gewälzte": "gewälzt",
    "Gewälzten": "Gewälzte",
    "Gewälztere": "gewälzt",
    "Gewälzteren": "Gewälztere",
    "Gewälzteste": "gewälzt",
    "Gewälztesten": "Gewälzteste",
    "Gewärmten": "Gewärmte",
    "Gewässern": "Gewässer",
    "Gewässers": "Gewässer",
    "Gewässerten": "Gewässerte",
    "Gewässerteren": "Gewässertere",
    "Gewässertesten": "Gewässerteste",
    "Gewöhnenden": "Gewöhnende",
    "Gewöhnens": "Gewöhnen",
    "Gewöhnlichen": "Gewöhnliche",
    "Gewöhnlicheren": "Gewöhnlichere",
    "Gewöhnlichsten": "Gewöhnlichste",
    "Gewöhnte": "gewöhnen",
    "Gewöhnten": "Gewöhnte",
    "Gewölben": "Gewölbe",
    "Gewölbes": "Gewölbe",
    "Gewölbten": "Gewölbte",
    "Gewühlten": "Gewühlte",
    "Gewünschten": "Gewünschte",
    "Gewürdigten": "Gewürdigte",
    "Gewürdigteren": "Gewürdigtere",
    "Gewürdigtesten": "Gewürdigteste",
    "Gewürfelten": "Gewürfelte",
    "Gewürgten": "Gewürgte",
    "Gewürgteren": "Gewürgtere",
    "Gewürgtesten": "Gewürgteste",
    "Gewürzen": "Gewürze",
    "Gewürzes": "Gewürze",
    "Gewürzten": "Gewürzte",
    "Gewürzteren": "Gewürztere",
    "Gewürztesten": "Gewürzteste",
    "Gewüteten": "Gewütete",
    "Gewüteteren": "Gewütetere",
    "Gewütetesten": "Gewüteteste",
    "Gezagten": "Gezagte",
    "Gezahlten": "Gezahlte",
    "Gezahnten": "Gezahnte",
    "Gezankes": "Gezanke",
    "Gezankten": "Gezankte",
    "Gezapften": "Gezapfte",
    "Gezappels": "Gezappel",
    "Gezappelten": "Gezappelte",
    "Gezauberten": "Gezauberte",
    "Gezauderten": "Gezauderte",
    "Gezausten": "Gezauste",
    "Gezechten": "Gezechte",
    "Gezehrten": "Gezehrte",
    "Gezehrteren": "Gezehrtere",
    "Gezehrtesten": "Gezehrteste",
    "Gezeichneten": "Gezeichnete",
    "Gezeigten": "Gezeigte",
    "Gezeigteren": "Gezeigtere",
    "Gezeigtesten": "Gezeigteste",
    "Gezelteten": "Gezeltete",
    "Gezerres": "Gezerre",
    "Gezerrten": "Gezerrte",
    "Gezeters": "Gezeter",
    "Gezettelten": "Gezettelte",
    "Gezeugten": "Gezeugte",
    "Geziefern": "Geziefer",
    "Geziefers": "Geziefer",
    "Gezielten": "Gezielte",
    "Gezielteren": "Gezieltere",
    "Gezieltesten": "Gezielteste",
    "Geziemenden": "Geziemende",
    "Geziemens": "Geziemen",
    "Geziemte": "geziemt",
    "Geziemten": "Geziemte",
    "Gezierten": "Gezierte",
    "Gezimmerten": "Gezimmerte",
    "Gezinkten": "Gezinkte",
    "Gezinkteren": "Gezinktere",
    "Gezinktesten": "Gezinkteste",
    "Gezirkelten": "Gezirkelte",
    "Gezirps": "Gezirp",
    "Gezischs": "Gezisch",
    "Gezischten": "Gezischte",
    "Gezitterten": "Gezitterte",
    "Gezogenen": "Gezogene",
    "Gezollten": "Gezollte",
    "Gezuckten": "Gezuckte",
    "Gezupften": "Gezupfte",
    "Gezurrten": "Gezurrte",
    "Gezweifelten": "Gezweifelte",
    "Gezweigten": "Gezweigte",
    "Gezwiebelten": "Gezwiebelte",
    "Gezwinkerten": "Gezwinkerte",
    "Gezwirbelten": "Gezwirbelte",
    "Gezwitschers": "Gezwitscher",
    "Gezwitscherten": "Gezwitscherte",
    "Gezwungenen": "Gezwungene",
    "Gezwungeneren": "Gezwungenere",
    "Gezwungensten": "Gezwungenste",
    "Gezwängten": "Gezwängte",
    "Gezählte": "gezählt",
    "Gezählten": "Gezählte",
    "Gezähmten": "Gezähmte",
    "Gezähmteren": "Gezähmtere",
    "Gezähmtesten": "Gezähmteste",
    "Gezäumten": "Gezäumte",
    "Gezäunten": "Gezäunte",
    "Gezögerten": "Gezögerte",
    "Gezüchteten": "Gezüchtete",
    "Gezüchtigten": "Gezüchtigte",
    "Gezügelten": "Gezügelte",
    "Gezügelteren": "Gezügeltere",
    "Gezügeltesten": "Gezügelteste",
    "Gezündelten": "Gezündelte",
    "Gezündeten": "Gezündete",
    "Gezüngels": "Gezüngel",
    "Gezüngelten": "Gezüngelte",
    "Gezürnten": "Gezürnte",
    "Gezürnteren": "Gezürntere",
    "Gezürntesten": "Gezürnteste",
    "Geächtete": "geächtet",
    "Geächteten": "Geächtete",
    "Geächtetere": "geächtet",
    "Geächteteren": "Geächtetere",
    "Geächteteste": "geächtet",
    "Geächtetesten": "Geächteteste",
    "Geächzten": "Geächzte",
    "Geäfften": "Geäffte",
    "Geäffteren": "Geäfftere",
    "Geäfftesten": "Geäffteste",
    "Geähnelten": "Geähnelte",
    "Geänderten": "Geänderte",
    "Geänderteren": "Geändertere",
    "Geändertesten": "Geänderteste",
    "Geängstigten": "Geängstigte",
    "Geängstigteren": "Geängstigtere",
    "Geängstigtesten": "Geängstigteste",
    "Geärgerten": "Geärgerte",
    "Geäscherten": "Geäscherte",
    "Geäste": "Geäst",
    "Geästen": "Geäst",
    "Geästeten": "Geästete",
    "Geästs": "Geäst",
    "Geätzten": "Geätzte",
    "Geäußerten": "Geäußerte",
    "Geödeten": "Geödete",
    "Geöffneten": "Geöffnete",
    "Geöffneteren": "Geöffnetere",
    "Geöffnetesten": "Geöffneteste",
    "Geölten": "Geölte",
    "Geübten": "Geübte",
    "Geübteren": "Geübtere",
    "Geübtesten": "Geübteste",
    "Ghalis": "Ghali",
    "Ghettos": "Ghetto",
    "Giebeln": "Giebel",
    "Giebels": "Giebel",
    "Giemens": "Giemen",
    "Gier": "gieren",
    "Gierenden": "Gierende",
    "Gierenderen": "Gierendere",
    "Gierendsten": "Gierendste",
    "Gierens": "Gieren",
    "Gierigen": "Gierige",
    "Gierigeren": "Gierigere",
    "Gierigsten": "Gierigste",
    "Gießenden": "Gießende",
    "Gießenern": "Gießener",
    "Gießeners": "Gießener",
    "Gießens": "Gießen",
    "Gießereien": "Gießerei",
    "Gießformen": "Gießform",
    "Gießkannen": "Gießkanne",
    "Gifte": "giften",
    "Giften": "Gift",
    "Giftenden": "Giftende",
    "Giftens": "Giften",
    "Giftes": "Gift",
    "Giftigen": "Giftige",
    "Giftigeren": "Giftigere",
    "Giftigsten": "Giftigste",
    "Giftnudeln": "Giftnudel",
    "Gifts": "Gift",
    "Giganten": "Gigant",
    "Gigantische": "gigantisch",
    "Gigantischen": "Gigantische",
    "Gigantischeren": "Gigantischere",
    "Gigantischsten": "Gigantischste",
    "Gigolos": "Gigolo",
    "Gigs": "Gig",
    "Ginnheimern": "Ginnheimer",
    "Ginnheimers": "Ginnheimer",
    "Ginnheims": "Ginnheim",
    "Gins": "Gin",
    "Gipfel": "gipfeln",
    "Gipfeln": "Gipfel",
    "Gipfelnden": "Gipfelnde",
    "Gipfelnderen": "Gipfelndere",
    "Gipfelndsten": "Gipfelndste",
    "Gipfelns": "Gipfeln",
    "Gipfels": "Gipfel",
    "Gips": "gipsen",
    "Gipse": "gipsen",
    "Gipsen": "Gips",
    "Gipsenden": "Gipsende",
    "Gipsens": "Gipsen",
    "Gipses": "Gips",
    "Giraffen": "Giraffe",
    "Girlanden": "Girlande",
    "Girls": "Girl",
    "Giros": "Giro",
    "Giselas": "Gisela",
    "Gitarren": "Gitarre",
    "Gitarristen": "Gitarrist",
    "Gitter": "gittern",
    "Gittern": "Gitter",
    "Gitternden": "Gitternde",
    "Gitterns": "Gittern",
    "Gitters": "Gitter",
    "Giuseppes": "Giuseppe",
    "Gladbachern": "Gladbacher",
    "Gladbachers": "Gladbacher",
    "Gladiolen": "Gladiole",
    "Glanze": "Glanz",
    "Glanzes": "Glanz",
    "Glanzlichte": "Glanzlicht",
    "Glanzlichter": "Glanzlicht",
    "Glanzlichtern": "Glanzlicht",
    "Glanzlichtes": "Glanzlicht",
    "Glanzlichts": "Glanzlicht",
    "Glanzlose": "glanzlos",
    "Glanzlosen": "Glanzlose",
    "Glanzloseren": "Glanzlosere",
    "Glanzlosesten": "Glanzloseste",
    "Glanzvollen": "Glanzvolle",
    "Glanzvolleren": "Glanzvollere",
    "Glanzvollsten": "Glanzvollste",
    "Glas": "glasen",
    "Glase": "glasen",
    "Glasenden": "Glasende",
    "Glasens": "Glasen",
    "Glasern": "Glaser",
    "Glasers": "Glaser",
    "Glases": "Glas",
    "Glasierenden": "Glasierende",
    "Glasierenderen": "Glasierendere",
    "Glasierendsten": "Glasierendste",
    "Glasierens": "Glasieren",
    "Glasierte": "glasiert",
    "Glasierten": "Glasierte",
    "Glasierteren": "Glasiertere",
    "Glasiertesten": "Glasierteste",
    "Glasigen": "Glasige",
    "Glasigeren": "Glasigere",
    "Glasigsten": "Glasigste",
    "Glasmalereien": "Glasmalerei",
    "Glatten": "Glatte",
    "Glatteren": "Glattere",
    "Glattesten": "Glatteste",
    "Glattgegangenen": "Glattgegangene",
    "Glattgehenden": "Glattgehende",
    "Glattgehens": "Glattgehen",
    "Glattgehobelten": "Glattgehobelte",
    "Glattgehobelteren": "Glattgehobeltere",
    "Glattgestrichenen": "Glattgestrichene",
    "Glattgezogenen": "Glattgezogene",
    "Glattgezogeneren": "Glattgezogenere",
    "Glattgezogensten": "Glattgezogenste",
    "Glatthobelnden": "Glatthobelnde",
    "Glatthobelnderen": "Glatthobelndere",
    "Glatthobelndsten": "Glatthobelndste",
    "Glatthobelns": "Glatthobeln",
    "Glattstreichenden": "Glattstreichende",
    "Glattstreichens": "Glattstreichen",
    "Glattziehenden": "Glattziehende",
    "Glattziehenderen": "Glattziehendere",
    "Glattziehendsten": "Glattziehendste",
    "Glattziehens": "Glattziehen",
    "Glattzüngigen": "Glattzüngige",
    "Glatzen": "Glatze",
    "Glatzköpfige": "glatzköpfig",
    "Glatzköpfigen": "Glatzköpfige",
    "Glauben": "Glaube",
    "Glaubenden": "Glaubende",
    "Glaubens": "Glauben",
    "Glaubhaften": "Glaubhafte",
    "Glaubhafteren": "Glaubhaftere",
    "Glaubhaftesten": "Glaubhafteste",
    "Glaubwürdigen": "Glaubwürdige",
    "Glaubwürdigeren": "Glaubwürdigere",
    "Glaubwürdigsten": "Glaubwürdigste",
    "Glazialen": "Glaziale",
    "Gleichaltrigen": "Gleichaltrige",
    "Gleichartigen": "Gleichartige",
    "Gleichbedeutenden": "Gleichbedeutende",
    "Gleichberechtigten": "Gleichberechtigte",
    "Gleiche": "gleichen",
    "Gleichen": "Gleiche",
    "Gleichenden": "Gleichende",
    "Gleichenderen": "Gleichendere",
    "Gleichendsten": "Gleichendste",
    "Gleichens": "Gleichen",
    "Gleichförmigen": "Gleichförmige",
    "Gleichförmigeren": "Gleichförmigere",
    "Gleichförmigsten": "Gleichförmigste",
    "Gleichgelaufenen": "Gleichgelaufene",
    "Gleichgelaufeneren": "Gleichgelaufenere",
    "Gleichgeschalteten": "Gleichgeschaltete",
    "Gleichgeschalteteren": "Gleichgeschaltetere",
    "Gleichgeschlechtlichen": "Gleichgeschlechtliche",
    "Gleichgesetzten": "Gleichgesetzte",
    "Gleichgesinnten": "Gleichgesinnte",
    "Gleichgestandenen": "Gleichgestandene",
    "Gleichgestellten": "Gleichgestellte",
    "Gleichgestellteren": "Gleichgestelltere",
    "Gleichgestimmten": "Gleichgestimmte",
    "Gleichgewichte": "Gleichgewicht",
    "Gleichgewichten": "Gleichgewicht",
    "Gleichgewichtes": "Gleichgewicht",
    "Gleichgewichts": "Gleichgewicht",
    "Gleichgezogenen": "Gleichgezogene",
    "Gleichgültigen": "Gleichgültige",
    "Gleichgültigeren": "Gleichgültigere",
    "Gleichgültigsten": "Gleichgültigste",
    "Gleichklange": "Gleichklang",
    "Gleichklangs": "Gleichklang",
    "Gleichklänge": "Gleichklang",
    "Gleichklängen": "Gleichklang",
    "Gleichlaufenden": "Gleichlaufende",
    "Gleichlaufenderen": "Gleichlaufendere",
    "Gleichlaufendsten": "Gleichlaufendste",
    "Gleichlaufens": "Gleichlaufen",
    "Gleichlaufs": "Gleichlauf",
    "Gleichlautenden": "Gleichlautende",
    "Gleichmäßigen": "Gleichmäßige",
    "Gleichmäßigeren": "Gleichmäßigere",
    "Gleichmäßigkeiten": "Gleichmäßigkeit",
    "Gleichmäßigste": "gleichmäßig",
    "Gleichmäßigsten": "Gleichmäßigste",
    "Gleichmütigen": "Gleichmütige",
    "Gleichnamigen": "Gleichnamige",
    "Gleichnisse": "Gleichnis",
    "Gleichnissen": "Gleichnis",
    "Gleichnisses": "Gleichnis",
    "Gleichrangige": "gleichrangig",
    "Gleichrangigen": "Gleichrangige",
    "Gleichschaltenden": "Gleichschaltende",
    "Gleichschaltenderen": "Gleichschaltendere",
    "Gleichschaltens": "Gleichschalten",
    "Gleichseitigen": "Gleichseitige",
    "Gleichsetzenden": "Gleichsetzende",
    "Gleichsetzens": "Gleichsetzen",
    "Gleichsetzungen": "Gleichsetzung",
    "Gleichstands": "Gleichstand",
    "Gleichstehenden": "Gleichstehende",
    "Gleichstehens": "Gleichstehen",
    "Gleichstellenden": "Gleichstellende",
    "Gleichstellenderen": "Gleichstellendere",
    "Gleichstellens": "Gleichstellen",
    "Gleichstellungen": "Gleichstellung",
    "Gleichstimmenden": "Gleichstimmende",
    "Gleichstimmens": "Gleichstimmen",
    "Gleichstromgeneratore": "Gleichstromgenerator",
    "Gleichstromgeneratoren": "Gleichstromgenerator",
    "Gleichstromgenerators": "Gleichstromgenerator",
    "Gleichstroms": "Gleichstrom",
    "Gleichungen": "Gleichung",
    "Gleichwertige": "gleichwertig",
    "Gleichwertigen": "Gleichwertige",
    "Gleichwertigkeiten": "Gleichwertigkeit",
    "Gleichzeitige": "gleichzeitig",
    "Gleichzeitigen": "Gleichzeitige",
    "Gleichziehenden": "Gleichziehende",
    "Gleichziehens": "Gleichziehen",
    "Gleis": "gleisen",
    "Gleise": "gleisen",
    "Gleisen": "Gleis",
    "Gleisenden": "Gleisende",
    "Gleisens": "Gleisen",
    "Gleises": "Gleis",
    "Gleitenden": "Gleitende",
    "Gleitenderen": "Gleitendere",
    "Gleitendsten": "Gleitendste",
    "Gleitens": "Gleiten",
    "Gleitern": "Gleiter",
    "Gleiters": "Gleiter",
    "Gleitlagern": "Gleitlager",
    "Gleitlagers": "Gleitlager",
    "Gleitmitteln": "Gleitmittel",
    "Gleitmittels": "Gleitmittel",
    "Gleitwinkeln": "Gleitwinkel",
    "Gleitwinkels": "Gleitwinkel",
    "Gleitzolls": "Gleitzoll",
    "Gletschern": "Gletscher",
    "Gletschers": "Gletscher",
    "Gliazellen": "Gliazelle",
    "Glibber": "glibbern",
    "Glibberigen": "Glibberige",
    "Glibberigeren": "Glibberigere",
    "Glibberigsten": "Glibberigste",
    "Glibbernden": "Glibbernde",
    "Glibbernderen": "Glibberndere",
    "Glibberndsten": "Glibberndste",
    "Glibberns": "Glibbern",
    "Glibbers": "Glibber",
    "Gliede": "Glied",
    "Glieder": "gliedern",
    "Gliedern": "Glied",
    "Gliedernden": "Gliedernde",
    "Gliederns": "Gliedern",
    "Gliederungen": "Gliederung",
    "Gliedes": "Glied",
    "Gliedmaßen": "Gliedmaße",
    "Glieds": "Glied",
    "Glimmenden": "Glimmende",
    "Glimmenderen": "Glimmendere",
    "Glimmendsten": "Glimmendste",
    "Glimmens": "Glimmen",
    "Glimmer": "glimmern",
    "Glimmerigen": "Glimmerige",
    "Glimmerigeren": "Glimmerigere",
    "Glimmerigsten": "Glimmerigste",
    "Glimmern": "Glimmer",
    "Glimmernden": "Glimmernde",
    "Glimmernderen": "Glimmerndere",
    "Glimmerndsten": "Glimmerndste",
    "Glimmerns": "Glimmern",
    "Glimmers": "Glimmer",
    "Glimpflichen": "Glimpfliche",
    "Glimpflicheren": "Glimpflichere",
    "Glimpflichsten": "Glimpflichste",
    "Glitschenden": "Glitschende",
    "Glitschenderen": "Glitschendere",
    "Glitschendsten": "Glitschendste",
    "Glitschens": "Glitschen",
    "Glitschigen": "Glitschige",
    "Glitschigeren": "Glitschigere",
    "Glitschigsten": "Glitschigste",
    "Globalen": "Globale",
    "Globaleren": "Globalere",
    "Globalsten": "Globalste",
    "Glocken": "Glocke",
    "Glorifikationen": "Glorifikation",
    "Glorifiziere": "glorifizieren",
    "Glorifizierenden": "Glorifizierende",
    "Glorifizierenderen": "Glorifizierendere",
    "Glorifizierens": "Glorifizieren",
    "Glorifizierte": "glorifiziert",
    "Glorifizierten": "Glorifizierte",
    "Glorifizierteren": "Glorifiziertere",
    "Glorifiziertesten": "Glorifizierteste",
    "Glossatore": "Glossator",
    "Glossatoren": "Glossator",
    "Glossators": "Glossator",
    "Glossen": "Glosse",
    "Glossografien": "Glossografie",
    "Glossographien": "Glossographie",
    "Glotze": "glotzen",
    "Glotzen": "Glotze",
    "Glotzenden": "Glotzende",
    "Glotzenderen": "Glotzendere",
    "Glotzendsten": "Glotzendste",
    "Glotzens": "Glotzen",
    "Gluckhennen": "Gluckhenne",
    "Glucksenden": "Glucksende",
    "Glucksenderen": "Glucksendere",
    "Glucksendsten": "Glucksendste",
    "Glucksens": "Glucksen",
    "Glupschenden": "Glupschende",
    "Glupschenderen": "Glupschendere",
    "Glupschendsten": "Glupschendste",
    "Glupschens": "Glupschen",
    "Glänzenden": "Glänzende",
    "Glänzenderen": "Glänzendere",
    "Glänzendsten": "Glänzendste",
    "Glänzens": "Glänzen",
    "Gläser": "Glas",
    "Gläsern": "Glas",
    "Gläserne": "gläsern",
    "Gläsernen": "Gläserne",
    "Glätte": "glätten",
    "Glättenden": "Glättende",
    "Glättenderen": "Glättendere",
    "Glättendsten": "Glättendste",
    "Glättens": "Glätten",
    "Gläubigen": "Gläubige",
    "Gläubigeren": "Gläubigere",
    "Gläubigkeiten": "Gläubigkeit",
    "Gläubigste": "gläubig",
    "Gläubigsten": "Gläubigste",
    "Glöckchens": "Glöckchen",
    "Glöckleins": "Glöcklein",
    "Glöcknern": "Glöckner",
    "Glöckners": "Glöckner",
    "Glück": "glücken",
    "Glücke": "glücken",
    "Glücken": "Glück",
    "Glückenden": "Glückende",
    "Glückens": "Glücken",
    "Glückes": "Glück",
    "Glückliche": "glücklich",
    "Glücklichen": "Glückliche",
    "Glücklicheren": "Glücklichere",
    "Glücklichsten": "Glücklichste",
    "Glücklosen": "Glücklose",
    "Glückloseren": "Glücklosere",
    "Glücklosesten": "Glückloseste",
    "Glücks": "Glück",
    "Glücksbringern": "Glücksbringer",
    "Glücksbringers": "Glücksbringer",
    "Glücksbuden": "Glücksbude",
    "Glückseligen": "Glückselige",
    "Glücksrittern": "Glücksritter",
    "Glücksritters": "Glücksritter",
    "Glückssträhnen": "Glückssträhne",
    "Glückstrahlenden": "Glückstrahlende",
    "Glühbirnen": "Glühbirne",
    "Glühenden": "Glühende",
    "Glühenderen": "Glühendere",
    "Glühendsten": "Glühendste",
    "Glühens": "Glühen",
    "Glühlampen": "Glühlampe",
    "Glühweine": "Glühwein",
    "Glühweinen": "Glühwein",
    "Glühweines": "Glühwein",
    "Glühweins": "Glühwein",
    "GmbHs": "GmbH",
    "Gnaden": "Gnade",
    "Gnadenlose": "gnadenlos",
    "Gnadenlosen": "Gnadenlose",
    "Gnadenloseren": "Gnadenlosere",
    "Gnadenlosesten": "Gnadenloseste",
    "Gnadenreichen": "Gnadenreiche",
    "Gnus": "Gnu",
    "Gnädigen": "Gnädige",
    "Gnädigeren": "Gnädigere",
    "Gnädigsten": "Gnädigste",
    "Gockeln": "Gockel",
    "Gockels": "Gockel",
    "Godards": "Godard",
    "Goethes": "Goethe",
    "Goghs": "Gogh",
    "Goldbleche": "Goldblech",
    "Goldblechen": "Goldblech",
    "Goldblechs": "Goldblech",
    "Goldemaillierte": "goldemailliert",
    "Goldemaillierten": "Goldemaillierte",
    "Goldemaillierteren": "Goldemailliertere",
    "Goldenen": "Goldene",
    "Goldeneren": "Goldenere",
    "Goldensten": "Goldenste",
    "Goldfische": "Goldfisch",
    "Goldfischen": "Goldfisch",
    "Goldfischs": "Goldfisch",
    "Goldhähnchens": "Goldhähnchen",
    "Goldige": "goldig",
    "Goldigen": "Goldige",
    "Goldigeren": "Goldigere",
    "Goldigsten": "Goldigste",
    "Goldjungen": "Goldjunge",
    "Goldkäfern": "Goldkäfer",
    "Goldkäfers": "Goldkäfer",
    "Goldrichtige": "goldrichtig",
    "Goldrichtigen": "Goldrichtige",
    "Golds": "Gold",
    "Goldstücke": "Goldstück",
    "Goldstücken": "Goldstück",
    "Goldstücks": "Goldstück",
    "Goldwaren": "Goldware",
    "Golf": "golfen",
    "Golfenden": "Golfende",
    "Golfens": "Golfen",
    "Golfs": "Golf",
    "Gomulkas": "Gomulka",
    "Gondel": "gondeln",
    "Gondeln": "Gondel",
    "Gondelnden": "Gondelnde",
    "Gondelnderen": "Gondelndere",
    "Gondelndsten": "Gondelndste",
    "Gondelns": "Gondeln",
    "Gong": "gongen",
    "Gonge": "gongen",
    "Gongenden": "Gongende",
    "Gongens": "Gongen",
    "Gonges": "Gong",
    "Gongs": "Gong",
    "Gorbatschows": "Gorbatschow",
    "Gordische": "gordisch",
    "Gordischen": "Gordische",
    "Gorillas": "Gorilla",
    "Gorlebens": "Gorleben",
    "Gospels": "Gospel",
    "Gossen": "Gosse",
    "Goten": "Gote",
    "Gotische": "gotisch",
    "Gotischen": "Gotische",
    "Gotte": "Gott",
    "Gottes": "Gott",
    "Gottesfürchtige": "gottesfürchtig",
    "Gottesfürchtigen": "Gottesfürchtige",
    "Gottesfürchtigeren": "Gottesfürchtigere",
    "Gotteslästerlichen": "Gotteslästerliche",
    "Gottesreiche": "Gottesreich",
    "Gottesreichen": "Gottesreich",
    "Gottesreichs": "Gottesreich",
    "Gottfrieds": "Gottfried",
    "Gottgläubige": "gottgläubig",
    "Gottgläubigen": "Gottgläubige",
    "Gottgläubigeren": "Gottgläubigere",
    "Gottgläubigsten": "Gottgläubigste",
    "Gottheiten": "Gottheit",
    "Gottjämmerliche": "gottjämmerlich",
    "Gottjämmerlichen": "Gottjämmerliche",
    "Gottlosen": "Gottlose",
    "Gottloseren": "Gottlosere",
    "Gottlosesten": "Gottloseste",
    "Gotts": "Gott",
    "Goudas": "Gouda",
    "Gouvernanten": "Gouvernante",
    "Gouverneure": "Gouverneur",
    "Gouverneuren": "Gouverneur",
    "Gouverneurs": "Gouverneur",
    "Grab": "graben",
    "Grabe": "graben",
    "Grabenden": "Grabende",
    "Grabenderen": "Grabendere",
    "Grabendsten": "Grabendste",
    "Grabens": "Graben",
    "Grabes": "Grab",
    "Grabmale": "Grabmal",
    "Grabmales": "Grabmal",
    "Grabmäler": "Grabmal",
    "Grabmälern": "Grabmal",
    "Grabs": "Grab",
    "Grabschenden": "Grabschende",
    "Grabschenderen": "Grabschendere",
    "Grabschendsten": "Grabschendste",
    "Grabschens": "Grabschen",
    "Grachten": "Gracht",
    "Grade": "Grad",
    "Graden": "Grad",
    "Grades": "Grad",
    "Gradierenden": "Gradierende",
    "Gradierens": "Gradieren",
    "Gradierte": "gradiert",
    "Gradierten": "Gradierte",
    "Grads": "Grad",
    "Graduelle": "graduell",
    "Graduellen": "Graduelle",
    "Graduierenden": "Graduierende",
    "Graduierens": "Graduieren",
    "Graduierte": "graduiert",
    "Graduierten": "Graduierte",
    "Grafen": "Graf",
    "Graffitis": "Graffiti",
    "Grafiken": "Grafik",
    "Grafschaften": "Grafschaft",
    "Grals": "Gral",
    "Gramerfüllte": "gramerfüllt",
    "Gramerfüllten": "Gramerfüllte",
    "Gramerfüllteren": "Gramerfülltere",
    "Gramerfülltesten": "Gramerfüllteste",
    "Grammatikalischen": "Grammatikalische",
    "Grammatiken": "Grammatik",
    "Grammatikern": "Grammatiker",
    "Grammatikers": "Grammatiker",
    "Grammatische": "grammatisch",
    "Grammatischen": "Grammatische",
    "Gramme": "Gramm",
    "Grammen": "Gramm",
    "Grammes": "Gramm",
    "Grammophone": "Grammophon",
    "Grammophonen": "Grammophon",
    "Grammophons": "Grammophon",
    "Gramms": "Gramm",
    "Gramvollen": "Gramvolle",
    "Gramvolleren": "Gramvollere",
    "Gramvollsten": "Gramvollste",
    "Granaten": "Granate",
    "Granatsplittern": "Granatsplitter",
    "Granatsplitters": "Granatsplitter",
    "Grandeln": "Grandel",
    "Grandiose": "grandios",
    "Grandiosen": "Grandiose",
    "Grandioseren": "Grandiosere",
    "Grandiosesten": "Grandioseste",
    "Grands": "Grand",
    "Granite": "Granit",
    "Graniten": "Granit",
    "Granits": "Granit",
    "Grantige": "grantig",
    "Grantigen": "Grantige",
    "Grantigeren": "Grantigere",
    "Grantigsten": "Grantigste",
    "Grantlern": "Grantler",
    "Grantlers": "Grantler",
    "Granulate": "Granulat",
    "Granulaten": "Granulat",
    "Granulats": "Granulat",
    "Granulite": "Granulit",
    "Granuliten": "Granulit",
    "Granulits": "Granulit",
    "Graphien": "Graphie",
    "Graphiken": "Graphik",
    "Graphikern": "Graphiker",
    "Graphikers": "Graphiker",
    "Graphische": "graphisch",
    "Graphischen": "Graphische",
    "Graphologen": "Graphologe",
    "Graphologische": "graphologisch",
    "Graphologischen": "Graphologische",
    "Grappas": "Grappa",
    "Graptolithen": "Graptolith",
    "Gras": "grasen",
    "Grase": "grasen",
    "Grasenden": "Grasende",
    "Grasens": "Grasen",
    "Grases": "Gras",
    "Grashüpfern": "Grashüpfer",
    "Grashüpfers": "Grashüpfer",
    "Grassierenden": "Grassierende",
    "Grassierenderen": "Grassierendere",
    "Grassierendsten": "Grassierendste",
    "Grassierens": "Grassieren",
    "Grassierte": "grassiert",
    "Grassierten": "Grassierte",
    "Grassierteren": "Grassiertere",
    "Grassiertesten": "Grassierteste",
    "Gratifizierenden": "Gratifizierende",
    "Gratifizierens": "Gratifizieren",
    "Gratifizierte": "gratifiziert",
    "Gratifizierten": "Gratifizierte",
    "Gratinierenden": "Gratinierende",
    "Gratinierenderen": "Gratinierendere",
    "Gratinierendsten": "Gratinierendste",
    "Gratinierens": "Gratinieren",
    "Gratinierte": "gratiniert",
    "Gratinierten": "Gratinierte",
    "Gratulationen": "Gratulation",
    "Gratulierenden": "Gratulierende",
    "Gratulierens": "Gratulieren",
    "Gratulierte": "gratuliert",
    "Gratulierten": "Gratulierte",
    "Grauen": "Graue",
    "Grauenerregende": "grauenerregend",
    "Grauenerregenden": "Grauenerregende",
    "Grauenerregenderen": "Grauenerregendere",
    "Grauenhaften": "Grauenhafte",
    "Grauenhafteren": "Grauenhaftere",
    "Grauenhaftesten": "Grauenhafteste",
    "Grauens": "Grauen",
    "Graueren": "Grauere",
    "Grauesten": "Graueste",
    "Grauhaarigen": "Grauhaarige",
    "Grauhörnchens": "Grauhörnchen",
    "Graulenden": "Graulende",
    "Graulens": "Graulen",
    "Graulichen": "Grauliche",
    "Graulicheren": "Graulichere",
    "Graulichsten": "Graulichste",
    "Graumelierten": "Graumelierte",
    "Graupel": "graupeln",
    "Graupeln": "Graupel",
    "Graupelnden": "Graupelnde",
    "Graupelnderen": "Graupelndere",
    "Graupelndsten": "Graupelndste",
    "Graupelns": "Graupeln",
    "Graupen": "Graupe",
    "Graus": "grausen",
    "Grausame": "grausam",
    "Grausamen": "Grausame",
    "Grausameren": "Grausamere",
    "Grausamsten": "Grausamste",
    "Grauschimmeln": "Grauschimmel",
    "Grauschimmels": "Grauschimmel",
    "Grausenden": "Grausende",
    "Grausens": "Grausen",
    "Grausigen": "Grausige",
    "Grausigeren": "Grausigere",
    "Grausigsten": "Grausigste",
    "Grauzonen": "Grauzone",
    "Gravierende": "gravierend",
    "Gravierenden": "Gravierende",
    "Gravierenderen": "Gravierendere",
    "Gravierendsten": "Gravierendste",
    "Grazilen": "Grazile",
    "Grazileren": "Grazilere",
    "Grazilsten": "Grazilste",
    "Graziösen": "Graziöse",
    "Graziöseren": "Graziösere",
    "Graziösesten": "Graziöseste",
    "Greenpeaces": "Greenpeace",
    "Gregors": "Gregor",
    "Greifbare": "greifbar",
    "Greifbaren": "Greifbare",
    "Greifbareren": "Greifbarere",
    "Greifbarsten": "Greifbarste",
    "Greifenden": "Greifende",
    "Greifens": "Greifen",
    "Greifern": "Greifer",
    "Greifers": "Greifer",
    "Greifswalds": "Greifswald",
    "Greisen": "Greise",
    "Greisenhafte": "greisenhaft",
    "Greisenhaften": "Greisenhafte",
    "Greisenhafteren": "Greisenhaftere",
    "Greisenhaftesten": "Greisenhafteste",
    "Greiseren": "Greisere",
    "Greisesten": "Greiseste",
    "Greisinnen": "Greisin",
    "Grelle": "grell",
    "Grellen": "Grelle",
    "Grelleren": "Grellere",
    "Grellsten": "Grellste",
    "Gremien": "Gremium",
    "Gremiums": "Gremium",
    "Grenadiere": "Grenadier",
    "Grenadieren": "Grenadier",
    "Grenadiers": "Grenadier",
    "Grenzbache": "Grenzbach",
    "Grenzbachs": "Grenzbach",
    "Grenzbahnhofe": "Grenzbahnhof",
    "Grenzbahnhofs": "Grenzbahnhof",
    "Grenzbahnhöfe": "Grenzbahnhof",
    "Grenzbahnhöfen": "Grenzbahnhof",
    "Grenzbäche": "Grenzbach",
    "Grenzbächen": "Grenzbach",
    "Grenze": "grenzen",
    "Grenzen": "Grenze",
    "Grenzenden": "Grenzende",
    "Grenzenlosen": "Grenzenlose",
    "Grenzenloseren": "Grenzenlosere",
    "Grenzenlosesten": "Grenzenloseste",
    "Grenzens": "Grenzen",
    "Grenzern": "Grenzer",
    "Grenzers": "Grenzer",
    "Grenzfalle": "Grenzfall",
    "Grenzfalls": "Grenzfall",
    "Grenzfälle": "Grenzfall",
    "Grenzfällen": "Grenzfall",
    "Grenzgebiete": "Grenzgebiet",
    "Grenzgebieten": "Grenzgebiet",
    "Grenzgebiets": "Grenzgebiet",
    "Grenzgängern": "Grenzgänger",
    "Grenzgängers": "Grenzgänger",
    "Grenzlande": "Grenzland",
    "Grenzlandes": "Grenzland",
    "Grenzlands": "Grenzland",
    "Grenzlehren": "Grenzlehre",
    "Grenzländer": "Grenzland",
    "Grenzländern": "Grenzland",
    "Grenzpostens": "Grenzposten",
    "Grenzpunkte": "Grenzpunkt",
    "Grenzpunkten": "Grenzpunkt",
    "Grenzpunkts": "Grenzpunkt",
    "Grenzsperren": "Grenzsperre",
    "Grenzsteine": "Grenzstein",
    "Grenzsteinen": "Grenzstein",
    "Grenzsteines": "Grenzstein",
    "Grenzsteins": "Grenzstein",
    "Grenzstädte": "Grenzstadt",
    "Grenzstädten": "Grenzstadt",
    "Grenzvertrage": "Grenzvertrag",
    "Grenzvertrags": "Grenzvertrag",
    "Grenzverträge": "Grenzvertrag",
    "Grenzverträgen": "Grenzvertrag",
    "Grenzwachen": "Grenzwache",
    "Grenzwerte": "Grenzwert",
    "Grenzwerten": "Grenzwert",
    "Grenzwerts": "Grenzwert",
    "Grenzzeichens": "Grenzzeichen",
    "Grenzzolls": "Grenzzoll",
    "Grenzübergange": "Grenzübergang",
    "Grenzübergangs": "Grenzübergang",
    "Grenzübergänge": "Grenzübergang",
    "Grenzübergängen": "Grenzübergang",
    "Grenzüberschreitende": "grenzüberschreitend",
    "Grenzüberschreitenden": "Grenzüberschreitende",
    "Greueln": "Greuel",
    "Greuels": "Greuel",
    "Griechen": "Grieche",
    "Griechenlands": "Griechenland",
    "Griechentums": "Griechentum",
    "Griechinnen": "Griechin",
    "Griechische": "griechisch",
    "Griechischen": "Griechische",
    "Griesheimern": "Griesheimer",
    "Griesheimers": "Griesheimer",
    "Griesheims": "Griesheim",
    "Grießbreie": "Grießbrei",
    "Grießbreien": "Grießbrei",
    "Grießbreis": "Grießbrei",
    "Griff": "greifen",
    "Griffbereiten": "Griffbereite",
    "Griffe": "Griff",
    "Griffeln": "Griffel",
    "Griffels": "Griffel",
    "Griffen": "Griff",
    "Griffes": "Griff",
    "Griffigen": "Griffige",
    "Griffigeren": "Griffigere",
    "Griffigsten": "Griffigste",
    "Griffs": "Griff",
    "Grill": "grillen",
    "Grille": "grillen",
    "Grillen": "Grille",
    "Grillenden": "Grillende",
    "Grillens": "Grillen",
    "Grilles": "Grill",
    "Grills": "Grill",
    "Grimassen": "Grimasse",
    "Grimmige": "grimmig",
    "Grimmigen": "Grimmige",
    "Grimmigeren": "Grimmigere",
    "Grimmigsten": "Grimmigste",
    "Grimms": "Grimm",
    "Grinsenden": "Grinsende",
    "Grinsenderen": "Grinsendere",
    "Grinsendsten": "Grinsendste",
    "Grinsens": "Grinsen",
    "Grippalen": "Grippale",
    "Grippen": "Grippe",
    "Grips": "Grip",
    "Grobe": "grob",
    "Groben": "Grobe",
    "Grobgewichte": "Grobgewicht",
    "Grobgewichten": "Grobgewicht",
    "Grobgewichts": "Grobgewicht",
    "Grobheiten": "Grobheit",
    "Grobiane": "Grobian",
    "Grobianen": "Grobian",
    "Grobians": "Grobian",
    "Grobkörnige": "grobkörnig",
    "Grobkörnigen": "Grobkörnige",
    "Grobkörnigeren": "Grobkörnigere",
    "Grobkörnigsten": "Grobkörnigste",
    "Grobschlächtigen": "Grobschlächtige",
    "Grobschlächtigeren": "Grobschlächtigere",
    "Grogs": "Grog",
    "Grolls": "Groll",
    "Gronemanns": "Gronemann",
    "Groschens": "Groschen",
    "Grotesken": "Groteske",
    "Groteskeren": "Groteskere",
    "Groteskesten": "Groteskeste",
    "Grotten": "Grotte",
    "Großabnehmern": "Großabnehmer",
    "Großabnehmers": "Großabnehmer",
    "Großaktionäre": "Großaktionär",
    "Großaktionären": "Großaktionär",
    "Großaktionärs": "Großaktionär",
    "Großartige": "großartig",
    "Großartigen": "Großartige",
    "Großartigeren": "Großartigere",
    "Großartigsten": "Großartigste",
    "Großaufnahmen": "Großaufnahme",
    "Großauheims": "Großauheim",
    "Großbaueren": "Großbauer",
    "Großbetriebe": "Großbetrieb",
    "Großbetrieben": "Großbetrieb",
    "Großbetriebs": "Großbetrieb",
    "Großbritanniens": "Großbritannien",
    "Großbuchstaben": "Großbuchstabe",
    "Großbürgertums": "Großbürgertum",
    "Großdeutsche": "großdeutsch",
    "Großdeutschen": "Großdeutsche",
    "Großeinkaufe": "Großeinkauf",
    "Großeinkaufs": "Großeinkauf",
    "Großeinkäufe": "Großeinkauf",
    "Großeinkäufen": "Großeinkauf",
    "Großfahndungen": "Großfahndung",
    "Großfeuern": "Großfeuer",
    "Großfeuers": "Großfeuer",
    "Großflächige": "großflächig",
    "Großflächigen": "Großflächige",
    "Großfürsten": "Großfürst",
    "Großfürstinnen": "Großfürstin",
    "Großhandels": "Großhandel",
    "Großherren": "Großherr",
    "Großherzige": "großherzig",
    "Großherzigen": "Großherzige",
    "Großherzigeren": "Großherzigere",
    "Großherzigsten": "Großherzigste",
    "Großherzoginnen": "Großherzogin",
    "Großherzogs": "Großherzog",
    "Großhändlern": "Großhändler",
    "Großhändlers": "Großhändler",
    "Großinquisitore": "Großinquisitor",
    "Großinquisitoren": "Großinquisitor",
    "Großinquisitors": "Großinquisitor",
    "Großkalibrige": "großkalibrig",
    "Großkalibrigen": "Großkalibrige",
    "Großkampftage": "Großkampftag",
    "Großkampftagen": "Großkampftag",
    "Großkampftags": "Großkampftag",
    "Großkanzlern": "Großkanzler",
    "Großkanzlers": "Großkanzler",
    "Großkapitals": "Großkapital",
    "Großkotzige": "großkotzig",
    "Großkotzigen": "Großkotzige",
    "Großkotzigeren": "Großkotzigere",
    "Großkotzigsten": "Großkotzigste",
    "Großkrotzenburgs": "Großkrotzenburg",
    "Großkunden": "Großkunde",
    "Großmamas": "Großmama",
    "Großmarkte": "Großmarkt",
    "Großmarktes": "Großmarkt",
    "Großmarkts": "Großmarkt",
    "Großmaste": "Großmast",
    "Großmasten": "Großmast",
    "Großmasts": "Großmast",
    "Großmaule": "Großmaul",
    "Großmauls": "Großmaul",
    "Großmeistern": "Großmeister",
    "Großmeisters": "Großmeister",
    "Großmuftis": "Großmufti",
    "Großmächte": "Großmacht",
    "Großmächten": "Großmacht",
    "Großmächtige": "großmächtig",
    "Großmächtigen": "Großmächtige",
    "Großmägde": "Großmagd",
    "Großmägden": "Großmagd",
    "Großmärkte": "Großmarkt",
    "Großmärkten": "Großmarkt",
    "Großmäuler": "Großmaul",
    "Großmäulern": "Großmaul",
    "Großmäulige": "großmäulig",
    "Großmäuligen": "Großmäulige",
    "Großmäuligeren": "Großmäuligere",
    "Großmäuligsten": "Großmäuligste",
    "Großmütige": "großmütig",
    "Großmütigen": "Großmütige",
    "Großmütigeren": "Großmütigere",
    "Großmütigsten": "Großmütigste",
    "Großmütter": "Großmutter",
    "Großmütterliche": "großmütterlich",
    "Großmütterlichen": "Großmütterliche",
    "Großmüttern": "Großmutter",
    "Großneffen": "Großneffe",
    "Großnichten": "Großnichte",
    "Großonkeln": "Großonkel",
    "Großonkels": "Großonkel",
    "Großpapas": "Großpapa",
    "Großraumbüros": "Großraumbüro",
    "Großraume": "Großraum",
    "Großraumes": "Großraum",
    "Großraums": "Großraum",
    "Großraumwagens": "Großraumwagen",
    "Großreinemachens": "Großreinemachen",
    "Großreinigungen": "Großreinigung",
    "Großräume": "Großraum",
    "Großräumen": "Großraum",
    "Großschnauzen": "Großschnauze",
    "Großschnauzige": "großschnauzig",
    "Großschnauzigen": "Großschnauzige",
    "Großschnauzigeren": "Großschnauzigere",
    "Großschnauzigsten": "Großschnauzigste",
    "Großsegeln": "Großsegel",
    "Großsegels": "Großsegel",
    "Großserien": "Großserie",
    "Großspurige": "großspurig",
    "Großspurigen": "Großspurige",
    "Großspurigeren": "Großspurigere",
    "Großspurigsten": "Großspurigste",
    "Großstädte": "Großstadt",
    "Großstädten": "Großstadt",
    "Großstädtern": "Großstädter",
    "Großstädters": "Großstädter",
    "Großteile": "Großteil",
    "Großteilen": "Großteil",
    "Großteils": "Großteil",
    "Großunternehmens": "Großunternehmen",
    "Großunternehmern": "Großunternehmer",
    "Großunternehmers": "Großunternehmer",
    "Großvaters": "Großvater",
    "Großverkaufe": "Großverkauf",
    "Großverkaufs": "Großverkauf",
    "Großverkäufe": "Großverkauf",
    "Großverkäufen": "Großverkauf",
    "Großviehs": "Großvieh",
    "Großväter": "Großvater",
    "Großväterliche": "großväterlich",
    "Großväterlichen": "Großväterliche",
    "Großvätern": "Großvater",
    "Großwallstadts": "Großwallstadt",
    "Großzügige": "großzügig",
    "Großzügigen": "Großzügige",
    "Großzügigeren": "Großzügigere",
    "Großzügigkeiten": "Großzügigkeit",
    "Großzügigste": "großzügig",
    "Großzügigsten": "Großzügigste",
    "Gruben": "Grube",
    "Grummelnden": "Grummelnde",
    "Grummelnderen": "Grummelndere",
    "Grummelndsten": "Grummelndste",
    "Grummelns": "Grummeln",
    "Grundanstriche": "Grundanstrich",
    "Grundanstrichen": "Grundanstrich",
    "Grundanstrichs": "Grundanstrich",
    "Grundanständige": "grundanständig",
    "Grundanständigen": "Grundanständige",
    "Grundanständigeren": "Grundanständigere",
    "Grundbedingungen": "Grundbedingung",
    "Grundbegriffe": "Grundbegriff",
    "Grundbegriffen": "Grundbegriff",
    "Grundbegriffs": "Grundbegriff",
    "Grundbestandteile": "Grundbestandteil",
    "Grundbestandteilen": "Grundbestandteil",
    "Grundbestandteils": "Grundbestandteil",
    "Grunde": "Grund",
    "Grundehrlichen": "Grundehrliche",
    "Grundehrlicheren": "Grundehrlichere",
    "Grundehrlichsten": "Grundehrlichste",
    "Grundeinheiten": "Grundeinheit",
    "Grundes": "Grund",
    "Grundfalschen": "Grundfalsche",
    "Grundformen": "Grundform",
    "Grundgütige": "grundgütig",
    "Grundgütigen": "Grundgütige",
    "Grundhäßlichen": "Grundhäßliche",
    "Grundierfarben": "Grundierfarbe",
    "Grundirrtume": "Grundirrtum",
    "Grundirrtumes": "Grundirrtum",
    "Grundirrtums": "Grundirrtum",
    "Grundirrtümer": "Grundirrtum",
    "Grundirrtümern": "Grundirrtum",
    "Grundlagen": "Grundlage",
    "Grundlegende": "grundlegend",
    "Grundlegenden": "Grundlegende",
    "Grundlegenderen": "Grundlegendere",
    "Grundlegendsten": "Grundlegendste",
    "Grundlosen": "Grundlose",
    "Grundnormen": "Grundnorm",
    "Grundrechenarten": "Grundrechenart",
    "Grundregeln": "Grundregel",
    "Grunds": "Grund",
    "Grundsatze": "Grundsatz",
    "Grundsatzes": "Grundsatz",
    "Grundschlechten": "Grundschlechte",
    "Grundsteine": "Grundstein",
    "Grundsteinen": "Grundstein",
    "Grundsteins": "Grundstein",
    "Grundstudiums": "Grundstudium",
    "Grundstücke": "Grundstück",
    "Grundstücken": "Grundstück",
    "Grundstückes": "Grundstück",
    "Grundstücks": "Grundstück",
    "Grundsätze": "Grundsatz",
    "Grundsätzen": "Grundsatz",
    "Grundsätzliche": "grundsätzlich",
    "Grundsätzlichen": "Grundsätzliche",
    "Grundverkehrte": "grundverkehrt",
    "Grundverkehrten": "Grundverkehrte",
    "Grundverschiedenen": "Grundverschiedene",
    "Grundworte": "Grundwort",
    "Grundwortes": "Grundwort",
    "Grundworts": "Grundwort",
    "Grundwörter": "Grundwort",
    "Grundwörtern": "Grundwort",
    "Grunzenden": "Grunzende",
    "Grunzenderen": "Grunzendere",
    "Grunzendsten": "Grunzendste",
    "Grunzens": "Grunzen",
    "Gruppen": "Gruppe",
    "Gruppendynamische": "gruppendynamisch",
    "Gruppendynamischen": "Gruppendynamische",
    "Gruppenspezifischen": "Gruppenspezifische",
    "Gruppierenden": "Gruppierende",
    "Gruppierens": "Gruppieren",
    "Gruppierte": "gruppiert",
    "Gruppierten": "Gruppierte",
    "Gruppierungen": "Gruppierung",
    "Gruseligen": "Gruselige",
    "Gruseligeren": "Gruseligere",
    "Gruseligsten": "Gruseligste",
    "Gruselnden": "Gruselnde",
    "Gruselnderen": "Gruselndere",
    "Gruselndsten": "Gruselndste",
    "Gruselns": "Gruseln",
    "Gruße": "Gruß",
    "Grußes": "Gruß",
    "Gräben": "Graben",
    "Gräbern": "Gräber",
    "Gräbers": "Gräber",
    "Gräferohdes": "Gräferohde",
    "Grämenden": "Grämende",
    "Grämenderen": "Grämendere",
    "Grämendsten": "Grämendste",
    "Grämens": "Grämen",
    "Grämlichen": "Grämliche",
    "Gräschens": "Gräschen",
    "Gräser": "Gras",
    "Gräsern": "Gras",
    "Gräten": "Gräte",
    "Grätschen": "Grätsche",
    "Grätschenden": "Grätschende",
    "Grätschenderen": "Grätschendere",
    "Grätschendsten": "Grätschendste",
    "Grätschens": "Grätschen",
    "Gräuliche": "gräulich",
    "Gräulichen": "Gräuliche",
    "Gräulichere": "gräulich",
    "Gräulicheren": "Gräulichere",
    "Gräulichste": "gräulich",
    "Gräulichsten": "Gräulichste",
    "Gräßlichen": "Gräßliche",
    "Gräßlicheren": "Gräßlichere",
    "Gräßlichsten": "Gräßlichste",
    "Gröberen": "Gröbere",
    "Gröbsten": "Gröbste",
    "Grölenden": "Grölende",
    "Grölenderen": "Grölendere",
    "Grölendsten": "Grölendste",
    "Grölens": "Grölen",
    "Grönlands": "Grönland",
    "Grönländern": "Grönländer",
    "Grönländers": "Grönländer",
    "Größen": "Größe",
    "Größenwahns": "Größenwahn",
    "Größenwahnsinnige": "größenwahnsinnig",
    "Größenwahnsinnigen": "Größenwahnsinnige",
    "Größenwahnsinnigeren": "Größenwahnsinnigere",
    "Größtmöglichen": "Größtmögliche",
    "Größtmöglicheren": "Größtmöglichere",
    "Größtmöglichsten": "Größtmöglichste",
    "Grübelnden": "Grübelnde",
    "Grübelnderen": "Grübelndere",
    "Grübelndsten": "Grübelndste",
    "Grübelns": "Grübeln",
    "Grüblerischen": "Grüblerische",
    "Grüblerischeren": "Grüblerischere",
    "Grüblerischsten": "Grüblerischste",
    "Grünanlagen": "Grünanlage",
    "Gründe": "gründen",
    "Gründen": "Grund",
    "Gründenden": "Gründende",
    "Gründens": "Gründen",
    "Gründern": "Gründer",
    "Gründers": "Gründer",
    "Gründlichen": "Gründliche",
    "Gründlicheren": "Gründlichere",
    "Gründlichsten": "Gründlichste",
    "Gründonnerstage": "Gründonnerstag",
    "Gründonnerstagen": "Gründonnerstag",
    "Gründonnerstags": "Gründonnerstag",
    "Gründungen": "Gründung",
    "Grüne": "grün",
    "Grünen": "Grüne",
    "Grüneren": "Grünere",
    "Grünflächen": "Grünfläche",
    "Grünliche": "grünlich",
    "Grünlichen": "Grünliche",
    "Grüns": "Grün",
    "Grünste": "grün",
    "Grünsten": "Grünste",
    "Grüppchens": "Grüppchen",
    "Grützen": "Grütze",
    "Grüße": "grüßen",
    "Grüßen": "Gruß",
    "Grüßenden": "Grüßende",
    "Grüßens": "Grüßen",
    "Guatemalas": "Guatemala",
    "Guckenden": "Guckende",
    "Guckens": "Gucken",
    "Guckfenstern": "Guckfenster",
    "Guckfensters": "Guckfenster",
    "Guckkastens": "Guckkasten",
    "Guckkästen": "Guckkasten",
    "Guckloche": "Guckloch",
    "Guckloches": "Guckloch",
    "Gucklochs": "Guckloch",
    "Gucklöcher": "Guckloch",
    "Gucklöchern": "Guckloch",
    "Gudruns": "Gudrun",
    "Guerillas": "Guerilla",
    "Guidos": "Guido",
    "Guineas": "Guinea",
    "Gulaschkanonen": "Gulaschkanone",
    "Gulaschs": "Gulasch",
    "Guldens": "Gulden",
    "Gummierenden": "Gummierende",
    "Gummierens": "Gummieren",
    "Gummierte": "gummiert",
    "Gummierten": "Gummierte",
    "Gummierteren": "Gummiertere",
    "Gummiertesten": "Gummierteste",
    "Gummierungen": "Gummierung",
    "Gummis": "Gummi",
    "Gunsten": "Gunst",
    "Gurgelnden": "Gurgelnde",
    "Gurgelns": "Gurgeln",
    "Gurken": "Gurke",
    "Gurrenden": "Gurrende",
    "Gurrens": "Gurren",
    "Gurte": "gurten",
    "Gurten": "Gurt",
    "Gurtenden": "Gurtende",
    "Gurtens": "Gurten",
    "Gurtes": "Gurt",
    "Gurts": "Gurt",
    "Gusse": "Guß",
    "Gusses": "Guß",
    "Gustavs": "Gustav",
    "Gutachtens": "Gutachten",
    "Gutachtern": "Gutachter",
    "Gutachters": "Gutachter",
    "Gutartige": "gutartig",
    "Gutartigen": "Gutartige",
    "Gutbürgerlichen": "Gutbürgerliche",
    "Gutenbergs": "Gutenberg",
    "Gutes": "gut",
    "Gutgeheißenen": "Gutgeheißene",
    "Gutgeheißeneren": "Gutgeheißenere",
    "Gutgeheißensten": "Gutgeheißenste",
    "Gutgelaunten": "Gutgelaunte",
    "Gutgemeinten": "Gutgemeinte",
    "Gutgläubigen": "Gutgläubige",
    "Gutgläubigeren": "Gutgläubigere",
    "Gutgläubigsten": "Gutgläubigste",
    "Guthabens": "Guthaben",
    "Gutheißenden": "Gutheißende",
    "Gutheißenderen": "Gutheißendere",
    "Gutheißendsten": "Gutheißendste",
    "Gutheißens": "Gutheißen",
    "Gutmütigen": "Gutmütige",
    "Gutmütigeren": "Gutmütigere",
    "Gutmütigkeiten": "Gutmütigkeit",
    "Gutmütigste": "gutmütig",
    "Gutmütigsten": "Gutmütigste",
    "Guts": "Gut",
    "Gutscheine": "Gutschein",
    "Gutscheinen": "Gutschein",
    "Gutscheins": "Gutschein",
    "Gutsituierte": "gutsituiert",
    "Gutsituierten": "Gutsituierte",
    "Gutsituierteren": "Gutsituiertere",
    "Gutsituiertesten": "Gutsituierteste",
    "Gutwilligen": "Gutwillige",
    "Gußeiserne": "gußeisern",
    "Gußeisernen": "Gußeiserne",
    "Gymnasialen": "Gymnasiale",
    "Gymnasiallehrern": "Gymnasiallehrer",
    "Gymnasiallehrers": "Gymnasiallehrer",
    "Gymnasien": "Gymnasium",
    "Gymnasiums": "Gymnasium",
    "Gymnastiken": "Gymnastik",
    "Gynäkologische": "gynäkologisch",
    "Gynäkologischen": "Gynäkologische",
    "Gysis": "Gysi",
    "Gäbelchens": "Gäbelchen",
    "Gähnenden": "Gähnende",
    "Gähnenderen": "Gähnendere",
    "Gähnendsten": "Gähnendste",
    "Gähnens": "Gähnen",
    "Gänge": "Gang",
    "Gängelnden": "Gängelnde",
    "Gängelnderen": "Gängelndere",
    "Gängelndsten": "Gängelndste",
    "Gängelns": "Gängeln",
    "Gängen": "Gang",
    "Gängige": "gängig",
    "Gängigen": "Gängige",
    "Gängigeren": "Gängigere",
    "Gängigsten": "Gängigste",
    "Gänschens": "Gänschen",
    "Gänse": "Gans",
    "Gänseblümchens": "Gänseblümchen",
    "Gänsefüßchens": "Gänsefüßchen",
    "Gänsen": "Gans",
    "Gänzlichen": "Gänzliche",
    "Gärende": "gärend",
    "Gärenden": "Gärende",
    "Gärendere": "gärend",
    "Gärenderen": "Gärendere",
    "Gärendste": "gärend",
    "Gärendsten": "Gärendste",
    "Gärens": "Gären",
    "Gärtchens": "Gärtchen",
    "Gärten": "Garten",
    "Gärtner": "gärtnern",
    "Gärtnereien": "Gärtnerei",
    "Gärtnerinnen": "Gärtnerin",
    "Gärtnern": "Gärtner",
    "Gärtnernden": "Gärtnernde",
    "Gärtnerns": "Gärtnern",
    "Gärtners": "Gärtner",
    "Gärungen": "Gärung",
    "Gäste": "Gast",
    "Gästen": "Gast",
    "Gäule": "Gaul",
    "Gäulen": "Gaul",
    "Gönnenden": "Gönnende",
    "Gönnens": "Gönnen",
    "Gönnerhafte": "gönnerhaft",
    "Gönnerhaften": "Gönnerhafte",
    "Gönnerhafteren": "Gönnerhaftere",
    "Gönnerhaftesten": "Gönnerhafteste",
    "Gönnern": "Gönner",
    "Gönners": "Gönner",
    "Göre": "Gör",
    "Gören": "Göre",
    "Görs": "Gör",
    "Götter": "Gott",
    "Göttern": "Gott",
    "Göttingens": "Göttingen",
    "Göttlichen": "Göttliche",
    "Göttlicheren": "Göttlichere",
    "Göttlichsten": "Göttlichste",
    "Götzen": "Götze",
    "Götzenbilde": "Götzenbild",
    "Götzenbilder": "Götzenbild",
    "Götzenbildern": "Götzenbild",
    "Götzenbildes": "Götzenbild",
    "Götzenbilds": "Götzenbild",
    "Güldene": "gülden",
    "Güldenen": "Güldene",
    "Gültige": "gültig",
    "Gültigen": "Gültige",
    "Gültigkeiten": "Gültigkeit",
    "Günstige": "günstig",
    "Günstigen": "Günstige",
    "Günstigeren": "Günstigere",
    "Günstigsten": "Günstigste",
    "Günters": "Günter",
    "Günthers": "Günther",
    "Gürteln": "Gürtel",
    "Gürtels": "Gürtel",
    "Güsse": "Guß",
    "Güssen": "Guß",
    "Güter": "Gut",
    "Gütern": "Gut",
    "Gütetermine": "Gütetermin",
    "Güteterminen": "Gütetermin",
    "Gütetermins": "Gütetermin",
    "Gütigen": "Gütige",
    "Gütigeren": "Gütigere",
    "Gütigsten": "Gütigste",
    "Gütlichen": "Gütliche",
    "Haar": "haaren",
    "Haare": "haaren",
    "Haaren": "Haar",
    "Haarenden": "Haarende",
    "Haarenderen": "Haarendere",
    "Haarendsten": "Haarendste",
    "Haarens": "Haaren",
    "Haarentfernern": "Haarentferner",
    "Haarentferners": "Haarentferner",
    "Haarfestigern": "Haarfestiger",
    "Haarfestigers": "Haarfestiger",
    "Haargenaue": "haargenau",
    "Haargenauen": "Haargenaue",
    "Haarigen": "Haarige",
    "Haarigeren": "Haarigere",
    "Haarigsten": "Haarigste",
    "Haarlosen": "Haarlose",
    "Haarloseren": "Haarlosere",
    "Haarlosesten": "Haarloseste",
    "Haars": "Haar",
    "Haarscharfe": "haarscharf",
    "Haarscharfen": "Haarscharfe",
    "Haarsträubenden": "Haarsträubende",
    "Haases": "Haase",
    "Habe": "haben",
    "Habenden": "Habende",
    "Habens": "Haben",
    "Habgierigen": "Habgierige",
    "Habgierigeren": "Habgierigere",
    "Habgierigsten": "Habgierigste",
    "Habichte": "Habicht",
    "Habichten": "Habicht",
    "Habichtes": "Habicht",
    "Habichts": "Habicht",
    "Habilitanden": "Habilitand",
    "Habilitationen": "Habilitation",
    "Habilitierenden": "Habilitierende",
    "Habilitierens": "Habilitieren",
    "Habilitierte": "habilitiert",
    "Habilitierten": "Habilitierte",
    "Habseligkeiten": "Habseligkeit",
    "Habsüchtige": "habsüchtig",
    "Habsüchtigen": "Habsüchtige",
    "Habsüchtigeren": "Habsüchtigere",
    "Habsüchtigsten": "Habsüchtigste",
    "Hacken": "Hacke",
    "Hackenden": "Hackende",
    "Hackens": "Hacken",
    "Hackfleische": "Hackfleisch",
    "Hackfleisches": "Hackfleisch",
    "Hackfleischs": "Hackfleisch",
    "Hackordnungen": "Hackordnung",
    "Hadernden": "Hadernde",
    "Hadernderen": "Haderndere",
    "Haderndsten": "Haderndste",
    "Haderns": "Hadern",
    "Hafens": "Hafen",
    "Hafers": "Hafer",
    "Haftbare": "haftbar",
    "Haftbaren": "Haftbare",
    "Haftenbleibenden": "Haftenbleibende",
    "Haftenbleibens": "Haftenbleiben",
    "Haftenden": "Haftende",
    "Haftenderen": "Haftendere",
    "Haftendsten": "Haftendste",
    "Haftengebliebenen": "Haftengebliebene",
    "Haftens": "Haften",
    "Haftfähigen": "Haftfähige",
    "Haftfähigeren": "Haftfähigere",
    "Haftfähigsten": "Haftfähigste",
    "Haftmitteln": "Haftmittel",
    "Haftmittels": "Haftmittel",
    "Haftpflichtige": "haftpflichtig",
    "Haftpflichtigen": "Haftpflichtige",
    "Haftunfähigen": "Haftunfähige",
    "Haftunfähigeren": "Haftunfähigere",
    "Haftunfähigsten": "Haftunfähigste",
    "Haftungen": "Haftung",
    "Hagebutten": "Hagebutte",
    "Hagel": "hageln",
    "Hageln": "Hagel",
    "Hagelnden": "Hagelnde",
    "Hagelns": "Hageln",
    "Hagels": "Hagel",
    "Hagens": "Hagen",
    "Hagere": "hager",
    "Hageren": "Hagere",
    "Hagereren": "Hagerere",
    "Hagersten": "Hagerste",
    "Hahne": "Hahn",
    "Hahnengeschreis": "Hahnengeschrei",
    "Hahnes": "Hahn",
    "Hahns": "Hahn",
    "Haie": "Hai",
    "Haien": "Hai",
    "Haies": "Hai",
    "Hainstadts": "Hainstadt",
    "Hais": "Hai",
    "Haitis": "Haiti",
    "Hakenden": "Hakende",
    "Hakens": "Haken",
    "Halbaffen": "Halbaffe",
    "Halbautomaten": "Halbautomat",
    "Halbautomatische": "halbautomatisch",
    "Halbautomatischen": "Halbautomatische",
    "Halbbilde": "Halbbild",
    "Halbbilder": "Halbbild",
    "Halbbildern": "Halbbild",
    "Halbbildes": "Halbbild",
    "Halbbilds": "Halbbild",
    "Halbbruders": "Halbbruder",
    "Halbbrüder": "Halbbruder",
    "Halbbrüdern": "Halbbruder",
    "Halbdrehungen": "Halbdrehung",
    "Halbe": "halb",
    "Halben": "Halbe",
    "Halbfabrikate": "Halbfabrikat",
    "Halbfabrikaten": "Halbfabrikat",
    "Halbfabrikats": "Halbfabrikat",
    "Halbfertige": "halbfertig",
    "Halbfertigen": "Halbfertige",
    "Halbfetten": "Halbfette",
    "Halbfinalen": "Halbfinale",
    "Halbfinales": "Halbfinale",
    "Halbgotte": "Halbgott",
    "Halbgottes": "Halbgott",
    "Halbgotts": "Halbgott",
    "Halbgötter": "Halbgott",
    "Halbgöttern": "Halbgott",
    "Halbherzige": "halbherzig",
    "Halbherzigen": "Halbherzige",
    "Halbherzigeren": "Halbherzigere",
    "Halbherzigsten": "Halbherzigste",
    "Halbierenden": "Halbierende",
    "Halbierens": "Halbieren",
    "Halbierte": "halbiert",
    "Halbierten": "Halbierte",
    "Halbierungen": "Halbierung",
    "Halbinseln": "Halbinsel",
    "Halbjahre": "Halbjahr",
    "Halbjahren": "Halbjahr",
    "Halbjahres": "Halbjahr",
    "Halbjahrs": "Halbjahr",
    "Halbjährige": "halbjährig",
    "Halbjährigen": "Halbjährige",
    "Halbjährlichen": "Halbjährliche",
    "Halbkreise": "Halbkreis",
    "Halbkreisen": "Halbkreis",
    "Halbkreises": "Halbkreis",
    "Halbkristalle": "Halbkristall",
    "Halbkristallen": "Halbkristall",
    "Halbkristalls": "Halbkristall",
    "Halbkugelförmige": "halbkugelförmig",
    "Halbkugelförmigen": "Halbkugelförmige",
    "Halbkugeln": "Halbkugel",
    "Halbkuppeln": "Halbkuppel",
    "Halbleinens": "Halbleinen",
    "Halbleitern": "Halbleiter",
    "Halbleiters": "Halbleiter",
    "Halblichte": "Halblicht",
    "Halblichtes": "Halblicht",
    "Halblichts": "Halblicht",
    "Halbmenschen": "Halbmensch",
    "Halbmonatsschriften": "Halbmonatsschrift",
    "Halbmonde": "Halbmond",
    "Halbmonden": "Halbmond",
    "Halbmonds": "Halbmond",
    "Halbnackte": "halbnackt",
    "Halbnackten": "Halbnackte",
    "Halbparasiten": "Halbparasit",
    "Halbrunds": "Halbrund",
    "Halbschattens": "Halbschatten",
    "Halbschlafe": "Halbschlaf",
    "Halbschlafes": "Halbschlaf",
    "Halbschlafs": "Halbschlaf",
    "Halbschnäblern": "Halbschnäbler",
    "Halbschnäblers": "Halbschnäbler",
    "Halbschuhe": "Halbschuh",
    "Halbschuhen": "Halbschuh",
    "Halbschuhs": "Halbschuh",
    "Halbschwergewichte": "Halbschwergewicht",
    "Halbschwergewichten": "Halbschwergewicht",
    "Halbschwergewichtlern": "Halbschwergewichtler",
    "Halbschwergewichtlers": "Halbschwergewichtler",
    "Halbschwergewichts": "Halbschwergewicht",
    "Halbschwestern": "Halbschwester",
    "Halbstarken": "Halbstarke",
    "Halbstiefeln": "Halbstiefel",
    "Halbstiefels": "Halbstiefel",
    "Halbstündige": "halbstündig",
    "Halbstündigen": "Halbstündige",
    "Halbtagskräfte": "Halbtagskraft",
    "Halbtagskräften": "Halbtagskraft",
    "Halbtone": "Halbton",
    "Halbtons": "Halbton",
    "Halbtägigen": "Halbtägige",
    "Halbtöne": "Halbton",
    "Halbtönen": "Halbton",
    "Halbwahrheiten": "Halbwahrheit",
    "Halbwertszeiten": "Halbwertszeit",
    "Halbwissens": "Halbwissen",
    "Halbzeiten": "Halbzeit",
    "Halden": "Halde",
    "Halfter": "halftern",
    "Halftern": "Halfter",
    "Halfternden": "Halfternde",
    "Halfterns": "Halftern",
    "Halfters": "Halfter",
    "Hall": "hallen",
    "Halle": "hallen",
    "Hallelujas": "Halleluja",
    "Hallen": "Halle",
    "Hallenden": "Hallende",
    "Hallenderen": "Hallendere",
    "Hallendsten": "Hallendste",
    "Hallens": "Hallen",
    "Halles": "Halle",
    "Hallos": "Hallo",
    "Halls": "Hall",
    "Halluzinationen": "Halluzination",
    "Halluziniere": "halluzinieren",
    "Halluzinierenden": "Halluzinierende",
    "Halluzinierenderen": "Halluzinierendere",
    "Halluzinierens": "Halluzinieren",
    "Halluzinierte": "halluziniert",
    "Halluzinierten": "Halluzinierte",
    "Halluzinogene": "Halluzinogen",
    "Halluzinogenen": "Halluzinogen",
    "Halluzinogens": "Halluzinogen",
    "Halme": "Halm",
    "Halmen": "Halm",
    "Halmes": "Halm",
    "Halms": "Halm",
    "Halogene": "Halogen",
    "Halogenen": "Halogene",
    "Halogenlampen": "Halogenlampe",
    "Halogens": "Halogen",
    "Halone": "Halon",
    "Halonen": "Halon",
    "Halons": "Halon",
    "Hals": "halsen",
    "Halsabschneidern": "Halsabschneider",
    "Halsabschneiders": "Halsabschneider",
    "Halsbrecherische": "halsbrecherisch",
    "Halsbrecherischen": "Halsbrecherische",
    "Halsbrecherischeren": "Halsbrecherischere",
    "Halse": "halsen",
    "Halsenden": "Halsende",
    "Halsens": "Halsen",
    "Halses": "Hals",
    "Halsfernen": "Halsferne",
    "Halsstarrige": "halsstarrig",
    "Halsstarrigen": "Halsstarrige",
    "Halsstarrigeren": "Halsstarrigere",
    "Halsstarrigsten": "Halsstarrigste",
    "Halswendern": "Halswender",
    "Halswenders": "Halswender",
    "Halt": "halten",
    "Haltbaren": "Haltbare",
    "Haltbareren": "Haltbarere",
    "Haltbarsten": "Haltbarste",
    "Halte": "halten",
    "Halten": "Halt",
    "Haltenden": "Haltende",
    "Haltens": "Halten",
    "Haltepunkte": "Haltepunkt",
    "Haltepunkten": "Haltepunkt",
    "Haltepunkts": "Haltepunkt",
    "Haltern": "Halter",
    "Halters": "Halter",
    "Haltes": "Halt",
    "Haltestellen": "Haltestelle",
    "Haltgemachten": "Haltgemachte",
    "Haltlosen": "Haltlose",
    "Haltloseren": "Haltlosere",
    "Haltlosesten": "Haltloseste",
    "Haltmachenden": "Haltmachende",
    "Haltmachens": "Haltmachen",
    "Halts": "Halt",
    "Haltungen": "Haltung",
    "Hamburgern": "Hamburger",
    "Hamburgers": "Hamburger",
    "Hamburgs": "Hamburg",
    "Hammeln": "Hammel",
    "Hammels": "Hammel",
    "Hammers": "Hammer",
    "Hammersbachs": "Hammersbach",
    "Hampel": "hampeln",
    "Hampelmanne": "Hampelmann",
    "Hampelmannes": "Hampelmann",
    "Hampelmanns": "Hampelmann",
    "Hampelmänner": "Hampelmann",
    "Hampelmännern": "Hampelmann",
    "Hampelnden": "Hampelnde",
    "Hampelns": "Hampeln",
    "Hampels": "Hampel",
    "Hamster": "hamstern",
    "Hamstern": "Hamster",
    "Hamsternden": "Hamsternde",
    "Hamsternderen": "Hamsterndere",
    "Hamsterndsten": "Hamsterndste",
    "Hamsterns": "Hamstern",
    "Hamsters": "Hamster",
    "Hanaus": "Hanau",
    "Handapparate": "Handapparat",
    "Handapparaten": "Handapparat",
    "Handapparats": "Handapparat",
    "Handarbeiten": "Handarbeit",
    "Handarbeitern": "Handarbeiter",
    "Handarbeiters": "Handarbeiter",
    "Handauflegens": "Handauflegen",
    "Handballe": "Handball",
    "Handballens": "Handballen",
    "Handballern": "Handballer",
    "Handballers": "Handballer",
    "Handballes": "Handball",
    "Handballs": "Handball",
    "Handbreite": "handbreit",
    "Handbreiten": "Handbreite",
    "Handel": "handeln",
    "Handelnden": "Handelnde",
    "Handelns": "Handeln",
    "Handels": "Handel",
    "Handelsfähige": "handelsfähig",
    "Handelsfähigen": "Handelsfähige",
    "Handelsfähigeren": "Handelsfähigere",
    "Handelsfähigsten": "Handelsfähigste",
    "Handelsgerichtlichen": "Handelsgerichtliche",
    "Handelskammern": "Handelskammer",
    "Handelspolitische": "handelspolitisch",
    "Handelspolitischen": "Handelspolitische",
    "Handelsüblichen": "Handelsübliche",
    "Handfesten": "Handfeste",
    "Handfesteren": "Handfestere",
    "Handfestesten": "Handfesteste",
    "Handgearbeiteten": "Handgearbeitete",
    "Handgebundenen": "Handgebundene",
    "Handgenähten": "Handgenähte",
    "Handgestrickten": "Handgestrickte",
    "Handgewebten": "Handgewebte",
    "Handgreiflichen": "Handgreifliche",
    "Handhabenden": "Handhabende",
    "Handhabens": "Handhaben",
    "Handhabungen": "Handhabung",
    "Handliche": "handlich",
    "Handlichen": "Handliche",
    "Handlicheren": "Handlichere",
    "Handlichsten": "Handlichste",
    "Handlungen": "Handlung",
    "Handlungsfähige": "handlungsfähig",
    "Handlungsfähigen": "Handlungsfähige",
    "Handlungsfähigeren": "Handlungsfähigere",
    "Handlungsleitenden": "Handlungsleitende",
    "Handschriftlichen": "Handschriftliche",
    "Handstande": "Handstand",
    "Handstands": "Handstand",
    "Handstreiche": "Handstreich",
    "Handstreichen": "Handstreich",
    "Handstreichs": "Handstreich",
    "Handstände": "Handstand",
    "Handständen": "Handstand",
    "Handwarme": "handwarm",
    "Handwarmen": "Handwarme",
    "Handwerkern": "Handwerker",
    "Handwerkers": "Handwerker",
    "Handwerkliche": "handwerklich",
    "Handwerklichen": "Handwerkliche",
    "Handwerklicheren": "Handwerklichere",
    "Handwerklichsten": "Handwerklichste",
    "Hanebüchenen": "Hanebüchene",
    "Hanebücheneren": "Hanebüchenere",
    "Hanebüchensten": "Hanebüchenste",
    "Hangars": "Hangar",
    "Hange": "Hang",
    "Hangelleitern": "Hangelleiter",
    "Hangelnden": "Hangelnde",
    "Hangelnderen": "Hangelndere",
    "Hangelndsten": "Hangelndste",
    "Hangelns": "Hangeln",
    "Hanges": "Hang",
    "Hangs": "Hang",
    "Hannas": "Hanna",
    "Hannelores": "Hannelore",
    "Hannovers": "Hannover",
    "Hansestädte": "Hansestadt",
    "Hansestädten": "Hansestadt",
    "Hansische": "hansisch",
    "Hansischen": "Hansische",
    "Hantierenden": "Hantierende",
    "Hantierenderen": "Hantierendere",
    "Hantierendsten": "Hantierendste",
    "Hantierens": "Hantieren",
    "Hantierte": "hantiert",
    "Hantierten": "Hantierte",
    "Hapernden": "Hapernde",
    "Hapernderen": "Haperndere",
    "Haperndsten": "Haperndste",
    "Haperns": "Hapern",
    "Happenings": "Happening",
    "Happens": "Happen",
    "Happige": "happig",
    "Happigen": "Happige",
    "Happigeren": "Happigere",
    "Happigsten": "Happigste",
    "Haralds": "Harald",
    "Harems": "Harem",
    "Harfen": "Harfe",
    "Harfenistinnen": "Harfenistin",
    "Harheimern": "Harheimer",
    "Harheimers": "Harheimer",
    "Harheims": "Harheim",
    "Harken": "Harke",
    "Harlekine": "Harlekin",
    "Harlekinen": "Harlekin",
    "Harlekins": "Harlekin",
    "Harmlose": "harmlos",
    "Harmlosen": "Harmlose",
    "Harmloseren": "Harmlosere",
    "Harmlosesten": "Harmloseste",
    "Harmonien": "Harmonie",
    "Harmonierenden": "Harmonierende",
    "Harmonierenderen": "Harmonierendere",
    "Harmonierendsten": "Harmonierendste",
    "Harmonierens": "Harmonieren",
    "Harmonierte": "harmoniert",
    "Harmonierten": "Harmonierte",
    "Harmonierteren": "Harmoniertere",
    "Harmoniertesten": "Harmonierteste",
    "Harmonikas": "Harmonika",
    "Harmonische": "harmonisch",
    "Harmonischen": "Harmonische",
    "Harmonischeren": "Harmonischere",
    "Harmonischsten": "Harmonischste",
    "Harmonisierenden": "Harmonisierende",
    "Harmonisierenderen": "Harmonisierendere",
    "Harmonisierens": "Harmonisieren",
    "Harmonisierte": "harmonisiert",
    "Harmonisierten": "Harmonisierte",
    "Harmonisierteren": "Harmonisiertere",
    "Harmonisiertesten": "Harmonisierteste",
    "Harnblasen": "Harnblase",
    "Harnflaschen": "Harnflasche",
    "Harnische": "Harnisch",
    "Harnischen": "Harnisch",
    "Harnischs": "Harnisch",
    "Harntreibende": "harntreibend",
    "Harntreibenden": "Harntreibende",
    "Harntreibenderen": "Harntreibendere",
    "Harntreibendsten": "Harntreibendste",
    "Harpunen": "Harpune",
    "Harpunierenden": "Harpunierende",
    "Harpunierens": "Harpunieren",
    "Harpunierte": "harpuniert",
    "Harpunierten": "Harpunierte",
    "Harrenden": "Harrende",
    "Harrens": "Harren",
    "Harrys": "Harry",
    "Harsche": "harsch",
    "Harschen": "Harsche",
    "Harscheren": "Harschere",
    "Harschigen": "Harschige",
    "Harschigeren": "Harschigere",
    "Harschigsten": "Harschigste",
    "Harschsten": "Harschste",
    "Harten": "Harte",
    "Hartfasern": "Hartfaser",
    "Hartfutters": "Hartfutter",
    "Hartgelde": "Hartgeld",
    "Hartgeldes": "Hartgeld",
    "Hartgelds": "Hartgeld",
    "Hartgelöteten": "Hartgelötete",
    "Hartgesottenen": "Hartgesottene",
    "Hartgesotteneren": "Hartgesottenere",
    "Hartgesottensten": "Hartgesottenste",
    "Hartgummis": "Hartgummi",
    "Hartherzige": "hartherzig",
    "Hartherzigen": "Hartherzige",
    "Hartherzigeren": "Hartherzigere",
    "Hartherzigsten": "Hartherzigste",
    "Harths": "Harth",
    "Hartlötenden": "Hartlötende",
    "Hartlötens": "Hartlöten",
    "Hartmanns": "Hartmann",
    "Hartmetalle": "Hartmetall",
    "Hartmetallen": "Hartmetall",
    "Hartmetalls": "Hartmetall",
    "Hartmuts": "Hartmut",
    "Hartnäckige": "hartnäckig",
    "Hartnäckigen": "Hartnäckige",
    "Hartnäckigeren": "Hartnäckigere",
    "Hartnäckigsten": "Hartnäckigste",
    "Hartriegeln": "Hartriegel",
    "Hartriegels": "Hartriegel",
    "Harz": "harzen",
    "Harzenden": "Harzende",
    "Harzenderen": "Harzendere",
    "Harzendsten": "Harzendste",
    "Harzens": "Harzen",
    "Harzes": "Harz",
    "Harzigen": "Harzige",
    "Harzigeren": "Harzigere",
    "Harzigsten": "Harzigste",
    "Haschenden": "Haschende",
    "Haschenderen": "Haschendere",
    "Haschendsten": "Haschendste",
    "Haschens": "Haschen",
    "Hascherln": "Hascherl",
    "Hascherls": "Hascherl",
    "Haselnüsse": "Haselnuß",
    "Haselnüssen": "Haselnuß",
    "Hasen": "Hase",
    "Haspelnden": "Haspelnde",
    "Haspelnderen": "Haspelndere",
    "Haspelndsten": "Haspelndste",
    "Haspelns": "Haspeln",
    "Hasse": "hassen",
    "Hassenden": "Hassende",
    "Hassenderen": "Hassendere",
    "Hassendsten": "Hassendste",
    "Hassens": "Hassen",
    "Hasses": "Haß",
    "Hastenden": "Hastende",
    "Hastenderen": "Hastendere",
    "Hastendsten": "Hastendste",
    "Hastens": "Hasten",
    "Hastigen": "Hastige",
    "Hastigeren": "Hastigere",
    "Hastigsten": "Hastigste",
    "Hattersheimern": "Hattersheimer",
    "Hattersheimers": "Hattersheimer",
    "Hattersheims": "Hattersheim",
    "Hauben": "Haube",
    "Haubitzen": "Haubitze",
    "Hauch": "hauchen",
    "Hauchdünne": "hauchdünn",
    "Hauchdünnen": "Hauchdünne",
    "Hauche": "hauchen",
    "Hauchenden": "Hauchende",
    "Hauchenderen": "Hauchendere",
    "Hauchendsten": "Hauchendste",
    "Hauchens": "Hauchen",
    "Hauches": "Hauch",
    "Hauchs": "Hauch",
    "Hauchzarten": "Hauchzarte",
    "Hauchzarteren": "Hauchzartere",
    "Hauchzartesten": "Hauchzarteste",
    "Haudegens": "Haudegen",
    "Hauenden": "Hauende",
    "Hauens": "Hauen",
    "Hauern": "Hauer",
    "Hauers": "Hauer",
    "Haufens": "Haufen",
    "Hauptamtlichen": "Hauptamtliche",
    "Hauptaugenmerke": "Hauptaugenmerk",
    "Hauptaugenmerken": "Hauptaugenmerk",
    "Hauptaugenmerkes": "Hauptaugenmerk",
    "Hauptaugenmerks": "Hauptaugenmerk",
    "Hauptbahnen": "Hauptbahn",
    "Hauptbahnhofe": "Hauptbahnhof",
    "Hauptbahnhofs": "Hauptbahnhof",
    "Hauptbahnhöfe": "Hauptbahnhof",
    "Hauptbahnhöfen": "Hauptbahnhof",
    "Hauptberufliche": "hauptberuflich",
    "Hauptberuflichen": "Hauptberufliche",
    "Hauptberufs": "Hauptberuf",
    "Hauptbuche": "Hauptbuch",
    "Hauptbuchs": "Hauptbuch",
    "Hauptbücher": "Hauptbuch",
    "Hauptbüchern": "Hauptbuch",
    "Hauptbühnen": "Hauptbühne",
    "Haupte": "Haupt",
    "Hauptes": "Haupt",
    "Hauptfache": "Hauptfach",
    "Hauptfaches": "Hauptfach",
    "Hauptfachs": "Hauptfach",
    "Hauptfeldwebeln": "Hauptfeldwebel",
    "Hauptfeldwebels": "Hauptfeldwebel",
    "Hauptfilme": "Hauptfilm",
    "Hauptfilmen": "Hauptfilm",
    "Hauptfilms": "Hauptfilm",
    "Hauptfrauen": "Hauptfrau",
    "Hauptfächer": "Hauptfach",
    "Hauptfächern": "Hauptfach",
    "Hauptnennern": "Hauptnenner",
    "Hauptnenners": "Hauptnenner",
    "Hauptquartiere": "Hauptquartier",
    "Hauptquartieren": "Hauptquartier",
    "Hauptquartieres": "Hauptquartier",
    "Hauptquartiers": "Hauptquartier",
    "Hauptschiffe": "Hauptschiff",
    "Hauptschiffen": "Hauptschiff",
    "Hauptschiffs": "Hauptschiff",
    "Hauptstraßen": "Hauptstraße",
    "Hauptstädte": "Hauptstadt",
    "Hauptstädten": "Hauptstadt",
    "Hauptstädtische": "hauptstädtisch",
    "Hauptstädtischen": "Hauptstädtische",
    "Hauptsächliche": "hauptsächlich",
    "Hauptsächlichen": "Hauptsächliche",
    "Hauptverursachern": "Hauptverursacher",
    "Hauptverursachers": "Hauptverursacher",
    "Haus": "hausen",
    "Hause": "hausen",
    "Hausenden": "Hausende",
    "Hausenern": "Hausener",
    "Hauseners": "Hausener",
    "Hausens": "Hausen",
    "Hauses": "Haus",
    "Hausgemachten": "Hausgemachte",
    "Haushalte": "Haushalt",
    "Haushalten": "Haushalt",
    "Haushaltern": "Haushalter",
    "Haushalters": "Haushalter",
    "Haushaltes": "Haushalt",
    "Haushalts": "Haushalt",
    "Hausierenden": "Hausierende",
    "Hausierens": "Hausieren",
    "Hausierte": "hausiert",
    "Hausierten": "Hausierte",
    "Haustiere": "Haustier",
    "Haustieren": "Haustier",
    "Haustieres": "Haustier",
    "Haustiers": "Haustier",
    "Haut": "hauen",
    "Hautengen": "Hautenge",
    "Hautkrems": "Hautkrem",
    "Havannas": "Havanna",
    "Havels": "Havel",
    "Hawaiis": "Hawaii",
    "Hawaiische": "hawaiisch",
    "Hawaiischen": "Hawaiische",
    "Haxen": "Haxe",
    "Hayduks": "Hayduk",
    "Haziendas": "Hazienda",
    "Haß": "hassen",
    "Haßerfüllte": "haßerfüllt",
    "Haßerfüllten": "Haßerfüllte",
    "Haßerfüllteren": "Haßerfülltere",
    "Haßerfülltesten": "Haßerfüllteste",
    "Hearings": "Hearing",
    "Hebebühnen": "Hebebühne",
    "Hebeln": "Hebel",
    "Hebels": "Hebel",
    "Hebenden": "Hebende",
    "Hebens": "Heben",
    "Hebern": "Heber",
    "Hebers": "Heber",
    "Hebungen": "Hebung",
    "Hecheleien": "Hechelei",
    "Hechelnden": "Hechelnde",
    "Hechelnderen": "Hechelndere",
    "Hechelndsten": "Hechelndste",
    "Hechelns": "Hecheln",
    "Hechten": "Hecht",
    "Hechtenden": "Hechtende",
    "Hechtenderen": "Hechtendere",
    "Hechtendsten": "Hechtendste",
    "Hechtens": "Hechten",
    "Hechtrollen": "Hechtrolle",
    "Hechts": "Hecht",
    "Hechtsprunge": "Hechtsprung",
    "Hechtsprungs": "Hechtsprung",
    "Hechtsprünge": "Hechtsprung",
    "Hechtsprüngen": "Hechtsprung",
    "Heckelmanns": "Heckelmann",
    "Hecken": "Hecke",
    "Heckflossen": "Heckflosse",
    "Heckklappen": "Heckklappe",
    "Hecks": "Heck",
    "Heddernheimern": "Heddernheimer",
    "Heddernheimers": "Heddernheimer",
    "Heddernheims": "Heddernheim",
    "Heere": "Heer",
    "Heeren": "Heer",
    "Heeres": "Heer",
    "Heers": "Heer",
    "Heerstraßen": "Heerstraße",
    "Hefen": "Hefe",
    "Hefte": "heften",
    "Heften": "Heft",
    "Heftenden": "Heftende",
    "Heftens": "Heften",
    "Heftern": "Hefter",
    "Hefters": "Hefter",
    "Heftes": "Heft",
    "Heftigen": "Heftige",
    "Heftigeren": "Heftigere",
    "Heftigkeiten": "Heftigkeit",
    "Heftigste": "heftig",
    "Heftigsten": "Heftigste",
    "Hefts": "Heft",
    "Hegels": "Hegel",
    "Hegenden": "Hegende",
    "Hegenderen": "Hegendere",
    "Hegendsten": "Hegendste",
    "Hegens": "Hegen",
    "Hehlereien": "Hehlerei",
    "Heidelbergern": "Heidelberger",
    "Heidelbergers": "Heidelberger",
    "Heidelbergs": "Heidelberg",
    "Heidemaries": "Heidemarie",
    "Heiden": "Heide",
    "Heidengelde": "Heidengeld",
    "Heidengeldes": "Heidengeld",
    "Heidengelds": "Heidengeld",
    "Heidenlärms": "Heidenlärm",
    "Heidenschrecks": "Heidenschreck",
    "Heidenspektakels": "Heidenspektakel",
    "Heidentums": "Heidentum",
    "Heidis": "Heidi",
    "Heidnische": "heidnisch",
    "Heidnischen": "Heidnische",
    "Heidnischeren": "Heidnischere",
    "Heidnischsten": "Heidnischste",
    "Heikelsten": "Heikelste",
    "Heikes": "Heike",
    "Heikle": "heikel",
    "Heiklen": "Heikle",
    "Heikleren": "Heiklere",
    "Heikos": "Heiko",
    "Heil": "heilen",
    "Heilande": "Heiland",
    "Heilanden": "Heiland",
    "Heilands": "Heiland",
    "Heilbare": "heilbar",
    "Heilbaren": "Heilbare",
    "Heilbringenden": "Heilbringende",
    "Heile": "heilen",
    "Heilenden": "Heilende",
    "Heilens": "Heilen",
    "Heiles": "Heil",
    "Heilfrohen": "Heilfrohe",
    "Heiligen": "Heilige",
    "Heiligeren": "Heiligere",
    "Heiliggesprochenen": "Heiliggesprochene",
    "Heiligsprechenden": "Heiligsprechende",
    "Heiligsprechens": "Heiligsprechen",
    "Heiligsten": "Heiligste",
    "Heilkraute": "Heilkraut",
    "Heilkrautes": "Heilkraut",
    "Heilkrauts": "Heilkraut",
    "Heilkräuter": "Heilkraut",
    "Heilkräutern": "Heilkraut",
    "Heillose": "heillos",
    "Heillosen": "Heillose",
    "Heilpraktikern": "Heilpraktiker",
    "Heilpraktikers": "Heilpraktiker",
    "Heils": "Heil",
    "Heilsame": "heilsam",
    "Heilsamen": "Heilsame",
    "Heilsameren": "Heilsamere",
    "Heilsamsten": "Heilsamste",
    "Heilschlafe": "Heilschlaf",
    "Heilschlafes": "Heilschlaf",
    "Heilschlafs": "Heilschlaf",
    "Heilungen": "Heilung",
    "Heimatliche": "heimatlich",
    "Heimatlichen": "Heimatliche",
    "Heimatlicheren": "Heimatlichere",
    "Heimatlichsten": "Heimatlichste",
    "Heimatlosen": "Heimatlose",
    "Heimbegebenden": "Heimbegebende",
    "Heimbegebenen": "Heimbegebene",
    "Heimbegebens": "Heimbegeben",
    "Heimbegleitenden": "Heimbegleitende",
    "Heimbegleitens": "Heimbegleiten",
    "Heimbegleitete": "heimbegleitet",
    "Heimbegleiteten": "Heimbegleitete",
    "Heimbringenden": "Heimbringende",
    "Heimbringens": "Heimbringen",
    "Heime": "Heim",
    "Heimeligen": "Heimelige",
    "Heimeligeren": "Heimeligere",
    "Heimeligsten": "Heimeligste",
    "Heimelnden": "Heimelnde",
    "Heimelnderen": "Heimelndere",
    "Heimelndsten": "Heimelndste",
    "Heimelns": "Heimeln",
    "Heimen": "Heim",
    "Heimes": "Heim",
    "Heimfallenden": "Heimfallende",
    "Heimfallens": "Heimfallen",
    "Heimfindenden": "Heimfindende",
    "Heimfindens": "Heimfinden",
    "Heimführenden": "Heimführende",
    "Heimführens": "Heimführen",
    "Heimgebrachten": "Heimgebrachte",
    "Heimgefallenen": "Heimgefallene",
    "Heimgefundenen": "Heimgefundene",
    "Heimgeführten": "Heimgeführte",
    "Heimgegeigten": "Heimgegeigte",
    "Heimgeholten": "Heimgeholte",
    "Heimgeigenden": "Heimgeigende",
    "Heimgeigens": "Heimgeigen",
    "Heimgekehrten": "Heimgekehrte",
    "Heimgekommenen": "Heimgekommene",
    "Heimgeleuchteten": "Heimgeleuchtete",
    "Heimgenommenen": "Heimgenommene",
    "Heimgereisten": "Heimgereiste",
    "Heimgesuchten": "Heimgesuchte",
    "Heimgetragenen": "Heimgetragene",
    "Heimgezahlten": "Heimgezahlte",
    "Heimholenden": "Heimholende",
    "Heimholens": "Heimholen",
    "Heimischen": "Heimische",
    "Heimischeren": "Heimischere",
    "Heimischsten": "Heimischste",
    "Heimkehrenden": "Heimkehrende",
    "Heimkehrens": "Heimkehren",
    "Heimkommenden": "Heimkommende",
    "Heimkommens": "Heimkommen",
    "Heimleuchtenden": "Heimleuchtende",
    "Heimleuchtens": "Heimleuchten",
    "Heimlichen": "Heimliche",
    "Heimlicheren": "Heimlichere",
    "Heimlichsten": "Heimlichste",
    "Heimnehmenden": "Heimnehmende",
    "Heimnehmens": "Heimnehmen",
    "Heimreisenden": "Heimreisende",
    "Heimreisens": "Heimreisen",
    "Heims": "heimsen",
    "Heimsenden": "Heimsende",
    "Heimsens": "Heimsen",
    "Heimspiele": "Heimspiel",
    "Heimspielen": "Heimspiel",
    "Heimspiels": "Heimspiel",
    "Heimstätten": "Heimstätte",
    "Heimsuchenden": "Heimsuchende",
    "Heimsuchens": "Heimsuchen",
    "Heimtragenden": "Heimtragende",
    "Heimtragens": "Heimtragen",
    "Heimzahlenden": "Heimzahlende",
    "Heimzahlens": "Heimzahlen",
    "Heinemanns": "Heinemann",
    "Heiners": "Heiner",
    "Heines": "Heine",
    "Heinis": "Heini",
    "Heinos": "Heino",
    "Heinrichs": "Heinrich",
    "Heinzelmännchens": "Heinzelmännchen",
    "Heiraten": "Heirat",
    "Heiratenden": "Heiratende",
    "Heiratens": "Heiraten",
    "Heiratsfähigen": "Heiratsfähige",
    "Heiratsfähigeren": "Heiratsfähigere",
    "Heiratsfähigsten": "Heiratsfähigste",
    "Heiratslustigen": "Heiratslustige",
    "Heiratslustigeren": "Heiratslustigere",
    "Heiratslustigsten": "Heiratslustigste",
    "Heiseren": "Heisere",
    "Heisereren": "Heiserere",
    "Heisersten": "Heiserste",
    "Heitere": "heitern",
    "Heiteren": "Heitere",
    "Heitereren": "Heiterere",
    "Heiterkeiten": "Heiterkeit",
    "Heiternden": "Heiternde",
    "Heiterns": "Heitern",
    "Heitersten": "Heiterste",
    "Heizanlagen": "Heizanlage",
    "Heizbade": "Heizbad",
    "Heizbades": "Heizbad",
    "Heizbads": "Heizbad",
    "Heizbare": "heizbar",
    "Heizbaren": "Heizbare",
    "Heizbareren": "Heizbarere",
    "Heizbarsten": "Heizbarste",
    "Heizbatterien": "Heizbatterie",
    "Heizbäder": "Heizbad",
    "Heizbädern": "Heizbad",
    "Heizenden": "Heizende",
    "Heizenderen": "Heizendere",
    "Heizendsten": "Heizendste",
    "Heizens": "Heizen",
    "Heizern": "Heizer",
    "Heizers": "Heizer",
    "Heizflächen": "Heizfläche",
    "Heizgeräte": "Heizgerät",
    "Heizgeräten": "Heizgerät",
    "Heizgeräts": "Heizgerät",
    "Heizkissens": "Heizkissen",
    "Heizkraftwerke": "Heizkraftwerk",
    "Heizkraftwerken": "Heizkraftwerk",
    "Heizkraftwerks": "Heizkraftwerk",
    "Heizkörpern": "Heizkörper",
    "Heizkörpers": "Heizkörper",
    "Heizlüftern": "Heizlüfter",
    "Heizlüfters": "Heizlüfter",
    "Heizplatten": "Heizplatte",
    "Heizstrahlern": "Heizstrahler",
    "Heizstrahlers": "Heizstrahler",
    "Heizungen": "Heizung",
    "Heizöle": "Heizöl",
    "Heizölen": "Heizöl",
    "Heizöls": "Heizöl",
    "Heißblütigen": "Heißblütige",
    "Heißblütigeren": "Heißblütigere",
    "Heißblütigsten": "Heißblütigste",
    "Heiße": "heißen",
    "Heißen": "Heiße",
    "Heißenden": "Heißende",
    "Heißens": "Heißen",
    "Heißeren": "Heißere",
    "Heißersehnten": "Heißersehnte",
    "Heißesten": "Heißeste",
    "Heißgeliebten": "Heißgeliebte",
    "Heißhungers": "Heißhunger",
    "Heißhungrige": "heißhungrig",
    "Heißhungrigen": "Heißhungrige",
    "Heißhungrigeren": "Heißhungrigere",
    "Heißhungrigsten": "Heißhungrigste",
    "Heißluftgeräte": "Heißluftgerät",
    "Heißluftgeräten": "Heißluftgerät",
    "Heißluftgeräts": "Heißluftgerät",
    "Heißmangeln": "Heißmangel",
    "Heißsporne": "Heißsporn",
    "Heißspornen": "Heißsporn",
    "Heißsporns": "Heißsporn",
    "Heißumkämpften": "Heißumkämpfte",
    "Heißumstrittenen": "Heißumstrittene",
    "Hektikern": "Hektiker",
    "Hektikers": "Hektiker",
    "Hektische": "hektisch",
    "Hektischen": "Hektische",
    "Hektischeren": "Hektischere",
    "Hektischsten": "Hektischste",
    "Hektographien": "Hektographie",
    "Helbings": "Helbing",
    "Helden": "Held",
    "Heldenhafte": "heldenhaft",
    "Heldenhaften": "Heldenhafte",
    "Heldenhafteren": "Heldenhaftere",
    "Heldenhaftesten": "Heldenhafteste",
    "Heldenmütigen": "Heldenmütige",
    "Heldentums": "Heldentum",
    "Heldinnen": "Heldin",
    "Helfenden": "Helfende",
    "Helfens": "Helfen",
    "Helfern": "Helfer",
    "Helfers": "Helfer",
    "Helgas": "Helga",
    "Heliums": "Helium",
    "Helle": "hellen",
    "Hellen": "Helle",
    "Hellenden": "Hellende",
    "Hellens": "Hellen",
    "Heller": "hell",
    "Helleren": "Hellere",
    "Hellern": "Heller",
    "Hellers": "Heller",
    "Hellhörigen": "Hellhörige",
    "Hellhörigeren": "Hellhörigere",
    "Hellhörigsten": "Hellhörigste",
    "Hellsehern": "Hellseher",
    "Hellsehers": "Hellseher",
    "Hellsten": "Hellste",
    "Hellwachen": "Hellwache",
    "Hellwacheren": "Hellwachere",
    "Hellwachsten": "Hellwachste",
    "Helme": "Helm",
    "Helmen": "Helm",
    "Helmes": "Helm",
    "Helms": "Helm",
    "Helmuts": "Helmut",
    "Helsinkis": "Helsinki",
    "Hemde": "Hemd",
    "Hemden": "Hemd",
    "Hemdes": "Hemd",
    "Hemds": "Hemd",
    "Hemmenden": "Hemmende",
    "Hemmenderen": "Hemmendere",
    "Hemmendsten": "Hemmendste",
    "Hemmens": "Hemmen",
    "Hemmgabeln": "Hemmgabel",
    "Hemmnisse": "Hemmnis",
    "Hemmnissen": "Hemmnis",
    "Hemmnisses": "Hemmnis",
    "Hemmungen": "Hemmung",
    "Hemmungslose": "hemmungslos",
    "Hemmungslosen": "Hemmungslose",
    "Hemmungsloseren": "Hemmungslosere",
    "Hemmungslosesten": "Hemmungsloseste",
    "Hemsbergs": "Hemsberg",
    "Hengste": "Hengst",
    "Hengsten": "Hengst",
    "Hengsts": "Hengst",
    "Henkeln": "Henkel",
    "Henkels": "Henkel",
    "Henkern": "Henker",
    "Henkers": "Henker",
    "Hennen": "Henne",
    "Hennings": "Henning",
    "Henriettes": "Henriette",
    "Henrys": "Henry",
    "Henscheids": "Henscheid",
    "Herabfließenden": "Herabfließende",
    "Herabfließens": "Herabfließen",
    "Herabgeflossenen": "Herabgeflossene",
    "Herabgeregneten": "Herabgeregnete",
    "Herabgerissenen": "Herabgerissene",
    "Herabgeschobenen": "Herabgeschobene",
    "Herabgeschobeneren": "Herabgeschobenere",
    "Herabgeschossenen": "Herabgeschossene",
    "Herabgesetzten": "Herabgesetzte",
    "Herabgesetzteren": "Herabgesetztere",
    "Herabgesetztesten": "Herabgesetzteste",
    "Herabgesunkenen": "Herabgesunkene",
    "Herabgesunkeneren": "Herabgesunkenere",
    "Herabgesunkensten": "Herabgesunkenste",
    "Herabregnenden": "Herabregnende",
    "Herabregnens": "Herabregnen",
    "Herabreißenden": "Herabreißende",
    "Herabreißens": "Herabreißen",
    "Herabschiebenden": "Herabschiebende",
    "Herabschiebens": "Herabschieben",
    "Herabschießenden": "Herabschießende",
    "Herabschießens": "Herabschießen",
    "Herabsetzenden": "Herabsetzende",
    "Herabsetzens": "Herabsetzen",
    "Herabsinkenden": "Herabsinkende",
    "Herabsinkenderen": "Herabsinkendere",
    "Herabsinkendsten": "Herabsinkendste",
    "Herabsinkens": "Herabsinken",
    "Herangegangenen": "Herangegangene",
    "Herangehenden": "Herangehende",
    "Herangehens": "Herangehen",
    "Herangekrochenen": "Herangekrochene",
    "Herangemachten": "Herangemachte",
    "Herangereiften": "Herangereifte",
    "Herangerückten": "Herangerückte",
    "Herangeschlichenen": "Herangeschlichene",
    "Herangeschmissenen": "Herangeschmissene",
    "Herangespielten": "Herangespielte",
    "Herangewachsenen": "Herangewachsene",
    "Herangewachsten": "Herangewachste",
    "Herangezogenen": "Herangezogene",
    "Herangezüchteten": "Herangezüchtete",
    "Herankriechenden": "Herankriechende",
    "Herankriechens": "Herankriechen",
    "Heranmachenden": "Heranmachende",
    "Heranmachens": "Heranmachen",
    "Heranreifenden": "Heranreifende",
    "Heranreifenderen": "Heranreifendere",
    "Heranreifendsten": "Heranreifendste",
    "Heranreifens": "Heranreifen",
    "Heranrückenden": "Heranrückende",
    "Heranrückens": "Heranrücken",
    "Heranschleichenden": "Heranschleichende",
    "Heranschleichens": "Heranschleichen",
    "Heranschmeißenden": "Heranschmeißende",
    "Heranschmeißens": "Heranschmeißen",
    "Heranspielenden": "Heranspielende",
    "Heranspielens": "Heranspielen",
    "Heranwachsenden": "Heranwachsende",
    "Heranwachsens": "Heranwachsen",
    "Heranziehenden": "Heranziehende",
    "Heranziehens": "Heranziehen",
    "Heranzüchtenden": "Heranzüchtende",
    "Heranzüchtens": "Heranzüchten",
    "Heraufbemühenden": "Heraufbemühende",
    "Heraufbemühens": "Heraufbemühen",
    "Heraufbemühte": "heraufbemüht",
    "Heraufbemühten": "Heraufbemühte",
    "Herauffallenden": "Herauffallende",
    "Herauffallens": "Herauffallen",
    "Herauffließenden": "Herauffließende",
    "Herauffließens": "Herauffließen",
    "Heraufführenden": "Heraufführende",
    "Heraufführens": "Heraufführen",
    "Heraufgefallenen": "Heraufgefallene",
    "Heraufgeflossenen": "Heraufgeflossene",
    "Heraufgeführten": "Heraufgeführte",
    "Heraufgereichten": "Heraufgereichte",
    "Heraufgerollten": "Heraufgerollte",
    "Heraufgerollteren": "Heraufgerolltere",
    "Heraufgesetzten": "Heraufgesetzte",
    "Heraufgesetzteren": "Heraufgesetztere",
    "Heraufreichenden": "Heraufreichende",
    "Heraufreichens": "Heraufreichen",
    "Heraufrollenden": "Heraufrollende",
    "Heraufrollenderen": "Heraufrollendere",
    "Heraufrollendsten": "Heraufrollendste",
    "Heraufrollens": "Heraufrollen",
    "Heraufsetzenden": "Heraufsetzende",
    "Heraufsetzens": "Heraufsetzen",
    "Herausarbeitenden": "Herausarbeitende",
    "Herausarbeitens": "Herausarbeiten",
    "Herausbeißenden": "Herausbeißende",
    "Herausbeißens": "Herausbeißen",
    "Herausbrechenden": "Herausbrechende",
    "Herausbrechens": "Herausbrechen",
    "Herausfilternden": "Herausfilternde",
    "Herausfilterns": "Herausfiltern",
    "Herausforderungen": "Herausforderung",
    "Herausführenden": "Herausführende",
    "Herausführens": "Herausführen",
    "Herausgearbeiteten": "Herausgearbeitete",
    "Herausgearbeiteteren": "Herausgearbeitetere",
    "Herausgebenden": "Herausgebende",
    "Herausgebens": "Herausgeben",
    "Herausgebern": "Herausgeber",
    "Herausgebers": "Herausgeber",
    "Herausgebissenen": "Herausgebissene",
    "Herausgebrochenen": "Herausgebrochene",
    "Herausgefilterten": "Herausgefilterte",
    "Herausgeführten": "Herausgeführte",
    "Herausgegebenen": "Herausgegebene",
    "Herausgehaltenen": "Herausgehaltene",
    "Herausgehobenen": "Herausgehobene",
    "Herausgehobeneren": "Herausgehobenere",
    "Herausgehobensten": "Herausgehobenste",
    "Herausgelugten": "Herausgelugte",
    "Herausgeputzten": "Herausgeputzte",
    "Herausgeputzteren": "Herausgeputztere",
    "Herausgereichten": "Herausgereichte",
    "Herausgerückten": "Herausgerückte",
    "Herausgeschossenen": "Herausgeschossene",
    "Herausgeschundenen": "Herausgeschundene",
    "Herausgeschundeneren": "Herausgeschundenere",
    "Herausgespielten": "Herausgespielte",
    "Herausgespielteren": "Herausgespieltere",
    "Herausgesprengten": "Herausgesprengte",
    "Herausgespritzten": "Herausgespritzte",
    "Herausgesprossenen": "Herausgesprossene",
    "Herausgesprudelten": "Herausgesprudelte",
    "Herausgestellten": "Herausgestellte",
    "Herausgesuchten": "Herausgesuchte",
    "Herausgeworfenen": "Herausgeworfene",
    "Herausgezogenen": "Herausgezogene",
    "Heraushaltenden": "Heraushaltende",
    "Heraushaltens": "Heraushalten",
    "Heraushebenden": "Heraushebende",
    "Heraushebens": "Herausheben",
    "Herauskristallisierte": "herauskristallisiert",
    "Herauskristallisierten": "Herauskristallisierte",
    "Herauslugenden": "Herauslugende",
    "Herauslugenderen": "Herauslugendere",
    "Herauslugendsten": "Herauslugendste",
    "Herauslugens": "Herauslugen",
    "Herausputzenden": "Herausputzende",
    "Herausputzens": "Herausputzen",
    "Herausreichenden": "Herausreichende",
    "Herausreichens": "Herausreichen",
    "Herausrückenden": "Herausrückende",
    "Herausrückens": "Herausrücken",
    "Herausschießenden": "Herausschießende",
    "Herausschießens": "Herausschießen",
    "Herausschindenden": "Herausschindende",
    "Herausschindenderen": "Herausschindendere",
    "Herausschindens": "Herausschinden",
    "Herausspielenden": "Herausspielende",
    "Herausspielens": "Herausspielen",
    "Heraussprengenden": "Heraussprengende",
    "Heraussprengens": "Heraussprengen",
    "Heraussprießenden": "Heraussprießende",
    "Heraussprießens": "Heraussprießen",
    "Herausspritzenden": "Herausspritzende",
    "Herausspritzens": "Herausspritzen",
    "Heraussprudelnden": "Heraussprudelnde",
    "Heraussprudelns": "Heraussprudeln",
    "Herausstellenden": "Herausstellende",
    "Herausstellens": "Herausstellen",
    "Heraussuchenden": "Heraussuchende",
    "Heraussuchens": "Heraussuchen",
    "Herauswerfenden": "Herauswerfende",
    "Herauswerfens": "Herauswerfen",
    "Herausziehbaren": "Herausziehbare",
    "Herausziehenden": "Herausziehende",
    "Herausziehens": "Herausziehen",
    "Herbegleitenden": "Herbegleitende",
    "Herbegleitens": "Herbegleiten",
    "Herbegleitete": "herbegleitet",
    "Herbegleiteten": "Herbegleitete",
    "Herbeibringenden": "Herbeibringende",
    "Herbeibringens": "Herbeibringen",
    "Herbeidrängenden": "Herbeidrängende",
    "Herbeidrängens": "Herbeidrängen",
    "Herbeieilenden": "Herbeieilende",
    "Herbeieilens": "Herbeieilen",
    "Herbeifliegenden": "Herbeifliegende",
    "Herbeifliegens": "Herbeifliegen",
    "Herbeiführenden": "Herbeiführende",
    "Herbeiführens": "Herbeiführen",
    "Herbeigebrachten": "Herbeigebrachte",
    "Herbeigedrängten": "Herbeigedrängte",
    "Herbeigeeilten": "Herbeigeeilte",
    "Herbeigeflogenen": "Herbeigeflogene",
    "Herbeigeführten": "Herbeigeführte",
    "Herbeigeholten": "Herbeigeholte",
    "Herbeigelaufenen": "Herbeigelaufene",
    "Herbeigerannten": "Herbeigerannte",
    "Herbeigerufenen": "Herbeigerufene",
    "Herbeigeschaffenen": "Herbeigeschaffene",
    "Herbeigeschafften": "Herbeigeschaffte",
    "Herbeigeschleppten": "Herbeigeschleppte",
    "Herbeigeschworenen": "Herbeigeschworene",
    "Herbeigesehnten": "Herbeigesehnte",
    "Herbeigesehnteren": "Herbeigesehntere",
    "Herbeigesprungenen": "Herbeigesprungene",
    "Herbeigeströmten": "Herbeigeströmte",
    "Herbeigestürzten": "Herbeigestürzte",
    "Herbeigetragenen": "Herbeigetragene",
    "Herbeigewinkten": "Herbeigewinkte",
    "Herbeigewünschten": "Herbeigewünschte",
    "Herbeiholenden": "Herbeiholende",
    "Herbeiholens": "Herbeiholen",
    "Herbeilaufenden": "Herbeilaufende",
    "Herbeilaufens": "Herbeilaufen",
    "Herbeirennenden": "Herbeirennende",
    "Herbeirennens": "Herbeirennen",
    "Herbeirufenden": "Herbeirufende",
    "Herbeirufens": "Herbeirufen",
    "Herbeischaffenden": "Herbeischaffende",
    "Herbeischaffens": "Herbeischaffen",
    "Herbeischleppenden": "Herbeischleppende",
    "Herbeischleppens": "Herbeischleppen",
    "Herbeischwörenden": "Herbeischwörende",
    "Herbeischwörens": "Herbeischwören",
    "Herbeisehnenden": "Herbeisehnende",
    "Herbeisehnenderen": "Herbeisehnendere",
    "Herbeisehnendsten": "Herbeisehnendste",
    "Herbeisehnens": "Herbeisehnen",
    "Herbeispringenden": "Herbeispringende",
    "Herbeispringens": "Herbeispringen",
    "Herbeiströmenden": "Herbeiströmende",
    "Herbeiströmens": "Herbeiströmen",
    "Herbeistürzenden": "Herbeistürzende",
    "Herbeistürzens": "Herbeistürzen",
    "Herbeitragenden": "Herbeitragende",
    "Herbeitragens": "Herbeitragen",
    "Herbeiwinkenden": "Herbeiwinkende",
    "Herbeiwinkens": "Herbeiwinken",
    "Herbeiwünschenden": "Herbeiwünschende",
    "Herbeiwünschens": "Herbeiwünschen",
    "Herbeizitierenden": "Herbeizitierende",
    "Herbeizitierens": "Herbeizitieren",
    "Herbeizitierte": "herbeizitiert",
    "Herbeizitierten": "Herbeizitierte",
    "Herbekommenden": "Herbekommende",
    "Herbekommenen": "Herbekommene",
    "Herbekommens": "Herbekommen",
    "Herbemühenden": "Herbemühende",
    "Herbemühens": "Herbemühen",
    "Herbemühte": "herbemüht",
    "Herbemühten": "Herbemühte",
    "Herben": "Herbe",
    "Herbeordernden": "Herbeordernde",
    "Herbeorderns": "Herbeordern",
    "Herbeorderte": "herbeordert",
    "Herbeorderten": "Herbeorderte",
    "Herbequemenden": "Herbequemende",
    "Herbequemens": "Herbequemen",
    "Herbequemte": "herbequemt",
    "Herbequemten": "Herbequemte",
    "Herberen": "Herbere",
    "Herbergen": "Herberge",
    "Herbergsvaters": "Herbergsvater",
    "Herbergsväter": "Herbergsvater",
    "Herbergsvätern": "Herbergsvater",
    "Herberts": "Herbert",
    "Herbestellenden": "Herbestellende",
    "Herbestellens": "Herbestellen",
    "Herbestellte": "herbestellt",
    "Herbestellten": "Herbestellte",
    "Herbetenden": "Herbetende",
    "Herbetens": "Herbeten",
    "Herbittenden": "Herbittende",
    "Herbittens": "Herbitten",
    "Herbizide": "Herbizid",
    "Herbiziden": "Herbizid",
    "Herbizids": "Herbizid",
    "Herborns": "Herborn",
    "Herbringenden": "Herbringende",
    "Herbringens": "Herbringen",
    "Herbste": "Herbst",
    "Herbsten": "Herbste",
    "Herbstes": "Herbst",
    "Herbstliche": "herbstlich",
    "Herbstlichen": "Herbstliche",
    "Herbstlicheren": "Herbstlichere",
    "Herbstlichsten": "Herbstlichste",
    "Herbsts": "Herbst",
    "Herde": "Herd",
    "Herden": "Herde",
    "Herdenkenden": "Herdenkende",
    "Herdenkens": "Herdenken",
    "Herds": "Herd",
    "Hereinfallenden": "Hereinfallende",
    "Hereinfallens": "Hereinfallen",
    "Hereingefallenen": "Hereingefallene",
    "Hereingefalleneren": "Hereingefallenere",
    "Hereingereichten": "Hereingereichte",
    "Hereingerufenen": "Hereingerufene",
    "Hereinreichenden": "Hereinreichende",
    "Hereinreichens": "Hereinreichen",
    "Hereinrufenden": "Hereinrufende",
    "Hereinrufens": "Hereinrufen",
    "Herfallenden": "Herfallende",
    "Herfallens": "Herfallen",
    "Herfindenden": "Herfindende",
    "Herfindens": "Herfinden",
    "Herfliegenden": "Herfliegende",
    "Herfliegens": "Herfliegen",
    "Herführenden": "Herführende",
    "Herführens": "Herführen",
    "Hergebenden": "Hergebende",
    "Hergebens": "Hergeben",
    "Hergebetenen": "Hergebetene",
    "Hergebeteten": "Hergebetete",
    "Hergebrachten": "Hergebrachte",
    "Hergedachten": "Hergedachte",
    "Hergefallenen": "Hergefallene",
    "Hergeflogenen": "Hergeflogene",
    "Hergefundenen": "Hergefundene",
    "Hergeführten": "Hergeführte",
    "Hergegebenen": "Hergegebene",
    "Hergehaltenen": "Hergehaltene",
    "Hergeholten": "Hergeholte",
    "Hergehörten": "Hergehörte",
    "Hergejagten": "Hergejagte",
    "Hergekommenen": "Hergekommene",
    "Hergekriegten": "Hergekriegte",
    "Hergelangten": "Hergelangte",
    "Hergelaufenen": "Hergelaufene",
    "Hergelegten": "Hergelegte",
    "Hergeleierten": "Hergeleierte",
    "Hergeleiteten": "Hergeleitete",
    "Hergeliehenen": "Hergeliehene",
    "Hergemachten": "Hergemachte",
    "Hergemachteren": "Hergemachtere",
    "Hergemachtesten": "Hergemachteste",
    "Hergenommenen": "Hergenommene",
    "Hergereichten": "Hergereichte",
    "Hergerichteten": "Hergerichtete",
    "Hergerufenen": "Hergerufene",
    "Hergerückten": "Hergerückte",
    "Hergerührten": "Hergerührte",
    "Hergesagten": "Hergesagte",
    "Hergeschaffenen": "Hergeschaffene",
    "Hergeschafften": "Hergeschaffte",
    "Hergeschauten": "Hergeschaute",
    "Hergeschleppten": "Hergeschleppte",
    "Hergeschobenen": "Hergeschobene",
    "Hergesehenen": "Hergesehene",
    "Hergesehnten": "Hergesehnte",
    "Hergesehnteren": "Hergesehntere",
    "Hergesehntesten": "Hergesehnteste",
    "Hergesetzten": "Hergesetzte",
    "Hergesprungenen": "Hergesprungene",
    "Hergestammten": "Hergestammte",
    "Hergestellten": "Hergestellte",
    "Hergetragenen": "Hergetragene",
    "Hergetriebenen": "Hergetriebene",
    "Hergewinkten": "Hergewinkte",
    "Hergeworfenen": "Hergeworfene",
    "Hergezauberten": "Hergezauberte",
    "Hergezeigten": "Hergezeigte",
    "Hergezogenen": "Hergezogene",
    "Hergezählten": "Hergezählte",
    "Herhaltenden": "Herhaltende",
    "Herhaltens": "Herhalten",
    "Herholenden": "Herholende",
    "Herholens": "Herholen",
    "Herhörenden": "Herhörende",
    "Herhörenderen": "Herhörendere",
    "Herhörendsten": "Herhörendste",
    "Herhörens": "Herhören",
    "Heriberts": "Heribert",
    "Heringe": "Hering",
    "Heringen": "Hering",
    "Herings": "Hering",
    "Herjagenden": "Herjagende",
    "Herjagens": "Herjagen",
    "Herkommenden": "Herkommende",
    "Herkommens": "Herkommen",
    "Herkriegenden": "Herkriegende",
    "Herkriegens": "Herkriegen",
    "Herkömmlichen": "Herkömmliche",
    "Herkömmlicheren": "Herkömmlichere",
    "Herkömmlichsten": "Herkömmlichste",
    "Herlangenden": "Herlangende",
    "Herlangens": "Herlangen",
    "Herlaufenden": "Herlaufende",
    "Herlaufens": "Herlaufen",
    "Herlegenden": "Herlegende",
    "Herlegens": "Herlegen",
    "Herleiernden": "Herleiernde",
    "Herleierns": "Herleiern",
    "Herleihenden": "Herleihende",
    "Herleihens": "Herleihen",
    "Herleitenden": "Herleitende",
    "Herleitens": "Herleiten",
    "Hermachenden": "Hermachende",
    "Hermachens": "Hermachen",
    "Hermanns": "Hermann",
    "Hermeneutische": "hermeneutisch",
    "Hermeneutischen": "Hermeneutische",
    "Hermetischen": "Hermetische",
    "Hernehmenden": "Hernehmende",
    "Hernehmens": "Hernehmen",
    "Heroins": "Heroin",
    "Heroische": "heroisch",
    "Heroischen": "Heroische",
    "Heroischeren": "Heroischere",
    "Heroischsten": "Heroischste",
    "Heroisierenden": "Heroisierende",
    "Heroisierenderen": "Heroisierendere",
    "Heroisierendsten": "Heroisierendste",
    "Heroisierens": "Heroisieren",
    "Heroisierte": "heroisiert",
    "Heroisierten": "Heroisierte",
    "Heroisierteren": "Heroisiertere",
    "Heroisiertesten": "Heroisierteste",
    "Herolde": "Herold",
    "Herolden": "Herold",
    "Herolds": "Herold",
    "Herpels": "Herpel",
    "Herrchens": "Herrchen",
    "Herreichenden": "Herreichende",
    "Herreichens": "Herreichen",
    "Herren": "Herr",
    "Herrenlose": "herrenlos",
    "Herrenlosen": "Herrenlose",
    "Herrichtenden": "Herrichtende",
    "Herrichtens": "Herrichten",
    "Herrischen": "Herrische",
    "Herrlichen": "Herrliche",
    "Herrlicheren": "Herrlichere",
    "Herrlichkeiten": "Herrlichkeit",
    "Herrlichste": "herrlich",
    "Herrlichsten": "Herrlichste",
    "Herrschaften": "Herrschaft",
    "Herrschaftliche": "herrschaftlich",
    "Herrschaftlichen": "Herrschaftliche",
    "Herrschenden": "Herrschende",
    "Herrschenderen": "Herrschendere",
    "Herrschendsten": "Herrschendste",
    "Herrschens": "Herrschen",
    "Herrscherinnen": "Herrscherin",
    "Herrschern": "Herrscher",
    "Herrschers": "Herrscher",
    "Herrschsüchtigen": "Herrschsüchtige",
    "Herrschsüchtigeren": "Herrschsüchtigere",
    "Herrufenden": "Herrufende",
    "Herrufens": "Herrufen",
    "Herrückenden": "Herrückende",
    "Herrückens": "Herrücken",
    "Herrührenden": "Herrührende",
    "Herrührens": "Herrühren",
    "Hersagenden": "Hersagende",
    "Hersagens": "Hersagen",
    "Herschaffenden": "Herschaffende",
    "Herschaffens": "Herschaffen",
    "Herschauenden": "Herschauende",
    "Herschauens": "Herschauen",
    "Herschiebenden": "Herschiebende",
    "Herschiebens": "Herschieben",
    "Herschleppenden": "Herschleppende",
    "Herschleppens": "Herschleppen",
    "Hersehenden": "Hersehende",
    "Hersehens": "Hersehen",
    "Hersehnenden": "Hersehnende",
    "Hersehnenderen": "Hersehnendere",
    "Hersehnendsten": "Hersehnendste",
    "Hersehnens": "Hersehnen",
    "Hersetzenden": "Hersetzende",
    "Hersetzens": "Hersetzen",
    "Hersfelds": "Hersfeld",
    "Herspringenden": "Herspringende",
    "Herspringens": "Herspringen",
    "Herstammenden": "Herstammende",
    "Herstammens": "Herstammen",
    "Herstellenden": "Herstellende",
    "Herstellens": "Herstellen",
    "Herstellern": "Hersteller",
    "Herstellers": "Hersteller",
    "Herstellungen": "Herstellung",
    "Herties": "Hertie",
    "Hertragenden": "Hertragende",
    "Hertragens": "Hertragen",
    "Hertreibenden": "Hertreibende",
    "Hertreibens": "Hertreiben",
    "Herumfahrenden": "Herumfahrende",
    "Herumfahrens": "Herumfahren",
    "Herumfliegenden": "Herumfliegende",
    "Herumfliegenderen": "Herumfliegendere",
    "Herumfliegendsten": "Herumfliegendste",
    "Herumfliegens": "Herumfliegen",
    "Herumführenden": "Herumführende",
    "Herumführens": "Herumführen",
    "Herumgefahrenen": "Herumgefahrene",
    "Herumgeflogenen": "Herumgeflogene",
    "Herumgeflogeneren": "Herumgeflogenere",
    "Herumgeflogensten": "Herumgeflogenste",
    "Herumgeführten": "Herumgeführte",
    "Herumgehangenen": "Herumgehangene",
    "Herumgehängten": "Herumgehängte",
    "Herumgelegenen": "Herumgelegene",
    "Herumgelungerten": "Herumgelungerte",
    "Herumgereichten": "Herumgereichte",
    "Herumgeschlagenen": "Herumgeschlagene",
    "Herumgespritzten": "Herumgespritzte",
    "Herumgesprochenen": "Herumgesprochene",
    "Herumgetönten": "Herumgetönte",
    "Herumgewirbelten": "Herumgewirbelte",
    "Herumgezogenen": "Herumgezogene",
    "Herumhängenden": "Herumhängende",
    "Herumhängenderen": "Herumhängendere",
    "Herumhängendsten": "Herumhängendste",
    "Herumhängens": "Herumhängen",
    "Herumliegenden": "Herumliegende",
    "Herumliegenderen": "Herumliegendere",
    "Herumliegendsten": "Herumliegendste",
    "Herumliegens": "Herumliegen",
    "Herumlungernden": "Herumlungernde",
    "Herumlungerns": "Herumlungern",
    "Herumreichenden": "Herumreichende",
    "Herumreichens": "Herumreichen",
    "Herumschlagenden": "Herumschlagende",
    "Herumschlagens": "Herumschlagen",
    "Herumsprechenden": "Herumsprechende",
    "Herumsprechens": "Herumsprechen",
    "Herumspritzenden": "Herumspritzende",
    "Herumspritzens": "Herumspritzen",
    "Herumtönenden": "Herumtönende",
    "Herumtönenderen": "Herumtönendere",
    "Herumtönendsten": "Herumtönendste",
    "Herumtönens": "Herumtönen",
    "Herumwirbelnden": "Herumwirbelnde",
    "Herumwirbelns": "Herumwirbeln",
    "Herumziehenden": "Herumziehende",
    "Herumziehens": "Herumziehen",
    "Herunterbemühenden": "Herunterbemühende",
    "Herunterbemühens": "Herunterbemühen",
    "Herunterbemühte": "herunterbemüht",
    "Herunterbemühten": "Herunterbemühte",
    "Herunterbringenden": "Herunterbringende",
    "Herunterbringens": "Herunterbringen",
    "Herunterdrückenden": "Herunterdrückende",
    "Herunterdrückens": "Herunterdrücken",
    "Herunterfallenden": "Herunterfallende",
    "Herunterfallens": "Herunterfallen",
    "Heruntergebrachten": "Heruntergebrachte",
    "Heruntergedrückten": "Heruntergedrückte",
    "Heruntergefallenen": "Heruntergefallene",
    "Heruntergekommenen": "Heruntergekommene",
    "Heruntergekommeneren": "Heruntergekommenere",
    "Heruntergemachten": "Heruntergemachte",
    "Heruntergemachteren": "Heruntergemachtere",
    "Heruntergenommenen": "Heruntergenommene",
    "Heruntergerannten": "Heruntergerannte",
    "Heruntergerasselten": "Heruntergerasselte",
    "Heruntergereichten": "Heruntergereichte",
    "Heruntergerissenen": "Heruntergerissene",
    "Heruntergerisseneren": "Heruntergerissenere",
    "Heruntergerollten": "Heruntergerollte",
    "Heruntergerollteren": "Heruntergerolltere",
    "Heruntergeschobenen": "Heruntergeschobene",
    "Heruntergeschobeneren": "Heruntergeschobenere",
    "Heruntergeschossenen": "Heruntergeschossene",
    "Heruntergesetzten": "Heruntergesetzte",
    "Heruntergesetzteren": "Heruntergesetztere",
    "Heruntergetragenen": "Heruntergetragene",
    "Heruntergezogenen": "Heruntergezogene",
    "Herunterkommenden": "Herunterkommende",
    "Herunterkommenderen": "Herunterkommendere",
    "Herunterkommens": "Herunterkommen",
    "Heruntermachenden": "Heruntermachende",
    "Heruntermachenderen": "Heruntermachendere",
    "Heruntermachens": "Heruntermachen",
    "Herunternehmenden": "Herunternehmende",
    "Herunternehmens": "Herunternehmen",
    "Herunterrasselnden": "Herunterrasselnde",
    "Herunterrasselns": "Herunterrasseln",
    "Herunterreichenden": "Herunterreichende",
    "Herunterreichens": "Herunterreichen",
    "Herunterreißenden": "Herunterreißende",
    "Herunterreißens": "Herunterreißen",
    "Herunterrennenden": "Herunterrennende",
    "Herunterrennens": "Herunterrennen",
    "Herunterrollenden": "Herunterrollende",
    "Herunterrollens": "Herunterrollen",
    "Herunterschiebenden": "Herunterschiebende",
    "Herunterschiebens": "Herunterschieben",
    "Herunterschießenden": "Herunterschießende",
    "Herunterschießens": "Herunterschießen",
    "Heruntersetzenden": "Heruntersetzende",
    "Heruntersetzens": "Heruntersetzen",
    "Heruntertragenden": "Heruntertragende",
    "Heruntertragens": "Heruntertragen",
    "Herunterziehenden": "Herunterziehende",
    "Herunterziehens": "Herunterziehen",
    "Hervorbrechenden": "Hervorbrechende",
    "Hervorbrechens": "Hervorbrechen",
    "Hervorbringenden": "Hervorbringende",
    "Hervorbringens": "Hervorbringen",
    "Hervordringenden": "Hervordringende",
    "Hervordringens": "Hervordringen",
    "Hervordrängenden": "Hervordrängende",
    "Hervordrängens": "Hervordrängen",
    "Hervorgebrachten": "Hervorgebrachte",
    "Hervorgebrochenen": "Hervorgebrochene",
    "Hervorgedrungenen": "Hervorgedrungene",
    "Hervorgedrängten": "Hervorgedrängte",
    "Hervorgegangenen": "Hervorgegangene",
    "Hervorgehenden": "Hervorgehende",
    "Hervorgehens": "Hervorgehen",
    "Hervorgehobenen": "Hervorgehobene",
    "Hervorgehobeneren": "Hervorgehobenere",
    "Hervorgehobensten": "Hervorgehobenste",
    "Hervorgekehrten": "Hervorgekehrte",
    "Hervorgekeimten": "Hervorgekeimte",
    "Hervorgekeimteren": "Hervorgekeimtere",
    "Hervorgekommenen": "Hervorgekommene",
    "Hervorgeleuchteten": "Hervorgeleuchtete",
    "Hervorgequellten": "Hervorgequellte",
    "Hervorgequollenen": "Hervorgequollene",
    "Hervorgeragten": "Hervorgeragte",
    "Hervorgerufenen": "Hervorgerufene",
    "Hervorgeschauten": "Hervorgeschaute",
    "Hervorgeschimmerten": "Hervorgeschimmerte",
    "Hervorgeschimmerteren": "Hervorgeschimmertere",
    "Hervorgeschossenen": "Hervorgeschossene",
    "Hervorgesprudelten": "Hervorgesprudelte",
    "Hervorgesprungenen": "Hervorgesprungene",
    "Hervorgestandenen": "Hervorgestandene",
    "Hervorgestochenen": "Hervorgestochene",
    "Hervorgestocheneren": "Hervorgestochenere",
    "Hervorgestoßenen": "Hervorgestoßene",
    "Hervorgestürzten": "Hervorgestürzte",
    "Hervorgesuchten": "Hervorgesuchte",
    "Hervorgetauchten": "Hervorgetauchte",
    "Hervorgewagten": "Hervorgewagte",
    "Hervorgezauberten": "Hervorgezauberte",
    "Hervorhebenden": "Hervorhebende",
    "Hervorhebens": "Hervorheben",
    "Hervorkehrenden": "Hervorkehrende",
    "Hervorkehrens": "Hervorkehren",
    "Hervorkeimenden": "Hervorkeimende",
    "Hervorkeimenderen": "Hervorkeimendere",
    "Hervorkeimendsten": "Hervorkeimendste",
    "Hervorkeimens": "Hervorkeimen",
    "Hervorkommenden": "Hervorkommende",
    "Hervorkommens": "Hervorkommen",
    "Hervorleuchtenden": "Hervorleuchtende",
    "Hervorleuchtens": "Hervorleuchten",
    "Hervorquellenden": "Hervorquellende",
    "Hervorquellens": "Hervorquellen",
    "Hervorragenden": "Hervorragende",
    "Hervorragenderen": "Hervorragendere",
    "Hervorragendsten": "Hervorragendste",
    "Hervorragens": "Hervorragen",
    "Hervorrufenden": "Hervorrufende",
    "Hervorrufens": "Hervorrufen",
    "Hervorschauenden": "Hervorschauende",
    "Hervorschauens": "Hervorschauen",
    "Hervorschießenden": "Hervorschießende",
    "Hervorschießens": "Hervorschießen",
    "Hervorschimmernden": "Hervorschimmernde",
    "Hervorschimmernderen": "Hervorschimmerndere",
    "Hervorschimmerns": "Hervorschimmern",
    "Hervorspringenden": "Hervorspringende",
    "Hervorspringens": "Hervorspringen",
    "Hervorsprudelnden": "Hervorsprudelnde",
    "Hervorsprudelns": "Hervorsprudeln",
    "Hervorstechenden": "Hervorstechende",
    "Hervorstechenderen": "Hervorstechendere",
    "Hervorstechens": "Hervorstechen",
    "Hervorstehenden": "Hervorstehende",
    "Hervorstehenderen": "Hervorstehendere",
    "Hervorstehendsten": "Hervorstehendste",
    "Hervorstehens": "Hervorstehen",
    "Hervorstoßenden": "Hervorstoßende",
    "Hervorstoßens": "Hervorstoßen",
    "Hervorstürzenden": "Hervorstürzende",
    "Hervorstürzens": "Hervorstürzen",
    "Hervorsuchenden": "Hervorsuchende",
    "Hervorsuchens": "Hervorsuchen",
    "Hervortauchenden": "Hervortauchende",
    "Hervortauchens": "Hervortauchen",
    "Hervorwagenden": "Hervorwagende",
    "Hervorwagens": "Hervorwagen",
    "Hervorzaubernden": "Hervorzaubernde",
    "Hervorzauberns": "Hervorzaubern",
    "Herwerfenden": "Herwerfende",
    "Herwerfens": "Herwerfen",
    "Herwinkenden": "Herwinkende",
    "Herwinkens": "Herwinken",
    "Herzallerlieben": "Herzallerliebe",
    "Herzaubernden": "Herzaubernde",
    "Herzauberns": "Herzaubern",
    "Herzbeklemmenden": "Herzbeklemmende",
    "Herzbeklemmenderen": "Herzbeklemmendere",
    "Herzchens": "Herzchen",
    "Herzegowinas": "Herzegowina",
    "Herzeigenden": "Herzeigende",
    "Herzeigens": "Herzeigen",
    "Herzeleide": "Herzeleid",
    "Herzeleides": "Herzeleid",
    "Herzeleids": "Herzeleid",
    "Herzen": "Herz",
    "Herzenden": "Herzende",
    "Herzenderen": "Herzendere",
    "Herzendsten": "Herzendste",
    "Herzens": "Herzen",
    "Herzensbrechern": "Herzensbrecher",
    "Herzensbrechers": "Herzensbrecher",
    "Herzensgute": "herzensgut",
    "Herzensguten": "Herzensgute",
    "Herzerfrischenden": "Herzerfrischende",
    "Herzerfrischenderen": "Herzerfrischendere",
    "Herzergreifenden": "Herzergreifende",
    "Herzergreifenderen": "Herzergreifendere",
    "Herzhaften": "Herzhafte",
    "Herzhafteren": "Herzhaftere",
    "Herzhaftesten": "Herzhafteste",
    "Herziehenden": "Herziehende",
    "Herziehens": "Herziehen",
    "Herzlichen": "Herzliche",
    "Herzlicheren": "Herzlichere",
    "Herzlichsten": "Herzlichste",
    "Herzlosen": "Herzlose",
    "Herzloseren": "Herzlosere",
    "Herzlosesten": "Herzloseste",
    "Herzogs": "Herzog",
    "Herzogtume": "Herzogtum",
    "Herzogtumes": "Herzogtum",
    "Herzogtums": "Herzogtum",
    "Herzogtümer": "Herzogtum",
    "Herzogtümern": "Herzogtum",
    "Herzueilenden": "Herzueilende",
    "Herzueilens": "Herzueilen",
    "Herzugeeilten": "Herzugeeilte",
    "Herzzerreißenden": "Herzzerreißende",
    "Herzzerreißenderen": "Herzzerreißendere",
    "Herzählenden": "Herzählende",
    "Herzählens": "Herzählen",
    "Herüberbemühenden": "Herüberbemühende",
    "Herüberbemühens": "Herüberbemühen",
    "Herüberbemühte": "herüberbemüht",
    "Herüberbemühten": "Herüberbemühte",
    "Herüberführenden": "Herüberführende",
    "Herüberführens": "Herüberführen",
    "Herübergeführten": "Herübergeführte",
    "Herübergelangten": "Herübergelangte",
    "Herübergereichten": "Herübergereichte",
    "Herübergerückten": "Herübergerückte",
    "Herübergetragenen": "Herübergetragene",
    "Herübergezogenen": "Herübergezogene",
    "Herüberlangenden": "Herüberlangende",
    "Herüberlangens": "Herüberlangen",
    "Herüberreichenden": "Herüberreichende",
    "Herüberreichens": "Herüberreichen",
    "Herüberrückenden": "Herüberrückende",
    "Herüberrückens": "Herüberrücken",
    "Herübertragenden": "Herübertragende",
    "Herübertragens": "Herübertragen",
    "Herüberziehenden": "Herüberziehende",
    "Herüberziehens": "Herüberziehen",
    "Hessens": "Hessen",
    "Hessische": "hessisch",
    "Hessischen": "Hessische",
    "Hessischeren": "Hessischere",
    "Hessischsten": "Hessischste",
    "Heterogenen": "Heterogene",
    "Heterogeneren": "Heterogenere",
    "Heterogensten": "Heterogenste",
    "Hetzels": "Hetzel",
    "Hetzen": "Hetze",
    "Hetzenden": "Hetzende",
    "Hetzenderen": "Hetzendere",
    "Hetzendsten": "Hetzendste",
    "Hetzens": "Hetzen",
    "Hetzerische": "hetzerisch",
    "Hetzerischen": "Hetzerische",
    "Hetzerischeren": "Hetzerischere",
    "Hetzerischsten": "Hetzerischste",
    "Hetzern": "Hetzer",
    "Hetzers": "Hetzer",
    "Hetzreden": "Hetzrede",
    "Heucheleien": "Heuchelei",
    "Heuchelnden": "Heuchelnde",
    "Heuchelnderen": "Heuchelndere",
    "Heuchelndsten": "Heuchelndste",
    "Heuchelns": "Heucheln",
    "Heuchlerischen": "Heuchlerische",
    "Heuchlerischeren": "Heuchlerischere",
    "Heuchlerischsten": "Heuchlerischste",
    "Heuchlern": "Heuchler",
    "Heuchlers": "Heuchler",
    "Heuernden": "Heuernde",
    "Heuerns": "Heuern",
    "Heulbojen": "Heulboje",
    "Heulenden": "Heulende",
    "Heulenderen": "Heulendere",
    "Heulendsten": "Heulendste",
    "Heulens": "Heulen",
    "Heulern": "Heuler",
    "Heulers": "Heuler",
    "Heuristischen": "Heuristische",
    "Heus": "Heu",
    "Heuschnupfens": "Heuschnupfen",
    "Heuschobern": "Heuschober",
    "Heuschobers": "Heuschober",
    "Heuschrecken": "Heuschrecke",
    "Heutige": "heutig",
    "Heutigen": "Heutige",
    "Hexaden": "Hexade",
    "Hexadezimalsysteme": "Hexadezimalsystem",
    "Hexadezimalsystemen": "Hexadezimalsystem",
    "Hexadezimalsystems": "Hexadezimalsystem",
    "Hexaedern": "Hexaeder",
    "Hexaeders": "Hexaeder",
    "Hexe": "hexen",
    "Hexen": "Hexe",
    "Hexenden": "Hexende",
    "Hexenderen": "Hexendere",
    "Hexendsten": "Hexendste",
    "Hexens": "Hexen",
    "Hexereien": "Hexerei",
    "Heydens": "Heyden",
    "Hickhacks": "Hickhack",
    "Hiebfeste": "hiebfest",
    "Hiebfesten": "Hiebfeste",
    "Hiebfesteren": "Hiebfestere",
    "Hiebfestesten": "Hiebfesteste",
    "Hierarchien": "Hierarchie",
    "Hierbehaltenden": "Hierbehaltende",
    "Hierbehaltenen": "Hierbehaltene",
    "Hierbehaltens": "Hierbehalten",
    "Hierbleibenden": "Hierbleibende",
    "Hierbleibens": "Hierbleiben",
    "Hiergebliebenen": "Hiergebliebene",
    "Hierherbemühenden": "Hierherbemühende",
    "Hierherbemühens": "Hierherbemühen",
    "Hierherbemühte": "hierherbemüht",
    "Hierherbemühten": "Hierherbemühte",
    "Hierherbittenden": "Hierherbittende",
    "Hierherbittens": "Hierherbitten",
    "Hierherbringenden": "Hierherbringende",
    "Hierherbringens": "Hierherbringen",
    "Hierhereilenden": "Hierhereilende",
    "Hierhereilens": "Hierhereilen",
    "Hierherführenden": "Hierherführende",
    "Hierherführens": "Hierherführen",
    "Hierhergebetenen": "Hierhergebetene",
    "Hierhergebrachten": "Hierhergebrachte",
    "Hierhergeeilten": "Hierhergeeilte",
    "Hierhergeführten": "Hierhergeführte",
    "Hierhergeholten": "Hierhergeholte",
    "Hierhergehörenden": "Hierhergehörende",
    "Hierhergehörens": "Hierhergehören",
    "Hierhergehörte": "hierhergehört",
    "Hierhergehörten": "Hierhergehörte",
    "Hierhergekommenen": "Hierhergekommene",
    "Hierhergelegten": "Hierhergelegte",
    "Hierhergereisten": "Hierhergereiste",
    "Hierhergeschaffenen": "Hierhergeschaffene",
    "Hierhergeschafften": "Hierhergeschaffte",
    "Hierhergeschauten": "Hierhergeschaute",
    "Hierhergeschleppten": "Hierhergeschleppte",
    "Hierhergeschobenen": "Hierhergeschobene",
    "Hierhergesetzten": "Hierhergesetzte",
    "Hierhergestellten": "Hierhergestellte",
    "Hierhergetragenen": "Hierhergetragene",
    "Hierhergetriebenen": "Hierhergetriebene",
    "Hierhergewagten": "Hierhergewagte",
    "Hierherholenden": "Hierherholende",
    "Hierherholens": "Hierherholen",
    "Hierherkommenden": "Hierherkommende",
    "Hierherkommens": "Hierherkommen",
    "Hierherlegenden": "Hierherlegende",
    "Hierherlegens": "Hierherlegen",
    "Hierherreisenden": "Hierherreisende",
    "Hierherreisens": "Hierherreisen",
    "Hierherschaffenden": "Hierherschaffende",
    "Hierherschaffens": "Hierherschaffen",
    "Hierherschauenden": "Hierherschauende",
    "Hierherschauens": "Hierherschauen",
    "Hierherschiebenden": "Hierherschiebende",
    "Hierherschiebens": "Hierherschieben",
    "Hierherschleppenden": "Hierherschleppende",
    "Hierherschleppens": "Hierherschleppen",
    "Hierhersetzenden": "Hierhersetzende",
    "Hierhersetzens": "Hierhersetzen",
    "Hierherstellenden": "Hierherstellende",
    "Hierherstellens": "Hierherstellen",
    "Hierhertragenden": "Hierhertragende",
    "Hierhertragens": "Hierhertragen",
    "Hierhertreibenden": "Hierhertreibende",
    "Hierhertreibens": "Hierhertreiben",
    "Hierherwagenden": "Hierherwagende",
    "Hierherwagens": "Hierherwagen",
    "Hierseins": "Hiersein",
    "Hiesigen": "Hiesige",
    "Hievenden": "Hievende",
    "Hievens": "Hieven",
    "Hilbigs": "Hilbig",
    "Hildegards": "Hildegard",
    "Hildes": "Hilde",
    "Hilfen": "Hilfe",
    "Hilfesuchende": "hilfesuchend",
    "Hilfesuchenden": "Hilfesuchende",
    "Hilflosen": "Hilflose",
    "Hilfloseren": "Hilflosere",
    "Hilflosesten": "Hilfloseste",
    "Hilflosigkeiten": "Hilflosigkeit",
    "Hilfreiche": "hilfreich",
    "Hilfreichen": "Hilfreiche",
    "Hilfreicheren": "Hilfreichere",
    "Hilfreichsten": "Hilfreichste",
    "Hilfsarbeiterinnen": "Hilfsarbeiterin",
    "Hilfsarbeitern": "Hilfsarbeiter",
    "Hilfsarbeiters": "Hilfsarbeiter",
    "Hilfsbedürftige": "hilfsbedürftig",
    "Hilfsbedürftigen": "Hilfsbedürftige",
    "Hilfsbedürftigeren": "Hilfsbedürftigere",
    "Hilfsbereiten": "Hilfsbereite",
    "Hilfsbereiteren": "Hilfsbereitere",
    "Hilfsbereitesten": "Hilfsbereiteste",
    "Hilfsdienste": "Hilfsdienst",
    "Hilfsdiensten": "Hilfsdienst",
    "Hilfsdienstes": "Hilfsdienst",
    "Hilfsdiensts": "Hilfsdienst",
    "Hilfskräfte": "Hilfskraft",
    "Hilfskräften": "Hilfskraft",
    "Hilfslehrern": "Hilfslehrer",
    "Hilfslehrers": "Hilfslehrer",
    "Hilfslieferungen": "Hilfslieferung",
    "Hilfsmitteln": "Hilfsmittel",
    "Hilfsmittels": "Hilfsmittel",
    "Hilfsmotore": "Hilfsmotor",
    "Hilfsmotoren": "Hilfsmotor",
    "Hilfsmotors": "Hilfsmotor",
    "Hilfsorganisationen": "Hilfsorganisation",
    "Hilfspredigern": "Hilfsprediger",
    "Hilfspredigers": "Hilfsprediger",
    "Hilfsrichtern": "Hilfsrichter",
    "Hilfsrichters": "Hilfsrichter",
    "Hilfsrudern": "Hilfsruder",
    "Hilfsruders": "Hilfsruder",
    "Hilfsschulen": "Hilfsschule",
    "Hilfsverbe": "Hilfsverb",
    "Hilfsverben": "Hilfsverb",
    "Hilfsverbs": "Hilfsverb",
    "Hilfswerke": "Hilfswerk",
    "Hilfswerken": "Hilfswerk",
    "Hilfswerkes": "Hilfswerk",
    "Hilfswerks": "Hilfswerk",
    "Hills": "Hill",
    "Himbachern": "Himbacher",
    "Himbachers": "Himbacher",
    "Himbeeren": "Himbeere",
    "Himmel": "himmeln",
    "Himmeln": "Himmel",
    "Himmelnden": "Himmelnde",
    "Himmelns": "Himmeln",
    "Himmels": "Himmel",
    "Himmelschreiende": "himmelschreiend",
    "Himmelschreienden": "Himmelschreiende",
    "Himmelweiten": "Himmelweite",
    "Himmlischen": "Himmlische",
    "Himmlischeren": "Himmlischere",
    "Himmlischsten": "Himmlischste",
    "Hinabgesehenen": "Hinabgesehene",
    "Hinabgesunkenen": "Hinabgesunkene",
    "Hinabgesunkeneren": "Hinabgesunkenere",
    "Hinabgesunkensten": "Hinabgesunkenste",
    "Hinabsehenden": "Hinabsehende",
    "Hinabsehens": "Hinabsehen",
    "Hinabsinkenden": "Hinabsinkende",
    "Hinabsinkenderen": "Hinabsinkendere",
    "Hinabsinkendsten": "Hinabsinkendste",
    "Hinabsinkens": "Hinabsinken",
    "Hinarbeitenden": "Hinarbeitende",
    "Hinarbeitens": "Hinarbeiten",
    "Hinaufbemühenden": "Hinaufbemühende",
    "Hinaufbemühens": "Hinaufbemühen",
    "Hinaufbemühte": "hinaufbemüht",
    "Hinaufbemühten": "Hinaufbemühte",
    "Hinaufgereichten": "Hinaufgereichte",
    "Hinaufgeschaffenen": "Hinaufgeschaffene",
    "Hinaufgeschafften": "Hinaufgeschaffte",
    "Hinaufgestellten": "Hinaufgestellte",
    "Hinaufgewundenen": "Hinaufgewundene",
    "Hinaufgezogenen": "Hinaufgezogene",
    "Hinaufreichenden": "Hinaufreichende",
    "Hinaufreichens": "Hinaufreichen",
    "Hinaufschaffenden": "Hinaufschaffende",
    "Hinaufschaffens": "Hinaufschaffen",
    "Hinaufstellenden": "Hinaufstellende",
    "Hinaufstellens": "Hinaufstellen",
    "Hinaufwindenden": "Hinaufwindende",
    "Hinaufwindens": "Hinaufwinden",
    "Hinaufziehenden": "Hinaufziehende",
    "Hinaufziehens": "Hinaufziehen",
    "Hinausgereichten": "Hinausgereichte",
    "Hinausgeschossenen": "Hinausgeschossene",
    "Hinausgeschrienen": "Hinausgeschriene",
    "Hinausgestürzten": "Hinausgestürzte",
    "Hinauskomplimentiereen": "Hinauskomplimentieree",
    "Hinauskomplimentierte": "hinauskomplimentiert",
    "Hinauskomplimentierten": "Hinauskomplimentierte",
    "Hinausreichenden": "Hinausreichende",
    "Hinausreichens": "Hinausreichen",
    "Hinausschießenden": "Hinausschießende",
    "Hinausschießens": "Hinausschießen",
    "Hinausschreienden": "Hinausschreiende",
    "Hinausschreiens": "Hinausschreien",
    "Hinausstürzenden": "Hinausstürzende",
    "Hinausstürzens": "Hinausstürzen",
    "Hinbegleitenden": "Hinbegleitende",
    "Hinbegleitens": "Hinbegleiten",
    "Hinbegleitete": "hinbegleitet",
    "Hinbegleiteten": "Hinbegleitete",
    "Hinbemühenden": "Hinbemühende",
    "Hinbemühens": "Hinbemühen",
    "Hinbemühte": "hinbemüht",
    "Hinbemühten": "Hinbemühte",
    "Hinbestellenden": "Hinbestellende",
    "Hinbestellens": "Hinbestellen",
    "Hinbestellte": "hinbestellt",
    "Hinbestellten": "Hinbestellte",
    "Hinbiegenden": "Hinbiegende",
    "Hinbiegens": "Hinbiegen",
    "Hinblicke": "Hinblick",
    "Hinblicken": "Hinblick",
    "Hinblickes": "Hinblick",
    "Hinblicks": "Hinblick",
    "Hinblätternden": "Hinblätternde",
    "Hinblätterns": "Hinblättern",
    "Hinbringenden": "Hinbringende",
    "Hinbringens": "Hinbringen",
    "Hinbrütenden": "Hinbrütende",
    "Hinbrütens": "Hinbrüten",
    "Hindemiths": "Hindemith",
    "Hindenkenden": "Hindenkende",
    "Hindenkens": "Hindenken",
    "Hinderlichen": "Hinderliche",
    "Hinderlicheren": "Hinderlichere",
    "Hinderlichsten": "Hinderlichste",
    "Hindernden": "Hindernde",
    "Hindernisse": "Hindernis",
    "Hindernissen": "Hindernis",
    "Hindernisses": "Hindernis",
    "Hinderns": "Hindern",
    "Hindeutenden": "Hindeutende",
    "Hindeutens": "Hindeuten",
    "Hindrängenden": "Hindrängende",
    "Hindrängens": "Hindrängen",
    "Hindurcharbeitenden": "Hindurcharbeitende",
    "Hindurcharbeitens": "Hindurcharbeiten",
    "Hindurchfließenden": "Hindurchfließende",
    "Hindurchfließens": "Hindurchfließen",
    "Hindurchgearbeiteten": "Hindurchgearbeitete",
    "Hindurchgeflossenen": "Hindurchgeflossene",
    "Hindurchgekrochenen": "Hindurchgekrochene",
    "Hindurchgezwängten": "Hindurchgezwängte",
    "Hindurchkriechenden": "Hindurchkriechende",
    "Hindurchkriechens": "Hindurchkriechen",
    "Hindurchzwängenden": "Hindurchzwängende",
    "Hindurchzwängens": "Hindurchzwängen",
    "Hindämmernden": "Hindämmernde",
    "Hindämmerns": "Hindämmern",
    "Hineilenden": "Hineilende",
    "Hineilens": "Hineilen",
    "Hineinbemühenden": "Hineinbemühende",
    "Hineinbemühens": "Hineinbemühen",
    "Hineinbemühte": "hineinbemüht",
    "Hineinbemühten": "Hineinbemühte",
    "Hineinbohrenden": "Hineinbohrende",
    "Hineinbohrens": "Hineinbohren",
    "Hineinfressenden": "Hineinfressende",
    "Hineinfressens": "Hineinfressen",
    "Hineinführenden": "Hineinführende",
    "Hineinführens": "Hineinführen",
    "Hineingebohrten": "Hineingebohrte",
    "Hineingefressenen": "Hineingefressene",
    "Hineingeführten": "Hineingeführte",
    "Hineingehangenen": "Hineingehangene",
    "Hineingehängten": "Hineingehängte",
    "Hineingelesenen": "Hineingelesene",
    "Hineingepaßten": "Hineingepaßte",
    "Hineingepaßteren": "Hineingepaßtere",
    "Hineingepaßtesten": "Hineingepaßteste",
    "Hineingereichten": "Hineingereichte",
    "Hineingerittenen": "Hineingerittene",
    "Hineingeschlungenen": "Hineingeschlungene",
    "Hineingestürzten": "Hineingestürzte",
    "Hineingezogenen": "Hineingezogene",
    "Hineinhängenden": "Hineinhängende",
    "Hineinhängens": "Hineinhängen",
    "Hineinlesenden": "Hineinlesende",
    "Hineinlesens": "Hineinlesen",
    "Hineinpassenden": "Hineinpassende",
    "Hineinpassenderen": "Hineinpassendere",
    "Hineinpassendsten": "Hineinpassendste",
    "Hineinpassens": "Hineinpassen",
    "Hineinprojizierenden": "Hineinprojizierende",
    "Hineinprojizierens": "Hineinprojizieren",
    "Hineinprojizierte": "hineinprojiziert",
    "Hineinprojizierten": "Hineinprojizierte",
    "Hineinreichenden": "Hineinreichende",
    "Hineinreichens": "Hineinreichen",
    "Hineinreitenden": "Hineinreitende",
    "Hineinreitens": "Hineinreiten",
    "Hineinschlingenden": "Hineinschlingende",
    "Hineinschlingens": "Hineinschlingen",
    "Hineinstürzenden": "Hineinstürzende",
    "Hineinstürzens": "Hineinstürzen",
    "Hineinziehenden": "Hineinziehende",
    "Hineinziehens": "Hineinziehen",
    "Hinfahrenden": "Hinfahrende",
    "Hinfahrens": "Hinfahren",
    "Hinfallenden": "Hinfallende",
    "Hinfallens": "Hinfallen",
    "Hinfindenden": "Hinfindende",
    "Hinfindens": "Hinfinden",
    "Hinflegelnden": "Hinflegelnde",
    "Hinflegelnderen": "Hinflegelndere",
    "Hinflegelndsten": "Hinflegelndste",
    "Hinflegelns": "Hinflegeln",
    "Hinfliegenden": "Hinfliegende",
    "Hinfliegens": "Hinfliegen",
    "Hinfließenden": "Hinfließende",
    "Hinfließens": "Hinfließen",
    "Hinfläzenden": "Hinfläzende",
    "Hinfläzenderen": "Hinfläzendere",
    "Hinfläzendsten": "Hinfläzendste",
    "Hinfläzens": "Hinfläzen",
    "Hinfälligen": "Hinfällige",
    "Hinführenden": "Hinführende",
    "Hinführens": "Hinführen",
    "Hingabefähigen": "Hingabefähige",
    "Hingabefähigeren": "Hingabefähigere",
    "Hingabefähigsten": "Hingabefähigste",
    "Hingearbeiteten": "Hingearbeitete",
    "Hingebenden": "Hingebende",
    "Hingebens": "Hingeben",
    "Hingeblätterten": "Hingeblätterte",
    "Hingebogenen": "Hingebogene",
    "Hingebrachten": "Hingebrachte",
    "Hingebrüteten": "Hingebrütete",
    "Hingebungsvollen": "Hingebungsvolle",
    "Hingebungsvolleren": "Hingebungsvollere",
    "Hingedachten": "Hingedachte",
    "Hingedeuteten": "Hingedeutete",
    "Hingedrängten": "Hingedrängte",
    "Hingedämmerten": "Hingedämmerte",
    "Hingeeilten": "Hingeeilte",
    "Hingefahrenen": "Hingefahrene",
    "Hingefallenen": "Hingefallene",
    "Hingeflegelten": "Hingeflegelte",
    "Hingeflogenen": "Hingeflogene",
    "Hingeflossenen": "Hingeflossene",
    "Hingefläzten": "Hingefläzte",
    "Hingefläzteren": "Hingefläztere",
    "Hingefläztesten": "Hingefläzteste",
    "Hingefundenen": "Hingefundene",
    "Hingeführten": "Hingeführte",
    "Hingegangenen": "Hingegangene",
    "Hingegebenen": "Hingegebene",
    "Hingegossenen": "Hingegossene",
    "Hingehaltenen": "Hingehaltene",
    "Hingehalteneren": "Hingehaltenere",
    "Hingehaltensten": "Hingehaltenste",
    "Hingehangenen": "Hingehangene",
    "Hingehauchten": "Hingehauchte",
    "Hingehauenen": "Hingehauene",
    "Hingehenden": "Hingehende",
    "Hingehens": "Hingehen",
    "Hingehorchten": "Hingehorchte",
    "Hingehorchteren": "Hingehorchtere",
    "Hingehorchtesten": "Hingehorchteste",
    "Hingehängten": "Hingehängte",
    "Hingehörenden": "Hingehörende",
    "Hingehörens": "Hingehören",
    "Hingehörte": "hingehört",
    "Hingehörten": "Hingehörte",
    "Hingekauerten": "Hingekauerte",
    "Hingekauerteren": "Hingekauertere",
    "Hingekauertesten": "Hingekauerteste",
    "Hingeklotzten": "Hingeklotzte",
    "Hingeknieten": "Hingekniete",
    "Hingekommenen": "Hingekommene",
    "Hingekriegten": "Hingekriegte",
    "Hingelangten": "Hingelangte",
    "Hingelassenen": "Hingelassene",
    "Hingelaufenen": "Hingelaufene",
    "Hingelegten": "Hingelegte",
    "Hingelümmelten": "Hingelümmelte",
    "Hingelümmelteren": "Hingelümmeltere",
    "Hingelümmeltesten": "Hingelümmelteste",
    "Hingemachten": "Hingemachte",
    "Hingeneigten": "Hingeneigte",
    "Hingenommenen": "Hingenommene",
    "Hingepurzelten": "Hingepurzelte",
    "Hingerafften": "Hingeraffte",
    "Hingerannten": "Hingerannte",
    "Hingeratenden": "Hingeratende",
    "Hingeratenen": "Hingeratene",
    "Hingeratens": "Hingeraten",
    "Hingereichten": "Hingereichte",
    "Hingereisten": "Hingereiste",
    "Hingerichteten": "Hingerichtete",
    "Hingeriebenen": "Hingeriebene",
    "Hingerissenen": "Hingerissene",
    "Hingerisseneren": "Hingerissenere",
    "Hingerissensten": "Hingerissenste",
    "Hingesagten": "Hingesagte",
    "Hingeschaffenen": "Hingeschaffene",
    "Hingeschafften": "Hingeschaffte",
    "Hingeschauten": "Hingeschaute",
    "Hingeschiedenen": "Hingeschiedene",
    "Hingeschlachteten": "Hingeschlachtete",
    "Hingeschlagenen": "Hingeschlagene",
    "Hingeschleppten": "Hingeschleppte",
    "Hingeschlichenen": "Hingeschlichene",
    "Hingeschmierten": "Hingeschmierte",
    "Hingeschmissenen": "Hingeschmissene",
    "Hingeschmolzenen": "Hingeschmolzene",
    "Hingeschmolzeneren": "Hingeschmolzenere",
    "Hingeschobenen": "Hingeschobene",
    "Hingeschriebenen": "Hingeschriebene",
    "Hingeschwommenen": "Hingeschwommene",
    "Hingeschwundenen": "Hingeschwundene",
    "Hingeschütteten": "Hingeschüttete",
    "Hingesehenen": "Hingesehene",
    "Hingesetzten": "Hingesetzte",
    "Hingesiechten": "Hingesiechte",
    "Hingesiechteren": "Hingesiechtere",
    "Hingesiechtesten": "Hingesiechteste",
    "Hingestellten": "Hingestellte",
    "Hingesteuerten": "Hingesteuerte",
    "Hingestorbenen": "Hingestorbene",
    "Hingestrebten": "Hingestrebte",
    "Hingeströmten": "Hingeströmte",
    "Hingestürzten": "Hingestürzte",
    "Hingesunkenen": "Hingesunkene",
    "Hingetragenen": "Hingetragene",
    "Hingetretenen": "Hingetretene",
    "Hingetriebenen": "Hingetriebene",
    "Hingewandten": "Hingewandte",
    "Hingewelkten": "Hingewelkte",
    "Hingewelkteren": "Hingewelktere",
    "Hingewelktesten": "Hingewelkteste",
    "Hingewendeten": "Hingewendete",
    "Hingewiesenen": "Hingewiesene",
    "Hingewirkten": "Hingewirkte",
    "Hingeworfenen": "Hingeworfene",
    "Hingezauberten": "Hingezauberte",
    "Hingezeigten": "Hingezeigte",
    "Hingezogenen": "Hingezogene",
    "Hingezogeneren": "Hingezogenere",
    "Hingezogensten": "Hingezogenste",
    "Hingezählten": "Hingezählte",
    "Hingießenden": "Hingießende",
    "Hingießens": "Hingießen",
    "Hinhaltenden": "Hinhaltende",
    "Hinhaltenderen": "Hinhaltendere",
    "Hinhaltendsten": "Hinhaltendste",
    "Hinhaltens": "Hinhalten",
    "Hinhauchenden": "Hinhauchende",
    "Hinhauchens": "Hinhauchen",
    "Hinhauenden": "Hinhauende",
    "Hinhauens": "Hinhauen",
    "Hinhorchenden": "Hinhorchende",
    "Hinhorchenderen": "Hinhorchendere",
    "Hinhorchendsten": "Hinhorchendste",
    "Hinhorchens": "Hinhorchen",
    "Hinhängenden": "Hinhängende",
    "Hinhängens": "Hinhängen",
    "Hinhörenden": "Hinhörende",
    "Hinhörenderen": "Hinhörendere",
    "Hinhörendsten": "Hinhörendste",
    "Hinhörens": "Hinhören",
    "Hinkauernden": "Hinkauernde",
    "Hinkauernderen": "Hinkauerndere",
    "Hinkauerndsten": "Hinkauerndste",
    "Hinkauerns": "Hinkauern",
    "Hinkenden": "Hinkende",
    "Hinkenderen": "Hinkendere",
    "Hinkendsten": "Hinkendste",
    "Hinkens": "Hinken",
    "Hinklotzenden": "Hinklotzende",
    "Hinklotzens": "Hinklotzen",
    "Hinknienden": "Hinkniende",
    "Hinkniens": "Hinknien",
    "Hinkommenden": "Hinkommende",
    "Hinkommens": "Hinkommen",
    "Hinkriegenden": "Hinkriegende",
    "Hinkriegens": "Hinkriegen",
    "Hinlangenden": "Hinlangende",
    "Hinlangens": "Hinlangen",
    "Hinlassenden": "Hinlassende",
    "Hinlassens": "Hinlassen",
    "Hinlaufenden": "Hinlaufende",
    "Hinlaufens": "Hinlaufen",
    "Hinlegenden": "Hinlegende",
    "Hinlegens": "Hinlegen",
    "Hinlümmelnden": "Hinlümmelnde",
    "Hinlümmelnderen": "Hinlümmelndere",
    "Hinlümmelndsten": "Hinlümmelndste",
    "Hinlümmelns": "Hinlümmeln",
    "Hinmachenden": "Hinmachende",
    "Hinmachens": "Hinmachen",
    "Hinnehmenden": "Hinnehmende",
    "Hinnehmens": "Hinnehmen",
    "Hinneigenden": "Hinneigende",
    "Hinneigens": "Hinneigen",
    "Hinpurzelnden": "Hinpurzelnde",
    "Hinpurzelns": "Hinpurzeln",
    "Hinraffenden": "Hinraffende",
    "Hinraffens": "Hinraffen",
    "Hinreibenden": "Hinreibende",
    "Hinreibens": "Hinreiben",
    "Hinreichenden": "Hinreichende",
    "Hinreichenderen": "Hinreichendere",
    "Hinreichendsten": "Hinreichendste",
    "Hinreichens": "Hinreichen",
    "Hinreisenden": "Hinreisende",
    "Hinreisens": "Hinreisen",
    "Hinreißenden": "Hinreißende",
    "Hinreißenderen": "Hinreißendere",
    "Hinreißendsten": "Hinreißendste",
    "Hinreißens": "Hinreißen",
    "Hinrennenden": "Hinrennende",
    "Hinrennens": "Hinrennen",
    "Hinrichtenden": "Hinrichtende",
    "Hinrichtens": "Hinrichten",
    "Hinsagenden": "Hinsagende",
    "Hinsagens": "Hinsagen",
    "Hinschaffenden": "Hinschaffende",
    "Hinschaffens": "Hinschaffen",
    "Hinschauenden": "Hinschauende",
    "Hinschauens": "Hinschauen",
    "Hinscheidenden": "Hinscheidende",
    "Hinscheidens": "Hinscheiden",
    "Hinschiebenden": "Hinschiebende",
    "Hinschiebens": "Hinschieben",
    "Hinschlachtenden": "Hinschlachtende",
    "Hinschlachtens": "Hinschlachten",
    "Hinschlagenden": "Hinschlagende",
    "Hinschlagens": "Hinschlagen",
    "Hinschleichenden": "Hinschleichende",
    "Hinschleichens": "Hinschleichen",
    "Hinschleppenden": "Hinschleppende",
    "Hinschleppens": "Hinschleppen",
    "Hinschmeißenden": "Hinschmeißende",
    "Hinschmeißens": "Hinschmeißen",
    "Hinschmelzenden": "Hinschmelzende",
    "Hinschmelzenderen": "Hinschmelzendere",
    "Hinschmelzendsten": "Hinschmelzendste",
    "Hinschmelzens": "Hinschmelzen",
    "Hinschmierenden": "Hinschmierende",
    "Hinschmierens": "Hinschmieren",
    "Hinschreibenden": "Hinschreibende",
    "Hinschreibens": "Hinschreiben",
    "Hinschwimmenden": "Hinschwimmende",
    "Hinschwimmens": "Hinschwimmen",
    "Hinschwindenden": "Hinschwindende",
    "Hinschwindens": "Hinschwinden",
    "Hinschüttenden": "Hinschüttende",
    "Hinschüttens": "Hinschütten",
    "Hinsehenden": "Hinsehende",
    "Hinsehens": "Hinsehen",
    "Hinsetzenden": "Hinsetzende",
    "Hinsetzens": "Hinsetzen",
    "Hinsiechenden": "Hinsiechende",
    "Hinsiechenderen": "Hinsiechendere",
    "Hinsiechendsten": "Hinsiechendste",
    "Hinsiechens": "Hinsiechen",
    "Hinsinkenden": "Hinsinkende",
    "Hinsinkens": "Hinsinken",
    "Hinstellenden": "Hinstellende",
    "Hinstellens": "Hinstellen",
    "Hinsterbenden": "Hinsterbende",
    "Hinsterbens": "Hinsterben",
    "Hinsteuernden": "Hinsteuernde",
    "Hinsteuerns": "Hinsteuern",
    "Hinstrebenden": "Hinstrebende",
    "Hinstrebens": "Hinstreben",
    "Hinströmenden": "Hinströmende",
    "Hinströmens": "Hinströmen",
    "Hinstürzenden": "Hinstürzende",
    "Hinstürzens": "Hinstürzen",
    "Hintenangestellten": "Hintenangestellte",
    "Hintenanstellenden": "Hintenanstellende",
    "Hintenanstellens": "Hintenanstellen",
    "Hintenüberfallenden": "Hintenüberfallende",
    "Hintenüberfallens": "Hintenüberfallen",
    "Hintenübergefallenen": "Hintenübergefallene",
    "Hintenübergekippte": "hintenübergekippt",
    "Hintenübergekippten": "Hintenübergekippte",
    "Hintenüberkippenden": "Hintenüberkippende",
    "Hintenüberkippens": "Hintenüberkippen",
    "Hinterbeine": "Hinterbein",
    "Hinterbeinen": "Hinterbein",
    "Hinterbeins": "Hinterbein",
    "Hinterbliebenen": "Hinterbliebene",
    "Hinterbänklern": "Hinterbänkler",
    "Hinterbänklers": "Hinterbänkler",
    "Hinterdecks": "Hinterdeck",
    "Hintere": "hinter",
    "Hinteren": "Hintere",
    "Hintereren": "Hinterere",
    "Hinteressenden": "Hinteressende",
    "Hinteressens": "Hinteressen",
    "Hinterfotzigen": "Hinterfotzige",
    "Hinterfotzigeren": "Hinterfotzigere",
    "Hinterfotzigsten": "Hinterfotzigste",
    "Hinterfragenden": "Hinterfragende",
    "Hinterfragenderen": "Hinterfragendere",
    "Hinterfragendsten": "Hinterfragendste",
    "Hinterfragens": "Hinterfragen",
    "Hinterfragte": "hinterfragt",
    "Hinterfragten": "Hinterfragte",
    "Hinterfragteren": "Hinterfragtere",
    "Hinterfragtesten": "Hinterfragteste",
    "Hintergangenen": "Hintergangene",
    "Hintergebäuden": "Hintergebäude",
    "Hintergebäudes": "Hintergebäude",
    "Hintergedanken": "Hintergedanke",
    "Hintergegessenen": "Hintergegessene",
    "Hintergegossenen": "Hintergegossene",
    "Hintergehakten": "Hintergehakte",
    "Hintergehenden": "Hintergehende",
    "Hintergehens": "Hintergehen",
    "Hintergekauten": "Hintergekaute",
    "Hintergestelle": "Hintergestell",
    "Hintergestellen": "Hintergestell",
    "Hintergestells": "Hintergestell",
    "Hintergießenden": "Hintergießende",
    "Hintergießens": "Hintergießen",
    "Hinterglasmalereien": "Hinterglasmalerei",
    "Hintergrunde": "Hintergrund",
    "Hintergrunds": "Hintergrund",
    "Hintergründe": "Hintergrund",
    "Hintergründen": "Hintergrund",
    "Hintergründige": "hintergründig",
    "Hintergründigen": "Hintergründige",
    "Hintergründigeren": "Hintergründigere",
    "Hintergründigsten": "Hintergründigste",
    "Hinterhakenden": "Hinterhakende",
    "Hinterhakens": "Hinterhaken",
    "Hinterhause": "Hinterhaus",
    "Hinterhauses": "Hinterhaus",
    "Hinterherfahrenden": "Hinterherfahrende",
    "Hinterherfahrens": "Hinterherfahren",
    "Hinterhergefahrenen": "Hinterhergefahrene",
    "Hinterhergeräumten": "Hinterhergeräumte",
    "Hinterhergesandten": "Hinterhergesandte",
    "Hinterhergeschwommenen": "Hinterhergeschwommene",
    "Hinterhergesendeten": "Hinterhergesendete",
    "Hinterhergesprungenen": "Hinterhergesprungene",
    "Hinterherräumenden": "Hinterherräumende",
    "Hinterherräumens": "Hinterherräumen",
    "Hinterherschwimmenden": "Hinterherschwimmende",
    "Hinterherschwimmens": "Hinterherschwimmen",
    "Hinterhersendenden": "Hinterhersendende",
    "Hinterhersendens": "Hinterhersenden",
    "Hinterherspringenden": "Hinterherspringende",
    "Hinterherspringens": "Hinterherspringen",
    "Hinterhofe": "Hinterhof",
    "Hinterhofs": "Hinterhof",
    "Hinterhältigen": "Hinterhältige",
    "Hinterhältigeren": "Hinterhältigere",
    "Hinterhältigsten": "Hinterhältigste",
    "Hinterhände": "Hinterhand",
    "Hinterhänden": "Hinterhand",
    "Hinterhäuser": "Hinterhaus",
    "Hinterhäusern": "Hinterhaus",
    "Hinterhöfe": "Hinterhof",
    "Hinterhöfen": "Hinterhof",
    "Hinterkauenden": "Hinterkauende",
    "Hinterkauens": "Hinterkauen",
    "Hinterladern": "Hinterlader",
    "Hinterladers": "Hinterlader",
    "Hinterlands": "Hinterland",
    "Hinterlassenden": "Hinterlassende",
    "Hinterlassenen": "Hinterlassene",
    "Hinterlassens": "Hinterlassen",
    "Hinterlassenschaften": "Hinterlassenschaft",
    "Hinterlaufe": "Hinterlauf",
    "Hinterlaufs": "Hinterlauf",
    "Hinterlegenden": "Hinterlegende",
    "Hinterlegens": "Hinterlegen",
    "Hinterlegern": "Hinterleger",
    "Hinterlegers": "Hinterleger",
    "Hinterlegte": "hinterlegt",
    "Hinterlegten": "Hinterlegte",
    "Hinterleibe": "Hinterleib",
    "Hinterleiber": "Hinterleib",
    "Hinterleibern": "Hinterleib",
    "Hinterleibes": "Hinterleib",
    "Hinterleibs": "Hinterleib",
    "Hinterlistigen": "Hinterlistige",
    "Hinterlistigeren": "Hinterlistigere",
    "Hinterlistigsten": "Hinterlistigste",
    "Hinterläufe": "Hinterlauf",
    "Hinterläufen": "Hinterlauf",
    "Hintermanne": "Hintermann",
    "Hintermannes": "Hintermann",
    "Hintermanns": "Hintermann",
    "Hintermänner": "Hintermann",
    "Hintermännern": "Hintermann",
    "Hinterrade": "Hinterrad",
    "Hinterrades": "Hinterrad",
    "Hinterrads": "Hinterrad",
    "Hinterräder": "Hinterrad",
    "Hinterrädern": "Hinterrad",
    "Hintersinnige": "hintersinnig",
    "Hintersinnigen": "Hintersinnige",
    "Hintersinnigeren": "Hintersinnigere",
    "Hintersinnigsten": "Hintersinnigste",
    "Hintersten": "Hinterste",
    "Hinterteile": "Hinterteil",
    "Hinterteilen": "Hinterteil",
    "Hinterteils": "Hinterteil",
    "Hintertreffens": "Hintertreffen",
    "Hintertreppen": "Hintertreppe",
    "Hintertürchens": "Hintertürchen",
    "Hintertüren": "Hintertür",
    "Hinterwäldlerische": "hinterwäldlerisch",
    "Hinterwäldlerischen": "Hinterwäldlerische",
    "Hinterwäldlerischeren": "Hinterwäldlerischere",
    "Hinterwäldlern": "Hinterwäldler",
    "Hinterwäldlers": "Hinterwäldler",
    "Hinterziehenden": "Hinterziehende",
    "Hinterziehens": "Hinterziehen",
    "Hinterziehungen": "Hinterziehung",
    "Hinterzimmern": "Hinterzimmer",
    "Hinterzimmers": "Hinterzimmer",
    "Hinterzogenen": "Hinterzogene",
    "Hintragenden": "Hintragende",
    "Hintragens": "Hintragen",
    "Hintreibenden": "Hintreibende",
    "Hintreibens": "Hintreiben",
    "Hintretenden": "Hintretende",
    "Hintretens": "Hintreten",
    "Hinunterbemühenden": "Hinunterbemühende",
    "Hinunterbemühens": "Hinunterbemühen",
    "Hinunterbemühte": "hinunterbemüht",
    "Hinunterbemühten": "Hinunterbemühte",
    "Hinunterfließenden": "Hinunterfließende",
    "Hinunterfließens": "Hinunterfließen",
    "Hinunterführenden": "Hinunterführende",
    "Hinunterführens": "Hinunterführen",
    "Hinuntergeflossenen": "Hinuntergeflossene",
    "Hinuntergeführten": "Hinuntergeführte",
    "Hinuntergestürzten": "Hinuntergestürzte",
    "Hinuntergezogenen": "Hinuntergezogene",
    "Hinunterstürzenden": "Hinunterstürzende",
    "Hinunterstürzens": "Hinunterstürzen",
    "Hinunterziehenden": "Hinunterziehende",
    "Hinunterziehens": "Hinunterziehen",
    "Hinwege": "Hinweg",
    "Hinwegen": "Hinweg",
    "Hinweggekommenen": "Hinweggekommene",
    "Hinweggesehenen": "Hinweggesehene",
    "Hinweggesetzten": "Hinweggesetzte",
    "Hinweggetrösteten": "Hinweggetröstete",
    "Hinweggetäuschten": "Hinweggetäuschte",
    "Hinwegkommenden": "Hinwegkommende",
    "Hinwegkommens": "Hinwegkommen",
    "Hinwegs": "Hinweg",
    "Hinwegsehenden": "Hinwegsehende",
    "Hinwegsehens": "Hinwegsehen",
    "Hinwegsetzenden": "Hinwegsetzende",
    "Hinwegsetzens": "Hinwegsetzen",
    "Hinwegtröstenden": "Hinwegtröstende",
    "Hinwegtröstens": "Hinwegtrösten",
    "Hinwegtäuschenden": "Hinwegtäuschende",
    "Hinwegtäuschens": "Hinwegtäuschen",
    "Hinweise": "hinweisen",
    "Hinweisen": "Hinweis",
    "Hinweisenden": "Hinweisende",
    "Hinweisens": "Hinweisen",
    "Hinweises": "Hinweis",
    "Hinwelkenden": "Hinwelkende",
    "Hinwelkenderen": "Hinwelkendere",
    "Hinwelkendsten": "Hinwelkendste",
    "Hinwelkens": "Hinwelken",
    "Hinwendenden": "Hinwendende",
    "Hinwendens": "Hinwenden",
    "Hinwendungen": "Hinwendung",
    "Hinwerfenden": "Hinwerfende",
    "Hinwerfens": "Hinwerfen",
    "Hinwirkenden": "Hinwirkende",
    "Hinwirkens": "Hinwirken",
    "Hinzaubernden": "Hinzaubernde",
    "Hinzauberns": "Hinzaubern",
    "Hinzeigenden": "Hinzeigende",
    "Hinzeigens": "Hinzeigen",
    "Hinziehenden": "Hinziehende",
    "Hinziehens": "Hinziehen",
    "Hinzudenkenden": "Hinzudenkende",
    "Hinzudenkens": "Hinzudenken",
    "Hinzufügenden": "Hinzufügende",
    "Hinzufügens": "Hinzufügen",
    "Hinzugedachten": "Hinzugedachte",
    "Hinzugefügten": "Hinzugefügte",
    "Hinzugesellenden": "Hinzugesellende",
    "Hinzugesellens": "Hinzugesellen",
    "Hinzugesellte": "hinzugesellt",
    "Hinzugesellten": "Hinzugesellte",
    "Hinzugesetzten": "Hinzugesetzte",
    "Hinzugestellten": "Hinzugestellte",
    "Hinzugetretenen": "Hinzugetretene",
    "Hinzugezählten": "Hinzugezählte",
    "Hinzusetzenden": "Hinzusetzende",
    "Hinzusetzens": "Hinzusetzen",
    "Hinzustellenden": "Hinzustellende",
    "Hinzustellens": "Hinzustellen",
    "Hinzutretenden": "Hinzutretende",
    "Hinzutretens": "Hinzutreten",
    "Hinzuzählenden": "Hinzuzählende",
    "Hinzuzählens": "Hinzuzählen",
    "Hinzählenden": "Hinzählende",
    "Hinzählens": "Hinzählen",
    "Hinüberbemühenden": "Hinüberbemühende",
    "Hinüberbemühens": "Hinüberbemühen",
    "Hinüberbemühte": "hinüberbemüht",
    "Hinüberbemühten": "Hinüberbemühte",
    "Hinüberführenden": "Hinüberführende",
    "Hinüberführens": "Hinüberführen",
    "Hinübergeführten": "Hinübergeführte",
    "Hinübergelappten": "Hinübergelappte",
    "Hinübergereichten": "Hinübergereichte",
    "Hinübergerückten": "Hinübergerückte",
    "Hinübergeschauten": "Hinübergeschaute",
    "Hinübergezogenen": "Hinübergezogene",
    "Hinüberlappenden": "Hinüberlappende",
    "Hinüberlappenderen": "Hinüberlappendere",
    "Hinüberlappens": "Hinüberlappen",
    "Hinüberreichenden": "Hinüberreichende",
    "Hinüberreichens": "Hinüberreichen",
    "Hinüberrückenden": "Hinüberrückende",
    "Hinüberrückens": "Hinüberrücken",
    "Hinüberschauenden": "Hinüberschauende",
    "Hinüberschauens": "Hinüberschauen",
    "Hinüberziehenden": "Hinüberziehende",
    "Hinüberziehens": "Hinüberziehen",
    "Hiphops": "Hiphop",
    "Hippies": "Hippie",
    "Hippokratikern": "Hippokratiker",
    "Hippokratikers": "Hippokratiker",
    "Hippokratische": "hippokratisch",
    "Hippokratischen": "Hippokratische",
    "Hirne": "Hirn",
    "Hirnen": "Hirn",
    "Hirngeschädigte": "hirngeschädigt",
    "Hirngeschädigten": "Hirngeschädigte",
    "Hirnlosen": "Hirnlose",
    "Hirnloseren": "Hirnlosere",
    "Hirnlosesten": "Hirnloseste",
    "Hirnrissigen": "Hirnrissige",
    "Hirnrissigeren": "Hirnrissigere",
    "Hirnrissigsten": "Hirnrissigste",
    "Hirns": "Hirn",
    "Hirnverbrannte": "hirnverbrannt",
    "Hirnverbrannten": "Hirnverbrannte",
    "Hirnverbrannteren": "Hirnverbranntere",
    "Hirsche": "Hirsch",
    "Hirschen": "Hirsch",
    "Hirsches": "Hirsch",
    "Hirschs": "Hirsch",
    "Hirten": "Hirte",
    "Hirtinnen": "Hirtin",
    "Histogramme": "Histogramm",
    "Histogrammen": "Histogramm",
    "Histogramms": "Histogramm",
    "Historikerinnen": "Historikerin",
    "Historikern": "Historiker",
    "Historikers": "Historiker",
    "Historische": "historisch",
    "Historischen": "Historische",
    "Historisten": "Historist",
    "Hitlerdeutschlands": "Hitlerdeutschland",
    "Hitlers": "Hitler",
    "Hitparaden": "Hitparade",
    "Hits": "Hit",
    "Hitzebeständige": "hitzebeständig",
    "Hitzebeständigen": "Hitzebeständige",
    "Hitzebeständigeren": "Hitzebeständigere",
    "Hitzeempfindlichen": "Hitzeempfindliche",
    "Hitzeempfindlicheren": "Hitzeempfindlichere",
    "Hitzegeplagten": "Hitzegeplagte",
    "Hitzegeplagteren": "Hitzegeplagtere",
    "Hitzegeplagtesten": "Hitzegeplagteste",
    "Hitzigen": "Hitzige",
    "Hitzigeren": "Hitzigere",
    "Hitzigsten": "Hitzigste",
    "Hiwis": "Hiwi",
    "Hobbys": "Hobby",
    "Hobel": "hobeln",
    "Hobeln": "Hobel",
    "Hobelnden": "Hobelnde",
    "Hobelns": "Hobeln",
    "Hobels": "Hobel",
    "Hochachtenden": "Hochachtende",
    "Hochachtenderen": "Hochachtendere",
    "Hochachtendsten": "Hochachtendste",
    "Hochachtens": "Hochachten",
    "Hochachtungsvollen": "Hochachtungsvolle",
    "Hochadeligen": "Hochadelige",
    "Hochaktuellen": "Hochaktuelle",
    "Hochaktuelleren": "Hochaktuellere",
    "Hochaktuellsten": "Hochaktuellste",
    "Hochaltare": "Hochaltar",
    "Hochaltars": "Hochaltar",
    "Hochaltäre": "Hochaltar",
    "Hochaltären": "Hochaltar",
    "Hochanständige": "hochanständig",
    "Hochanständigen": "Hochanständige",
    "Hochanständigeren": "Hochanständigere",
    "Hochanständigsten": "Hochanständigste",
    "Hocharbeitenden": "Hocharbeitende",
    "Hocharbeitenderen": "Hocharbeitendere",
    "Hocharbeitendsten": "Hocharbeitendste",
    "Hocharbeitens": "Hocharbeiten",
    "Hochaufgeschossenen": "Hochaufgeschossene",
    "Hochbahnen": "Hochbahn",
    "Hochbaus": "Hochbau",
    "Hochbegabte": "hochbegabt",
    "Hochbegabten": "Hochbegabte",
    "Hochbeglückten": "Hochbeglückte",
    "Hochbehältern": "Hochbehälter",
    "Hochbehälters": "Hochbehälter",
    "Hochbetagte": "hochbetagt",
    "Hochbetagten": "Hochbetagte",
    "Hochbetagteren": "Hochbetagtere",
    "Hochbetagtesten": "Hochbetagteste",
    "Hochbindenden": "Hochbindende",
    "Hochbindens": "Hochbinden",
    "Hochbringenden": "Hochbringende",
    "Hochbringens": "Hochbringen",
    "Hochbrisanten": "Hochbrisante",
    "Hochbrisanteren": "Hochbrisantere",
    "Hochbrisantesten": "Hochbrisanteste",
    "Hochburgen": "Hochburg",
    "Hochdeutsche": "hochdeutsch",
    "Hochdeutschen": "Hochdeutsche",
    "Hochdienenden": "Hochdienende",
    "Hochdienens": "Hochdienen",
    "Hochdruckgebiete": "Hochdruckgebiet",
    "Hochdruckgebieten": "Hochdruckgebiet",
    "Hochdruckgebiets": "Hochdruckgebiet",
    "Hochdrucks": "Hochdruck",
    "Hochebenen": "Hochebene",
    "Hochempfindliche": "hochempfindlich",
    "Hochempfindlichen": "Hochempfindliche",
    "Hocherfreuten": "Hocherfreute",
    "Hocherhitzten": "Hocherhitzte",
    "Hochexplosiven": "Hochexplosive",
    "Hochfahrenden": "Hochfahrende",
    "Hochfahrens": "Hochfahren",
    "Hochfluten": "Hochflut",
    "Hochflächen": "Hochfläche",
    "Hochformate": "Hochformat",
    "Hochformaten": "Hochformat",
    "Hochformats": "Hochformat",
    "Hochfrequente": "hochfrequent",
    "Hochfrequenten": "Hochfrequente",
    "Hochfrequenzen": "Hochfrequenz",
    "Hochfrequenzlexika": "Hochfrequenzlexikon",
    "Hochfrequenzlexikons": "Hochfrequenzlexikon",
    "Hochgeachteten": "Hochgeachtete",
    "Hochgeachteteren": "Hochgeachtetere",
    "Hochgeachtetesten": "Hochgeachteteste",
    "Hochgearbeiteten": "Hochgearbeitete",
    "Hochgearbeiteteren": "Hochgearbeitetere",
    "Hochgebildeten": "Hochgebildete",
    "Hochgebirgen": "Hochgebirge",
    "Hochgebirges": "Hochgebirge",
    "Hochgebrachten": "Hochgebrachte",
    "Hochgebundenen": "Hochgebundene",
    "Hochgedienten": "Hochgediente",
    "Hochgeehrten": "Hochgeehrte",
    "Hochgefahrenen": "Hochgefahrene",
    "Hochgefühle": "Hochgefühl",
    "Hochgefühlen": "Hochgefühl",
    "Hochgefühls": "Hochgefühl",
    "Hochgegangenen": "Hochgegangene",
    "Hochgehenden": "Hochgehende",
    "Hochgehens": "Hochgehen",
    "Hochgehobenen": "Hochgehobene",
    "Hochgejagten": "Hochgejagte",
    "Hochgejubelten": "Hochgejubelte",
    "Hochgejubelteren": "Hochgejubeltere",
    "Hochgejubeltesten": "Hochgejubelteste",
    "Hochgeklappten": "Hochgeklappte",
    "Hochgekämmten": "Hochgekämmte",
    "Hochgelebten": "Hochgelebte",
    "Hochgenommenen": "Hochgenommene",
    "Hochgepäppelten": "Hochgepäppelte",
    "Hochgerannten": "Hochgerannte",
    "Hochgerechneten": "Hochgerechnete",
    "Hochgerissenen": "Hochgerissene",
    "Hochgeschaukelten": "Hochgeschaukelte",
    "Hochgeschaukelteren": "Hochgeschaukeltere",
    "Hochgeschnellten": "Hochgeschnellte",
    "Hochgeschreckten": "Hochgeschreckte",
    "Hochgeschreckteren": "Hochgeschrecktere",
    "Hochgeschrockenen": "Hochgeschrockene",
    "Hochgeschrockeneren": "Hochgeschrockenere",
    "Hochgeschätzten": "Hochgeschätzte",
    "Hochgeschätzteren": "Hochgeschätztere",
    "Hochgesehenen": "Hochgesehene",
    "Hochgesetzten": "Hochgesetzte",
    "Hochgesetzteren": "Hochgesetztere",
    "Hochgesetztesten": "Hochgesetzteste",
    "Hochgespielten": "Hochgespielte",
    "Hochgespülten": "Hochgespülte",
    "Hochgestapelten": "Hochgestapelte",
    "Hochgestellten": "Hochgestellte",
    "Hochgestiegenen": "Hochgestiegene",
    "Hochgestiegeneren": "Hochgestiegenere",
    "Hochgestiegensten": "Hochgestiegenste",
    "Hochgestrebten": "Hochgestrebte",
    "Hochgetragenen": "Hochgetragene",
    "Hochgetriebenen": "Hochgetriebene",
    "Hochgezogenen": "Hochgezogene",
    "Hochgezogeneren": "Hochgezogenere",
    "Hochgezogensten": "Hochgezogenste",
    "Hochgezüchteten": "Hochgezüchtete",
    "Hochgezüchteteren": "Hochgezüchtetere",
    "Hochgradigen": "Hochgradige",
    "Hochhause": "Hochhaus",
    "Hochhauses": "Hochhaus",
    "Hochhebenden": "Hochhebende",
    "Hochhebens": "Hochheben",
    "Hochheimern": "Hochheimer",
    "Hochheimers": "Hochheimer",
    "Hochheims": "Hochheim",
    "Hochherrschaftliche": "hochherrschaftlich",
    "Hochherrschaftlichen": "Hochherrschaftliche",
    "Hochhäuser": "Hochhaus",
    "Hochhäusern": "Hochhaus",
    "Hochintelligenten": "Hochintelligente",
    "Hochjagenden": "Hochjagende",
    "Hochjagens": "Hochjagen",
    "Hochjubelnden": "Hochjubelnde",
    "Hochjubelnderen": "Hochjubelndere",
    "Hochjubelndsten": "Hochjubelndste",
    "Hochjubelns": "Hochjubeln",
    "Hochkarätigen": "Hochkarätige",
    "Hochkarätigeren": "Hochkarätigere",
    "Hochkarätigsten": "Hochkarätigste",
    "Hochklappenden": "Hochklappende",
    "Hochklappens": "Hochklappen",
    "Hochkulturen": "Hochkultur",
    "Hochkämmenden": "Hochkämmende",
    "Hochkämmens": "Hochkämmen",
    "Hochlande": "Hochland",
    "Hochlandes": "Hochland",
    "Hochlands": "Hochland",
    "Hochlebenden": "Hochlebende",
    "Hochlebens": "Hochleben",
    "Hochleitungen": "Hochleitung",
    "Hochländern": "Hochländer",
    "Hochländers": "Hochländer",
    "Hochmoderne": "hochmodern",
    "Hochmodernen": "Hochmoderne",
    "Hochmute": "Hochmut",
    "Hochmutes": "Hochmut",
    "Hochmuts": "Hochmut",
    "Hochmütige": "hochmütig",
    "Hochmütigen": "Hochmütige",
    "Hochmütigeren": "Hochmütigere",
    "Hochmütigsten": "Hochmütigste",
    "Hochnehmenden": "Hochnehmende",
    "Hochnehmens": "Hochnehmen",
    "Hochnäsigen": "Hochnäsige",
    "Hochnäsigeren": "Hochnäsigere",
    "Hochnäsigsten": "Hochnäsigste",
    "Hochofens": "Hochofen",
    "Hochprozentigen": "Hochprozentige",
    "Hochprozentigeren": "Hochprozentigere",
    "Hochprozentigsten": "Hochprozentigste",
    "Hochpäppelnden": "Hochpäppelnde",
    "Hochpäppelns": "Hochpäppeln",
    "Hochqualifizierten": "Hochqualifizierte",
    "Hochrade": "Hochrad",
    "Hochrades": "Hochrad",
    "Hochrads": "Hochrad",
    "Hochrechnenden": "Hochrechnende",
    "Hochrechnens": "Hochrechnen",
    "Hochrechnungen": "Hochrechnung",
    "Hochreißenden": "Hochreißende",
    "Hochreißens": "Hochreißen",
    "Hochrennenden": "Hochrennende",
    "Hochrennens": "Hochrennen",
    "Hochräder": "Hochrad",
    "Hochrädern": "Hochrad",
    "Hochs": "Hoch",
    "Hochschaukelnden": "Hochschaukelnde",
    "Hochschaukelnderen": "Hochschaukelndere",
    "Hochschaukelns": "Hochschaukeln",
    "Hochschnellenden": "Hochschnellende",
    "Hochschnellens": "Hochschnellen",
    "Hochschreckenden": "Hochschreckende",
    "Hochschreckens": "Hochschrecken",
    "Hochschulen": "Hochschule",
    "Hochschullehrern": "Hochschullehrer",
    "Hochschullehrers": "Hochschullehrer",
    "Hochschwangere": "hochschwanger",
    "Hochschwangeren": "Hochschwangere",
    "Hochschätzenden": "Hochschätzende",
    "Hochschätzenderen": "Hochschätzendere",
    "Hochschätzendsten": "Hochschätzendste",
    "Hochschätzens": "Hochschätzen",
    "Hochschülern": "Hochschüler",
    "Hochschülers": "Hochschüler",
    "Hochsehenden": "Hochsehende",
    "Hochsehens": "Hochsehen",
    "Hochsetzenden": "Hochsetzende",
    "Hochsetzens": "Hochsetzen",
    "Hochsommers": "Hochsommer",
    "Hochspielenden": "Hochspielende",
    "Hochspielens": "Hochspielen",
    "Hochsprunge": "Hochsprung",
    "Hochsprungs": "Hochsprung",
    "Hochsprünge": "Hochsprung",
    "Hochsprüngen": "Hochsprung",
    "Hochspülenden": "Hochspülende",
    "Hochspülens": "Hochspülen",
    "Hochstande": "Hochstand",
    "Hochstands": "Hochstand",
    "Hochstapeleien": "Hochstapelei",
    "Hochstapelnden": "Hochstapelnde",
    "Hochstapelns": "Hochstapeln",
    "Hochstaplern": "Hochstapler",
    "Hochstaplers": "Hochstapler",
    "Hochsteigenden": "Hochsteigende",
    "Hochsteigenderen": "Hochsteigendere",
    "Hochsteigendsten": "Hochsteigendste",
    "Hochsteigens": "Hochsteigen",
    "Hochstellenden": "Hochstellende",
    "Hochstellens": "Hochstellen",
    "Hochstilisierenden": "Hochstilisierende",
    "Hochstilisierenderen": "Hochstilisierendere",
    "Hochstilisierens": "Hochstilisieren",
    "Hochstilisierte": "hochstilisiert",
    "Hochstilisierten": "Hochstilisierte",
    "Hochstilisierteren": "Hochstilisiertere",
    "Hochstraßen": "Hochstraße",
    "Hochstrebenden": "Hochstrebende",
    "Hochstrebens": "Hochstreben",
    "Hochstände": "Hochstand",
    "Hochständen": "Hochstand",
    "Hochtale": "Hochtal",
    "Hochtales": "Hochtal",
    "Hochtals": "Hochtal",
    "Hochtaunuskreises": "Hochtaunuskreis",
    "Hochtone": "Hochton",
    "Hochtons": "Hochton",
    "Hochtrabende": "hochtrabend",
    "Hochtrabenden": "Hochtrabende",
    "Hochtrabenderen": "Hochtrabendere",
    "Hochtrabendsten": "Hochtrabendste",
    "Hochtragenden": "Hochtragende",
    "Hochtragens": "Hochtragen",
    "Hochtreibenden": "Hochtreibende",
    "Hochtreibens": "Hochtreiben",
    "Hochtäler": "Hochtal",
    "Hochtälern": "Hochtal",
    "Hochtöne": "Hochton",
    "Hochtönen": "Hochton",
    "Hochtönende": "hochtönend",
    "Hochtönenden": "Hochtönende",
    "Hochverdienten": "Hochverdiente",
    "Hochverehrten": "Hochverehrte",
    "Hochverräterischen": "Hochverräterische",
    "Hochverrätern": "Hochverräter",
    "Hochverräters": "Hochverräter",
    "Hochwalde": "Hochwald",
    "Hochwaldes": "Hochwald",
    "Hochwalds": "Hochwald",
    "Hochwassern": "Hochwasser",
    "Hochwassers": "Hochwasser",
    "Hochwertige": "hochwertig",
    "Hochwertigen": "Hochwertige",
    "Hochwertigeren": "Hochwertigere",
    "Hochwertigsten": "Hochwertigste",
    "Hochwilde": "Hochwild",
    "Hochwildes": "Hochwild",
    "Hochwilds": "Hochwild",
    "Hochwillkommene": "hochwillkommen",
    "Hochwillkommenen": "Hochwillkommene",
    "Hochwälder": "Hochwald",
    "Hochwäldern": "Hochwald",
    "Hochwürdigen": "Hochwürdige",
    "Hochwürdigeren": "Hochwürdigere",
    "Hochwürdigsten": "Hochwürdigste",
    "Hochzahlen": "Hochzahl",
    "Hochzeiten": "Hochzeit",
    "Hochzeiterinnen": "Hochzeiterin",
    "Hochzeitliche": "hochzeitlich",
    "Hochzeitlichen": "Hochzeitliche",
    "Hochziehenden": "Hochziehende",
    "Hochziehenderen": "Hochziehendere",
    "Hochziehendsten": "Hochziehendste",
    "Hochziehens": "Hochziehen",
    "Hochzüchtenden": "Hochzüchtende",
    "Hochzüchtenderen": "Hochzüchtendere",
    "Hochzüchtendsten": "Hochzüchtendste",
    "Hochzüchtens": "Hochzüchten",
    "Hochöfen": "Hochofen",
    "Hockenden": "Hockende",
    "Hockenderen": "Hockendere",
    "Hockendsten": "Hockendste",
    "Hockens": "Hocken",
    "Hockern": "Hocker",
    "Hockers": "Hocker",
    "Hockeys": "Hockey",
    "Hodens": "Hoden",
    "Hoechsts": "Hoechst",
    "Hofe": "Hof",
    "Hofes": "Hof",
    "Hoffenden": "Hoffende",
    "Hoffens": "Hoffen",
    "Hoffmanns": "Hoffmann",
    "Hoffnungen": "Hoffnung",
    "Hoffnungslose": "hoffnungslos",
    "Hoffnungslosen": "Hoffnungslose",
    "Hoffnungsloseren": "Hoffnungslosere",
    "Hoffnungslosesten": "Hoffnungsloseste",
    "Hoffnungsvollen": "Hoffnungsvolle",
    "Hoffnungsvolleren": "Hoffnungsvollere",
    "Hoffnungsvollsten": "Hoffnungsvollste",
    "Hoffähige": "hoffähig",
    "Hoffähigen": "Hoffähige",
    "Hoffähigeren": "Hoffähigere",
    "Hoffähigsten": "Hoffähigste",
    "Hofgängern": "Hofgänger",
    "Hofgängers": "Hofgänger",
    "Hofheimern": "Hofheimer",
    "Hofheimers": "Hofheimer",
    "Hofierenden": "Hofierende",
    "Hofierens": "Hofieren",
    "Hofierte": "hofiert",
    "Hofierten": "Hofierte",
    "Hofierteren": "Hofiertere",
    "Hofiertesten": "Hofierteste",
    "Hofs": "Hof",
    "Hoheiten": "Hoheit",
    "Hoheitliche": "hoheitlich",
    "Hoheitlichen": "Hoheitliche",
    "Hoheitsvollen": "Hoheitsvolle",
    "Hohlen": "Hohle",
    "Hohleren": "Hohlere",
    "Hohlflächen": "Hohlfläche",
    "Hohlleisten": "Hohlleiste",
    "Hohlraume": "Hohlraum",
    "Hohlraums": "Hohlraum",
    "Hohlräume": "Hohlraum",
    "Hohlräumen": "Hohlraum",
    "Hohlspiegeln": "Hohlspiegel",
    "Hohlspiegels": "Hohlspiegel",
    "Hohlsten": "Hohlste",
    "Hohlwege": "Hohlweg",
    "Hohlwegen": "Hohlweg",
    "Hohlwegs": "Hohlweg",
    "Hohlwellen": "Hohlwelle",
    "Hohlwurme": "Hohlwurm",
    "Hohlwurmes": "Hohlwurm",
    "Hohlwurms": "Hohlwurm",
    "Hohlwürmer": "Hohlwurm",
    "Hohlwürmern": "Hohlwurm",
    "Hohlziegeln": "Hohlziegel",
    "Hohlziegels": "Hohlziegel",
    "Hohne": "Hohn",
    "Hohnes": "Hohn",
    "Hohns": "Hohn",
    "Holde": "hold",
    "Holden": "Holde",
    "Holderen": "Holdere",
    "Holdesten": "Holdeste",
    "Holdings": "Holding",
    "Holenden": "Holende",
    "Holens": "Holen",
    "Holgers": "Holger",
    "Hollands": "Holland",
    "Hollerithmaschinen": "Hollerithmaschine",
    "Hollywoods": "Hollywood",
    "Holländern": "Holländer",
    "Holländers": "Holländer",
    "Holländische": "holländisch",
    "Holländischen": "Holländische",
    "Holländischeren": "Holländischere",
    "Holländischsten": "Holländischste",
    "Holocausts": "Holocaust",
    "Holografien": "Holografie",
    "Hologramme": "Hologramm",
    "Hologrammen": "Hologramm",
    "Hologramms": "Hologramm",
    "Holographische": "holographisch",
    "Holographischen": "Holographische",
    "Holperigen": "Holperige",
    "Holperigeren": "Holperigere",
    "Holperigsten": "Holperigste",
    "Holpernden": "Holpernde",
    "Holpernderen": "Holperndere",
    "Holperndsten": "Holperndste",
    "Holperns": "Holpern",
    "Holprigen": "Holprige",
    "Holprigeren": "Holprigere",
    "Holprigsten": "Holprigste",
    "Holsteins": "Holstein",
    "Holundern": "Holunder",
    "Holunders": "Holunder",
    "Holz": "holzen",
    "Holze": "holzen",
    "Holzenden": "Holzende",
    "Holzens": "Holzen",
    "Holzes": "Holz",
    "Holzfreien": "Holzfreie",
    "Holzhaltigen": "Holzhaltige",
    "Holzigen": "Holzige",
    "Holzigeren": "Holzigere",
    "Holzigsten": "Holzigste",
    "Homburgern": "Homburger",
    "Homburgers": "Homburger",
    "Homburgs": "Homburg",
    "Homoehen": "Homoehe",
    "Homogene": "homogen",
    "Homogenen": "Homogene",
    "Homogeneren": "Homogenere",
    "Homogenisierenden": "Homogenisierende",
    "Homogenisierenderen": "Homogenisierendere",
    "Homogenisierens": "Homogenisieren",
    "Homogenisierte": "homogenisiert",
    "Homogenisierten": "Homogenisierte",
    "Homogenisierteren": "Homogenisiertere",
    "Homogenisierteste": "homogenisiert",
    "Homogensten": "Homogenste",
    "Homosexuellen": "Homosexuelle",
    "Homöopathischen": "Homöopathische",
    "Hondas": "Honda",
    "Honeckers": "Honecker",
    "Hongkongs": "Hongkong",
    "Honigdrüsen": "Honigdrüse",
    "Honigs": "Honig",
    "Honorabelste": "honorabel",
    "Honorabelsten": "Honorabelste",
    "Honorablen": "Honorable",
    "Honorableren": "Honorablere",
    "Honorierenden": "Honorierende",
    "Honorierenderen": "Honorierendere",
    "Honorierendsten": "Honorierendste",
    "Honorierens": "Honorieren",
    "Honorierte": "honoriert",
    "Honorierten": "Honorierte",
    "Honorierteren": "Honoriertere",
    "Honoriertesten": "Honorierteste",
    "Honorigen": "Honorige",
    "Honorigeren": "Honorigere",
    "Honorigsten": "Honorigste",
    "Hopfens": "Hopfen",
    "Hoppelnden": "Hoppelnde",
    "Hoppelnderen": "Hoppelndere",
    "Hoppelndsten": "Hoppelndste",
    "Hoppelns": "Hoppeln",
    "Hoppenden": "Hoppende",
    "Hoppens": "Hoppen",
    "Hopsenden": "Hopsende",
    "Hopsenderen": "Hopsendere",
    "Hopsendsten": "Hopsendste",
    "Hopsens": "Hopsen",
    "Hopsgegangenen": "Hopsgegangene",
    "Hopsgehenden": "Hopsgehende",
    "Hopsgehens": "Hopsgehen",
    "Hopsgenommenen": "Hopsgenommene",
    "Hopsnehmenden": "Hopsnehmende",
    "Hopsnehmens": "Hopsnehmen",
    "Horchenden": "Horchende",
    "Horchens": "Horchen",
    "Horchern": "Horcher",
    "Horchers": "Horcher",
    "Horden": "Horde",
    "Horizontalen": "Horizontale",
    "Horizontalpendeln": "Horizontalpendel",
    "Horizontalpendels": "Horizontalpendel",
    "Horizonte": "Horizont",
    "Horizonten": "Horizont",
    "Horizontes": "Horizont",
    "Horizonts": "Horizont",
    "Hormone": "Hormon",
    "Hormonen": "Hormon",
    "Hormons": "Hormon",
    "Horne": "Horn",
    "Hornes": "Horn",
    "Horns": "Horn",
    "Horoskope": "Horoskop",
    "Horoskopen": "Horoskop",
    "Horoskops": "Horoskop",
    "Horrende": "horrend",
    "Horrenden": "Horrende",
    "Horrors": "Horror",
    "Horste": "Horst",
    "Horsten": "Horst",
    "Horstes": "Horst",
    "Horsts": "Horst",
    "Horte": "horten",
    "Horten": "Hort",
    "Hortenden": "Hortende",
    "Hortenderen": "Hortendere",
    "Hortendsten": "Hortendste",
    "Hortens": "Horten",
    "Hortes": "Hort",
    "Horts": "Hort",
    "Hosen": "Hose",
    "Hospitale": "Hospital",
    "Hospitales": "Hospital",
    "Hospitals": "Hospital",
    "Hospitierenden": "Hospitierende",
    "Hospitierens": "Hospitieren",
    "Hospitierte": "hospitiert",
    "Hospitierten": "Hospitierte",
    "Hospitäler": "Hospital",
    "Hospitälern": "Hospital",
    "Hotelkauffrauen": "Hotelkauffrau",
    "Hotels": "Hotel",
    "Houstons": "Houston",
    "Hoyerswerdas": "Hoyerswerda",
    "Hube": "Hub",
    "Hubers": "Huber",
    "Huberts": "Hubert",
    "Hubs": "Hub",
    "Hubschraubern": "Hubschrauber",
    "Hubschraubers": "Hubschrauber",
    "Huckligen": "Hucklige",
    "Huckligeren": "Huckligere",
    "Huckligsten": "Huckligste",
    "Hufe": "Huf",
    "Hufeisenförmige": "hufeisenförmig",
    "Hufeisenförmigen": "Hufeisenförmige",
    "Hufen": "Hufe",
    "Hufes": "Huf",
    "Hufs": "Huf",
    "Hugenottische": "hugenottisch",
    "Hugenottischen": "Hugenottische",
    "Hugos": "Hugo",
    "Huhne": "Huhn",
    "Huhnes": "Huhn",
    "Huhns": "Huhn",
    "Huldigenden": "Huldigende",
    "Huldigens": "Huldigen",
    "Humanen": "Humane",
    "Humaneren": "Humanere",
    "Humanisierenden": "Humanisierende",
    "Humanisierenderen": "Humanisierendere",
    "Humanisierendsten": "Humanisierendste",
    "Humanisierens": "Humanisieren",
    "Humanisierte": "humanisiert",
    "Humanisierten": "Humanisierte",
    "Humanisierteren": "Humanisiertere",
    "Humanisiertesten": "Humanisierteste",
    "Humanisten": "Humanist",
    "Humanistische": "humanistisch",
    "Humanistischen": "Humanistische",
    "Humanitären": "Humanitäre",
    "Humanitäreren": "Humanitärere",
    "Humanitärsten": "Humanitärste",
    "Humanmedizinischen": "Humanmedizinische",
    "Humansten": "Humanste",
    "Humanwissenschaften": "Humanwissenschaft",
    "Humboldts": "Humboldt",
    "Humbugs": "Humbug",
    "Humifizierenden": "Humifizierende",
    "Humifizierens": "Humifizieren",
    "Humifizierte": "humifiziert",
    "Humifizierten": "Humifizierte",
    "Hummern": "Hummer",
    "Hummers": "Hummer",
    "Humorige": "humorig",
    "Humorigen": "Humorige",
    "Humorigeren": "Humorigere",
    "Humorigsten": "Humorigste",
    "Humoristen": "Humorist",
    "Humoristische": "humoristisch",
    "Humoristischen": "Humoristische",
    "Humorlosen": "Humorlose",
    "Humorloseren": "Humorlosere",
    "Humorlosesten": "Humorloseste",
    "Humors": "Humor",
    "Humorvolle": "humorvoll",
    "Humorvollen": "Humorvolle",
    "Humorvolleren": "Humorvollere",
    "Humorvollsten": "Humorvollste",
    "Humpens": "Humpen",
    "Hunde": "Hund",
    "Hundeelende": "hundeelend",
    "Hundeelenden": "Hundeelende",
    "Hundekalten": "Hundekalte",
    "Hunden": "Hund",
    "Hunderten": "Hunderte",
    "Hundertfache": "hundertfach",
    "Hundertfachen": "Hundertfache",
    "Hundertjährigen": "Hundertjährige",
    "Hundertmeterlaufe": "Hundertmeterlauf",
    "Hundertmeterlaufs": "Hundertmeterlauf",
    "Hundertmeterläufe": "Hundertmeterlauf",
    "Hundertmeterläufen": "Hundertmeterlauf",
    "Hundertprozentige": "hundertprozentig",
    "Hundertprozentigen": "Hundertprozentige",
    "Hundertschaften": "Hundertschaft",
    "Hundertsteln": "Hundertstel",
    "Hundertstels": "Hundertstel",
    "Hunderttausendsteln": "Hunderttausendstel",
    "Hunderttausendstels": "Hunderttausendstel",
    "Hunds": "Hund",
    "Hundsgemeine": "hundsgemein",
    "Hundsgemeinen": "Hundsgemeine",
    "Hundsmiserablen": "Hundsmiserable",
    "Hunger": "hungern",
    "Hungerdaseins": "Hungerdasein",
    "Hungerleidern": "Hungerleider",
    "Hungerleiders": "Hungerleider",
    "Hungernden": "Hungernde",
    "Hungernderen": "Hungerndere",
    "Hungerndsten": "Hungerndste",
    "Hungerns": "Hungern",
    "Hungers": "Hunger",
    "Hungrigen": "Hungrige",
    "Hungrigeren": "Hungrigere",
    "Hungrigsten": "Hungrigste",
    "Hunnen": "Hunne",
    "Hupe": "hupen",
    "Hupen": "Hupe",
    "Hupenden": "Hupende",
    "Hupens": "Hupen",
    "Hurrikans": "Hurrikan",
    "Hurtige": "hurtig",
    "Hurtigen": "Hurtige",
    "Hurtigeren": "Hurtigere",
    "Hurtigsten": "Hurtigste",
    "Huschenden": "Huschende",
    "Huschens": "Huschen",
    "Husseins": "Hussein",
    "Hustenden": "Hustende",
    "Hustenderen": "Hustendere",
    "Hustendsten": "Hustendste",
    "Hustens": "Husten",
    "Hute": "Hut",
    "Hutes": "Hut",
    "Huts": "Hut",
    "Hybride": "hybrid",
    "Hybriden": "Hybride",
    "Hydraulischen": "Hydraulische",
    "Hydrierenden": "Hydrierende",
    "Hydrierens": "Hydrieren",
    "Hydrierte": "hydriert",
    "Hydrierten": "Hydrierte",
    "Hydrodynamischen": "Hydrodynamische",
    "Hydropneumatischen": "Hydropneumatische",
    "Hydropulsore": "Hydropulsor",
    "Hydropulsoren": "Hydropulsor",
    "Hydropulsors": "Hydropulsor",
    "Hydrostatische": "hydrostatisch",
    "Hydrostatischen": "Hydrostatische",
    "Hydrotechnischen": "Hydrotechnische",
    "Hyetografen": "Hyetograf",
    "Hymnen": "Hymne",
    "Hymnische": "hymnisch",
    "Hymnischen": "Hymnische",
    "Hyperbeln": "Hyperbel",
    "Hyperbolikern": "Hyperboliker",
    "Hyperbolikers": "Hyperboliker",
    "Hyperbolische": "hyperbolisch",
    "Hyperbolischen": "Hyperbolische",
    "Hyperkorrekten": "Hyperkorrekte",
    "Hyperkritischen": "Hyperkritische",
    "Hyperladungen": "Hyperladung",
    "Hypermoderne": "hypermodern",
    "Hypermodernen": "Hypermoderne",
    "Hyperschalls": "Hyperschall",
    "Hypersensible": "hypersensibel",
    "Hypersensiblen": "Hypersensible",
    "Hypertonikern": "Hypertoniker",
    "Hypertonikers": "Hypertoniker",
    "Hypnosen": "Hypnose",
    "Hypnotisierenden": "Hypnotisierende",
    "Hypnotisierens": "Hypnotisieren",
    "Hypnotisierte": "hypnotisiert",
    "Hypnotisierten": "Hypnotisierte",
    "Hypotenusen": "Hypotenuse",
    "Hypotheken": "Hypothek",
    "Hypothesen": "Hypothese",
    "Hypothetische": "hypothetisch",
    "Hypothetischen": "Hypothetische",
    "Hypotonien": "Hypotonie",
    "Hypotonikern": "Hypotoniker",
    "Hypotonikers": "Hypotoniker",
    "Hypotrophien": "Hypotrophie",
    "Hysterikern": "Hysteriker",
    "Hysterikers": "Hysteriker",
    "Hysterische": "hysterisch",
    "Hysterischen": "Hysterische",
    "Hysterischeren": "Hysterischere",
    "Hysterischsten": "Hysterischste",
    "HÖCHSTs": "HÖCHST",
    "Häckselnden": "Häckselnde",
    "Häckselns": "Häckseln",
    "Häfen": "Hafen",
    "Häftlinge": "Häftling",
    "Häftlingen": "Häftling",
    "Häftlinges": "Häftling",
    "Häftlings": "Häftling",
    "Hähnchens": "Hähnchen",
    "Hähne": "Hahn",
    "Hähnen": "Hahn",
    "Häkchens": "Häkchen",
    "Häkeleien": "Häkelei",
    "Häkelnden": "Häkelnde",
    "Häkelns": "Häkeln",
    "Hälften": "Hälfte",
    "Hälschens": "Hälschen",
    "Hälse": "Hals",
    "Hälsen": "Hals",
    "Hälsleins": "Hälslein",
    "Hämatome": "Hämatom",
    "Hämatomen": "Hämatom",
    "Hämatoms": "Hämatom",
    "Hämische": "hämisch",
    "Hämischen": "Hämische",
    "Hämischeren": "Hämischere",
    "Hämischsten": "Hämischste",
    "Hämmer": "hämmern",
    "Hämmerchens": "Hämmerchen",
    "Hämmerleins": "Hämmerlein",
    "Hämmern": "Hammer",
    "Hämmernden": "Hämmernde",
    "Hämmernderen": "Hämmerndere",
    "Hämmerndsten": "Hämmerndste",
    "Hämmerns": "Hämmern",
    "Hämogramme": "Hämogramm",
    "Hämogrammen": "Hämogramm",
    "Hämogramms": "Hämogramm",
    "Hände": "Hand",
    "Händel": "Handel",
    "Händeln": "Handel",
    "Händen": "Hand",
    "Händeringende": "händeringend",
    "Händeringenden": "Händeringende",
    "Händeringenderen": "Händeringendere",
    "Händeringendsten": "Händeringendste",
    "Händigenden": "Händigende",
    "Händigens": "Händigen",
    "Händlerinnen": "Händlerin",
    "Händlern": "Händler",
    "Händlers": "Händler",
    "Hänge": "hängen",
    "Hängegerüste": "Hängegerüst",
    "Hängegerüsten": "Hängegerüst",
    "Hängegerüsts": "Hängegerüst",
    "Hängegleitern": "Hängegleiter",
    "Hängegleiters": "Hängegleiter",
    "Hängegurte": "Hängegurt",
    "Hängegurten": "Hängegurt",
    "Hängegurts": "Hängegurt",
    "Hängelampen": "Hängelampe",
    "Hängemanne": "Hängemann",
    "Hängemannes": "Hängemann",
    "Hängemanns": "Hängemann",
    "Hängematten": "Hängematte",
    "Hängemänner": "Hängemann",
    "Hängemännern": "Hängemann",
    "Hängen": "Hang",
    "Hängenbleibenden": "Hängenbleibende",
    "Hängenbleibens": "Hängenbleiben",
    "Hängenden": "Hängende",
    "Hängengebliebenen": "Hängengebliebene",
    "Hängens": "Hängen",
    "Hänseleien": "Hänselei",
    "Hänselnden": "Hänselnde",
    "Hänselnderen": "Hänselndere",
    "Hänselndsten": "Hänselndste",
    "Hänselns": "Hänseln",
    "Härchens": "Härchen",
    "Härleins": "Härlein",
    "Härte": "härten",
    "Härtebereiche": "Härtebereich",
    "Härtebereichen": "Härtebereich",
    "Härtebereichs": "Härtebereich",
    "Härtefalle": "Härtefall",
    "Härtefalls": "Härtefall",
    "Härtefälle": "Härtefall",
    "Härtefällen": "Härtefall",
    "Härtemitteln": "Härtemittel",
    "Härtemittels": "Härtemittel",
    "Härten": "Härte",
    "Härtenden": "Härtende",
    "Härtenderen": "Härtendere",
    "Härtendsten": "Härtendste",
    "Härtens": "Härten",
    "Härteren": "Härtere",
    "Härtesten": "Härteste",
    "Häschens": "Häschen",
    "Häschern": "Häscher",
    "Häschers": "Häscher",
    "Häsleins": "Häslein",
    "Hätschelnden": "Hätschelnde",
    "Hätschelnderen": "Hätschelndere",
    "Hätschelndsten": "Hätschelndste",
    "Hätschelns": "Hätscheln",
    "Häubchens": "Häubchen",
    "Häubleins": "Häublein",
    "Häufchens": "Häufchen",
    "Häufenden": "Häufende",
    "Häufens": "Häufen",
    "Häufigen": "Häufige",
    "Häufigeren": "Häufigere",
    "Häufigkeiten": "Häufigkeit",
    "Häufigste": "häufig",
    "Häufigsten": "Häufigste",
    "Häupter": "Haupt",
    "Häuptern": "Haupt",
    "Häuptlinge": "Häuptling",
    "Häuptlingen": "Häuptling",
    "Häuptlings": "Häuptling",
    "Häuschens": "Häuschen",
    "Häuser": "Haus",
    "Häusern": "Haus",
    "Häuslichen": "Häusliche",
    "Häuslicheren": "Häuslichere",
    "Häuslichsten": "Häuslichste",
    "Häute": "häuten",
    "Häuten": "Haut",
    "Häutenden": "Häutende",
    "Häutenderen": "Häutendere",
    "Häutendsten": "Häutendste",
    "Häutens": "Häuten",
    "Häutungen": "Häutung",
    "Häßlers": "Häßler",
    "Häßliche": "häßlich",
    "Häßlichen": "Häßliche",
    "Häßlicheren": "Häßlichere",
    "Häßlichsten": "Häßlichste",
    "Höchstpersönlichen": "Höchstpersönliche",
    "Höchstpreise": "Höchstpreis",
    "Höchstpreisen": "Höchstpreis",
    "Höchstpreises": "Höchstpreis",
    "Höchststufen": "Höchststufe",
    "Höchstwerte": "Höchstwert",
    "Höchstwerten": "Höchstwert",
    "Höchstwerts": "Höchstwert",
    "Höchstzulässige": "höchstzulässig",
    "Höchstzulässigen": "Höchstzulässige",
    "Höfe": "Hof",
    "Höfen": "Hof",
    "Höfischen": "Höfische",
    "Höflichen": "Höfliche",
    "Höflicheren": "Höflichere",
    "Höflichkeiten": "Höflichkeit",
    "Höflichste": "höflich",
    "Höflichsten": "Höflichste",
    "Höhen": "Höhe",
    "Höhenfluge": "Höhenflug",
    "Höhenflugs": "Höhenflug",
    "Höhenflüge": "Höhenflug",
    "Höhenflügen": "Höhenflug",
    "Höhenschreibern": "Höhenschreiber",
    "Höhenschreibers": "Höhenschreiber",
    "Höhepunkte": "Höhepunkt",
    "Höhepunkten": "Höhepunkt",
    "Höhepunktes": "Höhepunkt",
    "Höhepunkts": "Höhepunkt",
    "Höhle": "höhlen",
    "Höhlen": "Höhle",
    "Höhlenden": "Höhlende",
    "Höhlens": "Höhlen",
    "Höhnische": "höhnisch",
    "Höhnischen": "Höhnische",
    "Höhnischeren": "Höhnischere",
    "Höhnischsten": "Höhnischste",
    "Höllische": "höllisch",
    "Höllischen": "Höllische",
    "Höllischeren": "Höllischere",
    "Höllischsten": "Höllischste",
    "Hölzchens": "Hölzchen",
    "Hölzer": "Holz",
    "Hölzern": "Holz",
    "Hölzerne": "hölzern",
    "Hölzernen": "Hölzerne",
    "Hölzerneren": "Hölzernere",
    "Hölzernsten": "Hölzernste",
    "Hörbaren": "Hörbare",
    "Hörbehinderten": "Hörbehinderte",
    "Hörbrillen": "Hörbrille",
    "Hörenden": "Hörende",
    "Hörens": "Hören",
    "Hörenswerte": "hörenswert",
    "Hörenswerten": "Hörenswerte",
    "Hörenswerteren": "Hörenswertere",
    "Hörenswertesten": "Hörenswerteste",
    "Hörern": "Hörer",
    "Hörers": "Hörer",
    "Hörfolgen": "Hörfolge",
    "Hörfunks": "Hörfunk",
    "Hörgeräte": "Hörgerät",
    "Hörgeräten": "Hörgerät",
    "Hörgeräts": "Hörgerät",
    "Hörgeschädigte": "hörgeschädigt",
    "Hörgeschädigten": "Hörgeschädigte",
    "Hörgrenzen": "Hörgrenze",
    "Hörige": "hörig",
    "Hörigen": "Hörige",
    "Hörigeren": "Hörigere",
    "Hörigsten": "Hörigste",
    "Hörnchens": "Hörnchen",
    "Hörner": "Horn",
    "Hörnerhauben": "Hörnerhaube",
    "Hörnern": "Horn",
    "Hörnerne": "hörnern",
    "Hörnernen": "Hörnerne",
    "Hörnerneren": "Hörnernere",
    "Hörnernsten": "Hörnernste",
    "Hörsaals": "Hörsaal",
    "Hörspiele": "Hörspiel",
    "Hörspielen": "Hörspiel",
    "Hörspieles": "Hörspiel",
    "Hörspiels": "Hörspiel",
    "Hörszenen": "Hörszene",
    "Hörsäle": "Hörsaal",
    "Hörsälen": "Hörsaal",
    "Hörvermögens": "Hörvermögen",
    "Hübe": "Hub",
    "Hüben": "Hub",
    "Hübners": "Hübner",
    "Hübsche": "hübsch",
    "Hübschen": "Hübsche",
    "Hübscheren": "Hübschere",
    "Hübschste": "hübsch",
    "Hübschsten": "Hübschste",
    "Hüften": "Hüfte",
    "Hüftgelenke": "Hüftgelenk",
    "Hüftgelenken": "Hüftgelenk",
    "Hüftgelenks": "Hüftgelenk",
    "Hüftknochens": "Hüftknochen",
    "Hüftleidens": "Hüftleiden",
    "Hügelige": "hügelig",
    "Hügeligen": "Hügelige",
    "Hügeligeren": "Hügeligere",
    "Hügeligsten": "Hügeligste",
    "Hügeln": "Hügel",
    "Hügels": "Hügel",
    "Hühnchens": "Hühnchen",
    "Hühner": "Huhn",
    "Hühnern": "Huhn",
    "Hüllen": "Hülle",
    "Hüllenden": "Hüllende",
    "Hüllenlosen": "Hüllenlose",
    "Hüllenloseren": "Hüllenlosere",
    "Hüllenlosesten": "Hüllenloseste",
    "Hüllens": "Hüllen",
    "Hülsen": "Hülse",
    "Hülsenden": "Hülsende",
    "Hülsens": "Hülsen",
    "Hündchens": "Hündchen",
    "Hündinnen": "Hündin",
    "Hünenhaften": "Hünenhafte",
    "Hünenhafteren": "Hünenhaftere",
    "Hünenhaftesten": "Hünenhafteste",
    "Hüpfenden": "Hüpfende",
    "Hüpfenderen": "Hüpfendere",
    "Hüpfendsten": "Hüpfendste",
    "Hüpfens": "Hüpfen",
    "Hürden": "Hürde",
    "Hüte": "hüten",
    "Hüten": "Hut",
    "Hütenden": "Hütende",
    "Hütenderen": "Hütendere",
    "Hütendsten": "Hütendste",
    "Hütens": "Hüten",
    "Hütern": "Hüter",
    "Hüters": "Hüter",
    "Hütleins": "Hütlein",
    "Hütten": "Hütte",
    "Hüttnern": "Hüttner",
    "Hüttners": "Hüttner",
    "IBMs": "IBM",
    "ICs": "IC",
    "IKEAs": "IKEA",
    "IMs": "IM",
    "IQs": "IQ",
    "Ibrahims": "Ibrahim",
    "Ichs": "Ich",
    "Ideale": "Ideal",
    "Idealen": "Ideale",
    "Idealeren": "Idealere",
    "Idealfalle": "Idealfall",
    "Idealfalls": "Idealfall",
    "Idealfälle": "Idealfall",
    "Idealfällen": "Idealfall",
    "Idealisierenden": "Idealisierende",
    "Idealisierens": "Idealisieren",
    "Idealisierte": "idealisiert",
    "Idealisierten": "Idealisierte",
    "Idealisten": "Idealist",
    "Idealistische": "idealistisch",
    "Idealistischen": "Idealistische",
    "Idealistischeren": "Idealistischere",
    "Idealistischsten": "Idealistischste",
    "Ideallösungen": "Ideallösung",
    "Ideals": "Ideal",
    "Idealste": "ideal",
    "Idealsten": "Idealste",
    "Idealtypischen": "Idealtypische",
    "Idealtypischeren": "Idealtypischere",
    "Idealtypischsten": "Idealtypischste",
    "Idealwerts": "Idealwert",
    "Idealzustands": "Idealzustand",
    "Ideelle": "ideell",
    "Ideellen": "Ideelle",
    "Ideelleren": "Ideellere",
    "Ideellsten": "Ideellste",
    "Ideen": "Idee",
    "Identifikationen": "Identifikation",
    "Identifizierenden": "Identifizierende",
    "Identifizierens": "Identifizieren",
    "Identifizierte": "identifiziert",
    "Identifizierten": "Identifizierte",
    "Identifizierungen": "Identifizierung",
    "Identische": "identisch",
    "Identischen": "Identische",
    "Identitäten": "Identität",
    "Ideologen": "Ideologe",
    "Ideologien": "Ideologie",
    "Ideologische": "ideologisch",
    "Ideologischen": "Ideologische",
    "Ideologischeren": "Ideologischere",
    "Ideologischsten": "Ideologischste",
    "Ideologisierenden": "Ideologisierende",
    "Ideologisierens": "Ideologisieren",
    "Ideologisierte": "ideologisiert",
    "Ideologisierten": "Ideologisierte",
    "Idiomatischen": "Idiomatische",
    "Idiomatisierenden": "Idiomatisierende",
    "Idiomatisierens": "Idiomatisieren",
    "Idiomatisierte": "idiomatisiert",
    "Idiomatisierten": "Idiomatisierte",
    "Idiome": "Idiom",
    "Idiomen": "Idiom",
    "Idioms": "Idiom",
    "Idole": "Idol",
    "Idolen": "Idol",
    "Idoles": "Idol",
    "Idols": "Idol",
    "Idyllische": "idyllisch",
    "Idyllischen": "Idyllische",
    "Idyllischeren": "Idyllischere",
    "Idyllischsten": "Idyllischste",
    "Igel": "igeln",
    "Igeln": "Igel",
    "Igelnden": "Igelnde",
    "Igelns": "Igeln",
    "Igels": "Igel",
    "Iglus": "Iglu",
    "Ignorante": "ignorant",
    "Ignoranten": "Ignorante",
    "Ignoranteren": "Ignorantere",
    "Ignorantesten": "Ignoranteste",
    "Ignorierenden": "Ignorierende",
    "Ignorierenderen": "Ignorierendere",
    "Ignorierendsten": "Ignorierendste",
    "Ignorierens": "Ignorieren",
    "Ignorierte": "ignoriert",
    "Ignorierten": "Ignorierte",
    "Ignorierteren": "Ignoriertere",
    "Ignoriertesten": "Ignorierteste",
    "Igors": "Igor",
    "Ikonen": "Ikone",
    "Ilbenstadts": "Ilbenstadt",
    "Illegale": "illegal",
    "Illegalen": "Illegale",
    "Illegaleren": "Illegalere",
    "Illegalsten": "Illegalste",
    "Illingens": "Illingen",
    "Illuminationen": "Illumination",
    "Illuminatore": "Illuminator",
    "Illuminatoren": "Illuminator",
    "Illuminators": "Illuminator",
    "Illuminierenden": "Illuminierende",
    "Illuminierens": "Illuminieren",
    "Illuminierte": "illuminiert",
    "Illuminierten": "Illuminierte",
    "Illuminierungen": "Illuminierung",
    "Illusionen": "Illusion",
    "Illusionisten": "Illusionist",
    "Illusionistische": "illusionistisch",
    "Illusionistischen": "Illusionistische",
    "Illusionäre": "illusionär",
    "Illusionären": "Illusionäre",
    "Illusionäreren": "Illusionärere",
    "Illusionärsten": "Illusionärste",
    "Illusorischen": "Illusorische",
    "Illustren": "Illustre",
    "Illustrierenden": "Illustrierende",
    "Illustrierens": "Illustrieren",
    "Illustrierte": "illustriert",
    "Illustrierten": "Illustrierte",
    "Ilses": "Ilse",
    "Imaginationen": "Imagination",
    "Imaginative": "imaginativ",
    "Imaginativen": "Imaginative",
    "Imaginäre": "imaginär",
    "Imaginären": "Imaginäre",
    "Imbisse": "Imbiß",
    "Imbissen": "Imbiß",
    "Imbisses": "Imbiß",
    "Imitate": "Imitat",
    "Imitaten": "Imitat",
    "Imitationen": "Imitation",
    "Imitatore": "Imitator",
    "Imitatoren": "Imitator",
    "Imitatorische": "imitatorisch",
    "Imitatorischen": "Imitatorische",
    "Imitators": "Imitator",
    "Imitats": "Imitat",
    "Imitierenden": "Imitierende",
    "Imitierens": "Imitieren",
    "Imitierte": "imitiert",
    "Imitierten": "Imitierte",
    "Imitierteren": "Imitiertere",
    "Imitiertesten": "Imitierteste",
    "Imker": "imkern",
    "Imkereien": "Imkerei",
    "Imkern": "Imker",
    "Imkernden": "Imkernde",
    "Imkerns": "Imkern",
    "Imkers": "Imker",
    "Immanenten": "Immanente",
    "Immergrüne": "Immergrün",
    "Immergrünen": "Immergrün",
    "Immergrüns": "Immergrün",
    "Immerwährende": "immerwährend",
    "Immerwährenden": "Immerwährende",
    "Immigranten": "Immigrant",
    "Imminente": "imminent",
    "Imminenten": "Imminente",
    "Immissionen": "Immission",
    "Immobilien": "Immobilie",
    "Immobilisierungen": "Immobilisierung",
    "Immobils": "Immobil",
    "Immoralisten": "Immoralist",
    "Immune": "immun",
    "Immunen": "Immune",
    "Immunisierenden": "Immunisierende",
    "Immunisierenderen": "Immunisierendere",
    "Immunisierendsten": "Immunisierendste",
    "Immunisierens": "Immunisieren",
    "Immunisierte": "immunisiert",
    "Immunisierten": "Immunisierte",
    "Immunisierteren": "Immunisiertere",
    "Immunisiertesten": "Immunisierteste",
    "Immunisierungen": "Immunisierung",
    "Immunkörpern": "Immunkörper",
    "Immunkörpers": "Immunkörper",
    "Immunologische": "immunologisch",
    "Immunologischen": "Immunologische",
    "Immunschwächen": "Immunschwäche",
    "Immunsysteme": "Immunsystem",
    "Immunsystemen": "Immunsystem",
    "Immunsystems": "Immunsystem",
    "Imperative": "Imperativ",
    "Imperativen": "Imperativ",
    "Imperatives": "Imperativ",
    "Imperativs": "Imperativ",
    "Imperatore": "Imperator",
    "Imperatoren": "Imperator",
    "Imperators": "Imperator",
    "Imperfekte": "Imperfekt",
    "Imperfekten": "Imperfekt",
    "Imperfekts": "Imperfekt",
    "Imperiale": "imperial",
    "Imperialen": "Imperiale",
    "Imperialisten": "Imperialist",
    "Imperialistische": "imperialistisch",
    "Imperialistischen": "Imperialistische",
    "Impertinenten": "Impertinente",
    "Impertinenteren": "Impertinentere",
    "Impertinentesten": "Impertinenteste",
    "Impfenden": "Impfende",
    "Impfens": "Impfen",
    "Impflinge": "Impfling",
    "Impflingen": "Impfling",
    "Impflings": "Impfling",
    "Impfpistolen": "Impfpistole",
    "Impfstoffe": "Impfstoff",
    "Impfstoffen": "Impfstoff",
    "Impfstoffes": "Impfstoff",
    "Implikationen": "Implikation",
    "Implizierenden": "Implizierende",
    "Implizierens": "Implizieren",
    "Implizierte": "impliziert",
    "Implizierten": "Implizierte",
    "Imponierenden": "Imponierende",
    "Imponierenderen": "Imponierendere",
    "Imponierendsten": "Imponierendste",
    "Imponierens": "Imponieren",
    "Imponiergehabes": "Imponiergehabe",
    "Imponierte": "imponiert",
    "Imponierten": "Imponierte",
    "Imponierteren": "Imponiertere",
    "Imponiertesten": "Imponierteste",
    "Importe": "Import",
    "Importen": "Importe",
    "Importierenden": "Importierende",
    "Importierens": "Importieren",
    "Importierte": "importiert",
    "Importierten": "Importierte",
    "Imports": "Import",
    "Importwaren": "Importware",
    "Imposante": "imposant",
    "Imposanten": "Imposante",
    "Imposanteren": "Imposantere",
    "Imposantesten": "Imposanteste",
    "Impossibelsten": "Impossibelste",
    "Impossiblen": "Impossible",
    "Impossibleren": "Impossiblere",
    "Impotenten": "Impotente",
    "Impotenteren": "Impotentere",
    "Impotentesten": "Impotenteste",
    "Impresarios": "Impresario",
    "Impressionen": "Impression",
    "Impressionisten": "Impressionist",
    "Impressionistische": "impressionistisch",
    "Impressionistischen": "Impressionistische",
    "Impressiven": "Impressive",
    "Improvisierenden": "Improvisierende",
    "Improvisierenderen": "Improvisierendere",
    "Improvisierens": "Improvisieren",
    "Improvisierte": "improvisiert",
    "Improvisierten": "Improvisierte",
    "Improvisierteren": "Improvisiertere",
    "Improvisiertesten": "Improvisierteste",
    "Impulse": "Impuls",
    "Impulsen": "Impuls",
    "Impulses": "Impuls",
    "Impulsive": "impulsiv",
    "Impulsiven": "Impulsive",
    "Impulsiveren": "Impulsivere",
    "Impulsivsten": "Impulsivste",
    "Inaktive": "inaktiv",
    "Inaktiven": "Inaktive",
    "Inakzeptablen": "Inakzeptable",
    "Inanspruchnahmen": "Inanspruchnahme",
    "Inbegriffene": "inbegriffen",
    "Inbegriffenen": "Inbegriffene",
    "Inbegriffs": "Inbegriff",
    "Inbilde": "Inbild",
    "Inbilder": "Inbild",
    "Inbildern": "Inbild",
    "Inbildes": "Inbild",
    "Inbilds": "Inbild",
    "Inbrünstige": "inbrünstig",
    "Inbrünstigen": "Inbrünstige",
    "Inbrünstigeren": "Inbrünstigere",
    "Inbrünstigsten": "Inbrünstigste",
    "Indern": "Inder",
    "Inders": "Inder",
    "Indexierenden": "Indexierende",
    "Indexierens": "Indexieren",
    "Indexierte": "indexiert",
    "Indexierten": "Indexierte",
    "Indexierungen": "Indexierung",
    "Indianern": "Indianer",
    "Indianers": "Indianer",
    "Indianische": "indianisch",
    "Indianischen": "Indianische",
    "Indianisten": "Indianist",
    "Indices": "Index",
    "Indiens": "Indien",
    "Indifferente": "indifferent",
    "Indifferenten": "Indifferente",
    "Indigolithen": "Indigolith",
    "Indikationen": "Indikation",
    "Indikatoren": "Indikator",
    "Indirekte": "indirekt",
    "Indirekten": "Indirekte",
    "Indirekteren": "Indirektere",
    "Indirektesten": "Indirekteste",
    "Indischen": "Indische",
    "Indiskreten": "Indiskrete",
    "Indiskretionen": "Indiskretion",
    "Indiskutabelste": "indiskutabel",
    "Indiskutabelsten": "Indiskutabelste",
    "Indiskutablen": "Indiskutable",
    "Indiskutableren": "Indiskutablere",
    "Indisponierten": "Indisponierte",
    "Indisponierteren": "Indisponiertere",
    "Indisponiertesten": "Indisponierteste",
    "Indiums": "Indium",
    "Individualisierungen": "Individualisierung",
    "Individuelle": "individuell",
    "Individuellen": "Individuelle",
    "Individuelleren": "Individuellere",
    "Individuellsten": "Individuellste",
    "Individuen": "Individuum",
    "Individuums": "Individuum",
    "Indizien": "Indiz",
    "Indizierenden": "Indizierende",
    "Indizierens": "Indizieren",
    "Indizierte": "indiziert",
    "Indizierten": "Indizierte",
    "Indochinas": "Indochina",
    "Indoeuropäern": "Indoeuropäer",
    "Indoeuropäers": "Indoeuropäer",
    "Indogermanen": "Indogermane",
    "Indogermanische": "indogermanisch",
    "Indogermanischen": "Indogermanische",
    "Indogermanisten": "Indogermanist",
    "Indologen": "Indologe",
    "Indonesiens": "Indonesien",
    "Indonesische": "indonesisch",
    "Indonesischen": "Indonesische",
    "Induktionen": "Induktion",
    "Induktive": "induktiv",
    "Induktiven": "Induktive",
    "Induktore": "Induktor",
    "Induktoren": "Induktor",
    "Induktors": "Induktor",
    "Industrialisierenden": "Industrialisierende",
    "Industrialisierens": "Industrialisieren",
    "Industrialisierte": "industrialisiert",
    "Industrialisierten": "Industrialisierte",
    "Industrialisierungen": "Industrialisierung",
    "Industrielle": "industriell",
    "Industriellen": "Industrielle",
    "Industrien": "Industrie",
    "Induzierenden": "Induzierende",
    "Induzierens": "Induzieren",
    "Induzierte": "induziert",
    "Induzierten": "Induzierte",
    "Ineffektiven": "Ineffektive",
    "Ineffektiveren": "Ineffektivere",
    "Ineffektivsten": "Ineffektivste",
    "Ineinanderfügenden": "Ineinanderfügende",
    "Ineinanderfügens": "Ineinanderfügen",
    "Ineinandergefügte": "ineinandergefügt",
    "Ineinandergefügten": "Ineinandergefügte",
    "Ineinandergegriffenen": "Ineinandergegriffene",
    "Ineinandergreifenden": "Ineinandergreifende",
    "Ineinandergreifens": "Ineinandergreifen",
    "Infamen": "Infame",
    "Infameren": "Infamere",
    "Infamsten": "Infamste",
    "Infantilen": "Infantile",
    "Infantileren": "Infantilere",
    "Infantilsten": "Infantilste",
    "Infarkte": "Infarkt",
    "Infarkten": "Infarkt",
    "Infarktes": "Infarkt",
    "Infarkts": "Infarkt",
    "Infekte": "Infekt",
    "Infekten": "Infekt",
    "Infektes": "Infekt",
    "Infektionen": "Infektion",
    "Infektiöse": "infektiös",
    "Infektiösen": "Infektiöse",
    "Infekts": "Infekt",
    "Infiltrierenden": "Infiltrierende",
    "Infiltrierens": "Infiltrieren",
    "Infiltrierte": "infiltriert",
    "Infiltrierten": "Infiltrierte",
    "Infiniten": "Infinite",
    "Infinitesimalen": "Infinitesimale",
    "Infinitive": "Infinitiv",
    "Infinitiven": "Infinitiv",
    "Infinitives": "Infinitiv",
    "Infinitivs": "Infinitiv",
    "Infizierenden": "Infizierende",
    "Infizierens": "Infizieren",
    "Infizierte": "infiziert",
    "Infizierten": "Infizierte",
    "Infizierungen": "Infizierung",
    "Inflationen": "Inflation",
    "Inflationäre": "inflationär",
    "Inflationären": "Inflationäre",
    "Inflatorische": "inflatorisch",
    "Inflatorischen": "Inflatorische",
    "Infloreszenzen": "Infloreszenz",
    "Informanden": "Informand",
    "Informatikern": "Informatiker",
    "Informatikers": "Informatiker",
    "Informationen": "Information",
    "Informative": "informativ",
    "Informativen": "Informative",
    "Informativeren": "Informativere",
    "Informativsten": "Informativste",
    "Informellen": "Informelle",
    "Informierenden": "Informierende",
    "Informierenderen": "Informierendere",
    "Informierendsten": "Informierendste",
    "Informierens": "Informieren",
    "Informierte": "informiert",
    "Informierten": "Informierte",
    "Informierteren": "Informiertere",
    "Informiertesten": "Informierteste",
    "Infos": "Info",
    "Infostande": "Infostand",
    "Infostands": "Infostand",
    "Infostände": "Infostand",
    "Infoständen": "Infostand",
    "Infragestellungen": "Infragestellung",
    "Infrarote": "infrarot",
    "Infraroten": "Infrarote",
    "Infrarotfilme": "Infrarotfilm",
    "Infrarotfilmen": "Infrarotfilm",
    "Infrarotfilms": "Infrarotfilm",
    "Infrarotmeldern": "Infrarotmelder",
    "Infrarotmelders": "Infrarotmelder",
    "Infrarotstrahlern": "Infrarotstrahler",
    "Infrarotstrahlers": "Infrarotstrahler",
    "Infrastrukturen": "Infrastruktur",
    "Infusionen": "Infusion",
    "Ingeborgs": "Ingeborg",
    "Ingelheims": "Ingelheim",
    "Ingenieure": "Ingenieur",
    "Ingenieuren": "Ingenieur",
    "Ingenieurs": "Ingenieur",
    "Inges": "Inge",
    "Ingos": "Ingo",
    "Ingrids": "Ingrid",
    "Ingwers": "Ingwer",
    "Inhaberinnen": "Inhaberin",
    "Inhabern": "Inhaber",
    "Inhabers": "Inhaber",
    "Inhaftierenden": "Inhaftierende",
    "Inhaftierens": "Inhaftieren",
    "Inhaftierte": "inhaftiert",
    "Inhaftierten": "Inhaftierte",
    "Inhaftierungen": "Inhaftierung",
    "Inhalationen": "Inhalation",
    "Inhalierenden": "Inhalierende",
    "Inhalierens": "Inhalieren",
    "Inhalierte": "inhaliert",
    "Inhalierten": "Inhalierte",
    "Inhalte": "Inhalt",
    "Inhalten": "Inhalt",
    "Inhaltes": "Inhalt",
    "Inhaltliche": "inhaltlich",
    "Inhaltlichen": "Inhaltliche",
    "Inhalts": "Inhalt",
    "Inhaltsleere": "inhaltsleer",
    "Inhaltsleeren": "Inhaltsleere",
    "Inhaltsreichen": "Inhaltsreiche",
    "Inhaltsreicheren": "Inhaltsreichere",
    "Inhaltsreichsten": "Inhaltsreichste",
    "Inhaltsschweren": "Inhaltsschwere",
    "Inhaltsschwereren": "Inhaltsschwerere",
    "Inhaltsschwersten": "Inhaltsschwerste",
    "Inhibitore": "Inhibitor",
    "Inhibitoren": "Inhibitor",
    "Inhibitors": "Inhibitor",
    "Inhärenten": "Inhärente",
    "Initiativen": "Initiative",
    "Initiatore": "Initiator",
    "Initiatoren": "Initiator",
    "Initiators": "Initiator",
    "Injektionen": "Injektion",
    "Injektionsspritzen": "Injektionsspritze",
    "Injektive": "Injektiv",
    "Injektiven": "Injektive",
    "Injektivs": "Injektiv",
    "Injektore": "Injektor",
    "Injektoren": "Injektor",
    "Injektors": "Injektor",
    "Injizierenden": "Injizierende",
    "Injizierens": "Injizieren",
    "Injizierte": "injiziert",
    "Injizierten": "Injizierte",
    "Injunktionen": "Injunktion",
    "Inkarnationen": "Inkarnation",
    "Inkas": "Inka",
    "Inkassos": "Inkasso",
    "Inkassovollmachten": "Inkassovollmacht",
    "Inkathas": "Inkatha",
    "Inkognitos": "Inkognito",
    "Inkompatibelste": "inkompatibel",
    "Inkompatibelsten": "Inkompatibelste",
    "Inkompatiblen": "Inkompatible",
    "Inkompatibleren": "Inkompatiblere",
    "Inkonsequenten": "Inkonsequente",
    "Inkonsequenteren": "Inkonsequentere",
    "Inkonsequentesten": "Inkonsequenteste",
    "Inkonsequenzen": "Inkonsequenz",
    "Inkonsistente": "inkonsistent",
    "Inkonsistenten": "Inkonsistente",
    "Inkonsistenteren": "Inkonsistentere",
    "Inkonsistentesten": "Inkonsistenteste",
    "Inkrafttretens": "Inkrafttreten",
    "Inkremente": "Inkrement",
    "Inkrementen": "Inkrement",
    "Inkrementierenden": "Inkrementierende",
    "Inkrementierens": "Inkrementieren",
    "Inkrementierte": "inkrementiert",
    "Inkrementierten": "Inkrementierte",
    "Inkrements": "Inkrement",
    "Inkubationen": "Inkubation",
    "Inkubationszeiten": "Inkubationszeit",
    "Inkubatore": "Inkubator",
    "Inkubatoren": "Inkubator",
    "Inkubators": "Inkubator",
    "Inlande": "Inland",
    "Inlandes": "Inland",
    "Inlands": "Inland",
    "Inlaute": "Inlaut",
    "Inlauten": "Inlaut",
    "Inlauts": "Inlaut",
    "Inländern": "Inländer",
    "Inländers": "Inländer",
    "Inländische": "inländisch",
    "Inländischen": "Inländische",
    "Innegehaltenen": "Innegehaltene",
    "Innegewohnten": "Innegewohnte",
    "Innehaltenden": "Innehaltende",
    "Innehaltens": "Innehalten",
    "Innenausstattungen": "Innenausstattung",
    "Innendekorationen": "Innendekoration",
    "Innendiensts": "Innendienst",
    "Inneneinrichtungen": "Inneneinrichtung",
    "Innenhofe": "Innenhof",
    "Innenhofs": "Innenhof",
    "Innenhöfe": "Innenhof",
    "Innenhöfen": "Innenhof",
    "Innenlebens": "Innenleben",
    "Innenliegende": "innenliegend",
    "Innenliegenden": "Innenliegende",
    "Innenmessungen": "Innenmessung",
    "Innenministerien": "Innenministerium",
    "Innenministeriums": "Innenministerium",
    "Innenministern": "Innenminister",
    "Innenministers": "Innenminister",
    "Innenpolitische": "innenpolitisch",
    "Innenpolitischen": "Innenpolitische",
    "Innenraume": "Innenraum",
    "Innenraums": "Innenraum",
    "Innenräume": "Innenraum",
    "Innenräumen": "Innenraum",
    "Innensenatore": "Innensenator",
    "Innensenatoren": "Innensenator",
    "Innensenators": "Innensenator",
    "Innentemperaturen": "Innentemperatur",
    "Innenverwaltungen": "Innenverwaltung",
    "Innenwinkeln": "Innenwinkel",
    "Innenwinkels": "Innenwinkel",
    "Innerbetriebliche": "innerbetrieblich",
    "Innerbetrieblichen": "Innerbetriebliche",
    "Innerdeutschen": "Innerdeutsche",
    "Innerdienstlichen": "Innerdienstliche",
    "Inneren": "Innere",
    "Innereren": "Innerere",
    "Innerlichen": "Innerliche",
    "Innerpolitischen": "Innerpolitische",
    "Innerstaatlichen": "Innerstaatliche",
    "Innersten": "Innerste",
    "Innewohnenden": "Innewohnende",
    "Innewohnens": "Innewohnen",
    "Innigen": "Innige",
    "Innigeren": "Innigere",
    "Innigsten": "Innigste",
    "Innovationen": "Innovation",
    "Innovative": "innovativ",
    "Innovativen": "Innovative",
    "Innovativeren": "Innovativere",
    "Innovativsten": "Innovativste",
    "Innsbrucks": "Innsbruck",
    "Innungen": "Innung",
    "Inoffizielle": "inoffiziell",
    "Inoffiziellen": "Inoffizielle",
    "Inoperablen": "Inoperable",
    "Inquisitionen": "Inquisition",
    "Inquisitore": "Inquisitor",
    "Inquisitoren": "Inquisitor",
    "Inquisitorische": "inquisitorisch",
    "Inquisitorischen": "Inquisitorische",
    "Inquisitors": "Inquisitor",
    "Insassen": "Insasse",
    "Insassinnen": "Insassin",
    "Inschriften": "Inschrift",
    "Insekte": "Insekt",
    "Insekten": "Insekt",
    "Insektes": "Insekt",
    "Insektizide": "Insektizid",
    "Insektiziden": "Insektizide",
    "Insektizids": "Insektizid",
    "Insektologen": "Insektologe",
    "Inseln": "Insel",
    "Inserate": "Inserat",
    "Inseraten": "Inserat",
    "Inserates": "Inserat",
    "Inserats": "Inserat",
    "Inserierenden": "Inserierende",
    "Inserierenderen": "Inserierendere",
    "Inserierendsten": "Inserierendste",
    "Inserierens": "Inserieren",
    "Inserierte": "inseriert",
    "Inserierten": "Inserierte",
    "Insertionen": "Insertion",
    "Insidern": "Insider",
    "Insiders": "Insider",
    "Inspekteure": "Inspekteur",
    "Inspekteuren": "Inspekteur",
    "Inspekteures": "Inspekteur",
    "Inspekteurs": "Inspekteur",
    "Inspektoren": "Inspektor",
    "Inspektorinnen": "Inspektorin",
    "Inspirationen": "Inspiration",
    "Inspirierenden": "Inspirierende",
    "Inspirierenderen": "Inspirierendere",
    "Inspirierendsten": "Inspirierendste",
    "Inspirierens": "Inspirieren",
    "Inspirierte": "inspiriert",
    "Inspirierten": "Inspirierte",
    "Inspirierteren": "Inspiriertere",
    "Inspiriertesten": "Inspirierteste",
    "Inspizienten": "Inspizient",
    "Inspizierenden": "Inspizierende",
    "Inspizierens": "Inspizieren",
    "Inspizierte": "inspiziert",
    "Inspizierten": "Inspizierte",
    "Instabilen": "Instabile",
    "Instabileren": "Instabilere",
    "Instabilsten": "Instabilste",
    "Installationen": "Installation",
    "Installierenden": "Installierende",
    "Installierens": "Installieren",
    "Installierte": "installiert",
    "Installierten": "Installierte",
    "Instandbesetzungen": "Instandbesetzung",
    "Instanzen": "Instanz",
    "Instinkte": "Instinkt",
    "Instinkten": "Instinkt",
    "Instinktive": "instinktiv",
    "Instinktiven": "Instinktive",
    "Instinktiveren": "Instinktivere",
    "Instinktivsten": "Instinktivste",
    "Instinkts": "Instinkt",
    "Institute": "Institut",
    "Instituten": "Institut",
    "Institutionalisieren": "institutionalisiere",
    "Institutionalisierens": "Institutionalisieren",
    "Institutionalisierte": "institutionalisiert",
    "Institutionalisierten": "Institutionalisierte",
    "Institutionalisierteren": "Institutionalisiertere",
    "Institutionellen": "Institutionelle",
    "Institutionen": "Institution",
    "Instituts": "Institut",
    "Institutsbüchereien": "Institutsbücherei",
    "Instruierenden": "Instruierende",
    "Instruierens": "Instruieren",
    "Instruierte": "instruiert",
    "Instruierten": "Instruierte",
    "Instruktionen": "Instruktion",
    "Instruktive": "instruktiv",
    "Instruktiven": "Instruktive",
    "Instrumentalen": "Instrumentale",
    "Instrumentalisierenden": "Instrumentalisierende",
    "Instrumentalisierens": "Instrumentalisieren",
    "Instrumentalisierte": "instrumentalisiert",
    "Instrumentalisierten": "Instrumentalisierte",
    "Instrumentalisten": "Instrumentalist",
    "Instrumente": "Instrument",
    "Instrumentelle": "instrumentell",
    "Instrumentellen": "Instrumentelle",
    "Instrumenten": "Instrument",
    "Instrumentes": "Instrument",
    "Instrumentierenden": "Instrumentierende",
    "Instrumentierens": "Instrumentieren",
    "Instrumentierte": "instrumentiert",
    "Instrumentierten": "Instrumentierte",
    "Instruments": "Instrument",
    "Inständige": "inständig",
    "Inständigen": "Inständige",
    "Insuffiziente": "insuffizient",
    "Insuffizienten": "Insuffiziente",
    "Insuffizienteren": "Insuffizientere",
    "Insuffizientesten": "Insuffizienteste",
    "Inszenierenden": "Inszenierende",
    "Inszenierens": "Inszenieren",
    "Inszenierte": "inszeniert",
    "Inszenierten": "Inszenierte",
    "Inszenierungen": "Inszenierung",
    "Intakte": "intakt",
    "Intakten": "Intakte",
    "Intakteren": "Intaktere",
    "Intaktesten": "Intakteste",
    "Integersten": "Integerste",
    "Integrale": "Integral",
    "Integralen": "Integral",
    "Integrals": "Integral",
    "Integranden": "Integrand",
    "Integrationen": "Integration",
    "Integrative": "integrativ",
    "Integrativen": "Integrative",
    "Integrativeren": "Integrativere",
    "Integrativsten": "Integrativste",
    "Integratore": "Integrator",
    "Integratoren": "Integrator",
    "Integrators": "Integrator",
    "Integre": "integer",
    "Integren": "Integre",
    "Integreren": "Integrere",
    "Integrierenden": "Integrierende",
    "Integrierens": "Integrieren",
    "Integrierte": "integriert",
    "Integrierten": "Integrierte",
    "Integrierteren": "Integriertere",
    "Integriertesten": "Integrierteste",
    "Intellektuellen": "Intellektuelle",
    "Intellektuelleren": "Intellektuellere",
    "Intellektuellsten": "Intellektuellste",
    "Intelligenten": "Intelligente",
    "Intelligenteren": "Intelligentere",
    "Intelligentesten": "Intelligenteste",
    "Intelligenzlern": "Intelligenzler",
    "Intelligenzlers": "Intelligenzler",
    "Intendanten": "Intendant",
    "Intendierenden": "Intendierende",
    "Intendierens": "Intendieren",
    "Intendierte": "intendiert",
    "Intendierten": "Intendierte",
    "Intensitäten": "Intensität",
    "Intensive": "intensiv",
    "Intensiven": "Intensive",
    "Intensiveren": "Intensivere",
    "Intensivstationen": "Intensivstation",
    "Intensivste": "intensiv",
    "Intensivsten": "Intensivste",
    "Intentionalen": "Intentionale",
    "Intentionen": "Intention",
    "Interaktionen": "Interaktion",
    "Interaktive": "interaktiv",
    "Interaktiven": "Interaktive",
    "Interaktiveren": "Interaktivere",
    "Interaktivsten": "Interaktivste",
    "Interdependenzen": "Interdependenz",
    "Interdisziplinaritäten": "Interdisziplinarität",
    "Interdisziplinäre": "interdisziplinär",
    "Interdisziplinären": "Interdisziplinäre",
    "Interessante": "interessant",
    "Interessanten": "Interessante",
    "Interessanteren": "Interessantere",
    "Interessantesten": "Interessanteste",
    "Interessen": "Interesse",
    "Interessenten": "Interessent",
    "Interesses": "Interesse",
    "Interessierenden": "Interessierende",
    "Interessierens": "Interessieren",
    "Interessierte": "interessiert",
    "Interessierten": "Interessierte",
    "Interessierteren": "Interessiertere",
    "Interessiertesten": "Interessierteste",
    "Interfraktionellen": "Interfraktionelle",
    "Intergalaktischen": "Intergalaktische",
    "Interims": "Interim",
    "Interimsbescheide": "Interimsbescheid",
    "Interimsbescheiden": "Interimsbescheid",
    "Interimsbescheids": "Interimsbescheid",
    "Interimslösungen": "Interimslösung",
    "Interimsregierungen": "Interimsregierung",
    "Interimsscheine": "Interimsschein",
    "Interimsscheinen": "Interimsschein",
    "Interimsscheins": "Interimsschein",
    "Interkonfessionelle": "interkonfessionell",
    "Interkonfessionellen": "Interkonfessionelle",
    "Interkontinentalen": "Interkontinentale",
    "Interkulturellen": "Interkulturelle",
    "Intermezzos": "Intermezzo",
    "Intermissionen": "Intermission",
    "Internalisierenden": "Internalisierende",
    "Internalisierens": "Internalisieren",
    "Internalisierte": "internalisiert",
    "Internalisierten": "Internalisierte",
    "Internate": "Internat",
    "Internaten": "Internat",
    "Internationale": "international",
    "Internationalen": "Internationale",
    "Internationaleren": "Internationalere",
    "Internationalsten": "Internationalste",
    "Internats": "Internat",
    "Interne": "intern",
    "Internen": "Interne",
    "Internierenden": "Internierende",
    "Internierens": "Internieren",
    "Internierte": "interniert",
    "Internierten": "Internierte",
    "Internierungen": "Internierung",
    "Internisten": "Internist",
    "Interplanetare": "interplanetar",
    "Interplanetaren": "Interplanetare",
    "Interpolationen": "Interpolation",
    "Interpolierenden": "Interpolierende",
    "Interpolierens": "Interpolieren",
    "Interpolierte": "interpoliert",
    "Interpolierten": "Interpolierte",
    "Interpretationen": "Interpretation",
    "Interpretative": "interpretativ",
    "Interpretativen": "Interpretative",
    "Interpretativeren": "Interpretativere",
    "Interpretativsten": "Interpretativste",
    "Interpreten": "Interpret",
    "Interpretierenden": "Interpretierende",
    "Interpretierens": "Interpretieren",
    "Interpretierte": "interpretiert",
    "Interpretierten": "Interpretierte",
    "Interpunktierenden": "Interpunktierende",
    "Interpunktierens": "Interpunktieren",
    "Interpunktierte": "interpunktiert",
    "Interpunktierten": "Interpunktierte",
    "Interregios": "Interregio",
    "Interrogative": "interrogativ",
    "Interrogativen": "Interrogative",
    "Interrogativpronomens": "Interrogativpronomen",
    "Intersexuelle": "intersexuell",
    "Intersexuellen": "Intersexuelle",
    "Interstellaren": "Interstellare",
    "Interterritorialen": "Interterritoriale",
    "Intervalle": "Intervall",
    "Intervallen": "Intervall",
    "Intervalles": "Intervall",
    "Intervalls": "Intervall",
    "Intervenierenden": "Intervenierende",
    "Intervenierens": "Intervenieren",
    "Intervenierte": "interveniert",
    "Intervenierten": "Intervenierte",
    "Interventionen": "Intervention",
    "Interviews": "Interview",
    "Inthronisierenden": "Inthronisierende",
    "Inthronisierens": "Inthronisieren",
    "Inthronisierte": "inthronisiert",
    "Inthronisierten": "Inthronisierte",
    "Inthronisierungen": "Inthronisierung",
    "Intimbereiche": "Intimbereich",
    "Intimbereichen": "Intimbereich",
    "Intimbereichs": "Intimbereich",
    "Intime": "intim",
    "Intimen": "Intime",
    "Intimeren": "Intimere",
    "Intimitäten": "Intimität",
    "Intimpartnern": "Intimpartner",
    "Intimpartners": "Intimpartner",
    "Intimste": "intim",
    "Intimsten": "Intimste",
    "Intimverkehrs": "Intimverkehr",
    "Intimzonen": "Intimzone",
    "Intolerante": "intolerant",
    "Intoleranten": "Intolerante",
    "Intoleranteren": "Intolerantere",
    "Intolerantesten": "Intoleranteste",
    "Intonierenden": "Intonierende",
    "Intonierens": "Intonieren",
    "Intonierte": "intoniert",
    "Intonierten": "Intonierte",
    "Intralingualen": "Intralinguale",
    "Intramolekularen": "Intramolekulare",
    "Intramuskulären": "Intramuskuläre",
    "Intransitiven": "Intransitive",
    "Intrazellularen": "Intrazellulare",
    "Intriganten": "Intrigante",
    "Intrigen": "Intrige",
    "Intrigierenden": "Intrigierende",
    "Intrigierens": "Intrigieren",
    "Intrigierte": "intrigiert",
    "Intrigierten": "Intrigierte",
    "Intrinsischen": "Intrinsische",
    "Introjektionen": "Introjektion",
    "Intros": "Intro",
    "Intubationen": "Intubation",
    "Intuitionen": "Intuition",
    "Intuitive": "intuitiv",
    "Intuitiven": "Intuitive",
    "Intuitiveren": "Intuitivere",
    "Intuitivsten": "Intuitivste",
    "Invasionen": "Invasion",
    "Inventars": "Inventar",
    "Investierenden": "Investierende",
    "Investierens": "Investieren",
    "Investierte": "investiert",
    "Investierten": "Investierte",
    "Investitionen": "Investition",
    "Investoren": "Investor",
    "Involvierenden": "Involvierende",
    "Involvierenderen": "Involvierendere",
    "Involvierendsten": "Involvierendste",
    "Involvierens": "Involvieren",
    "Involvierte": "involviert",
    "Involvierten": "Involvierte",
    "Involvierteren": "Involviertere",
    "Involviertesten": "Involvierteste",
    "Inwohnern": "Inwohner",
    "Inwohners": "Inwohner",
    "Inzeste": "Inzest",
    "Inzesten": "Inzest",
    "Inzests": "Inzest",
    "Inzidenzwinkeln": "Inzidenzwinkel",
    "Inzidenzwinkels": "Inzidenzwinkel",
    "Iods": "Iod",
    "Iodsäuren": "Iodsäure",
    "Ionisierenden": "Ionisierende",
    "Ionisierens": "Ionisieren",
    "Ionisierte": "ionisiert",
    "Ionisierten": "Ionisierte",
    "Irakern": "Iraker",
    "Irakers": "Iraker",
    "Irakische": "irakisch",
    "Irakischen": "Irakische",
    "Iraks": "Irak",
    "Iranische": "iranisch",
    "Iranischen": "Iranische",
    "Iranisten": "Iranist",
    "Irans": "Iran",
    "Irdische": "irdisch",
    "Irdischen": "Irdische",
    "Irdischeren": "Irdischere",
    "Irdischsten": "Irdischste",
    "Iren": "Ire",
    "Irinnen": "Irin",
    "Irisblenden": "Irisblende",
    "Irische": "irisch",
    "Irischen": "Irische",
    "Irlands": "Irland",
    "Irländerinnen": "Irländerin",
    "Irländern": "Irländer",
    "Irländers": "Irländer",
    "Irländische": "irländisch",
    "Irländischen": "Irländische",
    "Irmgards": "Irmgard",
    "Irokesen": "Irokese",
    "Irokesische": "irokesisch",
    "Irokesischen": "Irokesische",
    "Ironischen": "Ironische",
    "Ironischeren": "Ironischere",
    "Ironischsten": "Ironischste",
    "Irrationalen": "Irrationale",
    "Irrationaleren": "Irrationalere",
    "Irrationalsten": "Irrationalste",
    "Irreale": "irreal",
    "Irrealen": "Irreale",
    "Irrealeren": "Irrealere",
    "Irrealsten": "Irrealste",
    "Irredentisten": "Irredentist",
    "Irreduzible": "irreduzibel",
    "Irreduziblen": "Irreduzible",
    "Irreführenden": "Irreführende",
    "Irreführens": "Irreführen",
    "Irreführungen": "Irreführung",
    "Irregeführten": "Irregeführte",
    "Irregeleiteten": "Irregeleitete",
    "Irregulären": "Irreguläre",
    "Irreleitenden": "Irreleitende",
    "Irreleitens": "Irreleiten",
    "Irren": "Irre",
    "Irrenden": "Irrende",
    "Irrens": "Irren",
    "Irreparabelste": "irreparabel",
    "Irreparabelsten": "Irreparabelste",
    "Irreparablen": "Irreparable",
    "Irreparableren": "Irreparablere",
    "Irreseins": "Irresein",
    "Irreversibelsten": "Irreversibelste",
    "Irreversiblen": "Irreversible",
    "Irreversibleren": "Irreversiblere",
    "Irrfahrten": "Irrfahrt",
    "Irrgange": "Irrgang",
    "Irrgangs": "Irrgang",
    "Irrglauben": "Irrglaube",
    "Irrgläubige": "irrgläubig",
    "Irrgläubigen": "Irrgläubige",
    "Irrgläubigeren": "Irrgläubigere",
    "Irrgläubigsten": "Irrgläubigste",
    "Irrgänge": "Irrgang",
    "Irrgängen": "Irrgang",
    "Irrigatore": "Irrigator",
    "Irrigatoren": "Irrigator",
    "Irrigators": "Irrigator",
    "Irritationen": "Irritation",
    "Irritierenden": "Irritierende",
    "Irritierenderen": "Irritierendere",
    "Irritierendsten": "Irritierendste",
    "Irritierens": "Irritieren",
    "Irritierte": "irritiert",
    "Irritierten": "Irritierte",
    "Irritierteren": "Irritiertere",
    "Irritiertesten": "Irritierteste",
    "Irrlehren": "Irrlehre",
    "Irrlichte": "Irrlicht",
    "Irrlichter": "Irrlicht",
    "Irrlichtern": "Irrlicht",
    "Irrlichtes": "Irrlicht",
    "Irrlichts": "Irrlicht",
    "Irrläufern": "Irrläufer",
    "Irrläufers": "Irrläufer",
    "Irrnisse": "Irrnis",
    "Irrnissen": "Irrnis",
    "Irrsinnige": "irrsinnig",
    "Irrsinnigen": "Irrsinnige",
    "Irrsinnigeren": "Irrsinnigere",
    "Irrsinnigsten": "Irrsinnigste",
    "Irrsinns": "Irrsinn",
    "Irrtume": "Irrtum",
    "Irrtums": "Irrtum",
    "Irrtümer": "Irrtum",
    "Irrtümern": "Irrtum",
    "Irrtümliche": "irrtümlich",
    "Irrtümlichen": "Irrtümliche",
    "Irrwische": "Irrwisch",
    "Irrwischen": "Irrwisch",
    "Irrwisches": "Irrwisch",
    "Irrwischs": "Irrwisch",
    "Isabels": "Isabel",
    "Isenburgs": "Isenburg",
    "Islame": "Islam",
    "Islames": "Islam",
    "Islamische": "islamisch",
    "Islamischen": "Islamische",
    "Islamisierenden": "Islamisierende",
    "Islamisierens": "Islamisieren",
    "Islamisierte": "islamisiert",
    "Islamisierten": "Islamisierte",
    "Islamisten": "Islamist",
    "Islamiten": "Islamit",
    "Islams": "Islam",
    "Islands": "Island",
    "Isländische": "isländisch",
    "Isländischen": "Isländische",
    "Isobaren": "Isobare",
    "Isolationen": "Isolation",
    "Isolatore": "Isolator",
    "Isolatoren": "Isolator",
    "Isolators": "Isolator",
    "Isolierbande": "Isolierband",
    "Isolierbandes": "Isolierband",
    "Isolierbands": "Isolierband",
    "Isolierbänder": "Isolierband",
    "Isolierbändern": "Isolierband",
    "Isolierenden": "Isolierende",
    "Isolierenderen": "Isolierendere",
    "Isolierendsten": "Isolierendste",
    "Isolierens": "Isolieren",
    "Isolierstationen": "Isolierstation",
    "Isolierte": "isoliert",
    "Isolierten": "Isolierte",
    "Isolierteren": "Isoliertere",
    "Isoliertesten": "Isolierteste",
    "Isolierungen": "Isolierung",
    "Isolierzellen": "Isolierzelle",
    "Isomatten": "Isomatte",
    "Isomorphe": "isomorph",
    "Isomorphen": "Isomorphe",
    "Isotonischen": "Isotonische",
    "Israelis": "Israeli",
    "Israelische": "israelisch",
    "Israelischen": "Israelische",
    "Israeliten": "Israelit",
    "Israelitische": "israelitisch",
    "Israelitischen": "Israelitische",
    "Israels": "Israel",
    "Istanbuls": "Istanbul",
    "Italias": "Italia",
    "Italienern": "Italiener",
    "Italieners": "Italiener",
    "Italienische": "italienisch",
    "Italienischen": "Italienische",
    "Italienischeren": "Italienischere",
    "Italienischsten": "Italienischste",
    "Italiens": "Italien",
    "Items": "Item",
    "Iterationen": "Iteration",
    "Iterative": "iterativ",
    "Iterativen": "Iterative",
    "Ivans": "Ivan",
    "Izabellas": "Izabella",
    "Izetbegovics": "Izetbegovic",
    "JVAs": "JVA",
    "Jachten": "Jacht",
    "Jacken": "Jacke",
    "Jacks": "Jack",
    "Jacksons": "Jackson",
    "Jagdberechtigte": "jagdberechtigt",
    "Jagdberechtigten": "Jagdberechtigte",
    "Jagden": "Jagd",
    "Jagenden": "Jagende",
    "Jagenderen": "Jagendere",
    "Jagendsten": "Jagendste",
    "Jagens": "Jagen",
    "Jahns": "Jahn",
    "Jahre": "Jahr",
    "Jahrelange": "jahrelang",
    "Jahrelangen": "Jahrelange",
    "Jahren": "Jahr",
    "Jahres": "Jahr",
    "Jahreszeitliche": "jahreszeitlich",
    "Jahreszeitlichen": "Jahreszeitliche",
    "Jahrgange": "Jahrgang",
    "Jahrgangs": "Jahrgang",
    "Jahrgänge": "Jahrgang",
    "Jahrgängen": "Jahrgang",
    "Jahrhunderte": "Jahrhundert",
    "Jahrhundertealte": "jahrhundertealt",
    "Jahrhundertealten": "Jahrhundertealte",
    "Jahrhundertelangen": "Jahrhundertelange",
    "Jahrhunderten": "Jahrhundert",
    "Jahrhunderts": "Jahrhundert",
    "Jahrs": "Jahr",
    "Jahrtausende": "Jahrtausend",
    "Jahrtausenden": "Jahrtausend",
    "Jahrtausends": "Jahrtausend",
    "Jahrzehnte": "Jahrzehnt",
    "Jahrzehntelange": "jahrzehntelang",
    "Jahrzehntelangen": "Jahrzehntelange",
    "Jahrzehnten": "Jahrzehnt",
    "Jahrzehntes": "Jahrzehnt",
    "Jahrzehnts": "Jahrzehnt",
    "Jakobinern": "Jakobiner",
    "Jakobiners": "Jakobiner",
    "Jakobs": "Jakob",
    "Jalousetten": "Jalousette",
    "Jammer": "jammern",
    "Jammerbilde": "Jammerbild",
    "Jammerbilder": "Jammerbild",
    "Jammerbildern": "Jammerbild",
    "Jammerbildes": "Jammerbild",
    "Jammerbilds": "Jammerbild",
    "Jammerlappens": "Jammerlappen",
    "Jammern": "Jammer",
    "Jammernden": "Jammernde",
    "Jammernderen": "Jammerndere",
    "Jammerndsten": "Jammerndste",
    "Jammerns": "Jammern",
    "Jammers": "Jammer",
    "Jammervollen": "Jammervolle",
    "Jammervolleren": "Jammervollere",
    "Jammervollsten": "Jammervollste",
    "Janowskis": "Janowski",
    "Jans": "Jan",
    "Jansens": "Jansen",
    "Januars": "Januar",
    "Japanern": "Japaner",
    "Japaners": "Japaner",
    "Japanische": "japanisch",
    "Japanischen": "Japanische",
    "Japanischeren": "Japanischere",
    "Japanischsten": "Japanischste",
    "Japanologen": "Japanologe",
    "Japans": "Japan",
    "Japsenden": "Japsende",
    "Japsenderen": "Japsendere",
    "Japsendsten": "Japsendste",
    "Japsens": "Japsen",
    "Jargons": "Jargon",
    "Jas": "Ja",
    "Jauchen": "Jauche",
    "Jauchzenden": "Jauchzende",
    "Jauchzenderen": "Jauchzendere",
    "Jauchzendsten": "Jauchzendste",
    "Jauchzens": "Jauchzen",
    "Jauchzern": "Jauchzer",
    "Jauchzers": "Jauchzer",
    "Jaulenden": "Jaulende",
    "Jaulens": "Jaulen",
    "Jaworte": "Jawort",
    "Jaworten": "Jawort",
    "Jaworts": "Jawort",
    "Jeannes": "Jeanne",
    "Jeans": "Jean",
    "Jecke": "jeck",
    "Jecken": "Jecke",
    "Jeckeren": "Jeckere",
    "Jecksten": "Jeckste",
    "Jedrychowskis": "Jedrychowski",
    "Jeeps": "Jeep",
    "Jelzins": "Jelzin",
    "Jenas": "Jena",
    "Jerichos": "Jericho",
    "Jerrys": "Jerry",
    "Jerusalems": "Jerusalem",
    "Jesuiten": "Jesuit",
    "Jets": "Jet",
    "Jetzige": "jetzig",
    "Jetzigen": "Jetzige",
    "Jeweiligen": "Jeweilige",
    "Jims": "Jim",
    "Joachims": "Joachim",
    "Jobbenden": "Jobbende",
    "Jobbens": "Jobben",
    "Jobs": "Job",
    "Jochens": "Jochen",
    "Jode": "Jod",
    "Jodelnden": "Jodelnde",
    "Jodelnderen": "Jodelndere",
    "Jodelndsten": "Jodelndste",
    "Jodelns": "Jodeln",
    "Jodes": "Jod",
    "Jodlern": "Jodler",
    "Jodlers": "Jodler",
    "Jods": "Jod",
    "Joes": "Joe",
    "Joggern": "Jogger",
    "Joggers": "Jogger",
    "Joghurts": "Joghurt",
    "Johannaes": "Johanna",
    "Johannitern": "Johanniter",
    "Johanniters": "Johanniter",
    "Johanns": "Johann",
    "Johlenden": "Johlende",
    "Johlenderen": "Johlendere",
    "Johlendsten": "Johlendste",
    "Johlens": "Johlen",
    "Johns": "John",
    "Johnsons": "Johnson",
    "Joints": "Joint",
    "Jokern": "Joker",
    "Jokers": "Joker",
    "Jollen": "Jolle",
    "Jongleure": "Jongleur",
    "Jongleuren": "Jongleur",
    "Jongleures": "Jongleur",
    "Jongleurs": "Jongleur",
    "Jons": "Jon",
    "Jordaniens": "Jordanien",
    "Jordans": "Jordan",
    "Joschkas": "Joschka",
    "Josefines": "Josefine",
    "Josefs": "Josef",
    "Josephs": "Joseph",
    "Jotas": "Jota",
    "Jourdans": "Jourdan",
    "Journalisten": "Journalist",
    "Journalistinnen": "Journalistin",
    "Juans": "Juan",
    "Jubel": "jubeln",
    "Jubelhochzeiten": "Jubelhochzeit",
    "Jubeln": "Jubel",
    "Jubelnden": "Jubelnde",
    "Jubelnderen": "Jubelndere",
    "Jubelndsten": "Jubelndste",
    "Jubelns": "Jubeln",
    "Jubels": "Jubel",
    "Jubilare": "Jubilar",
    "Jubilaren": "Jubilar",
    "Jubilarinnen": "Jubilarin",
    "Jubilars": "Jubilar",
    "Jubilierenden": "Jubilierende",
    "Jubilierenderen": "Jubilierendere",
    "Jubilierendsten": "Jubilierendste",
    "Jubilierens": "Jubilieren",
    "Jubilierte": "jubiliert",
    "Jubilierten": "Jubilierte",
    "Jubiläen": "Jubiläum",
    "Jubiläums": "Jubiläum",
    "Juchzenden": "Juchzende",
    "Juchzenderen": "Juchzendere",
    "Juchzendsten": "Juchzendste",
    "Juchzens": "Juchzen",
    "Juden": "Jude",
    "Judentums": "Judentum",
    "Judikationen": "Judikation",
    "Judikaturen": "Judikatur",
    "Judokas": "Judoka",
    "Judos": "Judo",
    "Jugendfreie": "jugendfrei",
    "Jugendfreien": "Jugendfreie",
    "Jugendfreundinnen": "Jugendfreundin",
    "Jugendgefährdende": "jugendgefährdend",
    "Jugendgefährdenden": "Jugendgefährdende",
    "Jugendgefährdenderen": "Jugendgefährdendere",
    "Jugendlichen": "Jugendliche",
    "Jugendlicheren": "Jugendlichere",
    "Jugendlichsten": "Jugendlichste",
    "Jugoslawen": "Jugoslawe",
    "Jugoslawiens": "Jugoslawien",
    "Jugoslawische": "jugoslawisch",
    "Jugoslawischen": "Jugoslawische",
    "Julias": "Julia",
    "Julis": "Juli",
    "Jumpern": "Jumper",
    "Jumpers": "Jumper",
    "Jungchens": "Jungchen",
    "Junge": "jung",
    "Jungen": "Junge",
    "Jungenhafte": "jungenhaft",
    "Jungenhaften": "Jungenhafte",
    "Jungenhafteren": "Jungenhaftere",
    "Jungenhaftesten": "Jungenhafteste",
    "Jungfern": "Jungfer",
    "Jungfernfahrten": "Jungfernfahrt",
    "Jungfernhäutchens": "Jungfernhäutchen",
    "Jungfrauen": "Jungfrau",
    "Jungfräuliche": "jungfräulich",
    "Jungfräulichen": "Jungfräuliche",
    "Jungfräulicheren": "Jungfräulichere",
    "Jungfräulichsten": "Jungfräulichste",
    "Junggrammatikern": "Junggrammatiker",
    "Junggrammatikers": "Junggrammatiker",
    "Jungheringe": "Junghering",
    "Jungheringen": "Junghering",
    "Jungherings": "Junghering",
    "Junglehrern": "Junglehrer",
    "Junglehrers": "Junglehrer",
    "Jungmädeln": "Jungmädel",
    "Jungmädels": "Jungmädel",
    "Jungparlamentariern": "Jungparlamentarier",
    "Jungparlamentariers": "Jungparlamentarier",
    "Jungsozialisten": "Jungsozialist",
    "Jungsteinzeitlichen": "Jungsteinzeitliche",
    "Jungstiere": "Jungstier",
    "Jungstieren": "Jungstier",
    "Jungstiers": "Jungstier",
    "Jungvolks": "Jungvolk",
    "Jungwilde": "Jungwild",
    "Jungwildes": "Jungwild",
    "Jungwilds": "Jungwild",
    "Jungwählern": "Jungwähler",
    "Jungwählers": "Jungwähler",
    "Junioren": "Junior",
    "Junis": "Juni",
    "Junkern": "Junker",
    "Junkers": "Junker",
    "Junkies": "Junkie",
    "Juppis": "Juppi",
    "Jurierenden": "Jurierende",
    "Jurierens": "Jurieren",
    "Jurierte": "juriert",
    "Jurierten": "Jurierte",
    "Juristen": "Jurist",
    "Juristische": "juristisch",
    "Juristischen": "Juristische",
    "Jurore": "Juror",
    "Juroren": "Juror",
    "Jurors": "Juror",
    "Jusos": "Juso",
    "Justierenden": "Justierende",
    "Justierens": "Justieren",
    "Justierte": "justiert",
    "Justierten": "Justierte",
    "Justierteren": "Justiertere",
    "Justiertesten": "Justierteste",
    "Justifikationen": "Justifikation",
    "Justifikaturen": "Justifikatur",
    "Justifizierenden": "Justifizierende",
    "Justifizierens": "Justifizieren",
    "Justifizierte": "justifiziert",
    "Justifizierten": "Justifizierte",
    "Justitiare": "Justitiar",
    "Justitiaren": "Justitiar",
    "Justitiars": "Justitiar",
    "Juten": "Jute",
    "Juttas": "Jutta",
    "Juwele": "Juwel",
    "Juwelen": "Juwel",
    "Juweliere": "Juwelier",
    "Juwelieren": "Juwelier",
    "Juweliers": "Juwelier",
    "Juwels": "Juwel",
    "Jäckchens": "Jäckchen",
    "Jäckeln": "Jäckel",
    "Jäckels": "Jäckel",
    "Jägern": "Jäger",
    "Jägers": "Jäger",
    "Jähen": "Jähe",
    "Jähnigs": "Jähnig",
    "Jährige": "jährig",
    "Jährigen": "Jährige",
    "Jährlichen": "Jährliche",
    "Jähzornige": "jähzornig",
    "Jähzornigen": "Jähzornige",
    "Jähzornigeren": "Jähzornigere",
    "Jähzornigsten": "Jähzornigste",
    "Jämmerliche": "jämmerlich",
    "Jämmerlichen": "Jämmerliche",
    "Jämmerlicheren": "Jämmerlichere",
    "Jämmerlichsten": "Jämmerlichste",
    "Jätenden": "Jätende",
    "Jätens": "Jäten",
    "Jörgs": "Jörg",
    "Jörns": "Jörn",
    "Jüdinnen": "Jüdin",
    "Jüdische": "jüdisch",
    "Jüdischen": "Jüdische",
    "Jügesheims": "Jügesheim",
    "Jüngeren": "Jüngere",
    "Jüngerinnen": "Jüngerin",
    "Jüngferlichen": "Jüngferliche",
    "Jüngferlicheren": "Jüngferlichere",
    "Jüngferlichsten": "Jüngferlichste",
    "Jünglinge": "Jüngling",
    "Jünglingen": "Jüngling",
    "Jünglings": "Jüngling",
    "Jüngste": "jung",
    "Jüngsten": "Jüngste",
    "Jüngstenrechte": "Jüngstenrecht",
    "Jüngstenrechten": "Jüngstenrecht",
    "Jüngstenrechts": "Jüngstenrecht",
    "Jürgens": "Jürgen",
    "Jütländern": "Jütländer",
    "Jütländers": "Jütländer",
    "KBs": "KB",
    "KZs": "KZ",
    "Kabarette": "Kabarett",
    "Kabaretten": "Kabarett",
    "Kabarettes": "Kabarett",
    "Kabarettisten": "Kabarettist",
    "Kabarettistische": "kabarettistisch",
    "Kabarettistischen": "Kabarettistische",
    "Kabaretts": "Kabarett",
    "Kabeln": "Kabel",
    "Kabels": "Kabel",
    "Kabinen": "Kabine",
    "Kabinette": "Kabinett",
    "Kabinetten": "Kabinett",
    "Kabinetts": "Kabinett",
    "Kabuffs": "Kabuff",
    "Kabuls": "Kabul",
    "Kabäuschens": "Kabäuschen",
    "Kachel": "kacheln",
    "Kacheln": "Kachel",
    "Kachelnden": "Kachelnde",
    "Kachelns": "Kacheln",
    "Kadern": "Kader",
    "Kaders": "Kader",
    "Kaffeesatzs": "Kaffeesatz",
    "Kaffeesiedern": "Kaffeesieder",
    "Kaffeesieders": "Kaffeesieder",
    "Kaffeetanten": "Kaffeetante",
    "Kaffeewärmern": "Kaffeewärmer",
    "Kaffeewärmers": "Kaffeewärmer",
    "Kaffs": "Kaff",
    "Kafkas": "Kafka",
    "Kahle": "kahl",
    "Kahlen": "Kahle",
    "Kahleren": "Kahlere",
    "Kahlfressenden": "Kahlfressende",
    "Kahlfressenderen": "Kahlfressendere",
    "Kahlfressendsten": "Kahlfressendste",
    "Kahlfressens": "Kahlfressen",
    "Kahlgefressenen": "Kahlgefressene",
    "Kahlgefresseneren": "Kahlgefressenere",
    "Kahlgefressensten": "Kahlgefressenste",
    "Kahlgescherten": "Kahlgescherte",
    "Kahlgeschorenen": "Kahlgeschorene",
    "Kahlgeschoreneren": "Kahlgeschorenere",
    "Kahlgeschorensten": "Kahlgeschorenste",
    "Kahlköpfigen": "Kahlköpfige",
    "Kahlköpfigeren": "Kahlköpfigere",
    "Kahlköpfigsten": "Kahlköpfigste",
    "Kahlscherenden": "Kahlscherende",
    "Kahlscherens": "Kahlscheren",
    "Kahlsten": "Kahlste",
    "Kahne": "Kahn",
    "Kahns": "Kahn",
    "Kairos": "Kairo",
    "Kais": "Kai",
    "Kaiserinnen": "Kaiserin",
    "Kaiserliche": "kaiserlich",
    "Kaiserlichen": "Kaiserliche",
    "Kaisern": "Kaiser",
    "Kaisers": "Kaiser",
    "Kaiserslauterns": "Kaiserslautern",
    "Kajüten": "Kajüte",
    "Kakaos": "Kakao",
    "Kakelnden": "Kakelnde",
    "Kakelnderen": "Kakelndere",
    "Kakelndsten": "Kakelndste",
    "Kakelns": "Kakeln",
    "Kakteen": "Kaktus",
    "Kalaschnikows": "Kalaschnikow",
    "Kalauern": "Kalauer",
    "Kalauers": "Kalauer",
    "Kalb": "kalben",
    "Kalbachern": "Kalbacher",
    "Kalbachers": "Kalbacher",
    "Kalbachs": "Kalbach",
    "Kalbe": "kalben",
    "Kalbenden": "Kalbende",
    "Kalbens": "Kalben",
    "Kalbereien": "Kalberei",
    "Kalbes": "Kalb",
    "Kalbs": "Kalb",
    "Kalendern": "Kalender",
    "Kalenders": "Kalender",
    "Kaliforniens": "Kalifornien",
    "Kalis": "Kali",
    "Kaliums": "Kalium",
    "Kalk": "kalken",
    "Kalke": "kalken",
    "Kalken": "Kalk",
    "Kalkenden": "Kalkende",
    "Kalkenderen": "Kalkendere",
    "Kalkendsten": "Kalkendste",
    "Kalkens": "Kalken",
    "Kalkhaltigen": "Kalkhaltige",
    "Kalkhaltigeren": "Kalkhaltigere",
    "Kalkhaltigsten": "Kalkhaltigste",
    "Kalkigen": "Kalkige",
    "Kalkigeren": "Kalkigere",
    "Kalkigsten": "Kalkigste",
    "Kalks": "Kalk",
    "Kalkulationen": "Kalkulation",
    "Kalkulatore": "Kalkulator",
    "Kalkulatoren": "Kalkulator",
    "Kalkulatorische": "kalkulatorisch",
    "Kalkulatorischen": "Kalkulatorische",
    "Kalkulators": "Kalkulator",
    "Kalkulierenden": "Kalkulierende",
    "Kalkulierens": "Kalkulieren",
    "Kalkulierte": "kalkuliert",
    "Kalkulierten": "Kalkulierte",
    "Kalküle": "Kalkül",
    "Kalkülen": "Kalkül",
    "Kalküles": "Kalkül",
    "Kalküls": "Kalkül",
    "Kalorien": "Kalorie",
    "Kalorienarme": "kalorienarm",
    "Kalorienarmen": "Kalorienarme",
    "Kalorienbewußten": "Kalorienbewußte",
    "Kalorienbewußteren": "Kalorienbewußtere",
    "Kalorienärmeren": "Kalorienärmere",
    "Kaltblute": "Kaltblut",
    "Kaltblutes": "Kaltblut",
    "Kaltbluts": "Kaltblut",
    "Kaltblütern": "Kaltblüter",
    "Kaltblüters": "Kaltblüter",
    "Kaltblütige": "kaltblütig",
    "Kaltblütigen": "Kaltblütige",
    "Kaltblütigeren": "Kaltblütigere",
    "Kaltblütigsten": "Kaltblütigste",
    "Kalte": "kalt",
    "Kalten": "Kalte",
    "Kaltfronten": "Kaltfront",
    "Kaltgepreßte": "kaltgepreßt",
    "Kaltgepreßten": "Kaltgepreßte",
    "Kaltgepreßteren": "Kaltgepreßtere",
    "Kaltgepreßtesten": "Kaltgepreßteste",
    "Kaltgestellten": "Kaltgestellte",
    "Kaltherzigen": "Kaltherzige",
    "Kaltherzigeren": "Kaltherzigere",
    "Kaltherzigsten": "Kaltherzigste",
    "Kaltleitern": "Kaltleiter",
    "Kaltleiters": "Kaltleiter",
    "Kaltschnäuzige": "kaltschnäuzig",
    "Kaltschnäuzigen": "Kaltschnäuzige",
    "Kaltschnäuzigeren": "Kaltschnäuzigere",
    "Kaltschnäuzigsten": "Kaltschnäuzigste",
    "Kaltstellenden": "Kaltstellende",
    "Kaltstellens": "Kaltstellen",
    "Kalziumkarbonate": "Kalziumkarbonat",
    "Kalziumkarbonaten": "Kalziumkarbonat",
    "Kalziumkarbonats": "Kalziumkarbonat",
    "Kalziumoxide": "Kalziumoxid",
    "Kalziumoxiden": "Kalziumoxid",
    "Kalziumoxids": "Kalziumoxid",
    "Kalziums": "Kalzium",
    "Kalziumsulfate": "Kalziumsulfat",
    "Kalziumsulfaten": "Kalziumsulfat",
    "Kalziumsulfats": "Kalziumsulfat",
    "Kambodschas": "Kambodscha",
    "Kamele": "Kamel",
    "Kamelen": "Kamel",
    "Kamellen": "Kamelle",
    "Kamels": "Kamel",
    "Kameraden": "Kamerad",
    "Kameradinnen": "Kameradin",
    "Kameradschaften": "Kameradschaft",
    "Kameradschaftliche": "kameradschaftlich",
    "Kameradschaftlichen": "Kameradschaftliche",
    "Kameradschaftlicheren": "Kameradschaftlichere",
    "Kameras": "Kamera",
    "Kamillen": "Kamille",
    "Kamine": "Kamin",
    "Kaminen": "Kamin",
    "Kamines": "Kamin",
    "Kamins": "Kamin",
    "Kamme": "Kamm",
    "Kammerdienern": "Kammerdiener",
    "Kammerdieners": "Kammerdiener",
    "Kammerfrauen": "Kammerfrau",
    "Kammerjunkern": "Kammerjunker",
    "Kammerjunkers": "Kammerjunker",
    "Kammerjägern": "Kammerjäger",
    "Kammerjägers": "Kammerjäger",
    "Kammern": "Kammer",
    "Kammerschauspielern": "Kammerschauspieler",
    "Kammerschauspielers": "Kammerschauspieler",
    "Kammertons": "Kammerton",
    "Kammes": "Kamm",
    "Kamms": "Kamm",
    "Kampagnen": "Kampagne",
    "Kampe": "Kamp",
    "Kampes": "Kamp",
    "Kampfbereite": "kampfbereit",
    "Kampfbereiten": "Kampfbereite",
    "Kampfbereiteren": "Kampfbereitere",
    "Kampfbereitesten": "Kampfbereiteste",
    "Kampfe": "Kampf",
    "Kampfes": "Kampf",
    "Kampffähigen": "Kampffähige",
    "Kampffähigeren": "Kampffähigere",
    "Kampffähigsten": "Kampffähigste",
    "Kampflosen": "Kampflose",
    "Kampflustigen": "Kampflustige",
    "Kampflustigeren": "Kampflustigere",
    "Kampflustigsten": "Kampflustigste",
    "Kampfs": "Kampf",
    "Kampfunfähigen": "Kampfunfähige",
    "Kampfunfähigeren": "Kampfunfähigere",
    "Kampfunfähigsten": "Kampfunfähigste",
    "Kamps": "Kamp",
    "Kanadas": "Kanada",
    "Kanadische": "kanadisch",
    "Kanadischen": "Kanadische",
    "Kanale": "Kanal",
    "Kanales": "Kanal",
    "Kanalisationen": "Kanalisation",
    "Kanalisierenden": "Kanalisierende",
    "Kanalisierenderen": "Kanalisierendere",
    "Kanalisierendsten": "Kanalisierendste",
    "Kanalisierens": "Kanalisieren",
    "Kanalisierte": "kanalisiert",
    "Kanalisierten": "Kanalisierte",
    "Kanalisierteren": "Kanalisiertere",
    "Kanalisiertesten": "Kanalisierteste",
    "Kanals": "Kanal",
    "Kanarienvogels": "Kanarienvogel",
    "Kanarienvögel": "Kanarienvogel",
    "Kanarienvögeln": "Kanarienvogel",
    "Kandeln": "Kandel",
    "Kandidaten": "Kandidat",
    "Kandidaturen": "Kandidatur",
    "Kandidierenden": "Kandidierende",
    "Kandidierens": "Kandidieren",
    "Kandidierte": "kandidiert",
    "Kandidierten": "Kandidierte",
    "Kandierenden": "Kandierende",
    "Kandierens": "Kandieren",
    "Kandierte": "kandiert",
    "Kandierten": "Kandierte",
    "Kaninchens": "Kaninchen",
    "Kannas": "Kanna",
    "Kannen": "Kanne",
    "Kannibalen": "Kannibale",
    "Kannibalische": "kannibalisch",
    "Kannibalischen": "Kannibalische",
    "Kanonaden": "Kanonade",
    "Kanonen": "Kanone",
    "Kanonier": "kanonieren",
    "Kanoniere": "kanonieren",
    "Kanonieren": "Kanonier",
    "Kanonierenden": "Kanonierende",
    "Kanonierens": "Kanonieren",
    "Kanoniers": "Kanonier",
    "Kanonierte": "kanoniert",
    "Kanonierten": "Kanonierte",
    "Kanonischen": "Kanonische",
    "Kanonischeren": "Kanonischere",
    "Kanonischsten": "Kanonischste",
    "Kanonisierenden": "Kanonisierende",
    "Kanonisierens": "Kanonisieren",
    "Kanonisierte": "kanonisiert",
    "Kanonisierten": "Kanonisierte",
    "Kanonisten": "Kanonist",
    "Kanons": "Kanon",
    "Kantaten": "Kantate",
    "Kante": "kanten",
    "Kanten": "Kante",
    "Kantenden": "Kantende",
    "Kantenderen": "Kantendere",
    "Kantendsten": "Kantendste",
    "Kantens": "Kanten",
    "Kantern": "Kanter",
    "Kanters": "Kanter",
    "Kantersiege": "Kantersieg",
    "Kantersiegen": "Kantersieg",
    "Kantersiegs": "Kantersieg",
    "Kanthakens": "Kanthaken",
    "Kantige": "kantig",
    "Kantigen": "Kantige",
    "Kantigeren": "Kantigere",
    "Kantigsten": "Kantigste",
    "Kantinen": "Kantine",
    "Kantone": "Kanton",
    "Kantonen": "Kanton",
    "Kantonisten": "Kantonist",
    "Kantons": "Kanton",
    "Kantorate": "Kantorat",
    "Kantoraten": "Kantorat",
    "Kantorats": "Kantorat",
    "Kantorinnen": "Kantorin",
    "Kanus": "Kanu",
    "Kanuten": "Kanute",
    "Kanzel": "kanzeln",
    "Kanzeln": "Kanzel",
    "Kanzelnden": "Kanzelnde",
    "Kanzelns": "Kanzeln",
    "Kanzleien": "Kanzlei",
    "Kanzlern": "Kanzler",
    "Kanzlers": "Kanzler",
    "Kanäle": "Kanal",
    "Kanälen": "Kanal",
    "Kanülen": "Kanüle",
    "Kapazitäten": "Kapazität",
    "Kapellen": "Kapelle",
    "Kapernden": "Kapernde",
    "Kaperns": "Kapern",
    "Kapierenden": "Kapierende",
    "Kapierens": "Kapieren",
    "Kapierte": "kapiert",
    "Kapierten": "Kapierte",
    "Kapillaren": "Kapillare",
    "Kapitalintensiven": "Kapitalintensive",
    "Kapitalintensiveren": "Kapitalintensivere",
    "Kapitalisierenden": "Kapitalisierende",
    "Kapitalisierens": "Kapitalisieren",
    "Kapitalisierte": "kapitalisiert",
    "Kapitalisierten": "Kapitalisierte",
    "Kapitalisten": "Kapitalist",
    "Kapitalistische": "kapitalistisch",
    "Kapitalistischen": "Kapitalistische",
    "Kapitalistischeren": "Kapitalistischere",
    "Kapitalkräftigen": "Kapitalkräftige",
    "Kapitalkräftigeren": "Kapitalkräftigere",
    "Kapitals": "Kapital",
    "Kapitalvermögens": "Kapitalvermögen",
    "Kapitelfeste": "kapitelfest",
    "Kapitelfesten": "Kapitelfeste",
    "Kapitelfesteren": "Kapitelfestere",
    "Kapitelfestesten": "Kapitelfesteste",
    "Kapiteln": "Kapitel",
    "Kapitels": "Kapitel",
    "Kapitole": "Kapitol",
    "Kapitolen": "Kapitol",
    "Kapitols": "Kapitol",
    "Kapitulationen": "Kapitulation",
    "Kapitulierenden": "Kapitulierende",
    "Kapitulierens": "Kapitulieren",
    "Kapitulierte": "kapituliert",
    "Kapitulierten": "Kapitulierte",
    "Kapitäne": "Kapitän",
    "Kapitänen": "Kapitän",
    "Kapitäns": "Kapitän",
    "Kappe": "kappen",
    "Kappen": "Kappe",
    "Kappenden": "Kappende",
    "Kappens": "Kappen",
    "Kapriolen": "Kapriole",
    "Kapriziöse": "kapriziös",
    "Kapriziösen": "Kapriziöse",
    "Kapriziöseren": "Kapriziösere",
    "Kapriziösesten": "Kapriziöseste",
    "Kaps": "Kap",
    "Kapsel": "kapseln",
    "Kapseln": "Kapsel",
    "Kapselnden": "Kapselnde",
    "Kapselns": "Kapseln",
    "Kaputten": "Kaputte",
    "Kaputteren": "Kaputtere",
    "Kaputtesten": "Kaputteste",
    "Kaputtgegangenen": "Kaputtgegangene",
    "Kaputtgehenden": "Kaputtgehende",
    "Kaputtgehens": "Kaputtgehen",
    "Kaputtgekriegten": "Kaputtgekriegte",
    "Kaputtgelachten": "Kaputtgelachte",
    "Kaputtkriegenden": "Kaputtkriegende",
    "Kaputtkriegens": "Kaputtkriegen",
    "Kaputtlachenden": "Kaputtlachende",
    "Kaputtlachenderen": "Kaputtlachendere",
    "Kaputtlachendsten": "Kaputtlachendste",
    "Kaputtlachens": "Kaputtlachen",
    "Kapuzen": "Kapuze",
    "Kapuzinaden": "Kapuzinade",
    "Kapuzinern": "Kapuziner",
    "Kapuziners": "Kapuziner",
    "Karabachs": "Karabach",
    "Karadzics": "Karadzic",
    "Karaffen": "Karaffe",
    "Karambolagen": "Karambolage",
    "Karambolen": "Karambole",
    "Karamellen": "Karamelle",
    "Karamels": "Karamel",
    "Karawanen": "Karawane",
    "Karawansereien": "Karawanserei",
    "Karbenern": "Karbener",
    "Karbeners": "Karbener",
    "Kardinale": "Kardinal",
    "Kardinalfehlern": "Kardinalfehler",
    "Kardinalfehlers": "Kardinalfehler",
    "Kardinals": "Kardinal",
    "Kardinäle": "Kardinal",
    "Kardinälen": "Kardinal",
    "Kardiogramme": "Kardiogramm",
    "Kardiogrammen": "Kardiogramm",
    "Kardiogramms": "Kardiogramm",
    "Kardiographen": "Kardiograph",
    "Kardiologen": "Kardiologe",
    "Kardiologische": "kardiologisch",
    "Kardiologischen": "Kardiologische",
    "Karenzen": "Karenz",
    "Karenztage": "Karenztag",
    "Karenztagen": "Karenztag",
    "Karenztags": "Karenztag",
    "Karfreitage": "Karfreitag",
    "Karfreitagen": "Karfreitag",
    "Karfreitags": "Karfreitag",
    "Karfunkeln": "Karfunkel",
    "Karfunkels": "Karfunkel",
    "Karge": "karg",
    "Kargen": "Karge",
    "Karibischen": "Karibische",
    "Karierenden": "Karierende",
    "Karierens": "Karieren",
    "Karierte": "kariert",
    "Karierten": "Karierte",
    "Karikaturalen": "Karikaturale",
    "Karikaturen": "Karikatur",
    "Karikaturisten": "Karikaturist",
    "Karikaturistische": "karikaturistisch",
    "Karikaturistischen": "Karikaturistische",
    "Karikierenden": "Karikierende",
    "Karikierenderen": "Karikierendere",
    "Karikierendsten": "Karikierendste",
    "Karikierens": "Karikieren",
    "Karikierte": "karikiert",
    "Karikierten": "Karikierte",
    "Karikierteren": "Karikiertere",
    "Karikiertesten": "Karikierteste",
    "Karinas": "Karina",
    "Karins": "Karin",
    "Karitativen": "Karitative",
    "Kariöse": "kariös",
    "Kariösen": "Kariöse",
    "Karls": "Karl",
    "Karlsruhern": "Karlsruher",
    "Karlsruhers": "Karlsruher",
    "Karlsruhes": "Karlsruhe",
    "Karmeliten": "Karmelit",
    "Karmelitergeists": "Karmelitergeist",
    "Karnevalisten": "Karnevalist",
    "Karnevals": "Karneval",
    "Karnickeln": "Karnickel",
    "Karnickels": "Karnickel",
    "Karolines": "Karoline",
    "Karolins": "Karolin",
    "Karos": "Karo",
    "Karossen": "Karosse",
    "Karosserien": "Karosserie",
    "Karotine": "Karotin",
    "Karotinen": "Karotin",
    "Karotins": "Karotin",
    "Karotten": "Karotte",
    "Karpfens": "Karpfen",
    "Karre": "karren",
    "Karrees": "Karree",
    "Karren": "Karre",
    "Karrenden": "Karrende",
    "Karrens": "Karren",
    "Karrieren": "Karriere",
    "Karsamstage": "Karsamstag",
    "Karsamstagen": "Karsamstag",
    "Karsamstags": "Karsamstag",
    "Karstens": "Karsten",
    "Karte": "karten",
    "Karteien": "Kartei",
    "Karteileichen": "Karteileiche",
    "Kartellamte": "Kartellamt",
    "Kartellamtes": "Kartellamt",
    "Kartellamts": "Kartellamt",
    "Kartelle": "Kartell",
    "Kartellen": "Kartell",
    "Kartelles": "Kartell",
    "Kartellierenden": "Kartellierende",
    "Kartellierens": "Kartellieren",
    "Kartellierte": "kartelliert",
    "Kartellierten": "Kartellierte",
    "Kartells": "Kartell",
    "Kartellämter": "Kartellamt",
    "Kartellämtern": "Kartellamt",
    "Karten": "Karte",
    "Kartenden": "Kartende",
    "Kartens": "Karten",
    "Kartesische": "kartesisch",
    "Kartesischen": "Kartesische",
    "Kartoffeln": "Kartoffel",
    "Kartographen": "Kartograph",
    "Kartographierenden": "Kartographierende",
    "Kartographierens": "Kartographieren",
    "Kartographierte": "kartographiert",
    "Kartographierten": "Kartographierte",
    "Kartographischen": "Kartographische",
    "Kartonierenden": "Kartonierende",
    "Kartonierens": "Kartonieren",
    "Kartonierte": "kartoniert",
    "Kartonierten": "Kartonierte",
    "Kartons": "Karton",
    "Karunkeln": "Karunkel",
    "Karussells": "Karussell",
    "Kaschemmen": "Kaschemme",
    "Kaschierenden": "Kaschierende",
    "Kaschierenderen": "Kaschierendere",
    "Kaschierendsten": "Kaschierendste",
    "Kaschierens": "Kaschieren",
    "Kaschierte": "kaschiert",
    "Kaschierten": "Kaschierte",
    "Kaschierteren": "Kaschiertere",
    "Kaschiertesten": "Kaschierteste",
    "Kaschierungen": "Kaschierung",
    "Kaschmirs": "Kaschmir",
    "Kasernen": "Kaserne",
    "Kasernierenden": "Kasernierende",
    "Kasernierenderen": "Kasernierendere",
    "Kasernierendsten": "Kasernierendste",
    "Kasernierens": "Kasernieren",
    "Kasernierte": "kaserniert",
    "Kasernierten": "Kasernierte",
    "Kasernierteren": "Kaserniertere",
    "Kaserniertesten": "Kasernierteste",
    "Kasinos": "Kasino",
    "Kaskaden": "Kaskade",
    "Kasperlepuppen": "Kasperlepuppe",
    "Kaspernden": "Kaspernde",
    "Kaspernderen": "Kasperndere",
    "Kasperndsten": "Kasperndste",
    "Kasperns": "Kaspern",
    "Kasselern": "Kasseler",
    "Kasselers": "Kasseler",
    "Kassels": "Kassel",
    "Kassen": "Kasse",
    "Kasserolen": "Kasserole",
    "Kassetten": "Kassette",
    "Kassierenden": "Kassierende",
    "Kassierens": "Kassieren",
    "Kassiererinnen": "Kassiererin",
    "Kassierern": "Kassierer",
    "Kassierers": "Kassierer",
    "Kassierte": "kassiert",
    "Kassierten": "Kassierte",
    "Kastanien": "Kastanie",
    "Kasten": "Kaste",
    "Kastens": "Kasten",
    "Katakomben": "Katakombe",
    "Katalanen": "Katalane",
    "Katalanische": "katalanisch",
    "Katalanischen": "Katalanische",
    "Kataloge": "Katalog",
    "Katalogen": "Katalog",
    "Kataloges": "Katalog",
    "Katalogisierenden": "Katalogisierende",
    "Katalogisierens": "Katalogisieren",
    "Katalogisierte": "katalogisiert",
    "Katalogisierten": "Katalogisierte",
    "Katalogisierungen": "Katalogisierung",
    "Katalogs": "Katalog",
    "Katalysatore": "Katalysator",
    "Katalysatoren": "Katalysator",
    "Katalysators": "Katalysator",
    "Katalysen": "Katalyse",
    "Katalysierenden": "Katalysierende",
    "Katalysierens": "Katalysieren",
    "Katalysierte": "katalysiert",
    "Katalysierten": "Katalysierte",
    "Katapulte": "Katapult",
    "Katapulten": "Katapult",
    "Katapultes": "Katapult",
    "Katapultierenden": "Katapultierende",
    "Katapultierens": "Katapultieren",
    "Katapultierte": "katapultiert",
    "Katapultierten": "Katapultierte",
    "Katapults": "Katapult",
    "Katarre": "Katarr",
    "Katarren": "Katarr",
    "Katarrs": "Katarr",
    "Katastern": "Kataster",
    "Katasters": "Kataster",
    "Katastrophale": "katastrophal",
    "Katastrophalen": "Katastrophale",
    "Katastrophaleren": "Katastrophalere",
    "Katastrophalsten": "Katastrophalste",
    "Katastrophen": "Katastrophe",
    "Kategoriale": "kategorial",
    "Kategorialen": "Kategoriale",
    "Kategorien": "Kategorie",
    "Kategorische": "kategorisch",
    "Kategorischen": "Kategorische",
    "Kategorisierenden": "Kategorisierende",
    "Kategorisierens": "Kategorisieren",
    "Kategorisierte": "kategorisiert",
    "Kategorisierten": "Kategorisierte",
    "Katen": "Kate",
    "Katerideen": "Kateridee",
    "Katern": "Kater",
    "Katers": "Kater",
    "Katharinas": "Katharina",
    "Kathedern": "Katheder",
    "Katheders": "Katheder",
    "Kathedralen": "Kathedrale",
    "Kathoden": "Kathode",
    "Katholiken": "Katholik",
    "Katholische": "katholisch",
    "Katholischen": "Katholische",
    "Katholischeren": "Katholischere",
    "Katholischsten": "Katholischste",
    "Katholisierenden": "Katholisierende",
    "Katholisierenderen": "Katholisierendere",
    "Katholisierens": "Katholisieren",
    "Katholisierte": "katholisiert",
    "Katholisierten": "Katholisierte",
    "Katholisierteren": "Katholisiertere",
    "Katholisiertesten": "Katholisierteste",
    "Katholyten": "Katholyt",
    "Katjas": "Katja",
    "Katrins": "Katrin",
    "Kats": "Kat",
    "Katzbalgereien": "Katzbalgerei",
    "Katzen": "Katze",
    "Katzenfreundliche": "katzenfreundlich",
    "Katzenfreundlichen": "Katzenfreundliche",
    "Katzenfreundlicheren": "Katzenfreundlichere",
    "Katzenwäschen": "Katzenwäsche",
    "Kauenden": "Kauende",
    "Kauens": "Kauen",
    "Kauernden": "Kauernde",
    "Kauernderen": "Kauerndere",
    "Kauerndsten": "Kauerndste",
    "Kauerns": "Kauern",
    "Kauf": "kaufen",
    "Kaufe": "kaufen",
    "Kaufenden": "Kaufende",
    "Kaufens": "Kaufen",
    "Kaufes": "Kauf",
    "Kauffrauen": "Kauffrau",
    "Kaufkräftige": "kaufkräftig",
    "Kaufkräftigen": "Kaufkräftige",
    "Kaufkräftigeren": "Kaufkräftigere",
    "Kaufkräftigsten": "Kaufkräftigste",
    "Kauflustigen": "Kauflustige",
    "Kauflustigeren": "Kauflustigere",
    "Kauflustigsten": "Kauflustigste",
    "Kaufmännischen": "Kaufmännische",
    "Kaufs": "Kauf",
    "Kaufwerts": "Kaufwert",
    "Kaugummis": "Kaugummi",
    "Kaukasische": "kaukasisch",
    "Kaukasischen": "Kaukasische",
    "Kaulquappen": "Kaulquappe",
    "Kauris": "Kauri",
    "Kausale": "kausal",
    "Kausalen": "Kausale",
    "Kausalzusammenhange": "Kausalzusammenhang",
    "Kausalzusammenhangs": "Kausalzusammenhang",
    "Kausalzusammenhänge": "Kausalzusammenhang",
    "Kausalzusammenhängen": "Kausalzusammenhang",
    "Kautabake": "Kautabak",
    "Kautabaken": "Kautabak",
    "Kautabaks": "Kautabak",
    "Kautionen": "Kaution",
    "Kauwerkzeuge": "Kauwerkzeug",
    "Kauwerkzeugen": "Kauwerkzeug",
    "Kauwerkzeugs": "Kauwerkzeug",
    "Kauzige": "kauzig",
    "Kauzigen": "Kauzige",
    "Kauzigeren": "Kauzigere",
    "Kauzigsten": "Kauzigste",
    "Kebabs": "Kebab",
    "Kecke": "keck",
    "Kecken": "Kecke",
    "Keckeren": "Keckere",
    "Kecksten": "Keckste",
    "Keepern": "Keeper",
    "Keepers": "Keeper",
    "Kefirs": "Kefir",
    "Kegel": "kegeln",
    "Kegelbruders": "Kegelbruder",
    "Kegelbrüder": "Kegelbruder",
    "Kegelbrüdern": "Kegelbruder",
    "Kegeln": "Kegel",
    "Kegelnden": "Kegelnde",
    "Kegelnderen": "Kegelndere",
    "Kegelndsten": "Kegelndste",
    "Kegelns": "Kegeln",
    "Kegels": "Kegel",
    "Keglern": "Kegler",
    "Keglers": "Kegler",
    "Kehlen": "Kehle",
    "Kehlkopfe": "Kehlkopf",
    "Kehlkopfs": "Kehlkopf",
    "Kehlköpfe": "Kehlkopf",
    "Kehlköpfen": "Kehlkopf",
    "Kehrenden": "Kehrende",
    "Kehrens": "Kehren",
    "Kehrmaschinen": "Kehrmaschine",
    "Kehrseiten": "Kehrseite",
    "Kehrwerte": "Kehrwert",
    "Kehrwerten": "Kehrwert",
    "Kehrwerts": "Kehrwert",
    "Keifenden": "Keifende",
    "Keifenderen": "Keifendere",
    "Keifendsten": "Keifendste",
    "Keifens": "Keifen",
    "Keil": "keilen",
    "Keile": "keilen",
    "Keilen": "Keil",
    "Keilenden": "Keilende",
    "Keilens": "Keilen",
    "Keilereien": "Keilerei",
    "Keilern": "Keiler",
    "Keilers": "Keiler",
    "Keilhauen": "Keilhaue",
    "Keils": "Keil",
    "Keim": "keimen",
    "Keime": "keimen",
    "Keimen": "Keim",
    "Keimenden": "Keimende",
    "Keimenderen": "Keimendere",
    "Keimendsten": "Keimendste",
    "Keimens": "Keimen",
    "Keimfreien": "Keimfreie",
    "Keimfreieren": "Keimfreiere",
    "Keimfreisten": "Keimfreiste",
    "Keimfähigen": "Keimfähige",
    "Keimfähigeren": "Keimfähigere",
    "Keimfähigsten": "Keimfähigste",
    "Keimlinge": "Keimling",
    "Keimlingen": "Keimling",
    "Keimlings": "Keimling",
    "Keims": "Keim",
    "Kekse": "Keks",
    "Keksen": "Keks",
    "Kekses": "Keks",
    "Kelche": "Kelch",
    "Kelchen": "Kelch",
    "Kelchs": "Kelch",
    "Kelkheimern": "Kelkheimer",
    "Kelkheimers": "Kelkheimer",
    "Kelkheims": "Kelkheim",
    "Kellen": "Kelle",
    "Keller": "kellern",
    "Kellereien": "Kellerei",
    "Kellern": "Keller",
    "Kellernden": "Kellernde",
    "Kellerns": "Kellern",
    "Kellers": "Keller",
    "Kellner": "kellnern",
    "Kellnerinnen": "Kellnerin",
    "Kellnern": "Kellner",
    "Kellnernden": "Kellnernde",
    "Kellnerns": "Kellnern",
    "Kellners": "Kellner",
    "Kellys": "Kelly",
    "Kelsterbachern": "Kelsterbacher",
    "Kelsterbachers": "Kelsterbacher",
    "Kelsterbachs": "Kelsterbach",
    "Kelternden": "Kelternde",
    "Kelterns": "Keltern",
    "Keltischen": "Keltische",
    "Kemenaten": "Kemenate",
    "Kempinskis": "Kempinski",
    "Kenias": "Kenia",
    "Kennedys": "Kennedy",
    "Kennenden": "Kennende",
    "Kennengelernten": "Kennengelernte",
    "Kennenlernenden": "Kennenlernende",
    "Kennenlernens": "Kennenlernen",
    "Kennens": "Kennen",
    "Kennern": "Kenner",
    "Kenners": "Kenner",
    "Kenntlichen": "Kenntliche",
    "Kenntnisse": "Kenntnis",
    "Kenntnissen": "Kenntnis",
    "Kenntnisstands": "Kenntnisstand",
    "Kennungen": "Kennung",
    "Kennzahlen": "Kennzahl",
    "Kennzeichens": "Kennzeichen",
    "Kennzeichnenden": "Kennzeichnende",
    "Kennzeichnens": "Kennzeichnen",
    "Kennzeichnungen": "Kennzeichnung",
    "Kennziffern": "Kennziffer",
    "Kenternden": "Kenternde",
    "Kenterns": "Kentern",
    "Keramiken": "Keramik",
    "Keramikern": "Keramiker",
    "Keramikers": "Keramiker",
    "Keratome": "Keratom",
    "Keratomen": "Keratom",
    "Keratoms": "Keratom",
    "Kerbe": "kerben",
    "Kerben": "Kerbe",
    "Kerbenden": "Kerbende",
    "Kerbens": "Kerben",
    "Kerbschnitzereien": "Kerbschnitzerei",
    "Kerker": "kerkern",
    "Kerkern": "Kerker",
    "Kerkernden": "Kerkernde",
    "Kerkerns": "Kerkern",
    "Kerkers": "Kerker",
    "Kerlchens": "Kerlchen",
    "Kerle": "Kerl",
    "Kerlen": "Kerl",
    "Kerles": "Kerl",
    "Kerls": "Kerl",
    "Kern": "kernen",
    "Kernbeißern": "Kernbeißer",
    "Kernbeißers": "Kernbeißer",
    "Kerne": "kernen",
    "Kernen": "Kern",
    "Kernenden": "Kernende",
    "Kernens": "Kernen",
    "Kernes": "Kern",
    "Kernfache": "Kernfach",
    "Kernfaches": "Kernfach",
    "Kernfachs": "Kernfach",
    "Kernfächer": "Kernfach",
    "Kernfächern": "Kernfach",
    "Kernige": "kernig",
    "Kernigen": "Kernige",
    "Kernigeren": "Kernigere",
    "Kernigsten": "Kernigste",
    "Kernlosen": "Kernlose",
    "Kernloseren": "Kernlosere",
    "Kernlosesten": "Kernloseste",
    "Kernphysikalischen": "Kernphysikalische",
    "Kerns": "Kern",
    "Kerstins": "Kerstin",
    "Kerzen": "Kerze",
    "Keschern": "Kescher",
    "Keschers": "Kescher",
    "Kesse": "keß",
    "Kessel": "kesseln",
    "Kesseln": "Kessel",
    "Kesselnden": "Kesselnde",
    "Kesselns": "Kesseln",
    "Kessels": "Kessel",
    "Kessen": "Kesse",
    "Kesseren": "Kessere",
    "Kessesten": "Kesseste",
    "Ketchups": "Ketchup",
    "Kette": "ketten",
    "Ketten": "Kette",
    "Kettenden": "Kettende",
    "Kettens": "Ketten",
    "Ketzerischen": "Ketzerische",
    "Ketzerischeren": "Ketzerischere",
    "Ketzerischsten": "Ketzerischste",
    "Ketzern": "Ketzer",
    "Ketzers": "Ketzer",
    "Keuchenden": "Keuchende",
    "Keuchenderen": "Keuchendere",
    "Keuchendsten": "Keuchendste",
    "Keuchens": "Keuchen",
    "Keuchhustens": "Keuchhusten",
    "Keulen": "Keule",
    "Keusche": "keusch",
    "Keuschen": "Keusche",
    "Keuscheren": "Keuschere",
    "Keuschsten": "Keuschste",
    "Kevins": "Kevin",
    "Kibitkas": "Kibitka",
    "Kichererbsen": "Kichererbse",
    "Kichernden": "Kichernde",
    "Kichernderen": "Kicherndere",
    "Kicherndsten": "Kicherndste",
    "Kicherns": "Kichern",
    "Kick": "kicken",
    "Kickenden": "Kickende",
    "Kickens": "Kicken",
    "Kickern": "Kicker",
    "Kickers": "Kicker",
    "Kicks": "Kick",
    "Kickstartern": "Kickstarter",
    "Kickstarters": "Kickstarter",
    "Kids": "Kid",
    "Kiefern": "Kiefer",
    "Kiefers": "Kiefer",
    "Kiekenden": "Kiekende",
    "Kiekens": "Kieken",
    "Kielern": "Kieler",
    "Kielers": "Kieler",
    "Kiels": "Kiel",
    "Kiews": "Kiew",
    "Kiffenden": "Kiffende",
    "Kiffens": "Kiffen",
    "Kiffern": "Kiffer",
    "Kiffers": "Kiffer",
    "Kilians": "Kilian",
    "Killenden": "Killende",
    "Killens": "Killen",
    "Killern": "Killer",
    "Killers": "Killer",
    "Kilokalorien": "Kilokalorie",
    "Kilolitern": "Kiloliter",
    "Kiloliters": "Kiloliter",
    "Kilometerlange": "kilometerlang",
    "Kilometerlangen": "Kilometerlange",
    "Kilometern": "Kilometer",
    "Kilometers": "Kilometer",
    "Kilometerweite": "kilometerweit",
    "Kilometerweiten": "Kilometerweite",
    "Kilos": "Kilo",
    "Kilowattstunden": "Kilowattstunde",
    "Kimmen": "Kimme",
    "Kindchens": "Kindchen",
    "Kinde": "Kind",
    "Kinder": "Kind",
    "Kindereien": "Kinderei",
    "Kinderfeindliche": "kinderfeindlich",
    "Kinderfeindlichen": "Kinderfeindliche",
    "Kinderfeindlicheren": "Kinderfeindlichere",
    "Kindergärtnerinnen": "Kindergärtnerin",
    "Kinderleichte": "kinderleicht",
    "Kinderleichten": "Kinderleichte",
    "Kinderleichteren": "Kinderleichtere",
    "Kinderleichtesten": "Kinderleichteste",
    "Kinderlieben": "Kinderliebe",
    "Kinderlieberen": "Kinderliebere",
    "Kinderliebsten": "Kinderliebste",
    "Kinderlosen": "Kinderlose",
    "Kindern": "Kind",
    "Kinderreiche": "kinderreich",
    "Kinderreichen": "Kinderreiche",
    "Kinderreicheren": "Kinderreichere",
    "Kinderreichsten": "Kinderreichste",
    "Kindersicheren": "Kindersichere",
    "Kindersichereren": "Kindersicherere",
    "Kindersichersten": "Kindersicherste",
    "Kindes": "Kind",
    "Kindgemäße": "kindgemäß",
    "Kindgemäßen": "Kindgemäße",
    "Kindhaften": "Kindhafte",
    "Kindhafteren": "Kindhaftere",
    "Kindhaftesten": "Kindhafteste",
    "Kindheiten": "Kindheit",
    "Kindische": "kindisch",
    "Kindischen": "Kindische",
    "Kindischeren": "Kindischere",
    "Kindischsten": "Kindischste",
    "Kindlichen": "Kindliche",
    "Kindlicheren": "Kindlichere",
    "Kindlichsten": "Kindlichste",
    "Kinds": "Kind",
    "Kinematische": "kinematisch",
    "Kinematischen": "Kinematische",
    "Kinetischen": "Kinetische",
    "Kings": "King",
    "Kinkels": "Kinkel",
    "Kinkerlitzchens": "Kinkerlitzchen",
    "Kinne": "Kinn",
    "Kinnen": "Kinn",
    "Kinns": "Kinn",
    "Kinos": "Kino",
    "Kioske": "Kiosk",
    "Kiosken": "Kiosk",
    "Kioskes": "Kiosk",
    "Kippe": "kippen",
    "Kippen": "Kippe",
    "Kippenden": "Kippende",
    "Kippens": "Kippen",
    "Kippern": "Kipper",
    "Kippers": "Kipper",
    "Kippfenstern": "Kippfenster",
    "Kippfensters": "Kippfenster",
    "Kippladern": "Kipplader",
    "Kippladers": "Kipplader",
    "Kippregeln": "Kippregel",
    "Kippschaltern": "Kippschalter",
    "Kippschalters": "Kippschalter",
    "Kippschaltungen": "Kippschaltung",
    "Kirchen": "Kirche",
    "Kirchenmusikalische": "kirchenmusikalisch",
    "Kirchenmusikalischen": "Kirchenmusikalische",
    "Kirchenpolitischen": "Kirchenpolitische",
    "Kirchenrechtlichen": "Kirchenrechtliche",
    "Kirchhoffs": "Kirchhoff",
    "Kirchliche": "kirchlich",
    "Kirchlichen": "Kirchliche",
    "Kirchners": "Kirchner",
    "Kirchplatze": "Kirchplatz",
    "Kirchplatzes": "Kirchplatz",
    "Kirchplätze": "Kirchplatz",
    "Kirchplätzen": "Kirchplatz",
    "Kirchs": "Kirch",
    "Kirdorfs": "Kirdorf",
    "Kirejewskis": "Kirejewski",
    "Kirjakows": "Kirjakow",
    "Kirschdufte": "Kirschduft",
    "Kirschduftes": "Kirschduft",
    "Kirschdufts": "Kirschduft",
    "Kirschdüfte": "Kirschduft",
    "Kirschdüften": "Kirschduft",
    "Kirschen": "Kirsche",
    "Kirstens": "Kirsten",
    "Kissens": "Kissen",
    "Kisten": "Kiste",
    "Kitas": "Kita",
    "Kitsche": "Kitsch",
    "Kitsches": "Kitsch",
    "Kitschige": "kitschig",
    "Kitschigen": "Kitschige",
    "Kitschigeren": "Kitschigere",
    "Kitschigsten": "Kitschigste",
    "Kitschs": "Kitsch",
    "Kittchens": "Kittchen",
    "Kitteln": "Kittel",
    "Kittels": "Kittel",
    "Kittenden": "Kittende",
    "Kittenderen": "Kittendere",
    "Kittendsten": "Kittendste",
    "Kittens": "Kitten",
    "Kitzel": "kitzeln",
    "Kitzeligen": "Kitzelige",
    "Kitzeligeren": "Kitzeligere",
    "Kitzeligsten": "Kitzeligste",
    "Kitzeln": "Kitzel",
    "Kitzelnden": "Kitzelnde",
    "Kitzelnderen": "Kitzelndere",
    "Kitzelndsten": "Kitzelndste",
    "Kitzelns": "Kitzeln",
    "Kitzels": "Kitzel",
    "Kitzlern": "Kitzler",
    "Kitzlers": "Kitzler",
    "Kitzlige": "kitzlig",
    "Kitzligen": "Kitzlige",
    "Kitzligeren": "Kitzligere",
    "Kitzligsten": "Kitzligste",
    "Kiwis": "Kiwi",
    "Klabasternden": "Klabasternde",
    "Klabasterns": "Klabastern",
    "Klabasterte": "klabastert",
    "Klabasterten": "Klabasterte",
    "Klabautermanne": "Klabautermann",
    "Klabautermannes": "Klabautermann",
    "Klabautermanns": "Klabautermann",
    "Klabautermänner": "Klabautermann",
    "Klabautermännern": "Klabautermann",
    "Klackens": "Klacken",
    "Klackernden": "Klackernde",
    "Klackerns": "Klackern",
    "Kladden": "Kladde",
    "Klaffenden": "Klaffende",
    "Klaffenderen": "Klaffendere",
    "Klaffendsten": "Klaffendste",
    "Klaffens": "Klaffen",
    "Klaftern": "Klafter",
    "Klafters": "Klafter",
    "Klagbare": "klagbar",
    "Klagbaren": "Klagbare",
    "Klagen": "Klage",
    "Klagenden": "Klagende",
    "Klagens": "Klagen",
    "Klageschriften": "Klageschrift",
    "Klaglosen": "Klaglose",
    "Klagloseren": "Klaglosere",
    "Klaglosesten": "Klagloseste",
    "Klamauks": "Klamauk",
    "Klamme": "klamm",
    "Klammen": "Klamme",
    "Klammer": "klamm",
    "Klammere": "klamm",
    "Klammeren": "Klammere",
    "Klammern": "Klammer",
    "Klammernden": "Klammernde",
    "Klammernderen": "Klammerndere",
    "Klammerndsten": "Klammerndste",
    "Klammerns": "Klammern",
    "Klammheimlichen": "Klammheimliche",
    "Klammsten": "Klammste",
    "Klamotten": "Klamotte",
    "Klamottenkisten": "Klamottenkiste",
    "Klampfen": "Klampfe",
    "Klamüsernden": "Klamüsernde",
    "Klamüserns": "Klamüsern",
    "Klamüserte": "klamüsert",
    "Klamüserten": "Klamüserte",
    "Klange": "Klang",
    "Klanges": "Klang",
    "Klanglichen": "Klangliche",
    "Klanglosen": "Klanglose",
    "Klangloseren": "Klanglosere",
    "Klanglosesten": "Klangloseste",
    "Klangs": "Klang",
    "Klangvollen": "Klangvolle",
    "Klangvolleren": "Klangvollere",
    "Klangvollsten": "Klangvollste",
    "Klans": "Klan",
    "Klappenden": "Klappende",
    "Klappens": "Klappen",
    "Klapperigen": "Klapperige",
    "Klapperigeren": "Klapperigere",
    "Klapperigsten": "Klapperigste",
    "Klappernden": "Klappernde",
    "Klappernderen": "Klapperndere",
    "Klapperndsten": "Klapperndste",
    "Klapperns": "Klappern",
    "Klapprigen": "Klapprige",
    "Klapprigeren": "Klapprigere",
    "Klapprigsten": "Klapprigste",
    "Klappstuhle": "Klappstuhl",
    "Klappstuhls": "Klappstuhl",
    "Klappstühle": "Klappstuhl",
    "Klappstühlen": "Klappstuhl",
    "Klapptische": "Klapptisch",
    "Klapptischen": "Klapptisch",
    "Klapptischs": "Klapptisch",
    "Klare": "klar",
    "Klaren": "Klare",
    "Klarenden": "Klarende",
    "Klarens": "Klaren",
    "Klareren": "Klarere",
    "Klargekommenen": "Klargekommene",
    "Klargekriegten": "Klargekriegte",
    "Klargemachten": "Klargemachte",
    "Klargesehenen": "Klargesehene",
    "Klargestellten": "Klargestellte",
    "Klargestellteren": "Klargestelltere",
    "Klargestelltesten": "Klargestellteste",
    "Klarinetten": "Klarinette",
    "Klarinettisten": "Klarinettist",
    "Klarinettistinnen": "Klarinettistin",
    "Klarissen": "Klarisse",
    "Klarkommenden": "Klarkommende",
    "Klarkommens": "Klarkommen",
    "Klarkriegenden": "Klarkriegende",
    "Klarkriegens": "Klarkriegen",
    "Klarmachenden": "Klarmachende",
    "Klarmachens": "Klarmachen",
    "Klarschiffs": "Klarschiff",
    "Klarsehenden": "Klarsehende",
    "Klarsehenderen": "Klarsehendere",
    "Klarsehendsten": "Klarsehendste",
    "Klarsehens": "Klarsehen",
    "Klarstellenden": "Klarstellende",
    "Klarstellenderen": "Klarstellendere",
    "Klarstellendsten": "Klarstellendste",
    "Klarstellens": "Klarstellen",
    "Klarsten": "Klarste",
    "Klartexte": "Klartext",
    "Klartexten": "Klartext",
    "Klartexts": "Klartext",
    "Klassefrauen": "Klassefrau",
    "Klassen": "Klasse",
    "Klassierenden": "Klassierende",
    "Klassierens": "Klassieren",
    "Klassierte": "klassiert",
    "Klassierten": "Klassierte",
    "Klassifikationen": "Klassifikation",
    "Klassifizierenden": "Klassifizierende",
    "Klassifizierens": "Klassifizieren",
    "Klassifizierte": "klassifiziert",
    "Klassifizierten": "Klassifizierte",
    "Klassifizierteren": "Klassifiziertere",
    "Klassifizierteste": "klassifiziert",
    "Klassifizierungen": "Klassifizierung",
    "Klassikern": "Klassiker",
    "Klassikers": "Klassiker",
    "Klassische": "klassisch",
    "Klassischen": "Klassische",
    "Klassischeren": "Klassischere",
    "Klassischsten": "Klassischste",
    "Klatschenden": "Klatschende",
    "Klatschenderen": "Klatschendere",
    "Klatschendsten": "Klatschendste",
    "Klatschens": "Klatschen",
    "Klatschhaften": "Klatschhafte",
    "Klatschhafteren": "Klatschhaftere",
    "Klatschhaftesten": "Klatschhafteste",
    "Klatschnassen": "Klatschnasse",
    "Klatschnasseren": "Klatschnassere",
    "Klatschnassesten": "Klatschnasseste",
    "Klatschsüchtigen": "Klatschsüchtige",
    "Klatschsüchtigeren": "Klatschsüchtigere",
    "Klaubenden": "Klaubende",
    "Klaubens": "Klauben",
    "Klauenden": "Klauende",
    "Klauenderen": "Klauendere",
    "Klauendsten": "Klauendste",
    "Klauens": "Klauen",
    "Klausen": "Klause",
    "Klausuren": "Klausur",
    "Klaviere": "Klavier",
    "Klavieren": "Klavier",
    "Klaviers": "Klavier",
    "Klebebande": "Klebeband",
    "Klebebandes": "Klebeband",
    "Klebebands": "Klebeband",
    "Klebebänder": "Klebeband",
    "Klebebändern": "Klebeband",
    "Klebenbleibenden": "Klebenbleibende",
    "Klebenbleibens": "Klebenbleiben",
    "Klebenden": "Klebende",
    "Klebenderen": "Klebendere",
    "Klebendsten": "Klebendste",
    "Klebengebliebenen": "Klebengebliebene",
    "Klebens": "Kleben",
    "Kleberigen": "Kleberige",
    "Kleberigeren": "Kleberigere",
    "Kleberigsten": "Kleberigste",
    "Klebern": "Kleber",
    "Klebers": "Kleber",
    "Klebestreifens": "Klebestreifen",
    "Klebrigen": "Klebrige",
    "Klebrigeren": "Klebrigere",
    "Klebrigsten": "Klebrigste",
    "Klebstoffe": "Klebstoff",
    "Klebstoffen": "Klebstoff",
    "Klebstoffs": "Klebstoff",
    "Kleckernden": "Kleckernde",
    "Kleckerns": "Kleckern",
    "Klecksenden": "Klecksende",
    "Klecksens": "Klecksen",
    "Klecksereien": "Kleckserei",
    "Kleeblatte": "Kleeblatt",
    "Kleeblattes": "Kleeblatt",
    "Kleeblatts": "Kleeblatt",
    "Kleeblätter": "Kleeblatt",
    "Kleeblättern": "Kleeblatt",
    "Klees": "Klee",
    "Kleide": "kleiden",
    "Kleidenden": "Kleidende",
    "Kleidenderen": "Kleidendere",
    "Kleidendsten": "Kleidendste",
    "Kleidens": "Kleiden",
    "Kleider": "Kleid",
    "Kleidern": "Kleid",
    "Kleides": "Kleid",
    "Kleids": "Kleid",
    "Kleidsame": "kleidsam",
    "Kleidsamen": "Kleidsame",
    "Kleidsameren": "Kleidsamere",
    "Kleidsamsten": "Kleidsamste",
    "Kleidungen": "Kleidung",
    "Kleinbaueren": "Kleinbauer",
    "Kleinbetriebe": "Kleinbetrieb",
    "Kleinbetrieben": "Kleinbetrieb",
    "Kleinbetriebes": "Kleinbetrieb",
    "Kleinbetriebs": "Kleinbetrieb",
    "Kleinbürgerliche": "kleinbürgerlich",
    "Kleinbürgerlichen": "Kleinbürgerliche",
    "Kleinbürgerlicheren": "Kleinbürgerlichere",
    "Kleinbürgertums": "Kleinbürgertum",
    "Kleine": "klein",
    "Kleinen": "Kleine",
    "Kleineren": "Kleinere",
    "Kleinerts": "Kleinert",
    "Kleinformate": "Kleinformat",
    "Kleinformaten": "Kleinformat",
    "Kleinformates": "Kleinformat",
    "Kleinformats": "Kleinformat",
    "Kleingartens": "Kleingarten",
    "Kleingedruckte": "kleingedruckt",
    "Kleingedruckten": "Kleingedruckte",
    "Kleingekriegten": "Kleingekriegte",
    "Kleingeschnittenen": "Kleingeschnittene",
    "Kleingeschnitteneren": "Kleingeschnittenere",
    "Kleingärten": "Kleingarten",
    "Kleingärtnern": "Kleingärtner",
    "Kleingärtners": "Kleingärtner",
    "Kleinhandels": "Kleinhandel",
    "Kleinhirne": "Kleinhirn",
    "Kleinhirnen": "Kleinhirn",
    "Kleinhirns": "Kleinhirn",
    "Kleinhändlern": "Kleinhändler",
    "Kleinhändlers": "Kleinhändler",
    "Kleinigkeiten": "Kleinigkeit",
    "Kleinkalibern": "Kleinkaliber",
    "Kleinkalibers": "Kleinkaliber",
    "Kleinkarierte": "kleinkariert",
    "Kleinkarierten": "Kleinkarierte",
    "Kleinkarierteren": "Kleinkariertere",
    "Kleinkariertesten": "Kleinkarierteste",
    "Kleinkinde": "Kleinkind",
    "Kleinkinder": "Kleinkind",
    "Kleinkindern": "Kleinkind",
    "Kleinkindes": "Kleinkind",
    "Kleinkinds": "Kleinkind",
    "Kleinkrams": "Kleinkram",
    "Kleinkriegenden": "Kleinkriegende",
    "Kleinkriegens": "Kleinkriegen",
    "Kleinlauten": "Kleinlaute",
    "Kleinlauteren": "Kleinlautere",
    "Kleinlautesten": "Kleinlauteste",
    "Kleinlichen": "Kleinliche",
    "Kleinlicheren": "Kleinlichere",
    "Kleinlichsten": "Kleinlichste",
    "Kleinmute": "Kleinmut",
    "Kleinmutes": "Kleinmut",
    "Kleinmuts": "Kleinmut",
    "Kleinrentnern": "Kleinrentner",
    "Kleinrentners": "Kleinrentner",
    "Kleinschmidts": "Kleinschmidt",
    "Kleinschmiede": "Kleinschmied",
    "Kleinschmieden": "Kleinschmied",
    "Kleinschmieds": "Kleinschmied",
    "Kleinschneidenden": "Kleinschneidende",
    "Kleinschneidenderen": "Kleinschneidendere",
    "Kleinschneidens": "Kleinschneiden",
    "Kleinstaate": "Kleinstaat",
    "Kleinstaaten": "Kleinstaat",
    "Kleinstaats": "Kleinstaat",
    "Kleinstarbeiten": "Kleinstarbeit",
    "Kleinste": "klein",
    "Kleinsten": "Kleinste",
    "Kleinstkinde": "Kleinstkind",
    "Kleinstkinder": "Kleinstkind",
    "Kleinstkindern": "Kleinstkind",
    "Kleinstkindes": "Kleinstkind",
    "Kleinstkinds": "Kleinstkind",
    "Kleinstlebewesens": "Kleinstlebewesen",
    "Kleinstädte": "Kleinstadt",
    "Kleinstädten": "Kleinstadt",
    "Kleinstädtern": "Kleinstädter",
    "Kleinstädters": "Kleinstädter",
    "Kleinstädtische": "kleinstädtisch",
    "Kleinstädtischen": "Kleinstädtische",
    "Kleinstädtischeren": "Kleinstädtischere",
    "Kleintiere": "Kleintier",
    "Kleintieren": "Kleintier",
    "Kleintiers": "Kleintier",
    "Kleinverkaufe": "Kleinverkauf",
    "Kleinverkaufs": "Kleinverkauf",
    "Kleinverkäufe": "Kleinverkauf",
    "Kleinverkäufen": "Kleinverkauf",
    "Kleinviehs": "Kleinvieh",
    "Kleinwagens": "Kleinwagen",
    "Kleinwohnungen": "Kleinwohnung",
    "Kleister": "kleistern",
    "Kleistern": "Kleister",
    "Kleisternden": "Kleisternde",
    "Kleisterns": "Kleistern",
    "Kleisters": "Kleister",
    "Klementinen": "Klementine",
    "Klemme": "klemmen",
    "Klemmen": "Klemme",
    "Klemmenden": "Klemmende",
    "Klemmens": "Klemmen",
    "Klemmfuttern": "Klemmfutter",
    "Klemmfutters": "Klemmfutter",
    "Klempner": "klempnern",
    "Klempnereien": "Klempnerei",
    "Klempnern": "Klempner",
    "Klempnernden": "Klempnernde",
    "Klempnerns": "Klempnern",
    "Klempners": "Klempner",
    "Kleptomanen": "Kleptomane",
    "Kleptomaninnen": "Kleptomanin",
    "Klerikern": "Kleriker",
    "Klerikers": "Kleriker",
    "Klerks": "Klerk",
    "Kletten": "Klette",
    "Kletterern": "Kletterer",
    "Kletterers": "Kletterer",
    "Klettergerüste": "Klettergerüst",
    "Klettergerüsten": "Klettergerüst",
    "Klettergerüsts": "Klettergerüst",
    "Klettermaste": "Klettermast",
    "Klettermasten": "Klettermast",
    "Klettermasts": "Klettermast",
    "Kletternden": "Kletternde",
    "Kletterns": "Klettern",
    "Kletterseile": "Kletterseil",
    "Kletterseilen": "Kletterseil",
    "Kletterseils": "Kletterseil",
    "Klienteln": "Klientel",
    "Klientels": "Klientel",
    "Klienten": "Klient",
    "Klimas": "Klima",
    "Klimatische": "klimatisch",
    "Klimatischen": "Klimatische",
    "Klimatisierenden": "Klimatisierende",
    "Klimatisierens": "Klimatisieren",
    "Klimatisierte": "klimatisiert",
    "Klimatisierten": "Klimatisierte",
    "Klimatisierteren": "Klimatisiertere",
    "Klimatisiertesten": "Klimatisierteste",
    "Klimatologischen": "Klimatologische",
    "Klimbims": "Klimbim",
    "Klimmenden": "Klimmende",
    "Klimmens": "Klimmen",
    "Klimmzuge": "Klimmzug",
    "Klimmzugs": "Klimmzug",
    "Klimmzüge": "Klimmzug",
    "Klimmzügen": "Klimmzug",
    "Klimperkastens": "Klimperkasten",
    "Klimperkästen": "Klimperkasten",
    "Klimpernden": "Klimpernde",
    "Klimpernderen": "Klimperndere",
    "Klimperndsten": "Klimperndste",
    "Klimperns": "Klimpern",
    "Klingel": "klingeln",
    "Klingelbeuteln": "Klingelbeutel",
    "Klingelbeutels": "Klingelbeutel",
    "Klingeln": "Klingel",
    "Klingelnden": "Klingelnde",
    "Klingelnderen": "Klingelndere",
    "Klingelndsten": "Klingelndste",
    "Klingelns": "Klingeln",
    "Klingen": "Klinge",
    "Klingenden": "Klingende",
    "Klingenderen": "Klingendere",
    "Klingendsten": "Klingendste",
    "Klingens": "Klingen",
    "Kliniken": "Klinik",
    "Klinikums": "Klinikum",
    "Klinische": "klinisch",
    "Klinischen": "Klinische",
    "Klinischeren": "Klinischere",
    "Klinischsten": "Klinischste",
    "Klinken": "Klinke",
    "Klinkenden": "Klinkende",
    "Klinkens": "Klinken",
    "Klinkern": "Klinker",
    "Klinkers": "Klinker",
    "Klinsmanns": "Klinsmann",
    "Klippen": "Klippe",
    "Klirrenden": "Klirrende",
    "Klirrenderen": "Klirrendere",
    "Klirrendsten": "Klirrendste",
    "Klirrens": "Klirren",
    "Klirrfaktore": "Klirrfaktor",
    "Klirrfaktoren": "Klirrfaktor",
    "Klirrfaktors": "Klirrfaktor",
    "Klischeehaften": "Klischeehafte",
    "Klischeehafteren": "Klischeehaftere",
    "Klischeehaftesten": "Klischeehafteste",
    "Klischees": "Klischee",
    "Klitschen": "Klitsche",
    "Klitschnasse": "klitschnaß",
    "Klitschnassen": "Klitschnasse",
    "Klitschnasseren": "Klitschnassere",
    "Klitschnassesten": "Klitschnasseste",
    "Klitterungen": "Klitterung",
    "Klitzekleine": "klitzeklein",
    "Klitzekleinen": "Klitzekleine",
    "Kloaken": "Kloake",
    "Klobige": "klobig",
    "Klobigen": "Klobige",
    "Klobigeren": "Klobigere",
    "Klobigsten": "Klobigste",
    "Klofrauen": "Klofrau",
    "Klonenden": "Klonende",
    "Klonens": "Klonen",
    "Klonings": "Kloning",
    "Klopfenden": "Klopfende",
    "Klopfens": "Klopfen",
    "Klopfern": "Klopfer",
    "Klopfers": "Klopfer",
    "Klopffesten": "Klopffeste",
    "Klopffesteren": "Klopffestere",
    "Klopffestesten": "Klopffesteste",
    "Klopfgeiste": "Klopfgeist",
    "Klopfgeister": "Klopfgeist",
    "Klopfgeistern": "Klopfgeist",
    "Klopfgeistes": "Klopfgeist",
    "Klopfgeists": "Klopfgeist",
    "Kloppenden": "Kloppende",
    "Kloppenheims": "Kloppenheim",
    "Kloppens": "Kloppen",
    "Klos": "Klo",
    "Kloses": "Klose",
    "Klosetts": "Klosett",
    "Klosters": "Kloster",
    "Klotz": "klotzen",
    "Klotze": "klotzen",
    "Klotzenden": "Klotzende",
    "Klotzenderen": "Klotzendere",
    "Klotzendsten": "Klotzendste",
    "Klotzens": "Klotzen",
    "Klotzes": "Klotz",
    "Klotzigen": "Klotzige",
    "Klotzigeren": "Klotzigere",
    "Klotzigsten": "Klotzigste",
    "Klubs": "Klub",
    "Kluge": "klug",
    "Klugen": "Kluge",
    "Klugrednern": "Klugredner",
    "Klugredners": "Klugredner",
    "Klugscheißern": "Klugscheißer",
    "Klugscheißers": "Klugscheißer",
    "Klumpenden": "Klumpende",
    "Klumpenderen": "Klumpendere",
    "Klumpendsten": "Klumpendste",
    "Klumpens": "Klumpen",
    "Klumpigen": "Klumpige",
    "Klumpigeren": "Klumpigere",
    "Klumpigsten": "Klumpigste",
    "Klunkern": "Klunker",
    "Klunkers": "Klunker",
    "Kläffende": "kläffend",
    "Kläffenden": "Kläffende",
    "Kläffendere": "kläffend",
    "Kläffenderen": "Kläffendere",
    "Kläffendste": "kläffend",
    "Kläffendsten": "Kläffendste",
    "Kläffens": "Kläffen",
    "Klägern": "Kläger",
    "Klägers": "Kläger",
    "Kläglichen": "Klägliche",
    "Kläglicheren": "Kläglichere",
    "Kläglichsten": "Kläglichste",
    "Klänge": "klingen",
    "Klängen": "klingen",
    "Kläranlagen": "Kläranlage",
    "Klärende": "klärend",
    "Klärenden": "Klärende",
    "Klärenderen": "Klärendere",
    "Klärendsten": "Klärendste",
    "Klärens": "Klären",
    "Klärmaschinen": "Klärmaschine",
    "Klärschlamms": "Klärschlamm",
    "Klärungen": "Klärung",
    "Klöckners": "Klöckner",
    "Klöhnenden": "Klöhnende",
    "Klöhnenderen": "Klöhnendere",
    "Klöhnendsten": "Klöhnendste",
    "Klöhnens": "Klöhnen",
    "Klönende": "klönend",
    "Klönenden": "Klönende",
    "Klönenderen": "Klönendere",
    "Klönendsten": "Klönendste",
    "Klönens": "Klönen",
    "Klöppeleien": "Klöppelei",
    "Klöster": "Kloster",
    "Klösterliche": "klösterlich",
    "Klösterlichen": "Klösterliche",
    "Klöstern": "Kloster",
    "Klötzchens": "Klötzchen",
    "Klötze": "Klotz",
    "Klötzen": "Klotz",
    "Klößchens": "Klößchen",
    "Klügelnden": "Klügelnde",
    "Klügelns": "Klügeln",
    "Klügeren": "Klügere",
    "Klügste": "klug",
    "Klügsten": "Klügste",
    "Klüngel": "klüngeln",
    "Klüngeln": "Klüngel",
    "Klüngelnden": "Klüngelnde",
    "Klüngelnderen": "Klüngelndere",
    "Klüngelndsten": "Klüngelndste",
    "Klüngelns": "Klüngeln",
    "Klüngels": "Klüngel",
    "Klüsen": "Klüse",
    "Knabbernden": "Knabbernde",
    "Knabberns": "Knabbern",
    "Knaben": "Knabe",
    "Knabenhafte": "knabenhaft",
    "Knabenhaften": "Knabenhafte",
    "Knabenhafteren": "Knabenhaftere",
    "Knabenhaftesten": "Knabenhafteste",
    "Knackenden": "Knackende",
    "Knackenderen": "Knackendere",
    "Knackendsten": "Knackendste",
    "Knackens": "Knacken",
    "Knackern": "Knacker",
    "Knackers": "Knacker",
    "Knackpunkte": "Knackpunkt",
    "Knackpunkten": "Knackpunkt",
    "Knackpunkts": "Knackpunkt",
    "Knacksenden": "Knacksende",
    "Knacksenderen": "Knacksendere",
    "Knacksendsten": "Knacksendste",
    "Knacksens": "Knacksen",
    "Knackwürste": "Knackwurst",
    "Knackwürsten": "Knackwurst",
    "Knall": "knallen",
    "Knalle": "knallen",
    "Knallen": "Knall",
    "Knallenden": "Knallende",
    "Knallenderen": "Knallendere",
    "Knallendsten": "Knallendste",
    "Knallens": "Knallen",
    "Knallerbsen": "Knallerbse",
    "Knallern": "Knaller",
    "Knallers": "Knaller",
    "Knallfrosche": "Knallfrosch",
    "Knallfroschs": "Knallfrosch",
    "Knallfrösche": "Knallfrosch",
    "Knallfröschen": "Knallfrosch",
    "Knallharte": "knallhart",
    "Knallharten": "Knallharte",
    "Knalligen": "Knallige",
    "Knalligeren": "Knalligere",
    "Knalligsten": "Knalligste",
    "Knalls": "Knall",
    "Knappen": "Knappe",
    "Knapperen": "Knappere",
    "Knappgehaltenen": "Knappgehaltene",
    "Knappgehalteneren": "Knappgehaltenere",
    "Knappgehaltensten": "Knappgehaltenste",
    "Knapphaltenden": "Knapphaltende",
    "Knapphaltenderen": "Knapphaltendere",
    "Knapphaltendsten": "Knapphaltendste",
    "Knapphaltens": "Knapphalten",
    "Knappschaften": "Knappschaft",
    "Knappschaftskassen": "Knappschaftskasse",
    "Knappste": "knapp",
    "Knappsten": "Knappste",
    "Knapsenden": "Knapsende",
    "Knapsenderen": "Knapsendere",
    "Knapsendsten": "Knapsendste",
    "Knapsens": "Knapsen",
    "Knarren": "Knarre",
    "Knarrenden": "Knarrende",
    "Knarrenderen": "Knarrendere",
    "Knarrendsten": "Knarrendste",
    "Knarrens": "Knarren",
    "Knarzenden": "Knarzende",
    "Knarzenderen": "Knarzendere",
    "Knarzendsten": "Knarzendste",
    "Knarzens": "Knarzen",
    "Knastern": "Knaster",
    "Knasters": "Knaster",
    "Knasts": "Knast",
    "Knatternden": "Knatternde",
    "Knatternderen": "Knatterndere",
    "Knatterndsten": "Knatterndste",
    "Knatterns": "Knattern",
    "Knaupelige": "knaupelig",
    "Knaupeligen": "Knaupelige",
    "Knaupeligeren": "Knaupeligere",
    "Knaupeligsten": "Knaupeligste",
    "Knauserigen": "Knauserige",
    "Knauserigeren": "Knauserigere",
    "Knauserigsten": "Knauserigste",
    "Knausernden": "Knausernde",
    "Knausernderen": "Knauserndere",
    "Knauserndsten": "Knauserndste",
    "Knauserns": "Knausern",
    "Knautschenden": "Knautschende",
    "Knautschenderen": "Knautschendere",
    "Knautschendsten": "Knautschendste",
    "Knautschens": "Knautschen",
    "Knautschigen": "Knautschige",
    "Knautschigeren": "Knautschigere",
    "Knautschigsten": "Knautschigste",
    "Knautschzonen": "Knautschzone",
    "Knebel": "knebeln",
    "Knebeln": "Knebel",
    "Knebelnden": "Knebelnde",
    "Knebelns": "Knebeln",
    "Knebels": "Knebel",
    "Knebelschrauben": "Knebelschraube",
    "Knechte": "knechten",
    "Knechten": "Knecht",
    "Knechtenden": "Knechtende",
    "Knechtenderen": "Knechtendere",
    "Knechtendsten": "Knechtendste",
    "Knechtens": "Knechten",
    "Knechts": "Knecht",
    "Kneifenden": "Kneifende",
    "Kneifens": "Kneifen",
    "Kneifzangen": "Kneifzange",
    "Kneipen": "Kneipe",
    "Kneipereien": "Kneiperei",
    "Kneipern": "Kneiper",
    "Kneipers": "Kneiper",
    "Kneippkuren": "Kneippkur",
    "Kneipps": "Kneipp",
    "Knellwolfs": "Knellwolf",
    "Knete": "kneten",
    "Knetenden": "Knetende",
    "Knetenderen": "Knetendere",
    "Knetendsten": "Knetendste",
    "Knetens": "Kneten",
    "Knick": "knicken",
    "Knicke": "knicken",
    "Knicken": "Knick",
    "Knickenden": "Knickende",
    "Knickenderen": "Knickendere",
    "Knickendsten": "Knickendste",
    "Knickens": "Knicken",
    "Knickes": "Knick",
    "Knickrigen": "Knickrige",
    "Knickrigeren": "Knickrigere",
    "Knickrigsten": "Knickrigste",
    "Knicks": "knicksen",
    "Knicksenden": "Knicksende",
    "Knicksens": "Knicksen",
    "Kniebeugen": "Kniebeuge",
    "Kniefreie": "kniefrei",
    "Kniefreien": "Kniefreie",
    "Kniegelenke": "Kniegelenk",
    "Kniegelenken": "Kniegelenk",
    "Kniegelenks": "Kniegelenk",
    "Knien": "Knie",
    "Knienden": "Kniende",
    "Kniens": "Knien",
    "Knieps": "Kniep",
    "Knies": "Knie",
    "Kniffe": "Kniff",
    "Kniffelige": "kniffelig",
    "Kniffeligen": "Kniffelige",
    "Kniffeligeren": "Kniffeligere",
    "Kniffeligsten": "Kniffeligste",
    "Kniffen": "Kniff",
    "Kniffes": "Kniff",
    "Kniffligen": "Knifflige",
    "Kniffligeren": "Kniffligere",
    "Kniffligsten": "Kniffligste",
    "Kniffs": "Kniff",
    "Knipsenden": "Knipsende",
    "Knipsens": "Knipsen",
    "Knirpse": "Knirps",
    "Knirpsen": "Knirps",
    "Knirpses": "Knirps",
    "Knirschenden": "Knirschende",
    "Knirschenderen": "Knirschendere",
    "Knirschendsten": "Knirschendste",
    "Knirschens": "Knirschen",
    "Knisternden": "Knisternde",
    "Knisternderen": "Knisterndere",
    "Knisterndsten": "Knisterndste",
    "Knisterns": "Knistern",
    "Knitterfreien": "Knitterfreie",
    "Knitterigen": "Knitterige",
    "Knitterigeren": "Knitterigere",
    "Knitterigsten": "Knitterigste",
    "Knitternden": "Knitternde",
    "Knitternderen": "Knitterndere",
    "Knitterndsten": "Knitterndste",
    "Knitterns": "Knittern",
    "Knittrigen": "Knittrige",
    "Knittrigeren": "Knittrigere",
    "Knittrigsten": "Knittrigste",
    "Knobelnden": "Knobelnde",
    "Knobelnderen": "Knobelndere",
    "Knobelndsten": "Knobelndste",
    "Knobelns": "Knobeln",
    "Knochens": "Knochen",
    "Knochigen": "Knochige",
    "Knochigeren": "Knochigere",
    "Knochigsten": "Knochigste",
    "Knockouts": "Knockout",
    "Knollen": "Knolle",
    "Knollens": "Knollen",
    "Knollige": "knollig",
    "Knolligen": "Knollige",
    "Knolligeren": "Knolligere",
    "Knolligsten": "Knolligste",
    "Knopfe": "Knopf",
    "Knopfes": "Knopf",
    "Knopfs": "Knopf",
    "Knorpeligen": "Knorpelige",
    "Knorpeligeren": "Knorpeligere",
    "Knorpeligsten": "Knorpeligste",
    "Knorpeln": "Knorpel",
    "Knorpels": "Knorpel",
    "Knorplige": "knorplig",
    "Knorpligen": "Knorplige",
    "Knorpligeren": "Knorpligere",
    "Knorpligsten": "Knorpligste",
    "Knorrigen": "Knorrige",
    "Knorrigeren": "Knorrigere",
    "Knorrigsten": "Knorrigste",
    "Knospen": "Knospe",
    "Knotenden": "Knotende",
    "Knotens": "Knoten",
    "Knuffenden": "Knuffende",
    "Knuffens": "Knuffen",
    "Knurrenden": "Knurrende",
    "Knurrenderen": "Knurrendere",
    "Knurrendsten": "Knurrendste",
    "Knurrens": "Knurren",
    "Knuspernden": "Knuspernde",
    "Knuspernderen": "Knusperndere",
    "Knusperndsten": "Knusperndste",
    "Knusperns": "Knuspern",
    "Knusprigen": "Knusprige",
    "Knusprigeren": "Knusprigere",
    "Knusprigsten": "Knusprigste",
    "Knutschenden": "Knutschende",
    "Knutschenderen": "Knutschendere",
    "Knutschendsten": "Knutschendste",
    "Knutschens": "Knutschen",
    "Knäbleins": "Knäblein",
    "Knäueln": "Knäuel",
    "Knäuels": "Knäuel",
    "Knäulchens": "Knäulchen",
    "Knöcherige": "knöcherig",
    "Knöcherigen": "Knöcherige",
    "Knöcherigeren": "Knöcherigere",
    "Knöcherigsten": "Knöcherigste",
    "Knöchernen": "Knöcherne",
    "Knöcherneren": "Knöchernere",
    "Knöchernesten": "Knöcherneste",
    "Knödeln": "Knödel",
    "Knödels": "Knödel",
    "Knöpfchens": "Knöpfchen",
    "Knöpfe": "knöpfen",
    "Knöpfen": "Knopf",
    "Knöpfenden": "Knöpfende",
    "Knöpfens": "Knöpfen",
    "Knüllenden": "Knüllende",
    "Knüllens": "Knüllen",
    "Knüllern": "Knüller",
    "Knüllers": "Knüller",
    "Knüpfenden": "Knüpfende",
    "Knüpfens": "Knüpfen",
    "Knüppel": "knüppeln",
    "Knüppeldicke": "knüppeldick",
    "Knüppeldicken": "Knüppeldicke",
    "Knüppelharten": "Knüppelharte",
    "Knüppeln": "Knüppel",
    "Knüppelnden": "Knüppelnde",
    "Knüppelnderen": "Knüppelndere",
    "Knüppelndsten": "Knüppelndste",
    "Knüppelns": "Knüppeln",
    "Knüppels": "Knüppel",
    "Koalitionen": "Koalition",
    "Koautore": "Koautor",
    "Koautoren": "Koautor",
    "Koautors": "Koautor",
    "Koaxiale": "koaxial",
    "Koaxialen": "Koaxiale",
    "Kobalte": "Kobalt",
    "Kobalten": "Kobalt",
    "Kobalts": "Kobalt",
    "Kobolde": "Kobold",
    "Kobolden": "Kobold",
    "Koboldes": "Kobold",
    "Kobolds": "Kobold",
    "Kobras": "Kobra",
    "Koch": "kochen",
    "Koche": "kochen",
    "Kochechte": "kochecht",
    "Kochechten": "Kochechte",
    "Kochenden": "Kochende",
    "Kochens": "Kochen",
    "Kochern": "Kocher",
    "Kochers": "Kocher",
    "Kochfertigen": "Kochfertige",
    "Kochfesten": "Kochfeste",
    "Kochflaschen": "Kochflasche",
    "Kochgeschirre": "Kochgeschirr",
    "Kochgeschirren": "Kochgeschirr",
    "Kochgeschirrs": "Kochgeschirr",
    "Kochherde": "Kochherd",
    "Kochherden": "Kochherd",
    "Kochherds": "Kochherd",
    "Kochrezepte": "Kochrezept",
    "Kochrezepten": "Kochrezept",
    "Kochrezepts": "Kochrezept",
    "Kochs": "Koch",
    "Kochschinkens": "Kochschinken",
    "Kodderigen": "Kodderige",
    "Kodderigeren": "Kodderigere",
    "Kodderigsten": "Kodderigste",
    "Koedukativen": "Koedukative",
    "Koffeinfreien": "Koffeinfreie",
    "Koffern": "Koffer",
    "Koffers": "Koffer",
    "Koggen": "Kogge",
    "Kognitive": "kognitiv",
    "Kognitiven": "Kognitive",
    "Kognitiveren": "Kognitivere",
    "Kognitivsten": "Kognitivste",
    "Kohl": "kohlen",
    "Kohldampfs": "Kohldampf",
    "Kohle": "kohlen",
    "Kohlen": "Kohle",
    "Kohlenden": "Kohlende",
    "Kohlens": "Kohlen",
    "Kohlers": "Kohler",
    "Kohles": "Kohl",
    "Kohlrüben": "Kohlrübe",
    "Kohls": "Kohl",
    "Kohärenten": "Kohärente",
    "Kohäsionen": "Kohäsion",
    "Koinzidenzen": "Koinzidenz",
    "Kokains": "Kokain",
    "Kokelnden": "Kokelnde",
    "Kokelnderen": "Kokelndere",
    "Kokelndsten": "Kokelndste",
    "Kokelns": "Kokeln",
    "Koketten": "Kokette",
    "Koketteren": "Kokettere",
    "Kokettesten": "Koketteste",
    "Kokettierenden": "Kokettierende",
    "Kokettierenderen": "Kokettierendere",
    "Kokettierendsten": "Kokettierendste",
    "Kokettierens": "Kokettieren",
    "Kokettierte": "kokettiert",
    "Kokettierten": "Kokettierte",
    "Kokettierteren": "Kokettiertere",
    "Kokettiertesten": "Kokettierteste",
    "Kokosnüsse": "Kokosnuß",
    "Kokosnüssen": "Kokosnuß",
    "Koksenden": "Koksende",
    "Koksens": "Koksen",
    "Koksern": "Kokser",
    "Koksers": "Kokser",
    "Kolben": "Kolbe",
    "Kolbens": "Kolben",
    "Kolibris": "Kolibri",
    "Koliken": "Kolik",
    "Kollabierenden": "Kollabierende",
    "Kollabierenderen": "Kollabierendere",
    "Kollabierendsten": "Kollabierendste",
    "Kollabierens": "Kollabieren",
    "Kollabierte": "kollabiert",
    "Kollabierten": "Kollabierte",
    "Kollaboratore": "Kollaborator",
    "Kollaboratoren": "Kollaborator",
    "Kollaborators": "Kollaborator",
    "Kollaboriere": "kollaborieren",
    "Kollaborierenden": "Kollaborierende",
    "Kollaborierenderen": "Kollaborierendere",
    "Kollaborierens": "Kollaborieren",
    "Kollaborierte": "kollaboriert",
    "Kollaborierten": "Kollaborierte",
    "Kollaborierteren": "Kollaboriertere",
    "Kollaboriertesten": "Kollaborierteste",
    "Kollegen": "Kollege",
    "Kolleghefte": "Kollegheft",
    "Kollegheften": "Kollegheft",
    "Kolleghefts": "Kollegheft",
    "Kollegiale": "kollegial",
    "Kollegialen": "Kollegiale",
    "Kollegialeren": "Kollegialere",
    "Kollegialgerichte": "Kollegialgericht",
    "Kollegialgerichten": "Kollegialgericht",
    "Kollegialgerichts": "Kollegialgericht",
    "Kollegialste": "kollegial",
    "Kollegialsten": "Kollegialste",
    "Kollegiaten": "Kollegiat",
    "Kolleginnen": "Kollegin",
    "Kollegs": "Kolleg",
    "Kollekten": "Kollekte",
    "Kollektionen": "Kollektion",
    "Kollektive": "Kollektiv",
    "Kollektiven": "Kollektive",
    "Kollektivs": "Kollektiv",
    "Kollektivvertrage": "Kollektivvertrag",
    "Kollektivvertrags": "Kollektivvertrag",
    "Kollektivverträge": "Kollektivvertrag",
    "Kollektivverträgen": "Kollektivvertrag",
    "Kollektore": "Kollektor",
    "Kollektoren": "Kollektor",
    "Kollektors": "Kollektor",
    "Kollern": "Koller",
    "Kollers": "Koller",
    "Kollineationen": "Kollineation",
    "Kolonialamts": "Kolonialamt",
    "Koloniale": "kolonial",
    "Kolonialen": "Koloniale",
    "Kolonialisierenden": "Kolonialisierende",
    "Kolonialisierens": "Kolonialisieren",
    "Kolonialisierte": "kolonialisiert",
    "Kolonialisierten": "Kolonialisierte",
    "Kolonialistischen": "Kolonialistische",
    "Kolonialmächte": "Kolonialmacht",
    "Kolonialmächten": "Kolonialmacht",
    "Kolonialstils": "Kolonialstil",
    "Kolonien": "Kolonie",
    "Kolonisatore": "Kolonisator",
    "Kolonisatoren": "Kolonisator",
    "Kolonisators": "Kolonisator",
    "Kolonisierenden": "Kolonisierende",
    "Kolonisierens": "Kolonisieren",
    "Kolonisierte": "kolonisiert",
    "Kolonisierten": "Kolonisierte",
    "Kolonisten": "Kolonist",
    "Kolonnen": "Kolonne",
    "Koloristen": "Kolorist",
    "Kolossale": "kolossal",
    "Kolossalen": "Kolossale",
    "Kolossaleren": "Kolossalere",
    "Kolossalsten": "Kolossalste",
    "Kolpings": "Kolping",
    "Kolumbiens": "Kolumbien",
    "Kolumnen": "Kolumne",
    "Kolumnisten": "Kolumnist",
    "Komas": "Koma",
    "Kombinate": "Kombinat",
    "Kombinaten": "Kombinat",
    "Kombinates": "Kombinat",
    "Kombinationen": "Kombination",
    "Kombinatorische": "kombinatorisch",
    "Kombinatorischen": "Kombinatorische",
    "Kombinats": "Kombinat",
    "Kombinierenden": "Kombinierende",
    "Kombinierens": "Kombinieren",
    "Kombinierte": "kombiniert",
    "Kombinierten": "Kombinierte",
    "Kombis": "Kombi",
    "Kombiwagens": "Kombiwagen",
    "Kombizangen": "Kombizange",
    "Kombüsen": "Kombüse",
    "Kometen": "Komet",
    "Komfortabelste": "komfortabel",
    "Komfortabelsten": "Komfortabelste",
    "Komfortablen": "Komfortable",
    "Komfortableren": "Komfortablere",
    "Komforts": "Komfort",
    "Komikern": "Komiker",
    "Komikers": "Komiker",
    "Komische": "komisch",
    "Komischen": "Komische",
    "Komischeren": "Komischere",
    "Komischsten": "Komischste",
    "Komitees": "Komitee",
    "Kommandierenden": "Kommandierende",
    "Kommandierens": "Kommandieren",
    "Kommandierte": "kommandiert",
    "Kommandierten": "Kommandierte",
    "Kommanditen": "Kommandite",
    "Kommandos": "Kommando",
    "Kommas": "Komma",
    "Kommenden": "Kommende",
    "Kommens": "Kommen",
    "Kommentare": "Kommentar",
    "Kommentaren": "Kommentar",
    "Kommentarlose": "kommentarlos",
    "Kommentarlosen": "Kommentarlose",
    "Kommentars": "Kommentar",
    "Kommentatore": "Kommentator",
    "Kommentatoren": "Kommentator",
    "Kommentators": "Kommentator",
    "Kommentierenden": "Kommentierende",
    "Kommentierens": "Kommentieren",
    "Kommentierte": "kommentiert",
    "Kommentierten": "Kommentierte",
    "Kommerzialisierenden": "Kommerzialisierende",
    "Kommerzialisierenderen": "Kommerzialisierendere",
    "Kommerzialisierens": "Kommerzialisieren",
    "Kommerzialisierte": "kommerzialisiert",
    "Kommerzialisierten": "Kommerzialisierte",
    "Kommerzialisierteren": "Kommerzialisiertere",
    "Kommerzialrate": "Kommerzialrat",
    "Kommerzialrats": "Kommerzialrat",
    "Kommerzialräte": "Kommerzialrat",
    "Kommerzialräten": "Kommerzialrat",
    "Kommerzielle": "kommerziell",
    "Kommerziellen": "Kommerzielle",
    "Kommerzielleren": "Kommerziellere",
    "Kommerziellsten": "Kommerziellste",
    "Kommisionen": "Kommision",
    "Kommissare": "Kommissar",
    "Kommissaren": "Kommissar",
    "Kommissarische": "kommissarisch",
    "Kommissarischen": "Kommissarische",
    "Kommissars": "Kommissar",
    "Kommissionen": "Kommission",
    "Kommitees": "Kommitee",
    "Kommoden": "Kommode",
    "Kommodores": "Kommodore",
    "Kommunalen": "Kommunale",
    "Kommunalisierenden": "Kommunalisierende",
    "Kommunalisierenderen": "Kommunalisierendere",
    "Kommunalisierens": "Kommunalisieren",
    "Kommunalisierte": "kommunalisiert",
    "Kommunalisierten": "Kommunalisierte",
    "Kommunalisierteren": "Kommunalisiertere",
    "Kommunalpolitiken": "Kommunalpolitik",
    "Kommunalpolitikern": "Kommunalpolitiker",
    "Kommunalpolitikers": "Kommunalpolitiker",
    "Kommunalverwaltungen": "Kommunalverwaltung",
    "Kommunalwahlen": "Kommunalwahl",
    "Kommunen": "Kommune",
    "Kommunikationen": "Kommunikation",
    "Kommunikative": "kommunikativ",
    "Kommunikativen": "Kommunikative",
    "Kommuniques": "Kommunique",
    "Kommunisten": "Kommunist",
    "Kommunistische": "kommunistisch",
    "Kommunistischen": "Kommunistische",
    "Kommunistischeren": "Kommunistischere",
    "Kommunistischsten": "Kommunistischste",
    "Kommunizierenden": "Kommunizierende",
    "Kommunizierens": "Kommunizieren",
    "Kommunizierte": "kommuniziert",
    "Kommunizierten": "Kommunizierte",
    "Kommutativen": "Kommutative",
    "Kommutatore": "Kommutator",
    "Kommutatoren": "Kommutator",
    "Kommutators": "Kommutator",
    "Kompagnons": "Kompagnon",
    "Kompakte": "kompakt",
    "Kompakten": "Kompakte",
    "Kompakteren": "Kompaktere",
    "Kompaktesten": "Kompakteste",
    "Kompaktlagern": "Kompaktlager",
    "Kompaktlagers": "Kompaktlager",
    "Kompanien": "Kompanie",
    "Komparationen": "Komparation",
    "Komparierenden": "Komparierende",
    "Komparierenderen": "Komparierendere",
    "Komparierendsten": "Komparierendste",
    "Komparierens": "Komparieren",
    "Komparierte": "kompariert",
    "Komparierten": "Komparierte",
    "Komparierteren": "Kompariertere",
    "Kompariertesten": "Komparierteste",
    "Kompatibelsten": "Kompatibelste",
    "Kompatiblen": "Kompatible",
    "Kompatibleren": "Kompatiblere",
    "Kompensationen": "Kompensation",
    "Kompensatore": "Kompensator",
    "Kompensatoren": "Kompensator",
    "Kompensatorische": "kompensatorisch",
    "Kompensatorischen": "Kompensatorische",
    "Kompensators": "Kompensator",
    "Kompensierenden": "Kompensierende",
    "Kompensierenderen": "Kompensierendere",
    "Kompensierendsten": "Kompensierendste",
    "Kompensierens": "Kompensieren",
    "Kompensierte": "kompensiert",
    "Kompensierten": "Kompensierte",
    "Kompensierteren": "Kompensiertere",
    "Kompensiertesten": "Kompensierteste",
    "Kompetenten": "Kompetente",
    "Kompetenteren": "Kompetentere",
    "Kompetentesten": "Kompetenteste",
    "Kompetenzen": "Kompetenz",
    "Kompetitive": "kompetitiv",
    "Kompetitiven": "Kompetitive",
    "Kompilierenden": "Kompilierende",
    "Kompilierens": "Kompilieren",
    "Kompilierte": "kompiliert",
    "Kompilierten": "Kompilierte",
    "Komplanaren": "Komplanare",
    "Komplemente": "Komplement",
    "Komplementen": "Komplement",
    "Komplementierenden": "Komplementierende",
    "Komplementierens": "Komplementieren",
    "Komplementierte": "komplementiert",
    "Komplementierten": "Komplementierte",
    "Komplementierteren": "Komplementiertere",
    "Komplements": "Komplement",
    "Komplementwinkeln": "Komplementwinkel",
    "Komplementwinkels": "Komplementwinkel",
    "Komplementären": "Komplementäre",
    "Komplementärfarben": "Komplementärfarbe",
    "Komplette": "komplett",
    "Kompletten": "Komplette",
    "Kompletteren": "Komplettere",
    "Komplettesten": "Kompletteste",
    "Komplettierenden": "Komplettierende",
    "Komplettierenderen": "Komplettierendere",
    "Komplettierens": "Komplettieren",
    "Komplettierte": "komplettiert",
    "Komplettierten": "Komplettierte",
    "Komplettierteren": "Komplettiertere",
    "Komplettiertesten": "Komplettierteste",
    "Komplexen": "Komplexe",
    "Komplexeren": "Komplexere",
    "Komplexeste": "komplex",
    "Komplexesten": "Komplexeste",
    "Komplikationen": "Komplikation",
    "Komplimente": "Kompliment",
    "Komplimenten": "Kompliment",
    "Komplimentierenden": "Komplimentierende",
    "Komplimentierens": "Komplimentieren",
    "Komplimentierte": "komplimentiert",
    "Komplimentierten": "Komplimentierte",
    "Kompliments": "Kompliment",
    "Komplizen": "Komplize",
    "Komplizierenden": "Komplizierende",
    "Komplizierenderen": "Komplizierendere",
    "Komplizierendsten": "Komplizierendste",
    "Komplizierens": "Komplizieren",
    "Komplizierte": "kompliziert",
    "Komplizierten": "Komplizierte",
    "Komplizierteren": "Kompliziertere",
    "Kompliziertesten": "Komplizierteste",
    "Komplottierenden": "Komplottierende",
    "Komplottierens": "Komplottieren",
    "Komplottierte": "komplottiert",
    "Komplottierten": "Komplottierte",
    "Komponenten": "Komponente",
    "Komponierenden": "Komponierende",
    "Komponierens": "Komponieren",
    "Komponierte": "komponiert",
    "Komponierten": "Komponierte",
    "Komponisten": "Komponist",
    "Komponistinnen": "Komponistin",
    "Komposita": "Kompositum",
    "Kompositionen": "Komposition",
    "Kompositums": "Kompositum",
    "Komposte": "Kompost",
    "Komposten": "Kompost",
    "Kompostes": "Kompost",
    "Komposthaufens": "Komposthaufen",
    "Kompostierenden": "Kompostierende",
    "Kompostierens": "Kompostieren",
    "Kompostierte": "kompostiert",
    "Kompostierten": "Kompostierte",
    "Kompotte": "Kompott",
    "Kompotten": "Kompott",
    "Kompotts": "Kompott",
    "Kompressen": "Kompresse",
    "Kompressore": "Kompressor",
    "Kompressoren": "Kompressor",
    "Kompressors": "Kompressor",
    "Komprimierenden": "Komprimierende",
    "Komprimierenderen": "Komprimierendere",
    "Komprimierendsten": "Komprimierendste",
    "Komprimierens": "Komprimieren",
    "Komprimierte": "komprimiert",
    "Komprimierten": "Komprimierte",
    "Komprimierteren": "Komprimiertere",
    "Komprimiertesten": "Komprimierteste",
    "Kompromisse": "Kompromiß",
    "Kompromissen": "Kompromiß",
    "Kompromisses": "Kompromiß",
    "Kompromißbereiten": "Kompromißbereite",
    "Kompromißbereiteren": "Kompromißbereitere",
    "Kompromißlose": "kompromißlos",
    "Kompromißlosen": "Kompromißlose",
    "Kompromißloseren": "Kompromißlosere",
    "Kompromißlosesten": "Kompromißloseste",
    "Komunen": "Komune",
    "Komödien": "Komödie",
    "Kondensatore": "Kondensator",
    "Kondensatoren": "Kondensator",
    "Kondensators": "Kondensator",
    "Kondensierenden": "Kondensierende",
    "Kondensierenderen": "Kondensierendere",
    "Kondensierendsten": "Kondensierendste",
    "Kondensierens": "Kondensieren",
    "Kondensierte": "kondensiert",
    "Kondensierten": "Kondensierte",
    "Kondensierteren": "Kondensiertere",
    "Kondensiertesten": "Kondensierteste",
    "Kondensore": "Kondensor",
    "Kondensoren": "Kondensor",
    "Kondensors": "Kondensor",
    "Kondensstreifens": "Kondensstreifen",
    "Konditionale": "konditional",
    "Konditionalen": "Konditionale",
    "Konditionen": "Kondition",
    "Konditionierenden": "Konditionierende",
    "Konditionierenderen": "Konditionierendere",
    "Konditionierens": "Konditionieren",
    "Konditionierte": "konditioniert",
    "Konditionierten": "Konditionierte",
    "Konditionierteren": "Konditioniertere",
    "Konditionierteste": "konditioniert",
    "Konditionierungen": "Konditionierung",
    "Konditore": "Konditor",
    "Konditoreien": "Konditorei",
    "Konditoren": "Konditor",
    "Konditors": "Konditor",
    "Kondome": "Kondom",
    "Kondomen": "Kondom",
    "Kondoms": "Kondom",
    "Kondukte": "Kondukt",
    "Kondukten": "Kondukt",
    "Konduktore": "Konduktor",
    "Konduktoren": "Konduktor",
    "Konduktors": "Konduktor",
    "Kondukts": "Kondukt",
    "Kondurangos": "Kondurango",
    "Konfekte": "Konfekt",
    "Konfekten": "Konfekt",
    "Konfektionen": "Konfektion",
    "Konfektionierenden": "Konfektionierende",
    "Konfektionierenderen": "Konfektionierendere",
    "Konfektionierens": "Konfektionieren",
    "Konfektionierte": "konfektioniert",
    "Konfektionierten": "Konfektionierte",
    "Konfektionierteren": "Konfektioniertere",
    "Konfekts": "Konfekt",
    "Konferenzen": "Konferenz",
    "Konferierenden": "Konferierende",
    "Konferierens": "Konferieren",
    "Konferierte": "konferiert",
    "Konferierten": "Konferierte",
    "Konfessionen": "Konfession",
    "Konfessionslose": "konfessionslos",
    "Konfessionslosen": "Konfessionslose",
    "Konfidenten": "Konfident",
    "Konfidenzen": "Konfidenz",
    "Konfigurationen": "Konfiguration",
    "Konfigurierenden": "Konfigurierende",
    "Konfigurierens": "Konfigurieren",
    "Konfigurierte": "konfiguriert",
    "Konfigurierten": "Konfigurierte",
    "Konfigurierteren": "Konfiguriertere",
    "Konfiguriertesten": "Konfigurierteste",
    "Konfirmanden": "Konfirmand",
    "Konfirmandinnen": "Konfirmandin",
    "Konfirmationen": "Konfirmation",
    "Konfirmierenden": "Konfirmierende",
    "Konfirmierens": "Konfirmieren",
    "Konfirmierte": "konfirmiert",
    "Konfirmierten": "Konfirmierte",
    "Konfirmierteren": "Konfirmiertere",
    "Konfirmiertesten": "Konfirmierteste",
    "Konfiszierenden": "Konfiszierende",
    "Konfiszierens": "Konfiszieren",
    "Konfiszierte": "konfisziert",
    "Konfiszierten": "Konfiszierte",
    "Konfitüren": "Konfitüre",
    "Konflikte": "Konflikt",
    "Konflikten": "Konflikt",
    "Konfliktes": "Konflikt",
    "Konfliktfähige": "konfliktfähig",
    "Konfliktfähigen": "Konfliktfähige",
    "Konfliktfähigeren": "Konfliktfähigere",
    "Konfliktfähigsten": "Konfliktfähigste",
    "Konflikts": "Konflikt",
    "Konformationen": "Konformation",
    "Konforme": "konform",
    "Konformen": "Konforme",
    "Konformisten": "Konformist",
    "Konfrontationen": "Konfrontation",
    "Konfrontierenden": "Konfrontierende",
    "Konfrontierens": "Konfrontieren",
    "Konfrontierte": "konfrontiert",
    "Konfrontierten": "Konfrontierte",
    "Konfrontierungen": "Konfrontierung",
    "Konfuse": "konfus",
    "Konfusen": "Konfuse",
    "Konfuseren": "Konfusere",
    "Konfusesten": "Konfuseste",
    "Konfusionen": "Konfusion",
    "Konföderationen": "Konföderation",
    "Konföderierenden": "Konföderierende",
    "Konföderierens": "Konföderieren",
    "Konföderierte": "konföderiert",
    "Konföderierten": "Konföderierte",
    "Konglomerate": "Konglomerat",
    "Konglomeraten": "Konglomerat",
    "Konglomerats": "Konglomerat",
    "Kongresse": "Kongreß",
    "Kongressen": "Kongreß",
    "Kongresses": "Kongreß",
    "Kongruente": "kongruent",
    "Kongruenten": "Kongruente",
    "Kongruierenden": "Kongruierende",
    "Kongruierens": "Kongruieren",
    "Kongruierte": "kongruiert",
    "Kongruierten": "Kongruierte",
    "Konischen": "Konische",
    "Konischeren": "Konischere",
    "Konischsten": "Konischste",
    "Konjugierenden": "Konjugierende",
    "Konjugierens": "Konjugieren",
    "Konjugierte": "konjugiert",
    "Konjugierten": "Konjugierte",
    "Konjunkturellen": "Konjunkturelle",
    "Konjunkturen": "Konjunktur",
    "Konkave": "konkav",
    "Konkaven": "Konkave",
    "Konkaveren": "Konkavere",
    "Konkavsten": "Konkavste",
    "Konkordanten": "Konkordante",
    "Konkordanzen": "Konkordanz",
    "Konkordate": "Konkordat",
    "Konkordaten": "Konkordat",
    "Konkordats": "Konkordat",
    "Konkremente": "Konkrement",
    "Konkrementen": "Konkrement",
    "Konkrements": "Konkrement",
    "Konkrete": "konkret",
    "Konkreten": "Konkrete",
    "Konkreteren": "Konkretere",
    "Konkretesten": "Konkreteste",
    "Konkretisierenden": "Konkretisierende",
    "Konkretisierens": "Konkretisieren",
    "Konkretisierte": "konkretisiert",
    "Konkretisierten": "Konkretisierte",
    "Konkretisierungen": "Konkretisierung",
    "Konkubinate": "Konkubinat",
    "Konkubinaten": "Konkubinat",
    "Konkubinats": "Konkubinat",
    "Konkurrenten": "Konkurrent",
    "Konkurrenzen": "Konkurrenz",
    "Konkurrenzfähige": "konkurrenzfähig",
    "Konkurrenzfähigen": "Konkurrenzfähige",
    "Konkurrenzfähigeren": "Konkurrenzfähigere",
    "Konkurrenzlosen": "Konkurrenzlose",
    "Konkurrenzloseren": "Konkurrenzlosere",
    "Konkurrierenden": "Konkurrierende",
    "Konkurrierens": "Konkurrieren",
    "Konkurrierte": "konkurriert",
    "Konkurrierten": "Konkurrierte",
    "Konkurse": "Konkurs",
    "Konkursen": "Konkurs",
    "Konkurses": "Konkurs",
    "Konnektore": "Konnektor",
    "Konnektoren": "Konnektor",
    "Konnektors": "Konnektor",
    "Konnotationen": "Konnotation",
    "Konrads": "Konrad",
    "Konrektore": "Konrektor",
    "Konrektoren": "Konrektor",
    "Konrektors": "Konrektor",
    "Konsense": "Konsens",
    "Konsensen": "Konsens",
    "Konsenses": "Konsens",
    "Konsequente": "konsequent",
    "Konsequenten": "Konsequente",
    "Konsequenteren": "Konsequentere",
    "Konsequentesten": "Konsequenteste",
    "Konsequenzen": "Konsequenz",
    "Konservative": "konservativ",
    "Konservativen": "Konservative",
    "Konservativeren": "Konservativere",
    "Konservativsten": "Konservativste",
    "Konserven": "Konserve",
    "Konservierungen": "Konservierung",
    "Konsistente": "konsistent",
    "Konsistenten": "Konsistente",
    "Konsistenteren": "Konsistentere",
    "Konsistentesten": "Konsistenteste",
    "Konsistenzen": "Konsistenz",
    "Konsolen": "Konsole",
    "Konsolidierenden": "Konsolidierende",
    "Konsolidierens": "Konsolidieren",
    "Konsolidierte": "konsolidiert",
    "Konsolidierten": "Konsolidierte",
    "Konsolidierteren": "Konsolidiertere",
    "Konsolidiertesten": "Konsolidierteste",
    "Konsommees": "Konsommee",
    "Konsonanten": "Konsonant",
    "Konsonanzen": "Konsonanz",
    "Konsorten": "Konsorte",
    "Konsortien": "Konsortium",
    "Konsortiums": "Konsortium",
    "Konsoziationen": "Konsoziation",
    "Konspirationen": "Konspiration",
    "Konspirative": "konspirativ",
    "Konspirativen": "Konspirative",
    "Konspirativeren": "Konspirativere",
    "Konspirativsten": "Konspirativste",
    "Konspirierenden": "Konspirierende",
    "Konspirierens": "Konspirieren",
    "Konspirierte": "konspiriert",
    "Konspirierten": "Konspirierte",
    "Konstablern": "Konstabler",
    "Konstablers": "Konstabler",
    "Konstante": "konstant",
    "Konstanten": "Konstante",
    "Konstanteren": "Konstantere",
    "Konstantesten": "Konstanteste",
    "Konstatierenden": "Konstatierende",
    "Konstatierens": "Konstatieren",
    "Konstatierte": "konstatiert",
    "Konstatierten": "Konstatierte",
    "Konstellationen": "Konstellation",
    "Konsterniere": "konsternieren",
    "Konsternierenden": "Konsternierende",
    "Konsternierenderen": "Konsternierendere",
    "Konsternierens": "Konsternieren",
    "Konsternierte": "konsterniert",
    "Konsternierten": "Konsternierte",
    "Konsternierteren": "Konsterniertere",
    "Konsterniertesten": "Konsternierteste",
    "Konstituenten": "Konstituente",
    "Konstituierenden": "Konstituierende",
    "Konstituierens": "Konstituieren",
    "Konstituierte": "konstituiert",
    "Konstituierten": "Konstituierte",
    "Konstitutionellen": "Konstitutionelle",
    "Konstitutionen": "Konstitution",
    "Konstriktore": "Konstriktor",
    "Konstriktoren": "Konstriktor",
    "Konstriktors": "Konstriktor",
    "Konstruierenden": "Konstruierende",
    "Konstruierens": "Konstruieren",
    "Konstruierte": "konstruiert",
    "Konstruierten": "Konstruierte",
    "Konstrukte": "Konstrukt",
    "Konstrukten": "Konstrukt",
    "Konstruktionen": "Konstruktion",
    "Konstruktive": "konstruktiv",
    "Konstruktiven": "Konstruktive",
    "Konstruktiveren": "Konstruktivere",
    "Konstruktivsten": "Konstruktivste",
    "Konstrukts": "Konstrukt",
    "Konsulate": "Konsulat",
    "Konsulaten": "Konsulat",
    "Konsulats": "Konsulat",
    "Konsultationen": "Konsultation",
    "Konsultierenden": "Konsultierende",
    "Konsultierens": "Konsultieren",
    "Konsultierte": "konsultiert",
    "Konsultierten": "Konsultierte",
    "Konsumenten": "Konsument",
    "Konsumierenden": "Konsumierende",
    "Konsumierenderen": "Konsumierendere",
    "Konsumierendsten": "Konsumierendste",
    "Konsumierens": "Konsumieren",
    "Konsumierte": "konsumiert",
    "Konsumierten": "Konsumierte",
    "Konsums": "Konsum",
    "Kontaktarme": "kontaktarm",
    "Kontaktarmen": "Kontaktarme",
    "Kontakte": "kontakten",
    "Kontakten": "Kontakt",
    "Kontaktenden": "Kontaktende",
    "Kontaktens": "Kontakten",
    "Kontaktete": "kontaktet",
    "Kontakteten": "Kontaktete",
    "Kontaktfreudigen": "Kontaktfreudige",
    "Kontaktfreudigeren": "Kontaktfreudigere",
    "Kontaktierenden": "Kontaktierende",
    "Kontaktierens": "Kontaktieren",
    "Kontaktierte": "kontaktiert",
    "Kontaktierten": "Kontaktierte",
    "Kontakts": "Kontakt",
    "Kontaktscheue": "kontaktscheu",
    "Kontaktscheuen": "Kontaktscheue",
    "Kontaktscheueren": "Kontaktscheuere",
    "Kontaktscheusten": "Kontaktscheuste",
    "Kontaktschwachen": "Kontaktschwache",
    "Kontaktschwächeren": "Kontaktschwächere",
    "Kontaktärmeren": "Kontaktärmere",
    "Kontaminationen": "Kontamination",
    "Kontaminierenden": "Kontaminierende",
    "Kontaminierens": "Kontaminieren",
    "Kontaminierte": "kontaminiert",
    "Kontaminierten": "Kontaminierte",
    "Konten": "Konto",
    "Konter": "kontern",
    "Kontergewichte": "Kontergewicht",
    "Kontergewichten": "Kontergewicht",
    "Kontergewichts": "Kontergewicht",
    "Kontern": "Konter",
    "Konternden": "Konternde",
    "Konternderen": "Konterndere",
    "Konterndsten": "Konterndste",
    "Konterns": "Kontern",
    "Konters": "Konter",
    "Kontexte": "Kontext",
    "Kontexten": "Kontext",
    "Kontextes": "Kontext",
    "Kontexts": "Kontext",
    "Kontinentale": "kontinental",
    "Kontinentalen": "Kontinentale",
    "Kontinente": "Kontinent",
    "Kontinenten": "Kontinent",
    "Kontinents": "Kontinent",
    "Kontinuierliche": "kontinuierlich",
    "Kontinuierlichen": "Kontinuierliche",
    "Kontinuierlicheren": "Kontinuierlichere",
    "Kontinuitäten": "Kontinuität",
    "Kontinuums": "Kontinuum",
    "Kontore": "Kontor",
    "Kontoren": "Kontor",
    "Kontors": "Kontor",
    "Kontos": "Konto",
    "Kontrabassisten": "Kontrabassist",
    "Kontradiktionen": "Kontradiktion",
    "Kontradiktorische": "kontradiktorisch",
    "Kontradiktorischen": "Kontradiktorische",
    "Kontrafagotte": "Kontrafagott",
    "Kontrafagotten": "Kontrafagott",
    "Kontrafagotts": "Kontrafagott",
    "Kontrahenten": "Kontrahent",
    "Kontrahierenden": "Kontrahierende",
    "Kontrahierens": "Kontrahieren",
    "Kontrahierte": "kontrahiert",
    "Kontrahierten": "Kontrahierte",
    "Kontraindikationen": "Kontraindikation",
    "Kontrakte": "Kontrakt",
    "Kontrakten": "Kontrakt",
    "Kontraktionen": "Kontraktion",
    "Kontrakts": "Kontrakt",
    "Kontrakturen": "Kontraktur",
    "Kontraproduktive": "kontraproduktiv",
    "Kontraproduktiven": "Kontraproduktive",
    "Kontraproduktiveren": "Kontraproduktivere",
    "Kontraste": "Kontrast",
    "Kontrasten": "Kontrast",
    "Kontrastes": "Kontrast",
    "Kontrastiere": "kontrastieren",
    "Kontrastierenden": "Kontrastierende",
    "Kontrastierenderen": "Kontrastierendere",
    "Kontrastierens": "Kontrastieren",
    "Kontrastierte": "kontrastiert",
    "Kontrastierten": "Kontrastierte",
    "Kontrastierteren": "Kontrastiertere",
    "Kontrastiertesten": "Kontrastierteste",
    "Kontrastiven": "Kontrastive",
    "Kontrastiveren": "Kontrastivere",
    "Kontrastivsten": "Kontrastivste",
    "Kontrastreichen": "Kontrastreiche",
    "Kontrastreicheren": "Kontrastreichere",
    "Kontrastreichsten": "Kontrastreichste",
    "Kontrasts": "Kontrast",
    "Kontributionen": "Kontribution",
    "Kontrollabschnitte": "Kontrollabschnitt",
    "Kontrollabschnitten": "Kontrollabschnitt",
    "Kontrollabschnitts": "Kontrollabschnitt",
    "Kontrollbüros": "Kontrollbüro",
    "Kontrollen": "Kontrolle",
    "Kontrollgruppen": "Kontrollgruppe",
    "Kontrollierenden": "Kontrollierende",
    "Kontrollierens": "Kontrollieren",
    "Kontrollierte": "kontrolliert",
    "Kontrollierten": "Kontrollierte",
    "Kontrollierteren": "Kontrolliertere",
    "Kontrolliertesten": "Kontrollierteste",
    "Kontrollinstrumente": "Kontrollinstrument",
    "Kontrollinstrumenten": "Kontrollinstrument",
    "Kontrollinstrumentes": "Kontrollinstrument",
    "Kontrollinstruments": "Kontrollinstrument",
    "Kontroverse": "kontrovers",
    "Kontroversen": "Kontroverse",
    "Kontroverseren": "Kontroversere",
    "Kontroversesten": "Kontroverseste",
    "Konträren": "Konträre",
    "Konträreren": "Konträrere",
    "Konträrsten": "Konträrste",
    "Konturen": "Kontur",
    "Konventionelle": "konventionell",
    "Konventionellen": "Konventionelle",
    "Konventionelleren": "Konventionellere",
    "Konventionellsten": "Konventionellste",
    "Konventionen": "Konvention",
    "Konversationen": "Konversation",
    "Konversionen": "Konversion",
    "Konvertierenden": "Konvertierende",
    "Konvertierens": "Konvertieren",
    "Konvertierte": "konvertiert",
    "Konvertierten": "Konvertierte",
    "Konzentrate": "Konzentrat",
    "Konzentraten": "Konzentrat",
    "Konzentrates": "Konzentrat",
    "Konzentrationen": "Konzentration",
    "Konzentrats": "Konzentrat",
    "Konzentriere": "konzentrieren",
    "Konzentrierenden": "Konzentrierende",
    "Konzentrierenderen": "Konzentrierendere",
    "Konzentrierens": "Konzentrieren",
    "Konzentrierte": "konzentriert",
    "Konzentrierten": "Konzentrierte",
    "Konzentrierteren": "Konzentriertere",
    "Konzentriertesten": "Konzentrierteste",
    "Konzepte": "Konzept",
    "Konzepten": "Konzept",
    "Konzeptes": "Konzept",
    "Konzeptionelle": "konzeptionell",
    "Konzeptionellen": "Konzeptionelle",
    "Konzeptionen": "Konzeption",
    "Konzepts": "Konzept",
    "Konzerne": "Konzern",
    "Konzernen": "Konzern",
    "Konzernes": "Konzern",
    "Konzerns": "Konzern",
    "Konzerte": "Konzert",
    "Konzerten": "Konzert",
    "Konzertierte": "konzertiert",
    "Konzertierten": "Konzertierte",
    "Konzertinas": "Konzertina",
    "Konzertreife": "konzertreif",
    "Konzertreifen": "Konzertreife",
    "Konzerts": "Konzert",
    "Konzessionen": "Konzession",
    "Konzessive": "konzessiv",
    "Konzessiven": "Konzessive",
    "Konzipienten": "Konzipient",
    "Konzipierenden": "Konzipierende",
    "Konzipierens": "Konzipieren",
    "Konzipierte": "konzipiert",
    "Konzipierten": "Konzipierte",
    "Kooperationen": "Kooperation",
    "Kooperative": "kooperativ",
    "Kooperativen": "Kooperative",
    "Kooperatore": "Kooperator",
    "Kooperatoren": "Kooperator",
    "Kooperators": "Kooperator",
    "Kooperierenden": "Kooperierende",
    "Kooperierenderen": "Kooperierendere",
    "Kooperierendsten": "Kooperierendste",
    "Kooperierens": "Kooperieren",
    "Kooperierte": "kooperiert",
    "Kooperierten": "Kooperierte",
    "Kooperierteren": "Kooperiertere",
    "Kooperiertesten": "Kooperierteste",
    "Koordinationen": "Koordination",
    "Koordinierenden": "Koordinierende",
    "Koordinierens": "Koordinieren",
    "Koordinierte": "koordiniert",
    "Koordinierten": "Koordinierte",
    "Kopenhagens": "Kopenhagen",
    "Kopfe": "Kopf",
    "Kopfes": "Kopf",
    "Kopfgesteuerten": "Kopfgesteuerte",
    "Kopflastigen": "Kopflastige",
    "Kopflastigeren": "Kopflastigere",
    "Kopflastigsten": "Kopflastigste",
    "Kopflosen": "Kopflose",
    "Kopfloseren": "Kopflosere",
    "Kopflosesten": "Kopfloseste",
    "Kopfs": "Kopf",
    "Kopfschüttelnde": "kopfschüttelnd",
    "Kopfschüttelnden": "Kopfschüttelnde",
    "Kopfzerbrechens": "Kopfzerbrechen",
    "Kopien": "Kopie",
    "Kopierenden": "Kopierende",
    "Kopierens": "Kopieren",
    "Kopierern": "Kopierer",
    "Kopierers": "Kopierer",
    "Kopierte": "kopiert",
    "Kopierten": "Kopierte",
    "Kopiloten": "Kopilot",
    "Koppel": "koppeln",
    "Koppeln": "Koppel",
    "Koppelnden": "Koppelnde",
    "Koppelns": "Koppeln",
    "Koppels": "Koppel",
    "Kopulationen": "Kopulation",
    "Korallen": "Koralle",
    "Korbe": "Korb",
    "Korbs": "Korb",
    "Koreferenzen": "Koreferenz",
    "Korinthen": "Korinthe",
    "Korinthern": "Korinther",
    "Korinthers": "Korinther",
    "Kork": "korken",
    "Korke": "korken",
    "Korken": "Kork",
    "Korkenden": "Korkende",
    "Korkens": "Korken",
    "Korkigen": "Korkige",
    "Korkigeren": "Korkigere",
    "Korkigsten": "Korkigste",
    "Korks": "Kork",
    "Korne": "Korn",
    "Kornes": "Korn",
    "Korns": "Korn",
    "Korpora": "Korpus",
    "Korporationen": "Korporation",
    "Korpulente": "korpulent",
    "Korpulenten": "Korpulente",
    "Korpulenteren": "Korpulentere",
    "Korpulentesten": "Korpulenteste",
    "Korrekten": "Korrekte",
    "Korrekteren": "Korrektere",
    "Korrektesten": "Korrekteste",
    "Korrekturen": "Korrektur",
    "Korrelierenden": "Korrelierende",
    "Korrelierenderen": "Korrelierendere",
    "Korrelierendsten": "Korrelierendste",
    "Korrelierens": "Korrelieren",
    "Korrelierte": "korreliert",
    "Korrelierten": "Korrelierte",
    "Korrelierteren": "Korreliertere",
    "Korreliertesten": "Korrelierteste",
    "Korrepetitore": "Korrepetitor",
    "Korrepetitoren": "Korrepetitor",
    "Korrepetitors": "Korrepetitor",
    "Korrespondenten": "Korrespondent",
    "Korrespondentinnen": "Korrespondentin",
    "Korrigierenden": "Korrigierende",
    "Korrigierens": "Korrigieren",
    "Korrigierte": "korrigiert",
    "Korrigierten": "Korrigierte",
    "Korrosionen": "Korrosion",
    "Korrumpierenden": "Korrumpierende",
    "Korrumpierenderen": "Korrumpierendere",
    "Korrumpierendsten": "Korrumpierendste",
    "Korrumpierens": "Korrumpieren",
    "Korrumpierte": "korrumpiert",
    "Korrumpierten": "Korrumpierte",
    "Korrumpierteren": "Korrumpiertere",
    "Korrumpiertesten": "Korrumpierteste",
    "Korrupten": "Korrupte",
    "Korrupteren": "Korruptere",
    "Korruptesten": "Korrupteste",
    "Korruptionen": "Korruption",
    "Korsagen": "Korsage",
    "Korsen": "Korse",
    "Korsetts": "Korsett",
    "Korsische": "korsisch",
    "Korsischen": "Korsische",
    "Korsos": "Korso",
    "Kortisons": "Kortison",
    "Korvetten": "Korvette",
    "Koschere": "koscher",
    "Koscheren": "Koschere",
    "Koschereren": "Koscherere",
    "Koschersten": "Koscherste",
    "Kosenamen": "Kosename",
    "Koseworte": "Kosewort",
    "Kosewortes": "Kosewort",
    "Koseworts": "Kosewort",
    "Kosewörter": "Kosewort",
    "Kosewörtern": "Kosewort",
    "Kosmetische": "kosmetisch",
    "Kosmetischen": "Kosmetische",
    "Kosmischen": "Kosmische",
    "Kosmobiologischen": "Kosmobiologische",
    "Kosmographischen": "Kosmographische",
    "Kosmologischen": "Kosmologische",
    "Kosmonauten": "Kosmonaut",
    "Kosmopoliten": "Kosmopolit",
    "Kosmopolitische": "kosmopolitisch",
    "Kosmopolitischen": "Kosmopolitische",
    "Kosovos": "Kosovo",
    "Kostbare": "kostbar",
    "Kostbaren": "Kostbare",
    "Kostbareren": "Kostbarere",
    "Kostbarkeiten": "Kostbarkeit",
    "Kostbarste": "kostbar",
    "Kostbarsten": "Kostbarste",
    "Kostenbewußten": "Kostenbewußte",
    "Kostenbewußteren": "Kostenbewußtere",
    "Kostenbewußtesten": "Kostenbewußteste",
    "Kostenden": "Kostende",
    "Kostenfreien": "Kostenfreie",
    "Kostenfreieren": "Kostenfreiere",
    "Kostenfreiesten": "Kostenfreieste",
    "Kostengünstigen": "Kostengünstige",
    "Kostengünstigeren": "Kostengünstigere",
    "Kostengünstigsten": "Kostengünstigste",
    "Kostenintensiven": "Kostenintensive",
    "Kostenlosen": "Kostenlose",
    "Kostenpflichtigen": "Kostenpflichtige",
    "Kostgelde": "Kostgeld",
    "Kostgeldes": "Kostgeld",
    "Kostgelds": "Kostgeld",
    "Kostgeschäfte": "Kostgeschäft",
    "Kostgeschäften": "Kostgeschäft",
    "Kostgeschäfts": "Kostgeschäft",
    "Kostgängern": "Kostgänger",
    "Kostgängers": "Kostgänger",
    "Kostspieligen": "Kostspielige",
    "Kostspieligeren": "Kostspieligere",
    "Kostspieligsten": "Kostspieligste",
    "Kostverächtern": "Kostverächter",
    "Kostverächters": "Kostverächter",
    "Kostüme": "Kostüm",
    "Kostümen": "Kostüm",
    "Kostümierenden": "Kostümierende",
    "Kostümierenderen": "Kostümierendere",
    "Kostümierendsten": "Kostümierendste",
    "Kostümierens": "Kostümieren",
    "Kostümierte": "kostümiert",
    "Kostümierten": "Kostümierte",
    "Kostümierteren": "Kostümiertere",
    "Kostümiertesten": "Kostümierteste",
    "Kostümproben": "Kostümprobe",
    "Kostüms": "Kostüm",
    "Kote": "Kot",
    "Kotes": "Kot",
    "Kots": "Kot",
    "Kotze": "kotzen",
    "Kotzen": "Kotze",
    "Kotzenden": "Kotzende",
    "Kotzenderen": "Kotzendere",
    "Kotzendsten": "Kotzendste",
    "Kotzens": "Kotzen",
    "Kotzüblen": "Kotzüble",
    "Krabbeligen": "Krabbelige",
    "Krabbeligeren": "Krabbeligere",
    "Krabbeligsten": "Krabbeligste",
    "Krabbelnden": "Krabbelnde",
    "Krabbelnderen": "Krabbelndere",
    "Krabbelndsten": "Krabbelndste",
    "Krabbelns": "Krabbeln",
    "Krabbelstuben": "Krabbelstube",
    "Krabben": "Krabbe",
    "Krabbes": "Krabbe",
    "Krach": "krachen",
    "Krachenden": "Krachende",
    "Krachenderen": "Krachendere",
    "Krachendsten": "Krachendste",
    "Krachens": "Krachen",
    "Kracherln": "Kracherl",
    "Kracherls": "Kracherl",
    "Krachern": "Kracher",
    "Krachers": "Kracher",
    "Krachs": "Krach",
    "Kraftarme": "Kraftarm",
    "Kraftarmen": "Kraftarm",
    "Kraftarms": "Kraftarm",
    "Kraftfahrzeuge": "Kraftfahrzeug",
    "Kraftfahrzeugen": "Kraftfahrzeug",
    "Kraftfahrzeuges": "Kraftfahrzeug",
    "Kraftfahrzeugs": "Kraftfahrzeug",
    "Kraftlose": "kraftlos",
    "Kraftlosen": "Kraftlose",
    "Kraftloseren": "Kraftlosere",
    "Kraftloserklärungen": "Kraftloserklärung",
    "Kraftlosesten": "Kraftloseste",
    "Kraftmeiern": "Kraftmeier",
    "Kraftmeiers": "Kraftmeier",
    "Kraftstoffe": "Kraftstoff",
    "Kraftstoffen": "Kraftstoff",
    "Kraftstoffs": "Kraftstoff",
    "Kraftstrotzende": "kraftstrotzend",
    "Kraftstrotzenden": "Kraftstrotzende",
    "Kraftstrotzenderen": "Kraftstrotzendere",
    "Kraftvollen": "Kraftvolle",
    "Kraftvolleren": "Kraftvollere",
    "Kraftvollsten": "Kraftvollste",
    "Kraftwerke": "Kraftwerk",
    "Kraftwerken": "Kraftwerk",
    "Kraftwerkes": "Kraftwerk",
    "Kraftwerks": "Kraftwerk",
    "Kragens": "Kragen",
    "Krakeelenden": "Krakeelende",
    "Krakeelenderen": "Krakeelendere",
    "Krakeelendsten": "Krakeelendste",
    "Krakeelens": "Krakeelen",
    "Krakeelte": "krakeelt",
    "Krakeelten": "Krakeelte",
    "Krakeligen": "Krakelige",
    "Krakeligeren": "Krakeligere",
    "Krakeligsten": "Krakeligste",
    "Krakeln": "Krakel",
    "Krakels": "Krakel",
    "Kraken": "Krake",
    "Kralle": "krallen",
    "Krallen": "Kralle",
    "Krallenden": "Krallende",
    "Krallenderen": "Krallendere",
    "Krallendsten": "Krallendste",
    "Krallens": "Krallen",
    "Kram": "kramen",
    "Kramenden": "Kramende",
    "Kramenderen": "Kramendere",
    "Kramendsten": "Kramendste",
    "Kramens": "Kramen",
    "Krammigs": "Krammig",
    "Krampen": "Krampe",
    "Krampf": "krampfen",
    "Krampfartige": "krampfartig",
    "Krampfartigen": "Krampfartige",
    "Krampfe": "krampfen",
    "Krampfenden": "Krampfende",
    "Krampfens": "Krampfen",
    "Krampfes": "Krampf",
    "Krampfhaften": "Krampfhafte",
    "Krampflösenden": "Krampflösende",
    "Krampflösenderen": "Krampflösendere",
    "Krampflösendsten": "Krampflösendste",
    "Krampfs": "Krampf",
    "Krams": "Kram",
    "Krane": "Kran",
    "Kranes": "Kran",
    "Kraniche": "Kranich",
    "Kranichen": "Kranich",
    "Kraniches": "Kranich",
    "Kranichs": "Kranich",
    "Kranke": "kranken",
    "Kranken": "Kranke",
    "Krankenden": "Krankende",
    "Krankengeschichten": "Krankengeschichte",
    "Krankenhausreife": "krankenhausreif",
    "Krankenhausreifen": "Krankenhausreife",
    "Krankenkassen": "Krankenkasse",
    "Krankenpflegen": "Krankenpflege",
    "Krankens": "Kranken",
    "Krankfeiernden": "Krankfeiernde",
    "Krankfeiernderen": "Krankfeierndere",
    "Krankfeierndsten": "Krankfeierndste",
    "Krankfeierns": "Krankfeiern",
    "Krankgefeierten": "Krankgefeierte",
    "Krankgefeierteren": "Krankgefeiertere",
    "Krankgelachten": "Krankgelachte",
    "Krankgeschriebenen": "Krankgeschriebene",
    "Krankhaften": "Krankhafte",
    "Krankhafteren": "Krankhaftere",
    "Krankhaftesten": "Krankhafteste",
    "Krankheiten": "Krankheit",
    "Kranklachenden": "Kranklachende",
    "Kranklachenderen": "Kranklachendere",
    "Kranklachendsten": "Kranklachendste",
    "Kranklachens": "Kranklachen",
    "Krankschreibenden": "Krankschreibende",
    "Krankschreibens": "Krankschreiben",
    "Krans": "Kran",
    "Kranze": "Kranz",
    "Kranzes": "Kranz",
    "Krapfens": "Krapfen",
    "Krasse": "kraß",
    "Krassen": "Krasse",
    "Krasseren": "Krassere",
    "Krassesten": "Krasseste",
    "Kratern": "Krater",
    "Kraters": "Krater",
    "Kratzbürsten": "Kratzbürste",
    "Kratzbürstige": "kratzbürstig",
    "Kratzbürstigen": "Kratzbürstige",
    "Kratzbürstigeren": "Kratzbürstigere",
    "Kratzbürstigsten": "Kratzbürstigste",
    "Kratzeisens": "Kratzeisen",
    "Kratzenden": "Kratzende",
    "Kratzenderen": "Kratzendere",
    "Kratzendsten": "Kratzendste",
    "Kratzens": "Kratzen",
    "Kratzern": "Kratzer",
    "Kratzers": "Kratzer",
    "Kratzigen": "Kratzige",
    "Kratzigeren": "Kratzigere",
    "Kratzigsten": "Kratzigste",
    "Kraulenden": "Kraulende",
    "Kraulens": "Kraulen",
    "Kraulstils": "Kraulstil",
    "Krausen": "Krause",
    "Krausenden": "Krausende",
    "Krausenderen": "Krausendere",
    "Krausendsten": "Krausendste",
    "Krausens": "Krausen",
    "Krauses": "Krause",
    "Krausköpfigen": "Krausköpfige",
    "Kraute": "Kraut",
    "Krautes": "Kraut",
    "Krauts": "Kraut",
    "Krawalle": "Krawall",
    "Krawallen": "Krawall",
    "Krawalles": "Krawall",
    "Krawalls": "Krawall",
    "Krawatten": "Krawatte",
    "Kreationen": "Kreation",
    "Kreative": "kreativ",
    "Kreativen": "Kreative",
    "Kreativeren": "Kreativere",
    "Kreativsten": "Kreativste",
    "Krebse": "Krebs",
    "Krebsen": "Krebs",
    "Krebses": "Krebs",
    "Krebskranke": "krebskrank",
    "Krebskranken": "Krebskranke",
    "Kredenzenden": "Kredenzende",
    "Kredenzenderen": "Kredenzendere",
    "Kredenzendsten": "Kredenzendste",
    "Kredenzens": "Kredenzen",
    "Kredenzte": "kredenzt",
    "Kredenzten": "Kredenzte",
    "Kredenzteren": "Kredenztere",
    "Kredenztesten": "Kredenzteste",
    "Kredite": "Kredit",
    "Krediten": "Kredit",
    "Kredites": "Kredit",
    "Kreditfähige": "kreditfähig",
    "Kreditfähigen": "Kreditfähige",
    "Kredits": "Kredit",
    "Kreditunwürdige": "kreditunwürdig",
    "Kreditunwürdigen": "Kreditunwürdige",
    "Kreditwürdigen": "Kreditwürdige",
    "Kreditwürdigeren": "Kreditwürdigere",
    "Kreditwürdigsten": "Kreditwürdigste",
    "Kredos": "Kredo",
    "Krees": "Kree",
    "Krehbergs": "Krehberg",
    "Kreide": "kreiden",
    "Kreidebleichen": "Kreidebleiche",
    "Kreidebleicheren": "Kreidebleichere",
    "Kreidebleichsten": "Kreidebleichste",
    "Kreiden": "Kreide",
    "Kreidenden": "Kreidende",
    "Kreidens": "Kreiden",
    "Kreis": "kreisen",
    "Kreischenden": "Kreischende",
    "Kreischenderen": "Kreischendere",
    "Kreischendsten": "Kreischendste",
    "Kreischens": "Kreischen",
    "Kreise": "kreisen",
    "Kreiseln": "Kreisel",
    "Kreisels": "Kreisel",
    "Kreisen": "Kreis",
    "Kreisenden": "Kreisende",
    "Kreisens": "Kreisen",
    "Kreises": "Kreis",
    "Kreisfreien": "Kreisfreie",
    "Kreisförmigen": "Kreisförmige",
    "Kreislaufe": "Kreislauf",
    "Kreislaufes": "Kreislauf",
    "Kreislaufs": "Kreislauf",
    "Kreisläufe": "Kreislauf",
    "Kreisläufen": "Kreislauf",
    "Kreisrunde": "kreisrund",
    "Kreisrunden": "Kreisrunde",
    "Kremigen": "Kremige",
    "Kremigeren": "Kremigere",
    "Kremigsten": "Kremigste",
    "Kremls": "Kreml",
    "Krempel": "krempeln",
    "Krempeln": "Krempel",
    "Krempelnden": "Krempelnde",
    "Krempelns": "Krempeln",
    "Krempels": "Krempel",
    "Krempen": "Krempe",
    "Krepierenden": "Krepierende",
    "Krepierenderen": "Krepierendere",
    "Krepierendsten": "Krepierendste",
    "Krepierens": "Krepieren",
    "Krepierte": "krepiert",
    "Krepierten": "Krepierte",
    "Krepierteren": "Krepiertere",
    "Krepiertesten": "Krepierteste",
    "Krepps": "Krepp",
    "Kreuz": "kreuzen",
    "Kreuzdorne": "Kreuzdorn",
    "Kreuzdornen": "Kreuzdorn",
    "Kreuzdorns": "Kreuzdorn",
    "Kreuze": "kreuzen",
    "Kreuzen": "Kreuz",
    "Kreuzenden": "Kreuzende",
    "Kreuzens": "Kreuzen",
    "Kreuzern": "Kreuzer",
    "Kreuzers": "Kreuzer",
    "Kreuzes": "Kreuz",
    "Kreuzigenden": "Kreuzigende",
    "Kreuzigens": "Kreuzigen",
    "Kreuzungen": "Kreuzung",
    "Kreuzungsfreie": "kreuzungsfrei",
    "Kreuzungsfreien": "Kreuzungsfreie",
    "Kreuzzuge": "Kreuzzug",
    "Kreuzzugs": "Kreuzzug",
    "Kreuzzüge": "Kreuzzug",
    "Kreuzzügen": "Kreuzzug",
    "Kribbeligen": "Kribbelige",
    "Kribbeligeren": "Kribbeligere",
    "Kribbeligsten": "Kribbeligste",
    "Kribbelnden": "Kribbelnde",
    "Kribbelnderen": "Kribbelndere",
    "Kribbelndsten": "Kribbelndste",
    "Kribbelns": "Kribbeln",
    "Kriechenden": "Kriechende",
    "Kriechens": "Kriechen",
    "Kriechtiere": "Kriechtier",
    "Kriechtieren": "Kriechtier",
    "Kriechtieres": "Kriechtier",
    "Kriechtiers": "Kriechtier",
    "Krieg": "kriegen",
    "Kriege": "kriegen",
    "Kriegen": "Krieg",
    "Kriegenden": "Kriegende",
    "Kriegens": "Kriegen",
    "Kriegerische": "kriegerisch",
    "Kriegerischen": "Kriegerische",
    "Kriegerischeren": "Kriegerischere",
    "Kriegerischsten": "Kriegerischste",
    "Kriegern": "Krieger",
    "Kriegers": "Krieger",
    "Krieges": "Krieg",
    "Kriegführenden": "Kriegführende",
    "Kriegs": "Krieg",
    "Kriftelern": "Krifteler",
    "Kriftelers": "Krifteler",
    "Kriftels": "Kriftel",
    "Kriminale": "kriminal",
    "Kriminalen": "Kriminale",
    "Kriminalisierenden": "Kriminalisierende",
    "Kriminalisierenderen": "Kriminalisierendere",
    "Kriminalisierens": "Kriminalisieren",
    "Kriminalisierte": "kriminalisiert",
    "Kriminalisierten": "Kriminalisierte",
    "Kriminalisierteren": "Kriminalisiertere",
    "Kriminalistischen": "Kriminalistische",
    "Kriminalpolizeien": "Kriminalpolizei",
    "Kriminalromane": "Kriminalroman",
    "Kriminalromanen": "Kriminalroman",
    "Kriminalromans": "Kriminalroman",
    "Kriminelle": "kriminell",
    "Kriminellen": "Kriminelle",
    "Kriminelleren": "Kriminellere",
    "Kriminellsten": "Kriminellste",
    "Kriminologischen": "Kriminologische",
    "Krimis": "Krimi",
    "Krimsekte": "Krimsekt",
    "Krimsektes": "Krimsekt",
    "Krimsekts": "Krimsekt",
    "Kringelnden": "Kringelnde",
    "Kringelnderen": "Kringelndere",
    "Kringelndsten": "Kringelndste",
    "Kringelns": "Kringeln",
    "Kripos": "Kripo",
    "Krippen": "Krippe",
    "Kriselnden": "Kriselnde",
    "Kriselnderen": "Kriselndere",
    "Kriselndsten": "Kriselndste",
    "Kriselns": "Kriseln",
    "Krisen": "Krise",
    "Krisenanfällige": "krisenanfällig",
    "Krisenanfälligen": "Krisenanfällige",
    "Krisenanfälligeren": "Krisenanfälligere",
    "Krisenfesten": "Krisenfeste",
    "Krisenfesteren": "Krisenfestere",
    "Krisenfestesten": "Krisenfesteste",
    "Krisengeschüttelten": "Krisengeschüttelte",
    "Krisengeschüttelteren": "Krisengeschütteltere",
    "Kristalle": "Kristall",
    "Kristallen": "Kristall",
    "Kristallisationen": "Kristallisation",
    "Kristallisierenden": "Kristallisierende",
    "Kristallisierens": "Kristallisieren",
    "Kristallisierte": "kristallisiert",
    "Kristallisierten": "Kristallisierte",
    "Kristallisierungen": "Kristallisierung",
    "Kristalls": "Kristall",
    "Kriterien": "Kriterium",
    "Kriteriums": "Kriterium",
    "Kritiken": "Kritik",
    "Kritikern": "Kritiker",
    "Kritikers": "Kritiker",
    "Kritiklose": "kritiklos",
    "Kritiklosen": "Kritiklose",
    "Kritikloseren": "Kritiklosere",
    "Kritiklosesten": "Kritikloseste",
    "Kritischen": "Kritische",
    "Kritischeren": "Kritischere",
    "Kritischsten": "Kritischste",
    "Kritisierenden": "Kritisierende",
    "Kritisierenderen": "Kritisierendere",
    "Kritisierendsten": "Kritisierendste",
    "Kritisierens": "Kritisieren",
    "Kritisierte": "kritisiert",
    "Kritisierten": "Kritisierte",
    "Kritisierteren": "Kritisiertere",
    "Kritisiertesten": "Kritisierteste",
    "Kritzeleien": "Kritzelei",
    "Kritzelige": "kritzelig",
    "Kritzeligen": "Kritzelige",
    "Kritzeligeren": "Kritzeligere",
    "Kritzeligsten": "Kritzeligste",
    "Kritzelnden": "Kritzelnde",
    "Kritzelns": "Kritzeln",
    "Kroaten": "Kroate",
    "Kroatiens": "Kroatien",
    "Kroatische": "kroatisch",
    "Kroatischen": "Kroatische",
    "Kroketten": "Krokette",
    "Krokodile": "Krokodil",
    "Krokodilen": "Krokodil",
    "Krokodiles": "Krokodil",
    "Krokodils": "Krokodil",
    "Kronbergs": "Kronberg",
    "Kronen": "Krone",
    "Kronenkorkens": "Kronenkorken",
    "Kronerben": "Kronerbe",
    "Krongute": "Krongut",
    "Krongutes": "Krongut",
    "Kronguts": "Krongut",
    "Krongüter": "Krongut",
    "Krongütern": "Krongut",
    "Kronleuchtern": "Kronleuchter",
    "Kronleuchters": "Kronleuchter",
    "Kronprinzessinnen": "Kronprinzessin",
    "Kronrade": "Kronrad",
    "Kronrades": "Kronrad",
    "Kronrads": "Kronrad",
    "Kronräder": "Kronrad",
    "Kronrädern": "Kronrad",
    "Kronzeugen": "Kronzeuge",
    "Kropfe": "Kropf",
    "Kropfes": "Kropf",
    "Kropfs": "Kropf",
    "Krotzenburgs": "Krotzenburg",
    "Kruge": "Krug",
    "Kruges": "Krug",
    "Krugs": "Krug",
    "Krullen": "Krulle",
    "Krummbiegenden": "Krummbiegende",
    "Krummbiegens": "Krummbiegen",
    "Krummgebogenen": "Krummgebogene",
    "Krummgebogeneren": "Krummgebogenere",
    "Krummgebogensten": "Krummgebogenste",
    "Krummgelachten": "Krummgelachte",
    "Krummgelegten": "Krummgelegte",
    "Krummgelegteren": "Krummgelegtere",
    "Krummgelegtesten": "Krummgelegteste",
    "Krummgenommenen": "Krummgenommene",
    "Krummhorne": "Krummhorn",
    "Krummhorns": "Krummhorn",
    "Krummhörner": "Krummhorn",
    "Krummhörnern": "Krummhorn",
    "Krummlachenden": "Krummlachende",
    "Krummlachenderen": "Krummlachendere",
    "Krummlachendsten": "Krummlachendste",
    "Krummlachens": "Krummlachen",
    "Krummlegenden": "Krummlegende",
    "Krummlegenderen": "Krummlegendere",
    "Krummlegendsten": "Krummlegendste",
    "Krummlegens": "Krummlegen",
    "Krummnehmenden": "Krummnehmende",
    "Krummnehmens": "Krummnehmen",
    "Krummschnabels": "Krummschnabel",
    "Krummschnäbel": "Krummschnabel",
    "Krummschnäbeln": "Krummschnabel",
    "Krupps": "Krupp",
    "Kruses": "Kruse",
    "Krusten": "Kruste",
    "Kryptische": "kryptisch",
    "Kryptischen": "Kryptische",
    "Kryptischeren": "Kryptischere",
    "Kryptischsten": "Kryptischste",
    "Kryptografien": "Kryptografie",
    "Kryptogramme": "Kryptogramm",
    "Kryptogrammen": "Kryptogramm",
    "Kryptogramms": "Kryptogramm",
    "Kryptographien": "Kryptographie",
    "Kryptons": "Krypton",
    "Krächzenden": "Krächzende",
    "Krächzenderen": "Krächzendere",
    "Krächzendsten": "Krächzendste",
    "Krächzens": "Krächzen",
    "Kräfte": "Kraft",
    "Kräften": "Kraft",
    "Kräftige": "kräftigen",
    "Kräftigen": "Kräftige",
    "Kräftigenden": "Kräftigende",
    "Kräftigens": "Kräftigen",
    "Kräftigeren": "Kräftigere",
    "Kräftigsten": "Kräftigste",
    "Kräftigungen": "Kräftigung",
    "Krähenden": "Krähende",
    "Krähens": "Krähen",
    "Krämern": "Krämer",
    "Krämers": "Krämer",
    "Krämpfe": "Krampf",
    "Krämpfen": "Krampf",
    "Kräne": "Kran",
    "Kränen": "Kran",
    "Kränklichen": "Kränkliche",
    "Kränklicheren": "Kränklichere",
    "Kränklichsten": "Kränklichste",
    "Kränkungen": "Kränkung",
    "Kränze": "kränzen",
    "Kränzen": "Kranz",
    "Kränzenden": "Kränzende",
    "Kränzens": "Kränzen",
    "Krätschmers": "Krätschmer",
    "Krätzen": "Krätze",
    "Kräuselnden": "Kräuselnde",
    "Kräuselnderen": "Kräuselndere",
    "Kräuselndsten": "Kräuselndste",
    "Kräuselns": "Kräuseln",
    "Kräutchens": "Kräutchen",
    "Kräuter": "Kraut",
    "Kräutern": "Kraut",
    "Kräutleins": "Kräutlein",
    "Krönchens": "Krönchen",
    "Krönenden": "Krönende",
    "Krönens": "Krönen",
    "Krönings": "Kröning",
    "Krönungen": "Krönung",
    "Kröpfchens": "Kröpfchen",
    "Kröpfe": "Kropf",
    "Kröpfen": "Kropf",
    "Kröten": "Kröte",
    "Krücken": "Krücke",
    "Krüge": "Krug",
    "Krügen": "Krug",
    "Krügers": "Krüger",
    "Krügleins": "Krüglein",
    "Krümeligen": "Krümelige",
    "Krümeligeren": "Krümeligere",
    "Krümeligsten": "Krümeligste",
    "Krümelnden": "Krümelnde",
    "Krümelnderen": "Krümelndere",
    "Krümelndsten": "Krümelndste",
    "Krümelns": "Krümeln",
    "Krümmenden": "Krümmende",
    "Krümmenderen": "Krümmendere",
    "Krümmendsten": "Krümmendste",
    "Krümmens": "Krümmen",
    "Krümmungen": "Krümmung",
    "Krümpelmanns": "Krümpelmann",
    "Krüppeln": "Krüppel",
    "Krüppels": "Krüppel",
    "Kubanische": "kubanisch",
    "Kubanischen": "Kubanische",
    "Kubas": "Kuba",
    "Kubikdezimetern": "Kubikdezimeter",
    "Kubikdezimeters": "Kubikdezimeter",
    "Kubikhektometern": "Kubikhektometer",
    "Kubikhektometers": "Kubikhektometer",
    "Kubikkilometern": "Kubikkilometer",
    "Kubikkilometers": "Kubikkilometer",
    "Kubikmetern": "Kubikmeter",
    "Kubikmeters": "Kubikmeter",
    "Kubikmillimetern": "Kubikmillimeter",
    "Kubikmillimeters": "Kubikmillimeter",
    "Kubikwurzeln": "Kubikwurzel",
    "Kubikzahlen": "Kubikzahl",
    "Kubikzentimetern": "Kubikzentimeter",
    "Kubikzentimeters": "Kubikzentimeter",
    "Kubische": "kubisch",
    "Kubischen": "Kubische",
    "Kuchens": "Kuchen",
    "Kuckucke": "Kuckuck",
    "Kuckucken": "Kuckuck",
    "Kuckuckes": "Kuckuck",
    "Kuckucks": "Kuckuck",
    "Kugel": "kugeln",
    "Kugelfesten": "Kugelfeste",
    "Kugelfesteren": "Kugelfestere",
    "Kugelfestesten": "Kugelfesteste",
    "Kugeligen": "Kugelige",
    "Kugeln": "Kugel",
    "Kugelnden": "Kugelnde",
    "Kugelns": "Kugeln",
    "Kugelregens": "Kugelregen",
    "Kugelrunde": "kugelrund",
    "Kugelrunden": "Kugelrunde",
    "Kugelschreibern": "Kugelschreiber",
    "Kugelschreibers": "Kugelschreiber",
    "Kugelsichere": "kugelsicher",
    "Kugelsicheren": "Kugelsichere",
    "Kugelsichereren": "Kugelsicherere",
    "Kugelsichersten": "Kugelsicherste",
    "Kugelstoßens": "Kugelstoßen",
    "Kuhblumen": "Kuhblume",
    "Kuhlen": "Kuhle",
    "Kulante": "kulant",
    "Kulanten": "Kulante",
    "Kulanteren": "Kulantere",
    "Kulantesten": "Kulanteste",
    "Kulinarischen": "Kulinarische",
    "Kulinarischeren": "Kulinarischere",
    "Kulinarischsten": "Kulinarischste",
    "Kulis": "Kuli",
    "Kulissen": "Kulisse",
    "Kulminationen": "Kulmination",
    "Kulte": "Kult",
    "Kulten": "Kult",
    "Kultivierenden": "Kultivierende",
    "Kultivierenderen": "Kultivierendere",
    "Kultivierendsten": "Kultivierendste",
    "Kultivierens": "Kultivieren",
    "Kultivierte": "kultiviert",
    "Kultivierten": "Kultivierte",
    "Kultivierteren": "Kultiviertere",
    "Kultiviertesten": "Kultivierteste",
    "Kults": "Kult",
    "Kultstätten": "Kultstätte",
    "Kulturelle": "kulturell",
    "Kulturellen": "Kulturelle",
    "Kulturen": "Kultur",
    "Kulturhistorische": "kulturhistorisch",
    "Kulturhistorischen": "Kulturhistorische",
    "Kultusministerien": "Kultusministerium",
    "Kultusministeriums": "Kultusministerium",
    "Kultusministern": "Kultusminister",
    "Kultusministers": "Kultusminister",
    "Kummern": "Kummer",
    "Kummers": "Kummer",
    "Kumpels": "Kumpel",
    "Kumulationen": "Kumulation",
    "Kumulierenden": "Kumulierende",
    "Kumulierens": "Kumulieren",
    "Kumulierte": "kumuliert",
    "Kumulierten": "Kumulierte",
    "Kunden": "Kunde",
    "Kundgebenden": "Kundgebende",
    "Kundgebens": "Kundgeben",
    "Kundgebungen": "Kundgebung",
    "Kundgegebenen": "Kundgegebene",
    "Kundigen": "Kundige",
    "Kundigeren": "Kundigere",
    "Kundigsten": "Kundigste",
    "Kundinnen": "Kundin",
    "Kundschaften": "Kundschaft",
    "Kundschaftenden": "Kundschaftende",
    "Kundschaftens": "Kundschaften",
    "Kundschaftern": "Kundschafter",
    "Kundschafters": "Kundschafter",
    "Kungeleien": "Kungelei",
    "Kungelnden": "Kungelnde",
    "Kungelnderen": "Kungelndere",
    "Kungelndsten": "Kungelndste",
    "Kungelns": "Kungeln",
    "Kunkels": "Kunkel",
    "Kunstgerechte": "kunstgerecht",
    "Kunstgerechten": "Kunstgerechte",
    "Kunststoffe": "Kunststoff",
    "Kunststoffen": "Kunststoff",
    "Kunststoffes": "Kunststoff",
    "Kunststoffs": "Kunststoff",
    "Kunstvolle": "kunstvoll",
    "Kunstvollen": "Kunstvolle",
    "Kunstvolleren": "Kunstvollere",
    "Kunstvollsten": "Kunstvollste",
    "Kupfern": "Kupfer",
    "Kupfers": "Kupfer",
    "Kupferstechern": "Kupferstecher",
    "Kupferstechers": "Kupferstecher",
    "Kuppel": "kuppeln",
    "Kuppeln": "Kuppel",
    "Kuppelnden": "Kuppelnde",
    "Kuppelns": "Kuppeln",
    "Kuppen": "Kuppe",
    "Kupplerischen": "Kupplerische",
    "Kuratore": "Kurator",
    "Kuratoren": "Kurator",
    "Kurators": "Kurator",
    "Kurbel": "kurbeln",
    "Kurbeln": "Kurbel",
    "Kurbelnden": "Kurbelnde",
    "Kurbelnderen": "Kurbelndere",
    "Kurbelndsten": "Kurbelndste",
    "Kurbelns": "Kurbeln",
    "Kurden": "Kurde",
    "Kurdische": "kurdisch",
    "Kurdischen": "Kurdische",
    "Kurdistans": "Kurdistan",
    "Kuren": "Kur",
    "Kurfürsten": "Kurfürst",
    "Kurfürstliche": "kurfürstlich",
    "Kurfürstlichen": "Kurfürstliche",
    "Kurier": "kurieren",
    "Kuriere": "kurieren",
    "Kurieren": "Kurier",
    "Kurierenden": "Kurierende",
    "Kurierens": "Kurieren",
    "Kuriers": "Kurier",
    "Kurierte": "kuriert",
    "Kurierten": "Kurierte",
    "Kuriosen": "Kuriose",
    "Kurioseren": "Kuriosere",
    "Kuriosesten": "Kurioseste",
    "Kuriositäten": "Kuriosität",
    "Kurse": "Kurs",
    "Kursen": "Kurs",
    "Kurses": "Kurs",
    "Kursierenden": "Kursierende",
    "Kursierenderen": "Kursierendere",
    "Kursierendsten": "Kursierendste",
    "Kursierens": "Kursieren",
    "Kursierte": "kursiert",
    "Kursierten": "Kursierte",
    "Kursiven": "Kursive",
    "Kursorischen": "Kursorische",
    "Kurtaxen": "Kurtaxe",
    "Kurts": "Kurt",
    "Kurve": "kurven",
    "Kurven": "Kurve",
    "Kurvenden": "Kurvende",
    "Kurvens": "Kurven",
    "Kurvigen": "Kurvige",
    "Kurvigeren": "Kurvigere",
    "Kurvigsten": "Kurvigste",
    "Kurzarbeiten": "Kurzarbeit",
    "Kurzarbeitenden": "Kurzarbeitende",
    "Kurzarbeitens": "Kurzarbeiten",
    "Kurzatmigen": "Kurzatmige",
    "Kurzausgaben": "Kurzausgabe",
    "Kurze": "kurz",
    "Kurzen": "Kurze",
    "Kurzfristigen": "Kurzfristige",
    "Kurzfristigeren": "Kurzfristigere",
    "Kurzfristigsten": "Kurzfristigste",
    "Kurzgearbeiteten": "Kurzgearbeitete",
    "Kurzgehaltenen": "Kurzgehaltene",
    "Kurzgehalteneren": "Kurzgehaltenere",
    "Kurzgehaltensten": "Kurzgehaltenste",
    "Kurzgeschlossenen": "Kurzgeschlossene",
    "Kurzhaltenden": "Kurzhaltende",
    "Kurzhaltenderen": "Kurzhaltendere",
    "Kurzhaltendsten": "Kurzhaltendste",
    "Kurzhaltens": "Kurzhalten",
    "Kurzlebigen": "Kurzlebige",
    "Kurzlebigeren": "Kurzlebigere",
    "Kurzlebigsten": "Kurzlebigste",
    "Kurzschließenden": "Kurzschließende",
    "Kurzschließens": "Kurzschließen",
    "Kurzsichtigen": "Kurzsichtige",
    "Kurzsichtigeren": "Kurzsichtigere",
    "Kurzsichtigsten": "Kurzsichtigste",
    "Kurzweilige": "kurzweilig",
    "Kurzweiligen": "Kurzweilige",
    "Kurzweiligeren": "Kurzweiligere",
    "Kurzweiligsten": "Kurzweiligste",
    "Kurzwochen": "Kurzwoche",
    "Kurzworte": "Kurzwort",
    "Kurzwortes": "Kurzwort",
    "Kurzworts": "Kurzwort",
    "Kurzwörter": "Kurzwort",
    "Kurzwörtern": "Kurzwort",
    "Kurzzeitige": "kurzzeitig",
    "Kurzzeitigen": "Kurzzeitige",
    "Kurzärmligen": "Kurzärmlige",
    "Kuschelnden": "Kuschelnde",
    "Kuschelnderen": "Kuschelndere",
    "Kuschelndsten": "Kuschelndste",
    "Kuschelns": "Kuscheln",
    "Kuscheltiere": "Kuscheltier",
    "Kuscheltieren": "Kuscheltier",
    "Kuscheltieres": "Kuscheltier",
    "Kuscheltiers": "Kuscheltier",
    "Kuschenden": "Kuschende",
    "Kuschens": "Kuschen",
    "Kusinen": "Kusine",
    "Kusse": "Kuß",
    "Kusses": "Kuß",
    "Kutschen": "Kutsche",
    "Kutschern": "Kutscher",
    "Kutschers": "Kutscher",
    "Kutschierenden": "Kutschierende",
    "Kutschierens": "Kutschieren",
    "Kutschierte": "kutschiert",
    "Kutschierten": "Kutschierte",
    "Kutten": "Kutte",
    "Kuttern": "Kutter",
    "Kutters": "Kutter",
    "Kuwaits": "Kuwait",
    "Kußechten": "Kußechte",
    "Kußfesten": "Kußfeste",
    "Kußhändchens": "Kußhändchen",
    "Kybernetische": "kybernetisch",
    "Kybernetischen": "Kybernetische",
    "Kyrillischen": "Kyrillische",
    "Käfern": "Käfer",
    "Käfers": "Käfer",
    "Käffchens": "Käffchen",
    "Käfige": "Käfig",
    "Käfigen": "Käfig",
    "Käfigs": "Käfig",
    "Kähne": "Kahn",
    "Kähnen": "Kahn",
    "Kälber": "Kalb",
    "Kälbereien": "Kälberei",
    "Kälbern": "Kalb",
    "Kältemaschinen": "Kältemaschine",
    "Kälteren": "Kältere",
    "Kältesten": "Kälteste",
    "Kälteträgern": "Kälteträger",
    "Kälteträgers": "Kälteträger",
    "Kämme": "kämmen",
    "Kämmen": "Kamm",
    "Kämmenden": "Kämmende",
    "Kämmens": "Kämmen",
    "Kämmerern": "Kämmerer",
    "Kämmerers": "Kämmerer",
    "Kämmerleins": "Kämmerlein",
    "Kämpe": "Kamp",
    "Kämpen": "Kamp",
    "Kämpfe": "kämpfen",
    "Kämpfen": "Kampf",
    "Kämpfenden": "Kämpfende",
    "Kämpfenderen": "Kämpfendere",
    "Kämpfendsten": "Kämpfendste",
    "Kämpfens": "Kämpfen",
    "Kämpferische": "kämpferisch",
    "Kämpferischen": "Kämpferische",
    "Kämpferischeren": "Kämpferischere",
    "Kämpferischsten": "Kämpferischste",
    "Kämpfern": "Kämpfer",
    "Kämpfers": "Kämpfer",
    "Känguruhs": "Känguruh",
    "Kännchens": "Kännchen",
    "Kännleins": "Kännlein",
    "Käppchens": "Käppchen",
    "Käppis": "Käppi",
    "Käppleins": "Käpplein",
    "Käpselchens": "Käpselchen",
    "Kärgeren": "Kärgere",
    "Kärglichen": "Kärgliche",
    "Kärglicheren": "Kärglichere",
    "Kärglichsten": "Kärglichste",
    "Kärgsten": "Kärgste",
    "Kärtchens": "Kärtchen",
    "Käschern": "Käscher",
    "Käschers": "Käscher",
    "Käsen": "Käse",
    "Käsereien": "Käserei",
    "Käses": "Käse",
    "Käsige": "käsig",
    "Käsigen": "Käsige",
    "Käsigeren": "Käsigere",
    "Käsigsten": "Käsigste",
    "Kästen": "Kasten",
    "Käthes": "Käthe",
    "Kätzchens": "Kätzchen",
    "Kätzleins": "Kätzlein",
    "Käuende": "käuend",
    "Käuenden": "Käuende",
    "Käuens": "Käuen",
    "Käufe": "Kauf",
    "Käufen": "Kauf",
    "Käufern": "Käufer",
    "Käufers": "Käufer",
    "Käuflichen": "Käufliche",
    "Käuflicheren": "Käuflichere",
    "Käuflichsten": "Käuflichste",
    "Käuzchens": "Käuzchen",
    "Köche": "Koch",
    "Köchen": "Koch",
    "Köchern": "Köcher",
    "Köchers": "Köcher",
    "Köchinnen": "Köchin",
    "Köder": "ködern",
    "Ködern": "Köder",
    "Ködernden": "Ködernde",
    "Köderns": "Ködern",
    "Köders": "Köder",
    "Köhlers": "Köhler",
    "Kölnern": "Kölner",
    "Kölners": "Kölner",
    "Kölnische": "kölnisch",
    "Kölnischen": "Kölnische",
    "Kölns": "Köln",
    "Kölsche": "kölsch",
    "Kölschen": "Kölsche",
    "Kölscheren": "Kölschere",
    "Kölschesten": "Kölscheste",
    "Könige": "König",
    "Königen": "König",
    "Königinnen": "Königin",
    "Königliche": "königlich",
    "Königlichen": "Königliche",
    "Königlicheren": "Königlichere",
    "Königlichsten": "Königlichste",
    "Königs": "König",
    "Königsteinern": "Königsteiner",
    "Königsteiners": "Königsteiner",
    "Königstreue": "königstreu",
    "Königstreuen": "Königstreue",
    "Königstreueren": "Königstreuere",
    "Königstreuesten": "Königstreueste",
    "Könnens": "Können",
    "Könnern": "Könner",
    "Könners": "Könner",
    "Köpenicks": "Köpenick",
    "Köpfchens": "Köpfchen",
    "Köpfe": "köpfen",
    "Köpfen": "Kopf",
    "Köpfenden": "Köpfende",
    "Köpfens": "Köpfen",
    "Köpkes": "Köpke",
    "Körbchens": "Körbchen",
    "Körbe": "Korb",
    "Körben": "Korb",
    "Körbleins": "Körblein",
    "Körnchens": "Körnchen",
    "Körner": "Korn",
    "Körnern": "Korn",
    "Körnige": "körnig",
    "Körnigen": "Körnige",
    "Körnigeren": "Körnigere",
    "Körnigsten": "Körnigste",
    "Körpereigene": "körpereigen",
    "Körpereigenen": "Körpereigene",
    "Körperlichen": "Körperliche",
    "Körperlichkeiten": "Körperlichkeit",
    "Körpern": "Körper",
    "Körpers": "Körper",
    "Köstliche": "köstlich",
    "Köstlichen": "Köstliche",
    "Köstlicheren": "Köstlichere",
    "Köstlichkeiten": "Köstlichkeit",
    "Köstlichste": "köstlich",
    "Köstlichsten": "Köstlichste",
    "Kötern": "Köter",
    "Köters": "Köter",
    "Kötzen": "Kötze",
    "Kötzern": "Kötzer",
    "Kötzers": "Kötzer",
    "Kübel": "kübeln",
    "Kübeln": "Kübel",
    "Kübelnden": "Kübelnde",
    "Kübelnderen": "Kübelndere",
    "Kübelndsten": "Kübelndste",
    "Kübelns": "Kübeln",
    "Kübels": "Kübel",
    "Küchen": "Küche",
    "Küchenfeen": "Küchenfee",
    "Küchenmaschinen": "Küchenmaschine",
    "Kühe": "Kuh",
    "Kühen": "Kuh",
    "Kühle": "kühlen",
    "Kühlen": "Kühle",
    "Kühlenden": "Kühlende",
    "Kühlenderen": "Kühlendere",
    "Kühlendsten": "Kühlendste",
    "Kühlens": "Kühlen",
    "Kühleren": "Kühlere",
    "Kühlhause": "Kühlhaus",
    "Kühlhauses": "Kühlhaus",
    "Kühlhäuser": "Kühlhaus",
    "Kühlhäusern": "Kühlhaus",
    "Kühlmitteln": "Kühlmittel",
    "Kühlmittels": "Kühlmittel",
    "Kühlofens": "Kühlofen",
    "Kühlschranke": "Kühlschrank",
    "Kühlschrankes": "Kühlschrank",
    "Kühlschranks": "Kühlschrank",
    "Kühlschränke": "Kühlschrank",
    "Kühlschränken": "Kühlschrank",
    "Kühlsten": "Kühlste",
    "Kühltaschen": "Kühltasche",
    "Kühltruhen": "Kühltruhe",
    "Kühlungen": "Kühlung",
    "Kühlwagens": "Kühlwagen",
    "Kühlwassers": "Kühlwasser",
    "Kühlöfen": "Kühlofen",
    "Kühne": "kühn",
    "Kühnen": "Kühne",
    "Kühneren": "Kühnere",
    "Kühnsten": "Kühnste",
    "Kükens": "Küken",
    "Kümmerlichen": "Kümmerliche",
    "Kümmerlicheren": "Kümmerlichere",
    "Kümmerlichsten": "Kümmerlichste",
    "Kümmernden": "Kümmernde",
    "Kümmernisse": "Kümmernis",
    "Kümmernissen": "Kümmernis",
    "Kümmerns": "Kümmern",
    "Kündbaren": "Kündbare",
    "Kündigenden": "Kündigende",
    "Kündigens": "Kündigen",
    "Kündigungen": "Kündigung",
    "Künftigen": "Künftige",
    "Künste": "Kunst",
    "Künsten": "Kunst",
    "Künstlerinnen": "Künstlerin",
    "Künstlerische": "künstlerisch",
    "Künstlerischen": "Künstlerische",
    "Künstlern": "Künstler",
    "Künstlers": "Künstler",
    "Künstliche": "künstlich",
    "Künstlichen": "Künstliche",
    "Künstlicheren": "Künstlichere",
    "Künstlichsten": "Künstlichste",
    "Kür": "küren",
    "Kürbisse": "Kürbis",
    "Kürbissen": "Kürbis",
    "Kürbisses": "Kürbis",
    "Küren": "Kür",
    "Kürenden": "Kürende",
    "Kürens": "Küren",
    "Kürzeln": "Kürzel",
    "Kürzels": "Kürzel",
    "Kürzenden": "Kürzende",
    "Kürzens": "Kürzen",
    "Kürzeren": "Kürzere",
    "Kürzesten": "Kürzeste",
    "Kürzlichen": "Kürzliche",
    "Kürzungen": "Kürzung",
    "Küsse": "küssen",
    "Küssen": "Kuß",
    "Küssenden": "Küssende",
    "Küssens": "Küssen",
    "Küssereien": "Küsserei",
    "Küsten": "Küste",
    "Küstereien": "Küsterei",
    "Küstern": "Küster",
    "Küsters": "Küster",
    "Küßchens": "Küßchen",
    "Küßleins": "Küßlein",
    "LPs": "LP",
    "Labbadias": "Labbadia",
    "Labberigen": "Labberige",
    "Labberigeren": "Labberigere",
    "Labberigsten": "Labberigste",
    "Labbernden": "Labbernde",
    "Labbernderen": "Labberndere",
    "Labberndsten": "Labberndste",
    "Labberns": "Labbern",
    "Labenden": "Labende",
    "Labenderen": "Labendere",
    "Labendsten": "Labendste",
    "Labens": "Laben",
    "Labernden": "Labernde",
    "Labernderen": "Laberndere",
    "Laberndsten": "Laberndste",
    "Laberns": "Labern",
    "Labilen": "Labile",
    "Labileren": "Labilere",
    "Labilsten": "Labilste",
    "Laboranten": "Laborant",
    "Laboratorien": "Laboratorium",
    "Laboratoriums": "Laboratorium",
    "Laboratorys": "Laboratory",
    "Laborierenden": "Laborierende",
    "Laborierenderen": "Laborierendere",
    "Laborierendsten": "Laborierendste",
    "Laborierens": "Laborieren",
    "Laborierte": "laboriert",
    "Laborierten": "Laborierte",
    "Laborierteren": "Laboriertere",
    "Laboriertesten": "Laborierteste",
    "Labors": "Labor",
    "Labyrinthe": "Labyrinth",
    "Labyrinthen": "Labyrinth",
    "Labyrinths": "Labyrinth",
    "Lache": "lachen",
    "Lachen": "Lache",
    "Lachenden": "Lachende",
    "Lachenderen": "Lachendere",
    "Lachendsten": "Lachendste",
    "Lachens": "Lachen",
    "Lachern": "Lacher",
    "Lachers": "Lacher",
    "Lachhaften": "Lachhafte",
    "Lachhafteren": "Lachhaftere",
    "Lachhaftesten": "Lachhafteste",
    "Lachkrampfe": "Lachkrampf",
    "Lachkrampfs": "Lachkrampf",
    "Lachkrämpfe": "Lachkrampf",
    "Lachkrämpfen": "Lachkrampf",
    "Lachmöwen": "Lachmöwe",
    "Lachnummern": "Lachnummer",
    "Lachsalven": "Lachsalve",
    "Lachse": "Lachs",
    "Lachsen": "Lachs",
    "Lachses": "Lachs",
    "Lachtauben": "Lachtaube",
    "Lacke": "Lack",
    "Lacken": "Lack",
    "Lackes": "Lack",
    "Lackierenden": "Lackierende",
    "Lackierens": "Lackieren",
    "Lackierte": "lackiert",
    "Lackierten": "Lackierte",
    "Lacks": "Lack",
    "Lactasen": "Lactase",
    "Lactate": "Lactat",
    "Lactaten": "Lactat",
    "Lactats": "Lactat",
    "Lactosen": "Lactose",
    "Lade": "laden",
    "Ladekrane": "Ladekran",
    "Ladekrans": "Ladekran",
    "Ladekräne": "Ladekran",
    "Ladekränen": "Ladekran",
    "Laden": "Lade",
    "Ladenden": "Ladende",
    "Ladens": "Laden",
    "Ladungen": "Ladung",
    "Ladys": "Lady",
    "Lafontaines": "Lafontaine",
    "Lagen": "liegen",
    "Lager": "lagern",
    "Lagern": "Lager",
    "Lagernden": "Lagernde",
    "Lagerns": "Lagern",
    "Lagers": "Lager",
    "Lagerungen": "Lagerung",
    "Lagunen": "Lagune",
    "Lahmenden": "Lahmende",
    "Lahmenderen": "Lahmendere",
    "Lahmendsten": "Lahmendste",
    "Lahmens": "Lahmen",
    "Lahmgelegten": "Lahmgelegte",
    "Lahmgelegteren": "Lahmgelegtere",
    "Lahmgelegtesten": "Lahmgelegteste",
    "Lahmlegenden": "Lahmlegende",
    "Lahmlegenderen": "Lahmlegendere",
    "Lahmlegendsten": "Lahmlegendste",
    "Lahmlegens": "Lahmlegen",
    "Lahnungen": "Lahnung",
    "Laien": "Laie",
    "Laienhafte": "laienhaft",
    "Laienhaften": "Laienhafte",
    "Laienhafteren": "Laienhaftere",
    "Laienhaftesten": "Laienhafteste",
    "Laizistischen": "Laizistische",
    "Laizistischeren": "Laizistischere",
    "Laizistischsten": "Laizistischste",
    "Laken": "Lake",
    "Lakens": "Laken",
    "Lakonische": "lakonisch",
    "Lakonischen": "Lakonische",
    "Lakonischeren": "Lakonischere",
    "Lakonischsten": "Lakonischste",
    "Lakritzen": "Lakritze",
    "Laktierenden": "Laktierende",
    "Laktierenderen": "Laktierendere",
    "Laktierendsten": "Laktierendste",
    "Laktierens": "Laktieren",
    "Laktierte": "laktiert",
    "Laktierten": "Laktierte",
    "Laktierteren": "Laktiertere",
    "Laktiertesten": "Laktierteste",
    "Lallenden": "Lallende",
    "Lallenderen": "Lallendere",
    "Lallendsten": "Lallendste",
    "Lallens": "Lallen",
    "Lallworte": "Lallwort",
    "Lallwortes": "Lallwort",
    "Lallworts": "Lallwort",
    "Lallwörter": "Lallwort",
    "Lallwörtern": "Lallwort",
    "Lamas": "Lama",
    "Lambadas": "Lambada",
    "Lambdas": "Lambda",
    "Lambsdorffs": "Lambsdorff",
    "Lamellen": "Lamelle",
    "Lamentationen": "Lamentation",
    "Lamentierenden": "Lamentierende",
    "Lamentierenderen": "Lamentierendere",
    "Lamentierendsten": "Lamentierendste",
    "Lamentierens": "Lamentieren",
    "Lamentierte": "lamentiert",
    "Lamentierten": "Lamentierte",
    "Lamettas": "Lametta",
    "Laminate": "Laminat",
    "Laminaten": "Laminat",
    "Laminats": "Laminat",
    "Laminierenden": "Laminierende",
    "Laminierens": "Laminieren",
    "Laminierte": "laminiert",
    "Laminierten": "Laminierte",
    "Lamme": "Lamm",
    "Lammes": "Lamm",
    "Lammfromme": "lammfromm",
    "Lammfrommen": "Lammfromme",
    "Lammfrommeren": "Lammfrommere",
    "Lammfrommsten": "Lammfrommste",
    "Lamms": "Lamm",
    "Lampen": "Lampe",
    "Landauern": "Landauer",
    "Landauers": "Landauer",
    "Landaus": "Landau",
    "Landbaue": "Landbau",
    "Landbaues": "Landbau",
    "Landbaus": "Landbau",
    "Lande": "landen",
    "Landeerlaubnisse": "Landeerlaubnis",
    "Landeerlaubnissen": "Landeerlaubnis",
    "Landemanövern": "Landemanöver",
    "Landemanövers": "Landemanöver",
    "Landenden": "Landende",
    "Landens": "Landen",
    "Landes": "Land",
    "Landesligisten": "Landesligist",
    "Landesüblichen": "Landesübliche",
    "Landfremden": "Landfremde",
    "Landfremderen": "Landfremdere",
    "Landfremdesten": "Landfremdeste",
    "Landläufigen": "Landläufige",
    "Lands": "Land",
    "Landschaften": "Landschaft",
    "Landschaftliche": "landschaftlich",
    "Landschaftlichen": "Landschaftliche",
    "Landtage": "Landtag",
    "Landtagen": "Landtag",
    "Landtages": "Landtag",
    "Landtags": "Landtag",
    "Landungen": "Landung",
    "Landwirte": "Landwirt",
    "Landwirten": "Landwirt",
    "Landwirtes": "Landwirt",
    "Landwirts": "Landwirt",
    "Landwirtschaftliche": "landwirtschaftlich",
    "Landwirtschaftlichen": "Landwirtschaftliche",
    "Landwirtschaftlicheren": "Landwirtschaftlichere",
    "Langatmigen": "Langatmige",
    "Langatmigeren": "Langatmigere",
    "Langatmigsten": "Langatmigste",
    "Langdrehenden": "Langdrehende",
    "Langdrehens": "Langdrehen",
    "Lange": "langen",
    "Langen": "Lange",
    "Langenden": "Langende",
    "Langendiebachs": "Langendiebach",
    "Langenern": "Langener",
    "Langeners": "Langener",
    "Langens": "Langen",
    "Langenselboldern": "Langenselbolder",
    "Langenselbolders": "Langenselbolder",
    "Langfristigen": "Langfristige",
    "Langfristigeren": "Langfristigere",
    "Langfristigsten": "Langfristigste",
    "Langgedrehten": "Langgedrehte",
    "Langhaarigen": "Langhaarige",
    "Langjährigen": "Langjährige",
    "Langlebigen": "Langlebige",
    "Langlebigeren": "Langlebigere",
    "Langlebigsten": "Langlebigste",
    "Langmütigen": "Langmütige",
    "Langmütigeren": "Langmütigere",
    "Langmütigsten": "Langmütigste",
    "Langsamen": "Langsame",
    "Langsameren": "Langsamere",
    "Langsamsten": "Langsamste",
    "Langspielplatten": "Langspielplatte",
    "Langstieligen": "Langstielige",
    "Langstieligeren": "Langstieligere",
    "Langstieligsten": "Langstieligste",
    "Langstrecken": "Langstrecke",
    "Langstrecklern": "Langstreckler",
    "Langstrecklers": "Langstreckler",
    "Langusten": "Languste",
    "Langweilenden": "Langweilende",
    "Langweilenderen": "Langweilendere",
    "Langweilendsten": "Langweilendste",
    "Langweilens": "Langweilen",
    "Langweilern": "Langweiler",
    "Langweilers": "Langweiler",
    "Langweiligen": "Langweilige",
    "Langweiligeren": "Langweiligere",
    "Langweiligsten": "Langweiligste",
    "Langwellen": "Langwelle",
    "Langwierige": "langwierig",
    "Langwierigen": "Langwierige",
    "Langwierigeren": "Langwierigere",
    "Langwierigsten": "Langwierigste",
    "Langzeitarbeitslosen": "Langzeitarbeitslose",
    "Langzeitstudien": "Langzeitstudie",
    "Langärmeligen": "Langärmelige",
    "Lanzen": "Lanze",
    "Lapidare": "lapidar",
    "Lapidaren": "Lapidare",
    "Lappalien": "Lappalie",
    "Lappe": "lappen",
    "Lappen": "Lappe",
    "Lappenden": "Lappende",
    "Lappens": "Lappen",
    "Lappigen": "Lappige",
    "Lappigeren": "Lappigere",
    "Lappigsten": "Lappigste",
    "Lappländern": "Lappländer",
    "Lappländers": "Lappländer",
    "Laqueurs": "Laqueur",
    "Larifaris": "Larifari",
    "Larven": "Larve",
    "Laschen": "Lasche",
    "Lascheren": "Laschere",
    "Laschsten": "Laschste",
    "Lasers": "Laser",
    "Lasierungen": "Lasierung",
    "Lassenden": "Lassende",
    "Lassens": "Lassen",
    "Lassos": "Lasso",
    "Lasten": "Last",
    "Lastenden": "Lastende",
    "Lastens": "Lasten",
    "Lasterhafte": "lasterhaft",
    "Lasterhaften": "Lasterhafte",
    "Lasterhafteren": "Lasterhaftere",
    "Lasterhaftesten": "Lasterhafteste",
    "Lasterhöhlen": "Lasterhöhle",
    "Lastern": "Laster",
    "Lasters": "Laster",
    "Lastkraftwagens": "Lastkraftwagen",
    "Lateinamerikanern": "Lateinamerikaner",
    "Lateinamerikaners": "Lateinamerikaner",
    "Lateinamerikanische": "lateinamerikanisch",
    "Lateinamerikanischen": "Lateinamerikanische",
    "Lateinamerikas": "Lateinamerika",
    "Lateinische": "lateinisch",
    "Lateinischen": "Lateinische",
    "Lateins": "Latein",
    "Latente": "latent",
    "Latenten": "Latente",
    "Latenteren": "Latentere",
    "Latentesten": "Latenteste",
    "Lateralen": "Laterale",
    "Laterals": "Lateral",
    "Laternen": "Laterne",
    "Latinern": "Latiner",
    "Latiners": "Latiner",
    "Latinums": "Latinum",
    "Latitüden": "Latitüde",
    "Latrinen": "Latrine",
    "Latschenden": "Latschende",
    "Latschens": "Latschen",
    "Latteks": "Lattek",
    "Latten": "Latte",
    "Latüchten": "Latüchte",
    "Laube": "Laub",
    "Lauben": "Laube",
    "Laubes": "Laub",
    "Laubs": "Laub",
    "Lauche": "Lauch",
    "Lauchen": "Lauch",
    "Lauches": "Lauch",
    "Lauchs": "Lauch",
    "Laudas": "Lauda",
    "Laue": "lau",
    "Lauen": "Laue",
    "Lauere": "lauern",
    "Laueren": "Lauere",
    "Lauernden": "Lauernde",
    "Lauernderen": "Lauerndere",
    "Lauerndsten": "Lauerndste",
    "Lauerns": "Lauern",
    "Lauesten": "Laueste",
    "Lauf": "laufen",
    "Laufe": "laufen",
    "Laufenden": "Laufende",
    "Laufens": "Laufen",
    "Laufes": "Lauf",
    "Lauffähigen": "Lauffähige",
    "Lauffähigeren": "Lauffähigere",
    "Lauffähigsten": "Lauffähigste",
    "Laufmaschen": "Laufmasche",
    "Laufrade": "Laufrad",
    "Laufrades": "Laufrad",
    "Laufrads": "Laufrad",
    "Laufrichtungen": "Laufrichtung",
    "Laufräder": "Laufrad",
    "Laufrädern": "Laufrad",
    "Laufs": "Lauf",
    "Laufschienen": "Laufschiene",
    "Laufschritts": "Laufschritt",
    "Laufwerke": "Laufwerk",
    "Laufwerken": "Laufwerk",
    "Laufwerkes": "Laufwerk",
    "Laufwerks": "Laufwerk",
    "Laufzetteln": "Laufzettel",
    "Laufzettels": "Laufzettel",
    "Lauge": "laugen",
    "Laugen": "Lauge",
    "Laugenden": "Laugende",
    "Laugens": "Laugen",
    "Launen": "Laune",
    "Launenhafte": "launenhaft",
    "Launenhaften": "Launenhafte",
    "Launenhafteren": "Launenhaftere",
    "Launenhaftesten": "Launenhafteste",
    "Launigen": "Launige",
    "Launigeren": "Launigere",
    "Launigsten": "Launigste",
    "Launischen": "Launische",
    "Launischeren": "Launischere",
    "Launischsten": "Launischste",
    "Laus": "lausen",
    "Lauschenden": "Lauschende",
    "Lauschenderen": "Lauschendere",
    "Lauschendsten": "Lauschendste",
    "Lauschens": "Lauschen",
    "Lauschigen": "Lauschige",
    "Lauschigeren": "Lauschigere",
    "Lauschigsten": "Lauschigste",
    "Lausenden": "Lausende",
    "Lausenderen": "Lausendere",
    "Lausendsten": "Lausendste",
    "Lausens": "Lausen",
    "Lausigen": "Lausige",
    "Lausigeren": "Lausigere",
    "Lausigsten": "Lausigste",
    "Laute": "lauten",
    "Lauten": "Laute",
    "Lautenden": "Lautende",
    "Lautens": "Lauten",
    "Lauteren": "Lautere",
    "Lautesten": "Lauteste",
    "Lautlosen": "Lautlose",
    "Lautloseren": "Lautlosere",
    "Lautlosesten": "Lautloseste",
    "Lautmalereien": "Lautmalerei",
    "Lauts": "Laut",
    "Lautschriften": "Lautschrift",
    "Lautsprechern": "Lautsprecher",
    "Lautsprechers": "Lautsprecher",
    "Lautstarke": "lautstark",
    "Lautstarken": "Lautstarke",
    "Lautstärken": "Lautstärke",
    "Lauwarmen": "Lauwarme",
    "Lavendeln": "Lavendel",
    "Lavendels": "Lavendel",
    "Lawinen": "Lawine",
    "Laxe": "lax",
    "Laxen": "Laxe",
    "Laxeren": "Laxere",
    "Laxesten": "Laxeste",
    "Layouts": "Layout",
    "Lazarette": "Lazarett",
    "Lazaretten": "Lazarett",
    "Lazarettes": "Lazarett",
    "Lazaretts": "Lazarett",
    "Lazerationen": "Lazeration",
    "Lebenden": "Lebende",
    "Lebendigen": "Lebendige",
    "Lebendigeren": "Lebendigere",
    "Lebendigsten": "Lebendigste",
    "Lebens": "Leben",
    "Lebensbedrohliche": "lebensbedrohlich",
    "Lebensbedrohlichen": "Lebensbedrohliche",
    "Lebensbedrohlicheren": "Lebensbedrohlichere",
    "Lebensechten": "Lebensechte",
    "Lebensfreudigen": "Lebensfreudige",
    "Lebensfreudigeren": "Lebensfreudigere",
    "Lebensfreudigsten": "Lebensfreudigste",
    "Lebensfrohen": "Lebensfrohe",
    "Lebensfroheren": "Lebensfrohere",
    "Lebensfrohesten": "Lebensfroheste",
    "Lebensfähigen": "Lebensfähige",
    "Lebensfähigeren": "Lebensfähigere",
    "Lebensfähigsten": "Lebensfähigste",
    "Lebensgefährlichen": "Lebensgefährliche",
    "Lebensgefährlicheren": "Lebensgefährlichere",
    "Lebensgroßen": "Lebensgroße",
    "Lebenslangen": "Lebenslange",
    "Lebenslustigen": "Lebenslustige",
    "Lebenslustigeren": "Lebenslustigere",
    "Lebenslustigsten": "Lebenslustigste",
    "Lebenslänglichen": "Lebenslängliche",
    "Lebensmitteln": "Lebensmittel",
    "Lebensmüderen": "Lebensmüdere",
    "Lebensmüdesten": "Lebensmüdeste",
    "Lebensnotwendigen": "Lebensnotwendige",
    "Lebensnotwendigeren": "Lebensnotwendigere",
    "Lebenswichtigen": "Lebenswichtige",
    "Lebern": "Leber",
    "Lebewesens": "Lebewesen",
    "Lebhafte": "lebhaft",
    "Lebhaften": "Lebhafte",
    "Lebhafteren": "Lebhaftere",
    "Lebhaftesten": "Lebhafteste",
    "Lebkuchens": "Lebkuchen",
    "Leblose": "leblos",
    "Leblosen": "Leblose",
    "Lebloseren": "Leblosere",
    "Leblosesten": "Lebloseste",
    "Lechs": "Lech",
    "Lecithine": "Lecithin",
    "Lecithinen": "Lecithin",
    "Lecithins": "Lecithin",
    "Leckerbissens": "Leckerbissen",
    "Leckere": "lecker",
    "Leckeren": "Leckere",
    "Leckereren": "Leckerere",
    "Leckersten": "Leckerste",
    "Leckgeschlagenen": "Leckgeschlagene",
    "Lecks": "Leck",
    "Leckschlagenden": "Leckschlagende",
    "Leckschlagens": "Leckschlagen",
    "Leder": "ledern",
    "Ledern": "Leder",
    "Ledernden": "Ledernde",
    "Lederns": "Ledern",
    "Leders": "Leder",
    "Ledigen": "Ledige",
    "Leere": "leeren",
    "Leeren": "Leere",
    "Leerenden": "Leerende",
    "Leerens": "Leeren",
    "Leereren": "Leerere",
    "Leergestandenen": "Leergestandene",
    "Leergewichte": "Leergewicht",
    "Leergewichten": "Leergewicht",
    "Leergewichts": "Leergewicht",
    "Leerlaufs": "Leerlauf",
    "Leerstehenden": "Leerstehende",
    "Leerstehens": "Leerstehen",
    "Leersten": "Leerste",
    "Leertasten": "Leertaste",
    "Leerverkaufe": "Leerverkauf",
    "Leerverkaufs": "Leerverkauf",
    "Leerverkäufe": "Leerverkauf",
    "Leerverkäufen": "Leerverkauf",
    "Lees": "Lee",
    "Legale": "legal",
    "Legalen": "Legale",
    "Legalisierenden": "Legalisierende",
    "Legalisierens": "Legalisieren",
    "Legalisierte": "legalisiert",
    "Legalisierten": "Legalisierte",
    "Legalisierungen": "Legalisierung",
    "Legebatterien": "Legebatterie",
    "Legehennen": "Legehenne",
    "Legenden": "Legende",
    "Legendären": "Legendäre",
    "Legendäreren": "Legendärere",
    "Legendärsten": "Legendärste",
    "Legens": "Legen",
    "Legern": "Leger",
    "Legers": "Leger",
    "Legeröhren": "Legeröhre",
    "Legionen": "Legion",
    "Legionäre": "Legionär",
    "Legionären": "Legionär",
    "Legionärs": "Legionär",
    "Legislative": "legislativ",
    "Legislativen": "Legislative",
    "Legislatorischen": "Legislatorische",
    "Legislaturen": "Legislatur",
    "Legitimationen": "Legitimation",
    "Legitimationskarten": "Legitimationskarte",
    "Legitime": "legitim",
    "Legitimen": "Legitime",
    "Legitimeren": "Legitimere",
    "Legitimierenden": "Legitimierende",
    "Legitimierens": "Legitimieren",
    "Legitimierte": "legitimiert",
    "Legitimierten": "Legitimierte",
    "Legitimierungen": "Legitimierung",
    "Legitimistische": "legitimistisch",
    "Legitimistischen": "Legitimistische",
    "Legitimsten": "Legitimste",
    "Leguane": "Leguan",
    "Leguanen": "Leguan",
    "Leguans": "Leguan",
    "Lehmanns": "Lehmann",
    "Lehme": "Lehm",
    "Lehmen": "Lehm",
    "Lehmes": "Lehm",
    "Lehmige": "lehmig",
    "Lehmigen": "Lehmige",
    "Lehmigeren": "Lehmigere",
    "Lehmigsten": "Lehmigste",
    "Lehms": "Lehm",
    "Lehne": "lehnen",
    "Lehnen": "Lehne",
    "Lehnenden": "Lehnende",
    "Lehnens": "Lehnen",
    "Lehnsesseln": "Lehnsessel",
    "Lehnsessels": "Lehnsessel",
    "Lehnsmanne": "Lehnsmann",
    "Lehnsmannes": "Lehnsmann",
    "Lehnsmanns": "Lehnsmann",
    "Lehnsmänner": "Lehnsmann",
    "Lehnsmännern": "Lehnsmann",
    "Lehnworte": "Lehnwort",
    "Lehnwortes": "Lehnwort",
    "Lehnworts": "Lehnwort",
    "Lehnwörter": "Lehnwort",
    "Lehnwörtern": "Lehnwort",
    "Lehramte": "Lehramt",
    "Lehramtes": "Lehramt",
    "Lehramts": "Lehramt",
    "Lehramtsanwärtern": "Lehramtsanwärter",
    "Lehramtsanwärters": "Lehramtsanwärter",
    "Lehranstalten": "Lehranstalt",
    "Lehrbuche": "Lehrbuch",
    "Lehrbuches": "Lehrbuch",
    "Lehrbuchs": "Lehrbuch",
    "Lehrbücher": "Lehrbuch",
    "Lehrbüchern": "Lehrbuch",
    "Lehre": "lehren",
    "Lehren": "Lehre",
    "Lehrenden": "Lehrende",
    "Lehrens": "Lehren",
    "Lehrerfolge": "Lehrerfolg",
    "Lehrerfolgen": "Lehrerfolg",
    "Lehrerfolgs": "Lehrerfolg",
    "Lehrerinnen": "Lehrerin",
    "Lehrern": "Lehrer",
    "Lehrers": "Lehrer",
    "Lehrerschaften": "Lehrerschaft",
    "Lehrerschwemmen": "Lehrerschwemme",
    "Lehrfache": "Lehrfach",
    "Lehrfaches": "Lehrfach",
    "Lehrfachs": "Lehrfach",
    "Lehrfilme": "Lehrfilm",
    "Lehrfilmen": "Lehrfilm",
    "Lehrfilms": "Lehrfilm",
    "Lehrfächer": "Lehrfach",
    "Lehrfächern": "Lehrfach",
    "Lehrgange": "Lehrgang",
    "Lehrganges": "Lehrgang",
    "Lehrgangs": "Lehrgang",
    "Lehrgebäuden": "Lehrgebäude",
    "Lehrgebäudes": "Lehrgebäude",
    "Lehrgedichte": "Lehrgedicht",
    "Lehrgedichten": "Lehrgedicht",
    "Lehrgedichts": "Lehrgedicht",
    "Lehrgegenstande": "Lehrgegenstand",
    "Lehrgegenstands": "Lehrgegenstand",
    "Lehrgegenstände": "Lehrgegenstand",
    "Lehrgegenständen": "Lehrgegenstand",
    "Lehrgelde": "Lehrgeld",
    "Lehrgelder": "Lehrgeld",
    "Lehrgeldern": "Lehrgeld",
    "Lehrgeldes": "Lehrgeld",
    "Lehrgelds": "Lehrgeld",
    "Lehrgerüste": "Lehrgerüst",
    "Lehrgerüsten": "Lehrgerüst",
    "Lehrgerüsts": "Lehrgerüst",
    "Lehrgänge": "Lehrgang",
    "Lehrgängen": "Lehrgang",
    "Lehrhafte": "lehrhaft",
    "Lehrhaften": "Lehrhafte",
    "Lehrhafteren": "Lehrhaftere",
    "Lehrhaftesten": "Lehrhafteste",
    "Lehrjungen": "Lehrjunge",
    "Lehrlinge": "Lehrling",
    "Lehrlingen": "Lehrling",
    "Lehrlinges": "Lehrling",
    "Lehrlings": "Lehrling",
    "Lehrmaschinen": "Lehrmaschine",
    "Lehrmeistern": "Lehrmeister",
    "Lehrmeisters": "Lehrmeister",
    "Lehrplane": "Lehrplan",
    "Lehrplans": "Lehrplan",
    "Lehrpläne": "Lehrplan",
    "Lehrplänen": "Lehrplan",
    "Lehrreiche": "lehrreich",
    "Lehrreichen": "Lehrreiche",
    "Lehrreicheren": "Lehrreichere",
    "Lehrreichsten": "Lehrreichste",
    "Lehrstellen": "Lehrstelle",
    "Lehrstoffe": "Lehrstoff",
    "Lehrstoffen": "Lehrstoff",
    "Lehrstoffs": "Lehrstoff",
    "Lehrstunden": "Lehrstunde",
    "Lehrstühle": "Lehrstuhl",
    "Lehrstühlen": "Lehrstuhl",
    "Lehrvertrage": "Lehrvertrag",
    "Lehrvertrags": "Lehrvertrag",
    "Lehrverträge": "Lehrvertrag",
    "Lehrverträgen": "Lehrvertrag",
    "Lehrwerke": "Lehrwerk",
    "Lehrwerken": "Lehrwerk",
    "Lehrwerks": "Lehrwerk",
    "Lehrzeiten": "Lehrzeit",
    "Lehrämter": "Lehramt",
    "Lehrämtern": "Lehramt",
    "Leib": "leiben",
    "Leibchens": "Leibchen",
    "Leibe": "leiben",
    "Leibeigenen": "Leibeigene",
    "Leibenden": "Leibende",
    "Leibens": "Leiben",
    "Leiber": "Leib",
    "Leibern": "Leib",
    "Leibes": "Leib",
    "Leibgardisten": "Leibgardist",
    "Leibliche": "leiblich",
    "Leiblichen": "Leibliche",
    "Leibs": "Leib",
    "Leichen": "Leiche",
    "Leichenblasse": "leichenblaß",
    "Leichenblassen": "Leichenblasse",
    "Leichenblasseren": "Leichenblassere",
    "Leichenblassesten": "Leichenblasseste",
    "Leichname": "Leichnam",
    "Leichnamen": "Leichnam",
    "Leichnames": "Leichnam",
    "Leichnams": "Leichnam",
    "Leichtbenzine": "Leichtbenzin",
    "Leichtbenzinen": "Leichtbenzin",
    "Leichtbenzins": "Leichtbenzin",
    "Leichte": "leicht",
    "Leichten": "Leichte",
    "Leichteren": "Leichtere",
    "Leichtesten": "Leichteste",
    "Leichtfertigen": "Leichtfertige",
    "Leichtfertigeren": "Leichtfertigere",
    "Leichtfertigsten": "Leichtfertigste",
    "Leichtfüßigen": "Leichtfüßige",
    "Leichtgläubigen": "Leichtgläubige",
    "Leichtgläubigeren": "Leichtgläubigere",
    "Leichtgläubigsten": "Leichtgläubigste",
    "Leichtsinnige": "leichtsinnig",
    "Leichtsinnigen": "Leichtsinnige",
    "Leichtsinnigeren": "Leichtsinnigere",
    "Leichtsinnigsten": "Leichtsinnigste",
    "Leichtöle": "Leichtöl",
    "Leichtölen": "Leichtöl",
    "Leichtöls": "Leichtöl",
    "Leid": "leiden",
    "Leiden": "Leid",
    "Leidenden": "Leidende",
    "Leidens": "Leiden",
    "Leidenschaften": "Leidenschaft",
    "Leidenschaftliche": "leidenschaftlich",
    "Leidenschaftlichen": "Leidenschaftliche",
    "Leidenschaftlicheren": "Leidenschaftlichere",
    "Leidigen": "Leidige",
    "Leidlichen": "Leidliche",
    "Leidtragenden": "Leidtragende",
    "Leidvollen": "Leidvolle",
    "Leidvolleren": "Leidvollere",
    "Leidvollsten": "Leidvollste",
    "Leidwesens": "Leidwesen",
    "Leier": "leiern",
    "Leierkastens": "Leierkasten",
    "Leierkästen": "Leierkasten",
    "Leiern": "Leier",
    "Leiernden": "Leiernde",
    "Leiernderen": "Leierndere",
    "Leierndsten": "Leierndste",
    "Leierns": "Leiern",
    "Leihamte": "Leihamt",
    "Leihamtes": "Leihamt",
    "Leihamts": "Leihamt",
    "Leihautos": "Leihauto",
    "Leihenden": "Leihende",
    "Leihens": "Leihen",
    "Leihgaben": "Leihgabe",
    "Leihwagens": "Leihwagen",
    "Leihämter": "Leihamt",
    "Leihämtern": "Leihamt",
    "Leim": "leimen",
    "Leimenden": "Leimende",
    "Leimens": "Leimen",
    "Leims": "Leim",
    "Leinen": "Leine",
    "Leinenden": "Leinende",
    "Leinens": "Leinen",
    "Leinenwebern": "Leinenweber",
    "Leinenwebers": "Leinenweber",
    "Leintuche": "Leintuch",
    "Leintuches": "Leintuch",
    "Leintuchs": "Leintuch",
    "Leintücher": "Leintuch",
    "Leintüchern": "Leintuch",
    "Leinwände": "Leinwand",
    "Leinwänden": "Leinwand",
    "Leipzigern": "Leipziger",
    "Leipzigers": "Leipziger",
    "Leipzigs": "Leipzig",
    "Leiseren": "Leisere",
    "Leisesten": "Leiseste",
    "Leisten": "Leiste",
    "Leistenden": "Leistende",
    "Leistenderen": "Leistendere",
    "Leistendsten": "Leistendste",
    "Leistens": "Leisten",
    "Leistungen": "Leistung",
    "Leistungsfähige": "leistungsfähig",
    "Leistungsfähigen": "Leistungsfähige",
    "Leistungsfähigeren": "Leistungsfähigere",
    "Leistungsorientierten": "Leistungsorientierte",
    "Leistungsstarken": "Leistungsstarke",
    "Leistungsstärkeren": "Leistungsstärkere",
    "Leitartikeln": "Leitartikel",
    "Leitartikels": "Leitartikel",
    "Leitenden": "Leitende",
    "Leitenderen": "Leitendere",
    "Leitendsten": "Leitendste",
    "Leitens": "Leiten",
    "Leiterinnen": "Leiterin",
    "Leitern": "Leiter",
    "Leiters": "Leiter",
    "Leitfadens": "Leitfaden",
    "Leitpflanzen": "Leitpflanze",
    "Leitplanken": "Leitplanke",
    "Leitrade": "Leitrad",
    "Leitrades": "Leitrad",
    "Leitrads": "Leitrad",
    "Leiträder": "Leitrad",
    "Leiträdern": "Leitrad",
    "Leitsatze": "Leitsatz",
    "Leitsatzes": "Leitsatz",
    "Leitstellen": "Leitstelle",
    "Leitsätze": "Leitsatz",
    "Leitsätzen": "Leitsatz",
    "Leittiere": "Leittier",
    "Leittieren": "Leittier",
    "Leittieres": "Leittier",
    "Leittiers": "Leittier",
    "Leitungen": "Leitung",
    "Leitvermerke": "Leitvermerk",
    "Leitvermerken": "Leitvermerk",
    "Leitvermerks": "Leitvermerk",
    "Leitvorstellungen": "Leitvorstellung",
    "Leitwerke": "Leitwerk",
    "Leitwerken": "Leitwerk",
    "Leitwerks": "Leitwerk",
    "Leitwerte": "Leitwert",
    "Leitwerten": "Leitwert",
    "Leitwerts": "Leitwert",
    "Leitwährungen": "Leitwährung",
    "Leitzahlen": "Leitzahl",
    "Lektionen": "Lektion",
    "Lektore": "Lektor",
    "Lektoren": "Lektor",
    "Lektorinnen": "Lektorin",
    "Lektors": "Lektor",
    "Lektüren": "Lektüre",
    "Lemkes": "Lemke",
    "Lemmatisierenden": "Lemmatisierende",
    "Lemmatisierens": "Lemmatisieren",
    "Lemmatisierte": "lemmatisiert",
    "Lemmatisierten": "Lemmatisierte",
    "Lemmatisierungen": "Lemmatisierung",
    "Lemminge": "Lemming",
    "Lemmingen": "Lemming",
    "Lemmings": "Lemming",
    "Lemniskaten": "Lemniskate",
    "Lenden": "Lende",
    "Lendls": "Lendl",
    "Lenins": "Lenin",
    "Lenkbare": "lenkbar",
    "Lenkbaren": "Lenkbare",
    "Lenkenden": "Lenkende",
    "Lenkens": "Lenken",
    "Lenkern": "Lenker",
    "Lenkers": "Lenker",
    "Lenkgetrieben": "Lenkgetriebe",
    "Lenkgetriebes": "Lenkgetriebe",
    "Lenkkufen": "Lenkkufe",
    "Lenkrade": "Lenkrad",
    "Lenkrades": "Lenkrad",
    "Lenkrads": "Lenkrad",
    "Lenkräder": "Lenkrad",
    "Lenkrädern": "Lenkrad",
    "Lenksäulen": "Lenksäule",
    "Lenze": "Lenz",
    "Lenzes": "Lenz",
    "Leonhards": "Leonhard",
    "Leos": "Leo",
    "Lerchen": "Lerche",
    "Lernbare": "lernbar",
    "Lernbaren": "Lernbare",
    "Lernbegierigen": "Lernbegierige",
    "Lernbegierigeren": "Lernbegierigere",
    "Lernbegierigsten": "Lernbegierigste",
    "Lernbehinderten": "Lernbehinderte",
    "Lerneifrigen": "Lerneifrige",
    "Lerneifrigeren": "Lerneifrigere",
    "Lerneifrigsten": "Lerneifrigste",
    "Lernenden": "Lernende",
    "Lernens": "Lernen",
    "Lernern": "Lerner",
    "Lerners": "Lerner",
    "Lernhilfen": "Lernhilfe",
    "Lerninhalte": "Lerninhalt",
    "Lerninhalten": "Lerninhalt",
    "Lerninhalts": "Lerninhalt",
    "Lernmaschinen": "Lernmaschine",
    "Lernmitteln": "Lernmittel",
    "Lernmittels": "Lernmittel",
    "Lernprogramme": "Lernprogramm",
    "Lernprogrammen": "Lernprogramm",
    "Lernprogrammes": "Lernprogramm",
    "Lernprogramms": "Lernprogramm",
    "Lernprozesse": "Lernprozeß",
    "Lernprozessen": "Lernprozeß",
    "Lernprozesses": "Lernprozeß",
    "Lernziele": "Lernziel",
    "Lernzielen": "Lernziel",
    "Lernziels": "Lernziel",
    "Lersners": "Lersner",
    "Lesben": "Lesbe",
    "Lesbische": "lesbisch",
    "Lesbischen": "Lesbische",
    "Lesebrillen": "Lesebrille",
    "Lesebuche": "Lesebuch",
    "Lesebuches": "Lesebuch",
    "Lesebuchs": "Lesebuch",
    "Lesebücher": "Lesebuch",
    "Lesebüchern": "Lesebuch",
    "Leseerfahrungen": "Leseerfahrung",
    "Lesefreudige": "lesefreudig",
    "Lesefreudigen": "Lesefreudige",
    "Lesefreudigeren": "Lesefreudigere",
    "Lesefreudigsten": "Lesefreudigste",
    "Lesegeräte": "Lesegerät",
    "Lesegeräten": "Lesegerät",
    "Lesegeräts": "Lesegerät",
    "Lesegesellschaften": "Lesegesellschaft",
    "Lesen": "Lese",
    "Lesenden": "Lesende",
    "Lesens": "Lesen",
    "Lesenswerte": "lesenswert",
    "Lesenswerten": "Lesenswerte",
    "Lesenswerteren": "Lesenswertere",
    "Lesenswertesten": "Lesenswerteste",
    "Leseproben": "Leseprobe",
    "Lesepulte": "Lesepult",
    "Lesepulten": "Lesepult",
    "Lesepults": "Lesepult",
    "Leseratten": "Leseratte",
    "Leserinnen": "Leserin",
    "Leserliche": "leserlich",
    "Leserlichen": "Leserliche",
    "Leserlicheren": "Leserlichere",
    "Leserlichsten": "Leserlichste",
    "Lesern": "Leser",
    "Lesers": "Leser",
    "Lesestoffe": "Lesestoff",
    "Lesestoffen": "Lesestoff",
    "Lesestoffs": "Lesestoff",
    "Lesestücke": "Lesestück",
    "Lesestücken": "Lesestück",
    "Lesestücks": "Lesestück",
    "Lesezeichens": "Lesezeichen",
    "Lesezirkeln": "Lesezirkel",
    "Lesezirkels": "Lesezirkel",
    "Lesungen": "Lesung",
    "Lethargische": "lethargisch",
    "Lethargischen": "Lethargische",
    "Lettischen": "Lettische",
    "Lettlands": "Lettland",
    "Letzte": "letzt",
    "Letzten": "Letzte",
    "Letzteren": "Letztere",
    "Letztgenannten": "Letztgenannte",
    "Letztjährigen": "Letztjährige",
    "Letztlichen": "Letztliche",
    "Letztmaligen": "Letztmalige",
    "Leuchtbomben": "Leuchtbombe",
    "Leuchtdioden": "Leuchtdiode",
    "Leuchte": "leuchten",
    "Leuchten": "Leuchte",
    "Leuchtenden": "Leuchtende",
    "Leuchtenderen": "Leuchtendere",
    "Leuchtendsten": "Leuchtendste",
    "Leuchtens": "Leuchten",
    "Leuchtern": "Leuchter",
    "Leuchters": "Leuchter",
    "Leuchtfarben": "Leuchtfarbe",
    "Leuchtfeuern": "Leuchtfeuer",
    "Leuchtfeuers": "Leuchtfeuer",
    "Leuchtkäfern": "Leuchtkäfer",
    "Leuchtkäfers": "Leuchtkäfer",
    "Leuchtmaste": "Leuchtmast",
    "Leuchtmasten": "Leuchtmast",
    "Leuchtmasts": "Leuchtmast",
    "Leuchtpistolen": "Leuchtpistole",
    "Leuchtraketen": "Leuchtrakete",
    "Leuchtröhren": "Leuchtröhre",
    "Leuchtstoffe": "Leuchtstoff",
    "Leuchtstoffen": "Leuchtstoff",
    "Leuchtstoffes": "Leuchtstoff",
    "Leuchtstofflampen": "Leuchtstofflampe",
    "Leuchtstoffröhren": "Leuchtstoffröhre",
    "Leuchtstoffs": "Leuchtstoff",
    "Leuchttonnen": "Leuchttonne",
    "Leuchtwinkeln": "Leuchtwinkel",
    "Leuchtwinkels": "Leuchtwinkel",
    "Leuchtziffern": "Leuchtziffer",
    "Leugnenden": "Leugnende",
    "Leugnens": "Leugnen",
    "Leumunde": "Leumund",
    "Leumundes": "Leumund",
    "Leumunds": "Leumund",
    "Leumünder": "Leumund",
    "Leumündern": "Leumund",
    "Leuten": "Leute",
    "Leutnants": "Leutnant",
    "Leveln": "Level",
    "Levels": "Level",
    "Leverkusens": "Leverkusen",
    "Lexeme": "Lexem",
    "Lexemen": "Lexem",
    "Lexems": "Lexem",
    "Lexigraphische": "lexigraphisch",
    "Lexigraphischen": "Lexigraphische",
    "Lexika": "Lexikon",
    "Lexikalische": "lexikalisch",
    "Lexikalischen": "Lexikalische",
    "Lexikalisierenden": "Lexikalisierende",
    "Lexikalisierens": "Lexikalisieren",
    "Lexikalisierte": "lexikalisiert",
    "Lexikalisierten": "Lexikalisierte",
    "Lexikographen": "Lexikograph",
    "Lexikographische": "lexikographisch",
    "Lexikographischen": "Lexikographische",
    "Lexikons": "Lexikon",
    "Lexikotheken": "Lexikothek",
    "Liaisons": "Liaison",
    "Lianen": "Liane",
    "Libanesen": "Libanese",
    "Libanesische": "libanesisch",
    "Libanesischen": "Libanesische",
    "Libanons": "Libanon",
    "Libellen": "Libelle",
    "Liberale": "liberal",
    "Liberalen": "Liberale",
    "Liberaleren": "Liberalere",
    "Liberalisierenden": "Liberalisierende",
    "Liberalisierens": "Liberalisieren",
    "Liberalisierte": "liberalisiert",
    "Liberalisierten": "Liberalisierte",
    "Liberalisierteren": "Liberalisiertere",
    "Liberalisierteste": "liberalisiert",
    "Liberalisten": "Liberalist",
    "Liberalste": "liberal",
    "Liberalsten": "Liberalste",
    "Liberationen": "Liberation",
    "Liberos": "Libero",
    "Libyens": "Libyen",
    "Lichtbeständige": "lichtbeständig",
    "Lichtbeständigen": "Lichtbeständige",
    "Lichtbeständigeren": "Lichtbeständigere",
    "Lichtdurchlässigen": "Lichtdurchlässige",
    "Lichtdurchlässigeren": "Lichtdurchlässigere",
    "Lichte": "lichten",
    "Lichtempfindlichen": "Lichtempfindliche",
    "Lichtempfindlicheren": "Lichtempfindlichere",
    "Lichtenden": "Lichtende",
    "Lichtenhagens": "Lichtenhagen",
    "Lichtens": "Lichten",
    "Lichter": "Licht",
    "Lichtern": "Licht",
    "Lichtes": "Licht",
    "Lichts": "Licht",
    "Lichtscheue": "lichtscheu",
    "Lichtscheuen": "Lichtscheue",
    "Lichtscheueren": "Lichtscheuere",
    "Lichtscheusten": "Lichtscheuste",
    "Lichtschwachen": "Lichtschwache",
    "Lichtschwächeren": "Lichtschwächere",
    "Lichtschwächsten": "Lichtschwächste",
    "Lichtstarken": "Lichtstarke",
    "Lichtstärkeren": "Lichtstärkere",
    "Lichtstärksten": "Lichtstärkste",
    "Lichtungen": "Lichtung",
    "Liebbehaltenden": "Liebbehaltende",
    "Liebbehaltenen": "Liebbehaltene",
    "Liebbehaltens": "Liebbehalten",
    "Liebe": "lieben",
    "Liebebedürftigen": "Liebebedürftige",
    "Liebebedürftigeren": "Liebebedürftigere",
    "Liebeleien": "Liebelei",
    "Lieben": "Liebe",
    "Liebenden": "Liebende",
    "Liebenderen": "Liebendere",
    "Liebendsten": "Liebendste",
    "Liebens": "Lieben",
    "Liebenswerte": "liebenswert",
    "Liebenswerten": "Liebenswerte",
    "Liebenswerteren": "Liebenswertere",
    "Liebenswertesten": "Liebenswerteste",
    "Liebenswürdigen": "Liebenswürdige",
    "Liebenswürdigeren": "Liebenswürdigere",
    "Liebenswürdigsten": "Liebenswürdigste",
    "Lieberen": "Liebere",
    "Liebesgaben": "Liebesgabe",
    "Liebeskummers": "Liebeskummer",
    "Liebevollen": "Liebevolle",
    "Liebevolleren": "Liebevollere",
    "Liebevollsten": "Liebevollste",
    "Liebfrauenkirchen": "Liebfrauenkirche",
    "Liebgewinnenden": "Liebgewinnende",
    "Liebgewinnenderen": "Liebgewinnendere",
    "Liebgewinnendsten": "Liebgewinnendste",
    "Liebgewinnens": "Liebgewinnen",
    "Liebgewonnenen": "Liebgewonnene",
    "Liebgewonneneren": "Liebgewonnenere",
    "Liebgewonnensten": "Liebgewonnenste",
    "Liebhabern": "Liebhaber",
    "Liebhabers": "Liebhaber",
    "Liebigs": "Liebig",
    "Liebkosenden": "Liebkosende",
    "Liebkosenderen": "Liebkosendere",
    "Liebkosendsten": "Liebkosendste",
    "Liebkosens": "Liebkosen",
    "Liebkoste": "liebkost",
    "Liebkosten": "Liebkoste",
    "Liebkosungen": "Liebkosung",
    "Liebliche": "lieblich",
    "Lieblichen": "Liebliche",
    "Lieblicheren": "Lieblichere",
    "Lieblichsten": "Lieblichste",
    "Lieblinge": "Liebling",
    "Lieblingen": "Liebling",
    "Lieblings": "Liebling",
    "Lieblose": "lieblos",
    "Lieblosen": "Lieblose",
    "Liebloseren": "Lieblosere",
    "Lieblosesten": "Liebloseste",
    "Lieblosigkeiten": "Lieblosigkeit",
    "Liebreizende": "liebreizend",
    "Liebreizenden": "Liebreizende",
    "Liebreizenderen": "Liebreizendere",
    "Liebreizendsten": "Liebreizendste",
    "Liebsten": "Liebste",
    "Liebäugelnden": "Liebäugelnde",
    "Liebäugelnderen": "Liebäugelndere",
    "Liebäugelndsten": "Liebäugelndste",
    "Liebäugelns": "Liebäugeln",
    "Liede": "Lied",
    "Lieder": "Lied",
    "Liederjane": "Liederjan",
    "Liederjanen": "Liederjan",
    "Liederjans": "Liederjan",
    "Liederliche": "liederlich",
    "Liederlichen": "Liederliche",
    "Liederlicheren": "Liederlichere",
    "Liederlichsten": "Liederlichste",
    "Liedern": "Lied",
    "Liedes": "Lied",
    "Lieds": "Lied",
    "Lieferanten": "Lieferant",
    "Lieferbare": "lieferbar",
    "Lieferbaren": "Lieferbare",
    "Lieferfähigkeiten": "Lieferfähigkeit",
    "Liefernden": "Liefernde",
    "Lieferns": "Liefern",
    "Lieferscheine": "Lieferschein",
    "Lieferscheinen": "Lieferschein",
    "Lieferscheins": "Lieferschein",
    "Lieferungen": "Lieferung",
    "Liegeflächen": "Liegefläche",
    "Liegen": "Liege",
    "Liegenbleibenden": "Liegenbleibende",
    "Liegenbleibens": "Liegenbleiben",
    "Liegenden": "Liegende",
    "Liegengebliebenen": "Liegengebliebene",
    "Liegens": "Liegen",
    "Liegenschaftsamte": "Liegenschaftsamt",
    "Liegenschaftsamtes": "Liegenschaftsamt",
    "Liegenschaftsamts": "Liegenschaftsamt",
    "Liegenschaftsämter": "Liegenschaftsamt",
    "Liegenschaftsämtern": "Liegenschaftsamt",
    "Liegestuhle": "Liegestuhl",
    "Liegestuhls": "Liegestuhl",
    "Liegestühle": "Liegestuhl",
    "Liegestühlen": "Liegestuhl",
    "Liegezeiten": "Liegezeit",
    "Liesen": "Liese",
    "Lifte": "liften",
    "Liften": "Lift",
    "Liftenden": "Liftende",
    "Liftens": "Liften",
    "Liftes": "Lift",
    "Lifts": "Lift",
    "Ligaturen": "Ligatur",
    "Ligen": "Liga",
    "Liierungen": "Liierung",
    "Liköre": "Likör",
    "Likören": "Likör",
    "Liköres": "Likör",
    "Likörs": "Likör",
    "Lilien": "Lilie",
    "Liliputanern": "Liliputaner",
    "Liliputaners": "Liliputaner",
    "Limas": "Lima",
    "Limbachs": "Limbach",
    "Limburgern": "Limburger",
    "Limburgers": "Limburger",
    "Limburgs": "Limburg",
    "Limericks": "Limerick",
    "Limitationen": "Limitation",
    "Limitierenden": "Limitierende",
    "Limitierenderen": "Limitierendere",
    "Limitierendsten": "Limitierendste",
    "Limitierens": "Limitieren",
    "Limitierte": "limitiert",
    "Limitierten": "Limitierte",
    "Limitierteren": "Limitiertere",
    "Limitiertesten": "Limitierteste",
    "Limitierungen": "Limitierung",
    "Limits": "Limit",
    "Limonaden": "Limonade",
    "Limos": "Limo",
    "Limosen": "Limose",
    "Limousinen": "Limousine",
    "Lincolns": "Lincoln",
    "Lindas": "Linda",
    "Lindberghs": "Lindbergh",
    "Linden": "Linde",
    "Lindernden": "Lindernde",
    "Lindernderen": "Linderndere",
    "Linderndsten": "Linderndste",
    "Linderns": "Lindern",
    "Linderungen": "Linderung",
    "Lineale": "Lineal",
    "Linealen": "Lineal",
    "Lineals": "Lineal",
    "Lineare": "linear",
    "Linearen": "Lineare",
    "Linearmotore": "Linearmotor",
    "Linearmotoren": "Linearmotor",
    "Linearmotors": "Linearmotor",
    "Linearschriften": "Linearschrift",
    "Linearzeichnungen": "Linearzeichnung",
    "Lineaturen": "Lineatur",
    "Linguale": "lingual",
    "Lingualen": "Linguale",
    "Linguisten": "Linguist",
    "Liniaturen": "Liniatur",
    "Linien": "Linie",
    "Linienbreiten": "Linienbreite",
    "Linienrichtern": "Linienrichter",
    "Linienrichters": "Linienrichter",
    "Linierenden": "Linierende",
    "Linierens": "Linieren",
    "Linierte": "liniert",
    "Linierten": "Linierte",
    "Linken": "Linke",
    "Linkeren": "Linkere",
    "Linkesten": "Linkeste",
    "Linksabbiegern": "Linksabbieger",
    "Linksabbiegers": "Linksabbieger",
    "Linksabweichlern": "Linksabweichler",
    "Linksabweichlers": "Linksabweichler",
    "Linksdralls": "Linksdrall",
    "Linksdrehende": "linksdrehend",
    "Linksdrehenden": "Linksdrehende",
    "Linkshändern": "Linkshänder",
    "Linkshänders": "Linkshänder",
    "Linkshändige": "linkshändig",
    "Linkshändigen": "Linkshändige",
    "Linkskurven": "Linkskurve",
    "Linkslastige": "linkslastig",
    "Linkslastigen": "Linkslastige",
    "Linksliberalen": "Linksliberale",
    "Linksliberaleren": "Linksliberalere",
    "Linksliberalsten": "Linksliberalste",
    "Linksläufigen": "Linksläufige",
    "Linksradikalen": "Linksradikale",
    "Linksregierungen": "Linksregierung",
    "Linksrucke": "Linksruck",
    "Linksrucken": "Linksruck",
    "Linksrucks": "Linksruck",
    "Linksseitige": "linksseitig",
    "Linksseitigen": "Linksseitige",
    "Linkswendungen": "Linkswendung",
    "Linsen": "Linse",
    "Lipizzanern": "Lipizzaner",
    "Lipizzaners": "Lipizzaner",
    "Lippen": "Lippe",
    "Lippenblütlern": "Lippenblütler",
    "Lippenblütlers": "Lippenblütler",
    "Liptauern": "Liptauer",
    "Liptauers": "Liptauer",
    "Liquidationen": "Liquidation",
    "Liquidatore": "Liquidator",
    "Liquidatoren": "Liquidator",
    "Liquidators": "Liquidator",
    "Liquidierenden": "Liquidierende",
    "Liquidierens": "Liquidieren",
    "Liquidierte": "liquidiert",
    "Liquidierten": "Liquidierte",
    "Liquidierungen": "Liquidierung",
    "Lisas": "Lisa",
    "Lispelnden": "Lispelnde",
    "Lispelnderen": "Lispelndere",
    "Lispelndsten": "Lispelndste",
    "Lispelns": "Lispeln",
    "Lissabons": "Lissabon",
    "Liste": "listen",
    "Listen": "Liste",
    "Listenden": "Listende",
    "Listens": "Listen",
    "Listigen": "Listige",
    "Listigeren": "Listigere",
    "Listigsten": "Listigste",
    "Litaneien": "Litanei",
    "Litauens": "Litauen",
    "Litauische": "litauisch",
    "Litauischen": "Litauische",
    "Literalisierenden": "Literalisierende",
    "Literalisierens": "Literalisieren",
    "Literalisierte": "literalisiert",
    "Literalisierten": "Literalisierte",
    "Literarischen": "Literarische",
    "Literarisierenden": "Literarisierende",
    "Literarisierens": "Literarisieren",
    "Literarisierte": "literarisiert",
    "Literarisierten": "Literarisierte",
    "Litern": "Liter",
    "Liters": "Liter",
    "Litfaßsäulen": "Litfaßsäule",
    "Liturgien": "Liturgie",
    "Liturgische": "liturgisch",
    "Liturgischen": "Liturgische",
    "Litzen": "Litze",
    "Lizenzen": "Lizenz",
    "Lkws": "Lkw",
    "Lob": "loben",
    "Lobbyisten": "Lobbyist",
    "Lobe": "loben",
    "Loben": "Lob",
    "Lobenden": "Lobende",
    "Lobenderen": "Lobendere",
    "Lobendsten": "Lobendste",
    "Lobens": "Loben",
    "Lobenswerte": "lobenswert",
    "Lobenswerten": "Lobenswerte",
    "Lobenswerteren": "Lobenswertere",
    "Lobenswertesten": "Lobenswerteste",
    "Lobes": "Lob",
    "Lobhudeleien": "Lobhudelei",
    "Lobs": "Lob",
    "Lobspruche": "Lobspruch",
    "Lobspruchs": "Lobspruch",
    "Lobsprüche": "Lobspruch",
    "Lobsprüchen": "Lobspruch",
    "Loch": "lochen",
    "Loche": "lochen",
    "Lochenden": "Lochende",
    "Lochens": "Lochen",
    "Lochern": "Locher",
    "Lochers": "Locher",
    "Loches": "Loch",
    "Lochs": "Loch",
    "Lochungen": "Lochung",
    "Locke": "locken",
    "Locken": "Locke",
    "Lockenden": "Lockende",
    "Lockenderen": "Lockendere",
    "Lockendsten": "Lockendste",
    "Lockens": "Locken",
    "Lockenten": "Lockente",
    "Lockere": "lockern",
    "Lockeren": "Lockere",
    "Lockereren": "Lockerere",
    "Lockernden": "Lockernde",
    "Lockerns": "Lockern",
    "Lockersten": "Lockerste",
    "Lodernden": "Lodernde",
    "Lodernderen": "Loderndere",
    "Loderndsten": "Loderndste",
    "Loderns": "Lodern",
    "Loggenden": "Loggende",
    "Loggens": "Loggen",
    "Logikern": "Logiker",
    "Logikers": "Logiker",
    "Logische": "logisch",
    "Logischen": "Logische",
    "Logischeren": "Logischere",
    "Logischsten": "Logischste",
    "Logistischen": "Logistische",
    "Logopathien": "Logopathie",
    "Logos": "Logo",
    "Lohn": "lohnen",
    "Lohnabhängigen": "Lohnabhängige",
    "Lohnenden": "Lohnende",
    "Lohnenderen": "Lohnendere",
    "Lohnendsten": "Lohnendste",
    "Lohnens": "Lohnen",
    "Lohnn": "Lohn",
    "Lohnverzichts": "Lohnverzicht",
    "Loipen": "Loipe",
    "Lokalbehörden": "Lokalbehörde",
    "Lokale": "Lokal",
    "Lokalen": "Lokale",
    "Lokalisierenden": "Lokalisierende",
    "Lokalisierens": "Lokalisieren",
    "Lokalisierte": "lokalisiert",
    "Lokalisierten": "Lokalisierte",
    "Lokalitäten": "Lokalität",
    "Lokalredaktionen": "Lokalredaktion",
    "Lokals": "Lokal",
    "Lokomotiven": "Lokomotive",
    "Loks": "Lok",
    "Lolitas": "Lolita",
    "Lombarden": "Lombarde",
    "Lombardgeschäfte": "Lombardgeschäft",
    "Lombardgeschäften": "Lombardgeschäft",
    "Lombardgeschäfts": "Lombardgeschäft",
    "Lombardierenden": "Lombardierende",
    "Lombardierens": "Lombardieren",
    "Lombardierte": "lombardiert",
    "Lombardierten": "Lombardierte",
    "Lombardischen": "Lombardische",
    "Londonern": "Londoner",
    "Londoners": "Londoner",
    "Londons": "London",
    "Longdrinks": "Longdrink",
    "Lorbeeren": "Lorbeere",
    "Lorbeerzweige": "Lorbeerzweig",
    "Lorbeerzweigen": "Lorbeerzweig",
    "Lorbeerzweigs": "Lorbeerzweig",
    "Lords": "Lord",
    "Loriots": "Loriot",
    "Los": "losen",
    "Losarbeitenden": "Losarbeitende",
    "Losarbeitens": "Losarbeiten",
    "Losbekommenden": "Losbekommende",
    "Losbekommenen": "Losbekommene",
    "Losbekommens": "Losbekommen",
    "Losbindenden": "Losbindende",
    "Losbindens": "Losbinden",
    "Losbrausenden": "Losbrausende",
    "Losbrausens": "Losbrausen",
    "Losbrechenden": "Losbrechende",
    "Losbrechens": "Losbrechen",
    "Losbringenden": "Losbringende",
    "Losbringens": "Losbringen",
    "Losdonnernden": "Losdonnernde",
    "Losdonnerns": "Losdonnern",
    "Lose": "losen",
    "Loseblattbuchhaltungen": "Loseblattbuchhaltung",
    "Loseisenden": "Loseisende",
    "Loseisens": "Loseisen",
    "Losen": "lose",
    "Losenden": "Losende",
    "Losens": "Losen",
    "Loseren": "Losere",
    "Loses": "lose",
    "Losesten": "Loseste",
    "Losgearbeiteten": "Losgearbeitete",
    "Losgebenden": "Losgebende",
    "Losgebens": "Losgeben",
    "Losgebrachten": "Losgebrachte",
    "Losgebrausten": "Losgebrauste",
    "Losgebrochenen": "Losgebrochene",
    "Losgebundenen": "Losgebundene",
    "Losgedonnerten": "Losgedonnerte",
    "Losgeeisten": "Losgeeiste",
    "Losgegangenen": "Losgegangene",
    "Losgegebenen": "Losgegebene",
    "Losgehauchten": "Losgehauchte",
    "Losgehauenen": "Losgehauene",
    "Losgehenden": "Losgehende",
    "Losgehens": "Losgehen",
    "Losgekauften": "Losgekaufte",
    "Losgeketteten": "Losgekettete",
    "Losgekommenen": "Losgekommene",
    "Losgekoppelten": "Losgekoppelte",
    "Losgelachten": "Losgelachte",
    "Losgelassenen": "Losgelassene",
    "Losgelasseneren": "Losgelassenere",
    "Losgelassensten": "Losgelassenste",
    "Losgelaufenen": "Losgelaufene",
    "Losgelösten": "Losgelöste",
    "Losgelösteren": "Losgelöstere",
    "Losgelöstesten": "Losgelösteste",
    "Losgemachten": "Losgemachte",
    "Losgeplatzten": "Losgeplatzte",
    "Losgeplatzteren": "Losgeplatztere",
    "Losgeplatztesten": "Losgeplatzteste",
    "Losgerannten": "Losgerannte",
    "Losgerasten": "Losgeraste",
    "Losgerissenen": "Losgerissene",
    "Losgesagten": "Losgesagte",
    "Losgeschlagenen": "Losgeschlagene",
    "Losgeschossenen": "Losgeschossene",
    "Losgeschraubten": "Losgeschraubte",
    "Losgesprochenen": "Losgesprochene",
    "Losgesprungenen": "Losgesprungene",
    "Losgesteuerten": "Losgesteuerte",
    "Losgestürmten": "Losgestürmte",
    "Losgetrennten": "Losgetrennte",
    "Losgetretenen": "Losgetretene",
    "Losgezogenen": "Losgezogene",
    "Loshauchenden": "Loshauchende",
    "Loshauchens": "Loshauchen",
    "Loshauenden": "Loshauende",
    "Loshauens": "Loshauen",
    "Loskaufe": "loskaufen",
    "Loskaufenden": "Loskaufende",
    "Loskaufens": "Loskaufen",
    "Loskaufs": "Loskauf",
    "Loskettenden": "Loskettende",
    "Loskettens": "Losketten",
    "Loskommenden": "Loskommende",
    "Loskommens": "Loskommen",
    "Loskoppelnden": "Loskoppelnde",
    "Loskoppelns": "Loskoppeln",
    "Loskäufe": "Loskauf",
    "Loskäufen": "Loskauf",
    "Loslachenden": "Loslachende",
    "Loslachenderen": "Loslachendere",
    "Loslachendsten": "Loslachendste",
    "Loslachens": "Loslachen",
    "Loslassenden": "Loslassende",
    "Loslassenderen": "Loslassendere",
    "Loslassendsten": "Loslassendste",
    "Loslassens": "Loslassen",
    "Loslaufenden": "Loslaufende",
    "Loslaufens": "Loslaufen",
    "Loslösenden": "Loslösende",
    "Loslösenderen": "Loslösendere",
    "Loslösendsten": "Loslösendste",
    "Loslösens": "Loslösen",
    "Losmachenden": "Losmachende",
    "Losmachens": "Losmachen",
    "Losmarschierenden": "Losmarschierende",
    "Losmarschierens": "Losmarschieren",
    "Losmarschierte": "losmarschiert",
    "Losmarschierten": "Losmarschierte",
    "Losplatzenden": "Losplatzende",
    "Losplatzenderen": "Losplatzendere",
    "Losplatzendsten": "Losplatzendste",
    "Losplatzens": "Losplatzen",
    "Losrasenden": "Losrasende",
    "Losrasens": "Losrasen",
    "Losreißenden": "Losreißende",
    "Losreißens": "Losreißen",
    "Losrennenden": "Losrennende",
    "Losrennens": "Losrennen",
    "Lossagenden": "Lossagende",
    "Lossagens": "Lossagen",
    "Lossagungen": "Lossagung",
    "Losschießenden": "Losschießende",
    "Losschießens": "Losschießen",
    "Losschlagenden": "Losschlagende",
    "Losschlagens": "Losschlagen",
    "Losschraubenden": "Losschraubende",
    "Losschraubens": "Losschrauben",
    "Lossprechenden": "Lossprechende",
    "Lossprechens": "Lossprechen",
    "Losspringenden": "Losspringende",
    "Losspringens": "Losspringen",
    "Lossteuernden": "Lossteuernde",
    "Lossteuerns": "Lossteuern",
    "Losstürmenden": "Losstürmende",
    "Losstürmens": "Losstürmen",
    "Lostrennenden": "Lostrennende",
    "Lostrennens": "Lostrennen",
    "Lostretenden": "Lostretende",
    "Lostretens": "Lostreten",
    "Losungen": "Losung",
    "Losziehenden": "Losziehende",
    "Losziehens": "Losziehen",
    "Lotenden": "Lotende",
    "Lotens": "Loten",
    "Lothars": "Lothar",
    "Lotionen": "Lotion",
    "Lotrechte": "lotrecht",
    "Lotrechten": "Lotrechte",
    "Lotsenden": "Lotsende",
    "Lotsens": "Lotsen",
    "Lotterien": "Lotterie",
    "Lotterige": "lotterig",
    "Lotterigen": "Lotterige",
    "Lotterigeren": "Lotterigere",
    "Lotterigsten": "Lotterigste",
    "Lottermanns": "Lottermann",
    "Lotternden": "Lotternde",
    "Lotternderen": "Lotterndere",
    "Lotterndsten": "Lotterndste",
    "Lotterns": "Lottern",
    "Lotterwirtschaften": "Lotterwirtschaft",
    "Lotungen": "Lotung",
    "Lotusblumen": "Lotusblume",
    "Ludern": "Luder",
    "Luders": "Luder",
    "Ludwigs": "Ludwig",
    "Ludwigshafenern": "Ludwigshafener",
    "Ludwigshafeners": "Ludwigshafener",
    "Ludwigshafens": "Ludwigshafen",
    "Luftaufnahmen": "Luftaufnahme",
    "Luftballons": "Luftballon",
    "Luftdichte": "luftdicht",
    "Luftdichten": "Luftdichte",
    "Luftdruckbremsen": "Luftdruckbremse",
    "Luftigen": "Luftige",
    "Luftigeren": "Luftigere",
    "Luftigsten": "Luftigste",
    "Luftleeren": "Luftleere",
    "Luftmarschalls": "Luftmarschall",
    "Lugenden": "Lugende",
    "Lugens": "Lugen",
    "Luken": "Luke",
    "Lukrative": "lukrativ",
    "Lukrativen": "Lukrative",
    "Lukrativeren": "Lukrativere",
    "Lukrativsten": "Lukrativste",
    "Lullenden": "Lullende",
    "Lullens": "Lullen",
    "Lulus": "Lulu",
    "Lummers": "Lummer",
    "Lumpen": "Lump",
    "Lumpengesindels": "Lumpengesindel",
    "Lumpens": "Lumpen",
    "Lumpereien": "Lumperei",
    "Lumpige": "lumpig",
    "Lumpigen": "Lumpige",
    "Lumpigeren": "Lumpigere",
    "Lumpigsten": "Lumpigste",
    "Lunatikern": "Lunatiker",
    "Lunatikers": "Lunatiker",
    "Lunatische": "lunatisch",
    "Lunatischen": "Lunatische",
    "Lungen": "Lunge",
    "Lungenkranke": "lungenkrank",
    "Lungenkranken": "Lungenkranke",
    "Lungernden": "Lungernde",
    "Lungerns": "Lungern",
    "Lunten": "Lunte",
    "Lupen": "Lupe",
    "Lupenreine": "lupenrein",
    "Lupenreinen": "Lupenreine",
    "Lupfenden": "Lupfende",
    "Lupfens": "Lupfen",
    "Lurche": "Lurch",
    "Lurchen": "Lurch",
    "Lurches": "Lurch",
    "Lurchs": "Lurch",
    "Luschen": "Lusche",
    "Lustbetonte": "lustbetont",
    "Lustbetonten": "Lustbetonte",
    "Lustbetonteren": "Lustbetontere",
    "Lustbetontesten": "Lustbetonteste",
    "Lustige": "lustig",
    "Lustigen": "Lustige",
    "Lustigeren": "Lustigere",
    "Lustigsten": "Lustigste",
    "Lustlose": "lustlos",
    "Lustlosen": "Lustlose",
    "Lustloseren": "Lustlosere",
    "Lustlosesten": "Lustloseste",
    "Lustspiele": "Lustspiel",
    "Lustspielen": "Lustspiel",
    "Lustspiels": "Lustspiel",
    "Lustvolle": "lustvoll",
    "Lustvollen": "Lustvolle",
    "Lustvolleren": "Lustvollere",
    "Lustvollsten": "Lustvollste",
    "Lutetiums": "Lutetium",
    "Lutheranern": "Lutheraner",
    "Lutheraners": "Lutheraner",
    "Luthers": "Luther",
    "Luthertums": "Luthertum",
    "Lutschenden": "Lutschende",
    "Lutschens": "Lutschen",
    "Lutschern": "Lutscher",
    "Lutschers": "Lutscher",
    "Luxemburgs": "Luxemburg",
    "Luxuriöse": "luxuriös",
    "Luxuriösen": "Luxuriöse",
    "Luxuriöseren": "Luxuriösere",
    "Luxuriösesten": "Luxuriöseste",
    "Lymphdrüsen": "Lymphdrüse",
    "Lymphen": "Lymphe",
    "Lymphknotens": "Lymphknoten",
    "Lyriken": "Lyrik",
    "Lyrikern": "Lyriker",
    "Lyrikers": "Lyriker",
    "Lyrische": "lyrisch",
    "Lyrischen": "Lyrische",
    "Lyrischeren": "Lyrischere",
    "Lyrischsten": "Lyrischste",
    "Lysoforms": "Lysoform",
    "Lächelnden": "Lächelnde",
    "Lächelnderen": "Lächelndere",
    "Lächelndsten": "Lächelndste",
    "Lächelns": "Lächeln",
    "Lächerliche": "lächerlich",
    "Lächerlichen": "Lächerliche",
    "Lächerlicheren": "Lächerlichere",
    "Lächerlichkeiten": "Lächerlichkeit",
    "Lächerlichste": "lächerlich",
    "Lächerlichsten": "Lächerlichste",
    "Lädchens": "Lädchen",
    "Lädierenden": "Lädierende",
    "Lädierenderen": "Lädierendere",
    "Lädierendsten": "Lädierendste",
    "Lädierens": "Lädieren",
    "Lädierte": "lädiert",
    "Lädierten": "Lädierte",
    "Lädierteren": "Lädiertere",
    "Lädiertesten": "Lädierteste",
    "Lädierungen": "Lädierung",
    "Lähmende": "lähmend",
    "Lähmenden": "Lähmende",
    "Lähmendere": "lähmend",
    "Lähmenderen": "Lähmendere",
    "Lähmendste": "lähmend",
    "Lähmendsten": "Lähmendste",
    "Lähmens": "Lähmen",
    "Lämmer": "Lamm",
    "Lämmern": "Lamm",
    "Lämmleins": "Lämmlein",
    "Lämpchens": "Lämpchen",
    "Lämpleins": "Lämplein",
    "Ländchens": "Ländchen",
    "Länder": "Land",
    "Ländereien": "Länderei",
    "Ländern": "Land",
    "Ländlichen": "Ländliche",
    "Ländlicheren": "Ländlichere",
    "Ländlichsten": "Ländlichste",
    "Längen": "Länge",
    "Längeren": "Längere",
    "Längerfristigen": "Längerfristige",
    "Länglichen": "Längliche",
    "Länglicheren": "Länglichere",
    "Länglichsten": "Länglichste",
    "Längsschnitte": "Längsschnitt",
    "Längsschnitten": "Längsschnitt",
    "Längsschnitts": "Längsschnitt",
    "Längsstriche": "Längsstrich",
    "Längsstrichen": "Längsstrich",
    "Längsstrichs": "Längsstrich",
    "Längstale": "Längstal",
    "Längstales": "Längstal",
    "Längstals": "Längstal",
    "Längste": "lang",
    "Längsten": "Längste",
    "Längstäler": "Längstal",
    "Längstälern": "Längstal",
    "Längswellen": "Längswelle",
    "Läppchens": "Läppchen",
    "Läppernden": "Läppernde",
    "Läpperns": "Läppern",
    "Läppleins": "Läpplein",
    "Lärchen": "Lärche",
    "Lärm": "lärmen",
    "Lärmenden": "Lärmende",
    "Lärmenderen": "Lärmendere",
    "Lärmendsten": "Lärmendste",
    "Lärmens": "Lärmen",
    "Lärms": "Lärm",
    "Lässigen": "Lässige",
    "Lässigeren": "Lässigere",
    "Lässigkeiten": "Lässigkeit",
    "Lässigste": "lässig",
    "Lässigsten": "Lässigste",
    "Lästerern": "Lästerer",
    "Lästerers": "Lästerer",
    "Lästermaule": "Lästermaul",
    "Lästermauls": "Lästermaul",
    "Lästermäuler": "Lästermaul",
    "Lästermäulern": "Lästermaul",
    "Lästernden": "Lästernde",
    "Lästernderen": "Lästerndere",
    "Lästerndsten": "Lästerndste",
    "Lästerns": "Lästern",
    "Lästerzungen": "Lästerzunge",
    "Lästigen": "Lästige",
    "Lästigeren": "Lästigere",
    "Lästigsten": "Lästigste",
    "Läufchens": "Läufchen",
    "Läufe": "Lauf",
    "Läufen": "Lauf",
    "Läufigen": "Läufige",
    "Läufigeren": "Läufigere",
    "Läufigsten": "Läufigste",
    "Läuse": "Laus",
    "Läusen": "Laus",
    "Läutende": "läutend",
    "Läutenden": "Läutende",
    "Läutens": "Läuten",
    "Löbliche": "löblich",
    "Löblichen": "Löbliche",
    "Löcher": "löchern",
    "Löcherigen": "Löcherige",
    "Löcherigeren": "Löcherigere",
    "Löcherigsten": "Löcherigste",
    "Löchern": "Loch",
    "Löchernden": "Löchernde",
    "Löcherns": "Löchern",
    "Löchleins": "Löchlein",
    "Löchrige": "löchrig",
    "Löchrigen": "Löchrige",
    "Löchrigeren": "Löchrigere",
    "Löchrigsten": "Löchrigste",
    "Löffel": "löffeln",
    "Löffeln": "Löffel",
    "Löffelnden": "Löffelnde",
    "Löffelns": "Löffeln",
    "Löffels": "Löffel",
    "Löfflern": "Löffler",
    "Löfflers": "Löffler",
    "Löhnen": "Lohn",
    "Löhnende": "löhnend",
    "Löhnenden": "Löhnende",
    "Löhnens": "Löhnen",
    "Lösbaren": "Lösbare",
    "Löschblatte": "Löschblatt",
    "Löschblattes": "Löschblatt",
    "Löschblatts": "Löschblatt",
    "Löschblätter": "Löschblatt",
    "Löschblättern": "Löschblatt",
    "Löschenden": "Löschende",
    "Löschens": "Löschen",
    "Löschern": "Löscher",
    "Löschers": "Löscher",
    "Löschgeräte": "Löschgerät",
    "Löschgeräten": "Löschgerät",
    "Löschgeräts": "Löschgerät",
    "Löschmannschaften": "Löschmannschaft",
    "Löschpapiere": "Löschpapier",
    "Löschpapieren": "Löschpapier",
    "Löschpapiers": "Löschpapier",
    "Löschtasten": "Löschtaste",
    "Löschtrupps": "Löschtrupp",
    "Lösegelde": "Lösegeld",
    "Lösegelder": "Lösegeld",
    "Lösegeldern": "Lösegeld",
    "Lösegeldes": "Lösegeld",
    "Lösegelds": "Lösegeld",
    "Lösemitteln": "Lösemittel",
    "Lösemittels": "Lösemittel",
    "Lösende": "lösend",
    "Lösenden": "Lösende",
    "Lösens": "Lösen",
    "Löslichen": "Lösliche",
    "Löslicheren": "Löslichere",
    "Löslichsten": "Löslichste",
    "Lösungen": "Lösung",
    "Lösungsmitteln": "Lösungsmittel",
    "Lösungsmittels": "Lösungsmittel",
    "Lötende": "lötend",
    "Lötenden": "Lötende",
    "Lötens": "Löten",
    "Lötfugen": "Lötfuge",
    "Lötkolbens": "Lötkolben",
    "Lötpistolen": "Lötpistole",
    "Lötrohranalysen": "Lötrohranalyse",
    "Lötrohre": "Lötrohr",
    "Lötrohren": "Lötrohr",
    "Lötrohrs": "Lötrohr",
    "Lötwassers": "Lötwasser",
    "Löwen": "Löwe",
    "Löwenstarke": "löwenstark",
    "Löwenstarken": "Löwenstarke",
    "Löwinnen": "Löwin",
    "Lübecks": "Lübeck",
    "Lücken": "Lücke",
    "Lüfte": "lüften",
    "Lüften": "Luft",
    "Lüftenden": "Lüftende",
    "Lüftens": "Lüften",
    "Lüftern": "Lüfter",
    "Lüfters": "Lüfter",
    "Lüftungen": "Lüftung",
    "Lügen": "Lüge",
    "Lügende": "lügend",
    "Lügenden": "Lügende",
    "Lügenhaften": "Lügenhafte",
    "Lügens": "Lügen",
    "Lügnerischen": "Lügnerische",
    "Lügnerischeren": "Lügnerischere",
    "Lügnerischsten": "Lügnerischste",
    "Lümmel": "lümmeln",
    "Lümmeln": "Lümmel",
    "Lümmelnden": "Lümmelnde",
    "Lümmelns": "Lümmeln",
    "Lümmels": "Lümmel",
    "Lüste": "Lust",
    "Lüsten": "Lust",
    "Lüstern": "Lüster",
    "Lüsterne": "lüstern",
    "Lüsternen": "Lüsterne",
    "Lüsterneren": "Lüsternere",
    "Lüsternsten": "Lüsternste",
    "Lüsters": "Lüster",
    "Lüstlinge": "Lüstling",
    "Lüstlingen": "Lüstling",
    "Lüstlings": "Lüstling",
    "Lütten": "Lütte",
    "Lütteren": "Lüttere",
    "Lüttesten": "Lütteste",
    "Maastrichtern": "Maastrichter",
    "Maastrichters": "Maastrichter",
    "Maastrichts": "Maastricht",
    "Machbare": "machbar",
    "Machbaren": "Machbare",
    "Machbareren": "Machbarere",
    "Machbarsten": "Machbarste",
    "Machenden": "Machende",
    "Machens": "Machen",
    "Machenschaften": "Machenschaft",
    "Machern": "Macher",
    "Machers": "Macher",
    "Machos": "Macho",
    "Machthabern": "Machthaber",
    "Machthabers": "Machthaber",
    "Machtlosen": "Machtlose",
    "Machtloseren": "Machtlosere",
    "Machtlosesten": "Machtloseste",
    "Machwerke": "Machwerk",
    "Machwerken": "Machwerk",
    "Machwerks": "Machwerk",
    "Machzahlen": "Machzahl",
    "Macken": "Macke",
    "Madagassen": "Madagasse",
    "Maden": "Made",
    "Madige": "madig",
    "Madigen": "Madige",
    "Madigeren": "Madigere",
    "Madigsten": "Madigste",
    "Madonnen": "Madonna",
    "Madrids": "Madrid",
    "Mafias": "Mafia",
    "Magazine": "Magazin",
    "Magazinen": "Magazin",
    "Magazins": "Magazin",
    "Magdeburgern": "Magdeburger",
    "Magdeburgers": "Magdeburger",
    "Magdeburgs": "Magdeburg",
    "Magens": "Magen",
    "Magere": "magern",
    "Mageren": "Magere",
    "Magereren": "Magerere",
    "Magernden": "Magernde",
    "Magerns": "Magern",
    "Magersten": "Magerste",
    "Magersüchtigen": "Magersüchtige",
    "Magersüchtigeren": "Magersüchtigere",
    "Magersüchtigsten": "Magersüchtigste",
    "Magiern": "Magier",
    "Magiers": "Magier",
    "Magische": "magisch",
    "Magischen": "Magische",
    "Magischeren": "Magischere",
    "Magischsten": "Magischste",
    "Magistern": "Magister",
    "Magisters": "Magister",
    "Magistrate": "Magistrat",
    "Magistraten": "Magistrat",
    "Magistrates": "Magistrat",
    "Magistrats": "Magistrat",
    "Magnesiums": "Magnesium",
    "Magneten": "Magnet",
    "Magrittes": "Magritte",
    "Maharadschas": "Maharadscha",
    "Maharanis": "Maharani",
    "Maharashtras": "Maharashtra",
    "Mahl": "mahlen",
    "Mahle": "mahlen",
    "Mahlen": "Mahl",
    "Mahlenden": "Mahlende",
    "Mahlens": "Mahlen",
    "Mahls": "Mahl",
    "Mahlzeiten": "Mahlzeit",
    "Mahnenden": "Mahnende",
    "Mahnenderen": "Mahnendere",
    "Mahnendsten": "Mahnendste",
    "Mahnens": "Mahnen",
    "Mahnern": "Mahner",
    "Mahners": "Mahner",
    "Mahnmale": "Mahnmal",
    "Mahnmalen": "Mahnmal",
    "Mahnmals": "Mahnmal",
    "Mahnungen": "Mahnung",
    "Mahnverfahrens": "Mahnverfahren",
    "Mahnwachen": "Mahnwache",
    "Maiden": "Maid",
    "Maiers": "Maier",
    "Mains": "Main",
    "Maintalern": "Maintaler",
    "Maintalers": "Maintaler",
    "Maintals": "Maintal",
    "Mainzern": "Mainzer",
    "Mainzers": "Mainzer",
    "Mais": "Mai",
    "Maitressen": "Maitresse",
    "Maizieres": "Maiziere",
    "Majestäten": "Majestät",
    "Majestätische": "majestätisch",
    "Majestätischen": "Majestätische",
    "Majors": "Major",
    "Makabere": "makaber",
    "Makaberen": "Makabere",
    "Makabereren": "Makaberere",
    "Makabersten": "Makaberste",
    "Makellosen": "Makellose",
    "Makelloseren": "Makellosere",
    "Makellosesten": "Makelloseste",
    "Makeln": "Makel",
    "Makels": "Makel",
    "Makeups": "Makeup",
    "Maklern": "Makler",
    "Maklers": "Makler",
    "Makrelen": "Makrele",
    "Makroanalysen": "Makroanalyse",
    "Makroaufnahmen": "Makroaufnahme",
    "Makrofotografien": "Makrofotografie",
    "Makroklimas": "Makroklima",
    "Makromoleküle": "Makromolekül",
    "Makromolekülen": "Makromolekül",
    "Makromoleküls": "Makromolekül",
    "Makronen": "Makrone",
    "Makulaturen": "Makulatur",
    "Mal": "malen",
    "Malagas": "Malaga",
    "Malaien": "Malaie",
    "Male": "malen",
    "Malen": "Mal",
    "Malenden": "Malende",
    "Malens": "Malen",
    "Malerinnen": "Malerin",
    "Malerische": "malerisch",
    "Malerischen": "Malerische",
    "Malerischeren": "Malerischere",
    "Malerischsten": "Malerischste",
    "Malern": "Maler",
    "Malers": "Maler",
    "Males": "Mal",
    "Malgenommenen": "Malgenommene",
    "Malis": "Mali",
    "Mallorcas": "Mallorca",
    "Malnehmenden": "Malnehmende",
    "Malnehmens": "Malnehmen",
    "Mals": "Mal",
    "Maltesern": "Malteser",
    "Maltesers": "Malteser",
    "Malzeichens": "Malzeichen",
    "Mamas": "Mama",
    "Mambos": "Mambo",
    "Mammographien": "Mammographie",
    "Mammons": "Mammon",
    "Mampfenden": "Mampfende",
    "Mampfenderen": "Mampfendere",
    "Mampfendsten": "Mampfendste",
    "Mampfens": "Mampfen",
    "Managements": "Management",
    "Managenden": "Managende",
    "Managens": "Managen",
    "Managern": "Manager",
    "Managers": "Manager",
    "Managuas": "Managua",
    "Manchesters": "Manchester",
    "Mandanten": "Mandant",
    "Mandarinen": "Mandarine",
    "Mandate": "Mandat",
    "Mandaten": "Mandat",
    "Mandates": "Mandat",
    "Mandats": "Mandat",
    "Mandeln": "Mandel",
    "Mandolinen": "Mandoline",
    "Manegen": "Manege",
    "Manfreds": "Manfred",
    "Mangel": "mangeln",
    "Mangelberufe": "Mangelberuf",
    "Mangelberufen": "Mangelberuf",
    "Mangelberufs": "Mangelberuf",
    "Mangelhaften": "Mangelhafte",
    "Mangelhafteren": "Mangelhaftere",
    "Mangelhaftesten": "Mangelhafteste",
    "Mangeln": "Mangel",
    "Mangelnden": "Mangelnde",
    "Mangelns": "Mangeln",
    "Mangels": "Mangel",
    "Mangopflaumen": "Mangopflaume",
    "Mangos": "Mango",
    "Manien": "Manie",
    "Manieren": "Manier",
    "Manierliche": "manierlich",
    "Manierlichen": "Manierliche",
    "Manierlicheren": "Manierlichere",
    "Manierlichsten": "Manierlichste",
    "Manifestanten": "Manifestant",
    "Manifestationen": "Manifestation",
    "Manifeste": "Manifest",
    "Manifesten": "Manifest",
    "Manifestiere": "manifestieren",
    "Manifestierenden": "Manifestierende",
    "Manifestierenderen": "Manifestierendere",
    "Manifestierens": "Manifestieren",
    "Manifestierte": "manifestiert",
    "Manifestierten": "Manifestierte",
    "Manifestierteren": "Manifestiertere",
    "Manifestiertesten": "Manifestierteste",
    "Manifests": "Manifest",
    "Maniküren": "Maniküre",
    "Manipulationen": "Manipulation",
    "Manipulierbare": "manipulierbar",
    "Manipulierbaren": "Manipulierbare",
    "Manipulierbareren": "Manipulierbarere",
    "Manipulierbarsten": "Manipulierbarste",
    "Manipulierenden": "Manipulierende",
    "Manipulierens": "Manipulieren",
    "Manipulierte": "manipuliert",
    "Manipulierten": "Manipulierte",
    "Manipulierteren": "Manipuliertere",
    "Manipuliertesten": "Manipulierteste",
    "Manischen": "Manische",
    "Manischeren": "Manischere",
    "Manischsten": "Manischste",
    "Manitus": "Manitu",
    "Mankos": "Manko",
    "Manne": "Mann",
    "Mannequins": "Mannequin",
    "Mannes": "Mann",
    "Mannhafte": "mannhaft",
    "Mannhaften": "Mannhafte",
    "Mannhafteren": "Mannhaftere",
    "Mannhaftesten": "Mannhafteste",
    "Mannheimern": "Mannheimer",
    "Mannheimers": "Mannheimer",
    "Mannheims": "Mannheim",
    "Mannigfache": "mannigfach",
    "Mannigfachen": "Mannigfache",
    "Mannigfaltigen": "Mannigfaltige",
    "Mannigfaltigeren": "Mannigfaltigere",
    "Mannigfaltigsten": "Mannigfaltigste",
    "Manns": "Mann",
    "Mannsbilde": "Mannsbild",
    "Mannsbilder": "Mannsbild",
    "Mannsbildern": "Mannsbild",
    "Mannsbildes": "Mannsbild",
    "Mannsbilds": "Mannsbild",
    "Mannschaften": "Mannschaft",
    "Mansarden": "Mansarde",
    "Manschetten": "Manschette",
    "Mantels": "Mantel",
    "Manuelas": "Manuela",
    "Manuelle": "manuell",
    "Manuellen": "Manuelle",
    "Manuelleren": "Manuellere",
    "Manuellsten": "Manuellste",
    "Manuskripte": "Manuskript",
    "Manuskripten": "Manuskript",
    "Manuskriptes": "Manuskript",
    "Manuskripts": "Manuskript",
    "Manövern": "Manöver",
    "Manövers": "Manöver",
    "Mappen": "Mappe",
    "Maracujas": "Maracuja",
    "Marathons": "Marathon",
    "Marburgern": "Marburger",
    "Marburgers": "Marburger",
    "Marburgs": "Marburg",
    "Marcels": "Marcel",
    "Marcos": "Marco",
    "Marcs": "Marc",
    "Mardern": "Marder",
    "Marders": "Marder",
    "Margaretes": "Margarete",
    "Margarethas": "Margaretha",
    "Margarethes": "Margarethe",
    "Margarets": "Margaret",
    "Margarinen": "Margarine",
    "Margeriten": "Margerite",
    "Marginale": "marginal",
    "Marginalen": "Marginale",
    "Margots": "Margot",
    "Margrets": "Margret",
    "Margrittes": "Margritte",
    "Mariannes": "Marianne",
    "Marienbilde": "Marienbild",
    "Marienbilder": "Marienbild",
    "Marienbildern": "Marienbild",
    "Marienbildes": "Marienbild",
    "Marienbilds": "Marienbild",
    "Maries": "Marie",
    "Marimbas": "Marimba",
    "Marinaden": "Marinade",
    "Marinierenden": "Marinierende",
    "Marinierens": "Marinieren",
    "Marinierte": "mariniert",
    "Marinierten": "Marinierte",
    "Marionetten": "Marionette",
    "Marions": "Marion",
    "Marios": "Mario",
    "Maritime": "maritim",
    "Maritimen": "Maritime",
    "Markanten": "Markante",
    "Markanteren": "Markantere",
    "Markantesten": "Markanteste",
    "Marke": "Mark",
    "Marken": "Marke",
    "Marketendereien": "Marketenderei",
    "Marketings": "Marketing",
    "Markierenden": "Markierende",
    "Markierens": "Markieren",
    "Markierte": "markiert",
    "Markierten": "Markierte",
    "Markierteren": "Markiertere",
    "Markiertesten": "Markierteste",
    "Markierungen": "Markierung",
    "Markige": "markig",
    "Markigen": "Markige",
    "Markigeren": "Markigere",
    "Markigsten": "Markigste",
    "Markisen": "Markise",
    "Marktbeherrschende": "marktbeherrschend",
    "Marktbeherrschenden": "Marktbeherrschende",
    "Markte": "Markt",
    "Marktfähige": "marktfähig",
    "Marktfähigen": "Marktfähige",
    "Marktgerechten": "Marktgerechte",
    "Marktgerechteren": "Marktgerechtere",
    "Marktgerechtesten": "Marktgerechteste",
    "Marktlichen": "Marktliche",
    "Markts": "Markt",
    "Marmeladen": "Marmelade",
    "Marmorierenden": "Marmorierende",
    "Marmorierenderen": "Marmorierendere",
    "Marmorierendsten": "Marmorierendste",
    "Marmorierens": "Marmorieren",
    "Marmorierte": "marmoriert",
    "Marmorierten": "Marmorierte",
    "Marmorierteren": "Marmoriertere",
    "Marmoriertesten": "Marmorierteste",
    "Marmors": "Marmor",
    "Maroderen": "Marodere",
    "Marodesten": "Marodeste",
    "Marokkanischen": "Marokkanische",
    "Marokkos": "Marokko",
    "Marotten": "Marotte",
    "Marschallinnen": "Marschallin",
    "Marschalls": "Marschall",
    "Marsche": "Marsch",
    "Marsches": "Marsch",
    "Marschierenden": "Marschierende",
    "Marschierens": "Marschieren",
    "Marschierte": "marschiert",
    "Marschierten": "Marschierte",
    "Marschs": "Marsch",
    "Marseilles": "Marseille",
    "Marternden": "Marternde",
    "Marternderen": "Marterndere",
    "Marterndsten": "Marterndste",
    "Marterns": "Martern",
    "Marterungen": "Marterung",
    "Martins": "Martin",
    "Martinsgänse": "Martinsgans",
    "Martinsgänsen": "Martinsgans",
    "Marxistische": "marxistisch",
    "Marxistischen": "Marxistische",
    "Marxistischeren": "Marxistischere",
    "Marxistischsten": "Marxistischste",
    "Marys": "Mary",
    "Marzahns": "Marzahn",
    "Maschen": "Masche",
    "Maschinelle": "maschinell",
    "Maschinellen": "Maschinelle",
    "Maschinelleren": "Maschinellere",
    "Maschinellsten": "Maschinellste",
    "Maschinen": "Maschine",
    "Maschinenlesbare": "maschinenlesbar",
    "Maschinenlesbaren": "Maschinenlesbare",
    "Maschinenpistolen": "Maschinenpistole",
    "Masernden": "Masernde",
    "Maserns": "Masern",
    "Masken": "Maske",
    "Maskenhafte": "maskenhaft",
    "Maskenhaften": "Maskenhafte",
    "Maskenhafteren": "Maskenhaftere",
    "Maskenhaftesten": "Maskenhafteste",
    "Maskierenden": "Maskierende",
    "Maskierens": "Maskieren",
    "Maskierte": "maskiert",
    "Maskierten": "Maskierte",
    "Maskierungen": "Maskierung",
    "Massagen": "Massage",
    "Massakern": "Massaker",
    "Massakers": "Massaker",
    "Massas": "Massa",
    "Masseln": "Massel",
    "Massels": "Massel",
    "Massen": "Masse",
    "Massenhaften": "Massenhafte",
    "Massierenden": "Massierende",
    "Massierens": "Massieren",
    "Massierte": "massiert",
    "Massierten": "Massierte",
    "Massierteren": "Massiertere",
    "Massiertesten": "Massierteste",
    "Massigen": "Massige",
    "Massiven": "Massive",
    "Massiveren": "Massivere",
    "Massivsten": "Massivste",
    "Masten": "Mast",
    "Mastikatore": "Mastikator",
    "Mastikatoren": "Mastikator",
    "Mastikators": "Mastikator",
    "Masturbierenden": "Masturbierende",
    "Masturbierenderen": "Masturbierendere",
    "Masturbierendsten": "Masturbierendste",
    "Masturbierens": "Masturbieren",
    "Masturbierte": "masturbiert",
    "Masturbierten": "Masturbierte",
    "Matchs": "Match",
    "Materialien": "Material",
    "Materialisierenden": "Materialisierende",
    "Materialisierenderen": "Materialisierendere",
    "Materialisierens": "Materialisieren",
    "Materialisierte": "materialisiert",
    "Materialisierten": "Materialisierte",
    "Materialisierteren": "Materialisiertere",
    "Materialistischen": "Materialistische",
    "Materialistischeren": "Materialistischere",
    "Materials": "Material",
    "Materielle": "materiell",
    "Materiellen": "Materielle",
    "Materielleren": "Materiellere",
    "Materiellsten": "Materiellste",
    "Mathematischen": "Mathematische",
    "Mathematischeren": "Mathematischere",
    "Mathematischsten": "Mathematischste",
    "Mathematisierenden": "Mathematisierende",
    "Mathematisierens": "Mathematisieren",
    "Mathematisierte": "mathematisiert",
    "Mathematisierten": "Mathematisierte",
    "Mathematisierungen": "Mathematisierung",
    "Matineen": "Matinee",
    "Matratzen": "Matratze",
    "Matrikeln": "Matrikel",
    "Matrizen": "Matrize",
    "Matronen": "Matrone",
    "Matrosen": "Matrose",
    "Matsche": "Matsch",
    "Matschen": "Matsch",
    "Matsches": "Matsch",
    "Matschige": "matschig",
    "Matschigen": "Matschige",
    "Matschigeren": "Matschigere",
    "Matschigsten": "Matschigste",
    "Matten": "Matte",
    "Matteren": "Mattere",
    "Mattesten": "Matteste",
    "Mattmüllers": "Mattmüller",
    "Mattscheiben": "Mattscheibe",
    "Mauer": "mauern",
    "Mauern": "Mauer",
    "Mauernden": "Mauernde",
    "Mauerns": "Mauern",
    "Maul": "maulen",
    "Maule": "maulen",
    "Maulenden": "Maulende",
    "Maulenderen": "Maulendere",
    "Maulendsten": "Maulendste",
    "Maulens": "Maulen",
    "Mauls": "Maul",
    "Maulschellen": "Maulschelle",
    "Maultiere": "Maultier",
    "Maultieren": "Maultier",
    "Maultiers": "Maultier",
    "Mauren": "Maure",
    "Maurern": "Maurer",
    "Maurers": "Maurer",
    "Maurices": "Maurice",
    "Mauschelnden": "Mauschelnde",
    "Mauschelnderen": "Mauschelndere",
    "Mauschelndsten": "Mauschelndste",
    "Mauschelns": "Mauscheln",
    "Mausernden": "Mausernde",
    "Mausernderen": "Mauserndere",
    "Mauserndsten": "Mauserndste",
    "Mauserns": "Mausern",
    "Maxima": "Maximum",
    "Maximale": "maximal",
    "Maximalen": "Maximale",
    "Maximen": "Maxime",
    "Maximierenden": "Maximierende",
    "Maximierenderen": "Maximierendere",
    "Maximierendsten": "Maximierendste",
    "Maximierens": "Maximieren",
    "Maximierte": "maximiert",
    "Maximierten": "Maximierte",
    "Maximierteren": "Maximiertere",
    "Maximiertesten": "Maximierteste",
    "Maximums": "Maximum",
    "Maxs": "Max",
    "Mayers": "Mayer",
    "Mayonnaisen": "Mayonnaise",
    "Mays": "May",
    "Mazedoniern": "Mazedonier",
    "Mazedoniers": "Mazedonier",
    "Mazedonische": "mazedonisch",
    "Mazedonischen": "Mazedonische",
    "Mazowieckis": "Mazowiecki",
    "Maß": "maßen",
    "Maße": "maßen",
    "Maßen": "messen",
    "Maßenden": "Maßende",
    "Maßenderen": "Maßendere",
    "Maßendsten": "Maßendste",
    "Maßens": "Maßen",
    "Maßes": "Maß",
    "Maßgeblichen": "Maßgebliche",
    "Maßgehaltenen": "Maßgehaltene",
    "Maßgeschneiderten": "Maßgeschneiderte",
    "Maßhaltenden": "Maßhaltende",
    "Maßhaltens": "Maßhalten",
    "Maßlosen": "Maßlose",
    "Maßloseren": "Maßlosere",
    "Maßlosesten": "Maßloseste",
    "Maßnahmen": "Maßnahme",
    "Maßstabe": "Maßstab",
    "Maßstabgetreue": "maßstabgetreu",
    "Maßstabgetreuen": "Maßstabgetreue",
    "Maßstabgetreueren": "Maßstabgetreuere",
    "Maßstabgetreusten": "Maßstabgetreuste",
    "Maßstabs": "Maßstab",
    "Maßstäbe": "Maßstab",
    "Maßstäben": "Maßstab",
    "Maßvollen": "Maßvolle",
    "Maßvolleren": "Maßvollere",
    "Maßvollsten": "Maßvollste",
    "Mechaniken": "Mechanik",
    "Mechanikern": "Mechaniker",
    "Mechanikers": "Mechaniker",
    "Mechanisatore": "Mechanisator",
    "Mechanisatoren": "Mechanisator",
    "Mechanisators": "Mechanisator",
    "Mechanische": "mechanisch",
    "Mechanischen": "Mechanische",
    "Mechanismen": "Mechanismus",
    "Mechthilds": "Mechthild",
    "Meckernden": "Meckernde",
    "Meckernderen": "Meckerndere",
    "Meckerndsten": "Meckerndste",
    "Meckerns": "Meckern",
    "Mecklenburgs": "Mecklenburg",
    "Medaillen": "Medaille",
    "Medebachs": "Medebach",
    "Mediale": "medial",
    "Medialen": "Mediale",
    "Medianwerte": "Medianwert",
    "Medianwerten": "Medianwert",
    "Medianwerts": "Medianwert",
    "Mediationen": "Mediation",
    "Medien": "Medium",
    "Medikamente": "Medikament",
    "Medikamenten": "Medikament",
    "Medikaments": "Medikament",
    "Medikamentöse": "medikamentös",
    "Medikamentösen": "Medikamentöse",
    "Mediotheken": "Mediothek",
    "Meditationen": "Meditation",
    "Meditative": "meditativ",
    "Meditativen": "Meditative",
    "Mediterranen": "Mediterrane",
    "Meditierenden": "Meditierende",
    "Meditierens": "Meditieren",
    "Meditierte": "meditiert",
    "Meditierten": "Meditierte",
    "Mediums": "Medium",
    "Medizinern": "Mediziner",
    "Mediziners": "Mediziner",
    "Medizinische": "medizinisch",
    "Medizinischen": "Medizinische",
    "Meere": "Meer",
    "Meeren": "Meer",
    "Meeres": "Meer",
    "Meers": "Meer",
    "Meetings": "Meeting",
    "Mehle": "Mehl",
    "Mehlen": "Mehl",
    "Mehlers": "Mehler",
    "Mehls": "Mehl",
    "Mehlschwitzen": "Mehlschwitze",
    "Mehraufwande": "Mehraufwand",
    "Mehraufwandes": "Mehraufwand",
    "Mehraufwands": "Mehraufwand",
    "Mehrbetrage": "Mehrbetrag",
    "Mehrbetrags": "Mehrbetrag",
    "Mehrbeträge": "Mehrbetrag",
    "Mehrbeträgen": "Mehrbetrag",
    "Mehrdeutige": "mehrdeutig",
    "Mehrdeutigen": "Mehrdeutige",
    "Mehrdimensionalen": "Mehrdimensionale",
    "Mehreinnahmen": "Mehreinnahme",
    "Mehrenden": "Mehrende",
    "Mehrens": "Mehren",
    "Mehrertrage": "Mehrertrag",
    "Mehrertrags": "Mehrertrag",
    "Mehrerträge": "Mehrertrag",
    "Mehrerträgen": "Mehrertrag",
    "Mehrfachen": "Mehrfache",
    "Mehrfachimpfungen": "Mehrfachimpfung",
    "Mehrfarbige": "mehrfarbig",
    "Mehrfarbigen": "Mehrfarbige",
    "Mehrheiten": "Mehrheit",
    "Mehrheitliche": "mehrheitlich",
    "Mehrheitlichen": "Mehrheitliche",
    "Mehrjährigen": "Mehrjährige",
    "Mehrkampfe": "Mehrkampf",
    "Mehrkampfs": "Mehrkampf",
    "Mehrkämpfe": "Mehrkampf",
    "Mehrkämpfen": "Mehrkampf",
    "Mehrlinge": "Mehrling",
    "Mehrlingen": "Mehrling",
    "Mehrlings": "Mehrling",
    "Mehrmalige": "mehrmalig",
    "Mehrmaligen": "Mehrmalige",
    "Mehrsilbigen": "Mehrsilbige",
    "Mehrsprachigen": "Mehrsprachige",
    "Mehrspurigen": "Mehrspurige",
    "Mehrstimmigen": "Mehrstimmige",
    "Mehrteiligen": "Mehrteilige",
    "Mehrtägigen": "Mehrtägige",
    "Mehrverbrauchs": "Mehrverbrauch",
    "Mehrvölkerstaate": "Mehrvölkerstaat",
    "Mehrvölkerstaaten": "Mehrvölkerstaat",
    "Mehrvölkerstaats": "Mehrvölkerstaat",
    "Mehrwegflaschen": "Mehrwegflasche",
    "Mehrwerts": "Mehrwert",
    "Mehrwertsteuern": "Mehrwertsteuer",
    "Mehrzahlen": "Mehrzahl",
    "Mehrzellige": "mehrzellig",
    "Mehrzelligen": "Mehrzellige",
    "Mehrzylindern": "Mehrzylinder",
    "Mehrzylinders": "Mehrzylinder",
    "Meidenden": "Meidende",
    "Meidens": "Meiden",
    "Meiers": "Meier",
    "Meilen": "Meile",
    "Meilenlange": "meilenlang",
    "Meilenlangen": "Meilenlange",
    "Meilenweiten": "Meilenweite",
    "Meilern": "Meiler",
    "Meilers": "Meiler",
    "Meineide": "Meineid",
    "Meineiden": "Meineid",
    "Meineids": "Meineid",
    "Meinenden": "Meinende",
    "Meinens": "Meinen",
    "Meinungen": "Meinung",
    "Meisen": "Meise",
    "Meisners": "Meisner",
    "Meistbietenden": "Meistbietende",
    "Meistbietenderen": "Meistbietendere",
    "Meistbietendsten": "Meistbietendste",
    "Meisten": "Meiste",
    "Meister": "meist",
    "Meisterhaften": "Meisterhafte",
    "Meisterhafteren": "Meisterhaftere",
    "Meisterhaftesten": "Meisterhafteste",
    "Meisterlichen": "Meisterliche",
    "Meisterlicheren": "Meisterlichere",
    "Meisterlichsten": "Meisterlichste",
    "Meistern": "Meister",
    "Meisternden": "Meisternde",
    "Meisternderen": "Meisterndere",
    "Meisterndsten": "Meisterndste",
    "Meisterns": "Meistern",
    "Meisters": "Meister",
    "Meisterschaften": "Meisterschaft",
    "Meistgebräuchlichen": "Meistgebräuchliche",
    "Meistgebräuchlicheren": "Meistgebräuchlichere",
    "Meistgeflogenen": "Meistgeflogene",
    "Meistgeflogeneren": "Meistgeflogenere",
    "Meistgeflogensten": "Meistgeflogenste",
    "Meistgenannten": "Meistgenannte",
    "Meißel": "meißeln",
    "Meißeln": "Meißel",
    "Meißelnden": "Meißelnde",
    "Meißelns": "Meißeln",
    "Meißels": "Meißel",
    "Mekkas": "Mekka",
    "Meldeamte": "Meldeamt",
    "Meldeamtes": "Meldeamt",
    "Meldeamts": "Meldeamt",
    "Meldebehörden": "Meldebehörde",
    "Meldenden": "Meldende",
    "Meldens": "Melden",
    "Meldepflichtige": "meldepflichtig",
    "Meldepflichtigen": "Meldepflichtige",
    "Meldestellen": "Meldestelle",
    "Meldewesens": "Meldewesen",
    "Meldeämter": "Meldeamt",
    "Meldeämtern": "Meldeamt",
    "Meldungen": "Meldung",
    "Melissen": "Melisse",
    "Melkenden": "Melkende",
    "Melkens": "Melken",
    "Melkern": "Melker",
    "Melkers": "Melker",
    "Melkkühe": "Melkkuh",
    "Melkkühen": "Melkkuh",
    "Melodien": "Melodie",
    "Melodischen": "Melodische",
    "Melodischeren": "Melodischere",
    "Melodischsten": "Melodischste",
    "Melodiöse": "melodiös",
    "Melodiösen": "Melodiöse",
    "Melodiöseren": "Melodiösere",
    "Melodiösesten": "Melodiöseste",
    "Melodramatischen": "Melodramatische",
    "Melonen": "Melone",
    "Memmen": "Memme",
    "Memorierenden": "Memorierende",
    "Memorierens": "Memorieren",
    "Memorierte": "memoriert",
    "Memorierten": "Memorierte",
    "Memos": "Memo",
    "Mendaus": "Mendau",
    "Mendelssohns": "Mendelssohn",
    "Menge": "mengen",
    "Mengen": "Menge",
    "Mengenden": "Mengende",
    "Mengens": "Mengen",
    "Menschen": "Mensch",
    "Menschenfeindliche": "menschenfeindlich",
    "Menschenfeindlichen": "Menschenfeindliche",
    "Menschenfeindlicheren": "Menschenfeindlichere",
    "Menschenfreundlichen": "Menschenfreundliche",
    "Menschenfreundlicheren": "Menschenfreundlichere",
    "Menschenscheuen": "Menschenscheue",
    "Menschenscheueren": "Menschenscheuere",
    "Menschenscheusten": "Menschenscheuste",
    "Menschenunwürdigen": "Menschenunwürdige",
    "Menschenunwürdigeren": "Menschenunwürdigere",
    "Menschheiten": "Menschheit",
    "Menschliche": "menschlich",
    "Menschlichen": "Menschliche",
    "Menschlicheren": "Menschlichere",
    "Menschlichsten": "Menschlichste",
    "Mentalen": "Mentale",
    "Mentalitäten": "Mentalität",
    "Menues": "Menue",
    "Menüs": "Menü",
    "Meppens": "Meppen",
    "Mergeln": "Mergel",
    "Mergels": "Mergel",
    "Mergentheims": "Mergentheim",
    "Meridiane": "Meridian",
    "Meridianen": "Meridian",
    "Meridians": "Meridian",
    "Merkbare": "merkbar",
    "Merkbaren": "Merkbare",
    "Merkblatte": "Merkblatt",
    "Merkblattes": "Merkblatt",
    "Merkblatts": "Merkblatt",
    "Merkblätter": "Merkblatt",
    "Merkblättern": "Merkblatt",
    "Merkbuche": "Merkbuch",
    "Merkbuches": "Merkbuch",
    "Merkbuchs": "Merkbuch",
    "Merkbücher": "Merkbuch",
    "Merkbüchern": "Merkbuch",
    "Merkels": "Merkel",
    "Merkenden": "Merkende",
    "Merkens": "Merken",
    "Merklichen": "Merkliche",
    "Merkmale": "Merkmal",
    "Merkmalen": "Merkmal",
    "Merkmales": "Merkmal",
    "Merkmals": "Merkmal",
    "Merkwürdigen": "Merkwürdige",
    "Merkwürdigeren": "Merkwürdigere",
    "Merkwürdigkeiten": "Merkwürdigkeit",
    "Merkwürdigste": "merkwürdig",
    "Merkwürdigsten": "Merkwürdigste",
    "Merkzeichens": "Merkzeichen",
    "Merzenden": "Merzende",
    "Merzens": "Merzen",
    "Mesomerien": "Mesomerie",
    "Messe": "messen",
    "Messen": "Messe",
    "Messenden": "Messende",
    "Messens": "Messen",
    "Messern": "Messer",
    "Messers": "Messer",
    "Messerscharfe": "messerscharf",
    "Messerscharfen": "Messerscharfe",
    "Messerstechereien": "Messerstecherei",
    "Messings": "Messing",
    "Messungen": "Messung",
    "Metabolien": "Metabolie",
    "Metageschäfte": "Metageschäft",
    "Metageschäften": "Metageschäft",
    "Metageschäfts": "Metageschäft",
    "Metakritiken": "Metakritik",
    "Metalle": "Metall",
    "Metallen": "Metall",
    "Metallern": "Metaller",
    "Metallers": "Metaller",
    "Metallisatore": "Metallisator",
    "Metallisatoren": "Metallisator",
    "Metallisators": "Metallisator",
    "Metallische": "metallisch",
    "Metallischen": "Metallische",
    "Metallisierenden": "Metallisierende",
    "Metallisierenderen": "Metallisierendere",
    "Metallisierens": "Metallisieren",
    "Metallisierte": "metallisiert",
    "Metallisierten": "Metallisierte",
    "Metallisierteren": "Metallisiertere",
    "Metallisiertesten": "Metallisierteste",
    "Metalloxide": "Metalloxid",
    "Metalloxiden": "Metalloxid",
    "Metalloxids": "Metalloxid",
    "Metalls": "Metall",
    "Metamorphosen": "Metamorphose",
    "Metaphern": "Metapher",
    "Metaphysikern": "Metaphysiker",
    "Metaphysikers": "Metaphysiker",
    "Metaphysische": "metaphysisch",
    "Metaphysischen": "Metaphysische",
    "Metatheorien": "Metatheorie",
    "Meteore": "Meteor",
    "Meteoren": "Meteor",
    "Meteores": "Meteor",
    "Meteorologen": "Meteorologe",
    "Meteorologische": "meteorologisch",
    "Meteorologischen": "Meteorologische",
    "Meteors": "Meteor",
    "Meterlange": "meterlang",
    "Meterlangen": "Meterlange",
    "Meterlatten": "Meterlatte",
    "Metern": "Meter",
    "Meters": "Meter",
    "Meterwaren": "Meterware",
    "Methadons": "Methadon",
    "Methoden": "Methode",
    "Methodiken": "Methodik",
    "Methodikern": "Methodiker",
    "Methodikers": "Methodiker",
    "Methodische": "methodisch",
    "Methodischen": "Methodische",
    "Methodisierenden": "Methodisierende",
    "Methodisierens": "Methodisieren",
    "Methodisierte": "methodisiert",
    "Methodisierten": "Methodisierte",
    "Methodisierteren": "Methodisiertere",
    "Methodisiertesten": "Methodisierteste",
    "Methodisten": "Methodist",
    "Methusalems": "Methusalem",
    "Methyle": "Methyl",
    "Methylen": "Methyl",
    "Methyls": "Methyl",
    "Metiers": "Metier",
    "Metrische": "metrisch",
    "Metrischen": "Metrische",
    "Metropolen": "Metropole",
    "Metropoliten": "Metropolit",
    "Metros": "Metro",
    "Metzeleien": "Metzelei",
    "Metzelnden": "Metzelnde",
    "Metzelnderen": "Metzelndere",
    "Metzelndsten": "Metzelndste",
    "Metzelns": "Metzeln",
    "Metzgereien": "Metzgerei",
    "Metzgern": "Metzger",
    "Metzgers": "Metzger",
    "Meuchelmorde": "Meuchelmord",
    "Meuchelmorden": "Meuchelmord",
    "Meuchelmords": "Meuchelmord",
    "Meuchelmördern": "Meuchelmörder",
    "Meuchelmörders": "Meuchelmörder",
    "Meuniers": "Meunier",
    "Meurers": "Meurer",
    "Meuten": "Meute",
    "Meutereien": "Meuterei",
    "Meuterern": "Meuterer",
    "Meuterers": "Meuterer",
    "Meuternden": "Meuternde",
    "Meuternderen": "Meuterndere",
    "Meuterndsten": "Meuterndste",
    "Meuterns": "Meutern",
    "Mexikanischen": "Mexikanische",
    "Mexikanischeren": "Mexikanischere",
    "Mexikanischsten": "Mexikanischste",
    "Mexikos": "Mexiko",
    "Meyers": "Meyer",
    "Mezzamajolikas": "Mezzamajolika",
    "Meßbande": "Meßband",
    "Meßbandes": "Meßband",
    "Meßbands": "Meßband",
    "Meßbare": "meßbar",
    "Meßbaren": "Meßbare",
    "Meßbechern": "Meßbecher",
    "Meßbechers": "Meßbecher",
    "Meßbänder": "Meßband",
    "Meßbändern": "Meßband",
    "Meßdienern": "Meßdiener",
    "Meßdieners": "Meßdiener",
    "Meßfehlern": "Meßfehler",
    "Meßfehlers": "Meßfehler",
    "Meßfühlern": "Meßfühler",
    "Meßfühlers": "Meßfühler",
    "Meßgeräte": "Meßgerät",
    "Meßgeräten": "Meßgerät",
    "Meßgeräts": "Meßgerät",
    "Meßgewande": "Meßgewand",
    "Meßgewandes": "Meßgewand",
    "Meßgewands": "Meßgewand",
    "Meßgewänder": "Meßgewand",
    "Meßgewändern": "Meßgewand",
    "Meßgrößen": "Meßgröße",
    "Meßtechniken": "Meßtechnik",
    "Meßuhren": "Meßuhr",
    "Meßwagens": "Meßwagen",
    "Meßwandlern": "Meßwandler",
    "Meßwandlers": "Meßwandler",
    "Meßweine": "Meßwein",
    "Meßweinen": "Meßwein",
    "Meßweins": "Meßwein",
    "Meßwerke": "Meßwerk",
    "Meßwerken": "Meßwerk",
    "Meßwerks": "Meßwerk",
    "Meßwerte": "Meßwert",
    "Meßwerten": "Meßwert",
    "Meßwerts": "Meßwert",
    "Meßwesens": "Meßwesen",
    "Meßwiderstande": "Meßwiderstand",
    "Meßwiderstands": "Meßwiderstand",
    "Meßwiderstände": "Meßwiderstand",
    "Meßwiderständen": "Meßwiderstand",
    "Meßzahlen": "Meßzahl",
    "Miamis": "Miami",
    "Michaels": "Michael",
    "Michails": "Michail",
    "Micheln": "Michel",
    "Michels": "Michel",
    "Miedern": "Mieder",
    "Mieders": "Mieder",
    "Miedertuche": "Miedertuch",
    "Miedertuches": "Miedertuch",
    "Miedertuchs": "Miedertuch",
    "Miedertücher": "Miedertuch",
    "Miedertüchern": "Miedertuch",
    "Mief": "miefen",
    "Miefenden": "Miefende",
    "Miefenderen": "Miefendere",
    "Miefendsten": "Miefendste",
    "Miefens": "Miefen",
    "Miefs": "Mief",
    "Mielkes": "Mielke",
    "Mienen": "Miene",
    "Miese": "mies",
    "Miesekatzen": "Miesekatze",
    "Miesen": "Miese",
    "Miesepetern": "Miesepeter",
    "Miesepeters": "Miesepeter",
    "Mieseren": "Miesere",
    "Miesesten": "Mieseste",
    "Miesmachern": "Miesmacher",
    "Miesmachers": "Miesmacher",
    "Miesmuscheln": "Miesmuschel",
    "Miete": "mieten",
    "Mieten": "Miete",
    "Mietenden": "Mietende",
    "Mietens": "Mieten",
    "Mietern": "Mieter",
    "Mieters": "Mieter",
    "Mietertrage": "Mietertrag",
    "Mietertrags": "Mietertrag",
    "Mieterträge": "Mietertrag",
    "Mieterträgen": "Mietertrag",
    "Mietfreien": "Mietfreie",
    "Miethaie": "Miethai",
    "Miethaien": "Miethai",
    "Miethais": "Miethai",
    "Mietkaufe": "Mietkauf",
    "Mietkaufs": "Mietkauf",
    "Mietkäufe": "Mietkauf",
    "Mietkäufen": "Mietkauf",
    "Mietskasernen": "Mietskaserne",
    "Mietspiegeln": "Mietspiegel",
    "Mietspiegels": "Mietspiegel",
    "Mietvertrage": "Mietvertrag",
    "Mietvertrags": "Mietvertrag",
    "Mietverträge": "Mietvertrag",
    "Mietverträgen": "Mietvertrag",
    "Mietwohnungen": "Mietwohnung",
    "Mietzahlungen": "Mietzahlung",
    "Miezekatzen": "Miezekatze",
    "Miezen": "Mieze",
    "Mihajlovics": "Mihajlovic",
    "Mikes": "Mike",
    "Mikroben": "Mikrobe",
    "Mikrofilme": "Mikrofilm",
    "Mikrofilmen": "Mikrofilm",
    "Mikrofilmes": "Mikrofilm",
    "Mikrofilms": "Mikrofilm",
    "Mikrogramme": "Mikrogramm",
    "Mikrogrammen": "Mikrogramm",
    "Mikrogrammes": "Mikrogramm",
    "Mikrogramms": "Mikrogramm",
    "Mikroklimas": "Mikroklima",
    "Mikrokopien": "Mikrokopie",
    "Mikromanipulatore": "Mikromanipulator",
    "Mikromanipulatoren": "Mikromanipulator",
    "Mikromanipulators": "Mikromanipulator",
    "Mikrometern": "Mikrometer",
    "Mikrometers": "Mikrometer",
    "Mikrooptiken": "Mikrooptik",
    "Mikrophone": "Mikrophon",
    "Mikrophonen": "Mikrophon",
    "Mikrophones": "Mikrophon",
    "Mikrophons": "Mikrophon",
    "Mikroprozessore": "Mikroprozessor",
    "Mikroprozessoren": "Mikroprozessor",
    "Mikroprozessors": "Mikroprozessor",
    "Mikroskope": "Mikroskop",
    "Mikroskopen": "Mikroskop",
    "Mikroskopes": "Mikroskop",
    "Mikroskops": "Mikroskop",
    "Mikrotheken": "Mikrothek",
    "Mikrowaagen": "Mikrowaage",
    "Mikrowellen": "Mikrowelle",
    "Milans": "Milan",
    "Milben": "Milbe",
    "Milchbars": "Milchbar",
    "Milchige": "milchig",
    "Milchigen": "Milchige",
    "Milchigeren": "Milchigere",
    "Milchigsten": "Milchigste",
    "Milden": "Milde",
    "Mildere": "mildern",
    "Milderen": "Mildere",
    "Mildernden": "Mildernde",
    "Mildernderen": "Milderndere",
    "Milderndsten": "Milderndste",
    "Milderns": "Mildern",
    "Mildesten": "Mildeste",
    "Mildtätigen": "Mildtätige",
    "Mildtätigeren": "Mildtätigere",
    "Mildtätigsten": "Mildtätigste",
    "Milieus": "Milieu",
    "Militante": "militant",
    "Militanten": "Militante",
    "Militanteren": "Militantere",
    "Militantesten": "Militanteste",
    "Militarisierenden": "Militarisierende",
    "Militarisierenderen": "Militarisierendere",
    "Militarisierens": "Militarisieren",
    "Militarisierte": "militarisiert",
    "Militarisierten": "Militarisierte",
    "Militarisierteren": "Militarisiertere",
    "Militarisierteste": "militarisiert",
    "Militärischen": "Militärische",
    "Militärischeren": "Militärischere",
    "Militärischsten": "Militärischste",
    "Militärs": "Militär",
    "Militärwesens": "Militärwesen",
    "Milizen": "Miliz",
    "Millers": "Miller",
    "Milliarden": "Milliarde",
    "Milliardsteln": "Milliardstel",
    "Milliardstels": "Milliardstel",
    "Milligramme": "Milligramm",
    "Milligrammen": "Milligramm",
    "Milligrammes": "Milligramm",
    "Milligramms": "Milligramm",
    "Millimetergroße": "millimetergroß",
    "Millimetergroßen": "Millimetergroße",
    "Millimetern": "Millimeter",
    "Millimeters": "Millimeter",
    "Millionen": "Million",
    "Millionsteln": "Millionstel",
    "Millionstels": "Millionstel",
    "Millionäre": "Millionär",
    "Millionären": "Millionär",
    "Millionärs": "Millionär",
    "Millisekunden": "Millisekunde",
    "Mills": "Mill",
    "Milosevics": "Milosevic",
    "Mimenden": "Mimende",
    "Mimens": "Mimen",
    "Mimischen": "Mimische",
    "Mimosen": "Mimose",
    "Mimosenhafte": "mimosenhaft",
    "Mimosenhaften": "Mimosenhafte",
    "Mimosenhafteren": "Mimosenhaftere",
    "Mimosenhaftesten": "Mimosenhafteste",
    "Minderbegabten": "Minderbegabte",
    "Minderheiten": "Minderheit",
    "Minderjährige": "minderjährig",
    "Minderjährigen": "Minderjährige",
    "Mindernden": "Mindernde",
    "Minderns": "Mindern",
    "Minderungen": "Minderung",
    "Minderwertige": "minderwertig",
    "Minderwertigen": "Minderwertige",
    "Minderwertigeren": "Minderwertigere",
    "Minderwertigkeiten": "Minderwertigkeit",
    "Minderwertigste": "minderwertig",
    "Minderwertigsten": "Minderwertigste",
    "Mindestforderungen": "Mindestforderung",
    "Mindestpreise": "Mindestpreis",
    "Mindestpreisen": "Mindestpreis",
    "Mindestpreises": "Mindestpreis",
    "Mindestreserven": "Mindestreserve",
    "Minen": "Mine",
    "Minerale": "Mineral",
    "Mineralen": "Mineral",
    "Minerales": "Mineral",
    "Mineralien": "Mineral",
    "Mineralische": "mineralisch",
    "Mineralischen": "Mineralische",
    "Mineralogen": "Mineraloge",
    "Minerals": "Mineral",
    "Mineralöle": "Mineralöl",
    "Mineralölen": "Mineralöl",
    "Mineralöls": "Mineralöl",
    "Miniaturausgaben": "Miniaturausgabe",
    "Miniaturen": "Miniatur",
    "Miniaturisierenden": "Miniaturisierende",
    "Miniaturisierens": "Miniaturisieren",
    "Miniaturisierte": "miniaturisiert",
    "Miniaturisierten": "Miniaturisierte",
    "Minigarden": "Minigarde",
    "Minigolfs": "Minigolf",
    "Minima": "Minimum",
    "Minimalbelastungen": "Minimalbelastung",
    "Minimale": "minimal",
    "Minimalen": "Minimale",
    "Minimalisierenden": "Minimalisierende",
    "Minimalisierens": "Minimalisieren",
    "Minimalisierte": "minimalisiert",
    "Minimalisierten": "Minimalisierte",
    "Minimallohne": "Minimallohn",
    "Minimallohns": "Minimallohn",
    "Minimallöhne": "Minimallohn",
    "Minimallöhnen": "Minimallohn",
    "Minimierenden": "Minimierende",
    "Minimierenderen": "Minimierendere",
    "Minimierendsten": "Minimierendste",
    "Minimierens": "Minimieren",
    "Minimierte": "minimiert",
    "Minimierten": "Minimierte",
    "Minimierteren": "Minimiertere",
    "Minimiertesten": "Minimierteste",
    "Minimums": "Minimum",
    "Minipillen": "Minipille",
    "Minirocke": "Minirock",
    "Minirocks": "Minirock",
    "Miniröcke": "Minirock",
    "Miniröcken": "Minirock",
    "Ministeriale": "ministerial",
    "Ministerialen": "Ministeriale",
    "Ministeriellen": "Ministerielle",
    "Ministerien": "Ministerium",
    "Ministerinnen": "Ministerin",
    "Ministeriums": "Ministerium",
    "Ministern": "Minister",
    "Ministers": "Minister",
    "Minkels": "Minkel",
    "Minnas": "Minna",
    "Minneliede": "Minnelied",
    "Minnelieder": "Minnelied",
    "Minneliedern": "Minnelied",
    "Minneliedes": "Minnelied",
    "Minnelieds": "Minnelied",
    "Minnesingern": "Minnesinger",
    "Minnesingers": "Minnesinger",
    "Minnesängern": "Minnesänger",
    "Minnesängers": "Minnesänger",
    "Minoltas": "Minolta",
    "Minoritäten": "Minorität",
    "Minsks": "Minsk",
    "Minuenden": "Minuend",
    "Minusbetrage": "Minusbetrag",
    "Minusbetrags": "Minusbetrag",
    "Minusbeträge": "Minusbetrag",
    "Minusbeträgen": "Minusbetrag",
    "Minuspunkte": "Minuspunkt",
    "Minuspunkten": "Minuspunkt",
    "Minuspunkts": "Minuspunkt",
    "Minuszeichens": "Minuszeichen",
    "Minuten": "Minute",
    "Minutenlange": "minutenlang",
    "Minutenlangen": "Minutenlange",
    "Minutiösen": "Minutiöse",
    "Minzen": "Minze",
    "Mir": "ich",
    "Mirabellen": "Mirabelle",
    "Mirjams": "Mirjam",
    "Mischbatterien": "Mischbatterie",
    "Mischehen": "Mischehe",
    "Mischenden": "Mischende",
    "Mischens": "Mischen",
    "Mischfarben": "Mischfarbe",
    "Mischfutters": "Mischfutter",
    "Mischgarne": "Mischgarn",
    "Mischgarnen": "Mischgarn",
    "Mischgarns": "Mischgarn",
    "Mischgebiete": "Mischgebiet",
    "Mischgebieten": "Mischgebiet",
    "Mischgebietes": "Mischgebiet",
    "Mischgebiets": "Mischgebiet",
    "Mischkulturen": "Mischkultur",
    "Mischungen": "Mischung",
    "Miserabelste": "miserabel",
    "Miserabelsten": "Miserabelste",
    "Miserablen": "Miserable",
    "Miserableren": "Miserablere",
    "Miseren": "Misere",
    "Missenden": "Missende",
    "Missens": "Missen",
    "Missetaten": "Missetat",
    "Missetätern": "Missetäter",
    "Missetäters": "Missetäter",
    "Missionare": "Missionar",
    "Missionaren": "Missionar",
    "Missionarische": "missionarisch",
    "Missionarischen": "Missionarische",
    "Missionars": "Missionar",
    "Missionen": "Mission",
    "Missionierenden": "Missionierende",
    "Missionierenderen": "Missionierendere",
    "Missionierendsten": "Missionierendste",
    "Missionierens": "Missionieren",
    "Missionierte": "missioniert",
    "Missionierten": "Missionierte",
    "Missionierteren": "Missioniertere",
    "Missioniertesten": "Missionierteste",
    "Missionsschulen": "Missionsschule",
    "Missionäre": "Missionär",
    "Missionären": "Missionär",
    "Missionärs": "Missionär",
    "Misteln": "Mistel",
    "Misten": "Mist",
    "Mistenden": "Mistende",
    "Mistens": "Misten",
    "Mists": "Mist",
    "Mitarbeiten": "Mitarbeit",
    "Mitarbeitenden": "Mitarbeitende",
    "Mitarbeitens": "Mitarbeiten",
    "Mitarbeiterinnen": "Mitarbeiterin",
    "Mitarbeitern": "Mitarbeiter",
    "Mitarbeiters": "Mitarbeiter",
    "Mitautore": "Mitautor",
    "Mitautoren": "Mitautor",
    "Mitautors": "Mitautor",
    "Mitbegründern": "Mitbegründer",
    "Mitbegründers": "Mitbegründer",
    "Mitbekommenden": "Mitbekommende",
    "Mitbekommenen": "Mitbekommene",
    "Mitbekommens": "Mitbekommen",
    "Mitbenutzenden": "Mitbenutzende",
    "Mitbenutzens": "Mitbenutzen",
    "Mitbenutzte": "mitbenutzt",
    "Mitbenutzten": "Mitbenutzte",
    "Mitbestimmenden": "Mitbestimmende",
    "Mitbestimmenderen": "Mitbestimmendere",
    "Mitbestimmendsten": "Mitbestimmendste",
    "Mitbestimmens": "Mitbestimmen",
    "Mitbestimmte": "mitbestimmt",
    "Mitbestimmten": "Mitbestimmte",
    "Mitbestimmteren": "Mitbestimmtere",
    "Mitbestimmtesten": "Mitbestimmteste",
    "Mitbestimmungen": "Mitbestimmung",
    "Mitbewerbenden": "Mitbewerbende",
    "Mitbewerbens": "Mitbewerben",
    "Mitbewohnern": "Mitbewohner",
    "Mitbewohners": "Mitbewohner",
    "Mitbeworbenen": "Mitbeworbene",
    "Mitbringenden": "Mitbringende",
    "Mitbringens": "Mitbringen",
    "Mitbringseln": "Mitbringsel",
    "Mitbringsels": "Mitbringsel",
    "Mitbürgerinnen": "Mitbürgerin",
    "Mitbürgern": "Mitbürger",
    "Mitbürgers": "Mitbürger",
    "Miteinaders": "Miteinader",
    "Mitempfindenden": "Mitempfindende",
    "Mitempfindens": "Mitempfinden",
    "Mitempfundenen": "Mitempfundene",
    "Miterben": "Miterbe",
    "Miterlebenden": "Miterlebende",
    "Miterlebens": "Miterleben",
    "Miterlebte": "miterlebt",
    "Miterlebten": "Miterlebte",
    "Mitessenden": "Mitessende",
    "Mitessens": "Mitessen",
    "Mitessern": "Mitesser",
    "Mitessers": "Mitesser",
    "Mitfahrenden": "Mitfahrende",
    "Mitfahrens": "Mitfahren",
    "Mitfliegenden": "Mitfliegende",
    "Mitfliegens": "Mitfliegen",
    "Mitfreuenden": "Mitfreuende",
    "Mitfreuens": "Mitfreuen",
    "Mitfühlenden": "Mitfühlende",
    "Mitfühlenderen": "Mitfühlendere",
    "Mitfühlendsten": "Mitfühlendste",
    "Mitfühlens": "Mitfühlen",
    "Mitgearbeiteten": "Mitgearbeitete",
    "Mitgebenden": "Mitgebende",
    "Mitgebens": "Mitgeben",
    "Mitgebrachten": "Mitgebrachte",
    "Mitgefahrenen": "Mitgefahrene",
    "Mitgeflogenen": "Mitgeflogene",
    "Mitgefreuten": "Mitgefreute",
    "Mitgefühle": "Mitgefühl",
    "Mitgefühlen": "Mitgefühl",
    "Mitgefühles": "Mitgefühl",
    "Mitgefühls": "Mitgefühl",
    "Mitgefühlten": "Mitgefühlte",
    "Mitgegebenen": "Mitgegebene",
    "Mitgegessenen": "Mitgegessene",
    "Mitgehaltenen": "Mitgehaltene",
    "Mitgeholfenen": "Mitgeholfene",
    "Mitgehörten": "Mitgehörte",
    "Mitgekriegten": "Mitgekriegte",
    "Mitgekämpften": "Mitgekämpfte",
    "Mitgelassenen": "Mitgelassene",
    "Mitgelaufenen": "Mitgelaufene",
    "Mitgelernten": "Mitgelernte",
    "Mitgelittenen": "Mitgelittene",
    "Mitgemachten": "Mitgemachte",
    "Mitgemischten": "Mitgemischte",
    "Mitgenommenen": "Mitgenommene",
    "Mitgenommeneren": "Mitgenommenere",
    "Mitgenommensten": "Mitgenommenste",
    "Mitgerechneten": "Mitgerechnete",
    "Mitgeredeten": "Mitgeredete",
    "Mitgereisten": "Mitgereiste",
    "Mitgerissenen": "Mitgerissene",
    "Mitgeschleiften": "Mitgeschleifte",
    "Mitgeschleppten": "Mitgeschleppte",
    "Mitgeschliffenen": "Mitgeschliffene",
    "Mitgeschnittenen": "Mitgeschnittene",
    "Mitgeschriebenen": "Mitgeschriebene",
    "Mitgeschriebeneren": "Mitgeschriebenere",
    "Mitgeschwungenen": "Mitgeschwungene",
    "Mitgesoffenen": "Mitgesoffene",
    "Mitgespielten": "Mitgespielte",
    "Mitgesprochenen": "Mitgesprochene",
    "Mitgestaltenden": "Mitgestaltende",
    "Mitgestaltenderen": "Mitgestaltendere",
    "Mitgestaltendsten": "Mitgestaltendste",
    "Mitgestaltens": "Mitgestalten",
    "Mitgestaltete": "mitgestaltet",
    "Mitgestalteten": "Mitgestaltete",
    "Mitgesungenen": "Mitgesungene",
    "Mitgetanzten": "Mitgetanzte",
    "Mitgeteilten": "Mitgeteilte",
    "Mitgetragenen": "Mitgetragene",
    "Mitgetrunkenen": "Mitgetrunkene",
    "Mitgewirkten": "Mitgewirkte",
    "Mitgezogenen": "Mitgezogene",
    "Mitgezählten": "Mitgezählte",
    "Mitgliede": "Mitglied",
    "Mitglieder": "Mitglied",
    "Mitgliedern": "Mitglied",
    "Mitgliederstarke": "mitgliederstark",
    "Mitgliederstarken": "Mitgliederstarke",
    "Mitgliederstärkeren": "Mitgliederstärkere",
    "Mitgliedes": "Mitglied",
    "Mitglieds": "Mitglied",
    "Mitgliedschaften": "Mitgliedschaft",
    "Mitgründerinnen": "Mitgründerin",
    "Mithabens": "Mithaben",
    "Mithaltenden": "Mithaltende",
    "Mithaltens": "Mithalten",
    "Mithelfenden": "Mithelfende",
    "Mithelfens": "Mithelfen",
    "Mithörenden": "Mithörende",
    "Mithörens": "Mithören",
    "Mithörern": "Mithörer",
    "Mithörers": "Mithörer",
    "Mitinhabern": "Mitinhaber",
    "Mitinhabers": "Mitinhaber",
    "Mitinitiatore": "Mitinitiator",
    "Mitinitiatoren": "Mitinitiator",
    "Mitinitiators": "Mitinitiator",
    "Mitklägern": "Mitkläger",
    "Mitklägers": "Mitkläger",
    "Mitkriegenden": "Mitkriegende",
    "Mitkriegens": "Mitkriegen",
    "Mitkämpfenden": "Mitkämpfende",
    "Mitkämpfens": "Mitkämpfen",
    "Mitlassenden": "Mitlassende",
    "Mitlassens": "Mitlassen",
    "Mitlaufenden": "Mitlaufende",
    "Mitlaufens": "Mitlaufen",
    "Mitleidenden": "Mitleidende",
    "Mitleidens": "Mitleiden",
    "Mitleidigen": "Mitleidige",
    "Mitleidigeren": "Mitleidigere",
    "Mitleidigsten": "Mitleidigste",
    "Mitleids": "Mitleid",
    "Mitlernenden": "Mitlernende",
    "Mitlernens": "Mitlernen",
    "Mitläufern": "Mitläufer",
    "Mitläufers": "Mitläufer",
    "Mitmachenden": "Mitmachende",
    "Mitmachens": "Mitmachen",
    "Mitmenschen": "Mitmensch",
    "Mitmischenden": "Mitmischende",
    "Mitmischens": "Mitmischen",
    "Mitnehmenden": "Mitnehmende",
    "Mitnehmens": "Mitnehmen",
    "Mitnehmern": "Mitnehmer",
    "Mitnehmers": "Mitnehmer",
    "Mitosegifte": "Mitosegift",
    "Mitosegiften": "Mitosegift",
    "Mitosegifts": "Mitosegift",
    "Mitrechnenden": "Mitrechnende",
    "Mitrechnens": "Mitrechnen",
    "Mitredenden": "Mitredende",
    "Mitredens": "Mitreden",
    "Mitreisenden": "Mitreisende",
    "Mitreisens": "Mitreisen",
    "Mitreißenden": "Mitreißende",
    "Mitreißenderen": "Mitreißendere",
    "Mitreißendsten": "Mitreißendste",
    "Mitreißens": "Mitreißen",
    "Mitsaufenden": "Mitsaufende",
    "Mitsaufens": "Mitsaufen",
    "Mitschleifenden": "Mitschleifende",
    "Mitschleifens": "Mitschleifen",
    "Mitschleppenden": "Mitschleppende",
    "Mitschleppens": "Mitschleppen",
    "Mitschneidenden": "Mitschneidende",
    "Mitschneidens": "Mitschneiden",
    "Mitschnitte": "Mitschnitt",
    "Mitschnitten": "Mitschnitt",
    "Mitschnitts": "Mitschnitt",
    "Mitschreibenden": "Mitschreibende",
    "Mitschreibens": "Mitschreiben",
    "Mitschwingenden": "Mitschwingende",
    "Mitschwingens": "Mitschwingen",
    "Mitschülerinnen": "Mitschülerin",
    "Mitsingenden": "Mitsingende",
    "Mitsingens": "Mitsingen",
    "Mitspielenden": "Mitspielende",
    "Mitspielens": "Mitspielen",
    "Mitspielerinnen": "Mitspielerin",
    "Mitspielern": "Mitspieler",
    "Mitspielers": "Mitspieler",
    "Mitsprechenden": "Mitsprechende",
    "Mitsprechens": "Mitsprechen",
    "Mittage": "Mittag",
    "Mittagen": "Mittag",
    "Mittages": "Mittag",
    "Mittags": "Mittag",
    "Mittanzenden": "Mittanzende",
    "Mittanzens": "Mittanzen",
    "Mitteilenden": "Mitteilende",
    "Mitteilenderen": "Mitteilendere",
    "Mitteilendsten": "Mitteilendste",
    "Mitteilens": "Mitteilen",
    "Mitteilsamen": "Mitteilsame",
    "Mitteilsameren": "Mitteilsamere",
    "Mitteilsamsten": "Mitteilsamste",
    "Mitteilungen": "Mitteilung",
    "Mittel": "mitteln",
    "Mittelalterlichen": "Mittelalterliche",
    "Mittelalterlicheren": "Mittelalterlichere",
    "Mittelalters": "Mittelalter",
    "Mittelbare": "mittelbar",
    "Mittelbaren": "Mittelbare",
    "Mittelbaue": "Mittelbau",
    "Mittelbaues": "Mittelbau",
    "Mittelbaus": "Mittelbau",
    "Mitteleuropäischen": "Mitteleuropäische",
    "Mittelfristigen": "Mittelfristige",
    "Mittelgewichte": "Mittelgewicht",
    "Mittelgewichten": "Mittelgewicht",
    "Mittelgewichts": "Mittelgewicht",
    "Mittelgroße": "mittelgroß",
    "Mittelgroßen": "Mittelgroße",
    "Mittelhochdeutschen": "Mittelhochdeutsche",
    "Mittellosen": "Mittellose",
    "Mittelloseren": "Mittellosere",
    "Mittellosesten": "Mittelloseste",
    "Mittelmäßigen": "Mittelmäßige",
    "Mittelmäßigeren": "Mittelmäßigere",
    "Mittelmäßigsten": "Mittelmäßigste",
    "Mitteln": "Mittel",
    "Mittelnden": "Mittelnde",
    "Mittelns": "Mitteln",
    "Mittelprächtige": "mittelprächtig",
    "Mittelprächtigen": "Mittelprächtige",
    "Mittelpunkte": "Mittelpunkt",
    "Mittelpunkten": "Mittelpunkt",
    "Mittelpunktes": "Mittelpunkt",
    "Mittelpunkts": "Mittelpunkt",
    "Mittels": "Mittel",
    "Mittelscheiteln": "Mittelscheitel",
    "Mittelscheitels": "Mittelscheitel",
    "Mittelständigen": "Mittelständige",
    "Mittelständischen": "Mittelständische",
    "Mittelständlern": "Mittelständler",
    "Mittelständlers": "Mittelständler",
    "Mittelwege": "Mittelweg",
    "Mittelwegen": "Mittelweg",
    "Mittelwegs": "Mittelweg",
    "Mittelwellen": "Mittelwelle",
    "Mittelworte": "Mittelwort",
    "Mittelwortes": "Mittelwort",
    "Mittelworts": "Mittelwort",
    "Mittelwörter": "Mittelwort",
    "Mittelwörtern": "Mittelwort",
    "Mitten": "Mitte",
    "Mitterands": "Mitterand",
    "Mitternächte": "Mitternacht",
    "Mitternächten": "Mitternacht",
    "Mitterrands": "Mitterrand",
    "Mittige": "mittig",
    "Mittigen": "Mittige",
    "Mittigeren": "Mittigere",
    "Mittigsten": "Mittigste",
    "Mittle": "mitteln",
    "Mittlen": "Mittle",
    "Mittleren": "Mittlere",
    "Mittragenden": "Mittragende",
    "Mittragens": "Mittragen",
    "Mittrinkenden": "Mittrinkende",
    "Mittrinkens": "Mittrinken",
    "Mittwochs": "Mittwoch",
    "Mittätern": "Mittäter",
    "Mittäters": "Mittäter",
    "Mitverantwortliche": "mitverantwortlich",
    "Mitverantwortlichen": "Mitverantwortliche",
    "Mitwirkenden": "Mitwirkende",
    "Mitwirkens": "Mitwirken",
    "Mitwirkungen": "Mitwirkung",
    "Mitziehenden": "Mitziehende",
    "Mitziehens": "Mitziehen",
    "Mitzählenden": "Mitzählende",
    "Mitzählenderen": "Mitzählendere",
    "Mitzählendsten": "Mitzählendste",
    "Mitzählens": "Mitzählen",
    "Mixenden": "Mixende",
    "Mixens": "Mixen",
    "Mixern": "Mixer",
    "Mixers": "Mixer",
    "Mißachtenden": "Mißachtende",
    "Mißachtenderen": "Mißachtendere",
    "Mißachtendsten": "Mißachtendste",
    "Mißachtens": "Mißachten",
    "Mißachtete": "mißachtet",
    "Mißachteten": "Mißachtete",
    "Mißachteteren": "Mißachtetere",
    "Mißachtetesten": "Mißachteteste",
    "Mißachtungen": "Mißachtung",
    "Mißbildenden": "Mißbildende",
    "Mißbildenderen": "Mißbildendere",
    "Mißbildendsten": "Mißbildendste",
    "Mißbildens": "Mißbilden",
    "Mißbildete": "mißbildet",
    "Mißbildeten": "Mißbildete",
    "Mißbildeteren": "Mißbildetere",
    "Mißbildetesten": "Mißbildeteste",
    "Mißbildungen": "Mißbildung",
    "Mißbilligenden": "Mißbilligende",
    "Mißbilligens": "Mißbilligen",
    "Mißbilligte": "mißbilligt",
    "Mißbilligten": "Mißbilligte",
    "Mißbrauch": "mißbrauchen",
    "Mißbrauche": "mißbrauchen",
    "Mißbrauchenden": "Mißbrauchende",
    "Mißbrauchens": "Mißbrauchen",
    "Mißbrauches": "Mißbrauch",
    "Mißbrauchs": "Mißbrauch",
    "Mißbrauchte": "mißbraucht",
    "Mißbrauchten": "Mißbrauchte",
    "Mißbrauchteren": "Mißbrauchtere",
    "Mißbrauchtesten": "Mißbrauchteste",
    "Mißbringens": "Mißbringen",
    "Mißbräuche": "Mißbrauch",
    "Mißbräuchen": "Mißbrauch",
    "Mißbräuchlichen": "Mißbräuchliche",
    "Mißdeutungen": "Mißdeutung",
    "Mißerfolge": "Mißerfolg",
    "Mißerfolgen": "Mißerfolg",
    "Mißerfolgs": "Mißerfolg",
    "Mißernten": "Mißernte",
    "Mißfallenden": "Mißfallende",
    "Mißfallenen": "Mißfallene",
    "Mißfalleneren": "Mißfallenere",
    "Mißfallens": "Mißfallen",
    "Mißfallenste": "mißfallen",
    "Mißfallensten": "Mißfallenste",
    "Mißformen": "Mißform",
    "Mißgebildete": "mißgebildet",
    "Mißgebildeten": "Mißgebildete",
    "Mißgeschicke": "Mißgeschick",
    "Mißgeschicken": "Mißgeschick",
    "Mißgeschicks": "Mißgeschick",
    "Mißgestalten": "Mißgestalt",
    "Mißgestimmte": "mißgestimmt",
    "Mißgestimmten": "Mißgestimmte",
    "Mißgestimmteren": "Mißgestimmtere",
    "Mißgestimmtesten": "Mißgestimmteste",
    "Mißglückenden": "Mißglückende",
    "Mißglückenderen": "Mißglückendere",
    "Mißglückendsten": "Mißglückendste",
    "Mißglückens": "Mißglücken",
    "Mißglückte": "mißglückt",
    "Mißglückten": "Mißglückte",
    "Mißglückteren": "Mißglücktere",
    "Mißglücktesten": "Mißglückteste",
    "Mißgriffe": "Mißgriff",
    "Mißgriffen": "Mißgriff",
    "Mißgriffs": "Mißgriff",
    "Mißhandelnden": "Mißhandelnde",
    "Mißhandelns": "Mißhandeln",
    "Mißhandelte": "mißhandelt",
    "Mißhandelten": "Mißhandelte",
    "Mißhandelteren": "Mißhandeltere",
    "Mißhandeltesten": "Mißhandelteste",
    "Mißhandlungen": "Mißhandlung",
    "Mißheiraten": "Mißheirat",
    "Mißinterpretierenden": "Mißinterpretierende",
    "Mißinterpretierens": "Mißinterpretieren",
    "Mißinterpretierte": "mißinterpretiert",
    "Mißinterpretierten": "Mißinterpretierte",
    "Mißklange": "Mißklang",
    "Mißklanges": "Mißklang",
    "Mißklangs": "Mißklang",
    "Mißklänge": "Mißklang",
    "Mißklängen": "Mißklang",
    "Mißlichen": "Mißliche",
    "Mißlingenden": "Mißlingende",
    "Mißlingens": "Mißlingen",
    "Mißlungenen": "Mißlungene",
    "Mißlungeneren": "Mißlungenere",
    "Mißlungensten": "Mißlungenste",
    "Mißmutigen": "Mißmutige",
    "Mißmutigeren": "Mißmutigere",
    "Mißmutigsten": "Mißmutigste",
    "Mißratenden": "Mißratende",
    "Mißratenen": "Mißratene",
    "Mißrateneren": "Mißratenere",
    "Mißratens": "Mißraten",
    "Mißratenste": "mißraten",
    "Mißratensten": "Mißratenste",
    "Mißstande": "Mißstand",
    "Mißstandes": "Mißstand",
    "Mißstands": "Mißstand",
    "Mißstände": "Mißstand",
    "Mißständen": "Mißstand",
    "Mißtone": "Mißton",
    "Mißtons": "Mißton",
    "Mißtrauenden": "Mißtrauende",
    "Mißtrauenderen": "Mißtrauendere",
    "Mißtrauendsten": "Mißtrauendste",
    "Mißtrauens": "Mißtrauen",
    "Mißtrauischen": "Mißtrauische",
    "Mißtrauischeren": "Mißtrauischere",
    "Mißtrauischsten": "Mißtrauischste",
    "Mißtraute": "mißtraut",
    "Mißtrauten": "Mißtraute",
    "Mißtöne": "Mißton",
    "Mißtönen": "Mißton",
    "Mißverstandenen": "Mißverstandene",
    "Mißverstandeneren": "Mißverstandenere",
    "Mißverstandensten": "Mißverstandenste",
    "Mißverstehenden": "Mißverstehende",
    "Mißverstehens": "Mißverstehen",
    "Mißverständlichen": "Mißverständliche",
    "Mißverständnisse": "Mißverständnis",
    "Mißverständnissen": "Mißverständnis",
    "Mißverständnisses": "Mißverständnis",
    "Mißwirtschaftenden": "Mißwirtschaftende",
    "Mißwirtschaftens": "Mißwirtschaften",
    "Mißwirtschaftete": "mißwirtschaftet",
    "Mißwirtschafteten": "Mißwirtschaftete",
    "Mnemotechnischen": "Mnemotechnische",
    "Mobbings": "Mobbing",
    "Mobilen": "Mobile",
    "Mobileren": "Mobilere",
    "Mobilisierenden": "Mobilisierende",
    "Mobilisierenderen": "Mobilisierendere",
    "Mobilisierendsten": "Mobilisierendste",
    "Mobilisierens": "Mobilisieren",
    "Mobilisierte": "mobilisiert",
    "Mobilisierten": "Mobilisierte",
    "Mobilisierteren": "Mobilisiertere",
    "Mobilisiertesten": "Mobilisierteste",
    "Mobils": "Mobil",
    "Mobilste": "mobil",
    "Mobilsten": "Mobilste",
    "Mockstadts": "Mockstadt",
    "Modale": "modal",
    "Modalen": "Modale",
    "Modalitäten": "Modalität",
    "Modalverbe": "Modalverb",
    "Modalverben": "Modalverb",
    "Modalverbs": "Modalverb",
    "Modders": "Modder",
    "Modeartikeln": "Modeartikel",
    "Modeartikels": "Modeartikel",
    "Modebewußte": "modebewußt",
    "Modebewußten": "Modebewußte",
    "Modebewußteren": "Modebewußtere",
    "Modebewußtesten": "Modebewußteste",
    "Model": "modeln",
    "Modelle": "Modell",
    "Modellen": "Modell",
    "Modelles": "Modell",
    "Modellierenden": "Modellierende",
    "Modellierenderen": "Modellierendere",
    "Modellierendsten": "Modellierendste",
    "Modellierens": "Modellieren",
    "Modellierte": "modelliert",
    "Modellierten": "Modellierte",
    "Modellierungen": "Modellierung",
    "Modells": "Modell",
    "Modeln": "Model",
    "Modelnden": "Modelnde",
    "Modelns": "Modeln",
    "Models": "Model",
    "Modeme": "Modem",
    "Modemen": "Modem",
    "Modems": "Modem",
    "Moden": "Mode",
    "Modenschauen": "Modenschau",
    "Modepuppen": "Modepuppe",
    "Moderate": "moderat",
    "Moderaten": "Moderate",
    "Moderateren": "Moderatere",
    "Moderatesten": "Moderateste",
    "Moderatore": "Moderator",
    "Moderatoren": "Moderator",
    "Moderators": "Moderator",
    "Moderierenden": "Moderierende",
    "Moderierens": "Moderieren",
    "Moderierte": "moderiert",
    "Moderierten": "Moderierte",
    "Moderigen": "Moderige",
    "Moderigeren": "Moderigere",
    "Moderigsten": "Moderigste",
    "Modernen": "Moderne",
    "Moderneren": "Modernere",
    "Modernisierenden": "Modernisierende",
    "Modernisierens": "Modernisieren",
    "Modernisierte": "modernisiert",
    "Modernisierten": "Modernisierte",
    "Modernisierteren": "Modernisiertere",
    "Modernisiertesten": "Modernisierteste",
    "Modernisierungen": "Modernisierung",
    "Modernste": "modern",
    "Modernsten": "Modernste",
    "Moders": "Moder",
    "Modifikationen": "Modifikation",
    "Modifizierenden": "Modifizierende",
    "Modifizierens": "Modifizieren",
    "Modifizierte": "modifiziert",
    "Modifizierten": "Modifizierte",
    "Modifizierteren": "Modifiziertere",
    "Modifiziertesten": "Modifizierteste",
    "Modischen": "Modische",
    "Modischeren": "Modischere",
    "Modischsten": "Modischste",
    "Modistinnen": "Modistin",
    "Modrows": "Modrow",
    "Modulare": "modular",
    "Modularen": "Modulare",
    "Modulationsfähigen": "Modulationsfähige",
    "Modulierenden": "Modulierende",
    "Modulierens": "Modulieren",
    "Modulierte": "moduliert",
    "Modulierten": "Modulierte",
    "Mofas": "Mofa",
    "Mogadischus": "Mogadischu",
    "Mogelnden": "Mogelnde",
    "Mogelns": "Mogeln",
    "Mohammedanern": "Mohammedaner",
    "Mohammedaners": "Mohammedaner",
    "Mohammedanische": "mohammedanisch",
    "Mohammedanischen": "Mohammedanische",
    "Mohammeds": "Mohammed",
    "Mohikanern": "Mohikaner",
    "Mohikaners": "Mohikaner",
    "Mohne": "Mohn",
    "Mohnen": "Mohn",
    "Mohnes": "Mohn",
    "Mohns": "Mohn",
    "Mohrrüben": "Mohrrübe",
    "Mokassins": "Mokassin",
    "Mokicks": "Mokick",
    "Molche": "Molch",
    "Molchen": "Molch",
    "Molchs": "Molch",
    "Molekulare": "molekular",
    "Molekularen": "Molekulare",
    "Moleküle": "Molekül",
    "Molekülen": "Molekül",
    "Moleküls": "Molekül",
    "Molen": "Mole",
    "Molkereien": "Molkerei",
    "Mollige": "mollig",
    "Molligen": "Mollige",
    "Molligeren": "Molligere",
    "Molligsten": "Molligste",
    "Momentane": "momentan",
    "Momentanen": "Momentane",
    "Momentaufnahmen": "Momentaufnahme",
    "Momente": "Moment",
    "Momenten": "Moment",
    "Momentes": "Moment",
    "Moments": "Moment",
    "Mompers": "Momper",
    "Monarchien": "Monarchie",
    "Monate": "Monat",
    "Monaten": "Monat",
    "Monatliche": "monatlich",
    "Monatlichen": "Monatliche",
    "Monats": "Monat",
    "Monde": "Mond",
    "Monden": "Mond",
    "Mondenscheins": "Mondenschein",
    "Monds": "Mond",
    "Mondsüchtige": "mondsüchtig",
    "Mondsüchtigen": "Mondsüchtige",
    "Monegassen": "Monegasse",
    "Monegassische": "monegassisch",
    "Monegassischen": "Monegassische",
    "Mongolen": "Mongole",
    "Monicas": "Monica",
    "Monierenden": "Monierende",
    "Monierens": "Monieren",
    "Monierte": "moniert",
    "Monierten": "Monierte",
    "Monikas": "Monika",
    "Monogramme": "Monogramm",
    "Monogrammen": "Monogramm",
    "Monogramms": "Monogramm",
    "Monographische": "monographisch",
    "Monographischen": "Monographische",
    "Monokausalen": "Monokausale",
    "Monokulturen": "Monokultur",
    "Monolithen": "Monolith",
    "Monologe": "Monolog",
    "Monologen": "Monolog",
    "Monologes": "Monolog",
    "Monologs": "Monolog",
    "Monome": "Monom",
    "Monomen": "Monom",
    "Monomes": "Monom",
    "Monoms": "Monom",
    "Monopole": "Monopol",
    "Monopolen": "Monopol",
    "Monopoles": "Monopol",
    "Monopolisierenden": "Monopolisierende",
    "Monopolisierenderen": "Monopolisierendere",
    "Monopolisierens": "Monopolisieren",
    "Monopolisierte": "monopolisiert",
    "Monopolisierten": "Monopolisierte",
    "Monopolisierteren": "Monopolisiertere",
    "Monopolisierteste": "monopolisiert",
    "Monopolisten": "Monopolist",
    "Monopolistische": "monopolistisch",
    "Monopolistischen": "Monopolistische",
    "Monopols": "Monopol",
    "Monotone": "monoton",
    "Monotonen": "Monotone",
    "Monotoneren": "Monotonere",
    "Monotonsten": "Monotonste",
    "Monozellen": "Monozelle",
    "Monroes": "Monroe",
    "Monstern": "Monster",
    "Monsters": "Monster",
    "Monsune": "Monsun",
    "Monsunen": "Monsun",
    "Monsunes": "Monsun",
    "Monsuns": "Monsun",
    "Montagabende": "Montagabend",
    "Montagabenden": "Montagabend",
    "Montagabends": "Montagabend",
    "Montage": "Montag",
    "Montagen": "Montage",
    "Montags": "Montag",
    "Montane": "montan",
    "Montanen": "Montane",
    "Montanisten": "Montanist",
    "Montenegros": "Montenegro",
    "Monteure": "Monteur",
    "Monteuren": "Monteur",
    "Monteurs": "Monteur",
    "Montierenden": "Montierende",
    "Montierens": "Montieren",
    "Montierte": "montiert",
    "Montierten": "Montierte",
    "Montierungen": "Montierung",
    "Monumentale": "monumental",
    "Monumentalen": "Monumentale",
    "Monumentalfilme": "Monumentalfilm",
    "Monumentalfilmen": "Monumentalfilm",
    "Monumentalfilms": "Monumentalfilm",
    "Monumente": "Monument",
    "Monumenten": "Monument",
    "Monumentes": "Monument",
    "Monuments": "Monument",
    "Moore": "Moor",
    "Mooren": "Moor",
    "Moores": "Moor",
    "Moors": "Moor",
    "Moose": "Moos",
    "Moosen": "Moos",
    "Mooses": "Moos",
    "Mopeds": "Moped",
    "Moppeln": "Moppel",
    "Moppels": "Moppel",
    "Mopsenden": "Mopsende",
    "Mopsenderen": "Mopsendere",
    "Mopsendsten": "Mopsendste",
    "Mopsens": "Mopsen",
    "Mopsigen": "Mopsige",
    "Mopsigeren": "Mopsigere",
    "Mopsigsten": "Mopsigste",
    "Moralischen": "Moralische",
    "Moralisierenden": "Moralisierende",
    "Moralisierenderen": "Moralisierendere",
    "Moralisierendsten": "Moralisierendste",
    "Moralisierens": "Moralisieren",
    "Moralisierte": "moralisiert",
    "Moralisierten": "Moralisierte",
    "Moralisierteren": "Moralisiertere",
    "Moralisiertesten": "Moralisierteste",
    "Moraste": "Morast",
    "Morasten": "Morast",
    "Morastige": "morastig",
    "Morastigen": "Morastige",
    "Morastigeren": "Morastigere",
    "Morastigsten": "Morastigste",
    "Morasts": "Morast",
    "Morbide": "morbid",
    "Morbiden": "Morbide",
    "Morcheln": "Morchel",
    "Morde": "morden",
    "Morden": "Mord",
    "Mordenden": "Mordende",
    "Mordens": "Morden",
    "Mordes": "Mord",
    "Mords": "Mord",
    "Mordsmäßige": "mordsmäßig",
    "Mordsmäßigen": "Mordsmäßige",
    "Morgendliche": "morgendlich",
    "Morgendlichen": "Morgendliche",
    "Morgenländischen": "Morgenländische",
    "Morgens": "Morgen",
    "Morgenstunden": "Morgenstunde",
    "Morgige": "morgig",
    "Morgigen": "Morgige",
    "Morpheme": "Morphem",
    "Morphemen": "Morphem",
    "Morphems": "Morphem",
    "Morphologien": "Morphologie",
    "Morphologische": "morphologisch",
    "Morphologischen": "Morphologische",
    "Morphys": "Morphy",
    "Morsche": "morsch",
    "Morschen": "Morsche",
    "Morscheren": "Morschere",
    "Morschesten": "Morscheste",
    "Morsenden": "Morsende",
    "Morsens": "Morsen",
    "Mortadellas": "Mortadella",
    "Mortifizierenden": "Mortifizierende",
    "Mortifizierens": "Mortifizieren",
    "Mortifizierte": "mortifiziert",
    "Mortifizierten": "Mortifizierte",
    "Moränen": "Moräne",
    "Mosaike": "Mosaik",
    "Mosaiken": "Mosaik",
    "Mosaiks": "Mosaik",
    "Moscheen": "Moschee",
    "Moschuskrauts": "Moschuskraut",
    "Mosernden": "Mosernde",
    "Mosernderen": "Moserndere",
    "Moserndsten": "Moserndste",
    "Moserns": "Mosern",
    "Moskauern": "Moskauer",
    "Moskauers": "Moskauer",
    "Moskauhörige": "moskauhörig",
    "Moskauhörigen": "Moskauhörige",
    "Moskauhörigeren": "Moskauhörigere",
    "Moskauhörigsten": "Moskauhörigste",
    "Moskaus": "Moskau",
    "Moskitos": "Moskito",
    "Moslemische": "moslemisch",
    "Moslemischen": "Moslemische",
    "Moslems": "Moslem",
    "Moslimen": "Moslime",
    "Mostereien": "Mosterei",
    "Motels": "Motel",
    "Motivationen": "Motivation",
    "Motive": "Motiv",
    "Motiven": "Motiv",
    "Motives": "Motiv",
    "Motivierenden": "Motivierende",
    "Motivierenderen": "Motivierendere",
    "Motivierendsten": "Motivierendste",
    "Motivierens": "Motivieren",
    "Motivierte": "motiviert",
    "Motivierten": "Motivierte",
    "Motivierteren": "Motiviertere",
    "Motiviertesten": "Motivierteste",
    "Motivs": "Motiv",
    "Motore": "Motor",
    "Motoren": "Motor",
    "Motorische": "motorisch",
    "Motorischen": "Motorische",
    "Motorisierenden": "Motorisierende",
    "Motorisierens": "Motorisieren",
    "Motorisierte": "motorisiert",
    "Motorisierten": "Motorisierte",
    "Motorisierteren": "Motorisiertere",
    "Motorisiertesten": "Motorisierteste",
    "Motorisierungen": "Motorisierung",
    "Motorrade": "Motorrad",
    "Motorrades": "Motorrad",
    "Motorrads": "Motorrad",
    "Motorräder": "Motorrad",
    "Motorrädern": "Motorrad",
    "Motors": "Motor",
    "Motte": "motten",
    "Motten": "Motte",
    "Mottenden": "Mottende",
    "Mottens": "Motten",
    "Mottos": "Motto",
    "Motzenden": "Motzende",
    "Motzenderen": "Motzendere",
    "Motzendsten": "Motzendste",
    "Motzens": "Motzen",
    "Motzigen": "Motzige",
    "Motzigeren": "Motzigere",
    "Motzigsten": "Motzigste",
    "Mozarts": "Mozart",
    "Mucksenden": "Mucksende",
    "Mucksenderen": "Mucksendere",
    "Mucksendsten": "Mucksendste",
    "Mucksens": "Mucksen",
    "Muffe": "muffen",
    "Muffel": "muffeln",
    "Muffeligen": "Muffelige",
    "Muffeligeren": "Muffeligere",
    "Muffeligsten": "Muffeligste",
    "Muffeln": "Muffel",
    "Muffelnden": "Muffelnde",
    "Muffelnderen": "Muffelndere",
    "Muffelndsten": "Muffelndste",
    "Muffelns": "Muffeln",
    "Muffels": "Muffel",
    "Muffen": "Muffe",
    "Muffenden": "Muffende",
    "Muffenderen": "Muffendere",
    "Muffendsten": "Muffendste",
    "Muffens": "Muffen",
    "Muffigen": "Muffige",
    "Muffigeren": "Muffigere",
    "Muffigsten": "Muffigste",
    "Mulattinnen": "Mulattin",
    "Mulden": "Mulde",
    "Mulmige": "mulmig",
    "Mulmigen": "Mulmige",
    "Mulmigeren": "Mulmigere",
    "Mulmigsten": "Mulmigste",
    "Multidisziplinären": "Multidisziplinäre",
    "Multidisziplinäreren": "Multidisziplinärere",
    "Multifunktionalen": "Multifunktionale",
    "Multifunktionen": "Multifunktion",
    "Multikulturelle": "multikulturell",
    "Multikulturellen": "Multikulturelle",
    "Multikulturelleren": "Multikulturellere",
    "Multilingualen": "Multilinguale",
    "Multimedialen": "Multimediale",
    "Multimillionäre": "Multimillionär",
    "Multimillionären": "Multimillionär",
    "Multimillionärs": "Multimillionär",
    "Multis": "Multi",
    "Mumien": "Mumie",
    "Mumifizierenden": "Mumifizierende",
    "Mumifizierens": "Mumifizieren",
    "Mumifizierte": "mumifiziert",
    "Mumifizierten": "Mumifizierte",
    "Mumifizierungen": "Mumifizierung",
    "Munde": "munden",
    "Mundenden": "Mundende",
    "Mundenderen": "Mundendere",
    "Mundendsten": "Mundendste",
    "Mundens": "Munden",
    "Mundes": "Mund",
    "Mundgerechten": "Mundgerechte",
    "Mundgerechteren": "Mundgerechtere",
    "Mundgerechtesten": "Mundgerechteste",
    "Mundharmonikas": "Mundharmonika",
    "Mundraubs": "Mundraub",
    "Munds": "Mund",
    "Munkeleien": "Munkelei",
    "Munkelnden": "Munkelnde",
    "Munkelnderen": "Munkelndere",
    "Munkelndsten": "Munkelndste",
    "Munkelns": "Munkeln",
    "Munternden": "Munternde",
    "Munterns": "Muntern",
    "Murksenden": "Murksende",
    "Murksens": "Murksen",
    "Murmel": "murmeln",
    "Murmeln": "Murmel",
    "Murmelnden": "Murmelnde",
    "Murmelns": "Murmeln",
    "Murmeltiere": "Murmeltier",
    "Murmeltieren": "Murmeltier",
    "Murmeltiers": "Murmeltier",
    "Murrenden": "Murrende",
    "Murrenderen": "Murrendere",
    "Murrendsten": "Murrendste",
    "Murrens": "Murren",
    "Muscheln": "Muschel",
    "Muschis": "Muschi",
    "Museen": "Museum",
    "Musentempeln": "Musentempel",
    "Musentempels": "Musentempel",
    "Museums": "Museum",
    "Musicals": "Musical",
    "Musikalische": "musikalisch",
    "Musikalischen": "Musikalische",
    "Musikalischeren": "Musikalischere",
    "Musikalischsten": "Musikalischste",
    "Musikanten": "Musikant",
    "Musikerinnen": "Musikerin",
    "Musikern": "Musiker",
    "Musikers": "Musiker",
    "Musische": "musisch",
    "Musischen": "Musische",
    "Musischeren": "Musischere",
    "Musischsten": "Musischste",
    "Musizierenden": "Musizierende",
    "Musizierens": "Musizieren",
    "Musizierte": "musiziert",
    "Musizierten": "Musizierte",
    "Muskeln": "Muskel",
    "Muskels": "Muskel",
    "Musketen": "Muskete",
    "Musketiere": "Musketier",
    "Musketieren": "Musketier",
    "Musketiers": "Musketier",
    "Muskuläre": "muskulär",
    "Muskulären": "Muskuläre",
    "Muskuläreren": "Muskulärere",
    "Muskulärsten": "Muskulärste",
    "Muskulösen": "Muskulöse",
    "Muskulöseren": "Muskulösere",
    "Muskulösesten": "Muskulöseste",
    "Muslime": "Muslim",
    "Muslimen": "Muslime",
    "Muslimische": "muslimisch",
    "Muslimischen": "Muslimische",
    "Muslims": "Muslim",
    "Musse": "Muß",
    "Musses": "Muß",
    "Mustangs": "Mustang",
    "Muster": "mustern",
    "Mustergültigen": "Mustergültige",
    "Mustergültigeren": "Mustergültigere",
    "Mustergültigsten": "Mustergültigste",
    "Mustern": "Muster",
    "Musternden": "Musternde",
    "Musternderen": "Musterndere",
    "Musterndsten": "Musterndste",
    "Musterns": "Mustern",
    "Musters": "Muster",
    "Musterungen": "Musterung",
    "Mutanten": "Mutant",
    "Mutationen": "Mutation",
    "Mute": "muten",
    "Mutenden": "Mutende",
    "Mutens": "Muten",
    "Mutes": "Mut",
    "Mutierenden": "Mutierende",
    "Mutierenderen": "Mutierendere",
    "Mutierendsten": "Mutierendste",
    "Mutierens": "Mutieren",
    "Mutierte": "mutiert",
    "Mutierten": "Mutierte",
    "Mutierteren": "Mutiertere",
    "Mutiertesten": "Mutierteste",
    "Mutigen": "Mutige",
    "Mutigeren": "Mutigere",
    "Mutigsten": "Mutigste",
    "Mutlosen": "Mutlose",
    "Mutloseren": "Mutlosere",
    "Mutlosesten": "Mutloseste",
    "Mutmaßenden": "Mutmaßende",
    "Mutmaßenderen": "Mutmaßendere",
    "Mutmaßendsten": "Mutmaßendste",
    "Mutmaßens": "Mutmaßen",
    "Mutmaßlichen": "Mutmaßliche",
    "Muts": "Mut",
    "Muttermunde": "Muttermund",
    "Muttermundes": "Muttermund",
    "Muttermunds": "Muttermund",
    "Muttermünder": "Muttermund",
    "Muttermündern": "Muttermund",
    "Muttis": "Mutti",
    "Mutwillige": "mutwillig",
    "Mutwilligen": "Mutwillige",
    "Muß": "müssen",
    "Myrten": "Myrte",
    "Mys": "My",
    "Mysteriöse": "mysteriös",
    "Mysteriösen": "Mysteriöse",
    "Mysteriöseren": "Mysteriösere",
    "Mysteriösesten": "Mysteriöseste",
    "Mystifikationen": "Mystifikation",
    "Mystifiziere": "mystifizieren",
    "Mystifizierenden": "Mystifizierende",
    "Mystifizierenderen": "Mystifizierendere",
    "Mystifizierens": "Mystifizieren",
    "Mystifizierte": "mystifiziert",
    "Mystifizierten": "Mystifizierte",
    "Mystifizierteren": "Mystifiziertere",
    "Mystifiziertesten": "Mystifizierteste",
    "Mystikern": "Mystiker",
    "Mystikers": "Mystiker",
    "Mystische": "mystisch",
    "Mystischen": "Mystische",
    "Mystischeren": "Mystischere",
    "Mystischsten": "Mystischste",
    "Mythen": "Mythos",
    "Mythologien": "Mythologie",
    "Mächte": "Macht",
    "Mächten": "Macht",
    "Mächtige": "mächtig",
    "Mächtigen": "Mächtige",
    "Mächtigeren": "Mächtigere",
    "Mächtigsten": "Mächtigste",
    "Mädchens": "Mädchen",
    "Mädels": "Mädel",
    "Mägde": "Magd",
    "Mägden": "Magd",
    "Mägen": "Magen",
    "Mähdreschenden": "Mähdreschende",
    "Mähdreschens": "Mähdreschen",
    "Mähdreschern": "Mähdrescher",
    "Mähdreschers": "Mähdrescher",
    "Mähenden": "Mähende",
    "Mähens": "Mähen",
    "Mähern": "Mäher",
    "Mähers": "Mäher",
    "Mähnen": "Mähne",
    "Mähren": "Mähre",
    "Mäkelnden": "Mäkelnde",
    "Mäkelnderen": "Mäkelndere",
    "Mäkelndsten": "Mäkelndste",
    "Mäkelns": "Mäkeln",
    "Mängel": "Mangel",
    "Mängeln": "Mangel",
    "Mängelrügen": "Mängelrüge",
    "Männchens": "Männchen",
    "Männekens": "Männeken",
    "Männer": "Mann",
    "Männern": "Mann",
    "Männleins": "Männlein",
    "Männliche": "männlich",
    "Männlichen": "Männliche",
    "Männlicheren": "Männlichere",
    "Männlichkeiten": "Männlichkeit",
    "Männlichste": "männlich",
    "Männlichsten": "Männlichste",
    "Mäntel": "Mantel",
    "Mänteln": "Mantel",
    "Märchenhafte": "märchenhaft",
    "Märchenhaften": "Märchenhafte",
    "Märchenhafteren": "Märchenhaftere",
    "Märchenhaftesten": "Märchenhafteste",
    "Märchens": "Märchen",
    "Märkerwalds": "Märkerwald",
    "Märkischen": "Märkische",
    "Märkte": "Markt",
    "Märkten": "Markt",
    "Märsche": "Marsch",
    "Märschen": "Marsch",
    "Mästenden": "Mästende",
    "Mästenderen": "Mästendere",
    "Mästendsten": "Mästendste",
    "Mästens": "Mästen",
    "Mätressen": "Mätresse",
    "Mätzchens": "Mätzchen",
    "Mäulchens": "Mäulchen",
    "Mäuler": "Maul",
    "Mäulern": "Maul",
    "Mäuschens": "Mäuschen",
    "Mäuse": "Maus",
    "Mäusen": "Maus",
    "Mäzene": "Mäzen",
    "Mäzenen": "Mäzen",
    "Mäzens": "Mäzen",
    "Mäßige": "mäßig",
    "Mäßigen": "Mäßige",
    "Mäßigenden": "Mäßigende",
    "Mäßigens": "Mäßigen",
    "Mäßigeren": "Mäßigere",
    "Mäßigsten": "Mäßigste",
    "Möbel": "möbeln",
    "Möbeln": "Möbel",
    "Möbelnden": "Möbelnde",
    "Möbelns": "Möbeln",
    "Möbels": "Möbel",
    "Möblierenden": "Möblierende",
    "Möblierens": "Möblieren",
    "Möblierte": "möbliert",
    "Möblierten": "Möblierte",
    "Möblierungen": "Möblierung",
    "Möchtegerns": "Möchtegern",
    "Möglichen": "Mögliche",
    "Möglicheren": "Möglichere",
    "Möglichkeiten": "Möglichkeit",
    "Möglichste": "möglich",
    "Möglichsten": "Möglichste",
    "Möhren": "Möhre",
    "Möllemanns": "Möllemann",
    "Möllers": "Möller",
    "Möllns": "Mölln",
    "Mönche": "Mönch",
    "Mönchen": "Mönch",
    "Mönchengladbachs": "Mönchengladbach",
    "Mönches": "Mönch",
    "Mönchs": "Mönch",
    "Möndchens": "Möndchen",
    "Mörderinnen": "Mörderin",
    "Mörderische": "mörderisch",
    "Mörderischen": "Mörderische",
    "Mörderischeren": "Mörderischere",
    "Mörderischsten": "Mörderischste",
    "Mördern": "Mörder",
    "Mörders": "Mörder",
    "Mörfeldens": "Mörfelden",
    "Mörfeldern": "Mörfelder",
    "Mörfelders": "Mörfelder",
    "Mörlens": "Mörlen",
    "Mörtel": "mörteln",
    "Mörteln": "Mörtel",
    "Mörtelnden": "Mörtelnde",
    "Mörtelns": "Mörteln",
    "Mörtels": "Mörtel",
    "Möwen": "Möwe",
    "Mücken": "Mücke",
    "Müderen": "Müdere",
    "Müdesten": "Müdeste",
    "Müffchens": "Müffchen",
    "Mühelose": "mühelos",
    "Mühelosen": "Mühelose",
    "Müheloseren": "Mühelosere",
    "Mühelosesten": "Müheloseste",
    "Mühen": "Mühe",
    "Mühenden": "Mühende",
    "Mühens": "Mühen",
    "Mühevollen": "Mühevolle",
    "Mühevolleren": "Mühevollere",
    "Mühevollsten": "Mühevollste",
    "Mühlen": "Mühle",
    "Mühlheimern": "Mühlheimer",
    "Mühlheimers": "Mühlheimer",
    "Mühlheims": "Mühlheim",
    "Mühlrade": "Mühlrad",
    "Mühlrades": "Mühlrad",
    "Mühlrads": "Mühlrad",
    "Mühlräder": "Mühlrad",
    "Mühlrädern": "Mühlrad",
    "Mühlwerke": "Mühlwerk",
    "Mühlwerken": "Mühlwerk",
    "Mühlwerks": "Mühlwerk",
    "Mühsale": "Mühsal",
    "Mühsalen": "Mühsal",
    "Mühsame": "mühsam",
    "Mühsamen": "Mühsame",
    "Mühsameren": "Mühsamere",
    "Mühsamsten": "Mühsamste",
    "Mühseligen": "Mühselige",
    "Mühseligeren": "Mühseligere",
    "Mühseligsten": "Mühseligste",
    "Mülhausens": "Mülhausen",
    "Mülheims": "Mülheim",
    "Müllerinnen": "Müllerin",
    "Müllern": "Müller",
    "Müllers": "Müller",
    "Mülls": "Müll",
    "Mümmelnden": "Mümmelnde",
    "Mümmelnderen": "Mümmelndere",
    "Mümmelndsten": "Mümmelndste",
    "Mümmelns": "Mümmeln",
    "Münchenern": "Münchener",
    "Müncheners": "Münchener",
    "Münchens": "München",
    "Münchnern": "Münchner",
    "Münchners": "Münchner",
    "Münchs": "Münch",
    "Mündchens": "Mündchen",
    "Mündende": "mündend",
    "Mündenden": "Mündende",
    "Mündens": "Münden",
    "Münder": "Mund",
    "Mündern": "Mund",
    "Mündige": "mündig",
    "Mündigen": "Mündige",
    "Mündigeren": "Mündigere",
    "Mündigsten": "Mündigste",
    "Mündlichen": "Mündliche",
    "Mündungen": "Mündung",
    "Münsters": "Münster",
    "Münteferings": "Müntefering",
    "Münzen": "Münze",
    "Münzenden": "Münzende",
    "Münzens": "Münzen",
    "Münzern": "Münzer",
    "Münzers": "Münzer",
    "Münzzeichens": "Münzzeichen",
    "Mürberen": "Mürbere",
    "Mürbesten": "Mürbeste",
    "Mürbeteige": "Mürbeteig",
    "Mürbeteigen": "Mürbeteig",
    "Mürbeteigs": "Mürbeteig",
    "Mürrischen": "Mürrische",
    "Mürrischeren": "Mürrischere",
    "Mürrischsten": "Mürrischste",
    "Müschelchens": "Müschelchen",
    "Müslis": "Müsli",
    "Mütter": "Mutter",
    "Mütterchens": "Mütterchen",
    "Mütterleins": "Mütterlein",
    "Mütterliche": "mütterlich",
    "Mütterlichen": "Mütterliche",
    "Müttern": "Mutter",
    "Mützen": "Mütze",
    "Müßigen": "Müßige",
    "Müßigeren": "Müßigere",
    "Müßigsten": "Müßigste",
    "NVAs": "NVA",
    "Nabel": "nabeln",
    "Nabeln": "Nabel",
    "Nabelnden": "Nabelnde",
    "Nabelns": "Nabeln",
    "Nabels": "Nabel",
    "Naben": "Nabe",
    "Nachahmenden": "Nachahmende",
    "Nachahmenderen": "Nachahmendere",
    "Nachahmendsten": "Nachahmendste",
    "Nachahmens": "Nachahmen",
    "Nachahmenswerte": "nachahmenswert",
    "Nachahmenswerten": "Nachahmenswerte",
    "Nachahmungen": "Nachahmung",
    "Nacharbeitenden": "Nacharbeitende",
    "Nacharbeitens": "Nacharbeiten",
    "Nachbarinnen": "Nachbarin",
    "Nachbarn": "Nachbar",
    "Nachbauenden": "Nachbauende",
    "Nachbauens": "Nachbauen",
    "Nachbebens": "Nachbeben",
    "Nachbehandlungen": "Nachbehandlung",
    "Nachberechnenden": "Nachberechnende",
    "Nachberechnens": "Nachberechnen",
    "Nachberechnete": "nachberechnet",
    "Nachberechneten": "Nachberechnete",
    "Nachberechnungen": "Nachberechnung",
    "Nachbereitenden": "Nachbereitende",
    "Nachbereitens": "Nachbereiten",
    "Nachbereitete": "nachbereitet",
    "Nachbereiteten": "Nachbereitete",
    "Nachbereiteteren": "Nachbereitetere",
    "Nachbereitetesten": "Nachbereiteteste",
    "Nachbestellenden": "Nachbestellende",
    "Nachbestellens": "Nachbestellen",
    "Nachbestellte": "nachbestellt",
    "Nachbestellten": "Nachbestellte",
    "Nachbestellungen": "Nachbestellung",
    "Nachbetenden": "Nachbetende",
    "Nachbetens": "Nachbeten",
    "Nachbilde": "nachbilden",
    "Nachbildenden": "Nachbildende",
    "Nachbildenderen": "Nachbildendere",
    "Nachbildendsten": "Nachbildendste",
    "Nachbildens": "Nachbilden",
    "Nachbilder": "Nachbild",
    "Nachbildern": "Nachbild",
    "Nachbildes": "Nachbild",
    "Nachbilds": "Nachbild",
    "Nachbildungen": "Nachbildung",
    "Nachbleibenden": "Nachbleibende",
    "Nachbleibens": "Nachbleiben",
    "Nachbleichenden": "Nachbleichende",
    "Nachbleichens": "Nachbleichen",
    "Nachblickenden": "Nachblickende",
    "Nachblickenderen": "Nachblickendere",
    "Nachblickendsten": "Nachblickendste",
    "Nachblickens": "Nachblicken",
    "Nachblutenden": "Nachblutende",
    "Nachblutens": "Nachbluten",
    "Nachblutungen": "Nachblutung",
    "Nachbohrenden": "Nachbohrende",
    "Nachbohrens": "Nachbohren",
    "Nachbringenden": "Nachbringende",
    "Nachbringens": "Nachbringen",
    "Nachbürgen": "Nachbürge",
    "Nachdatierenden": "Nachdatierende",
    "Nachdatierens": "Nachdatieren",
    "Nachdatierte": "nachdatiert",
    "Nachdatierten": "Nachdatierte",
    "Nachdenkenden": "Nachdenkende",
    "Nachdenkenderen": "Nachdenkendere",
    "Nachdenkendsten": "Nachdenkendste",
    "Nachdenkens": "Nachdenken",
    "Nachdenklichen": "Nachdenkliche",
    "Nachdenklicheren": "Nachdenklichere",
    "Nachdenklichsten": "Nachdenklichste",
    "Nachdichtenden": "Nachdichtende",
    "Nachdichtens": "Nachdichten",
    "Nachdichtungen": "Nachdichtung",
    "Nachdringenden": "Nachdringende",
    "Nachdringens": "Nachdringen",
    "Nachdrucke": "nachdrucken",
    "Nachdrucken": "Nachdruck",
    "Nachdruckenden": "Nachdruckende",
    "Nachdruckens": "Nachdrucken",
    "Nachdruckes": "Nachdruck",
    "Nachdrucks": "Nachdruck",
    "Nachdrängenden": "Nachdrängende",
    "Nachdrängens": "Nachdrängen",
    "Nachdrücklichen": "Nachdrückliche",
    "Nachdunkelnden": "Nachdunkelnde",
    "Nachdunkelnderen": "Nachdunkelndere",
    "Nachdunkelndsten": "Nachdunkelndste",
    "Nachdunkelns": "Nachdunkeln",
    "Nacheifernden": "Nacheifernde",
    "Nacheiferns": "Nacheifern",
    "Nacheilenden": "Nacheilende",
    "Nacheilens": "Nacheilen",
    "Nachempfindenden": "Nachempfindende",
    "Nachempfindenderen": "Nachempfindendere",
    "Nachempfindens": "Nachempfinden",
    "Nachempfundenen": "Nachempfundene",
    "Nachempfundeneren": "Nachempfundenere",
    "Nachempfundensten": "Nachempfundenste",
    "Nacherzählenden": "Nacherzählende",
    "Nacherzählens": "Nacherzählen",
    "Nacherzählte": "nacherzählt",
    "Nacherzählten": "Nacherzählte",
    "Nacherzählungen": "Nacherzählung",
    "Nachessenden": "Nachessende",
    "Nachessens": "Nachessen",
    "Nachfahren": "Nachfahr",
    "Nachfahrenden": "Nachfahrende",
    "Nachfahrens": "Nachfahren",
    "Nachfassenden": "Nachfassende",
    "Nachfassens": "Nachfassen",
    "Nachfeiernden": "Nachfeiernde",
    "Nachfeierns": "Nachfeiern",
    "Nachfilmenden": "Nachfilmende",
    "Nachfilmens": "Nachfilmen",
    "Nachfolgenden": "Nachfolgende",
    "Nachfolgens": "Nachfolgen",
    "Nachfolgerinnen": "Nachfolgerin",
    "Nachfolgern": "Nachfolger",
    "Nachfolgers": "Nachfolger",
    "Nachfordernden": "Nachfordernde",
    "Nachforderns": "Nachfordern",
    "Nachforschenden": "Nachforschende",
    "Nachforschenderen": "Nachforschendere",
    "Nachforschendsten": "Nachforschendste",
    "Nachforschens": "Nachforschen",
    "Nachfragenden": "Nachfragende",
    "Nachfragens": "Nachfragen",
    "Nachfristen": "Nachfrist",
    "Nachfühlenden": "Nachfühlende",
    "Nachfühlenderen": "Nachfühlendere",
    "Nachfühlendsten": "Nachfühlendste",
    "Nachfühlens": "Nachfühlen",
    "Nachfüllenden": "Nachfüllende",
    "Nachfüllens": "Nachfüllen",
    "Nachfüllungen": "Nachfüllung",
    "Nachgeahmten": "Nachgeahmte",
    "Nachgeahmteren": "Nachgeahmtere",
    "Nachgeahmtesten": "Nachgeahmteste",
    "Nachgearbeiteten": "Nachgearbeitete",
    "Nachgebauten": "Nachgebaute",
    "Nachgebenden": "Nachgebende",
    "Nachgebenderen": "Nachgebendere",
    "Nachgebendsten": "Nachgebendste",
    "Nachgebens": "Nachgeben",
    "Nachgebeteten": "Nachgebetete",
    "Nachgebildeten": "Nachgebildete",
    "Nachgebildeteren": "Nachgebildetere",
    "Nachgebildetesten": "Nachgebildeteste",
    "Nachgeblichenen": "Nachgeblichene",
    "Nachgeblicheneren": "Nachgeblichenere",
    "Nachgeblichensten": "Nachgeblichenste",
    "Nachgeblickten": "Nachgeblickte",
    "Nachgeblickteren": "Nachgeblicktere",
    "Nachgeblicktesten": "Nachgeblickteste",
    "Nachgebliebenen": "Nachgebliebene",
    "Nachgebluteten": "Nachgeblutete",
    "Nachgebohrten": "Nachgebohrte",
    "Nachgebrachten": "Nachgebrachte",
    "Nachgeburten": "Nachgeburt",
    "Nachgebühren": "Nachgebühr",
    "Nachgedachten": "Nachgedachte",
    "Nachgedichteten": "Nachgedichtete",
    "Nachgedruckten": "Nachgedruckte",
    "Nachgedrungenen": "Nachgedrungene",
    "Nachgedrängten": "Nachgedrängte",
    "Nachgedunkelten": "Nachgedunkelte",
    "Nachgedunkelteren": "Nachgedunkeltere",
    "Nachgeeiferten": "Nachgeeiferte",
    "Nachgeeilten": "Nachgeeilte",
    "Nachgefahrenen": "Nachgefahrene",
    "Nachgefaßten": "Nachgefaßte",
    "Nachgefeierten": "Nachgefeierte",
    "Nachgefilmten": "Nachgefilmte",
    "Nachgefolgten": "Nachgefolgte",
    "Nachgeforderten": "Nachgeforderte",
    "Nachgeforschten": "Nachgeforschte",
    "Nachgefragten": "Nachgefragte",
    "Nachgefühlten": "Nachgefühlte",
    "Nachgefühlteren": "Nachgefühltere",
    "Nachgefühltesten": "Nachgefühlteste",
    "Nachgefüllten": "Nachgefüllte",
    "Nachgegangenen": "Nachgegangene",
    "Nachgegebenen": "Nachgegebene",
    "Nachgegessenen": "Nachgegessene",
    "Nachgegorenen": "Nachgegorene",
    "Nachgegoreneren": "Nachgegorenere",
    "Nachgegorensten": "Nachgegorenste",
    "Nachgegossenen": "Nachgegossene",
    "Nachgegrübelten": "Nachgegrübelte",
    "Nachgehakten": "Nachgehakte",
    "Nachgehallten": "Nachgehallte",
    "Nachgehangenen": "Nachgehangene",
    "Nachgehenden": "Nachgehende",
    "Nachgehens": "Nachgehen",
    "Nachgehinkten": "Nachgehinkte",
    "Nachgehinkteren": "Nachgehinktere",
    "Nachgehinktesten": "Nachgehinkteste",
    "Nachgeholfenen": "Nachgeholfene",
    "Nachgeholten": "Nachgeholte",
    "Nachgehängten": "Nachgehängte",
    "Nachgeimpften": "Nachgeimpfte",
    "Nachgejagten": "Nachgejagte",
    "Nachgejagteren": "Nachgejagtere",
    "Nachgejagtesten": "Nachgejagteste",
    "Nachgekarteten": "Nachgekartete",
    "Nachgekarteteren": "Nachgekartetere",
    "Nachgekartetesten": "Nachgekarteteste",
    "Nachgekauften": "Nachgekaufte",
    "Nachgeklungenen": "Nachgeklungene",
    "Nachgekommenen": "Nachgekommene",
    "Nachgeladenen": "Nachgeladene",
    "Nachgelassenen": "Nachgelassene",
    "Nachgelaufenen": "Nachgelaufene",
    "Nachgelebten": "Nachgelebte",
    "Nachgelegten": "Nachgelegte",
    "Nachgelernten": "Nachgelernte",
    "Nachgelesenen": "Nachgelesene",
    "Nachgelieferten": "Nachgelieferte",
    "Nachgelösten": "Nachgelöste",
    "Nachgemachten": "Nachgemachte",
    "Nachgemachteren": "Nachgemachtere",
    "Nachgemachtesten": "Nachgemachteste",
    "Nachgemalten": "Nachgemalte",
    "Nachgemeldeten": "Nachgemeldete",
    "Nachgemessenen": "Nachgemessene",
    "Nachgenommenen": "Nachgenommene",
    "Nachgepfiffenen": "Nachgepfiffene",
    "Nachgeprüften": "Nachgeprüfte",
    "Nachgeprüfteren": "Nachgeprüftere",
    "Nachgeprüftesten": "Nachgeprüfteste",
    "Nachgerannten": "Nachgerannte",
    "Nachgeratenden": "Nachgeratende",
    "Nachgeratenen": "Nachgeratene",
    "Nachgeratens": "Nachgeraten",
    "Nachgerechneten": "Nachgerechnete",
    "Nachgeredeten": "Nachgeredete",
    "Nachgereichten": "Nachgereichte",
    "Nachgereiften": "Nachgereifte",
    "Nachgereisten": "Nachgereiste",
    "Nachgerufenen": "Nachgerufene",
    "Nachgerühmten": "Nachgerühmte",
    "Nachgerüsteten": "Nachgerüstete",
    "Nachgesagten": "Nachgesagte",
    "Nachgesandten": "Nachgesandte",
    "Nachgeschaffenen": "Nachgeschaffene",
    "Nachgeschafften": "Nachgeschaffte",
    "Nachgeschauten": "Nachgeschaute",
    "Nachgeschlagenen": "Nachgeschlagene",
    "Nachgeschleppten": "Nachgeschleppte",
    "Nachgeschlichenen": "Nachgeschlichene",
    "Nachgeschmacke": "Nachgeschmack",
    "Nachgeschmackes": "Nachgeschmack",
    "Nachgeschmacks": "Nachgeschmack",
    "Nachgeschmissenen": "Nachgeschmissene",
    "Nachgeschmisseneren": "Nachgeschmissenere",
    "Nachgeschmäcker": "Nachgeschmack",
    "Nachgeschmäckern": "Nachgeschmack",
    "Nachgeschnittenen": "Nachgeschnittene",
    "Nachgeschriebenen": "Nachgeschriebene",
    "Nachgeschwommenen": "Nachgeschwommene",
    "Nachgeschütteten": "Nachgeschüttete",
    "Nachgesehenen": "Nachgesehene",
    "Nachgesendeten": "Nachgesendete",
    "Nachgesessenen": "Nachgesessene",
    "Nachgesetzten": "Nachgesetzte",
    "Nachgesonnenen": "Nachgesonnene",
    "Nachgespielten": "Nachgespielte",
    "Nachgesprochenen": "Nachgesprochene",
    "Nachgesprocheneren": "Nachgesprochenere",
    "Nachgesprungenen": "Nachgesprungene",
    "Nachgespülten": "Nachgespülte",
    "Nachgespürten": "Nachgespürte",
    "Nachgespürteren": "Nachgespürtere",
    "Nachgespürtesten": "Nachgespürteste",
    "Nachgestandenen": "Nachgestandene",
    "Nachgestellten": "Nachgestellte",
    "Nachgestiegenen": "Nachgestiegene",
    "Nachgestimmten": "Nachgestimmte",
    "Nachgestrebten": "Nachgestrebte",
    "Nachgestürzten": "Nachgestürzte",
    "Nachgesuchten": "Nachgesuchte",
    "Nachgesungenen": "Nachgesungene",
    "Nachgesungeneren": "Nachgesungenere",
    "Nachgesungensten": "Nachgesungenste",
    "Nachgetankten": "Nachgetankte",
    "Nachgetragenen": "Nachgetragene",
    "Nachgetrauerten": "Nachgetrauerte",
    "Nachgetönten": "Nachgetönte",
    "Nachgewachsenen": "Nachgewachsene",
    "Nachgewachsten": "Nachgewachste",
    "Nachgeweinten": "Nachgeweinte",
    "Nachgewiesenen": "Nachgewiesene",
    "Nachgewinkten": "Nachgewinkte",
    "Nachgewirkten": "Nachgewirkte",
    "Nachgewogenen": "Nachgewogene",
    "Nachgeworfenen": "Nachgeworfene",
    "Nachgeworfeneren": "Nachgeworfenere",
    "Nachgeworfensten": "Nachgeworfenste",
    "Nachgezahlten": "Nachgezahlte",
    "Nachgezeichneten": "Nachgezeichnete",
    "Nachgezogenen": "Nachgezogene",
    "Nachgezählte": "nachgezählt",
    "Nachgezählten": "Nachgezählte",
    "Nachgeäfften": "Nachgeäffte",
    "Nachgeäffteren": "Nachgeäfftere",
    "Nachgeäfftesten": "Nachgeäffteste",
    "Nachgießenden": "Nachgießende",
    "Nachgießens": "Nachgießen",
    "Nachgrübelnden": "Nachgrübelnde",
    "Nachgrübelnderen": "Nachgrübelndere",
    "Nachgrübelndsten": "Nachgrübelndste",
    "Nachgrübelns": "Nachgrübeln",
    "Nachgärenden": "Nachgärende",
    "Nachgärenderen": "Nachgärendere",
    "Nachgärendsten": "Nachgärendste",
    "Nachgärens": "Nachgären",
    "Nachgärungen": "Nachgärung",
    "Nachhakenden": "Nachhakende",
    "Nachhakenderen": "Nachhakendere",
    "Nachhakendsten": "Nachhakendste",
    "Nachhakens": "Nachhaken",
    "Nachhalle": "nachhallen",
    "Nachhallen": "Nachhall",
    "Nachhallenden": "Nachhallende",
    "Nachhallenderen": "Nachhallendere",
    "Nachhallendsten": "Nachhallendste",
    "Nachhallens": "Nachhallen",
    "Nachhalls": "Nachhall",
    "Nachhaltigen": "Nachhaltige",
    "Nachhaltigeren": "Nachhaltigere",
    "Nachhaltigsten": "Nachhaltigste",
    "Nachhausewege": "Nachhauseweg",
    "Nachhausewegen": "Nachhauseweg",
    "Nachhausewegs": "Nachhauseweg",
    "Nachhelfenden": "Nachhelfende",
    "Nachhelfens": "Nachhelfen",
    "Nachherbste": "Nachherbst",
    "Nachherbsten": "Nachherbst",
    "Nachherbsts": "Nachherbst",
    "Nachhilfen": "Nachhilfe",
    "Nachhinkenden": "Nachhinkende",
    "Nachhinkenderen": "Nachhinkendere",
    "Nachhinkendsten": "Nachhinkendste",
    "Nachhinkens": "Nachhinken",
    "Nachholbedarfs": "Nachholbedarf",
    "Nachholenden": "Nachholende",
    "Nachholens": "Nachholen",
    "Nachhuten": "Nachhut",
    "Nachhängenden": "Nachhängende",
    "Nachhängens": "Nachhängen",
    "Nachimpfenden": "Nachimpfende",
    "Nachimpfens": "Nachimpfen",
    "Nachimpfungen": "Nachimpfung",
    "Nachjagenden": "Nachjagende",
    "Nachjagenderen": "Nachjagendere",
    "Nachjagendsten": "Nachjagendste",
    "Nachjagens": "Nachjagen",
    "Nachkartenden": "Nachkartende",
    "Nachkartenderen": "Nachkartendere",
    "Nachkartendsten": "Nachkartendste",
    "Nachkartens": "Nachkarten",
    "Nachkaufenden": "Nachkaufende",
    "Nachkaufens": "Nachkaufen",
    "Nachklange": "Nachklang",
    "Nachklangs": "Nachklang",
    "Nachklingenden": "Nachklingende",
    "Nachklingens": "Nachklingen",
    "Nachklänge": "nachklingen",
    "Nachklängen": "nachklingen",
    "Nachkommen": "Nachkomme",
    "Nachkommenden": "Nachkommende",
    "Nachkommens": "Nachkommen",
    "Nachkontrollierenden": "Nachkontrollierende",
    "Nachkontrollierens": "Nachkontrollieren",
    "Nachkontrollierte": "nachkontrolliert",
    "Nachkontrollierten": "Nachkontrollierte",
    "Nachkriegszeiten": "Nachkriegszeit",
    "Nachkuren": "Nachkur",
    "Nachkömmlinge": "Nachkömmling",
    "Nachkömmlingen": "Nachkömmling",
    "Nachkömmlings": "Nachkömmling",
    "Nachladenden": "Nachladende",
    "Nachladens": "Nachladen",
    "Nachlasse": "nachlassen",
    "Nachlassenden": "Nachlassende",
    "Nachlassens": "Nachlassen",
    "Nachlasses": "Nachlaß",
    "Nachlaufe": "nachlaufen",
    "Nachlaufenden": "Nachlaufende",
    "Nachlaufens": "Nachlaufen",
    "Nachlaufs": "Nachlauf",
    "Nachlebenden": "Nachlebende",
    "Nachlebens": "Nachleben",
    "Nachlegenden": "Nachlegende",
    "Nachlegens": "Nachlegen",
    "Nachlernenden": "Nachlernende",
    "Nachlernens": "Nachlernen",
    "Nachlesen": "Nachlese",
    "Nachlesenden": "Nachlesende",
    "Nachlesens": "Nachlesen",
    "Nachliefernden": "Nachliefernde",
    "Nachlieferns": "Nachliefern",
    "Nachlieferungen": "Nachlieferung",
    "Nachlässe": "Nachlaß",
    "Nachlässen": "Nachlaß",
    "Nachlässigen": "Nachlässige",
    "Nachlässigeren": "Nachlässigere",
    "Nachlässigkeiten": "Nachlässigkeit",
    "Nachlässigste": "nachlässig",
    "Nachlässigsten": "Nachlässigste",
    "Nachläufe": "Nachlauf",
    "Nachläufen": "Nachlauf",
    "Nachläufern": "Nachläufer",
    "Nachläufers": "Nachläufer",
    "Nachlösenden": "Nachlösende",
    "Nachlösens": "Nachlösen",
    "Nachmachenden": "Nachmachende",
    "Nachmachens": "Nachmachen",
    "Nachmalenden": "Nachmalende",
    "Nachmalens": "Nachmalen",
    "Nachmeldenden": "Nachmeldende",
    "Nachmeldens": "Nachmelden",
    "Nachmessenden": "Nachmessende",
    "Nachmessens": "Nachmessen",
    "Nachmittage": "Nachmittag",
    "Nachmittagen": "Nachmittag",
    "Nachmittages": "Nachmittag",
    "Nachmittags": "Nachmittag",
    "Nachnahmen": "nachnehmen",
    "Nachnamen": "Nachname",
    "Nachnehmenden": "Nachnehmende",
    "Nachnehmens": "Nachnehmen",
    "Nachpfeifenden": "Nachpfeifende",
    "Nachpfeifenderen": "Nachpfeifendere",
    "Nachpfeifendsten": "Nachpfeifendste",
    "Nachpfeifens": "Nachpfeifen",
    "Nachprüfbaren": "Nachprüfbare",
    "Nachprüfenden": "Nachprüfende",
    "Nachprüfens": "Nachprüfen",
    "Nachprüfungen": "Nachprüfung",
    "Nachrechnenden": "Nachrechnende",
    "Nachrechnens": "Nachrechnen",
    "Nachreden": "Nachrede",
    "Nachredenden": "Nachredende",
    "Nachredens": "Nachreden",
    "Nachreichenden": "Nachreichende",
    "Nachreichens": "Nachreichen",
    "Nachreifenden": "Nachreifende",
    "Nachreifens": "Nachreifen",
    "Nachreisenden": "Nachreisende",
    "Nachreisens": "Nachreisen",
    "Nachrennenden": "Nachrennende",
    "Nachrennens": "Nachrennen",
    "Nachrichten": "Nachricht",
    "Nachrufe": "nachrufen",
    "Nachrufen": "Nachruf",
    "Nachrufenden": "Nachrufende",
    "Nachrufens": "Nachrufen",
    "Nachrufs": "Nachruf",
    "Nachruhme": "Nachruhm",
    "Nachruhmes": "Nachruhm",
    "Nachruhms": "Nachruhm",
    "Nachrühmenden": "Nachrühmende",
    "Nachrühmens": "Nachrühmen",
    "Nachrüstenden": "Nachrüstende",
    "Nachrüstens": "Nachrüsten",
    "Nachsagenden": "Nachsagende",
    "Nachsagens": "Nachsagen",
    "Nachsatze": "Nachsatz",
    "Nachsatzes": "Nachsatz",
    "Nachschaffenden": "Nachschaffende",
    "Nachschaffens": "Nachschaffen",
    "Nachschauenden": "Nachschauende",
    "Nachschauens": "Nachschauen",
    "Nachschlagenden": "Nachschlagende",
    "Nachschlagens": "Nachschlagen",
    "Nachschlagewerke": "Nachschlagewerk",
    "Nachschlagewerken": "Nachschlagewerk",
    "Nachschlagewerks": "Nachschlagewerk",
    "Nachschleichenden": "Nachschleichende",
    "Nachschleichens": "Nachschleichen",
    "Nachschleppenden": "Nachschleppende",
    "Nachschleppens": "Nachschleppen",
    "Nachschlüsseln": "Nachschlüssel",
    "Nachschlüssels": "Nachschlüssel",
    "Nachschmeißenden": "Nachschmeißende",
    "Nachschmeißens": "Nachschmeißen",
    "Nachschneidenden": "Nachschneidende",
    "Nachschneidens": "Nachschneiden",
    "Nachschreibenden": "Nachschreibende",
    "Nachschreibens": "Nachschreiben",
    "Nachschriften": "Nachschrift",
    "Nachschube": "Nachschub",
    "Nachschubes": "Nachschub",
    "Nachschubs": "Nachschub",
    "Nachschwimmenden": "Nachschwimmende",
    "Nachschwimmens": "Nachschwimmen",
    "Nachschübe": "Nachschub",
    "Nachschüben": "Nachschub",
    "Nachschüttenden": "Nachschüttende",
    "Nachschüttens": "Nachschütten",
    "Nachsehenden": "Nachsehende",
    "Nachsehens": "Nachsehen",
    "Nachsendenden": "Nachsendende",
    "Nachsendens": "Nachsenden",
    "Nachsendungen": "Nachsendung",
    "Nachsetzenden": "Nachsetzende",
    "Nachsetzenderen": "Nachsetzendere",
    "Nachsetzendsten": "Nachsetzendste",
    "Nachsetzens": "Nachsetzen",
    "Nachsichtigen": "Nachsichtige",
    "Nachsichtigeren": "Nachsichtigere",
    "Nachsichtigsten": "Nachsichtigste",
    "Nachsilben": "Nachsilbe",
    "Nachsingenden": "Nachsingende",
    "Nachsingenderen": "Nachsingendere",
    "Nachsingendsten": "Nachsingendste",
    "Nachsingens": "Nachsingen",
    "Nachsinnenden": "Nachsinnende",
    "Nachsinnenderen": "Nachsinnendere",
    "Nachsinnendsten": "Nachsinnendste",
    "Nachsinnens": "Nachsinnen",
    "Nachsitzenden": "Nachsitzende",
    "Nachsitzens": "Nachsitzen",
    "Nachsommern": "Nachsommer",
    "Nachsommers": "Nachsommer",
    "Nachspielenden": "Nachspielende",
    "Nachspielens": "Nachspielen",
    "Nachsprechenden": "Nachsprechende",
    "Nachsprechenderen": "Nachsprechendere",
    "Nachsprechendsten": "Nachsprechendste",
    "Nachsprechens": "Nachsprechen",
    "Nachspringenden": "Nachspringende",
    "Nachspringens": "Nachspringen",
    "Nachspülenden": "Nachspülende",
    "Nachspülens": "Nachspülen",
    "Nachspürenden": "Nachspürende",
    "Nachspürenderen": "Nachspürendere",
    "Nachspürendsten": "Nachspürendste",
    "Nachspürens": "Nachspüren",
    "Nachstehenden": "Nachstehende",
    "Nachstehens": "Nachstehen",
    "Nachsteigenden": "Nachsteigende",
    "Nachsteigens": "Nachsteigen",
    "Nachstellenden": "Nachstellende",
    "Nachstellens": "Nachstellen",
    "Nachstimmenden": "Nachstimmende",
    "Nachstimmens": "Nachstimmen",
    "Nachstrebenden": "Nachstrebende",
    "Nachstrebenderen": "Nachstrebendere",
    "Nachstrebendsten": "Nachstrebendste",
    "Nachstrebens": "Nachstreben",
    "Nachstürzenden": "Nachstürzende",
    "Nachstürzens": "Nachstürzen",
    "Nachsuchenden": "Nachsuchende",
    "Nachsuchens": "Nachsuchen",
    "Nachsätze": "Nachsatz",
    "Nachsätzen": "Nachsatz",
    "Nachtankenden": "Nachtankende",
    "Nachtankens": "Nachtanken",
    "Nachteile": "Nachteil",
    "Nachteilen": "Nachteil",
    "Nachteils": "Nachteil",
    "Nachtessens": "Nachtessen",
    "Nachteulen": "Nachteule",
    "Nachthauben": "Nachthaube",
    "Nachtigallen": "Nachtigall",
    "Nachtische": "Nachtisch",
    "Nachtischen": "Nachtisch",
    "Nachtischs": "Nachtisch",
    "Nachtrage": "nachtragen",
    "Nachtragenden": "Nachtragende",
    "Nachtragenderen": "Nachtragendere",
    "Nachtragendsten": "Nachtragendste",
    "Nachtragens": "Nachtragen",
    "Nachtrages": "Nachtrag",
    "Nachtrags": "Nachtrag",
    "Nachtrauernden": "Nachtrauernde",
    "Nachtrauerns": "Nachtrauern",
    "Nachträge": "Nachtrag",
    "Nachträgen": "Nachtrag",
    "Nachträglichen": "Nachträgliche",
    "Nachtschlafe": "Nachtschlaf",
    "Nachtschlafende": "nachtschlafend",
    "Nachtschlafenden": "Nachtschlafende",
    "Nachtschlafes": "Nachtschlaf",
    "Nachtschlafs": "Nachtschlaf",
    "Nachtwachen": "Nachtwache",
    "Nachtwandlerische": "nachtwandlerisch",
    "Nachtwandlerischen": "Nachtwandlerische",
    "Nachtönenden": "Nachtönende",
    "Nachtönens": "Nachtönen",
    "Nachuntersuchungen": "Nachuntersuchung",
    "Nachversichernden": "Nachversichernde",
    "Nachversicherns": "Nachversichern",
    "Nachversicherte": "nachversichert",
    "Nachversicherten": "Nachversicherte",
    "Nachvertonenden": "Nachvertonende",
    "Nachvertonens": "Nachvertonen",
    "Nachvertonte": "nachvertont",
    "Nachvertonten": "Nachvertonte",
    "Nachvollziehbaren": "Nachvollziehbare",
    "Nachvollziehenden": "Nachvollziehende",
    "Nachvollziehenderen": "Nachvollziehendere",
    "Nachvollziehens": "Nachvollziehen",
    "Nachvollzogenen": "Nachvollzogene",
    "Nachvollzogeneren": "Nachvollzogenere",
    "Nachvollzogensten": "Nachvollzogenste",
    "Nachvollzugs": "Nachvollzug",
    "Nachwachsenden": "Nachwachsende",
    "Nachwachsens": "Nachwachsen",
    "Nachweinenden": "Nachweinende",
    "Nachweinens": "Nachweinen",
    "Nachweisbaren": "Nachweisbare",
    "Nachweise": "nachweisen",
    "Nachweisen": "Nachweis",
    "Nachweisenden": "Nachweisende",
    "Nachweisens": "Nachweisen",
    "Nachweises": "Nachweis",
    "Nachweislichen": "Nachweisliche",
    "Nachwerfenden": "Nachwerfende",
    "Nachwerfens": "Nachwerfen",
    "Nachwiegenden": "Nachwiegende",
    "Nachwiegens": "Nachwiegen",
    "Nachwinkenden": "Nachwinkende",
    "Nachwinkens": "Nachwinken",
    "Nachwirkenden": "Nachwirkende",
    "Nachwirkenderen": "Nachwirkendere",
    "Nachwirkendsten": "Nachwirkendste",
    "Nachwirkens": "Nachwirken",
    "Nachwirkungen": "Nachwirkung",
    "Nachwuchse": "Nachwuchs",
    "Nachwuchses": "Nachwuchs",
    "Nachwüchse": "Nachwuchs",
    "Nachwüchsen": "Nachwuchs",
    "Nachzahlenden": "Nachzahlende",
    "Nachzahlens": "Nachzahlen",
    "Nachzahlungen": "Nachzahlung",
    "Nachzeichnenden": "Nachzeichnende",
    "Nachzeichnens": "Nachzeichnen",
    "Nachziehenden": "Nachziehende",
    "Nachziehens": "Nachziehen",
    "Nachzählende": "nachzählend",
    "Nachzählenden": "Nachzählende",
    "Nachzählens": "Nachzählen",
    "Nachäffenden": "Nachäffende",
    "Nachäffenderen": "Nachäffendere",
    "Nachäffendsten": "Nachäffendste",
    "Nachäffens": "Nachäffen",
    "Nackten": "Nackte",
    "Nackteren": "Nacktere",
    "Nacktesten": "Nackteste",
    "Nadeln": "Nadel",
    "Nadelstiche": "Nadelstich",
    "Nadelstichen": "Nadelstich",
    "Nadelstichs": "Nadelstich",
    "Nadelöhre": "Nadelöhr",
    "Nadelöhren": "Nadelöhr",
    "Nadelöhrs": "Nadelöhr",
    "Nagaikas": "Nagaika",
    "Nagel": "nageln",
    "Nagelnden": "Nagelnde",
    "Nagelneuen": "Nagelneue",
    "Nagelns": "Nageln",
    "Nagels": "Nagel",
    "Nagenden": "Nagende",
    "Nagenderen": "Nagendere",
    "Nagendsten": "Nagendste",
    "Nagens": "Nagen",
    "Nagern": "Nager",
    "Nagers": "Nager",
    "Nahaufnahmen": "Nahaufnahme",
    "Nahe": "nah",
    "Nahebringenden": "Nahebringende",
    "Nahebringenderen": "Nahebringendere",
    "Nahebringendsten": "Nahebringendste",
    "Nahebringens": "Nahebringen",
    "Nahegebrachten": "Nahegebrachte",
    "Nahegebrachteren": "Nahegebrachtere",
    "Nahegebrachtesten": "Nahegebrachteste",
    "Nahegegangenen": "Nahegegangene",
    "Nahegehenden": "Nahegehende",
    "Nahegehens": "Nahegehen",
    "Nahegekommenen": "Nahegekommene",
    "Nahegelegenen": "Nahegelegene",
    "Nahegelegeneren": "Nahegelegenere",
    "Nahegelegensten": "Nahegelegenste",
    "Nahegelegten": "Nahegelegte",
    "Nahegestandenen": "Nahegestandene",
    "Nahegestandeneren": "Nahegestandenere",
    "Nahegestandensten": "Nahegestandenste",
    "Nahegetretenen": "Nahegetretene",
    "Nahekommenden": "Nahekommende",
    "Nahekommens": "Nahekommen",
    "Nahelegenden": "Nahelegende",
    "Nahelegens": "Nahelegen",
    "Naheliegenden": "Naheliegende",
    "Naheliegens": "Naheliegen",
    "Nahen": "Nahe",
    "Naherholungen": "Naherholung",
    "Nahestehenden": "Nahestehende",
    "Nahestehenderen": "Nahestehendere",
    "Nahestehendsten": "Nahestehendste",
    "Nahestehens": "Nahestehen",
    "Nahetretenden": "Nahetretende",
    "Nahetretens": "Nahetreten",
    "Nahkampfe": "Nahkampf",
    "Nahkampfs": "Nahkampf",
    "Nahkämpfe": "Nahkampf",
    "Nahkämpfen": "Nahkampf",
    "Nahrhaften": "Nahrhafte",
    "Nahrhafteren": "Nahrhaftere",
    "Nahrhaftesten": "Nahrhafteste",
    "Nahtlose": "nahtlos",
    "Nahtlosen": "Nahtlose",
    "Nahtloseren": "Nahtlosere",
    "Nahtlosesten": "Nahtloseste",
    "Nahverkehrs": "Nahverkehr",
    "Naive": "naiv",
    "Naiven": "Naive",
    "Naiveren": "Naivere",
    "Naivsten": "Naivste",
    "Namen": "Name",
    "Namenlose": "namenlos",
    "Namenlosen": "Namenlose",
    "Namens": "Name",
    "Namensgebungen": "Namensgebung",
    "Namensänderungen": "Namensänderung",
    "Namentliche": "namentlich",
    "Namentlichen": "Namentliche",
    "Namhaften": "Namhafte",
    "Namibias": "Namibia",
    "Namibische": "namibisch",
    "Namibischen": "Namibische",
    "Nanosekunden": "Nanosekunde",
    "Napalmbomben": "Napalmbombe",
    "Napfe": "Napf",
    "Napfes": "Napf",
    "Napfs": "Napf",
    "Narben": "Narbe",
    "Narbige": "narbig",
    "Narbigen": "Narbige",
    "Narbigeren": "Narbigere",
    "Narbigsten": "Narbigste",
    "Narkosen": "Narkose",
    "Narkotisiere": "narkotisieren",
    "Narkotisierenden": "Narkotisierende",
    "Narkotisierenderen": "Narkotisierendere",
    "Narkotisierens": "Narkotisieren",
    "Narkotisierte": "narkotisiert",
    "Narkotisierten": "Narkotisierte",
    "Narkotisierteren": "Narkotisiertere",
    "Narkotisiertesten": "Narkotisierteste",
    "Narr": "narren",
    "Narrative": "narrativ",
    "Narrativen": "Narrative",
    "Narratore": "Narrator",
    "Narratoren": "Narrator",
    "Narrators": "Narrator",
    "Narren": "Narr",
    "Narrenden": "Narrende",
    "Narrenderen": "Narrendere",
    "Narrendsten": "Narrendste",
    "Narrens": "Narren",
    "Narzissen": "Narzisse",
    "Nasale": "nasal",
    "Nasalen": "Nasale",
    "Nasalierenden": "Nasalierende",
    "Nasalierens": "Nasalieren",
    "Nasalierte": "nasaliert",
    "Nasalierten": "Nasalierte",
    "Nasalierungen": "Nasalierung",
    "Nasallaute": "Nasallaut",
    "Nasallauten": "Nasallaut",
    "Nasallauts": "Nasallaut",
    "Naschenden": "Naschende",
    "Naschenderen": "Naschendere",
    "Naschendsten": "Naschendste",
    "Naschens": "Naschen",
    "Naschereien": "Nascherei",
    "Nascherinnen": "Nascherin",
    "Naschern": "Nascher",
    "Naschers": "Nascher",
    "Naschhaften": "Naschhafte",
    "Naschhafteren": "Naschhaftere",
    "Naschhaftesten": "Naschhafteste",
    "Naschkatzen": "Naschkatze",
    "Naschsüchtigen": "Naschsüchtige",
    "Naschsüchtigeren": "Naschsüchtigere",
    "Naschsüchtigsten": "Naschsüchtigste",
    "Nasen": "Nase",
    "Nasenlängen": "Nasenlänge",
    "Nasenschleimhäute": "Nasenschleimhaut",
    "Nasenschleimhäuten": "Nasenschleimhaut",
    "Nashorne": "Nashorn",
    "Nashornes": "Nashorn",
    "Nashorns": "Nashorn",
    "Nashörner": "Nashorn",
    "Nashörnern": "Nashorn",
    "Nassauischen": "Nassauische",
    "Nassaus": "Nassau",
    "Nasse": "Naß",
    "Nassen": "Nasse",
    "Nasseren": "Nassere",
    "Nassesten": "Nasseste",
    "Nationalbewußte": "nationalbewußt",
    "Nationalbewußten": "Nationalbewußte",
    "Nationalbewußteren": "Nationalbewußtere",
    "Nationalen": "Nationale",
    "Nationaleren": "Nationalere",
    "Nationalgefühle": "Nationalgefühl",
    "Nationalgefühlen": "Nationalgefühl",
    "Nationalgefühls": "Nationalgefühl",
    "Nationalgerichte": "Nationalgericht",
    "Nationalgerichten": "Nationalgericht",
    "Nationalgerichts": "Nationalgericht",
    "Nationalisierenden": "Nationalisierende",
    "Nationalisierenderen": "Nationalisierendere",
    "Nationalisierens": "Nationalisieren",
    "Nationalisierte": "nationalisiert",
    "Nationalisierten": "Nationalisierte",
    "Nationalisierteren": "Nationalisiertere",
    "Nationalisierungen": "Nationalisierung",
    "Nationalistische": "nationalistisch",
    "Nationalistischen": "Nationalistische",
    "Nationalistischeren": "Nationalistischere",
    "Nationalitäten": "Nationalität",
    "Nationalliberale": "nationalliberal",
    "Nationalliberalen": "Nationalliberale",
    "Nationalmannschaften": "Nationalmannschaft",
    "Nationalparks": "Nationalpark",
    "Nationalrate": "Nationalrat",
    "Nationalrats": "Nationalrat",
    "Nationalräte": "Nationalrat",
    "Nationalräten": "Nationalrat",
    "Nationalsozialisten": "Nationalsozialist",
    "Nationalspielern": "Nationalspieler",
    "Nationalspielers": "Nationalspieler",
    "Nationalstaate": "Nationalstaat",
    "Nationalstaaten": "Nationalstaat",
    "Nationalstaates": "Nationalstaat",
    "Nationalstaats": "Nationalstaat",
    "Nationalste": "national",
    "Nationalsten": "Nationalste",
    "Nationaltheatern": "Nationaltheater",
    "Nationaltheaters": "Nationaltheater",
    "Nationalversammlungen": "Nationalversammlung",
    "Nationalökonomen": "Nationalökonom",
    "Nationen": "Nation",
    "Native": "nativ",
    "Nativen": "Native",
    "Nattern": "Natter",
    "Naturalisationen": "Naturalisation",
    "Naturalisierenden": "Naturalisierende",
    "Naturalisierens": "Naturalisieren",
    "Naturalisierte": "naturalisiert",
    "Naturalisierten": "Naturalisierte",
    "Naturalisierungen": "Naturalisierung",
    "Naturalistische": "naturalistisch",
    "Naturalistischen": "Naturalistische",
    "Naturellen": "Naturelle",
    "Naturells": "Naturell",
    "Naturgefühle": "Naturgefühl",
    "Naturgefühlen": "Naturgefühl",
    "Naturgefühls": "Naturgefühl",
    "Naturgegebene": "naturgegeben",
    "Naturgegebenen": "Naturgegebene",
    "Naturgemäßen": "Naturgemäße",
    "Naturgetreuen": "Naturgetreue",
    "Naturgetreueren": "Naturgetreuere",
    "Naturgetreusten": "Naturgetreuste",
    "Naturinteressierten": "Naturinteressierte",
    "Naturinteressierteren": "Naturinteressiertere",
    "Naturisten": "Naturist",
    "Naturkundliche": "naturkundlich",
    "Naturkundlichen": "Naturkundliche",
    "Naturreinen": "Naturreine",
    "Naturreineren": "Naturreinere",
    "Naturreinsten": "Naturreinste",
    "Naturtrüben": "Naturtrübe",
    "Naturtrüberen": "Naturtrübere",
    "Naturtrübsten": "Naturtrübste",
    "Natürlichen": "Natürliche",
    "Natürlicheren": "Natürlichere",
    "Natürlichsten": "Natürlichste",
    "Nauheimern": "Nauheimer",
    "Nauheimers": "Nauheimer",
    "Nauheims": "Nauheim",
    "Naumanns": "Naumann",
    "Nazis": "Nazi",
    "Naßkalten": "Naßkalte",
    "Naßwäschen": "Naßwäsche",
    "Neapels": "Neapel",
    "Nebel": "nebeln",
    "Nebeligen": "Nebelige",
    "Nebeligeren": "Nebeligere",
    "Nebeligsten": "Nebeligste",
    "Nebeln": "Nebel",
    "Nebelnden": "Nebelnde",
    "Nebelns": "Nebeln",
    "Nebels": "Nebel",
    "Nebenabsichten": "Nebenabsicht",
    "Nebenamte": "Nebenamt",
    "Nebenamtes": "Nebenamt",
    "Nebenamtliche": "nebenamtlich",
    "Nebenamtlichen": "Nebenamtliche",
    "Nebenamts": "Nebenamt",
    "Nebenbahnen": "Nebenbahn",
    "Nebenberufliche": "nebenberuflich",
    "Nebenberuflichen": "Nebenberufliche",
    "Nebeneffekte": "Nebeneffekt",
    "Nebeneffekten": "Nebeneffekt",
    "Nebeneffektes": "Nebeneffekt",
    "Nebeneffekts": "Nebeneffekt",
    "Nebeneinanders": "Nebeneinander",
    "Nebeneingange": "Nebeneingang",
    "Nebeneingangs": "Nebeneingang",
    "Nebeneingänge": "Nebeneingang",
    "Nebeneingängen": "Nebeneingang",
    "Nebenfache": "Nebenfach",
    "Nebenfaches": "Nebenfach",
    "Nebenfachs": "Nebenfach",
    "Nebenfrauen": "Nebenfrau",
    "Nebenfächer": "Nebenfach",
    "Nebenfächern": "Nebenfach",
    "Nebengebäuden": "Nebengebäude",
    "Nebengebäudes": "Nebengebäude",
    "Nebengedanken": "Nebengedanke",
    "Nebengeordneten": "Nebengeordnete",
    "Nebengeräusche": "Nebengeräusch",
    "Nebengeräuschen": "Nebengeräusch",
    "Nebengeräuschs": "Nebengeräusch",
    "Nebengeschäfte": "Nebengeschäft",
    "Nebengeschäften": "Nebengeschäft",
    "Nebengeschäfts": "Nebengeschäft",
    "Nebengewinne": "Nebengewinn",
    "Nebengewinnen": "Nebengewinn",
    "Nebengewinns": "Nebengewinn",
    "Nebenhandlungen": "Nebenhandlung",
    "Nebenhöhlen": "Nebenhöhle",
    "Nebenklagen": "Nebenklage",
    "Nebenklägern": "Nebenkläger",
    "Nebenklägers": "Nebenkläger",
    "Nebenkratern": "Nebenkrater",
    "Nebenkraters": "Nebenkrater",
    "Nebenordnenden": "Nebenordnende",
    "Nebenordnens": "Nebenordnen",
    "Nebenpersonen": "Nebenperson",
    "Nebenprodukte": "Nebenprodukt",
    "Nebenprodukten": "Nebenprodukt",
    "Nebenprodukts": "Nebenprodukt",
    "Nebenpunkte": "Nebenpunkt",
    "Nebenpunkten": "Nebenpunkt",
    "Nebenpunkts": "Nebenpunkt",
    "Nebenraume": "Nebenraum",
    "Nebenraums": "Nebenraum",
    "Nebenrollen": "Nebenrolle",
    "Nebenräume": "Nebenraum",
    "Nebenräumen": "Nebenraum",
    "Nebensachen": "Nebensache",
    "Nebenschaltungen": "Nebenschaltung",
    "Nebenstehende": "nebenstehend",
    "Nebenstehenden": "Nebenstehende",
    "Nebenstellen": "Nebenstelle",
    "Nebenstraßen": "Nebenstraße",
    "Nebensächliche": "nebensächlich",
    "Nebensächlichen": "Nebensächliche",
    "Nebensächlichkeiten": "Nebensächlichkeit",
    "Nebentale": "Nebental",
    "Nebentales": "Nebental",
    "Nebentals": "Nebental",
    "Nebentische": "Nebentisch",
    "Nebentischen": "Nebentisch",
    "Nebentischs": "Nebentisch",
    "Nebentone": "Nebenton",
    "Nebentons": "Nebenton",
    "Nebentäler": "Nebental",
    "Nebentälern": "Nebental",
    "Nebentöne": "Nebenton",
    "Nebentönen": "Nebenton",
    "Nebentüren": "Nebentür",
    "Nebenumstande": "Nebenumstand",
    "Nebenumstands": "Nebenumstand",
    "Nebenumstände": "Nebenumstand",
    "Nebenumständen": "Nebenumstand",
    "Nebenverdienste": "Nebenverdienst",
    "Nebenverdiensten": "Nebenverdienst",
    "Nebenverdiensts": "Nebenverdienst",
    "Nebenwege": "Nebenweg",
    "Nebenwegen": "Nebenweg",
    "Nebenwegs": "Nebenweg",
    "Nebenwinkeln": "Nebenwinkel",
    "Nebenwinkels": "Nebenwinkel",
    "Nebenwirkungen": "Nebenwirkung",
    "Nebenwohnungen": "Nebenwohnung",
    "Nebenzimmern": "Nebenzimmer",
    "Nebenzimmers": "Nebenzimmer",
    "Nebenzweige": "Nebenzweig",
    "Nebenzweigen": "Nebenzweig",
    "Nebenzweigs": "Nebenzweig",
    "Nebenämter": "Nebenamt",
    "Nebenämtern": "Nebenamt",
    "Nebligen": "Neblige",
    "Nebligeren": "Nebligere",
    "Nebligsten": "Nebligste",
    "Neckars": "Neckar",
    "Neffen": "Neffe",
    "Negationen": "Negation",
    "Negative": "Negativ",
    "Negativen": "Negative",
    "Negativeren": "Negativere",
    "Negativs": "Negativ",
    "Negativste": "negativ",
    "Negativsten": "Negativste",
    "Negativtrends": "Negativtrend",
    "Negerinnen": "Negerin",
    "Negern": "Neger",
    "Negers": "Neger",
    "Negierenden": "Negierende",
    "Negierens": "Negieren",
    "Negierte": "negiert",
    "Negierten": "Negierte",
    "Negierungen": "Negierung",
    "Nehls": "Nehl",
    "Nehmenden": "Nehmende",
    "Nehmens": "Nehmen",
    "Neidenden": "Neidende",
    "Neidenderen": "Neidendere",
    "Neidendsten": "Neidendste",
    "Neidens": "Neiden",
    "Neidern": "Neider",
    "Neiders": "Neider",
    "Neidhammeln": "Neidhammel",
    "Neidhammels": "Neidhammel",
    "Neidhards": "Neidhard",
    "Neidische": "neidisch",
    "Neidischen": "Neidische",
    "Neidischeren": "Neidischere",
    "Neidischsten": "Neidischste",
    "Neids": "Neid",
    "Neige": "neigen",
    "Neigen": "Neige",
    "Neigenden": "Neigende",
    "Neigens": "Neigen",
    "Neigungen": "Neigung",
    "Neinsagern": "Neinsager",
    "Neinsagers": "Neinsager",
    "Nektarinen": "Nektarine",
    "Nektars": "Nektar",
    "Nelken": "Nelke",
    "Nelsons": "Nelson",
    "Nennbetrage": "Nennbetrag",
    "Nennbetrags": "Nennbetrag",
    "Nennbeträge": "Nennbetrag",
    "Nennbeträgen": "Nennbetrag",
    "Nennenden": "Nennende",
    "Nennens": "Nennen",
    "Nennenswerte": "nennenswert",
    "Nennenswerten": "Nennenswerte",
    "Nennern": "Nenner",
    "Nenners": "Nenner",
    "Nennformen": "Nennform",
    "Nennleistungen": "Nennleistung",
    "Nennonkeln": "Nennonkel",
    "Nennonkels": "Nennonkel",
    "Nenntanten": "Nenntante",
    "Nennungen": "Nennung",
    "Nennwerte": "Nennwert",
    "Nennwerten": "Nennwert",
    "Nennwerts": "Nennwert",
    "Neonazis": "Neonazi",
    "Neonlichte": "Neonlicht",
    "Neonlichter": "Neonlicht",
    "Neonlichtern": "Neonlicht",
    "Neonlichtes": "Neonlicht",
    "Neonlichts": "Neonlicht",
    "Neonröhren": "Neonröhre",
    "Neons": "Neon",
    "Neoplasmas": "Neoplasma",
    "Nephrolithen": "Nephrolith",
    "Nepp": "neppen",
    "Neppenden": "Neppende",
    "Neppens": "Neppen",
    "Nepps": "Nepp",
    "Nerv": "nerven",
    "Nerve": "nerven",
    "Nerven": "Nerv",
    "Nervenden": "Nervende",
    "Nervenderen": "Nervendere",
    "Nervendsten": "Nervendste",
    "Nervenkranken": "Nervenkranke",
    "Nervens": "Nerven",
    "Nervensägen": "Nervensäge",
    "Nerves": "Nerv",
    "Nervigen": "Nervige",
    "Nervigeren": "Nervigere",
    "Nervigsten": "Nervigste",
    "Nervs": "Nerv",
    "Nervösen": "Nervöse",
    "Nervöseren": "Nervösere",
    "Nervösesten": "Nervöseste",
    "Nesseln": "Nessel",
    "Nessels": "Nessel",
    "Neste": "Nest",
    "Nestelnden": "Nestelnde",
    "Nestelnderen": "Nestelndere",
    "Nestelndsten": "Nestelndste",
    "Nestelns": "Nesteln",
    "Nester": "Nest",
    "Nestern": "Nest",
    "Nests": "Nest",
    "Nette": "nett",
    "Netten": "Nette",
    "Netteren": "Nettere",
    "Nettesten": "Netteste",
    "Nettigkeiten": "Nettigkeit",
    "Nettoeinkommens": "Nettoeinkommen",
    "Nettoeinnahmen": "Nettoeinnahme",
    "Nettoertrage": "Nettoertrag",
    "Nettoertrags": "Nettoertrag",
    "Nettoerträge": "Nettoertrag",
    "Nettoerträgen": "Nettoertrag",
    "Nettogewichte": "Nettogewicht",
    "Nettogewichten": "Nettogewicht",
    "Nettogewichts": "Nettogewicht",
    "Nettogewinne": "Nettogewinn",
    "Nettogewinnen": "Nettogewinn",
    "Nettogewinns": "Nettogewinn",
    "Nettoregistertonnen": "Nettoregistertonne",
    "Nettoverdienste": "Nettoverdienst",
    "Nettoverdiensten": "Nettoverdienst",
    "Nettoverdiensts": "Nettoverdienst",
    "Netze": "Netz",
    "Netzen": "Netz",
    "Netzes": "Netz",
    "Neuanfange": "Neuanfang",
    "Neuanfangs": "Neuanfang",
    "Neuanfänge": "Neuanfang",
    "Neuanfängen": "Neuanfang",
    "Neuankömmlinge": "Neuankömmling",
    "Neuankömmlingen": "Neuankömmling",
    "Neuankömmlings": "Neuankömmling",
    "Neuanschaffungen": "Neuanschaffung",
    "Neuartige": "neuartig",
    "Neuartigen": "Neuartige",
    "Neuauflagen": "Neuauflage",
    "Neubaus": "Neubau",
    "Neubauten": "Neubau",
    "Neue": "neu",
    "Neuen": "Neue",
    "Neuentwicklungen": "Neuentwicklung",
    "Neueren": "Neuere",
    "Neuerlichen": "Neuerliche",
    "Neuerungen": "Neuerung",
    "Neufundlands": "Neufundland",
    "Neugeborene": "neugeboren",
    "Neugeborenen": "Neugeborene",
    "Neugeschaffenen": "Neugeschaffene",
    "Neugestaltungen": "Neugestaltung",
    "Neugierige": "neugierig",
    "Neugierigen": "Neugierige",
    "Neugierigeren": "Neugierigere",
    "Neugierigsten": "Neugierigste",
    "Neuheidentums": "Neuheidentum",
    "Neuheiten": "Neuheit",
    "Neuhochdeutsche": "neuhochdeutsch",
    "Neuhochdeutschen": "Neuhochdeutsche",
    "Neuigkeiten": "Neuigkeit",
    "Neuintonationen": "Neuintonation",
    "Neuköllns": "Neukölln",
    "Neulands": "Neuland",
    "Neulehrern": "Neulehrer",
    "Neulehrers": "Neulehrer",
    "Neulinge": "Neuling",
    "Neulingen": "Neuling",
    "Neulings": "Neuling",
    "Neumachens": "Neumachen",
    "Neumanns": "Neumann",
    "Neunen": "Neun",
    "Neuners": "Neuner",
    "Neunkirchens": "Neunkirchen",
    "Neunteln": "Neuntel",
    "Neuntels": "Neuntel",
    "Neuordnungen": "Neuordnung",
    "Neuorientierungen": "Neuorientierung",
    "Neuregelungen": "Neuregelung",
    "Neureiche": "neureich",
    "Neureichen": "Neureiche",
    "Neurologen": "Neurologe",
    "Neurologische": "neurologisch",
    "Neurologischen": "Neurologische",
    "Neuronalen": "Neuronale",
    "Neurosen": "Neurose",
    "Neurotikern": "Neurotiker",
    "Neurotikers": "Neurotiker",
    "Neurotische": "neurotisch",
    "Neurotischen": "Neurotische",
    "Neurotischeren": "Neurotischere",
    "Neurotischsten": "Neurotischste",
    "Neurotisierenden": "Neurotisierende",
    "Neurotisierenderen": "Neurotisierendere",
    "Neurotisierens": "Neurotisieren",
    "Neurotisierte": "neurotisiert",
    "Neurotisierten": "Neurotisierte",
    "Neurotisierteren": "Neurotisiertere",
    "Neurotisiertesten": "Neurotisierteste",
    "Neurotomien": "Neurotomie",
    "Neurotransmittern": "Neurotransmitter",
    "Neurotransmitters": "Neurotransmitter",
    "Neururern": "Neururer",
    "Neururers": "Neururer",
    "Neuschnees": "Neuschnee",
    "Neuseelands": "Neuseeland",
    "Neusprachlern": "Neusprachler",
    "Neusprachlers": "Neusprachler",
    "Neuste": "neu",
    "Neusten": "Neuste",
    "Neustädte": "Neustadt",
    "Neustädten": "Neustadt",
    "Neutestamentlern": "Neutestamentler",
    "Neutestamentlers": "Neutestamentler",
    "Neutestamentliche": "neutestamentlich",
    "Neutestamentlichen": "Neutestamentliche",
    "Neutralen": "Neutrale",
    "Neutraleren": "Neutralere",
    "Neutralisationen": "Neutralisation",
    "Neutralisierenden": "Neutralisierende",
    "Neutralisierens": "Neutralisieren",
    "Neutralisierte": "neutralisiert",
    "Neutralisierten": "Neutralisierte",
    "Neutralitäten": "Neutralität",
    "Neutralste": "neutral",
    "Neutralsten": "Neutralste",
    "Neutronenquellen": "Neutronenquelle",
    "Neutronenwaffen": "Neutronenwaffe",
    "Neuvermählte": "neuvermählt",
    "Neuvermählten": "Neuvermählte",
    "Neuwahlen": "Neuwahl",
    "Neuworte": "Neuwort",
    "Neuworts": "Neuwort",
    "Neuwörter": "Neuwort",
    "Neuwörtern": "Neuwort",
    "Neuzeitliche": "neuzeitlich",
    "Neuzeitlichen": "Neuzeitliche",
    "Neuzugange": "Neuzugang",
    "Neuzugangs": "Neuzugang",
    "Neuzugänge": "Neuzugang",
    "Neuzugängen": "Neuzugang",
    "Neuzüchtungen": "Neuzüchtung",
    "Newtonmetern": "Newtonmeter",
    "Newtonmeters": "Newtonmeter",
    "Nibelungen": "Nibelung",
    "Nicaraguas": "Nicaragua",
    "Nichtachtungen": "Nichtachtung",
    "Nichtangriffspakte": "Nichtangriffspakt",
    "Nichtangriffspakten": "Nichtangriffspakt",
    "Nichtangriffspakts": "Nichtangriffspakt",
    "Nichtariern": "Nichtarier",
    "Nichtariers": "Nichtarier",
    "Nichtautomatische": "nichtautomatisch",
    "Nichtautomatischen": "Nichtautomatische",
    "Nichtdeutschen": "Nichtdeutsche",
    "Nichten": "Nichte",
    "Nichterscheinens": "Nichterscheinen",
    "Nichtgefallens": "Nichtgefallen",
    "Nichtige": "nichtig",
    "Nichtigen": "Nichtige",
    "Nichtigkeiten": "Nichtigkeit",
    "Nichtkatholiken": "Nichtkatholik",
    "Nichtmitgliede": "Nichtmitglied",
    "Nichtmitglieder": "Nichtmitglied",
    "Nichtmitgliedern": "Nichtmitglied",
    "Nichtmitgliedes": "Nichtmitglied",
    "Nichtmitglieds": "Nichtmitglied",
    "Nichtrauchern": "Nichtraucher",
    "Nichtrauchers": "Nichtraucher",
    "Nichtrevanchistische": "nichtrevanchistisch",
    "Nichtrevanchistischen": "Nichtrevanchistische",
    "Nichtschwimmern": "Nichtschwimmer",
    "Nichtschwimmers": "Nichtschwimmer",
    "Nichtseßhaften": "Nichtseßhafte",
    "Nichtskönnern": "Nichtskönner",
    "Nichtskönners": "Nichtskönner",
    "Nichtsnutzige": "nichtsnutzig",
    "Nichtsnutzigen": "Nichtsnutzige",
    "Nichtsnutzigeren": "Nichtsnutzigere",
    "Nichtsnutzigsten": "Nichtsnutzigste",
    "Nichtssagenden": "Nichtssagende",
    "Nichtstuns": "Nichtstun",
    "Nichtwissens": "Nichtwissen",
    "Nichtöffentliche": "nichtöffentlich",
    "Nichtöffentlichen": "Nichtöffentliche",
    "Nichtübereinstimmungen": "Nichtübereinstimmung",
    "Nickenden": "Nickende",
    "Nickens": "Nicken",
    "Nickis": "Nicki",
    "Nicoles": "Nicole",
    "Nidderauern": "Nidderauer",
    "Nidderauers": "Nidderauer",
    "Nidderaus": "Nidderau",
    "Niederbeugenden": "Niederbeugende",
    "Niederbeugens": "Niederbeugen",
    "Niederbiegenden": "Niederbiegende",
    "Niederbiegens": "Niederbiegen",
    "Niederblasenden": "Niederblasende",
    "Niederblasens": "Niederblasen",
    "Niederbrechenden": "Niederbrechende",
    "Niederbrechens": "Niederbrechen",
    "Niederbrennenden": "Niederbrennende",
    "Niederbrennens": "Niederbrennen",
    "Niederbringenden": "Niederbringende",
    "Niederbringens": "Niederbringen",
    "Niederbügelnden": "Niederbügelnde",
    "Niederbügelns": "Niederbügeln",
    "Niederdorfeldens": "Niederdorfelden",
    "Niedere": "nieder",
    "Niederen": "Niedere",
    "Niedereren": "Niederere",
    "Niederfallenden": "Niederfallende",
    "Niederfallens": "Niederfallen",
    "Niederfrequenzen": "Niederfrequenz",
    "Niedergange": "Niedergang",
    "Niedergangs": "Niedergang",
    "Niedergebeugten": "Niedergebeugte",
    "Niedergeblasenen": "Niedergeblasene",
    "Niedergebogenen": "Niedergebogene",
    "Niedergebrachten": "Niedergebrachte",
    "Niedergebrannten": "Niedergebrannte",
    "Niedergebrochenen": "Niedergebrochene",
    "Niedergebügelten": "Niedergebügelte",
    "Niedergefallenen": "Niedergefallene",
    "Niedergeglittenen": "Niedergeglittene",
    "Niedergehaltenen": "Niedergehaltene",
    "Niedergehalteneren": "Niedergehaltenere",
    "Niedergehauenen": "Niedergehauene",
    "Niedergeholten": "Niedergeholte",
    "Niedergeknieten": "Niedergekniete",
    "Niedergeknüppelten": "Niedergeknüppelte",
    "Niedergekämpften": "Niedergekämpfte",
    "Niedergekämpfteren": "Niedergekämpftere",
    "Niedergelassenen": "Niedergelassene",
    "Niedergelegten": "Niedergelegte",
    "Niedergemachten": "Niedergemachte",
    "Niedergemetzelten": "Niedergemetzelte",
    "Niedergemähten": "Niedergemähte",
    "Niedergemähteren": "Niedergemähtere",
    "Niedergemähtesten": "Niedergemähteste",
    "Niedergeprasselten": "Niedergeprasselte",
    "Niedergeprasselteren": "Niedergeprasseltere",
    "Niedergerissenen": "Niedergerissene",
    "Niedergerungenen": "Niedergerungene",
    "Niedergerungeneren": "Niedergerungenere",
    "Niedergesausten": "Niedergesauste",
    "Niedergeschlagenen": "Niedergeschlagene",
    "Niedergeschlageneren": "Niedergeschlagenere",
    "Niedergeschmetterten": "Niedergeschmetterte",
    "Niedergeschmetterteren": "Niedergeschmettertere",
    "Niedergeschossenen": "Niedergeschossene",
    "Niedergeschriebenen": "Niedergeschriebene",
    "Niedergeschrienen": "Niedergeschriene",
    "Niedergeschrieneren": "Niedergeschrienere",
    "Niedergesetzten": "Niedergesetzte",
    "Niedergestampften": "Niedergestampfte",
    "Niedergestiegenen": "Niedergestiegene",
    "Niedergestiegeneren": "Niedergestiegenere",
    "Niedergestochenen": "Niedergestochene",
    "Niedergestoßenen": "Niedergestoßene",
    "Niedergestreckten": "Niedergestreckte",
    "Niedergesunkenen": "Niedergesunkene",
    "Niedergetrampelten": "Niedergetrampelte",
    "Niedergetrampelteren": "Niedergetrampeltere",
    "Niedergetretenen": "Niedergetretene",
    "Niedergetreteneren": "Niedergetretenere",
    "Niedergeworfenen": "Niedergeworfene",
    "Niedergezwungenen": "Niedergezwungene",
    "Niedergleitenden": "Niedergleitende",
    "Niedergleitens": "Niedergleiten",
    "Niedergänge": "Niedergang",
    "Niedergängen": "Niedergang",
    "Niederhaltenden": "Niederhaltende",
    "Niederhaltenderen": "Niederhaltendere",
    "Niederhaltendsten": "Niederhaltendste",
    "Niederhaltens": "Niederhalten",
    "Niederhauenden": "Niederhauende",
    "Niederhauens": "Niederhauen",
    "Niederholenden": "Niederholende",
    "Niederholens": "Niederholen",
    "Niederhöchstadts": "Niederhöchstadt",
    "Niederknienden": "Niederkniende",
    "Niederkniens": "Niederknien",
    "Niederknüppelnden": "Niederknüppelnde",
    "Niederknüppelns": "Niederknüppeln",
    "Niederkämpfenden": "Niederkämpfende",
    "Niederkämpfenderen": "Niederkämpfendere",
    "Niederkämpfens": "Niederkämpfen",
    "Niederkünfte": "Niederkunft",
    "Niederkünften": "Niederkunft",
    "Niederlagen": "Niederlage",
    "Niederlanden": "Niederlande",
    "Niederlandes": "Niederlande",
    "Niederlassenden": "Niederlassende",
    "Niederlassens": "Niederlassen",
    "Niederlassungen": "Niederlassung",
    "Niederlegenden": "Niederlegende",
    "Niederlegens": "Niederlegen",
    "Niederlegungen": "Niederlegung",
    "Niederländern": "Niederländer",
    "Niederländers": "Niederländer",
    "Niederländische": "niederländisch",
    "Niederländischen": "Niederländische",
    "Niederländischeren": "Niederländischere",
    "Niedermachenden": "Niedermachende",
    "Niedermachens": "Niedermachen",
    "Niedermetzelnden": "Niedermetzelnde",
    "Niedermetzelns": "Niedermetzeln",
    "Niedermittlaus": "Niedermittlau",
    "Niedermähenden": "Niedermähende",
    "Niedermähenderen": "Niedermähendere",
    "Niedermähendsten": "Niedermähendste",
    "Niedermähens": "Niedermähen",
    "Niederprasselnden": "Niederprasselnde",
    "Niederprasselnderen": "Niederprasselndere",
    "Niederprasselns": "Niederprasseln",
    "Niederrads": "Niederrad",
    "Niederreißenden": "Niederreißende",
    "Niederreißens": "Niederreißen",
    "Niederringenden": "Niederringende",
    "Niederringenderen": "Niederringendere",
    "Niederringendsten": "Niederringendste",
    "Niederringens": "Niederringen",
    "Niederrodenbachs": "Niederrodenbach",
    "Niedersachsens": "Niedersachsen",
    "Niedersausenden": "Niedersausende",
    "Niedersausens": "Niedersausen",
    "Niederschießenden": "Niederschießende",
    "Niederschießens": "Niederschießen",
    "Niederschlage": "niederschlagen",
    "Niederschlagenden": "Niederschlagende",
    "Niederschlagenderen": "Niederschlagendere",
    "Niederschlagens": "Niederschlagen",
    "Niederschlags": "Niederschlag",
    "Niederschlagungen": "Niederschlagung",
    "Niederschläge": "Niederschlag",
    "Niederschlägen": "Niederschlag",
    "Niederschmetternden": "Niederschmetternde",
    "Niederschmetternderen": "Niederschmetterndere",
    "Niederschmetterns": "Niederschmettern",
    "Niederschreibenden": "Niederschreibende",
    "Niederschreibens": "Niederschreiben",
    "Niederschreienden": "Niederschreiende",
    "Niederschreienderen": "Niederschreiendere",
    "Niederschreiens": "Niederschreien",
    "Niederschriften": "Niederschrift",
    "Niedersetzenden": "Niedersetzende",
    "Niedersetzens": "Niedersetzen",
    "Niedersinkenden": "Niedersinkende",
    "Niedersinkens": "Niedersinken",
    "Niederspannungen": "Niederspannung",
    "Niederstampfenden": "Niederstampfende",
    "Niederstampfens": "Niederstampfen",
    "Niederstechenden": "Niederstechende",
    "Niederstechens": "Niederstechen",
    "Niedersteigenden": "Niedersteigende",
    "Niedersteigenderen": "Niedersteigendere",
    "Niedersteigens": "Niedersteigen",
    "Niedersten": "Niederste",
    "Niederstoßenden": "Niederstoßende",
    "Niederstoßens": "Niederstoßen",
    "Niederstreckenden": "Niederstreckende",
    "Niederstreckens": "Niederstrecken",
    "Niedersächsische": "niedersächsisch",
    "Niedersächsischen": "Niedersächsische",
    "Niedertrampelnden": "Niedertrampelnde",
    "Niedertrampelnderen": "Niedertrampelndere",
    "Niedertrampelns": "Niedertrampeln",
    "Niedertretenden": "Niedertretende",
    "Niedertretenderen": "Niedertretendere",
    "Niedertretendsten": "Niedertretendste",
    "Niedertretens": "Niedertreten",
    "Niederträchtigen": "Niederträchtige",
    "Niederträchtigeren": "Niederträchtigere",
    "Niederträchtigkeiten": "Niederträchtigkeit",
    "Niederträchtigste": "niederträchtig",
    "Niederungen": "Niederung",
    "Niederurselern": "Niederurseler",
    "Niederurselers": "Niederurseler",
    "Niederursels": "Niederursel",
    "Niederwerfenden": "Niederwerfende",
    "Niederwerfens": "Niederwerfen",
    "Niederwilde": "Niederwild",
    "Niederwildes": "Niederwild",
    "Niederwilds": "Niederwild",
    "Niederzwingenden": "Niederzwingende",
    "Niederzwingens": "Niederzwingen",
    "Niedlichen": "Niedliche",
    "Niedlicheren": "Niedlichere",
    "Niedlichsten": "Niedlichste",
    "Niednagels": "Niednagel",
    "Niednägel": "Niednagel",
    "Niednägeln": "Niednagel",
    "Niedrige": "niedrig",
    "Niedrigen": "Niedrige",
    "Niedrigeren": "Niedrigere",
    "Niedrigsten": "Niedrigste",
    "Niedrigwassers": "Niedrigwasser",
    "Niemandslands": "Niemandsland",
    "Nieren": "Niere",
    "Nieselnden": "Nieselnde",
    "Nieselnderen": "Nieselndere",
    "Nieselndsten": "Nieselndste",
    "Nieselns": "Nieseln",
    "Nieselprieme": "Nieselpriem",
    "Nieselpriemen": "Nieselpriem",
    "Nieselpriems": "Nieselpriem",
    "Niesenden": "Niesende",
    "Niesenderen": "Niesendere",
    "Niesendsten": "Niesendste",
    "Niesens": "Niesen",
    "Nieten": "Niete",
    "Nietenden": "Nietende",
    "Nietens": "Nieten",
    "Nietnagels": "Nietnagel",
    "Nietnägel": "Nietnagel",
    "Nietnägeln": "Nietnagel",
    "Nießnutzern": "Nießnutzer",
    "Nießnutzers": "Nießnutzer",
    "Nigerias": "Nigeria",
    "Nihilisten": "Nihilist",
    "Nihilistische": "nihilistisch",
    "Nihilistischen": "Nihilistische",
    "Niklashausens": "Niklashausen",
    "Nikolause": "Nikolaus",
    "Nikolauses": "Nikolaus",
    "Nikoläuse": "Nikolaus",
    "Nikoläusen": "Nikolaus",
    "Nikotinarme": "nikotinarm",
    "Nikotinarmen": "Nikotinarme",
    "Nikotinärmeren": "Nikotinärmere",
    "Nilpferde": "Nilpferd",
    "Nilpferden": "Nilpferd",
    "Nilpferds": "Nilpferd",
    "Nimmersatten": "Nimmersatte",
    "Nimmersatts": "Nimmersatt",
    "Nippeln": "Nippel",
    "Nippels": "Nippel",
    "Nippenden": "Nippende",
    "Nippens": "Nippen",
    "Nirgendlande": "Nirgendland",
    "Nirgendlandes": "Nirgendland",
    "Nirgendlands": "Nirgendland",
    "Nischen": "Nische",
    "Nissen": "Nisse",
    "Nistenden": "Nistende",
    "Nistens": "Nisten",
    "Nistkastens": "Nistkasten",
    "Nistkästen": "Nistkasten",
    "Nitrogens": "Nitrogen",
    "Nitroglycerine": "Nitroglycerin",
    "Nitroglycerinen": "Nitroglycerin",
    "Nitroglycerins": "Nitroglycerin",
    "Nitrophosphate": "Nitrophosphat",
    "Nitrophosphaten": "Nitrophosphat",
    "Nitrophosphats": "Nitrophosphat",
    "Niveaus": "Niveau",
    "Nivelliergeräte": "Nivelliergerät",
    "Nivelliergeräten": "Nivelliergerät",
    "Nivelliergeräts": "Nivelliergerät",
    "Nixen": "Nixe",
    "Nizzas": "Nizza",
    "Nobelpreisträgern": "Nobelpreisträger",
    "Nobelpreisträgers": "Nobelpreisträger",
    "Nobelste": "nobel",
    "Nobelsten": "Nobelste",
    "Noblen": "Noble",
    "Nobleren": "Noblere",
    "Nochmaligen": "Nochmalige",
    "Nockenwellen": "Nockenwelle",
    "Nomaden": "Nomade",
    "Nomadische": "nomadisch",
    "Nomadischen": "Nomadische",
    "Nomadisierenden": "Nomadisierende",
    "Nomadisierens": "Nomadisieren",
    "Nomadisierte": "nomadisiert",
    "Nomadisierten": "Nomadisierte",
    "Nomenklaturen": "Nomenklatur",
    "Nominalbetrage": "Nominalbetrag",
    "Nominalbetrags": "Nominalbetrag",
    "Nominalbeträge": "Nominalbetrag",
    "Nominalbeträgen": "Nominalbetrag",
    "Nominaldefinitionen": "Nominaldefinition",
    "Nominale": "nominal",
    "Nominaleinkommens": "Nominaleinkommen",
    "Nominalen": "Nominale",
    "Nominalisierenden": "Nominalisierende",
    "Nominalisierens": "Nominalisieren",
    "Nominalisierte": "nominalisiert",
    "Nominalisierten": "Nominalisierte",
    "Nominalphrasen": "Nominalphrase",
    "Nominalwerte": "Nominalwert",
    "Nominalwerten": "Nominalwert",
    "Nominalwerts": "Nominalwert",
    "Nominationen": "Nomination",
    "Nominative": "Nominativ",
    "Nominativen": "Nominativ",
    "Nominativs": "Nominativ",
    "Nominelle": "nominell",
    "Nominellen": "Nominelle",
    "Nominierenden": "Nominierende",
    "Nominierens": "Nominieren",
    "Nominierte": "nominiert",
    "Nominierten": "Nominierte",
    "Nominierungen": "Nominierung",
    "Nonen": "None",
    "Nonkonformisten": "Nonkonformist",
    "Nonnen": "Nonne",
    "Noppen": "Noppe",
    "Norberts": "Norbert",
    "Nordatlantiks": "Nordatlantik",
    "Norddeutsche": "norddeutsch",
    "Norddeutschen": "Norddeutsche",
    "Norde": "norden",
    "Nordende": "nordend",
    "Nordenden": "Nordende",
    "Nordends": "Nordend",
    "Nordens": "Norden",
    "Norderneys": "Norderney",
    "Nordes": "Nord",
    "Nordischen": "Nordische",
    "Nordischeren": "Nordischere",
    "Nordischsten": "Nordischste",
    "Nordkoreas": "Nordkorea",
    "Nordküsten": "Nordküste",
    "Nordlichte": "Nordlicht",
    "Nordlichter": "Nordlicht",
    "Nordlichtern": "Nordlicht",
    "Nordlichtes": "Nordlicht",
    "Nordlichts": "Nordlicht",
    "Nordländern": "Nordländer",
    "Nordländers": "Nordländer",
    "Nordländische": "nordländisch",
    "Nordländischen": "Nordländische",
    "Nordnordostens": "Nordnordosten",
    "Nordnordwestens": "Nordnordwesten",
    "Nordpunkte": "Nordpunkt",
    "Nordpunkten": "Nordpunkt",
    "Nordpunkts": "Nordpunkt",
    "Nords": "Nord",
    "Nordsterns": "Nordstern",
    "Nordwestens": "Nordwesten",
    "Nordwestliche": "nordwestlich",
    "Nordwestlichen": "Nordwestliche",
    "Nordzipfeln": "Nordzipfel",
    "Nordzipfels": "Nordzipfel",
    "Nordöstliche": "nordöstlich",
    "Nordöstlichen": "Nordöstliche",
    "Nordöstlicheren": "Nordöstlichere",
    "Nordöstlichsten": "Nordöstlichste",
    "Norm": "normen",
    "Normalbenzine": "Normalbenzin",
    "Normalbenzinen": "Normalbenzin",
    "Normalbenzins": "Normalbenzin",
    "Normalbürgern": "Normalbürger",
    "Normalbürgers": "Normalbürger",
    "Normale": "normal",
    "Normalen": "Normale",
    "Normaleren": "Normalere",
    "Normalisierenden": "Normalisierende",
    "Normalisierenderen": "Normalisierendere",
    "Normalisierens": "Normalisieren",
    "Normalisierte": "normalisiert",
    "Normalisierten": "Normalisierte",
    "Normalisierteren": "Normalisiertere",
    "Normalisiertesten": "Normalisierteste",
    "Normalisierungen": "Normalisierung",
    "Normalitäten": "Normalität",
    "Normallösungen": "Normallösung",
    "Normalste": "normal",
    "Normalsten": "Normalste",
    "Normalverdienern": "Normalverdiener",
    "Normalverdieners": "Normalverdiener",
    "Normalwissenschaften": "Normalwissenschaft",
    "Normalzeiten": "Normalzeit",
    "Normalzustands": "Normalzustand",
    "Normannische": "normannisch",
    "Normannischen": "Normannische",
    "Normativen": "Normative",
    "Normen": "Norm",
    "Normenden": "Normende",
    "Normenderen": "Normendere",
    "Normendsten": "Normendste",
    "Normens": "Normen",
    "Normierenden": "Normierende",
    "Normierenderen": "Normierendere",
    "Normierendsten": "Normierendste",
    "Normierens": "Normieren",
    "Normierte": "normiert",
    "Normierten": "Normierte",
    "Normierteren": "Normiertere",
    "Normiertesten": "Normierteste",
    "Normierungen": "Normierung",
    "Normwidrigen": "Normwidrige",
    "Norwegens": "Norwegen",
    "Norwegische": "norwegisch",
    "Norwegischen": "Norwegische",
    "Nostalgien": "Nostalgie",
    "Nostalgische": "nostalgisch",
    "Nostalgischen": "Nostalgische",
    "Nostalgischeren": "Nostalgischere",
    "Nostalgischsten": "Nostalgischste",
    "Notare": "Notar",
    "Notaren": "Notar",
    "Notares": "Notar",
    "Notarielle": "notariell",
    "Notariellen": "Notarielle",
    "Notarischen": "Notarische",
    "Notars": "Notar",
    "Notationen": "Notation",
    "Notaufnahmen": "Notaufnahme",
    "Notbremsen": "Notbremse",
    "Notdürftige": "notdürftig",
    "Notdürftigen": "Notdürftige",
    "Notdürftigeren": "Notdürftigere",
    "Notdürftigsten": "Notdürftigste",
    "Noten": "Note",
    "Notgedrungene": "notgedrungen",
    "Notgedrungenen": "Notgedrungene",
    "Notierenden": "Notierende",
    "Notierens": "Notieren",
    "Notierte": "notiert",
    "Notierten": "Notierte",
    "Notifikationen": "Notifikation",
    "Notizen": "Notiz",
    "Notorische": "notorisch",
    "Notorischen": "Notorische",
    "Notrufe": "Notruf",
    "Notrufen": "Notruf",
    "Notrufes": "Notruf",
    "Notrufs": "Notruf",
    "Nottinghams": "Nottingham",
    "Notwendige": "notwendig",
    "Notwendigen": "Notwendige",
    "Notwendigeren": "Notwendigere",
    "Notwendigkeiten": "Notwendigkeit",
    "Notwendigste": "notwendig",
    "Notwendigsten": "Notwendigste",
    "Novellen": "Novelle",
    "Novembers": "November",
    "Nowakowskis": "Nowakowski",
    "Nuancen": "Nuance",
    "Nudel": "nudeln",
    "Nudeln": "Nudel",
    "Nudelnden": "Nudelnde",
    "Nudelns": "Nudeln",
    "Nuklearen": "Nukleare",
    "Nullen": "Null",
    "Nullenden": "Nullende",
    "Nullens": "Nullen",
    "Nullern": "Nuller",
    "Nullers": "Nuller",
    "Numerierenden": "Numerierende",
    "Numerierens": "Numerieren",
    "Numerierte": "numeriert",
    "Numerierten": "Numerierte",
    "Numerierungen": "Numerierung",
    "Numerische": "numerisch",
    "Numerischen": "Numerische",
    "Numerischeren": "Numerischere",
    "Numerischsten": "Numerischste",
    "Nummern": "Nummer",
    "Nuschelnden": "Nuschelnde",
    "Nuschelnderen": "Nuschelndere",
    "Nuschelndsten": "Nuschelndste",
    "Nuschelns": "Nuscheln",
    "Nutten": "Nutte",
    "Nutzanwendungen": "Nutzanwendung",
    "Nutzbare": "nutzbar",
    "Nutzbaren": "Nutzbare",
    "Nutzbarkeiten": "Nutzbarkeit",
    "Nutzbringende": "nutzbringend",
    "Nutzbringenden": "Nutzbringende",
    "Nutzbringenderen": "Nutzbringendere",
    "Nutzbringendsten": "Nutzbringendste",
    "Nutzeffekte": "Nutzeffekt",
    "Nutzeffekten": "Nutzeffekt",
    "Nutzeffekts": "Nutzeffekt",
    "Nutzenden": "Nutzende",
    "Nutzens": "Nutzen",
    "Nutzlasten": "Nutzlast",
    "Nutzlosen": "Nutzlose",
    "Nutzloseren": "Nutzlosere",
    "Nutzlosesten": "Nutzloseste",
    "Nutzungen": "Nutzung",
    "Nutzungsfähige": "nutzungsfähig",
    "Nutzungsfähigen": "Nutzungsfähige",
    "Nutzungsfähigeren": "Nutzungsfähigere",
    "Nutzungsfähigsten": "Nutzungsfähigste",
    "Nutzwassers": "Nutzwasser",
    "Nutzwilde": "Nutzwild",
    "Nutzwildes": "Nutzwild",
    "Nutzwilds": "Nutzwild",
    "Nußbraunen": "Nußbraune",
    "Nylons": "Nylon",
    "Nymphen": "Nymphe",
    "Nymphomane": "nymphoman",
    "Nymphomanen": "Nymphomane",
    "Nächsten": "Nächste",
    "Nächstliegenden": "Nächstliegende",
    "Nächstliegenderen": "Nächstliegendere",
    "Nächstliegendsten": "Nächstliegendste",
    "Nächte": "Nacht",
    "Nächten": "Nacht",
    "Nächtigenden": "Nächtigende",
    "Nächtigens": "Nächtigen",
    "Nächtliche": "nächtlich",
    "Nächtlichen": "Nächtliche",
    "Nädelchens": "Nädelchen",
    "Nägel": "Nagel",
    "Nägeln": "Nagel",
    "Nägleins": "Näglein",
    "Nähenden": "Nähende",
    "Nähens": "Nähen",
    "Näherbringenden": "Näherbringende",
    "Näherbringenderen": "Näherbringendere",
    "Näherbringendsten": "Näherbringendste",
    "Näherbringens": "Näherbringen",
    "Nähere": "nähern",
    "Näheren": "Nähere",
    "Nähergebrachten": "Nähergebrachte",
    "Nähergebrachteren": "Nähergebrachtere",
    "Näherinnen": "Näherin",
    "Nähernden": "Nähernde",
    "Nähernderen": "Näherndere",
    "Näherndsten": "Näherndste",
    "Näherns": "Nähern",
    "Näherungen": "Näherung",
    "Nähesten": "Näheste",
    "Nähmaschinen": "Nähmaschine",
    "Nährbodens": "Nährboden",
    "Nährböden": "Nährboden",
    "Nährenden": "Nährende",
    "Nährens": "Nähren",
    "Nährstoffe": "Nährstoff",
    "Nährstoffen": "Nährstoff",
    "Nährstoffs": "Nährstoff",
    "Nähseiden": "Nähseide",
    "Nähstiche": "Nähstich",
    "Nähstichen": "Nähstich",
    "Nähstichs": "Nähstich",
    "Nähtische": "Nähtisch",
    "Nähtischen": "Nähtisch",
    "Nähtischs": "Nähtisch",
    "Näpfe": "Napf",
    "Näpfen": "Napf",
    "Närrischen": "Närrische",
    "Närrischeren": "Närrischere",
    "Närrischsten": "Närrischste",
    "Näschens": "Näschen",
    "Näselnden": "Näselnde",
    "Näselnderen": "Näselndere",
    "Näselndsten": "Näselndste",
    "Näselns": "Näseln",
    "Nässe": "nässen",
    "Nässelnden": "Nässelnde",
    "Nässelnderen": "Nässelndere",
    "Nässelndsten": "Nässelndste",
    "Nässelns": "Nässeln",
    "Nässen": "Naß",
    "Nässenden": "Nässende",
    "Nässenderen": "Nässendere",
    "Nässendsten": "Nässendste",
    "Nässens": "Nässen",
    "Nölenden": "Nölende",
    "Nölenderen": "Nölendere",
    "Nölendsten": "Nölendste",
    "Nölens": "Nölen",
    "Nönnchens": "Nönnchen",
    "Nördlichen": "Nördliche",
    "Nördlicheren": "Nördlichere",
    "Nördlichsten": "Nördlichste",
    "Nördlingens": "Nördlingen",
    "Nörgeligen": "Nörgelige",
    "Nörgeligeren": "Nörgeligere",
    "Nörgeligsten": "Nörgeligste",
    "Nörgelnden": "Nörgelnde",
    "Nörgelnderen": "Nörgelndere",
    "Nörgelndsten": "Nörgelndste",
    "Nörgelns": "Nörgeln",
    "Nörglern": "Nörgler",
    "Nörglers": "Nörgler",
    "Nöte": "Not",
    "Nöten": "Not",
    "Nötige": "nötigen",
    "Nötigen": "Nötige",
    "Nötigenden": "Nötigende",
    "Nötigens": "Nötigen",
    "Nötigeren": "Nötigere",
    "Nötigsten": "Nötigste",
    "Nötigungen": "Nötigung",
    "Nüchterne": "nüchtern",
    "Nüchternen": "Nüchterne",
    "Nüchterneren": "Nüchternere",
    "Nüchternsten": "Nüchternste",
    "Nürnbergern": "Nürnberger",
    "Nürnbergers": "Nürnberger",
    "Nürnbergs": "Nürnberg",
    "Nüsse": "Nuß",
    "Nüssen": "Nuß",
    "Nützende": "nützend",
    "Nützenden": "Nützende",
    "Nützens": "Nützen",
    "Nützliche": "nützlich",
    "Nützlichen": "Nützliche",
    "Nützlicheren": "Nützlichere",
    "Nützlichsten": "Nützlichste",
    "Nüßchens": "Nüßchen",
    "OBs": "OB",
    "Oasen": "Oase",
    "Obdachlose": "obdachlos",
    "Obdachlosen": "Obdachlose",
    "Obdachs": "Obdach",
    "Obduktionen": "Obduktion",
    "Obduzenten": "Obduzent",
    "Obduzierenden": "Obduzierende",
    "Obduzierens": "Obduzieren",
    "Obduzierte": "obduziert",
    "Obduzierten": "Obduzierte",
    "Obelisken": "Obelisk",
    "Oberarme": "Oberarm",
    "Oberarmen": "Oberarm",
    "Oberarms": "Oberarm",
    "Oberbefehls": "Oberbefehl",
    "Oberbegriffe": "Oberbegriff",
    "Oberbegriffen": "Oberbegriff",
    "Oberbegriffs": "Oberbegriff",
    "Oberbette": "Oberbett",
    "Oberbetten": "Oberbett",
    "Oberbetts": "Oberbett",
    "Oberbürgermeistern": "Oberbürgermeister",
    "Oberbürgermeisters": "Oberbürgermeister",
    "Oberdorfeldens": "Oberdorfelden",
    "Obere": "ober",
    "Oberen": "Obere",
    "Obereren": "Oberere",
    "Oberfeldwebeln": "Oberfeldwebel",
    "Oberfeldwebels": "Oberfeldwebel",
    "Oberflächen": "Oberfläche",
    "Oberflächige": "oberflächig",
    "Oberflächigen": "Oberflächige",
    "Oberflächigeren": "Oberflächigere",
    "Oberflächigsten": "Oberflächigste",
    "Oberflächlichen": "Oberflächliche",
    "Oberflächlicheren": "Oberflächlichere",
    "Oberflächlichsten": "Oberflächlichste",
    "Oberförstern": "Oberförster",
    "Oberförsters": "Oberförster",
    "Obergefreiten": "Obergefreite",
    "Obergrenzen": "Obergrenze",
    "Oberhause": "Oberhaus",
    "Oberhauses": "Oberhaus",
    "Oberhemde": "Oberhemd",
    "Oberhemden": "Oberhemd",
    "Oberhemds": "Oberhemd",
    "Oberherren": "Oberherr",
    "Oberhirten": "Oberhirte",
    "Oberhäuser": "Oberhaus",
    "Oberhäusern": "Oberhaus",
    "Oberjägern": "Oberjäger",
    "Oberjägers": "Oberjäger",
    "Oberkellnern": "Oberkellner",
    "Oberkellners": "Oberkellner",
    "Oberkiefern": "Oberkiefer",
    "Oberkiefers": "Oberkiefer",
    "Oberklassen": "Oberklasse",
    "Oberkommandos": "Oberkommando",
    "Oberkörpern": "Oberkörper",
    "Oberkörpers": "Oberkörper",
    "Oberlands": "Oberland",
    "Oberlehrerhafte": "oberlehrerhaft",
    "Oberlehrerhaften": "Oberlehrerhafte",
    "Oberlehrerhafteren": "Oberlehrerhaftere",
    "Oberlehrern": "Oberlehrer",
    "Oberlehrers": "Oberlehrer",
    "Oberleibe": "Oberleib",
    "Oberleiber": "Oberleib",
    "Oberleibern": "Oberleib",
    "Oberleibes": "Oberleib",
    "Oberleibs": "Oberleib",
    "Oberleitungen": "Oberleitung",
    "Oberleutnants": "Oberleutnant",
    "Oberlichte": "Oberlicht",
    "Oberlichter": "Oberlicht",
    "Oberlichtern": "Oberlicht",
    "Oberlichtes": "Oberlicht",
    "Oberlichts": "Oberlicht",
    "Oberlide": "Oberlid",
    "Oberlider": "Oberlid",
    "Oberlidern": "Oberlid",
    "Oberlides": "Oberlid",
    "Oberlids": "Oberlid",
    "Oberligisten": "Oberligist",
    "Oberlippen": "Oberlippe",
    "Obern": "Ober",
    "Obernhains": "Obernhain",
    "Oberpriestern": "Oberpriester",
    "Oberpriesters": "Oberpriester",
    "Oberrads": "Oberrad",
    "Oberrichtern": "Oberrichter",
    "Oberrichters": "Oberrichter",
    "Obers": "Ober",
    "Oberschenkeln": "Oberschenkel",
    "Oberschenkels": "Oberschenkel",
    "Oberschichten": "Oberschicht",
    "Oberschulen": "Oberschule",
    "Oberschurken": "Oberschurke",
    "Oberschwingungen": "Oberschwingung",
    "Oberseiten": "Oberseite",
    "Oberstaatsanwalte": "Oberstaatsanwalt",
    "Oberstaatsanwaltes": "Oberstaatsanwalt",
    "Oberstaatsanwalts": "Oberstaatsanwalt",
    "Oberstaatsanwälte": "Oberstaatsanwalt",
    "Oberstaatsanwälten": "Oberstaatsanwalt",
    "Oberste": "ober",
    "Oberstedtens": "Oberstedten",
    "Obersteigern": "Obersteiger",
    "Obersteigers": "Obersteiger",
    "Obersten": "Oberste",
    "Oberstimmen": "Oberstimme",
    "Oberstleutnants": "Oberstleutnant",
    "Obersts": "Oberst",
    "Oberstudiendirektore": "Oberstudiendirektor",
    "Oberstudiendirektoren": "Oberstudiendirektor",
    "Oberstudiendirektors": "Oberstudiendirektor",
    "Oberstudienrate": "Oberstudienrat",
    "Oberstudienrats": "Oberstudienrat",
    "Oberstudienräte": "Oberstudienrat",
    "Oberstudienräten": "Oberstudienrat",
    "Oberstufen": "Oberstufe",
    "Oberstübchens": "Oberstübchen",
    "Obertassen": "Obertasse",
    "Obertasten": "Obertaste",
    "Obertone": "Oberton",
    "Obertons": "Oberton",
    "Obertshausens": "Obertshausen",
    "Obertöne": "Oberton",
    "Obertönen": "Oberton",
    "Oberurselern": "Oberurseler",
    "Oberurselers": "Oberurseler",
    "Oberursels": "Oberursel",
    "Oberwassers": "Oberwasser",
    "Oberweiten": "Oberweite",
    "Oberwellen": "Oberwelle",
    "Obige": "obig",
    "Obigen": "Obige",
    "Objekte": "Objekt",
    "Objekten": "Objekt",
    "Objektive": "Objektiv",
    "Objektiven": "Objektive",
    "Objektiveren": "Objektivere",
    "Objektiviere": "objektivieren",
    "Objektivierenden": "Objektivierende",
    "Objektivierenderen": "Objektivierendere",
    "Objektivierens": "Objektivieren",
    "Objektivierte": "objektiviert",
    "Objektivierten": "Objektivierte",
    "Objektivierteren": "Objektiviertere",
    "Objektiviertesten": "Objektivierteste",
    "Objektivistischen": "Objektivistische",
    "Objektivistischeren": "Objektivistischere",
    "Objektivitäten": "Objektivität",
    "Objektivs": "Objektiv",
    "Objektivste": "objektiv",
    "Objektivsten": "Objektivste",
    "Objekts": "Objekt",
    "Oblaten": "Oblate",
    "Obleuten": "Obleute",
    "Obligatorische": "obligatorisch",
    "Obligatorischen": "Obligatorische",
    "Obligatorischeren": "Obligatorischere",
    "Obligatorischsten": "Obligatorischste",
    "Obmanne": "Obmann",
    "Obmannes": "Obmann",
    "Obmanns": "Obmann",
    "Obmänner": "Obmann",
    "Obmännern": "Obmann",
    "Obmänninnen": "Obmännin",
    "Oboen": "Oboe",
    "Oboisten": "Oboist",
    "Obrigkeiten": "Obrigkeit",
    "Obsessionen": "Obsession",
    "Obsessive": "obsessiv",
    "Obsessiven": "Obsessive",
    "Obsts": "Obst",
    "Obturatore": "Obturator",
    "Obturatoren": "Obturator",
    "Obturators": "Obturator",
    "Ochsen": "Ochse",
    "Ockern": "Ocker",
    "Ockers": "Ocker",
    "Ockstadts": "Ockstadt",
    "Odems": "Odem",
    "Oden": "Ode",
    "Odenwaldes": "Odenwald",
    "Odiums": "Odium",
    "Odontologische": "odontologisch",
    "Odontologischen": "Odontologische",
    "Ofenfrischen": "Ofenfrische",
    "Ofens": "Ofen",
    "Offenbachern": "Offenbacher",
    "Offenbachers": "Offenbacher",
    "Offenbachs": "Offenbach",
    "Offenbarenden": "Offenbarende",
    "Offenbarenderen": "Offenbarendere",
    "Offenbarendsten": "Offenbarendste",
    "Offenbarens": "Offenbaren",
    "Offenbarte": "offenbart",
    "Offenbarten": "Offenbarte",
    "Offenbleibenden": "Offenbleibende",
    "Offenbleibens": "Offenbleiben",
    "Offenen": "Offene",
    "Offeneren": "Offenere",
    "Offengebliebenen": "Offengebliebene",
    "Offengehaltenen": "Offengehaltene",
    "Offengehalteneren": "Offengehaltenere",
    "Offengehaltensten": "Offengehaltenste",
    "Offengelassenen": "Offengelassene",
    "Offengelegten": "Offengelegte",
    "Offenhaltenden": "Offenhaltende",
    "Offenhaltenderen": "Offenhaltendere",
    "Offenhaltendsten": "Offenhaltendste",
    "Offenhaltens": "Offenhalten",
    "Offenheiten": "Offenheit",
    "Offenherzige": "offenherzig",
    "Offenherzigen": "Offenherzige",
    "Offenherzigeren": "Offenherzigere",
    "Offenherzigsten": "Offenherzigste",
    "Offenkundigen": "Offenkundige",
    "Offenkundigeren": "Offenkundigere",
    "Offenkundigsten": "Offenkundigste",
    "Offenlassenden": "Offenlassende",
    "Offenlassens": "Offenlassen",
    "Offenlegenden": "Offenlegende",
    "Offenlegens": "Offenlegen",
    "Offensichtlichen": "Offensichtliche",
    "Offensichtlicheren": "Offensichtlichere",
    "Offensiven": "Offensive",
    "Offensiveren": "Offensivere",
    "Offensivsten": "Offensivste",
    "Offensten": "Offenste",
    "Offenthals": "Offenthal",
    "Offerierenden": "Offerierende",
    "Offerierens": "Offerieren",
    "Offerierte": "offeriert",
    "Offerierten": "Offerierte",
    "Offerten": "Offerte",
    "Offizielle": "offiziell",
    "Offiziellen": "Offizielle",
    "Offizielleren": "Offiziellere",
    "Offiziellsten": "Offiziellste",
    "Offiziere": "Offizier",
    "Offizieren": "Offizier",
    "Offiziers": "Offizier",
    "Ohnmachten": "Ohnmacht",
    "Ohnmächtige": "ohnmächtig",
    "Ohnmächtigen": "Ohnmächtige",
    "Ohnmächtigeren": "Ohnmächtigere",
    "Ohnmächtigsten": "Ohnmächtigste",
    "Ohre": "Ohr",
    "Ohren": "Ohr",
    "Ohrenbetäubende": "ohrenbetäubend",
    "Ohrenbetäubenden": "Ohrenbetäubende",
    "Ohrenbetäubenderen": "Ohrenbetäubendere",
    "Ohrensausens": "Ohrensausen",
    "Ohrfeigenden": "Ohrfeigende",
    "Ohrfeigens": "Ohrfeigen",
    "Ohrgehängen": "Ohrgehänge",
    "Ohrgehänges": "Ohrgehänge",
    "Ohrläppchens": "Ohrläppchen",
    "Ohrs": "Ohr",
    "Okkasionelle": "okkasionell",
    "Okkasionellen": "Okkasionelle",
    "Okkludierenden": "Okkludierende",
    "Okkludierens": "Okkludieren",
    "Okkludierte": "okkludiert",
    "Okkludierten": "Okkludierte",
    "Okklusionen": "Okklusion",
    "Okklusive": "okklusiv",
    "Okklusiven": "Okklusive",
    "Okkulten": "Okkulte",
    "Okkultisten": "Okkultist",
    "Okkultistische": "okkultistisch",
    "Okkultistischen": "Okkultistische",
    "Okkupanten": "Okkupant",
    "Okkupationen": "Okkupation",
    "Okkupierenden": "Okkupierende",
    "Okkupierenderen": "Okkupierendere",
    "Okkupierendsten": "Okkupierendste",
    "Okkupierens": "Okkupieren",
    "Okkupierte": "okkupiert",
    "Okkupierten": "Okkupierte",
    "Okkupierteren": "Okkupiertere",
    "Okkupiertesten": "Okkupierteste",
    "Oktanzahlen": "Oktanzahl",
    "Oktaven": "Oktave",
    "Oktavzahlen": "Oktavzahl",
    "Oktobern": "Oktober",
    "Oktobers": "Oktober",
    "Okulare": "Okular",
    "Okularen": "Okulare",
    "Okulars": "Okular",
    "Olafs": "Olaf",
    "Oldenburgern": "Oldenburger",
    "Oldenburgers": "Oldenburger",
    "Oldenburgs": "Oldenburg",
    "Oldies": "Oldie",
    "Oldtimers": "Oldtimer",
    "Oleandern": "Oleander",
    "Oleanders": "Oleander",
    "Olfens": "Olfen",
    "Olgas": "Olga",
    "Oliven": "Olive",
    "Olivers": "Oliver",
    "Olle": "oll",
    "Ollen": "Olle",
    "Olleren": "Ollere",
    "Ollsten": "Ollste",
    "Olympiaden": "Olympiade",
    "Olympias": "Olympia",
    "Olympische": "olympisch",
    "Olympischen": "Olympische",
    "Omamas": "Omama",
    "Omas": "Oma",
    "Omeletts": "Omelett",
    "Ominöse": "ominös",
    "Ominösen": "Ominöse",
    "Ominöseren": "Ominösere",
    "Ominösesten": "Ominöseste",
    "Omis": "Omi",
    "Omittierenden": "Omittierende",
    "Omittierens": "Omittieren",
    "Omittierte": "omittiert",
    "Omittierten": "Omittierte",
    "Omnibusse": "Omnibus",
    "Omnibussen": "Omnibus",
    "Omnibusses": "Omnibus",
    "Omnipotente": "omnipotent",
    "Omnipotenten": "Omnipotente",
    "Omnipotenteren": "Omnipotentere",
    "Omnipotentesten": "Omnipotenteste",
    "Omnipräsenten": "Omnipräsente",
    "Onanierenden": "Onanierende",
    "Onanierens": "Onanieren",
    "Onanierte": "onaniert",
    "Onanierten": "Onanierte",
    "Onkelhaften": "Onkelhafte",
    "Onkelhafteren": "Onkelhaftere",
    "Onkelhaftesten": "Onkelhafteste",
    "Onkeln": "Onkel",
    "Onkels": "Onkel",
    "Onkologen": "Onkologe",
    "Onkologische": "onkologisch",
    "Onkologischen": "Onkologische",
    "Ontologischen": "Ontologische",
    "Opas": "Opa",
    "Opels": "Opel",
    "Operable": "operabel",
    "Operablen": "Operable",
    "Operanden": "Operand",
    "Operateure": "Operateur",
    "Operateuren": "Operateur",
    "Operateurs": "Operateur",
    "Operationen": "Operation",
    "Operative": "operativ",
    "Operativen": "Operative",
    "Operatore": "Operator",
    "Operatoren": "Operator",
    "Operatorinnen": "Operatorin",
    "Operators": "Operator",
    "Operetten": "Operette",
    "Operierenden": "Operierende",
    "Operierens": "Operieren",
    "Operierte": "operiert",
    "Operierten": "Operierte",
    "Opern": "Oper",
    "Opfer": "opfern",
    "Opferbereite": "opferbereit",
    "Opferbereiten": "Opferbereite",
    "Opferbereiteren": "Opferbereitere",
    "Opferbereitesten": "Opferbereiteste",
    "Opfern": "Opfer",
    "Opfernden": "Opfernde",
    "Opferns": "Opfern",
    "Opfers": "Opfer",
    "Opferungen": "Opferung",
    "Opferwillige": "opferwillig",
    "Opferwilligen": "Opferwillige",
    "Opferwilligeren": "Opferwilligere",
    "Opferwilligsten": "Opferwilligste",
    "Opis": "Opi",
    "Opiums": "Opium",
    "Oppenheimern": "Oppenheimer",
    "Oppenheimers": "Oppenheimer",
    "Opponierenden": "Opponierende",
    "Opponierenderen": "Opponierendere",
    "Opponierendsten": "Opponierendste",
    "Opponierens": "Opponieren",
    "Opponierte": "opponiert",
    "Opponierten": "Opponierte",
    "Opponierteren": "Opponiertere",
    "Opponiertesten": "Opponierteste",
    "Opportunen": "Opportune",
    "Opportunistischen": "Opportunistische",
    "Opportunistischeren": "Opportunistischere",
    "Oppositionellen": "Oppositionelle",
    "Oppositionen": "Opposition",
    "Optiken": "Optik",
    "Optikern": "Optiker",
    "Optikers": "Optiker",
    "Optimale": "optimal",
    "Optimalen": "Optimale",
    "Optimierenden": "Optimierende",
    "Optimierenderen": "Optimierendere",
    "Optimierendsten": "Optimierendste",
    "Optimierens": "Optimieren",
    "Optimierte": "optimiert",
    "Optimierten": "Optimierte",
    "Optimierteren": "Optimiertere",
    "Optimiertesten": "Optimierteste",
    "Optimierungen": "Optimierung",
    "Optimistische": "optimistisch",
    "Optimistischen": "Optimistische",
    "Optimistischeren": "Optimistischere",
    "Optimistischsten": "Optimistischste",
    "Optionen": "Option",
    "Optische": "optisch",
    "Optischen": "Optische",
    "Optometern": "Optometer",
    "Optometers": "Optometer",
    "Opulente": "opulent",
    "Opulenten": "Opulente",
    "Opulenteren": "Opulentere",
    "Opulentesten": "Opulenteste",
    "Orakeln": "Orakel",
    "Orakels": "Orakel",
    "Orangen": "Orange",
    "Oratorische": "oratorisch",
    "Oratorischen": "Oratorische",
    "Orbitalen": "Orbitale",
    "Orbitalraketen": "Orbitalrakete",
    "Orbitern": "Orbiter",
    "Orbiters": "Orbiter",
    "Orbits": "Orbit",
    "Orchestern": "Orchester",
    "Orchesters": "Orchester",
    "Orchideen": "Orchidee",
    "Ordens": "Orden",
    "Ordentliche": "ordentlich",
    "Ordentlichen": "Ordentliche",
    "Ordentlicheren": "Ordentlichere",
    "Ordentlichsten": "Ordentlichste",
    "Order": "ordern",
    "Ordern": "Order",
    "Ordernden": "Ordernde",
    "Ordernderen": "Orderndere",
    "Orderndsten": "Orderndste",
    "Orderns": "Ordern",
    "Ordinalen": "Ordinale",
    "Ordinalzahlen": "Ordinalzahl",
    "Ordinationen": "Ordination",
    "Ordinierenden": "Ordinierende",
    "Ordinierens": "Ordinieren",
    "Ordinierte": "ordiniert",
    "Ordinierten": "Ordinierte",
    "Ordinäre": "ordinär",
    "Ordinären": "Ordinäre",
    "Ordinäreren": "Ordinärere",
    "Ordinärsten": "Ordinärste",
    "Ordnenden": "Ordnende",
    "Ordnens": "Ordnen",
    "Ordnern": "Ordner",
    "Ordners": "Ordner",
    "Ordnungen": "Ordnung",
    "Ordnungsgemäße": "ordnungsgemäß",
    "Ordnungsgemäßen": "Ordnungsgemäße",
    "Ordnungsliebenden": "Ordnungsliebende",
    "Ordnungsliebenderen": "Ordnungsliebendere",
    "Ordnungsmäßigen": "Ordnungsmäßige",
    "Ordnungswidrigen": "Ordnungswidrige",
    "Ordnungswidrigeren": "Ordnungswidrigere",
    "Organe": "Organ",
    "Organen": "Organ",
    "Organes": "Organ",
    "Organisationen": "Organisation",
    "Organisatoren": "Organisator",
    "Organisatorische": "organisatorisch",
    "Organisatorischen": "Organisatorische",
    "Organischen": "Organische",
    "Organisierenden": "Organisierende",
    "Organisierens": "Organisieren",
    "Organisierte": "organisiert",
    "Organisierten": "Organisierte",
    "Organismen": "Organismus",
    "Organisten": "Organist",
    "Organistinnen": "Organistin",
    "Organs": "Organ",
    "Orgasmen": "Orgasmus",
    "Orgel": "orgeln",
    "Orgeln": "Orgel",
    "Orgelnden": "Orgelnde",
    "Orgelns": "Orgeln",
    "Orgien": "Orgie",
    "Orientalinnen": "Orientalin",
    "Orientalische": "orientalisch",
    "Orientalischen": "Orientalische",
    "Orientalischeren": "Orientalischere",
    "Orientalischsten": "Orientalischste",
    "Orientalisten": "Orientalist",
    "Oriente": "Orient",
    "Orientes": "Orient",
    "Orientierenden": "Orientierende",
    "Orientierens": "Orientieren",
    "Orientierte": "orientiert",
    "Orientierten": "Orientierte",
    "Orientierungen": "Orientierung",
    "Orients": "Orient",
    "Originale": "Original",
    "Originalen": "Originale",
    "Originals": "Original",
    "Originaltexte": "Originaltext",
    "Originaltexten": "Originaltext",
    "Originaltexts": "Originaltext",
    "Originellen": "Originelle",
    "Originelleren": "Originellere",
    "Originellsten": "Originellste",
    "Originäre": "originär",
    "Originären": "Originäre",
    "Orkane": "Orkan",
    "Orkanen": "Orkan",
    "Orkans": "Orkan",
    "Ornamentale": "ornamental",
    "Ornamentalen": "Ornamentale",
    "Ornamente": "Ornament",
    "Ornamenten": "Ornament",
    "Ornaments": "Ornament",
    "Ornithologische": "ornithologisch",
    "Ornithologischen": "Ornithologische",
    "Orte": "orten",
    "Orten": "Ort",
    "Ortenden": "Ortende",
    "Ortens": "Orten",
    "Orthodoxen": "Orthodoxe",
    "Orthogonalen": "Orthogonale",
    "Orthografien": "Orthografie",
    "Orthographien": "Orthographie",
    "Orthographische": "orthographisch",
    "Orthographischen": "Orthographische",
    "Orthopäden": "Orthopäde",
    "Orthopädische": "orthopädisch",
    "Orthopädischen": "Orthopädische",
    "Orthopädischeren": "Orthopädischere",
    "Orthopädischsten": "Orthopädischste",
    "Orthopädisten": "Orthopädist",
    "Orts": "Ort",
    "Ortsansässige": "ortsansässig",
    "Ortsansässigen": "Ortsansässige",
    "Ortsbeweglichen": "Ortsbewegliche",
    "Ortschaften": "Ortschaft",
    "Ortsfeste": "ortsfest",
    "Ortsfesten": "Ortsfeste",
    "Ortsfremden": "Ortsfremde",
    "Ortsfremderen": "Ortsfremdere",
    "Ortsfremdesten": "Ortsfremdeste",
    "Ortskundigen": "Ortskundige",
    "Ortskundigeren": "Ortskundigere",
    "Ortskundigsten": "Ortskundigste",
    "Ortsvorsteherinnen": "Ortsvorsteherin",
    "Ortsüblichen": "Ortsübliche",
    "Ortungen": "Ortung",
    "Os": "O",
    "Oscars": "Oscar",
    "Oskars": "Oskar",
    "Oslos": "Oslo",
    "Osmanen": "Osmane",
    "Osmanische": "osmanisch",
    "Osmanischen": "Osmanische",
    "Osnabrücks": "Osnabrück",
    "Osramlampen": "Osramlampe",
    "Ossis": "Ossi",
    "Ostdeutsche": "ostdeutsch",
    "Ostdeutschen": "Ostdeutsche",
    "Ostdeutschlands": "Ostdeutschland",
    "Oste": "Ost",
    "Ostends": "Ostend",
    "Ostens": "Osten",
    "Osterfeste": "Osterfest",
    "Osterfesten": "Osterfest",
    "Osterfests": "Osterfest",
    "Osterhasen": "Osterhase",
    "Ostermontage": "Ostermontag",
    "Ostermontagen": "Ostermontag",
    "Ostermontags": "Ostermontag",
    "Osterns": "Ostern",
    "Ostersonnabende": "Ostersonnabend",
    "Ostersonnabenden": "Ostersonnabend",
    "Ostersonnabends": "Ostersonnabend",
    "Ostersonntage": "Ostersonntag",
    "Ostersonntagen": "Ostersonntag",
    "Ostersonntags": "Ostersonntag",
    "Ostes": "Ost",
    "Osteuropas": "Osteuropa",
    "Osteuropäische": "osteuropäisch",
    "Osteuropäischen": "Osteuropäische",
    "Ostgelde": "Ostgeld",
    "Ostgeldes": "Ostgeld",
    "Ostgelds": "Ostgeld",
    "Ostheims": "Ostheim",
    "Ostküsten": "Ostküste",
    "Ostmitteldeutsche": "ostmitteldeutsch",
    "Ostmitteldeutschen": "Ostmitteldeutsche",
    "Ostnordostens": "Ostnordosten",
    "Osts": "Ost",
    "Ostwinde": "Ostwind",
    "Ostwinden": "Ostwind",
    "Ostwinds": "Ostwind",
    "Oszillationen": "Oszillation",
    "Oszillatore": "Oszillator",
    "Oszillatoren": "Oszillator",
    "Oszillators": "Oszillator",
    "Oszillierenden": "Oszillierende",
    "Oszillierens": "Oszillieren",
    "Oszillierte": "oszilliert",
    "Oszillierten": "Oszillierte",
    "Oszillographen": "Oszillograph",
    "Otosklerosen": "Otosklerose",
    "Ottern": "Otter",
    "Otters": "Otter",
    "Ottomotore": "Ottomotor",
    "Ottomotoren": "Ottomotor",
    "Ottomotors": "Ottomotor",
    "Ottos": "Otto",
    "Outfits": "Outfit",
    "Outputs": "Output",
    "Ouzos": "Ouzo",
    "Overalls": "Overall",
    "Ovulationen": "Ovulation",
    "Owens": "Owen",
    "Oxidationen": "Oxidation",
    "Oxidierenden": "Oxidierende",
    "Oxidierens": "Oxidieren",
    "Oxidierte": "oxidiert",
    "Oxidierten": "Oxidierte",
    "Ozeane": "Ozean",
    "Ozeanen": "Ozean",
    "Ozeans": "Ozean",
    "Ozonisierenden": "Ozonisierende",
    "Ozonisierens": "Ozonisieren",
    "Ozonisierte": "ozonisiert",
    "Ozonisierten": "Ozonisierte",
    "Ozons": "Ozon",
    "PCs": "PC",
    "PRs": "PR",
    "PVCs": "PVC",
    "Paar": "paaren",
    "Paare": "paaren",
    "Paaren": "Paar",
    "Paarenden": "Paarende",
    "Paarens": "Paaren",
    "Paares": "Paar",
    "Paars": "Paar",
    "Paarungen": "Paarung",
    "Pachten": "Pacht",
    "Pachtenden": "Pachtende",
    "Pachtens": "Pachten",
    "Pachtgute": "Pachtgut",
    "Pachtgutes": "Pachtgut",
    "Pachtguts": "Pachtgut",
    "Pachtgüter": "Pachtgut",
    "Pachtgütern": "Pachtgut",
    "Pachtungen": "Pachtung",
    "Pacifics": "Pacific",
    "Pack": "packen",
    "Packenden": "Packende",
    "Packenderen": "Packendere",
    "Packendsten": "Packendste",
    "Packens": "Packen",
    "Packlagen": "Packlage",
    "Packleinens": "Packleinen",
    "Packpapiere": "Packpapier",
    "Packpapieren": "Packpapier",
    "Packpapiers": "Packpapier",
    "Packpferde": "Packpferd",
    "Packpferden": "Packpferd",
    "Packpferds": "Packpferd",
    "Packs": "Pack",
    "Packungen": "Packung",
    "Packwerke": "Packwerk",
    "Packwerken": "Packwerk",
    "Packwerks": "Packwerk",
    "Paddel": "paddeln",
    "Paddeln": "Paddel",
    "Paddelnden": "Paddelnde",
    "Paddelns": "Paddeln",
    "Paddels": "Paddel",
    "Paderborns": "Paderborn",
    "Paffenden": "Paffende",
    "Paffens": "Paffen",
    "Pakete": "Paket",
    "Paketen": "Paket",
    "Paketes": "Paket",
    "Pakets": "Paket",
    "Pakistanische": "pakistanisch",
    "Pakistanischen": "Pakistanische",
    "Pakistans": "Pakistan",
    "Paks": "Pak",
    "Pakte": "Pakt",
    "Pakten": "Pakt",
    "Paktes": "Pakt",
    "Pakts": "Pakt",
    "Palaste": "Palast",
    "Palastes": "Palast",
    "Palasts": "Palast",
    "Paletten": "Palette",
    "Palisaden": "Palisade",
    "Palisandern": "Palisander",
    "Palisanders": "Palisander",
    "Palmen": "Palme",
    "Palmweine": "Palmwein",
    "Palmweinen": "Palmwein",
    "Palmweins": "Palmwein",
    "Palmöle": "Palmöl",
    "Palmölen": "Palmöl",
    "Palmöls": "Palmöl",
    "Paläontologen": "Paläontologe",
    "Paläste": "Palast",
    "Palästen": "Palast",
    "Palästinas": "Palästina",
    "Palästinensern": "Palästinenser",
    "Palästinensers": "Palästinenser",
    "Palästinensische": "palästinensisch",
    "Palästinensischen": "Palästinensische",
    "Pampas": "Pampa",
    "Pampelmusen": "Pampelmuse",
    "Pampige": "pampig",
    "Pampigen": "Pampige",
    "Pampigeren": "Pampigere",
    "Pampigsten": "Pampigste",
    "Panamas": "Panama",
    "Panierenden": "Panierende",
    "Panierens": "Panieren",
    "Panierte": "paniert",
    "Panierten": "Panierte",
    "Paniken": "Panik",
    "Panische": "panisch",
    "Panischen": "Panische",
    "Panischeren": "Panischere",
    "Panischsten": "Panischste",
    "Pankows": "Pankow",
    "Pannen": "Panne",
    "Panoramas": "Panorama",
    "Pans": "Pan",
    "Panschenden": "Panschende",
    "Panschenderen": "Panschendere",
    "Panschendsten": "Panschendste",
    "Panschens": "Panschen",
    "Panschereien": "Panscherei",
    "Panschern": "Panscher",
    "Panschers": "Panscher",
    "Panthern": "Panther",
    "Panthers": "Panther",
    "Pantinen": "Pantine",
    "Pantoffeln": "Pantoffel",
    "Pantoffels": "Pantoffel",
    "Pantomimische": "pantomimisch",
    "Pantomimischen": "Pantomimische",
    "Pantschenden": "Pantschende",
    "Pantschens": "Pantschen",
    "Pantöffelchens": "Pantöffelchen",
    "Panzer": "panzern",
    "Panzerabwehrkanonen": "Panzerabwehrkanone",
    "Panzerfäuste": "Panzerfaust",
    "Panzerfäusten": "Panzerfaust",
    "Panzern": "Panzer",
    "Panzernden": "Panzernde",
    "Panzernderen": "Panzerndere",
    "Panzerndsten": "Panzerndste",
    "Panzerns": "Panzern",
    "Panzers": "Panzer",
    "Panzerungen": "Panzerung",
    "Papageie": "Papagei",
    "Papageien": "Papagei",
    "Papageis": "Papagei",
    "Papas": "Papa",
    "Papern": "Paper",
    "Papers": "Paper",
    "Papiere": "Papier",
    "Papieren": "Papier",
    "Papierene": "papieren",
    "Papierenen": "Papierene",
    "Papiers": "Papier",
    "Papillare": "papillar",
    "Papillaren": "Papillare",
    "Papisten": "Papist",
    "Pappbechern": "Pappbecher",
    "Pappbechers": "Pappbecher",
    "Pappe": "pappen",
    "Pappeln": "Pappel",
    "Pappenden": "Pappende",
    "Pappenheimern": "Pappenheimer",
    "Pappenheimers": "Pappenheimer",
    "Pappens": "Pappen",
    "Pappigen": "Pappige",
    "Pappigeren": "Pappigere",
    "Pappigsten": "Pappigste",
    "Pappplakate": "Pappplakat",
    "Pappplakaten": "Pappplakat",
    "Pappplakates": "Pappplakat",
    "Pappplakats": "Pappplakat",
    "Pappsatte": "pappsatt",
    "Pappsatten": "Pappsatte",
    "Papste": "Papst",
    "Papstes": "Papst",
    "Papsts": "Papst",
    "Papsttums": "Papsttum",
    "Papyri": "Papyrus",
    "Parabeln": "Parabel",
    "Parabolantennen": "Parabolantenne",
    "Parabolische": "parabolisch",
    "Parabolischen": "Parabolische",
    "Parabolisierenden": "Parabolisierende",
    "Parabolisierens": "Parabolisieren",
    "Parabolisierte": "parabolisiert",
    "Parabolisierten": "Parabolisierte",
    "Parabolspiegeln": "Parabolspiegel",
    "Parabolspiegels": "Parabolspiegel",
    "Paraden": "Parade",
    "Paradentosen": "Paradentose",
    "Paradiese": "Paradies",
    "Paradiesen": "Paradies",
    "Paradieses": "Paradies",
    "Paradiesische": "paradiesisch",
    "Paradiesischen": "Paradiesische",
    "Paradigmas": "Paradigma",
    "Paradigmatische": "paradigmatisch",
    "Paradigmatischen": "Paradigmatische",
    "Paradigmen": "Paradigma",
    "Paradoxe": "paradox",
    "Paradoxen": "Paradoxe",
    "Paradoxeren": "Paradoxere",
    "Paradoxesten": "Paradoxeste",
    "Paradoxien": "Paradoxon",
    "Paradoxons": "Paradoxon",
    "Paragenesen": "Paragenese",
    "Paragraphen": "Paragraph",
    "Paragraphierenden": "Paragraphierende",
    "Paragraphierens": "Paragraphieren",
    "Paragraphierte": "paragraphiert",
    "Paragraphierten": "Paragraphierte",
    "Paragraphzeichens": "Paragraphzeichen",
    "Parakinesen": "Parakinese",
    "Parallelgeschalteten": "Parallelgeschaltete",
    "Parallelschaltenden": "Parallelschaltende",
    "Parallelschaltens": "Parallelschalten",
    "Paralysen": "Paralyse",
    "Paralysierenden": "Paralysierende",
    "Paralysierenderen": "Paralysierendere",
    "Paralysierendsten": "Paralysierendste",
    "Paralysierens": "Paralysieren",
    "Paralysierte": "paralysiert",
    "Paralysierten": "Paralysierte",
    "Paralysierteren": "Paralysiertere",
    "Paralysiertesten": "Paralysierteste",
    "Paralytischen": "Paralytische",
    "Parametern": "Parameter",
    "Parameters": "Parameter",
    "Paramilitärische": "paramilitärisch",
    "Paramilitärischen": "Paramilitärische",
    "Paranoiden": "Paranoide",
    "Paranoideren": "Paranoidere",
    "Paranoidesten": "Paranoideste",
    "Paraphrasen": "Paraphrase",
    "Paraphrasierenden": "Paraphrasierende",
    "Paraphrasierens": "Paraphrasieren",
    "Paraphrasierte": "paraphrasiert",
    "Paraphrasierten": "Paraphrasierte",
    "Parasiten": "Parasit",
    "Parasitische": "parasitisch",
    "Parasitischen": "Parasitische",
    "Parasitischeren": "Parasitischere",
    "Parasitischsten": "Parasitischste",
    "Parasitären": "Parasitäre",
    "Parasitäreren": "Parasitärere",
    "Parasitärsten": "Parasitärste",
    "Parataxen": "Parataxe",
    "Parate": "parat",
    "Paraten": "Parate",
    "Parateren": "Paratere",
    "Paratesten": "Parateste",
    "Parentale": "parental",
    "Parentalen": "Parentale",
    "Parfums": "Parfum",
    "Parfümerien": "Parfümerie",
    "Parfümierenden": "Parfümierende",
    "Parfümierenderen": "Parfümierendere",
    "Parfümierendsten": "Parfümierendste",
    "Parfümierens": "Parfümieren",
    "Parfümierte": "parfümiert",
    "Parfümierten": "Parfümierte",
    "Parfümierteren": "Parfümiertere",
    "Parfümiertesten": "Parfümierteste",
    "Parfüms": "Parfüm",
    "Parierenden": "Parierende",
    "Parierens": "Parieren",
    "Parierte": "pariert",
    "Parierten": "Parierte",
    "Pariserinnen": "Pariserin",
    "Parisern": "Pariser",
    "Parisers": "Pariser",
    "Paritätische": "paritätisch",
    "Paritätischen": "Paritätische",
    "Pariwerte": "Pariwert",
    "Pariwerten": "Pariwert",
    "Pariwerts": "Pariwert",
    "Park": "parken",
    "Parkas": "Parka",
    "Parkbuchten": "Parkbucht",
    "Parkdecks": "Parkdeck",
    "Parkenden": "Parkende",
    "Parkens": "Parken",
    "Parkern": "Parker",
    "Parkers": "Parker",
    "Parkette": "Parkett",
    "Parketten": "Parkette",
    "Parkettierenden": "Parkettierende",
    "Parkettierens": "Parkettieren",
    "Parkettierte": "parkettiert",
    "Parkettierten": "Parkettierte",
    "Parketts": "Parkett",
    "Parkkrallen": "Parkkralle",
    "Parkleuchten": "Parkleuchte",
    "Parklücken": "Parklücke",
    "Parkometern": "Parkometer",
    "Parkometers": "Parkometer",
    "Parkplatze": "Parkplatz",
    "Parkplatzes": "Parkplatz",
    "Parkplätze": "Parkplatz",
    "Parkplätzen": "Parkplatz",
    "Parks": "Park",
    "Parkscheiben": "Parkscheibe",
    "Parksündern": "Parksünder",
    "Parksünders": "Parksünder",
    "Parkverbote": "Parkverbot",
    "Parkverboten": "Parkverbot",
    "Parkverbots": "Parkverbot",
    "Parlamentariern": "Parlamentarier",
    "Parlamentariers": "Parlamentarier",
    "Parlamentarische": "parlamentarisch",
    "Parlamentarischen": "Parlamentarische",
    "Parlamente": "Parlament",
    "Parlamenten": "Parlament",
    "Parlaments": "Parlament",
    "Parlamentäre": "Parlamentär",
    "Parlamentären": "Parlamentär",
    "Parlamentärs": "Parlamentär",
    "Parodien": "Parodie",
    "Parolen": "Parole",
    "Parsenden": "Parsende",
    "Parsens": "Parsen",
    "Parsern": "Parser",
    "Parsers": "Parser",
    "Parteien": "Partei",
    "Parteiinterne": "parteiintern",
    "Parteiinternen": "Parteiinterne",
    "Parteiischen": "Parteiische",
    "Parteiischeren": "Parteiischere",
    "Parteiischsten": "Parteiischste",
    "Parteilichen": "Parteiliche",
    "Parteilicheren": "Parteilichere",
    "Parteilichsten": "Parteilichste",
    "Parteilosen": "Parteilose",
    "Partieführern": "Partieführer",
    "Partieführers": "Partieführer",
    "Partien": "Partie",
    "Partikeln": "Partikel",
    "Partikels": "Partikel",
    "Partikulare": "partikular",
    "Partikularen": "Partikulare",
    "Partikularistischen": "Partikularistische",
    "Partikularistischeren": "Partikularistischere",
    "Partisanen": "Partisan",
    "Partitionen": "Partition",
    "Partituren": "Partitur",
    "Partizipien": "Partizip",
    "Partizipiere": "partizipieren",
    "Partizipierenden": "Partizipierende",
    "Partizipierenderen": "Partizipierendere",
    "Partizipierens": "Partizipieren",
    "Partizipierte": "partizipiert",
    "Partizipierten": "Partizipierte",
    "Partizipierteren": "Partizipiertere",
    "Partizipiertesten": "Partizipierteste",
    "Partizips": "Partizip",
    "Partnerinnen": "Partnerin",
    "Partnern": "Partner",
    "Partners": "Partner",
    "Partnerschaften": "Partnerschaft",
    "Partys": "Party",
    "Parzellen": "Parzelle",
    "Parzellierenden": "Parzellierende",
    "Parzellierenderen": "Parzellierendere",
    "Parzellierendsten": "Parzellierendste",
    "Parzellierens": "Parzellieren",
    "Parzellierte": "parzelliert",
    "Parzellierten": "Parzellierte",
    "Parzellierteren": "Parzelliertere",
    "Parzelliertesten": "Parzellierteste",
    "Paschas": "Pascha",
    "Passabelste": "passabel",
    "Passabelsten": "Passabelste",
    "Passablen": "Passable",
    "Passableren": "Passablere",
    "Passagen": "Passage",
    "Passagiere": "Passagier",
    "Passagieren": "Passagier",
    "Passagieres": "Passagier",
    "Passagiers": "Passagier",
    "Passanten": "Passant",
    "Passats": "Passat",
    "Passe": "passen",
    "Passenden": "Passende",
    "Passens": "Passen",
    "Passes": "Paß",
    "Passierbaren": "Passierbare",
    "Passierbareren": "Passierbarere",
    "Passierbarsten": "Passierbarste",
    "Passierenden": "Passierende",
    "Passierens": "Passieren",
    "Passierscheine": "Passierschein",
    "Passierscheinen": "Passierschein",
    "Passierscheins": "Passierschein",
    "Passierte": "passiert",
    "Passierten": "Passierte",
    "Passionen": "Passion",
    "Passionierte": "passioniert",
    "Passionierten": "Passionierte",
    "Passionierteren": "Passioniertere",
    "Passioniertesten": "Passionierteste",
    "Passionssonntage": "Passionssonntag",
    "Passionssonntagen": "Passionssonntag",
    "Passionssonntags": "Passionssonntag",
    "Passive": "passiv",
    "Passiven": "Passive",
    "Passiveren": "Passivere",
    "Passivitäten": "Passivität",
    "Passivrauchens": "Passivrauchen",
    "Passivste": "passiv",
    "Passivsten": "Passivste",
    "Pastellfarben": "Pastellfarbe",
    "Pastellmalereien": "Pastellmalerei",
    "Pasten": "Paste",
    "Pasteten": "Pastete",
    "Pastillen": "Pastille",
    "Pastorale": "pastoral",
    "Pastoralen": "Pastorale",
    "Pastorate": "Pastorat",
    "Pastoraten": "Pastorat",
    "Pastorats": "Pastorat",
    "Pastore": "Pastor",
    "Pastoren": "Pastor",
    "Pastorinnen": "Pastorin",
    "Pastors": "Pastor",
    "Paten": "Pate",
    "Patenschaften": "Patenschaft",
    "Patente": "Patent",
    "Patenten": "Patente",
    "Patenteren": "Patentere",
    "Patenteste": "patent",
    "Patentesten": "Patenteste",
    "Patentierenden": "Patentierende",
    "Patentierens": "Patentieren",
    "Patentierte": "patentiert",
    "Patentierten": "Patentierte",
    "Patents": "Patent",
    "Patern": "Pater",
    "Paters": "Pater",
    "Pathetische": "pathetisch",
    "Pathetischen": "Pathetische",
    "Pathetischeren": "Pathetischere",
    "Pathetischsten": "Pathetischste",
    "Pathologen": "Pathologe",
    "Pathologische": "pathologisch",
    "Pathologischen": "Pathologische",
    "Patienten": "Patient",
    "Patientinnen": "Patientin",
    "Patinnen": "Patin",
    "Patriarchats": "Patriarchat",
    "Patriarchische": "patriarchisch",
    "Patriarchischen": "Patriarchische",
    "Patricks": "Patrick",
    "Patriziern": "Patrizier",
    "Patriziers": "Patrizier",
    "Patronen": "Patrone",
    "Patrouillen": "Patrouille",
    "Patschenassen": "Patschenasse",
    "Patschenden": "Patschende",
    "Patschens": "Patschen",
    "Patschhände": "Patschhand",
    "Patschhänden": "Patschhand",
    "Patschnasse": "patschnaß",
    "Patschnassen": "Patschnasse",
    "Patten": "Patte",
    "Patts": "Patt",
    "Patzenden": "Patzende",
    "Patzenderen": "Patzendere",
    "Patzendsten": "Patzendste",
    "Patzens": "Patzen",
    "Patzern": "Patzer",
    "Patzers": "Patzer",
    "Patzigen": "Patzige",
    "Patzigeren": "Patzigere",
    "Patzigsten": "Patzigste",
    "Pauken": "Pauke",
    "Paukenden": "Paukende",
    "Paukens": "Pauken",
    "Paukern": "Pauker",
    "Paukers": "Pauker",
    "Paulines": "Pauline",
    "Paulis": "Pauli",
    "Pauls": "Paul",
    "Pauschalbetrage": "Pauschalbetrag",
    "Pauschalbetrags": "Pauschalbetrag",
    "Pauschalbeträge": "Pauschalbetrag",
    "Pauschalbeträgen": "Pauschalbetrag",
    "Pauschale": "pauschal",
    "Pauschalen": "Pauschale",
    "Pauschaleren": "Pauschalere",
    "Pauschalierenden": "Pauschalierende",
    "Pauschalierenderen": "Pauschalierendere",
    "Pauschalierens": "Pauschalieren",
    "Pauschalierte": "pauschaliert",
    "Pauschalierten": "Pauschalierte",
    "Pauschalierteren": "Pauschaliertere",
    "Pauschaliertesten": "Pauschalierteste",
    "Pauschalisierenden": "Pauschalisierende",
    "Pauschalisierenderen": "Pauschalisierendere",
    "Pauschalisierens": "Pauschalisieren",
    "Pauschalisierte": "pauschalisiert",
    "Pauschalisierten": "Pauschalisierte",
    "Pauschalisierteren": "Pauschalisiertere",
    "Pauschalsten": "Pauschalste",
    "Pauschalsummen": "Pauschalsumme",
    "Pauschalurteile": "Pauschalurteil",
    "Pauschalurteilen": "Pauschalurteil",
    "Pauschalurteils": "Pauschalurteil",
    "Pauschbetrage": "Pauschbetrag",
    "Pauschbetrags": "Pauschbetrag",
    "Pauschbeträge": "Pauschbetrag",
    "Pauschbeträgen": "Pauschbetrag",
    "Pause": "pausen",
    "Pausen": "Pause",
    "Pausenden": "Pausende",
    "Pausenlosen": "Pausenlose",
    "Pausens": "Pausen",
    "Pausierenden": "Pausierende",
    "Pausierens": "Pausieren",
    "Pausierte": "pausiert",
    "Pausierten": "Pausierte",
    "Pauspapiere": "Pauspapier",
    "Pauspapieren": "Pauspapier",
    "Pauspapiers": "Pauspapier",
    "Pavillons": "Pavillon",
    "Pazifische": "pazifisch",
    "Pazifischen": "Pazifische",
    "Pazifisten": "Pazifist",
    "Paß": "passen",
    "Paßworte": "Paßwort",
    "Paßwortes": "Paßwort",
    "Paßworts": "Paßwort",
    "Paßwörter": "Paßwort",
    "Paßwörtern": "Paßwort",
    "Peche": "Pech",
    "Pechen": "Pech",
    "Pechs": "Pech",
    "Pechsträhnen": "Pechsträhne",
    "Pedale": "Pedal",
    "Pedalen": "Pedal",
    "Pedals": "Pedal",
    "Pedante": "pedant",
    "Pedanten": "Pedante",
    "Pedanteren": "Pedantere",
    "Pedantesten": "Pedanteste",
    "Pedantischen": "Pedantische",
    "Pedantischeren": "Pedantischere",
    "Pedantischsten": "Pedantischste",
    "Pediküren": "Pediküre",
    "Pedikürenden": "Pedikürende",
    "Pedikürenderen": "Pedikürendere",
    "Pedikürendsten": "Pedikürendste",
    "Pedikürens": "Pediküren",
    "Pedikürte": "pedikürt",
    "Pedikürten": "Pedikürte",
    "Pedikürteren": "Pedikürtere",
    "Pedikürtesten": "Pedikürteste",
    "Pegeln": "Pegel",
    "Pegels": "Pegel",
    "Peilenden": "Peilende",
    "Peilens": "Peilen",
    "Peilfrequenzen": "Peilfrequenz",
    "Peilgeräte": "Peilgerät",
    "Peilgeräten": "Peilgerät",
    "Peilgeräts": "Peilgerät",
    "Peilungen": "Peilung",
    "Peinigenden": "Peinigende",
    "Peinigenderen": "Peinigendere",
    "Peinigendsten": "Peinigendste",
    "Peinigens": "Peinigen",
    "Peinigern": "Peiniger",
    "Peinigers": "Peiniger",
    "Peinigungen": "Peinigung",
    "Peinliche": "peinlich",
    "Peinlichen": "Peinliche",
    "Peinlicheren": "Peinlichere",
    "Peinlichsten": "Peinlichste",
    "Peitschen": "Peitsche",
    "Peitschenden": "Peitschende",
    "Peitschens": "Peitschen",
    "Pejorativen": "Pejorative",
    "Pejorativeren": "Pejorativere",
    "Pejorativsten": "Pejorativste",
    "Pekings": "Peking",
    "Pelikane": "Pelikan",
    "Pelikanen": "Pelikan",
    "Pelikans": "Pelikan",
    "Pelle": "pellen",
    "Pellen": "Pelle",
    "Pellenden": "Pellende",
    "Pellenderen": "Pellendere",
    "Pellendsten": "Pellendste",
    "Pellens": "Pellen",
    "Pellkartoffeln": "Pellkartoffel",
    "Pelze": "Pelz",
    "Pelzen": "Pelz",
    "Pelzes": "Pelz",
    "Pelzige": "pelzig",
    "Pelzigen": "Pelzige",
    "Pelzigeren": "Pelzigere",
    "Pelzigsten": "Pelzigste",
    "Pendel": "pendeln",
    "Pendeln": "Pendel",
    "Pendelnden": "Pendelnde",
    "Pendelnderen": "Pendelndere",
    "Pendelndsten": "Pendelndste",
    "Pendelns": "Pendeln",
    "Pendels": "Pendel",
    "Pendlern": "Pendler",
    "Pendlers": "Pendler",
    "Penetrante": "penetrant",
    "Penetranten": "Penetrante",
    "Penetranteren": "Penetrantere",
    "Penetrantesten": "Penetranteste",
    "Penibelsten": "Penibelste",
    "Peniblen": "Penible",
    "Penibleren": "Peniblere",
    "Penicilline": "Penicillin",
    "Penicillinen": "Penicillin",
    "Penicillins": "Penicillin",
    "Pennbruders": "Pennbruder",
    "Pennbrüder": "Pennbruder",
    "Pennbrüdern": "Pennbruder",
    "Penne": "pennen",
    "Pennen": "Penne",
    "Pennenden": "Pennende",
    "Pennenderen": "Pennendere",
    "Pennendsten": "Pennendste",
    "Pennens": "Pennen",
    "Pennern": "Penner",
    "Penners": "Penner",
    "Pensionen": "Pension",
    "Pensionierenden": "Pensionierende",
    "Pensionierens": "Pensionieren",
    "Pensionierte": "pensioniert",
    "Pensionierten": "Pensionierte",
    "Pensionierungen": "Pensionierung",
    "Pensioniäre": "Pensioniär",
    "Pensioniären": "Pensioniär",
    "Pensioniärs": "Pensioniär",
    "Pensionäre": "Pensionär",
    "Pensionären": "Pensionär",
    "Pensionärs": "Pensionär",
    "Pentagons": "Pentagon",
    "Peppige": "peppig",
    "Peppigen": "Peppige",
    "Peppigeren": "Peppigere",
    "Peppigsten": "Peppigste",
    "Peps": "Pep",
    "Perfekte": "perfekt",
    "Perfekten": "Perfekte",
    "Perfekteren": "Perfektere",
    "Perfektesten": "Perfekteste",
    "Perfektionen": "Perfektion",
    "Perfektionierenden": "Perfektionierende",
    "Perfektionierenderen": "Perfektionierendere",
    "Perfektionierens": "Perfektionieren",
    "Perfektionierte": "perfektioniert",
    "Perfektionierten": "Perfektionierte",
    "Perfektionierteren": "Perfektioniertere",
    "Perfektionisten": "Perfektionist",
    "Perfektionistische": "perfektionistisch",
    "Perfektionistischen": "Perfektionistische",
    "Perfektionistischeren": "Perfektionistischere",
    "Perfiden": "Perfide",
    "Perfideren": "Perfidere",
    "Perfidesten": "Perfideste",
    "Perfidien": "Perfidie",
    "Perforationen": "Perforation",
    "Perforatore": "Perforator",
    "Perforatoren": "Perforator",
    "Perforators": "Perforator",
    "Perforierenden": "Perforierende",
    "Perforierenderen": "Perforierendere",
    "Perforierendsten": "Perforierendste",
    "Perforierens": "Perforieren",
    "Perforierte": "perforiert",
    "Perforierten": "Perforierte",
    "Perforierteren": "Perforiertere",
    "Perforiertesten": "Perforierteste",
    "Pergamentbande": "Pergamentband",
    "Pergamentbands": "Pergamentband",
    "Pergamentbände": "Pergamentband",
    "Pergamentbänden": "Pergamentband",
    "Pergamente": "Pergament",
    "Pergamenten": "Pergament",
    "Pergamentes": "Pergament",
    "Pergaments": "Pergament",
    "Perioden": "Periode",
    "Periodische": "periodisch",
    "Periodischen": "Periodische",
    "Periodisierenden": "Periodisierende",
    "Periodisierenderen": "Periodisierendere",
    "Periodisierens": "Periodisieren",
    "Periodisierte": "periodisiert",
    "Periodisierten": "Periodisierte",
    "Periodisierteren": "Periodisiertere",
    "Periodisiertesten": "Periodisierteste",
    "Peripheren": "Periphere",
    "Peripherien": "Peripherie",
    "Perkussionen": "Perkussion",
    "Perle": "perlen",
    "Perlen": "Perle",
    "Perlenden": "Perlende",
    "Perlenderen": "Perlendere",
    "Perlendsten": "Perlendste",
    "Perlens": "Perlen",
    "Perleulen": "Perleule",
    "Perlons": "Perlon",
    "Perlweine": "Perlwein",
    "Perlweinen": "Perlwein",
    "Perlweins": "Perlwein",
    "Permafrostbodens": "Permafrostboden",
    "Permafrostböden": "Permafrostboden",
    "Permanente": "permanent",
    "Permanenten": "Permanente",
    "Permutablen": "Permutable",
    "Permutationen": "Permutation",
    "Permutierenden": "Permutierende",
    "Permutierens": "Permutieren",
    "Permutierte": "permutiert",
    "Permutierten": "Permutierte",
    "Peronistischen": "Peronistische",
    "Peronistischeren": "Peronistischere",
    "Peronistischsten": "Peronistischste",
    "Perons": "Peron",
    "Perplexe": "perplex",
    "Perplexen": "Perplexe",
    "Perplexeren": "Perplexere",
    "Perplexesten": "Perplexeste",
    "Persern": "Perser",
    "Persers": "Perser",
    "Persische": "persisch",
    "Persischen": "Persische",
    "Persistenten": "Persistente",
    "Personalen": "Personale",
    "Personalisierenden": "Personalisierende",
    "Personalisierens": "Personalisieren",
    "Personalisierte": "personalisiert",
    "Personalisierten": "Personalisierte",
    "Personalpronomens": "Personalpronomen",
    "Personals": "Personal",
    "Personelle": "personell",
    "Personellen": "Personelle",
    "Personen": "Person",
    "Personifizierenden": "Personifizierende",
    "Personifizierenderen": "Personifizierendere",
    "Personifizierens": "Personifizieren",
    "Personifizierte": "personifiziert",
    "Personifizierten": "Personifizierte",
    "Personifizierteren": "Personifiziertere",
    "Perspektiven": "Perspektive",
    "Perspektivische": "perspektivisch",
    "Perspektivischen": "Perspektivische",
    "Perspektivischeren": "Perspektivischere",
    "Persönchens": "Persönchen",
    "Persönlichen": "Persönliche",
    "Persönlicheren": "Persönlichere",
    "Persönlichkeiten": "Persönlichkeit",
    "Persönlichste": "persönlich",
    "Persönlichsten": "Persönlichste",
    "Peruanischen": "Peruanische",
    "Peruanischeren": "Peruanischere",
    "Peruanischsten": "Peruanischste",
    "Perus": "Peru",
    "Perverse": "pervers",
    "Perversen": "Perverse",
    "Perverseren": "Perversere",
    "Perversesten": "Perverseste",
    "Pervertierenden": "Pervertierende",
    "Pervertierenderen": "Pervertierendere",
    "Pervertierendsten": "Pervertierendste",
    "Pervertierens": "Pervertieren",
    "Pervertierte": "pervertiert",
    "Pervertierten": "Pervertierte",
    "Pervertierteren": "Pervertiertere",
    "Pervertiertesten": "Pervertierteste",
    "Perzeptionen": "Perzeption",
    "Perzeptive": "perzeptiv",
    "Perzeptiven": "Perzeptive",
    "Perücken": "Perücke",
    "Pesags": "Pesag",
    "Pesenden": "Pesende",
    "Pesens": "Pesen",
    "Pessimisten": "Pessimist",
    "Pessimistische": "pessimistisch",
    "Pessimistischen": "Pessimistische",
    "Pessimistischeren": "Pessimistischere",
    "Pessimistischsten": "Pessimistischste",
    "Pestizide": "Pestizid",
    "Pestiziden": "Pestizid",
    "Pestizids": "Pestizid",
    "Peters": "Peter",
    "Petersbergs": "Petersberg",
    "Petersburgs": "Petersburg",
    "Petersilien": "Petersilie",
    "Petitionen": "Petition",
    "Petitionierenden": "Petitionierende",
    "Petitionierens": "Petitionieren",
    "Petitionierte": "petitioniert",
    "Petitionierten": "Petitionierte",
    "Petras": "Petra",
    "Petrijüngern": "Petrijünger",
    "Petrijüngers": "Petrijünger",
    "Petris": "Petri",
    "Petroleums": "Petroleum",
    "Petterweils": "Petterweil",
    "Petunien": "Petunie",
    "Petze": "petzen",
    "Petzen": "Petze",
    "Petzenden": "Petzende",
    "Petzenderen": "Petzendere",
    "Petzendsten": "Petzendste",
    "Petzens": "Petzen",
    "Pfade": "Pfad",
    "Pfaden": "Pfad",
    "Pfades": "Pfad",
    "Pfadfindern": "Pfadfinder",
    "Pfadfinders": "Pfadfinder",
    "Pfads": "Pfad",
    "Pfaffen": "Pfaffe",
    "Pfaffenbrunnenwegs": "Pfaffenbrunnenweg",
    "Pfaffenwiesbachs": "Pfaffenwiesbach",
    "Pfaffs": "Pfaff",
    "Pfahle": "Pfahl",
    "Pfahles": "Pfahl",
    "Pfande": "Pfand",
    "Pfandes": "Pfand",
    "Pfandleihern": "Pfandleiher",
    "Pfandleihers": "Pfandleiher",
    "Pfands": "Pfand",
    "Pfandwertflaschen": "Pfandwertflasche",
    "Pfannen": "Pfanne",
    "Pfannkuchens": "Pfannkuchen",
    "Pfarramte": "Pfarramt",
    "Pfarramtes": "Pfarramt",
    "Pfarramts": "Pfarramt",
    "Pfarreien": "Pfarrei",
    "Pfarrern": "Pfarrer",
    "Pfarrers": "Pfarrer",
    "Pfarrfeste": "Pfarrfest",
    "Pfarrfesten": "Pfarrfest",
    "Pfarrfestes": "Pfarrfest",
    "Pfarrfests": "Pfarrfest",
    "Pfarrliche": "pfarrlich",
    "Pfarrlichen": "Pfarrliche",
    "Pfarrämter": "Pfarramt",
    "Pfarrämtern": "Pfarramt",
    "Pfaue": "Pfau",
    "Pfauen": "Pfau",
    "Pfaus": "Pfau",
    "Pfeffer": "pfeffern",
    "Pfeffernden": "Pfeffernde",
    "Pfeffernderen": "Pfefferndere",
    "Pfefferndsten": "Pfefferndste",
    "Pfefferns": "Pfeffern",
    "Pfeffers": "Pfeffer",
    "Pfeifen": "Pfeife",
    "Pfeifenden": "Pfeifende",
    "Pfeifens": "Pfeifen",
    "Pfeifern": "Pfeifer",
    "Pfeifers": "Pfeifer",
    "Pfeifgeräusche": "Pfeifgeräusch",
    "Pfeifgeräuschen": "Pfeifgeräusch",
    "Pfeifgeräuschs": "Pfeifgeräusch",
    "Pfeifkonzerte": "Pfeifkonzert",
    "Pfeifkonzerten": "Pfeifkonzert",
    "Pfeifkonzerts": "Pfeifkonzert",
    "Pfeile": "Pfeil",
    "Pfeilen": "Pfeil",
    "Pfeilern": "Pfeiler",
    "Pfeilers": "Pfeiler",
    "Pfeils": "Pfeil",
    "Pfeilschnelle": "pfeilschnell",
    "Pfeilschnellen": "Pfeilschnelle",
    "Pfennige": "Pfennig",
    "Pfennigen": "Pfennig",
    "Pfennigs": "Pfennig",
    "Pferchenden": "Pferchende",
    "Pferchenderen": "Pferchendere",
    "Pferchendsten": "Pferchendste",
    "Pferchens": "Pferchen",
    "Pferdchens": "Pferdchen",
    "Pferde": "Pferd",
    "Pferden": "Pferd",
    "Pferdes": "Pferd",
    "Pferdestärken": "Pferdestärke",
    "Pferds": "Pferd",
    "Pfiffigen": "Pfiffige",
    "Pfiffigeren": "Pfiffigere",
    "Pfiffigsten": "Pfiffigste",
    "Pfingstfeste": "Pfingstfest",
    "Pfingstfesten": "Pfingstfest",
    "Pfingstfests": "Pfingstfest",
    "Pfingstliche": "pfingstlich",
    "Pfingstlichen": "Pfingstliche",
    "Pfirsiche": "Pfirsich",
    "Pfirsichen": "Pfirsich",
    "Pfirsichs": "Pfirsich",
    "Pflanze": "pflanzen",
    "Pflanzen": "Pflanze",
    "Pflanzenden": "Pflanzende",
    "Pflanzens": "Pflanzen",
    "Pflanzern": "Pflanzer",
    "Pflanzers": "Pflanzer",
    "Pflanzgeländen": "Pflanzgelände",
    "Pflanzgeländes": "Pflanzgelände",
    "Pflanzliche": "pflanzlich",
    "Pflanzlichen": "Pflanzliche",
    "Pflanzungen": "Pflanzung",
    "Pflastern": "Pflaster",
    "Pflasters": "Pflaster",
    "Pflaume": "pflaumen",
    "Pflaumen": "Pflaume",
    "Pflaumenden": "Pflaumende",
    "Pflaumenderen": "Pflaumendere",
    "Pflaumendsten": "Pflaumendste",
    "Pflaumens": "Pflaumen",
    "Pflegebedürftige": "pflegebedürftig",
    "Pflegebedürftigen": "Pflegebedürftige",
    "Pflegebedürftigeren": "Pflegebedürftigere",
    "Pflegeleichten": "Pflegeleichte",
    "Pflegen": "Pflege",
    "Pflegenden": "Pflegende",
    "Pflegenderen": "Pflegendere",
    "Pflegendsten": "Pflegendste",
    "Pflegens": "Pflegen",
    "Pflegerinnen": "Pflegerin",
    "Pflegerische": "pflegerisch",
    "Pflegerischen": "Pflegerische",
    "Pflegern": "Pfleger",
    "Pflegers": "Pfleger",
    "Pfleglichen": "Pflegliche",
    "Pflichtbewußten": "Pflichtbewußte",
    "Pflichtbewußteren": "Pflichtbewußtere",
    "Pflichten": "Pflicht",
    "Pflichtenden": "Pflichtende",
    "Pflichtens": "Pflichten",
    "Pflichtfache": "Pflichtfach",
    "Pflichtfaches": "Pflichtfach",
    "Pflichtfachs": "Pflichtfach",
    "Pflichtfächer": "Pflichtfach",
    "Pflichtfächern": "Pflichtfach",
    "Pflichtgemäße": "pflichtgemäß",
    "Pflichtgemäßen": "Pflichtgemäße",
    "Pflichtigen": "Pflichtige",
    "Pfluge": "Pflug",
    "Pfluges": "Pflug",
    "Pflugs": "Pflug",
    "Pflänzlinge": "Pflänzling",
    "Pflänzlingen": "Pflänzling",
    "Pflänzlings": "Pflänzling",
    "Pflästerchens": "Pflästerchen",
    "Pfläumchens": "Pfläumchen",
    "Pflückenden": "Pflückende",
    "Pflückens": "Pflücken",
    "Pflüge": "pflügen",
    "Pflügen": "Pflug",
    "Pflügenden": "Pflügende",
    "Pflügens": "Pflügen",
    "Pforten": "Pforte",
    "Pfostens": "Pfosten",
    "Pfoten": "Pfote",
    "Pfropfenden": "Pfropfende",
    "Pfropfens": "Pfropfen",
    "Pfunde": "Pfund",
    "Pfunden": "Pfund",
    "Pfundes": "Pfund",
    "Pfundige": "pfundig",
    "Pfundigen": "Pfundige",
    "Pfundigeren": "Pfundigere",
    "Pfundigsten": "Pfundigste",
    "Pfunds": "Pfund",
    "Pfungstadts": "Pfungstadt",
    "Pfusch": "pfuschen",
    "Pfusche": "pfuschen",
    "Pfuschenden": "Pfuschende",
    "Pfuschenderen": "Pfuschendere",
    "Pfuschendsten": "Pfuschendste",
    "Pfuschens": "Pfuschen",
    "Pfusches": "Pfusch",
    "Pfuschs": "Pfusch",
    "Pfähle": "Pfahl",
    "Pfählen": "Pfahl",
    "Pfälzern": "Pfälzer",
    "Pfälzers": "Pfälzer",
    "Pfälzerwalds": "Pfälzerwald",
    "Pfälzische": "pfälzisch",
    "Pfälzischen": "Pfälzische",
    "Pfändbaren": "Pfändbare",
    "Pfändenden": "Pfändende",
    "Pfändens": "Pfänden",
    "Pfänder": "Pfand",
    "Pfändern": "Pfand",
    "Pfändungen": "Pfändung",
    "Pfännleins": "Pfännlein",
    "Pfötchens": "Pfötchen",
    "Pfündchens": "Pfündchen",
    "Pfützchens": "Pfützchen",
    "Pfützen": "Pfütze",
    "Phantasielose": "phantasielos",
    "Phantasielosen": "Phantasielose",
    "Phantasieloseren": "Phantasielosere",
    "Phantasielosesten": "Phantasieloseste",
    "Phantasien": "Phantasie",
    "Phantasierenden": "Phantasierende",
    "Phantasierenderen": "Phantasierendere",
    "Phantasierendsten": "Phantasierendste",
    "Phantasierens": "Phantasieren",
    "Phantasierte": "phantasiert",
    "Phantasierten": "Phantasierte",
    "Phantasierteren": "Phantasiertere",
    "Phantasiertesten": "Phantasierteste",
    "Phantasievollen": "Phantasievolle",
    "Phantasievolleren": "Phantasievollere",
    "Phantasievollsten": "Phantasievollste",
    "Phantasten": "Phantast",
    "Phantastereien": "Phantasterei",
    "Phantastische": "phantastisch",
    "Phantastischen": "Phantastische",
    "Phantastischeren": "Phantastischere",
    "Phantastischsten": "Phantastischste",
    "Phantome": "Phantom",
    "Phantomen": "Phantom",
    "Phantomes": "Phantom",
    "Phantoms": "Phantom",
    "Pharisäern": "Pharisäer",
    "Pharisäers": "Pharisäer",
    "Pharisäische": "pharisäisch",
    "Pharisäischen": "Pharisäische",
    "Pharmakeulen": "Pharmakeule",
    "Pharmazeuten": "Pharmazeut",
    "Pharmazeutische": "pharmazeutisch",
    "Pharmazeutischen": "Pharmazeutische",
    "Phasen": "Phase",
    "Phenole": "Phenol",
    "Phenolen": "Phenol",
    "Phenols": "Phenol",
    "Philharmonien": "Philharmonie",
    "Philharmonikern": "Philharmoniker",
    "Philharmonikers": "Philharmoniker",
    "Philipps": "Philipp",
    "Philips": "Philip",
    "Philistern": "Philister",
    "Philisters": "Philister",
    "Phillipsruhern": "Phillipsruher",
    "Phillipsruhers": "Phillipsruher",
    "Philologen": "Philologe",
    "Philologische": "philologisch",
    "Philologischen": "Philologische",
    "Philosophastern": "Philosophaster",
    "Philosophasters": "Philosophaster",
    "Philosophen": "Philosoph",
    "Philosophien": "Philosophie",
    "Philosophierenden": "Philosophierende",
    "Philosophierenderen": "Philosophierendere",
    "Philosophierens": "Philosophieren",
    "Philosophierte": "philosophiert",
    "Philosophierten": "Philosophierte",
    "Philosophischen": "Philosophische",
    "Philosophischeren": "Philosophischere",
    "Philosophischsten": "Philosophischste",
    "Phlegmatischen": "Phlegmatische",
    "Phobien": "Phobie",
    "Phoneme": "Phonem",
    "Phonemen": "Phonem",
    "Phonems": "Phonem",
    "Phonetikern": "Phonetiker",
    "Phonetikers": "Phonetiker",
    "Phonetische": "phonetisch",
    "Phonetischen": "Phonetische",
    "Phonogeräte": "Phonogerät",
    "Phonogeräten": "Phonogerät",
    "Phonogeräts": "Phonogerät",
    "Phonogramme": "Phonogramm",
    "Phonogrammen": "Phonogramm",
    "Phonogramms": "Phonogramm",
    "Phonographien": "Phonographie",
    "Phonokoffern": "Phonokoffer",
    "Phonokoffers": "Phonokoffer",
    "Phonolithen": "Phonolith",
    "Phonologische": "phonologisch",
    "Phonologischen": "Phonologische",
    "Phonometern": "Phonometer",
    "Phonometers": "Phonometer",
    "Phonotheken": "Phonothek",
    "Phonotypistinnen": "Phonotypistin",
    "Phosphors": "Phosphor",
    "Photodioden": "Photodiode",
    "Photographierenden": "Photographierende",
    "Photographierens": "Photographieren",
    "Photographierte": "photographiert",
    "Photographierten": "Photographierte",
    "Photographierteren": "Photographiertere",
    "Photone": "Photon",
    "Photonen": "Photon",
    "Photons": "Photon",
    "Photos": "Photo",
    "Phototherapien": "Phototherapie",
    "Photozellen": "Photozelle",
    "Phrasen": "Phrase",
    "Phrasendreschern": "Phrasendrescher",
    "Phrasendreschers": "Phrasendrescher",
    "Phrasenhafte": "phrasenhaft",
    "Phrasenhaften": "Phrasenhafte",
    "Phrasenhafteren": "Phrasenhaftere",
    "Phrasenhaftesten": "Phrasenhafteste",
    "Phrasierungen": "Phrasierung",
    "Phrenetische": "phrenetisch",
    "Phrenetischen": "Phrenetische",
    "Phrenetischeren": "Phrenetischere",
    "Phrenetischsten": "Phrenetischste",
    "Physikalischen": "Physikalische",
    "Physikern": "Physiker",
    "Physikers": "Physiker",
    "Physikums": "Physikum",
    "Physiographien": "Physiographie",
    "Physiologische": "physiologisch",
    "Physiologischen": "Physiologische",
    "Physiotherapien": "Physiotherapie",
    "Physische": "physisch",
    "Physischen": "Physische",
    "Phytolithen": "Phytolith",
    "Phytoplanktons": "Phytoplankton",
    "Phänologische": "phänologisch",
    "Phänologischen": "Phänologische",
    "Phänomenalen": "Phänomenale",
    "Phänomenaleren": "Phänomenalere",
    "Phänomenalsten": "Phänomenalste",
    "Phänomene": "Phänomen",
    "Phänomenen": "Phänomen",
    "Phänomenes": "Phänomen",
    "Phänomenologische": "phänomenologisch",
    "Phänomenologischen": "Phänomenologische",
    "Phänomens": "Phänomen",
    "Piaffen": "Piaffe",
    "Pianisten": "Pianist",
    "Pianos": "Piano",
    "Pichelnden": "Pichelnde",
    "Pichelnderen": "Pichelndere",
    "Pichelndsten": "Pichelndste",
    "Pichelns": "Picheln",
    "Pickeln": "Pickel",
    "Pickels": "Pickel",
    "Pickenden": "Pickende",
    "Pickens": "Picken",
    "Picknicks": "Picknick",
    "Piefkes": "Piefke",
    "Piekfeine": "piekfein",
    "Piekfeinen": "Piekfeine",
    "Piep": "piepen",
    "Piependen": "Piepende",
    "Piependeren": "Piependere",
    "Piependsten": "Piependste",
    "Piepens": "Piepen",
    "Piepern": "Pieper",
    "Piepers": "Pieper",
    "Pieps": "piepsen",
    "Piepsenden": "Piepsende",
    "Piepsenderen": "Piepsendere",
    "Piepsendsten": "Piepsendste",
    "Piepsens": "Piepsen",
    "Piepsern": "Piepser",
    "Piepsers": "Piepser",
    "Piepsigen": "Piepsige",
    "Piepsigeren": "Piepsigere",
    "Piepsigsten": "Piepsigste",
    "Piere": "Pier",
    "Pieren": "Pier",
    "Pieroths": "Pieroth",
    "Pierres": "Pierre",
    "Piers": "Pier",
    "Pieselnden": "Pieselnde",
    "Pieselnderen": "Pieselndere",
    "Pieselndsten": "Pieselndste",
    "Pieselns": "Pieseln",
    "Pigmente": "Pigment",
    "Pigmenten": "Pigment",
    "Pigmentierenden": "Pigmentierende",
    "Pigmentierenderen": "Pigmentierendere",
    "Pigmentierendsten": "Pigmentierendste",
    "Pigmentierens": "Pigmentieren",
    "Pigmentierte": "pigmentiert",
    "Pigmentierten": "Pigmentierte",
    "Pigmentierteren": "Pigmentiertere",
    "Pigmentiertesten": "Pigmentierteste",
    "Pigments": "Pigment",
    "Pikante": "pikant",
    "Pikanten": "Pikante",
    "Pikanteren": "Pikantere",
    "Pikanterien": "Pikanterie",
    "Pikantesten": "Pikanteste",
    "Piken": "Pike",
    "Pikkolos": "Pikkolo",
    "Piktografien": "Piktografie",
    "Piktogramme": "Piktogramm",
    "Piktogrammen": "Piktogramm",
    "Piktogramms": "Piktogramm",
    "Piktographien": "Piktographie",
    "Pilastern": "Pilaster",
    "Pilasters": "Pilaster",
    "Pilger": "pilgern",
    "Pilgern": "Pilger",
    "Pilgernden": "Pilgernde",
    "Pilgerns": "Pilgern",
    "Pilgers": "Pilger",
    "Pillen": "Pille",
    "Pilotanlagen": "Pilotanlage",
    "Piloten": "Pilot",
    "Pilotinnen": "Pilotin",
    "Pilotsendungen": "Pilotsendung",
    "Pilze": "Pilz",
    "Pilzen": "Pilz",
    "Pilzes": "Pilz",
    "Pimente": "Piment",
    "Pimenten": "Piment",
    "Pimentes": "Piment",
    "Piments": "Piment",
    "Pimmeln": "Pimmel",
    "Pimmels": "Pimmel",
    "Pimpfe": "Pimpf",
    "Pimpfen": "Pimpf",
    "Pimpfes": "Pimpf",
    "Pimpfs": "Pimpf",
    "Pingelige": "pingelig",
    "Pingeligen": "Pingelige",
    "Pingeligeren": "Pingeligere",
    "Pingeligsten": "Pingeligste",
    "Pinguine": "Pinguin",
    "Pinguinen": "Pinguin",
    "Pinguines": "Pinguin",
    "Pinguins": "Pinguin",
    "Pinien": "Pinie",
    "Pinkel": "pinkeln",
    "Pinkeln": "Pinkel",
    "Pinkelnden": "Pinkelnde",
    "Pinkelnderen": "Pinkelndere",
    "Pinkelndsten": "Pinkelndste",
    "Pinkelns": "Pinkeln",
    "Pinkels": "Pinkel",
    "Pinnenden": "Pinnende",
    "Pinnens": "Pinnen",
    "Pinnwände": "Pinnwand",
    "Pinnwänden": "Pinnwand",
    "Pinsel": "pinseln",
    "Pinseln": "Pinsel",
    "Pinselnden": "Pinselnde",
    "Pinselnderen": "Pinselndere",
    "Pinselndsten": "Pinselndste",
    "Pinselns": "Pinseln",
    "Pinsels": "Pinsel",
    "Pinten": "Pinte",
    "Pioniere": "Pionier",
    "Pionieren": "Pionier",
    "Pioniers": "Pionier",
    "Pipelines": "Pipeline",
    "Pipetten": "Pipette",
    "Piraten": "Pirat",
    "Piraterien": "Piraterie",
    "Pirouetten": "Pirouette",
    "Pirsch": "pirschen",
    "Pirschenden": "Pirschende",
    "Pirschens": "Pirschen",
    "Pis": "Pi",
    "Pissenden": "Pissende",
    "Pissenderen": "Pissendere",
    "Pissendsten": "Pissendste",
    "Pissens": "Pissen",
    "Pisten": "Piste",
    "Pistolen": "Pistole",
    "Pixeln": "Pixel",
    "Pixels": "Pixel",
    "Pizzas": "Pizza",
    "Pizzen": "Pizza",
    "Pkws": "Pkw",
    "Placebos": "Placebo",
    "Plage": "plagen",
    "Plagen": "Plage",
    "Plagenden": "Plagende",
    "Plagenderen": "Plagendere",
    "Plagendsten": "Plagendste",
    "Plagens": "Plagen",
    "Plagiate": "Plagiat",
    "Plagiaten": "Plagiat",
    "Plagiats": "Plagiat",
    "Plakate": "Plakat",
    "Plakaten": "Plakat",
    "Plakates": "Plakat",
    "Plakatierenden": "Plakatierende",
    "Plakatierenderen": "Plakatierendere",
    "Plakatierendsten": "Plakatierendste",
    "Plakatierens": "Plakatieren",
    "Plakatierte": "plakatiert",
    "Plakatierten": "Plakatierte",
    "Plakatierteren": "Plakatiertere",
    "Plakatiertesten": "Plakatierteste",
    "Plakativen": "Plakative",
    "Plakativeren": "Plakativere",
    "Plakativsten": "Plakativste",
    "Plakats": "Plakat",
    "Plaketten": "Plakette",
    "Plan": "planen",
    "Plancks": "Planck",
    "Plane": "planen",
    "Planen": "Plane",
    "Planenden": "Planende",
    "Planenderen": "Planendere",
    "Planendsten": "Planendste",
    "Planens": "Planen",
    "Planern": "Planer",
    "Planers": "Planer",
    "Planes": "Plan",
    "Planetarische": "planetarisch",
    "Planetarischen": "Planetarische",
    "Planeten": "Planet",
    "Planetoiden": "Planetoid",
    "Plangemäße": "plangemäß",
    "Plangemäßen": "Plangemäße",
    "Planierbänke": "Planierbank",
    "Planierbänken": "Planierbank",
    "Planierenden": "Planierende",
    "Planierenderen": "Planierendere",
    "Planierendsten": "Planierendste",
    "Planierens": "Planieren",
    "Planierraupen": "Planierraupe",
    "Planierte": "planiert",
    "Planierten": "Planierte",
    "Planierteren": "Planiertere",
    "Planiertesten": "Planierteste",
    "Planken": "Planke",
    "Planktons": "Plankton",
    "Planlose": "planlos",
    "Planlosen": "Planlose",
    "Planloseren": "Planlosere",
    "Planlosesten": "Planloseste",
    "Planmäßigen": "Planmäßige",
    "Planmäßigeren": "Planmäßigere",
    "Planmäßigsten": "Planmäßigste",
    "Plans": "Plan",
    "Planschenden": "Planschende",
    "Planschenderen": "Planschendere",
    "Planschendsten": "Planschendste",
    "Planschens": "Planschen",
    "Plantagen": "Plantage",
    "Planungen": "Planung",
    "Planvolle": "planvoll",
    "Planvollen": "Planvolle",
    "Planvolleren": "Planvollere",
    "Planvollsten": "Planvollste",
    "Planwagens": "Planwagen",
    "Plappernden": "Plappernde",
    "Plappernderen": "Plapperndere",
    "Plapperndsten": "Plapperndste",
    "Plapperns": "Plappern",
    "Plappertaschen": "Plappertasche",
    "Plasmatischen": "Plasmatische",
    "Plasten": "Plaste",
    "Plastiks": "Plastik",
    "Plastische": "plastisch",
    "Plastischen": "Plastische",
    "Plastischeren": "Plastischere",
    "Plastischsten": "Plastischste",
    "Plateaus": "Plateau",
    "Platinblonde": "platinblond",
    "Platinblonden": "Platinblonde",
    "Platonischen": "Platonische",
    "Platschenden": "Platschende",
    "Platschenderen": "Platschendere",
    "Platschendsten": "Platschendste",
    "Platschens": "Platschen",
    "Plattdeutschen": "Plattdeutsche",
    "Platten": "Platte",
    "Plattenspielern": "Plattenspieler",
    "Plattenspielers": "Plattenspieler",
    "Platterbsen": "Platterbse",
    "Plattere": "platt",
    "Platteren": "Plattere",
    "Plattesten": "Platteste",
    "Plattformen": "Plattform",
    "Plattfuße": "Plattfuß",
    "Plattfußes": "Plattfuß",
    "Plattfüße": "Plattfuß",
    "Plattfüßen": "Plattfuß",
    "Plattfüßige": "plattfüßig",
    "Plattfüßigen": "Plattfüßige",
    "Plattfüßigeren": "Plattfüßigere",
    "Plattfüßigsten": "Plattfüßigste",
    "Plattheiten": "Plattheit",
    "Plattitüden": "Plattitüde",
    "Plattwurme": "Plattwurm",
    "Plattwurmes": "Plattwurm",
    "Plattwurms": "Plattwurm",
    "Plattwürmer": "Plattwurm",
    "Plattwürmern": "Plattwurm",
    "Platz": "platzen",
    "Platze": "platzen",
    "Platzenden": "Platzende",
    "Platzenderen": "Platzendere",
    "Platzendsten": "Platzendste",
    "Platzens": "Platzen",
    "Platzes": "Platz",
    "Platzierungen": "Platzierung",
    "Platzwetten": "Platzwette",
    "Plaudereien": "Plauderei",
    "Plauderern": "Plauderer",
    "Plauderers": "Plauderer",
    "Plaudernden": "Plaudernde",
    "Plaudernderen": "Plauderndere",
    "Plauderndsten": "Plauderndste",
    "Plauderns": "Plaudern",
    "Plaudertaschen": "Plaudertasche",
    "Plausch": "plauschen",
    "Plausche": "plauschen",
    "Plauschen": "Plausch",
    "Plauschenden": "Plauschende",
    "Plauschenderen": "Plauschendere",
    "Plauschendsten": "Plauschendste",
    "Plauschens": "Plauschen",
    "Plausches": "Plausch",
    "Plauschs": "Plausch",
    "Plausibelsten": "Plausibelste",
    "Plausibilitäten": "Plausibilität",
    "Plausible": "plausibel",
    "Plausiblen": "Plausible",
    "Plausibleren": "Plausiblere",
    "Plauzen": "Plauze",
    "Playboys": "Playboy",
    "Plazas": "Plaza",
    "Plazentale": "plazental",
    "Plazentalen": "Plazentale",
    "Plazets": "Plazet",
    "Plazierenden": "Plazierende",
    "Plazierens": "Plazieren",
    "Plazierte": "plaziert",
    "Plazierten": "Plazierte",
    "Plazierungen": "Plazierung",
    "Plebejern": "Plebejer",
    "Plebejers": "Plebejer",
    "Pleiten": "Pleite",
    "Plempernden": "Plempernde",
    "Plempernderen": "Plemperndere",
    "Plemperndsten": "Plemperndste",
    "Plemperns": "Plempern",
    "Plenums": "Plenum",
    "Plissees": "Plissee",
    "Plomben": "Plombe",
    "Plombierenden": "Plombierende",
    "Plombierenderen": "Plombierendere",
    "Plombierendsten": "Plombierendste",
    "Plombierens": "Plombieren",
    "Plombierte": "plombiert",
    "Plombierten": "Plombierte",
    "Plombierteren": "Plombiertere",
    "Plombiertesten": "Plombierteste",
    "Plottenden": "Plottende",
    "Plottens": "Plotten",
    "Plottern": "Plotter",
    "Plotters": "Plotter",
    "Pluderhosen": "Pluderhose",
    "Pluderige": "pluderig",
    "Pluderigen": "Pluderige",
    "Pluderigeren": "Pluderigere",
    "Pluderigsten": "Pluderigste",
    "Plumpen": "Plumpe",
    "Plumperen": "Plumpere",
    "Plumpesten": "Plumpeste",
    "Plumpsenden": "Plumpsende",
    "Plumpsens": "Plumpsen",
    "Plumpsklos": "Plumpsklo",
    "Plunders": "Plunder",
    "Plunzen": "Plunze",
    "Plurale": "Plural",
    "Pluralen": "Plural",
    "Plurals": "Plural",
    "Pluspole": "Pluspol",
    "Pluspolen": "Pluspol",
    "Pluspols": "Pluspol",
    "Plusquamperfekte": "Plusquamperfekt",
    "Plusquamperfekten": "Plusquamperfekt",
    "Plusquamperfekts": "Plusquamperfekt",
    "Plusternden": "Plusternde",
    "Plusterns": "Plustern",
    "Plutonischen": "Plutonische",
    "Plutoniums": "Plutonium",
    "Plädierenden": "Plädierende",
    "Plädierens": "Plädieren",
    "Plädierte": "plädiert",
    "Plädierten": "Plädierte",
    "Plädoyers": "Plädoyer",
    "Pläne": "Plan",
    "Plänen": "Plan",
    "Plänkeleien": "Plänkelei",
    "Plätschernden": "Plätschernde",
    "Plätschernderen": "Plätscherndere",
    "Plätscherndsten": "Plätscherndste",
    "Plätscherns": "Plätschern",
    "Plättenden": "Plättende",
    "Plättenderen": "Plättendere",
    "Plättendsten": "Plättendste",
    "Plättens": "Plätten",
    "Plättereien": "Plätterei",
    "Plätzchens": "Plätzchen",
    "Plätze": "Platz",
    "Plätzen": "Platz",
    "Plörren": "Plörre",
    "Plötzlichen": "Plötzliche",
    "Plötzlicheren": "Plötzlichere",
    "Plötzlichsten": "Plötzlichste",
    "Plünderern": "Plünderer",
    "Plünderers": "Plünderer",
    "Plündernden": "Plündernde",
    "Plündernderen": "Plünderndere",
    "Plünderndsten": "Plünderndste",
    "Plünderns": "Plündern",
    "Plünderungen": "Plünderung",
    "Plüsche": "Plüsch",
    "Plüschen": "Plüsch",
    "Plüschs": "Plüsch",
    "Pneumas": "Pneuma",
    "Pneumatische": "pneumatisch",
    "Pneumatischen": "Pneumatische",
    "Pneumatometern": "Pneumatometer",
    "Pneumatometers": "Pneumatometer",
    "Pochenden": "Pochende",
    "Pochens": "Pochen",
    "Podeste": "Podest",
    "Podesten": "Podest",
    "Podests": "Podest",
    "Podien": "Podium",
    "Podiums": "Podium",
    "Poeten": "Poet",
    "Poetische": "poetisch",
    "Poetischen": "Poetische",
    "Poetischeren": "Poetischere",
    "Poetischsten": "Poetischste",
    "Poetisierenden": "Poetisierende",
    "Poetisierenderen": "Poetisierendere",
    "Poetisierendsten": "Poetisierendste",
    "Poetisierens": "Poetisieren",
    "Poetisierte": "poetisiert",
    "Poetisierten": "Poetisierte",
    "Poetisierteren": "Poetisiertere",
    "Poetisiertesten": "Poetisierteste",
    "Pohls": "Pohl",
    "Pointen": "Pointe",
    "Pokale": "Pokal",
    "Pokalen": "Pokal",
    "Pokales": "Pokal",
    "Pokals": "Pokal",
    "Pokernden": "Pokernde",
    "Pokernderen": "Pokerndere",
    "Pokerndsten": "Pokerndste",
    "Pokerns": "Pokern",
    "Pol": "polen",
    "Polare": "polar",
    "Polaren": "Polare",
    "Polarexpeditionen": "Polarexpedition",
    "Polarforschern": "Polarforscher",
    "Polarforschers": "Polarforscher",
    "Polarfronten": "Polarfront",
    "Polarisationen": "Polarisation",
    "Polarisierenden": "Polarisierende",
    "Polarisierenderen": "Polarisierendere",
    "Polarisierendsten": "Polarisierendste",
    "Polarisierens": "Polarisieren",
    "Polarisierte": "polarisiert",
    "Polarisierten": "Polarisierte",
    "Polarisierteren": "Polarisiertere",
    "Polarisiertesten": "Polarisierteste",
    "Polarisierungen": "Polarisierung",
    "Polarlichte": "Polarlicht",
    "Polarlichter": "Polarlicht",
    "Polarlichtern": "Polarlicht",
    "Polarlichtes": "Polarlicht",
    "Polarlichts": "Polarlicht",
    "Polarnächte": "Polarnacht",
    "Polarnächten": "Polarnacht",
    "Polarzonen": "Polarzone",
    "Pole": "polen",
    "Polemiken": "Polemik",
    "Polemikern": "Polemiker",
    "Polemikers": "Polemiker",
    "Polemische": "polemisch",
    "Polemischen": "Polemische",
    "Polemischeren": "Polemischere",
    "Polemischsten": "Polemischste",
    "Polemisierenden": "Polemisierende",
    "Polemisierenderen": "Polemisierendere",
    "Polemisierendsten": "Polemisierendste",
    "Polemisierens": "Polemisieren",
    "Polemisierte": "polemisiert",
    "Polemisierten": "Polemisierte",
    "Polemisierteren": "Polemisiertere",
    "Polemisiertesten": "Polemisierteste",
    "Polen": "Pol",
    "Polenden": "Polende",
    "Polens": "Polen",
    "Poles": "Pol",
    "Policen": "Police",
    "Polier": "polieren",
    "Poliere": "polieren",
    "Polieren": "Polier",
    "Polierenden": "Polierende",
    "Polierenderen": "Polierendere",
    "Polierendsten": "Polierendste",
    "Polierens": "Polieren",
    "Polieres": "Polier",
    "Poliers": "Polier",
    "Polierte": "poliert",
    "Polierten": "Polierte",
    "Polierteren": "Poliertere",
    "Poliertesten": "Polierteste",
    "Polikliniken": "Poliklinik",
    "Polinnen": "Polin",
    "Politbüros": "Politbüro",
    "Politikerinnen": "Politikerin",
    "Politikern": "Politiker",
    "Politikers": "Politiker",
    "Politische": "politisch",
    "Politischen": "Politische",
    "Politischeren": "Politischere",
    "Politischsten": "Politischste",
    "Politisierenden": "Politisierende",
    "Politisierenderen": "Politisierendere",
    "Politisierendsten": "Politisierendste",
    "Politisierens": "Politisieren",
    "Politisierte": "politisiert",
    "Politisierten": "Politisierte",
    "Politisierteren": "Politisiertere",
    "Politisiertesten": "Politisierteste",
    "Politologen": "Politologe",
    "Politologische": "politologisch",
    "Politologischen": "Politologische",
    "Polituren": "Politur",
    "Polivalente": "polivalent",
    "Polivalenten": "Polivalente",
    "Polivalenteren": "Polivalentere",
    "Polivalentesten": "Polivalenteste",
    "Polizeilichen": "Polizeiliche",
    "Polizeiwidrigen": "Polizeiwidrige",
    "Polizisten": "Polizist",
    "Polizistinnen": "Polizistin",
    "Polkas": "Polka",
    "Pollens": "Pollen",
    "Pollern": "Poller",
    "Pollers": "Poller",
    "Polnische": "polnisch",
    "Polnischen": "Polnische",
    "Polnischeren": "Polnischere",
    "Polnischsten": "Polnischste",
    "Polonaisen": "Polonaise",
    "Poloniums": "Polonium",
    "Polos": "Polo",
    "Pols": "Pol",
    "Polster": "polstern",
    "Polsterern": "Polsterer",
    "Polsterers": "Polsterer",
    "Polstern": "Polster",
    "Polsternden": "Polsternde",
    "Polsternderen": "Polsterndere",
    "Polsterndsten": "Polsterndste",
    "Polsterns": "Polstern",
    "Polsters": "Polster",
    "Polternden": "Polternde",
    "Polternderen": "Polterndere",
    "Polterndsten": "Polterndste",
    "Polterns": "Poltern",
    "Polygamen": "Polygame",
    "Polygonalen": "Polygonale",
    "Polygraphischen": "Polygraphische",
    "Polymorphen": "Polymorphe",
    "Polynome": "Polynom",
    "Polynomen": "Polynom",
    "Polynomische": "polynomisch",
    "Polynomischen": "Polynomische",
    "Polynoms": "Polynom",
    "Polypen": "Polyp",
    "Polyphone": "polyphon",
    "Polyphonen": "Polyphone",
    "Polypole": "Polypol",
    "Polypolen": "Polypol",
    "Polypols": "Polypol",
    "Polytechnische": "polytechnisch",
    "Polytechnischen": "Polytechnische",
    "Pomaden": "Pomade",
    "Pomadige": "pomadig",
    "Pomadigen": "Pomadige",
    "Pomadigeren": "Pomadigere",
    "Pomadigsten": "Pomadigste",
    "Pomeranzen": "Pomeranze",
    "Pompöse": "pompös",
    "Pompösen": "Pompöse",
    "Pompöseren": "Pompösere",
    "Pompösesten": "Pompöseste",
    "Ponchos": "Poncho",
    "Pontifikalamte": "Pontifikalamt",
    "Pontifikalamtes": "Pontifikalamt",
    "Pontifikalamts": "Pontifikalamt",
    "Pontifikalämter": "Pontifikalamt",
    "Pontifikalämtern": "Pontifikalamt",
    "Pontifikate": "Pontifikat",
    "Pontifikaten": "Pontifikat",
    "Pontifikats": "Pontifikat",
    "Ponys": "Pony",
    "Popel": "popeln",
    "Popeligen": "Popelige",
    "Popeligeren": "Popeligere",
    "Popeligsten": "Popeligste",
    "Popeln": "Popel",
    "Popelnden": "Popelnde",
    "Popelnderen": "Popelndere",
    "Popelndsten": "Popelndste",
    "Popelns": "Popeln",
    "Popels": "Popel",
    "Popligen": "Poplige",
    "Popligeren": "Popligere",
    "Popligsten": "Popligste",
    "Popos": "Popo",
    "Poppenden": "Poppende",
    "Poppens": "Poppen",
    "Poppigen": "Poppige",
    "Poppigeren": "Poppigere",
    "Poppigsten": "Poppigste",
    "Pops": "Pop",
    "Popularisierenden": "Popularisierende",
    "Popularisierenderen": "Popularisierendere",
    "Popularisierens": "Popularisieren",
    "Popularisierte": "popularisiert",
    "Popularisierten": "Popularisierte",
    "Popularisierteren": "Popularisiertere",
    "Popularisierteste": "popularisiert",
    "Popularitäten": "Popularität",
    "Populationen": "Population",
    "Populäre": "populär",
    "Populären": "Populäre",
    "Populäreren": "Populärere",
    "Populärkulturen": "Populärkultur",
    "Populärste": "populär",
    "Populärsten": "Populärste",
    "Poren": "Pore",
    "Porige": "porig",
    "Porigen": "Porige",
    "Porigeren": "Porigere",
    "Porigsten": "Porigste",
    "Pornofilme": "Pornofilm",
    "Pornofilmen": "Pornofilm",
    "Pornofilms": "Pornofilm",
    "Pornographen": "Pornograph",
    "Pornographische": "pornographisch",
    "Pornographischen": "Pornographische",
    "Pornos": "Porno",
    "Porrees": "Porree",
    "Portale": "Portal",
    "Portalen": "Portal",
    "Portales": "Portal",
    "Portals": "Portal",
    "Portemonnaies": "Portemonnaie",
    "Portierenden": "Portierende",
    "Portierens": "Portieren",
    "Portierte": "portiert",
    "Portierten": "Portierte",
    "Portionen": "Portion",
    "Portionierenden": "Portionierende",
    "Portionierens": "Portionieren",
    "Portionierte": "portioniert",
    "Portionierten": "Portionierte",
    "Portofreien": "Portofreie",
    "Portos": "Porto",
    "Portraits": "Portrait",
    "Porträtierenden": "Porträtierende",
    "Porträtierens": "Porträtieren",
    "Porträtierte": "porträtiert",
    "Porträtierten": "Porträtierte",
    "Porträts": "Porträt",
    "Portugals": "Portugal",
    "Portugiesische": "portugiesisch",
    "Portugiesischen": "Portugiesische",
    "Portugiesischeren": "Portugiesischere",
    "Portugiesischsten": "Portugiesischste",
    "Porzellans": "Porzellan",
    "Poröse": "porös",
    "Porösen": "Poröse",
    "Poröseren": "Porösere",
    "Porösesten": "Poröseste",
    "Pos": "Po",
    "Posaune": "posaunen",
    "Posaunen": "Posaune",
    "Posaunenden": "Posaunende",
    "Posaunens": "Posaunen",
    "Posaunisten": "Posaunist",
    "Posaunte": "posaunt",
    "Posaunten": "Posaunte",
    "Posen": "Pose",
    "Posierenden": "Posierende",
    "Posierens": "Posieren",
    "Posierte": "posiert",
    "Posierten": "Posierte",
    "Positionen": "Position",
    "Positionierenden": "Positionierende",
    "Positionierens": "Positionieren",
    "Positionierte": "positioniert",
    "Positionierten": "Positionierte",
    "Positiven": "Positive",
    "Positiveren": "Positivere",
    "Positivs": "Positiv",
    "Positivste": "positiv",
    "Positivsten": "Positivste",
    "Positivverfahrens": "Positivverfahren",
    "Possen": "Posse",
    "Possenhafte": "possenhaft",
    "Possenhaften": "Possenhafte",
    "Possenhafteren": "Possenhaftere",
    "Possenhaftesten": "Possenhafteste",
    "Possibilitäten": "Possibilität",
    "Possierliche": "possierlich",
    "Possierlichen": "Possierliche",
    "Possierlicheren": "Possierlichere",
    "Possierlichsten": "Possierlichste",
    "Postalischen": "Postalische",
    "Postens": "Posten",
    "Postern": "Poster",
    "Posters": "Poster",
    "Postfrische": "postfrisch",
    "Postfrischen": "Postfrische",
    "Posthaltereien": "Posthalterei",
    "Posthume": "posthum",
    "Posthumen": "Posthume",
    "Postierenden": "Postierende",
    "Postierens": "Postieren",
    "Postierte": "postiert",
    "Postierten": "Postierte",
    "Postlagernden": "Postlagernde",
    "Postmodernen": "Postmoderne",
    "Postmortalen": "Postmortale",
    "Postnatalen": "Postnatale",
    "Postnationalen": "Postnationale",
    "Postnationaleren": "Postnationalere",
    "Postnationalsten": "Postnationalste",
    "Postoperativen": "Postoperative",
    "Posttraumatischen": "Posttraumatische",
    "Postulate": "Postulat",
    "Postulaten": "Postulat",
    "Postulates": "Postulat",
    "Postulats": "Postulat",
    "Postulierenden": "Postulierende",
    "Postulierens": "Postulieren",
    "Postulierte": "postuliert",
    "Postulierten": "Postulierte",
    "Postwendenden": "Postwendende",
    "Potenten": "Potente",
    "Potenteren": "Potentere",
    "Potentesten": "Potenteste",
    "Potentiale": "Potential",
    "Potentialen": "Potential",
    "Potentiales": "Potential",
    "Potentials": "Potential",
    "Potentielle": "potentiell",
    "Potentiellen": "Potentielle",
    "Potentielleren": "Potentiellere",
    "Potentiellsten": "Potentiellste",
    "Potentiometern": "Potentiometer",
    "Potentiometers": "Potentiometer",
    "Potenzen": "Potenz",
    "Potenzierenden": "Potenzierende",
    "Potenzierens": "Potenzieren",
    "Potenzierte": "potenziert",
    "Potenzierten": "Potenzierte",
    "Potpourris": "Potpourri",
    "Potsdamern": "Potsdamer",
    "Potsdamers": "Potsdamer",
    "Potsdams": "Potsdam",
    "Potte": "Pott",
    "Potthäßliche": "potthäßlich",
    "Potthäßlichen": "Potthäßliche",
    "Potts": "Pott",
    "Power": "powern",
    "Powernden": "Powernde",
    "Powernderen": "Powerndere",
    "Powerndsten": "Powerndste",
    "Powerns": "Powern",
    "Prachtstücke": "Prachtstück",
    "Prachtstücken": "Prachtstück",
    "Prachtstücks": "Prachtstück",
    "Prachtvolle": "prachtvoll",
    "Prachtvollen": "Prachtvolle",
    "Prachtvolleren": "Prachtvollere",
    "Prachtvollsten": "Prachtvollste",
    "Pragern": "Prager",
    "Pragers": "Prager",
    "Pragmatiken": "Pragmatik",
    "Pragmatikern": "Pragmatiker",
    "Pragmatikers": "Pragmatiker",
    "Pragmatische": "pragmatisch",
    "Pragmatischen": "Pragmatische",
    "Pragmatischeren": "Pragmatischere",
    "Pragmatischsten": "Pragmatischste",
    "Prags": "Prag",
    "Prahlenden": "Prahlende",
    "Prahlenderen": "Prahlendere",
    "Prahlendsten": "Prahlendste",
    "Prahlens": "Prahlen",
    "Prahlerische": "prahlerisch",
    "Prahlerischen": "Prahlerische",
    "Prahlerischeren": "Prahlerischere",
    "Prahlerischsten": "Prahlerischste",
    "Praktika": "Praktikum",
    "Praktikabelste": "praktikabel",
    "Praktikabelsten": "Praktikabelste",
    "Praktikablen": "Praktikable",
    "Praktikableren": "Praktikablere",
    "Praktikanten": "Praktikant",
    "Praktiken": "Praktik",
    "Praktikern": "Praktiker",
    "Praktikers": "Praktiker",
    "Praktikums": "Praktikum",
    "Praktische": "praktisch",
    "Praktischen": "Praktische",
    "Praktischeren": "Praktischere",
    "Praktischsten": "Praktischste",
    "Praktizierenden": "Praktizierende",
    "Praktizierens": "Praktizieren",
    "Praktizierte": "praktiziert",
    "Praktizierten": "Praktizierte",
    "Pralinen": "Praline",
    "Prallenden": "Prallende",
    "Prallens": "Prallen",
    "Prangenden": "Prangende",
    "Prangens": "Prangen",
    "Pranger": "prangern",
    "Prangern": "Pranger",
    "Prangernden": "Prangernde",
    "Prangernderen": "Prangerndere",
    "Prangerndsten": "Prangerndste",
    "Prangerns": "Prangern",
    "Prangers": "Pranger",
    "Pranken": "Pranke",
    "Prasselnden": "Prasselnde",
    "Prasselns": "Prasseln",
    "Praunheims": "Praunheim",
    "Praxen": "Praxis",
    "Praxisreife": "praxisreif",
    "Praxisreifen": "Praxisreife",
    "Praxisreiferen": "Praxisreifere",
    "Praxisreifsten": "Praxisreifste",
    "Predigenden": "Predigende",
    "Predigenderen": "Predigendere",
    "Predigendsten": "Predigendste",
    "Predigens": "Predigen",
    "Predigern": "Prediger",
    "Predigers": "Prediger",
    "Predigten": "Predigt",
    "Preis": "preisen",
    "Preise": "preisen",
    "Preisen": "Preis",
    "Preisenden": "Preisende",
    "Preisens": "Preisen",
    "Preises": "Preis",
    "Preisgebenden": "Preisgebende",
    "Preisgebens": "Preisgeben",
    "Preisgebundenen": "Preisgebundene",
    "Preisgegebenen": "Preisgegebene",
    "Preisgegebeneren": "Preisgegebenere",
    "Preisgegebensten": "Preisgegebenste",
    "Preisgekrönten": "Preisgekrönte",
    "Preisgünstigen": "Preisgünstige",
    "Preisgünstigeren": "Preisgünstigere",
    "Preisgünstigsten": "Preisgünstigste",
    "Preislichen": "Preisliche",
    "Preisscheren": "Preisschere",
    "Preiswerten": "Preiswerte",
    "Preiswerteren": "Preiswertere",
    "Preiswertesten": "Preiswerteste",
    "Preiswürdigen": "Preiswürdige",
    "Preiswürdigeren": "Preiswürdigere",
    "Preiswürdigsten": "Preiswürdigste",
    "Prekären": "Prekäre",
    "Prekäreren": "Prekärere",
    "Prekärsten": "Prekärste",
    "Prellenden": "Prellende",
    "Prellenderen": "Prellendere",
    "Prellendsten": "Prellendste",
    "Prellens": "Prellen",
    "Prellern": "Preller",
    "Prellers": "Preller",
    "Premieren": "Premiere",
    "Premiers": "Premier",
    "Prenzlauern": "Prenzlauer",
    "Prenzlauers": "Prenzlauer",
    "Presbytern": "Presbyter",
    "Presbyters": "Presbyter",
    "Preschenden": "Preschende",
    "Preschens": "Preschen",
    "Pressenden": "Pressende",
    "Pressens": "Pressen",
    "Pressierenden": "Pressierende",
    "Pressierenderen": "Pressierendere",
    "Pressierendsten": "Pressierendste",
    "Pressierens": "Pressieren",
    "Pressierte": "pressiert",
    "Pressierten": "Pressierte",
    "Pressierteren": "Pressiertere",
    "Pressiertesten": "Pressierteste",
    "Pressungen": "Pressung",
    "Prestiges": "Prestige",
    "Preungesheimern": "Preungesheimer",
    "Preungesheimers": "Preungesheimer",
    "Preungesheims": "Preungesheim",
    "Preußen": "Preuße",
    "Preußens": "Preußen",
    "Preußische": "preußisch",
    "Preußischen": "Preußische",
    "Preußischeren": "Preußischere",
    "Preußischsten": "Preußischste",
    "Preßkuchens": "Preßkuchen",
    "Preßlufthammers": "Preßlufthammer",
    "Preßlufthämmer": "Preßlufthammer",
    "Preßlufthämmern": "Preßlufthammer",
    "Priele": "Priel",
    "Prielen": "Priel",
    "Priels": "Priel",
    "Priesterlichen": "Priesterliche",
    "Priestern": "Priester",
    "Priesters": "Priester",
    "Priestertums": "Priestertum",
    "Primarstufen": "Primarstufe",
    "Primeln": "Primel",
    "Primen": "Prime",
    "Primitive": "primitiv",
    "Primitiven": "Primitive",
    "Primitiveren": "Primitivere",
    "Primitivsten": "Primitivste",
    "Primäraffekte": "Primäraffekt",
    "Primäraffekten": "Primäraffekt",
    "Primäraffekts": "Primäraffekt",
    "Primäre": "primär",
    "Primären": "Primäre",
    "Primärgesteine": "Primärgestein",
    "Primärgesteinen": "Primärgestein",
    "Primärgesteins": "Primärgestein",
    "Primärspannungen": "Primärspannung",
    "Primärspulen": "Primärspule",
    "Primärstrahlungen": "Primärstrahlung",
    "Primärtumore": "Primärtumor",
    "Primärtumoren": "Primärtumor",
    "Primärtumors": "Primärtumor",
    "Primärversorgungen": "Primärversorgung",
    "Primärwicklungen": "Primärwicklung",
    "Printen": "Printe",
    "Printern": "Printer",
    "Printers": "Printer",
    "Prinzen": "Prinz",
    "Prinzessinnen": "Prinzessin",
    "Prinzipalinnen": "Prinzipalin",
    "Prinzipielle": "prinzipiell",
    "Prinzipiellen": "Prinzipielle",
    "Prinzipien": "Prinzip",
    "Prinzips": "Prinzip",
    "Prioritäten": "Priorität",
    "Prisen": "Prise",
    "Pritsche": "pritschen",
    "Pritschen": "Pritsche",
    "Pritschenden": "Pritschende",
    "Pritschens": "Pritschen",
    "Privaten": "Private",
    "Privateren": "Privatere",
    "Privatesten": "Privateste",
    "Privatisierenden": "Privatisierende",
    "Privatisierens": "Privatisieren",
    "Privatisierte": "privatisiert",
    "Privatisierten": "Privatisierte",
    "Privatisierteren": "Privatisiertere",
    "Privatisiertesten": "Privatisierteste",
    "Privatisierungen": "Privatisierung",
    "Privatlebens": "Privatleben",
    "Privatraume": "Privatraum",
    "Privatraumes": "Privatraum",
    "Privatraums": "Privatraum",
    "Privaträume": "Privatraum",
    "Privaträumen": "Privatraum",
    "Privilegien": "Privileg",
    "Privilegs": "Privileg",
    "Probanden": "Proband",
    "Probate": "probat",
    "Probaten": "Probate",
    "Probateren": "Probatere",
    "Probatesten": "Probateste",
    "Proben": "Probe",
    "Probenden": "Probende",
    "Probens": "Proben",
    "Probierenden": "Probierende",
    "Probierens": "Probieren",
    "Probierte": "probiert",
    "Probierten": "Probierte",
    "Problematiken": "Problematik",
    "Problematische": "problematisch",
    "Problematischen": "Problematische",
    "Problematischeren": "Problematischere",
    "Problematischsten": "Problematischste",
    "Problematisierenden": "Problematisierende",
    "Problematisierens": "Problematisieren",
    "Problematisierte": "problematisiert",
    "Problematisierten": "Problematisierte",
    "Probleme": "Problem",
    "Problemen": "Problem",
    "Problemgeladene": "problemgeladen",
    "Problemgeladenen": "Problemgeladene",
    "Problemgeladeneren": "Problemgeladenere",
    "Problemlosen": "Problemlose",
    "Problemloseren": "Problemlosere",
    "Problemlosesten": "Problemloseste",
    "Problemorientierten": "Problemorientierte",
    "Problemorientierteren": "Problemorientiertere",
    "Problems": "Problem",
    "Prodekane": "Prodekan",
    "Prodekanen": "Prodekan",
    "Prodekans": "Prodekan",
    "Produkte": "Produkt",
    "Produkten": "Produkt",
    "Produktionen": "Produktion",
    "Produktive": "produktiv",
    "Produktiven": "Produktive",
    "Produktiveren": "Produktivere",
    "Produktivkräfte": "Produktivkraft",
    "Produktivkräften": "Produktivkraft",
    "Produktivste": "produktiv",
    "Produktivsten": "Produktivste",
    "Produkts": "Produkt",
    "Produzenten": "Produzent",
    "Produzierenden": "Produzierende",
    "Produzierens": "Produzieren",
    "Produzierte": "produziert",
    "Produzierten": "Produzierte",
    "Profanen": "Profane",
    "Profaneren": "Profanere",
    "Profansten": "Profanste",
    "Professionalisierenden": "Professionalisierende",
    "Professionalisierenderen": "Professionalisierendere",
    "Professionalisierens": "Professionalisieren",
    "Professionalisierte": "professionalisiert",
    "Professionalisierten": "Professionalisierte",
    "Professionalisierteren": "Professionalisiertere",
    "Professionellen": "Professionelle",
    "Professionelleren": "Professionellere",
    "Professionellsten": "Professionellste",
    "Professoralen": "Professorale",
    "Professore": "Professor",
    "Professoren": "Professor",
    "Professors": "Professor",
    "Profile": "Profil",
    "Profilen": "Profil",
    "Profiles": "Profil",
    "Profilierenden": "Profilierende",
    "Profilierenderen": "Profilierendere",
    "Profilierendsten": "Profilierendste",
    "Profilierens": "Profilieren",
    "Profilierte": "profiliert",
    "Profilierten": "Profilierte",
    "Profilierteren": "Profiliertere",
    "Profiliertesten": "Profilierteste",
    "Profilierungssüchtigen": "Profilierungssüchtige",
    "Profilierungssüchtigeren": "Profilierungssüchtigere",
    "Profils": "Profil",
    "Profis": "Profi",
    "Profitabelste": "profitabel",
    "Profitabelsten": "Profitabelste",
    "Profitablen": "Profitable",
    "Profitableren": "Profitablere",
    "Profite": "Profit",
    "Profiten": "Profit",
    "Profites": "Profit",
    "Profitierenden": "Profitierende",
    "Profitierenderen": "Profitierendere",
    "Profitierendsten": "Profitierendste",
    "Profitierens": "Profitieren",
    "Profitierte": "profitiert",
    "Profitierten": "Profitierte",
    "Profits": "Profit",
    "Prognosen": "Prognose",
    "Programmatische": "programmatisch",
    "Programmatischen": "Programmatische",
    "Programme": "Programm",
    "Programmen": "Programm",
    "Programmes": "Programm",
    "Programmgemäße": "programmgemäß",
    "Programmgemäßen": "Programmgemäße",
    "Programmgesteuerten": "Programmgesteuerte",
    "Programmierenden": "Programmierende",
    "Programmierenderen": "Programmierendere",
    "Programmierens": "Programmieren",
    "Programmierern": "Programmierer",
    "Programmierers": "Programmierer",
    "Programmierte": "programmiert",
    "Programmierten": "Programmierte",
    "Programmierteren": "Programmiertere",
    "Programmiertesten": "Programmierteste",
    "Programmierungen": "Programmierung",
    "Programms": "Programm",
    "Programmvorschauen": "Programmvorschau",
    "Progressionen": "Progression",
    "Progressive": "progressiv",
    "Progressiven": "Progressive",
    "Progressiveren": "Progressivere",
    "Progressivsten": "Progressivste",
    "Prohibierenden": "Prohibierende",
    "Prohibierens": "Prohibieren",
    "Prohibierte": "prohibiert",
    "Prohibierten": "Prohibierte",
    "Prohibitionen": "Prohibition",
    "Projekte": "Projekt",
    "Projekten": "Projekt",
    "Projektierenden": "Projektierende",
    "Projektierens": "Projektieren",
    "Projektierte": "projektiert",
    "Projektierten": "Projektierte",
    "Projektionen": "Projektion",
    "Projekts": "Projekt",
    "Projizierenden": "Projizierende",
    "Projizierens": "Projizieren",
    "Projizierte": "projiziert",
    "Projizierten": "Projizierte",
    "Proklamierenden": "Proklamierende",
    "Proklamierens": "Proklamieren",
    "Proklamierte": "proklamiert",
    "Proklamierten": "Proklamierte",
    "Prokuratore": "Prokurator",
    "Prokuratoren": "Prokurator",
    "Prokurators": "Prokurator",
    "Prokuristen": "Prokurist",
    "Proletariate": "Proletariat",
    "Proletariaten": "Proletariat",
    "Proletariats": "Proletariat",
    "Proletariern": "Proletarier",
    "Proletariers": "Proletarier",
    "Proletarische": "proletarisch",
    "Proletarischen": "Proletarische",
    "Proletarischeren": "Proletarischere",
    "Proletarischsten": "Proletarischste",
    "Proletarisierenden": "Proletarisierende",
    "Proletarisierenderen": "Proletarisierendere",
    "Proletarisierens": "Proletarisieren",
    "Proletarisierte": "proletarisiert",
    "Proletarisierten": "Proletarisierte",
    "Proletarisierteren": "Proletarisiertere",
    "Proleten": "Prolet",
    "Proletenhafte": "proletenhaft",
    "Proletenhaften": "Proletenhafte",
    "Proletenhafteren": "Proletenhaftere",
    "Proletenhaftesten": "Proletenhafteste",
    "Prologe": "Prolog",
    "Prologen": "Prolog",
    "Prologs": "Prolog",
    "Promenaden": "Promenade",
    "Promilles": "Promille",
    "Prominente": "prominent",
    "Prominenten": "Prominente",
    "Prominenteren": "Prominentere",
    "Prominentesten": "Prominenteste",
    "Prominenzen": "Prominenz",
    "Promissionen": "Promission",
    "Promotenden": "Promotende",
    "Promotenderen": "Promotendere",
    "Promotendsten": "Promotendste",
    "Promotens": "Promoten",
    "Promotern": "Promoter",
    "Promoters": "Promoter",
    "Promotete": "promotet",
    "Promoteten": "Promotete",
    "Promoteteren": "Promotetere",
    "Promotetesten": "Promoteteste",
    "Promotionen": "Promotion",
    "Promovierenden": "Promovierende",
    "Promovierens": "Promovieren",
    "Promovierte": "promoviert",
    "Promovierten": "Promovierte",
    "Prompten": "Prompte",
    "Prompteren": "Promptere",
    "Promptesten": "Prompteste",
    "Pronomens": "Pronomen",
    "Pronominaladjektive": "Pronominaladjektiv",
    "Pronominaladjektiven": "Pronominaladjektiv",
    "Pronominaladjektivs": "Pronominaladjektiv",
    "Pronominale": "pronominal",
    "Pronominalen": "Pronominale",
    "Propagandierenden": "Propagandierende",
    "Propagandierenderen": "Propagandierendere",
    "Propagandierens": "Propagandieren",
    "Propagandierte": "propagandiert",
    "Propagandierten": "Propagandierte",
    "Propagandierteren": "Propagandiertere",
    "Propagandierteste": "propagandiert",
    "Propagandistischen": "Propagandistische",
    "Propagierenden": "Propagierende",
    "Propagierens": "Propagieren",
    "Propagierte": "propagiert",
    "Propagierten": "Propagierte",
    "Propellern": "Propeller",
    "Propellers": "Propeller",
    "Propellerturbinen": "Propellerturbine",
    "Propheten": "Prophet",
    "Prophetische": "prophetisch",
    "Prophetischen": "Prophetische",
    "Prophezeienden": "Prophezeiende",
    "Prophezeiens": "Prophezeien",
    "Prophezeite": "prophezeit",
    "Prophezeiten": "Prophezeite",
    "Prophezeiungen": "Prophezeiung",
    "Prophylaktische": "prophylaktisch",
    "Prophylaktischen": "Prophylaktische",
    "Proportionalen": "Proportionale",
    "Proportionalsteuern": "Proportionalsteuer",
    "Proportionen": "Proportion",
    "Proportionierte": "proportioniert",
    "Proportionierten": "Proportionierte",
    "Propositionen": "Proposition",
    "Proppens": "Proppen",
    "Proppenvolle": "proppenvoll",
    "Proppenvollen": "Proppenvolle",
    "Propädeutischen": "Propädeutische",
    "Prorektorate": "Prorektorat",
    "Prorektoraten": "Prorektorat",
    "Prorektorats": "Prorektorat",
    "Prorektore": "Prorektor",
    "Prorektoren": "Prorektor",
    "Prorektors": "Prorektor",
    "Prosaische": "prosaisch",
    "Prosaischen": "Prosaische",
    "Prosaischeren": "Prosaischere",
    "Prosaischsten": "Prosaischste",
    "Prosaisten": "Prosaist",
    "Prosatexte": "Prosatext",
    "Prosatexten": "Prosatext",
    "Prosatextes": "Prosatext",
    "Prosatexts": "Prosatext",
    "Prosektore": "Prosektor",
    "Prosektoren": "Prosektor",
    "Prosektors": "Prosektor",
    "Prosekutore": "Prosekutor",
    "Prosekutoren": "Prosekutor",
    "Prosekutors": "Prosekutor",
    "Proseminare": "Proseminar",
    "Proseminaren": "Proseminar",
    "Proseminars": "Proseminar",
    "Prospekte": "Prospekt",
    "Prospekten": "Prospekt",
    "Prospektes": "Prospekt",
    "Prospekts": "Prospekt",
    "Prosperierenden": "Prosperierende",
    "Prosperierenderen": "Prosperierendere",
    "Prosperierendsten": "Prosperierendste",
    "Prosperierens": "Prosperieren",
    "Prosperierte": "prosperiert",
    "Prosperierten": "Prosperierte",
    "Prosperierteren": "Prosperiertere",
    "Prosperiertesten": "Prosperierteste",
    "Prostenden": "Prostende",
    "Prostens": "Prosten",
    "Prostituierten": "Prostituierte",
    "Protagonisten": "Protagonist",
    "Proteine": "Protein",
    "Proteinen": "Protein",
    "Proteins": "Protein",
    "Protektionistische": "protektionistisch",
    "Protektionistischen": "Protektionistische",
    "Protektorate": "Protektorat",
    "Protektoraten": "Protektorat",
    "Protektorats": "Protektorat",
    "Protektore": "Protektor",
    "Protektoren": "Protektor",
    "Protektors": "Protektor",
    "Protestanten": "Protestant",
    "Protestantische": "protestantisch",
    "Protestantischen": "Protestantische",
    "Proteste": "Protest",
    "Protesten": "Protest",
    "Protestes": "Protest",
    "Protestierenden": "Protestierende",
    "Protestierens": "Protestieren",
    "Protestierte": "protestiert",
    "Protestierten": "Protestierte",
    "Protests": "Protest",
    "Protoklasen": "Protoklase",
    "Protokollarische": "protokollarisch",
    "Protokollarischen": "Protokollarische",
    "Protokolle": "Protokoll",
    "Protokollen": "Protokoll",
    "Protokollierenden": "Protokollierende",
    "Protokollierens": "Protokollieren",
    "Protokollierte": "protokolliert",
    "Protokollierten": "Protokollierte",
    "Protokolls": "Protokoll",
    "Protoplasmas": "Protoplasma",
    "Prototype": "Prototyp",
    "Prototypen": "Prototyp",
    "Prototypische": "prototypisch",
    "Prototypischen": "Prototypische",
    "Prototyps": "Prototyp",
    "Protz": "protzen",
    "Protzen": "Protz",
    "Protzenden": "Protzende",
    "Protzenderen": "Protzendere",
    "Protzendsten": "Protzendste",
    "Protzens": "Protzen",
    "Protzereien": "Protzerei",
    "Protzigen": "Protzige",
    "Protzigeren": "Protzigere",
    "Protzigsten": "Protzigste",
    "Protzwagens": "Protzwagen",
    "Proudhons": "Proudhon",
    "Provinzen": "Provinz",
    "Provinzielle": "provinziell",
    "Provinziellen": "Provinzielle",
    "Provinzielleren": "Provinziellere",
    "Provinziellsten": "Provinziellste",
    "Provisorien": "Provisorium",
    "Provisorische": "provisorisch",
    "Provisorischen": "Provisorische",
    "Provisorischeren": "Provisorischere",
    "Provisorischsten": "Provisorischste",
    "Provisoriums": "Provisorium",
    "Provokationen": "Provokation",
    "Provozierenden": "Provozierende",
    "Provozierenderen": "Provozierendere",
    "Provozierendsten": "Provozierendste",
    "Provozierens": "Provozieren",
    "Provozierte": "provoziert",
    "Provozierten": "Provozierte",
    "Provozierteren": "Provoziertere",
    "Provoziertesten": "Provozierteste",
    "Prozeduren": "Prozedur",
    "Prozente": "Prozent",
    "Prozenten": "Prozent",
    "Prozentes": "Prozent",
    "Prozents": "Prozent",
    "Prozentuale": "prozentual",
    "Prozentualen": "Prozentuale",
    "Prozesse": "Prozeß",
    "Prozessen": "Prozeß",
    "Prozesses": "Prozeß",
    "Prozessierenden": "Prozessierende",
    "Prozessierens": "Prozessieren",
    "Prozessierte": "prozessiert",
    "Prozessierten": "Prozessierte",
    "Prozessore": "Prozessor",
    "Prozessoren": "Prozessor",
    "Prozessors": "Prozessor",
    "Prozeßfähige": "prozeßfähig",
    "Prozeßfähigen": "Prozeßfähige",
    "Prudeleien": "Prudelei",
    "Pruefungen": "Pruefung",
    "Prunkgemache": "Prunkgemach",
    "Prunkgemaches": "Prunkgemach",
    "Prunkgemachs": "Prunkgemach",
    "Prunkgemächer": "Prunkgemach",
    "Prunkgemächern": "Prunkgemach",
    "Prunks": "Prunk",
    "Prunksüchtige": "prunksüchtig",
    "Prunksüchtigen": "Prunksüchtige",
    "Prunksüchtigeren": "Prunksüchtigere",
    "Prunksüchtigsten": "Prunksüchtigste",
    "Prunkvollen": "Prunkvolle",
    "Prunkvolleren": "Prunkvollere",
    "Prunkvollsten": "Prunkvollste",
    "Prustenden": "Prustende",
    "Prustenderen": "Prustendere",
    "Prustendsten": "Prustendste",
    "Prustens": "Prusten",
    "Präambeln": "Präambel",
    "Prächtige": "prächtig",
    "Prächtigen": "Prächtige",
    "Prächtigeren": "Prächtigere",
    "Prächtigsten": "Prächtigste",
    "Prädestinierenden": "Prädestinierende",
    "Prädestinierenderen": "Prädestinierendere",
    "Prädestinierens": "Prädestinieren",
    "Prädestinierte": "prädestiniert",
    "Prädestinierten": "Prädestinierte",
    "Prädestinierteren": "Prädestiniertere",
    "Prädestinierteste": "prädestiniert",
    "Prädikate": "Prädikat",
    "Prädikaten": "Prädikat",
    "Prädikates": "Prädikat",
    "Prädikationen": "Prädikation",
    "Prädikative": "prädikativ",
    "Prädikativen": "Prädikative",
    "Prädikats": "Prädikat",
    "Prädiktionen": "Prädiktion",
    "Prädispositionen": "Prädisposition",
    "Präexistenzen": "Präexistenz",
    "Präfekten": "Präfekt",
    "Präfekturen": "Präfektur",
    "Präfigierenden": "Präfigierende",
    "Präfigierens": "Präfigieren",
    "Präfigierte": "präfigiert",
    "Präfigierten": "Präfigierte",
    "Präfixe": "Präfix",
    "Präfixen": "Präfix",
    "Präfixes": "Präfix",
    "Prägedrucke": "Prägedruck",
    "Prägedrucken": "Prägedruck",
    "Prägedrucks": "Prägedruck",
    "Prägenden": "Prägende",
    "Prägenderen": "Prägendere",
    "Prägendsten": "Prägendste",
    "Prägens": "Prägen",
    "Prägestempeln": "Prägestempel",
    "Prägestempels": "Prägestempel",
    "Prägungen": "Prägung",
    "Prähistorische": "prähistorisch",
    "Prähistorischen": "Prähistorische",
    "Präklusionen": "Präklusion",
    "Präkolumbianische": "präkolumbianisch",
    "Präkolumbianischen": "Präkolumbianische",
    "Prälaten": "Prälat",
    "Prämien": "Prämie",
    "Prämienbegünstigte": "prämienbegünstigt",
    "Prämienbegünstigten": "Prämienbegünstigte",
    "Prämienfreien": "Prämienfreie",
    "Prämierenden": "Prämierende",
    "Prämierenderen": "Prämierendere",
    "Prämierendsten": "Prämierendste",
    "Prämierens": "Prämieren",
    "Prämierte": "prämiert",
    "Prämierten": "Prämierte",
    "Prämierteren": "Prämiertere",
    "Prämiertesten": "Prämierteste",
    "Prämierungen": "Prämierung",
    "Prämissen": "Prämisse",
    "Pränumerationen": "Pränumeration",
    "Präparate": "Präparat",
    "Präparaten": "Präparat",
    "Präparationen": "Präparation",
    "Präparatore": "Präparator",
    "Präparatoren": "Präparator",
    "Präparators": "Präparator",
    "Präparats": "Präparat",
    "Präparierenden": "Präparierende",
    "Präparierenderen": "Präparierendere",
    "Präparierendsten": "Präparierendste",
    "Präparierens": "Präparieren",
    "Präparierte": "präpariert",
    "Präparierten": "Präparierte",
    "Präparierteren": "Präpariertere",
    "Präpariertesten": "Präparierteste",
    "Präpositionen": "Präposition",
    "Präsentationen": "Präsentation",
    "Präsente": "Präsent",
    "Präsenten": "Präsente",
    "Präsentierenden": "Präsentierende",
    "Präsentierens": "Präsentieren",
    "Präsentierte": "präsentiert",
    "Präsentiertellern": "Präsentierteller",
    "Präsentiertellers": "Präsentierteller",
    "Präsentierten": "Präsentierte",
    "Präsents": "Präsent",
    "Präsidenten": "Präsident",
    "Präsidentinnen": "Präsidentin",
    "Präsidentschaften": "Präsidentschaft",
    "Präsidien": "Präsidium",
    "Präsidiums": "Präsidium",
    "Präsumtionen": "Präsumtion",
    "Präsuppositionen": "Präsupposition",
    "Prätensionen": "Prätension",
    "Prätore": "Prätor",
    "Prätoren": "Prätor",
    "Prätors": "Prätor",
    "Präventionen": "Prävention",
    "Präzedenzen": "Präzedenz",
    "Präzedenzfalle": "Präzedenzfall",
    "Präzedenzfalles": "Präzedenzfall",
    "Präzedenzfalls": "Präzedenzfall",
    "Präzedenzfälle": "Präzedenzfall",
    "Präzedenzfällen": "Präzedenzfall",
    "Präzessionen": "Präzession",
    "Präzise": "präzis",
    "Präzisen": "Präzise",
    "Präziseren": "Präzisere",
    "Präzisesten": "Präziseste",
    "Präzisierenden": "Präzisierende",
    "Präzisierenderen": "Präzisierendere",
    "Präzisierendsten": "Präzisierendste",
    "Präzisierens": "Präzisieren",
    "Präzisierte": "präzisiert",
    "Präzisierten": "Präzisierte",
    "Präzisierteren": "Präzisiertere",
    "Präzisiertesten": "Präzisierteste",
    "Prüderen": "Prüdere",
    "Prüdesten": "Prüdeste",
    "Prüfenden": "Prüfende",
    "Prüfens": "Prüfen",
    "Prüfern": "Prüfer",
    "Prüfers": "Prüfer",
    "Prüfmaschinen": "Prüfmaschine",
    "Prüfstande": "Prüfstand",
    "Prüfstands": "Prüfstand",
    "Prüfsteine": "Prüfstein",
    "Prüfsteinen": "Prüfstein",
    "Prüfsteins": "Prüfstein",
    "Prüfstände": "Prüfstand",
    "Prüfständen": "Prüfstand",
    "Prüfungen": "Prüfung",
    "Prügeleien": "Prügelei",
    "Prügelnden": "Prügelnde",
    "Prügelns": "Prügeln",
    "Psalme": "Psalm",
    "Psalmen": "Psalm",
    "Psalmisten": "Psalmist",
    "Psalms": "Psalm",
    "Pschychotherapeuten": "Pschychotherapeut",
    "Pseudographen": "Pseudograph",
    "Pseudokonkordanzen": "Pseudokonkordanz",
    "Pseudolegierungen": "Pseudolegierung",
    "Psychen": "Psyche",
    "Psychiatern": "Psychiater",
    "Psychiaters": "Psychiater",
    "Psychiatrien": "Psychiatrie",
    "Psychiatrische": "psychiatrisch",
    "Psychiatrischen": "Psychiatrische",
    "Psychischen": "Psychische",
    "Psychischeren": "Psychischere",
    "Psychischsten": "Psychischste",
    "Psychoanalysen": "Psychoanalyse",
    "Psychoanalytikern": "Psychoanalytiker",
    "Psychoanalytikers": "Psychoanalytiker",
    "Psychoanalytische": "psychoanalytisch",
    "Psychoanalytischen": "Psychoanalytische",
    "Psychoanalytischeren": "Psychoanalytischere",
    "Psychogenen": "Psychogene",
    "Psychogenesen": "Psychogenese",
    "Psychografien": "Psychografie",
    "Psychogramme": "Psychogramm",
    "Psychogrammen": "Psychogramm",
    "Psychogramms": "Psychogramm",
    "Psychographien": "Psychographie",
    "Psychokinesen": "Psychokinese",
    "Psychokrimis": "Psychokrimi",
    "Psychologen": "Psychologe",
    "Psychologens": "Psychologe",
    "Psychologinnen": "Psychologin",
    "Psychologische": "psychologisch",
    "Psychologischen": "Psychologische",
    "Psychologischeren": "Psychologischere",
    "Psychologischsten": "Psychologischste",
    "Psychomotorischen": "Psychomotorische",
    "Psychoneurosen": "Psychoneurose",
    "Psychopathen": "Psychopath",
    "Psychopathien": "Psychopathie",
    "Psychopatische": "psychopatisch",
    "Psychopatischen": "Psychopatische",
    "Psychosen": "Psychose",
    "Psychosomatische": "psychosomatisch",
    "Psychosomatischen": "Psychosomatische",
    "Psychosozialen": "Psychosoziale",
    "Psychoterrors": "Psychoterror",
    "Psychotests": "Psychotest",
    "Psychotherapeuten": "Psychotherapeut",
    "Psychotherapeutische": "psychotherapeutisch",
    "Psychotherapeutischen": "Psychotherapeutische",
    "Psychothrillern": "Psychothriller",
    "Psychothrillers": "Psychothriller",
    "Psychotikern": "Psychotiker",
    "Psychotikers": "Psychotiker",
    "Psychotische": "psychotisch",
    "Psychotischen": "Psychotische",
    "Psychotischeren": "Psychotischere",
    "Psychotischsten": "Psychotischste",
    "Psyschiatrischen": "Psyschiatrische",
    "Pubertierenden": "Pubertierende",
    "Pubertierenderen": "Pubertierendere",
    "Pubertierendsten": "Pubertierendste",
    "Pubertierens": "Pubertieren",
    "Pubertierte": "pubertiert",
    "Pubertierten": "Pubertierte",
    "Pubertierteren": "Pubertiertere",
    "Pubertiertesten": "Pubertierteste",
    "Publikationen": "Publikation",
    "Publikums": "Publikum",
    "Publikumswirksame": "publikumswirksam",
    "Publikumswirksamen": "Publikumswirksame",
    "Publikumswirksameren": "Publikumswirksamere",
    "Publizierenden": "Publizierende",
    "Publizierenderen": "Publizierendere",
    "Publizierendsten": "Publizierendste",
    "Publizierens": "Publizieren",
    "Publizierte": "publiziert",
    "Publizierten": "Publizierte",
    "Publizierungen": "Publizierung",
    "Publizisten": "Publizist",
    "Publizistische": "publizistisch",
    "Publizistischen": "Publizistische",
    "Pubs": "Pub",
    "Pucks": "Puck",
    "Puddings": "Pudding",
    "Pudelmützen": "Pudelmütze",
    "Pudeln": "Pudel",
    "Pudelnackte": "pudelnackt",
    "Pudelnackten": "Pudelnackte",
    "Pudelnassen": "Pudelnasse",
    "Pudels": "Pudel",
    "Puder": "pudern",
    "Puderigen": "Puderige",
    "Puderigeren": "Puderigere",
    "Puderigsten": "Puderigste",
    "Pudern": "Puder",
    "Pudernden": "Pudernde",
    "Pudernderen": "Puderndere",
    "Puderndsten": "Puderndste",
    "Puderns": "Pudern",
    "Puders": "Puder",
    "Pueblos": "Pueblo",
    "Puffbohnen": "Puffbohne",
    "Puffenden": "Puffende",
    "Puffenderen": "Puffendere",
    "Puffendsten": "Puffendste",
    "Puffens": "Puffen",
    "Puffern": "Puffer",
    "Puffers": "Puffer",
    "Pulenden": "Pulende",
    "Pulenderen": "Pulendere",
    "Pulendsten": "Pulendste",
    "Pulens": "Pulen",
    "Pullen": "Pulle",
    "Pullis": "Pulli",
    "Pullovern": "Pullover",
    "Pullovers": "Pullover",
    "Pulsatore": "Pulsator",
    "Pulsatoren": "Pulsator",
    "Pulsators": "Pulsator",
    "Pulsierenden": "Pulsierende",
    "Pulsierenderen": "Pulsierendere",
    "Pulsierendsten": "Pulsierendste",
    "Pulsierens": "Pulsieren",
    "Pulsierte": "pulsiert",
    "Pulsierten": "Pulsierte",
    "Pulte": "Pult",
    "Pulten": "Pult",
    "Pults": "Pult",
    "Pulver": "pulvern",
    "Pulverigen": "Pulverige",
    "Pulverigeren": "Pulverigere",
    "Pulverigsten": "Pulverigste",
    "Pulvern": "Pulver",
    "Pulvernden": "Pulvernde",
    "Pulvernderen": "Pulverndere",
    "Pulverndsten": "Pulverndste",
    "Pulverns": "Pulvern",
    "Pulvers": "Pulver",
    "Pumas": "Puma",
    "Pummelige": "pummelig",
    "Pummeligen": "Pummelige",
    "Pummeligeren": "Pummeligere",
    "Pummeligsten": "Pummeligste",
    "Pummeln": "Pummel",
    "Pummels": "Pummel",
    "Pumpe": "pumpen",
    "Pumpen": "Pumpe",
    "Pumpenden": "Pumpende",
    "Pumpens": "Pumpen",
    "Pumpernickeln": "Pumpernickel",
    "Pumpernickels": "Pumpernickel",
    "Pumphosen": "Pumphose",
    "Punks": "Punk",
    "Punkte": "punkten",
    "Punkten": "Punkt",
    "Punktenden": "Punktende",
    "Punktens": "Punkten",
    "Punktes": "Punkt",
    "Punktierenden": "Punktierende",
    "Punktierens": "Punktieren",
    "Punktiernadeln": "Punktiernadel",
    "Punktierte": "punktiert",
    "Punktierten": "Punktierte",
    "Punktionen": "Punktion",
    "Punkts": "Punkt",
    "Punktuelle": "punktuell",
    "Punktuellen": "Punktuelle",
    "Punktuelleren": "Punktuellere",
    "Punktuellsten": "Punktuellste",
    "Pupenden": "Pupende",
    "Pupenderen": "Pupendere",
    "Pupendsten": "Pupendste",
    "Pupens": "Pupen",
    "Pupillen": "Pupille",
    "Puppen": "Puppe",
    "Puppenhafte": "puppenhaft",
    "Puppenhaften": "Puppenhafte",
    "Puppenhafteren": "Puppenhaftere",
    "Puppenhaftesten": "Puppenhafteste",
    "Puren": "Pure",
    "Pureren": "Purere",
    "Puresten": "Pureste",
    "Puristen": "Purist",
    "Puristische": "puristisch",
    "Puristischen": "Puristische",
    "Puritanern": "Puritaner",
    "Puritaners": "Puritaner",
    "Puritanische": "puritanisch",
    "Puritanischen": "Puritanische",
    "Purzelbaume": "Purzelbaum",
    "Purzelbaumes": "Purzelbaum",
    "Purzelbaums": "Purzelbaum",
    "Purzelbäume": "Purzelbaum",
    "Purzelbäumen": "Purzelbaum",
    "Purzelnden": "Purzelnde",
    "Purzelns": "Purzeln",
    "Puschenden": "Puschende",
    "Puschenderen": "Puschendere",
    "Puschendsten": "Puschendste",
    "Puschens": "Puschen",
    "Pustenden": "Pustende",
    "Pustens": "Pusten",
    "Puten": "Pute",
    "Putsch": "putschen",
    "Putsche": "putschen",
    "Putschen": "Putsch",
    "Putschenden": "Putschende",
    "Putschens": "Putschen",
    "Putsches": "Putsch",
    "Putschisten": "Putschist",
    "Putschs": "Putsch",
    "Puttenden": "Puttende",
    "Puttens": "Putten",
    "Putts": "Putt",
    "Putze": "putzen",
    "Putzen": "Putze",
    "Putzenden": "Putzende",
    "Putzenderen": "Putzendere",
    "Putzendsten": "Putzendste",
    "Putzens": "Putzen",
    "Putzereien": "Putzerei",
    "Putzern": "Putzer",
    "Putzers": "Putzer",
    "Putzfrauen": "Putzfrau",
    "Putzige": "putzig",
    "Putzigen": "Putzige",
    "Putzigeren": "Putzigere",
    "Putzigsten": "Putzigste",
    "Putzmunteren": "Putzmuntere",
    "Putzmuntereren": "Putzmunterere",
    "Putzmuntersten": "Putzmunterste",
    "Putzsüchtigen": "Putzsüchtige",
    "Putzsüchtigeren": "Putzsüchtigere",
    "Putzsüchtigsten": "Putzsüchtigste",
    "Putzteufeln": "Putzteufel",
    "Putzteufels": "Putzteufel",
    "Putzzeuge": "Putzzeug",
    "Putzzeugen": "Putzzeug",
    "Putzzeugs": "Putzzeug",
    "Pygmäen": "Pygmäe",
    "Pygmäische": "pygmäisch",
    "Pygmäischen": "Pygmäische",
    "Pyjamas": "Pyjama",
    "Pyramiden": "Pyramide",
    "Pyrotechnische": "pyrotechnisch",
    "Pyrotechnischen": "Pyrotechnische",
    "Pythagoreischen": "Pythagoreische",
    "Pythias": "Pythia",
    "Pythons": "Python",
    "Pythonschlangen": "Pythonschlange",
    "Pächtern": "Pächter",
    "Pächters": "Pächter",
    "Päckchens": "Päckchen",
    "Pädagogen": "Pädagoge",
    "Pädagogische": "pädagogisch",
    "Pädagogischen": "Pädagogische",
    "Pädogogen": "Pädogoge",
    "Päppelnden": "Päppelnde",
    "Päppelns": "Päppeln",
    "Päpste": "Papst",
    "Päpsten": "Papst",
    "Päpstliche": "päpstlich",
    "Päpstlichen": "Päpstliche",
    "Pärchens": "Pärchen",
    "Pärleins": "Pärlein",
    "Pässe": "Paß",
    "Pässen": "Paß",
    "Pätzolds": "Pätzold",
    "Pöbel": "pöbeln",
    "Pöbeln": "Pöbel",
    "Pöbelnden": "Pöbelnde",
    "Pöbelnderen": "Pöbelndere",
    "Pöbelndsten": "Pöbelndste",
    "Pöbelns": "Pöbeln",
    "Pöbels": "Pöbel",
    "Pökelfleische": "Pökelfleisch",
    "Pökelfleischen": "Pökelfleisch",
    "Pökelfleischs": "Pökelfleisch",
    "Pökelnden": "Pökelnde",
    "Pökelns": "Pökeln",
    "Pöstchens": "Pöstchen",
    "Pötte": "Pott",
    "Pötten": "Pott",
    "Pünktchens": "Pünktchen",
    "Pünktliche": "pünktlich",
    "Pünktlichen": "Pünktliche",
    "Pünktlicheren": "Pünktlichere",
    "Pünktlichsten": "Pünktlichste",
    "Püppchens": "Püppchen",
    "Pürees": "Püree",
    "Quacksalbern": "Quacksalber",
    "Quacksalbers": "Quacksalber",
    "Quaddeln": "Quaddel",
    "Quadern": "Quader",
    "Quaders": "Quader",
    "Quadranten": "Quadrant",
    "Quadratdezimetern": "Quadratdezimeter",
    "Quadratdezimeters": "Quadratdezimeter",
    "Quadrate": "Quadrat",
    "Quadraten": "Quadrat",
    "Quadrates": "Quadrat",
    "Quadrathektometern": "Quadrathektometer",
    "Quadrathektometers": "Quadrathektometer",
    "Quadratische": "quadratisch",
    "Quadratischen": "Quadratische",
    "Quadratkilometern": "Quadratkilometer",
    "Quadratkilometers": "Quadratkilometer",
    "Quadratmetern": "Quadratmeter",
    "Quadratmeters": "Quadratmeter",
    "Quadratmillimetern": "Quadratmillimeter",
    "Quadratmillimeters": "Quadratmillimeter",
    "Quadrats": "Quadrat",
    "Quadraturen": "Quadratur",
    "Quadratwurzeln": "Quadratwurzel",
    "Quadrierenden": "Quadrierende",
    "Quadrierens": "Quadrieren",
    "Quadrierte": "quadriert",
    "Quadrierten": "Quadrierte",
    "Quadrophonen": "Quadrophone",
    "Quakenden": "Quakende",
    "Quakenderen": "Quakendere",
    "Quakendsten": "Quakendste",
    "Quakens": "Quaken",
    "Qualen": "Qual",
    "Qualifikationen": "Qualifikation",
    "Qualifizierenden": "Qualifizierende",
    "Qualifizierens": "Qualifizieren",
    "Qualifizierte": "qualifiziert",
    "Qualifizierten": "Qualifizierte",
    "Qualifizierteren": "Qualifiziertere",
    "Qualifiziertesten": "Qualifizierteste",
    "Qualifizierungen": "Qualifizierung",
    "Qualitative": "qualitativ",
    "Qualitativen": "Qualitative",
    "Qualitäten": "Qualität",
    "Qualitätsvollen": "Qualitätsvolle",
    "Qualitätsvolleren": "Qualitätsvollere",
    "Qualitätsvollsten": "Qualitätsvollste",
    "Quallen": "Qualle",
    "Quallige": "quallig",
    "Qualligen": "Quallige",
    "Qualligeren": "Qualligere",
    "Qualligsten": "Qualligste",
    "Qualm": "qualmen",
    "Qualme": "qualmen",
    "Qualmenden": "Qualmende",
    "Qualmenderen": "Qualmendere",
    "Qualmendsten": "Qualmendste",
    "Qualmens": "Qualmen",
    "Qualmes": "Qualm",
    "Qualmigen": "Qualmige",
    "Qualmigeren": "Qualmigere",
    "Qualmigsten": "Qualmigste",
    "Qualms": "Qualm",
    "Qualvollen": "Qualvolle",
    "Qualvolleren": "Qualvollere",
    "Qualvollsten": "Qualvollste",
    "Quantifizierenden": "Quantifizierende",
    "Quantifizierens": "Quantifizieren",
    "Quantifizierte": "quantifiziert",
    "Quantifizierten": "Quantifizierte",
    "Quantisierungen": "Quantisierung",
    "Quantitative": "quantitativ",
    "Quantitativen": "Quantitative",
    "Quantitäten": "Quantität",
    "Quappen": "Quappe",
    "Quarke": "Quark",
    "Quarkes": "Quark",
    "Quarks": "Quark",
    "Quartale": "Quartal",
    "Quartalen": "Quartal",
    "Quartals": "Quartal",
    "Quarten": "Quarte",
    "Quarterdecks": "Quarterdeck",
    "Quartette": "Quartett",
    "Quartetten": "Quartett",
    "Quartettes": "Quartett",
    "Quartetts": "Quartett",
    "Quartier": "quartieren",
    "Quartiere": "quartieren",
    "Quartieren": "Quartier",
    "Quartierenden": "Quartierende",
    "Quartierens": "Quartieren",
    "Quartiers": "Quartier",
    "Quartierte": "quartiert",
    "Quartierten": "Quartierte",
    "Quarzenden": "Quarzende",
    "Quarzenderen": "Quarzendere",
    "Quarzendsten": "Quarzendste",
    "Quarzens": "Quarzen",
    "Quarzigen": "Quarzige",
    "Quarzigeren": "Quarzigere",
    "Quarzigsten": "Quarzigste",
    "Quasikristalle": "Quasikristall",
    "Quasikristallen": "Quasikristall",
    "Quasikristalls": "Quasikristall",
    "Quasselnden": "Quasselnde",
    "Quasselnderen": "Quasselndere",
    "Quasselndsten": "Quasselndste",
    "Quasselns": "Quasseln",
    "Quasselstrippen": "Quasselstrippe",
    "Quasten": "Quaste",
    "Quaternen": "Quaterne",
    "Quaternionen": "Quaternion",
    "Quatschenden": "Quatschende",
    "Quatschenderen": "Quatschendere",
    "Quatschendsten": "Quatschendste",
    "Quatschens": "Quatschen",
    "Quatschereien": "Quatscherei",
    "Quatschkopfe": "Quatschkopf",
    "Quatschkopfs": "Quatschkopf",
    "Quatschköpfe": "Quatschkopf",
    "Quatschköpfen": "Quatschkopf",
    "Quecksilberigen": "Quecksilberige",
    "Quecksilbers": "Quecksilber",
    "Quelle": "quellen",
    "Quellen": "Quelle",
    "Quellenden": "Quellende",
    "Quellens": "Quellen",
    "Quellnymphen": "Quellnymphe",
    "Quellwassers": "Quellwasser",
    "Quengeligen": "Quengelige",
    "Quengeligeren": "Quengeligere",
    "Quengeligsten": "Quengeligste",
    "Quengelnden": "Quengelnde",
    "Quengelnderen": "Quengelndere",
    "Quengelndsten": "Quengelndste",
    "Quengelns": "Quengeln",
    "Querdenkenden": "Querdenkende",
    "Querdenkenderen": "Querdenkendere",
    "Querdenkendsten": "Querdenkendste",
    "Querdenkens": "Querdenken",
    "Quergedachten": "Quergedachte",
    "Quergelegten": "Quergelegte",
    "Quergeschossenen": "Quergeschossene",
    "Quergestreiften": "Quergestreifte",
    "Querköpfigen": "Querköpfige",
    "Querköpfigeren": "Querköpfigere",
    "Querköpfigsten": "Querköpfigste",
    "Querlegenden": "Querlegende",
    "Querlegens": "Querlegen",
    "Querpfeifen": "Querpfeife",
    "Querrudern": "Querruder",
    "Querruders": "Querruder",
    "Querschießenden": "Querschießende",
    "Querschießens": "Querschießen",
    "Querschlage": "Querschlag",
    "Querschlags": "Querschlag",
    "Querschläge": "Querschlag",
    "Querschlägen": "Querschlag",
    "Querschlägern": "Querschläger",
    "Querschlägers": "Querschläger",
    "Querschnitte": "Querschnitt",
    "Querschnitten": "Querschnitt",
    "Querschnitts": "Querschnitt",
    "Querschnittsgelähmte": "querschnittsgelähmt",
    "Querschnittsgelähmten": "Querschnittsgelähmte",
    "Querschreibens": "Querschreiben",
    "Querstraßen": "Querstraße",
    "Querstriche": "Querstrich",
    "Querstrichen": "Querstrich",
    "Querstrichs": "Querstrich",
    "Quersummen": "Quersumme",
    "Quertale": "Quertal",
    "Quertales": "Quertal",
    "Quertals": "Quertal",
    "Quertreibereien": "Quertreiberei",
    "Quertreibern": "Quertreiber",
    "Quertreibers": "Quertreiber",
    "Quertäler": "Quertal",
    "Quertälern": "Quertal",
    "Querulanten": "Querulant",
    "Querverbindungen": "Querverbindung",
    "Querwellen": "Querwelle",
    "Quetschen": "Quetsche",
    "Quetschenden": "Quetschende",
    "Quetschenderen": "Quetschendere",
    "Quetschendsten": "Quetschendste",
    "Quetschens": "Quetschen",
    "Quetschkommoden": "Quetschkommode",
    "Quetschungen": "Quetschung",
    "Quetschwunden": "Quetschwunde",
    "Queues": "Queue",
    "Quicklebendige": "quicklebendig",
    "Quicklebendigen": "Quicklebendige",
    "Quieckenden": "Quieckende",
    "Quieckenderen": "Quieckendere",
    "Quieckendsten": "Quieckendste",
    "Quieckens": "Quiecken",
    "Quiecksern": "Quieckser",
    "Quiecksers": "Quieckser",
    "Quieksern": "Quiekser",
    "Quieksers": "Quiekser",
    "Quietschenden": "Quietschende",
    "Quietschenderen": "Quietschendere",
    "Quietschendsten": "Quietschendste",
    "Quietschens": "Quietschen",
    "Quietschern": "Quietscher",
    "Quietschers": "Quietscher",
    "Quietschvergnügten": "Quietschvergnügte",
    "Quinten": "Quinte",
    "Quinternen": "Quinterne",
    "Quintette": "Quintett",
    "Quintetten": "Quintett",
    "Quintetts": "Quintett",
    "Quirl": "quirlen",
    "Quirle": "quirlen",
    "Quirlen": "Quirl",
    "Quirlenden": "Quirlende",
    "Quirlens": "Quirlen",
    "Quirligen": "Quirlige",
    "Quirligeren": "Quirligere",
    "Quirligsten": "Quirligste",
    "Quirls": "Quirl",
    "Quittierenden": "Quittierende",
    "Quittierens": "Quittieren",
    "Quittierte": "quittiert",
    "Quittierten": "Quittierte",
    "Quittungen": "Quittung",
    "Quotationen": "Quotation",
    "Quoten": "Quote",
    "Quotienten": "Quotient",
    "Quotierenden": "Quotierende",
    "Quotierens": "Quotieren",
    "Quotierte": "quotiert",
    "Quotierten": "Quotierte",
    "Quotierungen": "Quotierung",
    "Quäkern": "Quäker",
    "Quäkers": "Quäker",
    "Quälenden": "Quälende",
    "Quälenderen": "Quälendere",
    "Quälendsten": "Quälendste",
    "Quälens": "Quälen",
    "Quälereien": "Quälerei",
    "Quästore": "Quästor",
    "Quästoren": "Quästor",
    "Quästors": "Quästor",
    "RTLs": "RTL",
    "Rabatte": "Rabatt",
    "Rabatten": "Rabatt",
    "Rabattes": "Rabatt",
    "Rabattierenden": "Rabattierende",
    "Rabattierens": "Rabattieren",
    "Rabattierte": "rabattiert",
    "Rabattierten": "Rabattierte",
    "Rabatts": "Rabatt",
    "Rabauken": "Rabauke",
    "Rabbinern": "Rabbiner",
    "Rabbiners": "Rabbiner",
    "Rabbis": "Rabbi",
    "Raben": "Rabe",
    "Rabenvaters": "Rabenvater",
    "Rabenväter": "Rabenvater",
    "Rabenvätern": "Rabenvater",
    "Rabiate": "rabiat",
    "Rabiaten": "Rabiate",
    "Rabiateren": "Rabiatere",
    "Rabiatesten": "Rabiateste",
    "Rabins": "Rabin",
    "Rachedurstigen": "Rachedurstige",
    "Rachedurstigeren": "Rachedurstigere",
    "Rachedurstigsten": "Rachedurstigste",
    "Rachens": "Rachen",
    "Rachsüchtigen": "Rachsüchtige",
    "Rachsüchtigeren": "Rachsüchtigere",
    "Rachsüchtigsten": "Rachsüchtigste",
    "Raclettes": "Raclette",
    "Radars": "Radar",
    "Rade": "Rad",
    "Radelnden": "Radelnde",
    "Radelnderen": "Radelndere",
    "Radelndsten": "Radelndste",
    "Radelns": "Radeln",
    "Rades": "Rad",
    "Radfahrenden": "Radfahrende",
    "Radfahrens": "Radfahren",
    "Radfahrwege": "Radfahrweg",
    "Radfahrwegen": "Radfahrweg",
    "Radfahrwegs": "Radfahrweg",
    "Radgefahrenen": "Radgefahrene",
    "Radialen": "Radiale",
    "Radialreifens": "Radialreifen",
    "Radianten": "Radiant",
    "Radiationen": "Radiation",
    "Radien": "Radius",
    "Radierenden": "Radierende",
    "Radierens": "Radieren",
    "Radierern": "Radierer",
    "Radierers": "Radierer",
    "Radiergummis": "Radiergummi",
    "Radierte": "radiert",
    "Radierten": "Radierte",
    "Radierungen": "Radierung",
    "Radieschens": "Radieschen",
    "Radikale": "radikal",
    "Radikalen": "Radikale",
    "Radikaleren": "Radikalere",
    "Radikalisierenden": "Radikalisierende",
    "Radikalisierenderen": "Radikalisierendere",
    "Radikalisierens": "Radikalisieren",
    "Radikalisierte": "radikalisiert",
    "Radikalisierten": "Radikalisierte",
    "Radikalisierteren": "Radikalisiertere",
    "Radikalisierteste": "radikalisiert",
    "Radikalistischen": "Radikalistische",
    "Radikalistischeren": "Radikalistischere",
    "Radikalsten": "Radikalste",
    "Radioaktiven": "Radioaktive",
    "Radioaktiveren": "Radioaktivere",
    "Radioaktivitäten": "Radioaktivität",
    "Radioaktivste": "radioaktiv",
    "Radioaktivsten": "Radioaktivste",
    "Radiogramme": "Radiogramm",
    "Radiogrammen": "Radiogramm",
    "Radiogramms": "Radiogramm",
    "Radiographien": "Radiographie",
    "Radiologen": "Radiologe",
    "Radiologische": "radiologisch",
    "Radiologischen": "Radiologische",
    "Radios": "Radio",
    "Radkurven": "Radkurve",
    "Radlern": "Radler",
    "Radlers": "Radler",
    "Rads": "Rad",
    "Radwanderns": "Radwandern",
    "Raffenden": "Raffende",
    "Raffenderen": "Raffendere",
    "Raffendsten": "Raffendste",
    "Raffens": "Raffen",
    "Raffgierigen": "Raffgierige",
    "Raffgierigeren": "Raffgierigere",
    "Raffgierigsten": "Raffgierigste",
    "Raffinerien": "Raffinerie",
    "Raffinessen": "Raffinesse",
    "Raffinierenden": "Raffinierende",
    "Raffinierens": "Raffinieren",
    "Raffinierte": "raffiniert",
    "Raffinierten": "Raffinierte",
    "Raffinierteren": "Raffiniertere",
    "Raffiniertesten": "Raffinierteste",
    "Ragenden": "Ragende",
    "Ragens": "Ragen",
    "Ragouts": "Ragout",
    "Rahmenden": "Rahmende",
    "Rahmens": "Rahmen",
    "Rahmigen": "Rahmige",
    "Rahmigeren": "Rahmigere",
    "Rahmigsten": "Rahmigste",
    "Rainers": "Rainer",
    "Raketen": "Rakete",
    "Raketenwerfern": "Raketenwerfer",
    "Raketenwerfers": "Raketenwerfer",
    "Ralfs": "Ralf",
    "Rallyes": "Rallye",
    "Ralphs": "Ralph",
    "Rammdösige": "rammdösig",
    "Rammdösigen": "Rammdösige",
    "Rammdösigeren": "Rammdösigere",
    "Rammdösigsten": "Rammdösigste",
    "Rammelnden": "Rammelnde",
    "Rammelnderen": "Rammelndere",
    "Rammelndsten": "Rammelndste",
    "Rammelns": "Rammeln",
    "Rammenden": "Rammende",
    "Rammens": "Rammen",
    "Rammlern": "Rammler",
    "Rammlers": "Rammler",
    "Rampen": "Rampe",
    "Rampenlichte": "Rampenlicht",
    "Rampenlichter": "Rampenlicht",
    "Rampenlichtern": "Rampenlicht",
    "Rampenlichtes": "Rampenlicht",
    "Rampenlichts": "Rampenlicht",
    "Ramponierenden": "Ramponierende",
    "Ramponierenderen": "Ramponierendere",
    "Ramponierendsten": "Ramponierendste",
    "Ramponierens": "Ramponieren",
    "Ramponierte": "ramponiert",
    "Ramponierten": "Ramponierte",
    "Ramponierteren": "Ramponiertere",
    "Ramponiertesten": "Ramponierteste",
    "Ramsch": "ramschen",
    "Ramsche": "ramschen",
    "Ramschenden": "Ramschende",
    "Ramschenderen": "Ramschendere",
    "Ramschendsten": "Ramschendste",
    "Ramschens": "Ramschen",
    "Ramsches": "Ramsch",
    "Ramschs": "Ramsch",
    "Ramsteins": "Ramstein",
    "Randalierenden": "Randalierende",
    "Randalierenderen": "Randalierendere",
    "Randalierendsten": "Randalierendste",
    "Randalierens": "Randalieren",
    "Randalierern": "Randalierer",
    "Randalierers": "Randalierer",
    "Randalierte": "randaliert",
    "Randalierten": "Randalierte",
    "Randalierteren": "Randaliertere",
    "Randaliertesten": "Randalierteste",
    "Rande": "Rand",
    "Randes": "Rand",
    "Rands": "Rand",
    "Rang": "ringen",
    "Range": "Rang",
    "Rangeklotzten": "Rangeklotzte",
    "Rangekriegten": "Rangekriegte",
    "Ranges": "Rang",
    "Rangeschmissenen": "Rangeschmissene",
    "Ranghöchsten": "Ranghöchste",
    "Rangierenden": "Rangierende",
    "Rangierens": "Rangieren",
    "Rangierte": "rangiert",
    "Rangierten": "Rangierte",
    "Rangs": "Rang",
    "Rangältesten": "Rangälteste",
    "Ranken": "Ranke",
    "Rankenden": "Rankende",
    "Rankenderen": "Rankendere",
    "Rankendsten": "Rankendste",
    "Rankens": "Ranken",
    "Ranklotzenden": "Ranklotzende",
    "Ranklotzenderen": "Ranklotzendere",
    "Ranklotzendsten": "Ranklotzendste",
    "Ranklotzens": "Ranklotzen",
    "Rankriegenden": "Rankriegende",
    "Rankriegens": "Rankriegen",
    "Ranschmeißenden": "Ranschmeißende",
    "Ranschmeißens": "Ranschmeißen",
    "Ranzenden": "Ranzende",
    "Ranzens": "Ranzen",
    "Ranzigen": "Ranzige",
    "Ranzigeren": "Ranzigere",
    "Ranzigsten": "Ranzigste",
    "Rapiden": "Rapide",
    "Rappel": "rappeln",
    "Rappeldürre": "rappeldürr",
    "Rappeldürren": "Rappeldürre",
    "Rappeligen": "Rappelige",
    "Rappeligeren": "Rappeligere",
    "Rappeligsten": "Rappeligste",
    "Rappeln": "Rappel",
    "Rappelnden": "Rappelnde",
    "Rappelnderen": "Rappelndere",
    "Rappelndsten": "Rappelndste",
    "Rappelns": "Rappeln",
    "Rappels": "Rappel",
    "Rappen": "Rappe",
    "Rapse": "Raps",
    "Rapsen": "Raps",
    "Rapses": "Raps",
    "Raritäten": "Rarität",
    "Rasante": "rasant",
    "Rasanten": "Rasante",
    "Rasanteren": "Rasantere",
    "Rasantesten": "Rasanteste",
    "Raschelnden": "Raschelnde",
    "Raschelnderen": "Raschelndere",
    "Raschelndsten": "Raschelndste",
    "Raschelns": "Rascheln",
    "Raschen": "Rasche",
    "Rascheren": "Raschere",
    "Raschsten": "Raschste",
    "Rasenden": "Rasende",
    "Rasenderen": "Rasendere",
    "Rasendsten": "Rasendste",
    "Rasens": "Rasen",
    "Rasensprengern": "Rasensprenger",
    "Rasensprengers": "Rasensprenger",
    "Rasierapparate": "Rasierapparat",
    "Rasierapparaten": "Rasierapparat",
    "Rasierapparats": "Rasierapparat",
    "Rasierenden": "Rasierende",
    "Rasierens": "Rasieren",
    "Rasierklingen": "Rasierklinge",
    "Rasiersteine": "Rasierstein",
    "Rasiersteinen": "Rasierstein",
    "Rasiersteins": "Rasierstein",
    "Rasierte": "rasiert",
    "Rasierten": "Rasierte",
    "Raspelnden": "Raspelnde",
    "Raspelnderen": "Raspelndere",
    "Raspelndsten": "Raspelndste",
    "Raspelns": "Raspeln",
    "Rasselnden": "Rasselnde",
    "Rasselnderen": "Rasselndere",
    "Rasselndsten": "Rasselndste",
    "Rasselns": "Rasseln",
    "Rassen": "Rasse",
    "Rassige": "rassig",
    "Rassigen": "Rassige",
    "Rassigeren": "Rassigere",
    "Rassigsten": "Rassigste",
    "Rassischen": "Rassische",
    "Rassistischen": "Rassistische",
    "Rassistischeren": "Rassistischere",
    "Rassistischsten": "Rassistischste",
    "Raste": "rasen",
    "Rasten": "Raste",
    "Rastenden": "Rastende",
    "Rastenderen": "Rastendere",
    "Rastendsten": "Rastendste",
    "Rastens": "Rasten",
    "Raster": "rastern",
    "Rastern": "Raster",
    "Rasternden": "Rasternde",
    "Rasterns": "Rastern",
    "Rasters": "Raster",
    "Rastlosen": "Rastlose",
    "Rastloseren": "Rastlosere",
    "Rastlosesten": "Rastloseste",
    "Raststätten": "Raststätte",
    "Rasuren": "Rasur",
    "Rat": "raten",
    "Rate": "raten",
    "Raten": "Rate",
    "Ratenden": "Ratende",
    "Ratens": "Raten",
    "Rates": "Rat",
    "Ratifikationen": "Ratifikation",
    "Ratifizierenden": "Ratifizierende",
    "Ratifizierens": "Ratifizieren",
    "Ratifizierte": "ratifiziert",
    "Ratifizierten": "Ratifizierte",
    "Rationalen": "Rationale",
    "Rationaleren": "Rationalere",
    "Rationalisierenden": "Rationalisierende",
    "Rationalisierens": "Rationalisieren",
    "Rationalisierte": "rationalisiert",
    "Rationalisierten": "Rationalisierte",
    "Rationalitäten": "Rationalität",
    "Rationalste": "rational",
    "Rationalsten": "Rationalste",
    "Rationellen": "Rationelle",
    "Rationen": "Ration",
    "Rationierenden": "Rationierende",
    "Rationierenderen": "Rationierendere",
    "Rationierendsten": "Rationierendste",
    "Rationierens": "Rationieren",
    "Rationierte": "rationiert",
    "Rationierten": "Rationierte",
    "Rationierteren": "Rationiertere",
    "Rationiertesten": "Rationierteste",
    "Ratlosen": "Ratlose",
    "Ratloseren": "Ratlosere",
    "Ratlosesten": "Ratloseste",
    "Rats": "Rat",
    "Ratsame": "ratsam",
    "Ratsamen": "Ratsame",
    "Ratten": "Ratte",
    "Ratternden": "Ratternde",
    "Ratternderen": "Ratterndere",
    "Ratterndsten": "Ratterndste",
    "Ratterns": "Rattern",
    "Ratzenden": "Ratzende",
    "Ratzenderen": "Ratzendere",
    "Ratzendsten": "Ratzendste",
    "Ratzens": "Ratzen",
    "Raub": "rauben",
    "Raubbaue": "Raubbau",
    "Raubbaues": "Raubbau",
    "Raubbaus": "Raubbau",
    "Raube": "rauben",
    "Raubenden": "Raubende",
    "Raubens": "Rauben",
    "Raubes": "Raub",
    "Raubs": "Raub",
    "Raubschiffe": "Raubschiff",
    "Raubschiffen": "Raubschiff",
    "Raubschiffs": "Raubschiff",
    "Raubtiere": "Raubtier",
    "Raubtieren": "Raubtier",
    "Raubtiers": "Raubtier",
    "Raubvogels": "Raubvogel",
    "Raubvögel": "Raubvogel",
    "Raubvögeln": "Raubvogel",
    "Rauch": "rauchen",
    "Rauchenden": "Rauchende",
    "Rauchenderen": "Rauchendere",
    "Rauchendsten": "Rauchendste",
    "Rauchens": "Rauchen",
    "Rauchern": "Raucher",
    "Rauchers": "Raucher",
    "Rauchigen": "Rauchige",
    "Rauchigeren": "Rauchigere",
    "Rauchigsten": "Rauchigste",
    "Rauchlosen": "Rauchlose",
    "Rauchs": "Rauch",
    "Rauchverbote": "Rauchverbot",
    "Rauchverboten": "Rauchverbot",
    "Rauchverbots": "Rauchverbot",
    "Raudis": "Raudi",
    "Rauenden": "Rauende",
    "Rauens": "Rauen",
    "Raufasern": "Raufaser",
    "Raufbolde": "Raufbold",
    "Raufbolden": "Raufbold",
    "Raufbolds": "Raufbold",
    "Raufenden": "Raufende",
    "Raufenderen": "Raufendere",
    "Raufendsten": "Raufendste",
    "Raufens": "Raufen",
    "Raufereien": "Rauferei",
    "Raufern": "Raufer",
    "Raufers": "Raufer",
    "Rauflustigen": "Rauflustige",
    "Rauflustigeren": "Rauflustigere",
    "Rauflustigsten": "Rauflustigste",
    "Rauhe": "rauhen",
    "Rauhen": "Rauhe",
    "Rauhenden": "Rauhende",
    "Rauhens": "Rauhen",
    "Rauheren": "Rauhere",
    "Rauhesten": "Rauheste",
    "Rauhreife": "Rauhreif",
    "Rauhreifes": "Rauhreif",
    "Rauhreifs": "Rauhreif",
    "Raume": "Raum",
    "Raumes": "Raum",
    "Raumfahrern": "Raumfahrer",
    "Raumfahrers": "Raumfahrer",
    "Raums": "Raum",
    "Raunenden": "Raunende",
    "Raunens": "Raunen",
    "Raunheims": "Raunheim",
    "Raupen": "Raupe",
    "Rausch": "rauschen",
    "Rauscharme": "rauscharm",
    "Rauscharmen": "Rauscharme",
    "Rausche": "rauschen",
    "Rauschenden": "Rauschende",
    "Rauschenderen": "Rauschendere",
    "Rauschendsten": "Rauschendste",
    "Rauschens": "Rauschen",
    "Rausches": "Rausch",
    "Rauschgiftsüchtigen": "Rauschgiftsüchtige",
    "Rauschhaften": "Rauschhafte",
    "Rauschhafteren": "Rauschhaftere",
    "Rauschhaftesten": "Rauschhafteste",
    "Rauschärmeren": "Rauschärmere",
    "Rausgelaufenen": "Rausgelaufene",
    "Rauslaufenden": "Rauslaufende",
    "Rauslaufens": "Rauslaufen",
    "Rausschmeißern": "Rausschmeißer",
    "Rausschmeißers": "Rausschmeißer",
    "Rauten": "Raute",
    "Reagans": "Reagan",
    "Reagierenden": "Reagierende",
    "Reagierenderen": "Reagierendere",
    "Reagierendsten": "Reagierendste",
    "Reagierens": "Reagieren",
    "Reagierte": "reagiert",
    "Reagierten": "Reagierte",
    "Reaktionen": "Reaktion",
    "Reaktionsfähige": "reaktionsfähig",
    "Reaktionsfähigen": "Reaktionsfähige",
    "Reaktionsfähigeren": "Reaktionsfähigere",
    "Reaktionären": "Reaktionäre",
    "Reaktionäreren": "Reaktionärere",
    "Reaktionärsten": "Reaktionärste",
    "Reaktiven": "Reaktive",
    "Reaktore": "Reaktor",
    "Reaktoren": "Reaktor",
    "Reaktors": "Reaktor",
    "Reale": "real",
    "Realen": "Reale",
    "Realeren": "Realere",
    "Realisatore": "Realisator",
    "Realisatoren": "Realisator",
    "Realisators": "Realisator",
    "Realisierbare": "realisierbar",
    "Realisierbaren": "Realisierbare",
    "Realisierbareren": "Realisierbarere",
    "Realisierbarsten": "Realisierbarste",
    "Realisierenden": "Realisierende",
    "Realisierens": "Realisieren",
    "Realisierte": "realisiert",
    "Realisierten": "Realisierte",
    "Realisierungen": "Realisierung",
    "Realistische": "realistisch",
    "Realistischen": "Realistische",
    "Realistischeren": "Realistischere",
    "Realistischsten": "Realistischste",
    "Realitäten": "Realität",
    "Realkredite": "Realkredit",
    "Realkrediten": "Realkredit",
    "Realkredits": "Realkredit",
    "Realos": "Realo",
    "Realsozialistische": "realsozialistisch",
    "Realsozialistischen": "Realsozialistische",
    "Realsten": "Realste",
    "Realwerte": "Realwert",
    "Realwerten": "Realwert",
    "Realwerts": "Realwert",
    "Rebellen": "Rebell",
    "Rebellierenden": "Rebellierende",
    "Rebellierenderen": "Rebellierendere",
    "Rebellierendsten": "Rebellierendste",
    "Rebellierens": "Rebellieren",
    "Rebellierte": "rebelliert",
    "Rebellierten": "Rebellierte",
    "Rebellischen": "Rebellische",
    "Rebellischeren": "Rebellischere",
    "Rebellischsten": "Rebellischste",
    "Reben": "Rebe",
    "Rebhuhne": "Rebhuhn",
    "Rebhuhnes": "Rebhuhn",
    "Rebhuhns": "Rebhuhn",
    "Rebhühner": "Rebhuhn",
    "Rebhühnern": "Rebhuhn",
    "Rebstocke": "Rebstock",
    "Rebstockes": "Rebstock",
    "Rebstocks": "Rebstock",
    "Rebstöcke": "Rebstock",
    "Rebstöcken": "Rebstock",
    "Rechenautomaten": "Rechenautomat",
    "Rechenbuche": "Rechenbuch",
    "Rechenbuches": "Rechenbuch",
    "Rechenbuchs": "Rechenbuch",
    "Rechenbücher": "Rechenbuch",
    "Rechenbüchern": "Rechenbuch",
    "Rechenfehlern": "Rechenfehler",
    "Rechenfehlers": "Rechenfehler",
    "Rechengeräte": "Rechengerät",
    "Rechengeräten": "Rechengerät",
    "Rechengeräts": "Rechengerät",
    "Rechenkünstlern": "Rechenkünstler",
    "Rechenkünstlers": "Rechenkünstler",
    "Rechenmaschinen": "Rechenmaschine",
    "Rechenmeistern": "Rechenmeister",
    "Rechenmeisters": "Rechenmeister",
    "Rechenoperationen": "Rechenoperation",
    "Rechens": "Rechen",
    "Rechenschiebern": "Rechenschieber",
    "Rechenschiebers": "Rechenschieber",
    "Rechentafeln": "Rechentafel",
    "Recherchen": "Recherche",
    "Rechnenden": "Rechnende",
    "Rechnens": "Rechnen",
    "Rechnerische": "rechnerisch",
    "Rechnerischen": "Rechnerische",
    "Rechnern": "Rechner",
    "Rechners": "Rechner",
    "Rechnungen": "Rechnung",
    "Rechte": "Recht",
    "Rechtecke": "Rechteck",
    "Rechtecken": "Rechteck",
    "Rechtecks": "Rechteck",
    "Rechten": "Rechte",
    "Rechtfertigenden": "Rechtfertigende",
    "Rechtfertigenderen": "Rechtfertigendere",
    "Rechtfertigens": "Rechtfertigen",
    "Rechtfertigungen": "Rechtfertigung",
    "Rechtgläubige": "rechtgläubig",
    "Rechtgläubigen": "Rechtgläubige",
    "Rechthaberischen": "Rechthaberische",
    "Rechthaberischeren": "Rechthaberischere",
    "Rechthabern": "Rechthaber",
    "Rechthabers": "Rechthaber",
    "Rechtliche": "rechtlich",
    "Rechtlichen": "Rechtliche",
    "Rechtmäßigen": "Rechtmäßige",
    "Rechtmäßigkeiten": "Rechtmäßigkeit",
    "Rechts": "Recht",
    "Rechtsabbiegern": "Rechtsabbieger",
    "Rechtsabbiegers": "Rechtsabbieger",
    "Rechtsabweichlern": "Rechtsabweichler",
    "Rechtsabweichlers": "Rechtsabweichler",
    "Rechtschaffende": "rechtschaffend",
    "Rechtschaffenden": "Rechtschaffende",
    "Rechtschaffenderen": "Rechtschaffendere",
    "Rechtsdralls": "Rechtsdrall",
    "Rechtsdrehende": "rechtsdrehend",
    "Rechtsdrehenden": "Rechtsdrehende",
    "Rechtsextremen": "Rechtsextreme",
    "Rechtsextremeren": "Rechtsextremere",
    "Rechtsextremsten": "Rechtsextremste",
    "Rechtsfähigen": "Rechtsfähige",
    "Rechtsfähigeren": "Rechtsfähigere",
    "Rechtsfähigsten": "Rechtsfähigste",
    "Rechtsgelehrten": "Rechtsgelehrte",
    "Rechtsgerichteten": "Rechtsgerichtete",
    "Rechtsgültigen": "Rechtsgültige",
    "Rechtshändern": "Rechtshänder",
    "Rechtshänders": "Rechtshänder",
    "Rechtshändige": "rechtshändig",
    "Rechtshändigen": "Rechtshändige",
    "Rechtskräftigen": "Rechtskräftige",
    "Rechtslastigen": "Rechtslastige",
    "Rechtslastigeren": "Rechtslastigere",
    "Rechtslastigsten": "Rechtslastigste",
    "Rechtsliberalen": "Rechtsliberale",
    "Rechtsläufigen": "Rechtsläufige",
    "Rechtsmitteln": "Rechtsmittel",
    "Rechtsmittels": "Rechtsmittel",
    "Rechtsradikale": "rechtsradikal",
    "Rechtsradikalen": "Rechtsradikale",
    "Rechtsradikaleren": "Rechtsradikalere",
    "Rechtsradikalsten": "Rechtsradikalste",
    "Rechtsseitigen": "Rechtsseitige",
    "Rechtsstaatlichkeiten": "Rechtsstaatlichkeit",
    "Rechtsverbindliche": "rechtsverbindlich",
    "Rechtsverbindlichen": "Rechtsverbindliche",
    "Rechtsverkehrs": "Rechtsverkehr",
    "Rechtswidrige": "rechtswidrig",
    "Rechtswidrigen": "Rechtswidrige",
    "Rechtswidrigeren": "Rechtswidrigere",
    "Rechtswidrigsten": "Rechtswidrigste",
    "Rechtwinkligen": "Rechtwinklige",
    "Rechtzeitigen": "Rechtzeitige",
    "Recken": "Recke",
    "Reclams": "Reclam",
    "Recyclings": "Recycling",
    "Redakteure": "Redakteur",
    "Redakteuren": "Redakteur",
    "Redakteures": "Redakteur",
    "Redakteurinnen": "Redakteurin",
    "Redakteurs": "Redakteur",
    "Redaktionelle": "redaktionell",
    "Redaktionellen": "Redaktionelle",
    "Redaktionen": "Redaktion",
    "Rede": "reden",
    "Redegewandten": "Redegewandte",
    "Redegewandteren": "Redegewandtere",
    "Redegewandtesten": "Redegewandteste",
    "Reden": "Rede",
    "Redenden": "Redende",
    "Redens": "Reden",
    "Redlichkeiten": "Redlichkeit",
    "Rednern": "Redner",
    "Redners": "Redner",
    "Redselige": "redselig",
    "Redseligen": "Redselige",
    "Redseligeren": "Redseligere",
    "Redseligsten": "Redseligste",
    "Reduktionen": "Reduktion",
    "Reduzenten": "Reduzent",
    "Reduzible": "reduzibel",
    "Reduziblen": "Reduzible",
    "Reduzierenden": "Reduzierende",
    "Reduzierens": "Reduzieren",
    "Reduzierte": "reduziert",
    "Reduzierten": "Reduzierte",
    "Reduzierteren": "Reduziertere",
    "Reduziertesten": "Reduzierteste",
    "Reduzierungen": "Reduzierung",
    "Reedereien": "Reederei",
    "Reedern": "Reeder",
    "Reeders": "Reeder",
    "Reelle": "reell",
    "Reellen": "Reelle",
    "Reetablierenden": "Reetablierende",
    "Reetablierenderen": "Reetablierendere",
    "Reetablierendsten": "Reetablierendste",
    "Reetablierens": "Reetablieren",
    "Reetablierte": "reetabliert",
    "Reetablierten": "Reetablierte",
    "Referate": "Referat",
    "Referaten": "Referat",
    "Referates": "Referat",
    "Referats": "Referat",
    "Referendare": "Referendar",
    "Referendaren": "Referendar",
    "Referendares": "Referendar",
    "Referendars": "Referendar",
    "Referendums": "Referendum",
    "Referenten": "Referent",
    "Referenzen": "Referenz",
    "Referenzsendern": "Referenzsender",
    "Referenzsenders": "Referenzsender",
    "Referierenden": "Referierende",
    "Referierens": "Referieren",
    "Referierte": "referiert",
    "Referierten": "Referierte",
    "Refinanzierenden": "Refinanzierende",
    "Refinanzierens": "Refinanzieren",
    "Refinanzierte": "refinanziert",
    "Refinanzierten": "Refinanzierte",
    "Refinanzierungen": "Refinanzierung",
    "Reflektierenden": "Reflektierende",
    "Reflektierenderen": "Reflektierendere",
    "Reflektierendsten": "Reflektierendste",
    "Reflektierens": "Reflektieren",
    "Reflektierte": "reflektiert",
    "Reflektierten": "Reflektierte",
    "Reflektierteren": "Reflektiertere",
    "Reflektiertesten": "Reflektierteste",
    "Reflektorischen": "Reflektorische",
    "Reflexe": "Reflex",
    "Reflexen": "Reflex",
    "Reflexes": "Reflex",
    "Reflexionen": "Reflexion",
    "Reflexive": "reflexiv",
    "Reflexiven": "Reflexive",
    "Reflexiveren": "Reflexivere",
    "Reflexivsten": "Reflexivste",
    "Reformationen": "Reformation",
    "Reformatore": "Reformator",
    "Reformatoren": "Reformator",
    "Reformatorische": "reformatorisch",
    "Reformatorischen": "Reformatorische",
    "Reformators": "Reformator",
    "Reformen": "Reform",
    "Reformerische": "reformerisch",
    "Reformerischen": "Reformerische",
    "Reformern": "Reformer",
    "Reformers": "Reformer",
    "Reformierenden": "Reformierende",
    "Reformierenderen": "Reformierendere",
    "Reformierendsten": "Reformierendste",
    "Reformierens": "Reformieren",
    "Reformierte": "reformiert",
    "Reformierten": "Reformierte",
    "Reformierteren": "Reformiertere",
    "Reformiertesten": "Reformierteste",
    "Reformisten": "Reformist",
    "Refrains": "Refrain",
    "Refraktore": "Refraktor",
    "Refraktoren": "Refraktor",
    "Refraktors": "Refraktor",
    "Refundierenden": "Refundierende",
    "Refundierenderen": "Refundierendere",
    "Refundierendsten": "Refundierendste",
    "Refundierens": "Refundieren",
    "Refundierte": "refundiert",
    "Refundierten": "Refundierte",
    "Refundierteren": "Refundiertere",
    "Refundiertesten": "Refundierteste",
    "Regale": "Regal",
    "Regalen": "Regal",
    "Regales": "Regal",
    "Regals": "Regal",
    "Regel": "regeln",
    "Regellosen": "Regellose",
    "Regelloseren": "Regellosere",
    "Regellosesten": "Regelloseste",
    "Regelmäßigen": "Regelmäßige",
    "Regelmäßigeren": "Regelmäßigere",
    "Regelmäßigsten": "Regelmäßigste",
    "Regeln": "Regel",
    "Regelnden": "Regelnde",
    "Regelns": "Regeln",
    "Regelrechte": "regelrecht",
    "Regelrechten": "Regelrechte",
    "Regelstudienzeiten": "Regelstudienzeit",
    "Regelungen": "Regelung",
    "Regelwidrige": "regelwidrig",
    "Regelwidrigen": "Regelwidrige",
    "Regelwidrigeren": "Regelwidrigere",
    "Regelwidrigsten": "Regelwidrigste",
    "Regenbogens": "Regenbogen",
    "Regenden": "Regende",
    "Regenerationen": "Regeneration",
    "Regenerative": "regenerativ",
    "Regenerativen": "Regenerative",
    "Regeneratore": "Regenerator",
    "Regeneratoren": "Regenerator",
    "Regenerators": "Regenerator",
    "Regenerierenden": "Regenerierende",
    "Regenerierens": "Regenerieren",
    "Regenerierte": "regeneriert",
    "Regenerierten": "Regenerierte",
    "Regenreichen": "Regenreiche",
    "Regenreicheren": "Regenreichere",
    "Regenreichsten": "Regenreichste",
    "Regens": "Regen",
    "Regentinnen": "Regentin",
    "Regierenden": "Regierende",
    "Regierens": "Regieren",
    "Regierte": "regiert",
    "Regierten": "Regierte",
    "Regierungen": "Regierung",
    "Regierungstreue": "regierungstreu",
    "Regierungstreuen": "Regierungstreue",
    "Regimen": "Regime",
    "Regimente": "Regiment",
    "Regimenter": "Regiment",
    "Regimentern": "Regiment",
    "Regimentes": "Regiment",
    "Regiments": "Regiment",
    "Regimes": "Regime",
    "Reginas": "Regina",
    "Regionale": "regional",
    "Regionalen": "Regionale",
    "Regionalstudios": "Regionalstudio",
    "Regionen": "Region",
    "Regisseure": "Regisseur",
    "Regisseuren": "Regisseur",
    "Regisseurinnen": "Regisseurin",
    "Regisseurs": "Regisseur",
    "Registern": "Register",
    "Registers": "Register",
    "Registrierbare": "registrierbar",
    "Registrierbaren": "Registrierbare",
    "Registrierenden": "Registrierende",
    "Registrierens": "Registrieren",
    "Registrierte": "registriert",
    "Registrierten": "Registrierte",
    "Registrierungen": "Registrierung",
    "Reglern": "Regler",
    "Reglers": "Regler",
    "Reglose": "reglos",
    "Reglosen": "Reglose",
    "Regloseren": "Reglosere",
    "Reglosesten": "Regloseste",
    "Regnenden": "Regnende",
    "Regnens": "Regnen",
    "Regnerische": "regnerisch",
    "Regnerischen": "Regnerische",
    "Regressionen": "Regression",
    "Regressive": "regressiv",
    "Regressiven": "Regressive",
    "Regulativen": "Regulative",
    "Regulierenden": "Regulierende",
    "Regulierens": "Regulieren",
    "Regulierte": "reguliert",
    "Regulierten": "Regulierte",
    "Regulären": "Reguläre",
    "Regungen": "Regung",
    "Regungslose": "regungslos",
    "Regungslosen": "Regungslose",
    "Rehabilitationen": "Rehabilitation",
    "Rehabilitierenden": "Rehabilitierende",
    "Rehabilitierens": "Rehabilitieren",
    "Rehabilitierte": "rehabilitiert",
    "Rehabilitierten": "Rehabilitierte",
    "Rehabilitierteren": "Rehabilitiertere",
    "Rehabilitierteste": "rehabilitiert",
    "Rehabilitierungen": "Rehabilitierung",
    "Rehe": "Reh",
    "Rehen": "Reh",
    "Rehes": "Reh",
    "Rehs": "Reh",
    "Rehwilde": "Rehwild",
    "Rehwildes": "Rehwild",
    "Rehwilds": "Rehwild",
    "Reibeisens": "Reibeisen",
    "Reibekuchens": "Reibekuchen",
    "Reibenden": "Reibende",
    "Reibenderen": "Reibendere",
    "Reibendsten": "Reibendste",
    "Reibens": "Reiben",
    "Reibereien": "Reiberei",
    "Reibflächen": "Reibfläche",
    "Reibungen": "Reibung",
    "Reibungslose": "reibungslos",
    "Reibungslosen": "Reibungslose",
    "Reibungsloseren": "Reibungslosere",
    "Reibungslosesten": "Reibungsloseste",
    "Reiche": "Reich",
    "Reichen": "Reiche",
    "Reichenden": "Reichende",
    "Reichens": "Reichen",
    "Reichere": "reichern",
    "Reicheren": "Reichere",
    "Reichernden": "Reichernde",
    "Reicherns": "Reichern",
    "Reichhaltigen": "Reichhaltige",
    "Reichhaltigeren": "Reichhaltigere",
    "Reichhaltigsten": "Reichhaltigste",
    "Reichlichen": "Reichliche",
    "Reichlicheren": "Reichlichere",
    "Reichlichsten": "Reichlichste",
    "Reichs": "Reich",
    "Reichspräsidenten": "Reichspräsident",
    "Reichsten": "Reichste",
    "Reichtume": "Reichtum",
    "Reichtumes": "Reichtum",
    "Reichtums": "Reichtum",
    "Reichtümer": "Reichtum",
    "Reichtümern": "Reichtum",
    "Reif": "reifen",
    "Reife": "reifen",
    "Reifen": "Reife",
    "Reifenden": "Reifende",
    "Reifenderen": "Reifendere",
    "Reifendsten": "Reifendste",
    "Reifens": "Reifen",
    "Reiferen": "Reifere",
    "Reiflichen": "Reifliche",
    "Reifs": "Reif",
    "Reifsten": "Reifste",
    "Reifungen": "Reifung",
    "Reigens": "Reigen",
    "Reihe": "reihen",
    "Reihen": "Reihe",
    "Reihenden": "Reihende",
    "Reihenfolgen": "Reihenfolge",
    "Reihens": "Reihen",
    "Reihernden": "Reihernde",
    "Reiherns": "Reihern",
    "Reimenden": "Reimende",
    "Reimens": "Reimen",
    "Reimworte": "Reimwort",
    "Reimwortes": "Reimwort",
    "Reimworts": "Reimwort",
    "Reimwörter": "Reimwort",
    "Reimwörtern": "Reimwort",
    "Reine": "rein",
    "Reinen": "Reine",
    "Reineren": "Reinere",
    "Reinfallenden": "Reinfallende",
    "Reinfallens": "Reinfallen",
    "Reingefallenen": "Reingefallene",
    "Reingeredeten": "Reingeredete",
    "Reingerissenen": "Reingerissene",
    "Reingerittenen": "Reingerittene",
    "Reingerochenen": "Reingerochene",
    "Reingewaschenen": "Reingewaschene",
    "Reingewürgten": "Reingewürgte",
    "Reinhards": "Reinhard",
    "Reinhardts": "Reinhardt",
    "Reinheiten": "Reinheit",
    "Reinholds": "Reinhold",
    "Reinigenden": "Reinigende",
    "Reinigenderen": "Reinigendere",
    "Reinigendsten": "Reinigendste",
    "Reinigens": "Reinigen",
    "Reinigern": "Reiniger",
    "Reinigers": "Reiniger",
    "Reinigungen": "Reinigung",
    "Reinkarnationen": "Reinkarnation",
    "Reinkulturen": "Reinkultur",
    "Reinliche": "reinlich",
    "Reinlichen": "Reinliche",
    "Reinlicheren": "Reinlichere",
    "Reinlichsten": "Reinlichste",
    "Reinmachens": "Reinmachen",
    "Reinrassige": "reinrassig",
    "Reinrassigen": "Reinrassige",
    "Reinrassigeren": "Reinrassigere",
    "Reinrassigsten": "Reinrassigste",
    "Reinredenden": "Reinredende",
    "Reinredenderen": "Reinredendere",
    "Reinredendsten": "Reinredendste",
    "Reinredens": "Reinreden",
    "Reinreitenden": "Reinreitende",
    "Reinreitens": "Reinreiten",
    "Reinreißenden": "Reinreißende",
    "Reinreißens": "Reinreißen",
    "Reinriechenden": "Reinriechende",
    "Reinriechens": "Reinriechen",
    "Reinsten": "Reinste",
    "Reinwaschenden": "Reinwaschende",
    "Reinwaschens": "Reinwaschen",
    "Reinwürgenden": "Reinwürgende",
    "Reinwürgens": "Reinwürgen",
    "Reis": "reisen",
    "Reisbündeln": "Reisbündel",
    "Reisbündels": "Reisbündel",
    "Reise": "reisen",
    "Reisefertigen": "Reisefertige",
    "Reiselustigen": "Reiselustige",
    "Reiselustigeren": "Reiselustigere",
    "Reiselustigsten": "Reiselustigste",
    "Reisen": "Reise",
    "Reisenden": "Reisende",
    "Reisens": "Reisen",
    "Reiseschecks": "Reisescheck",
    "Reitenden": "Reitende",
    "Reitens": "Reiten",
    "Reiterleins": "Reiterlein",
    "Reitern": "Reiter",
    "Reiters": "Reiter",
    "Reitersmanne": "Reitersmann",
    "Reitersmannes": "Reitersmann",
    "Reitersmanns": "Reitersmann",
    "Reitersmänner": "Reitersmann",
    "Reitersmännern": "Reitersmann",
    "Reitpeitschen": "Reitpeitsche",
    "Reitpferde": "Reitpferd",
    "Reitpferden": "Reitpferd",
    "Reitpferds": "Reitpferd",
    "Reitschulen": "Reitschule",
    "Reitstalle": "Reitstall",
    "Reitstalls": "Reitstall",
    "Reitstocke": "Reitstock",
    "Reitstocks": "Reitstock",
    "Reitställe": "Reitstall",
    "Reitställen": "Reitstall",
    "Reitstöcke": "Reitstock",
    "Reitstöcken": "Reitstock",
    "Reittiere": "Reittier",
    "Reittieren": "Reittier",
    "Reittiers": "Reittier",
    "Reitturniere": "Reitturnier",
    "Reitturnieren": "Reitturnier",
    "Reitturniers": "Reitturnier",
    "Reiz": "reizen",
    "Reizbare": "reizbar",
    "Reizbaren": "Reizbare",
    "Reizbareren": "Reizbarere",
    "Reizbarsten": "Reizbarste",
    "Reize": "reizen",
    "Reizen": "Reiz",
    "Reizenden": "Reizende",
    "Reizens": "Reizen",
    "Reizes": "Reiz",
    "Reizlosen": "Reizlose",
    "Reizloseren": "Reizlosere",
    "Reizlosesten": "Reizloseste",
    "Reizungen": "Reizung",
    "Reizvolle": "reizvoll",
    "Reizvollen": "Reizvolle",
    "Reizvolleren": "Reizvollere",
    "Reizvollsten": "Reizvollste",
    "Reißenden": "Reißende",
    "Reißens": "Reißen",
    "Reißfedern": "Reißfeder",
    "Reißfeste": "reißfest",
    "Reißfesten": "Reißfeste",
    "Reißfesteren": "Reißfestere",
    "Reißfestesten": "Reißfesteste",
    "Reißlängen": "Reißlänge",
    "Rejektionen": "Rejektion",
    "Rekapitulationen": "Rekapitulation",
    "Rekapitulierenden": "Rekapitulierende",
    "Rekapitulierens": "Rekapitulieren",
    "Rekapitulierte": "rekapituliert",
    "Rekapitulierten": "Rekapitulierte",
    "Reklamationen": "Reklamation",
    "Reklamen": "Reklame",
    "Reklamierenden": "Reklamierende",
    "Reklamierens": "Reklamieren",
    "Reklamierte": "reklamiert",
    "Reklamierten": "Reklamierte",
    "Rekombinationen": "Rekombination",
    "Rekonstruierenden": "Rekonstruierende",
    "Rekonstruierens": "Rekonstruieren",
    "Rekonstruierte": "rekonstruiert",
    "Rekonstruierten": "Rekonstruierte",
    "Rekonstruierteren": "Rekonstruiertere",
    "Rekonstruierteste": "rekonstruiert",
    "Rekonstruktionen": "Rekonstruktion",
    "Rekorde": "Rekord",
    "Rekorden": "Rekord",
    "Rekordes": "Rekord",
    "Rekords": "Rekord",
    "Rekrutierenden": "Rekrutierende",
    "Rekrutierens": "Rekrutieren",
    "Rekrutierte": "rekrutiert",
    "Rekrutierten": "Rekrutierte",
    "Rektalen": "Rektale",
    "Rektifizierenden": "Rektifizierende",
    "Rektifizierens": "Rektifizieren",
    "Rektifizierte": "rektifiziert",
    "Rektifizierten": "Rektifizierte",
    "Rektorate": "Rektorat",
    "Rektoraten": "Rektorat",
    "Rektorats": "Rektorat",
    "Rektore": "Rektor",
    "Rektoren": "Rektor",
    "Rektorinnen": "Rektorin",
    "Rektors": "Rektor",
    "Rektums": "Rektum",
    "Rekuperatore": "Rekuperator",
    "Rekuperatoren": "Rekuperator",
    "Rekuperators": "Rekuperator",
    "Rekurrente": "rekurrent",
    "Rekurrenten": "Rekurrente",
    "Rekurrierenden": "Rekurrierende",
    "Rekurrierens": "Rekurrieren",
    "Rekurrierte": "rekurriert",
    "Rekurrierten": "Rekurrierte",
    "Rekursiven": "Rekursive",
    "Relationen": "Relation",
    "Relative": "relativ",
    "Relativen": "Relative",
    "Relativierungen": "Relativierung",
    "Relativpronomens": "Relativpronomen",
    "Relaxationen": "Relaxation",
    "Relegationen": "Relegation",
    "Relevante": "relevant",
    "Relevanten": "Relevante",
    "Relevanteren": "Relevantere",
    "Relevantesten": "Relevanteste",
    "Reliefkarten": "Reliefkarte",
    "Reliefs": "Relief",
    "Religionen": "Religion",
    "Religionslose": "religionslos",
    "Religionslosen": "Religionslose",
    "Religiösen": "Religiöse",
    "Religiöseren": "Religiösere",
    "Religiösesten": "Religiöseste",
    "Relikte": "Relikt",
    "Relikten": "Relikt",
    "Reliktes": "Relikt",
    "Relikts": "Relikt",
    "Relings": "Reling",
    "Reliquien": "Reliquie",
    "Remilitarisierenden": "Remilitarisierende",
    "Remilitarisierens": "Remilitarisieren",
    "Remilitarisierte": "remilitarisiert",
    "Remilitarisierten": "Remilitarisierte",
    "Reminiszenzen": "Reminiszenz",
    "Remisen": "Remise",
    "Remontierenden": "Remontierende",
    "Remontierens": "Remontieren",
    "Remontierte": "remontiert",
    "Remontierten": "Remontierte",
    "Remouladen": "Remoulade",
    "Rempelnden": "Rempelnde",
    "Rempelnderen": "Rempelndere",
    "Rempelndsten": "Rempelndste",
    "Rempelns": "Rempeln",
    "Renates": "Renate",
    "Renaturierenden": "Renaturierende",
    "Renaturierenderen": "Renaturierendere",
    "Renaturierendsten": "Renaturierendste",
    "Renaturierens": "Renaturieren",
    "Renaturierte": "renaturiert",
    "Renaturierten": "Renaturierte",
    "Renaturierteren": "Renaturiertere",
    "Renaturiertesten": "Renaturierteste",
    "Renditen": "Rendite",
    "Renitente": "renitent",
    "Renitenten": "Renitente",
    "Renitenteren": "Renitentere",
    "Renitentesten": "Renitenteste",
    "Renkenden": "Renkende",
    "Renkens": "Renken",
    "Rennboote": "Rennboot",
    "Rennbooten": "Rennboot",
    "Rennboots": "Rennboot",
    "Rennenden": "Rennende",
    "Rennens": "Rennen",
    "Rennereien": "Rennerei",
    "Rennern": "Renner",
    "Renners": "Renner",
    "Rennfahrern": "Rennfahrer",
    "Rennfahrers": "Rennfahrer",
    "Rennpferde": "Rennpferd",
    "Rennpferden": "Rennpferd",
    "Rennpferds": "Rennpferd",
    "Rennrade": "Rennrad",
    "Rennrades": "Rennrad",
    "Rennrads": "Rennrad",
    "Rennräder": "Rennrad",
    "Rennrädern": "Rennrad",
    "Renntage": "Renntag",
    "Renntagen": "Renntag",
    "Renntags": "Renntag",
    "Rennwagens": "Rennwagen",
    "Rennwetten": "Rennwette",
    "Renommees": "Renommee",
    "Renommierte": "renommiert",
    "Renommierten": "Renommierte",
    "Renommierteren": "Renommiertere",
    "Renommiertesten": "Renommierteste",
    "Renovierenden": "Renovierende",
    "Renovierens": "Renovieren",
    "Renovierte": "renoviert",
    "Renovierten": "Renovierte",
    "Renovierteren": "Renoviertere",
    "Renoviertesten": "Renovierteste",
    "Renovierungen": "Renovierung",
    "Rentabelste": "rentabel",
    "Rentabelsten": "Rentabelste",
    "Rentablen": "Rentable",
    "Rentableren": "Rentablere",
    "Renten": "Rente",
    "Rentenpflichtige": "rentenpflichtig",
    "Rentenpflichtigen": "Rentenpflichtige",
    "Rentier": "rentieren",
    "Rentiere": "rentieren",
    "Rentieren": "Rentier",
    "Rentierenden": "Rentierende",
    "Rentierenderen": "Rentierendere",
    "Rentierendsten": "Rentierendste",
    "Rentierens": "Rentieren",
    "Rentiers": "Rentier",
    "Rentierte": "rentiert",
    "Rentierten": "Rentierte",
    "Rentnerinnen": "Rentnerin",
    "Rentnern": "Rentner",
    "Rentners": "Rentner",
    "Renumerationen": "Renumeration",
    "Renumerierenden": "Renumerierende",
    "Renumerierens": "Renumerieren",
    "Renumerierte": "renumeriert",
    "Renumerierten": "Renumerierte",
    "Reokkupationen": "Reokkupation",
    "Reorganisationen": "Reorganisation",
    "Reorganisatore": "Reorganisator",
    "Reorganisatoren": "Reorganisator",
    "Reorganisators": "Reorganisator",
    "Reorganisierenden": "Reorganisierende",
    "Reorganisierenderen": "Reorganisierendere",
    "Reorganisierens": "Reorganisieren",
    "Reorganisierte": "reorganisiert",
    "Reorganisierten": "Reorganisierte",
    "Reorganisierteren": "Reorganisiertere",
    "Reorganisierteste": "reorganisiert",
    "Reparablen": "Reparable",
    "Reparationen": "Reparation",
    "Reparaturen": "Reparatur",
    "Reparierenden": "Reparierende",
    "Reparierens": "Reparieren",
    "Reparierte": "repariert",
    "Reparierten": "Reparierte",
    "Repertoires": "Repertoire",
    "Repetitive": "repetitiv",
    "Repetitiven": "Repetitive",
    "Reportagen": "Reportage",
    "Reporte": "Report",
    "Reporten": "Report",
    "Reportern": "Reporter",
    "Reporters": "Reporter",
    "Reportes": "Report",
    "Reports": "Report",
    "Repressalien": "Repressalie",
    "Repressionen": "Repression",
    "Repressive": "repressiv",
    "Repressiven": "Repressive",
    "Reprisen": "Reprise",
    "Reproduktionen": "Reproduktion",
    "Reproduktive": "reproduktiv",
    "Reproduktiven": "Reproduktive",
    "Reproduzierenden": "Reproduzierende",
    "Reproduzierens": "Reproduzieren",
    "Reproduzierte": "reproduziert",
    "Reproduzierten": "Reproduzierte",
    "Reprographien": "Reprographie",
    "Reprokameras": "Reprokamera",
    "Repräsentanten": "Repräsentant",
    "Repräsentantinnen": "Repräsentantin",
    "Repräsentationen": "Repräsentation",
    "Repräsentative": "repräsentativ",
    "Repräsentativen": "Repräsentative",
    "Repräsentativeren": "Repräsentativere",
    "Repräsentativsten": "Repräsentativste",
    "Repräsentierenden": "Repräsentierende",
    "Repräsentierenderen": "Repräsentierendere",
    "Repräsentierens": "Repräsentieren",
    "Repräsentierte": "repräsentiert",
    "Repräsentierten": "Repräsentierte",
    "Repräsentierteren": "Repräsentiertere",
    "Repräsentierteste": "repräsentiert",
    "Reptilien": "Reptil",
    "Reptils": "Reptil",
    "Republikanern": "Republikaner",
    "Republikaners": "Republikaner",
    "Republiken": "Republik",
    "Repulsive": "repulsiv",
    "Repulsiven": "Repulsive",
    "Reputationen": "Reputation",
    "Requiems": "Requiem",
    "Requirierenden": "Requirierende",
    "Requirierens": "Requirieren",
    "Requirierte": "requiriert",
    "Requirierten": "Requirierte",
    "Requisite": "Requisit",
    "Requisiten": "Requisite",
    "Requisitionen": "Requisition",
    "Requisits": "Requisit",
    "Resektionen": "Resektion",
    "Reserven": "Reserve",
    "Reservierenden": "Reservierende",
    "Reservierens": "Reservieren",
    "Reservierte": "reserviert",
    "Reservierten": "Reservierte",
    "Reservoire": "Reservoir",
    "Reservoiren": "Reservoir",
    "Reservoirs": "Reservoir",
    "Residente": "resident",
    "Residenten": "Residente",
    "Residenteren": "Residentere",
    "Residentesten": "Residenteste",
    "Residenzen": "Residenz",
    "Residierenden": "Residierende",
    "Residierens": "Residieren",
    "Residierte": "residiert",
    "Residierten": "Residierte",
    "Residualen": "Residuale",
    "Residualeren": "Residualere",
    "Residualsten": "Residualste",
    "Resignationen": "Resignation",
    "Resignierenden": "Resignierende",
    "Resignierens": "Resignieren",
    "Resignierte": "resigniert",
    "Resignierten": "Resignierte",
    "Resignierteren": "Resigniertere",
    "Resigniertesten": "Resignierteste",
    "Resistenten": "Resistente",
    "Resistenteren": "Resistentere",
    "Resistentesten": "Resistenteste",
    "Resistierenden": "Resistierende",
    "Resistierenderen": "Resistierendere",
    "Resistierendsten": "Resistierendste",
    "Resistierens": "Resistieren",
    "Resistierte": "resistiert",
    "Resistierten": "Resistierte",
    "Resistierteren": "Resistiertere",
    "Resistiertesten": "Resistierteste",
    "Resoluten": "Resolute",
    "Resolutionen": "Resolution",
    "Resonanzen": "Resonanz",
    "Resorbierenden": "Resorbierende",
    "Resorbierenderen": "Resorbierendere",
    "Resorbierendsten": "Resorbierendste",
    "Resorbierens": "Resorbieren",
    "Resorbierte": "resorbiert",
    "Resorbierten": "Resorbierte",
    "Resorbierteren": "Resorbiertere",
    "Resorbiertesten": "Resorbierteste",
    "Resorptionen": "Resorption",
    "Resozialisierenden": "Resozialisierende",
    "Resozialisierenderen": "Resozialisierendere",
    "Resozialisierens": "Resozialisieren",
    "Resozialisierte": "resozialisiert",
    "Resozialisierten": "Resozialisierte",
    "Resozialisierteren": "Resozialisiertere",
    "Resozialisierungen": "Resozialisierung",
    "Respektabelste": "respektabel",
    "Respektabelsten": "Respektabelste",
    "Respektablen": "Respektable",
    "Respektableren": "Respektablere",
    "Respektblatte": "Respektblatt",
    "Respektblattes": "Respektblatt",
    "Respektblatts": "Respektblatt",
    "Respektblätter": "Respektblatt",
    "Respektblättern": "Respektblatt",
    "Respektierenden": "Respektierende",
    "Respektierens": "Respektieren",
    "Respektierte": "respektiert",
    "Respektierten": "Respektierte",
    "Respektierteren": "Respektiertere",
    "Respektiertesten": "Respektierteste",
    "Respektlosen": "Respektlose",
    "Respektloseren": "Respektlosere",
    "Respektlosesten": "Respektloseste",
    "Respekts": "Respekt",
    "Respektvolle": "respektvoll",
    "Respektvollen": "Respektvolle",
    "Respektvolleren": "Respektvollere",
    "Respektvollsten": "Respektvollste",
    "Respiratore": "Respirator",
    "Respiratoren": "Respirator",
    "Respirators": "Respirator",
    "Ressorts": "Ressort",
    "Ressourcen": "Ressource",
    "Restaurants": "Restaurant",
    "Restaurierungen": "Restaurierung",
    "Reste": "Rest",
    "Resten": "Rest",
    "Restes": "Rest",
    "Restliche": "restlich",
    "Restlichen": "Restliche",
    "Restlosen": "Restlose",
    "Restloseren": "Restlosere",
    "Restlosesten": "Restloseste",
    "Restrukturierenden": "Restrukturierende",
    "Restrukturierenderen": "Restrukturierendere",
    "Restrukturierens": "Restrukturieren",
    "Restrukturierte": "restrukturiert",
    "Restrukturierten": "Restrukturierte",
    "Restrukturierteren": "Restrukturiertere",
    "Rests": "Rest",
    "Resultanten": "Resultante",
    "Resultate": "Resultat",
    "Resultaten": "Resultat",
    "Resultats": "Resultat",
    "Resultierenden": "Resultierende",
    "Resultierens": "Resultieren",
    "Resultierte": "resultiert",
    "Resultierten": "Resultierte",
    "Resümierenden": "Resümierende",
    "Resümierens": "Resümieren",
    "Resümierte": "resümiert",
    "Resümierten": "Resümierte",
    "Retardationen": "Retardation",
    "Retardierenden": "Retardierende",
    "Retardierens": "Retardieren",
    "Retardierte": "retardiert",
    "Retardierten": "Retardierte",
    "Retikulosen": "Retikulose",
    "Retorsionen": "Retorsion",
    "Retroflexionen": "Retroflexion",
    "Rettenden": "Rettende",
    "Rettens": "Retten",
    "Rettern": "Retter",
    "Retters": "Retter",
    "Rettungen": "Rettung",
    "Retuschen": "Retusche",
    "Retuschierenden": "Retuschierende",
    "Retuschierens": "Retuschieren",
    "Retuschierte": "retuschiert",
    "Retuschierten": "Retuschierte",
    "Reuevollen": "Reuevolle",
    "Reuevolleren": "Reuevollere",
    "Reuevollsten": "Reuevollste",
    "Reuigen": "Reuige",
    "Reuigeren": "Reuigere",
    "Reuigsten": "Reuigste",
    "Reumütigen": "Reumütige",
    "Reumütigeren": "Reumütigere",
    "Reumütigsten": "Reumütigste",
    "Reuters": "Reuter",
    "Revanchen": "Revanche",
    "Reviere": "Revier",
    "Revieren": "Revier",
    "Revieres": "Revier",
    "Reviers": "Revier",
    "Revisionen": "Revision",
    "Revolten": "Revolte",
    "Revolutionen": "Revolution",
    "Revolutionierenden": "Revolutionierende",
    "Revolutionierenderen": "Revolutionierendere",
    "Revolutionierens": "Revolutionieren",
    "Revolutionierte": "revolutioniert",
    "Revolutionierten": "Revolutionierte",
    "Revolutionäre": "revolutionär",
    "Revolutionären": "Revolutionäre",
    "Revolutionäreren": "Revolutionärere",
    "Revolutionärsten": "Revolutionärste",
    "Revolvern": "Revolver",
    "Revolvers": "Revolver",
    "Revuen": "Revue",
    "Rexrodts": "Rexrodt",
    "Rezensenten": "Rezensent",
    "Rezensierenden": "Rezensierende",
    "Rezensierens": "Rezensieren",
    "Rezensierte": "rezensiert",
    "Rezensierten": "Rezensierte",
    "Rezensionen": "Rezension",
    "Rezepte": "Rezept",
    "Rezepten": "Rezept",
    "Rezeptes": "Rezept",
    "Rezeptfreie": "rezeptfrei",
    "Rezeptfreien": "Rezeptfreie",
    "Rezeptionen": "Rezeption",
    "Rezeptive": "rezeptiv",
    "Rezeptiven": "Rezeptive",
    "Rezeptore": "Rezeptor",
    "Rezeptoren": "Rezeptor",
    "Rezeptors": "Rezeptor",
    "Rezeptpflichtige": "rezeptpflichtig",
    "Rezeptpflichtigen": "Rezeptpflichtige",
    "Rezepts": "Rezept",
    "Rezessionen": "Rezession",
    "Rezipierenden": "Rezipierende",
    "Rezipierens": "Rezipieren",
    "Rezipierte": "rezipiert",
    "Rezipierten": "Rezipierte",
    "Rezitierenden": "Rezitierende",
    "Rezitierens": "Rezitieren",
    "Rezitierte": "rezitiert",
    "Rezitierten": "Rezitierte",
    "Rhabarbern": "Rhabarber",
    "Rhabarbers": "Rhabarber",
    "Rheingaus": "Rheingau",
    "Rheinische": "rheinisch",
    "Rheinischen": "Rheinische",
    "Rheinlands": "Rheinland",
    "Rheinländern": "Rheinländer",
    "Rheinländers": "Rheinländer",
    "Rheinländische": "rheinländisch",
    "Rheinländischen": "Rheinländische",
    "Rheins": "Rhein",
    "Rhesusfaktore": "Rhesusfaktor",
    "Rhesusfaktoren": "Rhesusfaktor",
    "Rhesusfaktors": "Rhesusfaktor",
    "Rhetorische": "rhetorisch",
    "Rhetorischen": "Rhetorische",
    "Rheumatischen": "Rheumatische",
    "Rhos": "Rho",
    "Rhyolithen": "Rhyolith",
    "Rhythmen": "Rhythmus",
    "Rhythmikern": "Rhythmiker",
    "Rhythmikers": "Rhythmiker",
    "Rhythmische": "rhythmisch",
    "Rhythmischen": "Rhythmische",
    "Rhythmischeren": "Rhythmischere",
    "Rhythmischsten": "Rhythmischste",
    "Ribbelnden": "Ribbelnde",
    "Ribbelns": "Ribbeln",
    "Richards": "Richard",
    "Richtantennen": "Richtantenne",
    "Richtbaume": "Richtbaum",
    "Richtbaums": "Richtbaum",
    "Richtbäume": "Richtbaum",
    "Richtbäumen": "Richtbaum",
    "Richtenden": "Richtende",
    "Richtens": "Richten",
    "Richterinnen": "Richterin",
    "Richterliche": "richterlich",
    "Richterlichen": "Richterliche",
    "Richtern": "Richter",
    "Richters": "Richter",
    "Richtfeste": "Richtfest",
    "Richtfesten": "Richtfest",
    "Richtfests": "Richtfest",
    "Richtfeuern": "Richtfeuer",
    "Richtfeuers": "Richtfeuer",
    "Richtgeschwindigkeiten": "Richtgeschwindigkeit",
    "Richtgrößen": "Richtgröße",
    "Richthammers": "Richthammer",
    "Richthämmer": "Richthammer",
    "Richthämmern": "Richthammer",
    "Richtige": "richtig",
    "Richtigen": "Richtige",
    "Richtigeren": "Richtigere",
    "Richtiggehenden": "Richtiggehende",
    "Richtiggelegenen": "Richtiggelegene",
    "Richtiggestellten": "Richtiggestellte",
    "Richtigliegenden": "Richtigliegende",
    "Richtigliegens": "Richtigliegen",
    "Richtigstellenden": "Richtigstellende",
    "Richtigstellens": "Richtigstellen",
    "Richtigstellungen": "Richtigstellung",
    "Richtigsten": "Richtigste",
    "Richtkronen": "Richtkrone",
    "Richtkräfte": "Richtkraft",
    "Richtkräften": "Richtkraft",
    "Richtlatten": "Richtlatte",
    "Richtlinien": "Richtlinie",
    "Richtplatten": "Richtplatte",
    "Richtpunkte": "Richtpunkt",
    "Richtpunkten": "Richtpunkt",
    "Richtpunktes": "Richtpunkt",
    "Richtpunkts": "Richtpunkt",
    "Richtungen": "Richtung",
    "Richtungslose": "richtungslos",
    "Richtungslosen": "Richtungslose",
    "Richtungsloseren": "Richtungslosere",
    "Richtungslosesten": "Richtungsloseste",
    "Richtwerte": "Richtwert",
    "Richtwerten": "Richtwert",
    "Richtwertes": "Richtwert",
    "Richtwerts": "Richtwert",
    "Richtzahlen": "Richtzahl",
    "Ricinusöle": "Ricinusöl",
    "Ricinusölen": "Ricinusöl",
    "Ricinusöls": "Ricinusöl",
    "Riechenden": "Riechende",
    "Riechenderen": "Riechendere",
    "Riechendsten": "Riechendste",
    "Riechens": "Riechen",
    "Riechern": "Riecher",
    "Riechers": "Riecher",
    "Riechfläschchens": "Riechfläschchen",
    "Riechorgane": "Riechorgan",
    "Riechorganen": "Riechorgan",
    "Riechorgans": "Riechorgan",
    "Riechwerkzeuge": "Riechwerkzeug",
    "Riechwerkzeugen": "Riechwerkzeug",
    "Riechwerkzeugs": "Riechwerkzeug",
    "Riederwalds": "Riederwald",
    "Riedrodes": "Riedrode",
    "Rieds": "Ried",
    "Riedstadts": "Riedstadt",
    "Riegel": "riegeln",
    "Riegelhauben": "Riegelhaube",
    "Riegeln": "Riegel",
    "Riegelnden": "Riegelnde",
    "Riegelns": "Riegeln",
    "Riegels": "Riegel",
    "Riegen": "Riege",
    "Riemchens": "Riemchen",
    "Riemens": "Riemen",
    "Riemenschneiders": "Riemenschneider",
    "Rieselnden": "Rieselnde",
    "Rieselnderen": "Rieselndere",
    "Rieselndsten": "Rieselndste",
    "Rieselns": "Rieseln",
    "Riesen": "Riese",
    "Riesenanstrengungen": "Riesenanstrengung",
    "Riesengroße": "riesengroß",
    "Riesengroßen": "Riesengroße",
    "Riesenhaften": "Riesenhafte",
    "Riesenhafteren": "Riesenhaftere",
    "Riesenhaftesten": "Riesenhafteste",
    "Riesenschritte": "Riesenschritt",
    "Riesenschritten": "Riesenschritt",
    "Riesenschritts": "Riesenschritt",
    "Riesige": "riesig",
    "Riesigen": "Riesige",
    "Riesigeren": "Riesigere",
    "Riesigsten": "Riesigste",
    "Riffel": "riffeln",
    "Riffeln": "Riffel",
    "Riffelnden": "Riffelnde",
    "Riffelns": "Riffeln",
    "Rigiden": "Rigide",
    "Rigorosen": "Rigorose",
    "Rigoroseren": "Rigorosere",
    "Rigorosesten": "Rigoroseste",
    "Rikschas": "Rikscha",
    "Rille": "rillen",
    "Rillen": "Rille",
    "Rillenden": "Rillende",
    "Rillenderen": "Rillendere",
    "Rillendsten": "Rillendste",
    "Rillens": "Rillen",
    "Rinde": "rinden",
    "Rinden": "Rinde",
    "Rindenden": "Rindende",
    "Rindens": "Rinden",
    "Rinder": "Rind",
    "Rindern": "Rind",
    "Rindes": "Rind",
    "Ring": "ringen",
    "Ringbuche": "Ringbuch",
    "Ringbuches": "Ringbuch",
    "Ringbuchs": "Ringbuch",
    "Ringbücher": "Ringbuch",
    "Ringbüchern": "Ringbuch",
    "Ringe": "ringen",
    "Ringeligen": "Ringelige",
    "Ringelnden": "Ringelnde",
    "Ringelnderen": "Ringelndere",
    "Ringelndsten": "Ringelndste",
    "Ringelns": "Ringeln",
    "Ringen": "Ring",
    "Ringenden": "Ringende",
    "Ringenderen": "Ringendere",
    "Ringendsten": "Ringendste",
    "Ringens": "Ringen",
    "Ringern": "Ringer",
    "Ringers": "Ringer",
    "Ringförmigen": "Ringförmige",
    "Ringleins": "Ringlein",
    "Rings": "Ring",
    "Rinnen": "Rinne",
    "Rinnenden": "Rinnende",
    "Rinnenderen": "Rinnendere",
    "Rinnendsten": "Rinnendste",
    "Rinnens": "Rinnen",
    "Rios": "Rio",
    "Rippchens": "Rippchen",
    "Rippe": "rippen",
    "Rippen": "Rippe",
    "Rippenden": "Rippende",
    "Rippenderen": "Rippendere",
    "Rippendsten": "Rippendste",
    "Rippens": "Rippen",
    "Risiken": "Risiko",
    "Risikoreiche": "risikoreich",
    "Risikoreichen": "Risikoreiche",
    "Risikoreicheren": "Risikoreichere",
    "Risikoreichsten": "Risikoreichste",
    "Risikos": "Risiko",
    "Riskante": "riskant",
    "Riskanten": "Riskante",
    "Riskanteren": "Riskantere",
    "Riskantesten": "Riskanteste",
    "Riskierenden": "Riskierende",
    "Riskierens": "Riskieren",
    "Riskierte": "riskiert",
    "Riskierten": "Riskierte",
    "Risse": "Riß",
    "Rissen": "Riß",
    "Risses": "Riß",
    "Rissigen": "Rissige",
    "Rissigeren": "Rissigere",
    "Rissigsten": "Rissigste",
    "Ritas": "Rita",
    "Ritt": "reiten",
    "Ritte": "Ritt",
    "Ritten": "Ritt",
    "Ritterakademien": "Ritterakademie",
    "Ritterliche": "ritterlich",
    "Ritterlichen": "Ritterliche",
    "Ritterlicheren": "Ritterlichere",
    "Ritterlichsten": "Ritterlichste",
    "Rittern": "Ritter",
    "Ritters": "Ritter",
    "Rittertums": "Rittertum",
    "Rittmeistern": "Rittmeister",
    "Rittmeisters": "Rittmeister",
    "Ritts": "Ritt",
    "Rituale": "Ritual",
    "Ritualen": "Ritual",
    "Ritualisierenden": "Ritualisierende",
    "Ritualisierens": "Ritualisieren",
    "Ritualisierte": "ritualisiert",
    "Ritualisierten": "Ritualisierte",
    "Ritualisten": "Ritualist",
    "Rituals": "Ritual",
    "Ritze": "ritzen",
    "Ritzeln": "Ritzel",
    "Ritzels": "Ritzel",
    "Ritzen": "Ritze",
    "Ritzenden": "Ritzende",
    "Ritzens": "Ritzen",
    "Rivalen": "Rivale",
    "Rivales": "Rivale",
    "Robbe": "robben",
    "Robben": "Robbe",
    "Robbenden": "Robbende",
    "Robbens": "Robben",
    "Roben": "Robe",
    "Roberts": "Robert",
    "Robins": "Robin",
    "Robotern": "Roboter",
    "Roboters": "Roboter",
    "Robuste": "robust",
    "Robusten": "Robuste",
    "Robusteren": "Robustere",
    "Robustesten": "Robusteste",
    "Rocke": "Rock",
    "Rocks": "Rock",
    "Rodelbahnen": "Rodelbahn",
    "Rodelnden": "Rodelnde",
    "Rodelnderen": "Rodelndere",
    "Rodelndsten": "Rodelndste",
    "Rodelns": "Rodeln",
    "Rodelschlittens": "Rodelschlitten",
    "Rodenbachs": "Rodenbach",
    "Rodenden": "Rodende",
    "Rodenderen": "Rodendere",
    "Rodendsten": "Rodendste",
    "Rodens": "Roden",
    "Rodgauern": "Rodgauer",
    "Rodgauers": "Rodgauer",
    "Rodgaus": "Rodgau",
    "Rodheims": "Rodheim",
    "Rodungen": "Rodung",
    "Rogers": "Roger",
    "Roggens": "Roggen",
    "Rohbilanzen": "Rohbilanz",
    "Rohdes": "Rohde",
    "Rohe": "roh",
    "Rohen": "Rohe",
    "Roheren": "Rohere",
    "Rohesten": "Roheste",
    "Rohgewichte": "Rohgewicht",
    "Rohgewichten": "Rohgewicht",
    "Rohgewichts": "Rohgewicht",
    "Rohgusse": "Rohguß",
    "Rohgusses": "Rohguß",
    "Rohgüsse": "Rohguß",
    "Rohgüssen": "Rohguß",
    "Rohre": "Rohr",
    "Rohren": "Rohr",
    "Rohres": "Rohr",
    "Rohrs": "Rohr",
    "Rohstoffe": "Rohstoff",
    "Rohstoffen": "Rohstoff",
    "Rohstoffs": "Rohstoff",
    "Rolands": "Roland",
    "Rolfs": "Rolf",
    "Rolladens": "Rolladen",
    "Rollbrette": "Rollbrett",
    "Rollbretter": "Rollbrett",
    "Rollbrettern": "Rollbrett",
    "Rollbrettes": "Rollbrett",
    "Rollbretts": "Rollbrett",
    "Rolle": "rollen",
    "Rollen": "Rolle",
    "Rollenden": "Rollende",
    "Rollens": "Rollen",
    "Rollern": "Roller",
    "Rollers": "Roller",
    "Rollfelde": "Rollfeld",
    "Rollfelder": "Rollfeld",
    "Rollfeldern": "Rollfeld",
    "Rollfeldes": "Rollfeld",
    "Rollfelds": "Rollfeld",
    "Rollis": "Rolli",
    "Rollkommandos": "Rollkommando",
    "Rollschlangen": "Rollschlange",
    "Rollschuhe": "Rollschuh",
    "Rollschuhen": "Rollschuh",
    "Rollschuhes": "Rollschuh",
    "Rollschuhs": "Rollschuh",
    "Rollstuhle": "Rollstuhl",
    "Rollstuhles": "Rollstuhl",
    "Rollstuhls": "Rollstuhl",
    "Rollstühle": "Rollstuhl",
    "Rollstühlen": "Rollstuhl",
    "Rollwagens": "Rollwagen",
    "Rollwäschen": "Rollwäsche",
    "Rolläden": "Rolladen",
    "Romane": "Roman",
    "Romanen": "Roman",
    "Romanische": "romanisch",
    "Romanischen": "Romanische",
    "Romanisten": "Romanist",
    "Romanistische": "romanistisch",
    "Romanistischen": "Romanistische",
    "Romans": "Roman",
    "Romantikern": "Romantiker",
    "Romantikers": "Romantiker",
    "Romantische": "romantisch",
    "Romantischen": "Romantische",
    "Romantischeren": "Romantischere",
    "Romantischsten": "Romantischste",
    "Romanzen": "Romanze",
    "Romas": "Roma",
    "Romeos": "Romeo",
    "Roms": "Rom",
    "Ronalds": "Ronald",
    "Rondelle": "Rondell",
    "Rondellen": "Rondell",
    "Rondells": "Rondell",
    "Ronneburgs": "Ronneburg",
    "Rosarios": "Rosario",
    "Rosbachern": "Rosbacher",
    "Rosbachers": "Rosbacher",
    "Rosbachs": "Rosbach",
    "Rosen": "Rose",
    "Rosetten": "Rosette",
    "Rosige": "rosig",
    "Rosigen": "Rosige",
    "Rosigeren": "Rosigere",
    "Rosigsten": "Rosigste",
    "Rosinen": "Rosine",
    "Roste": "rosten",
    "Rosten": "Rost",
    "Rostenden": "Rostende",
    "Rostenderen": "Rostendere",
    "Rostendsten": "Rostendste",
    "Rostens": "Rosten",
    "Rostes": "Rost",
    "Rostfreien": "Rostfreie",
    "Rostigen": "Rostige",
    "Rostigeren": "Rostigere",
    "Rostigsten": "Rostigste",
    "Rostockern": "Rostocker",
    "Rostockers": "Rostocker",
    "Rostocks": "Rostock",
    "Rotationen": "Rotation",
    "Rote": "rot",
    "Roten": "Rote",
    "Roteren": "Rotere",
    "Rotesten": "Roteste",
    "Rotfedern": "Rotfeder",
    "Rotgardisten": "Rotgardist",
    "Rothaarige": "rothaarig",
    "Rothaarigen": "Rothaarige",
    "Rothenburgs": "Rothenburg",
    "Rothmanns": "Rothmann",
    "Roths": "Roth",
    "Rotierenden": "Rotierende",
    "Rotierenderen": "Rotierendere",
    "Rotierendsten": "Rotierendste",
    "Rotierens": "Rotieren",
    "Rotierte": "rotiert",
    "Rotierten": "Rotierte",
    "Rotkreuzlerinnen": "Rotkreuzlerin",
    "Rotkreuzlern": "Rotkreuzler",
    "Rotkreuzlers": "Rotkreuzler",
    "Rotore": "Rotor",
    "Rotoren": "Rotor",
    "Rotors": "Rotor",
    "Rots": "Rot",
    "Rotstifte": "Rotstift",
    "Rotstiften": "Rotstift",
    "Rotstifts": "Rotstift",
    "Rotte": "rotten",
    "Rotten": "Rotte",
    "Rottenden": "Rottende",
    "Rottens": "Rotten",
    "Rotzenden": "Rotzende",
    "Rotzenderen": "Rotzendere",
    "Rotzendsten": "Rotzendste",
    "Rotzens": "Rotzen",
    "Rotzfrechen": "Rotzfreche",
    "Rotzigen": "Rotzige",
    "Rotzigeren": "Rotzigere",
    "Rotzigsten": "Rotzigste",
    "Rouladen": "Roulade",
    "Rouletten": "Roulette",
    "Rousseaus": "Rousseau",
    "Routen": "Route",
    "Routinen": "Routine",
    "Rowdys": "Rowdy",
    "Rowohlts": "Rowohlt",
    "Roys": "Roy",
    "Ruandas": "Ruanda",
    "Rubbeligen": "Rubbelige",
    "Rubbeligeren": "Rubbeligere",
    "Rubbeligsten": "Rubbeligste",
    "Rubbelnden": "Rubbelnde",
    "Rubbelnderen": "Rubbelndere",
    "Rubbelndsten": "Rubbelndste",
    "Rubbelns": "Rubbeln",
    "Rubels": "Rubel",
    "Rubine": "Rubin",
    "Rubinen": "Rubin",
    "Rubines": "Rubin",
    "Rubins": "Rubin",
    "Rubriken": "Rubrik",
    "Ruckartige": "ruckartig",
    "Ruckartigen": "Ruckartige",
    "Ruckartigeren": "Ruckartigere",
    "Ruckartigsten": "Ruckartigste",
    "Ruckelnden": "Ruckelnde",
    "Ruckelnderen": "Ruckelndere",
    "Ruckelndsten": "Ruckelndste",
    "Ruckelns": "Ruckeln",
    "Rucksacke": "Rucksack",
    "Rucksacks": "Rucksack",
    "Rucksäcke": "Rucksack",
    "Rucksäcken": "Rucksack",
    "Rudeln": "Rudel",
    "Rudels": "Rudel",
    "Ruder": "rudern",
    "Ruderboote": "Ruderboot",
    "Ruderbooten": "Ruderboot",
    "Ruderboots": "Ruderboot",
    "Ruderern": "Ruderer",
    "Ruderers": "Ruderer",
    "Rudern": "Ruder",
    "Rudernden": "Rudernde",
    "Rudernderen": "Ruderndere",
    "Ruderndsten": "Ruderndste",
    "Ruderns": "Rudern",
    "Ruders": "Ruder",
    "Ruderstangen": "Ruderstange",
    "Ruderzeichens": "Ruderzeichen",
    "Rudimentäre": "rudimentär",
    "Rudimentären": "Rudimentäre",
    "Rudimentäreren": "Rudimentärere",
    "Rudimentärsten": "Rudimentärste",
    "Rudis": "Rudi",
    "Rudolfs": "Rudolf",
    "Rudys": "Rudy",
    "Ruf": "rufen",
    "Rufe": "rufen",
    "Rufen": "Ruf",
    "Rufenden": "Rufende",
    "Rufens": "Rufen",
    "Rufes": "Ruf",
    "Rufs": "Ruf",
    "Ruhelose": "ruhelos",
    "Ruhelosen": "Ruhelose",
    "Ruheloseren": "Ruhelosere",
    "Ruhelosesten": "Ruheloseste",
    "Ruhen": "Ruhe",
    "Ruhenden": "Ruhende",
    "Ruhenderen": "Ruhendere",
    "Ruhendsten": "Ruhendste",
    "Ruhens": "Ruhen",
    "Ruhestands": "Ruhestand",
    "Ruhestörende": "ruhestörend",
    "Ruhestörenden": "Ruhestörende",
    "Ruhigen": "Ruhige",
    "Ruhigeren": "Ruhigere",
    "Ruhigsten": "Ruhigste",
    "Ruhleders": "Ruhleder",
    "Ruhme": "Ruhm",
    "Ruhmes": "Ruhm",
    "Ruhmreichen": "Ruhmreiche",
    "Ruhmreicheren": "Ruhmreichere",
    "Ruhmreichsten": "Ruhmreichste",
    "Ruhms": "Ruhm",
    "Ruinen": "Ruine",
    "Ruinierenden": "Ruinierende",
    "Ruinierenderen": "Ruinierendere",
    "Ruinierendsten": "Ruinierendste",
    "Ruinierens": "Ruinieren",
    "Ruinierte": "ruiniert",
    "Ruinierten": "Ruinierte",
    "Ruinierteren": "Ruiniertere",
    "Ruiniertesten": "Ruinierteste",
    "Ruins": "Ruin",
    "Ruinösen": "Ruinöse",
    "Ruinöseren": "Ruinösere",
    "Ruinösesten": "Ruinöseste",
    "Rumbas": "Rumba",
    "Rumgehangenen": "Rumgehangene",
    "Rumgehängten": "Rumgehängte",
    "Rumhängenden": "Rumhängende",
    "Rumhängenderen": "Rumhängendere",
    "Rumhängendsten": "Rumhängendste",
    "Rumhängens": "Rumhängen",
    "Rummeln": "Rummel",
    "Rummels": "Rummel",
    "Rumor": "rumoren",
    "Rumorenden": "Rumorende",
    "Rumorenderen": "Rumorendere",
    "Rumorendsten": "Rumorendste",
    "Rumorens": "Rumoren",
    "Rumorn": "Rumor",
    "Rumors": "Rumor",
    "Rumorte": "rumort",
    "Rumorten": "Rumorte",
    "Rumpenheims": "Rumpenheim",
    "Rumpfbeugen": "Rumpfbeuge",
    "Rumpfe": "Rumpf",
    "Rumpfes": "Rumpf",
    "Rumpfs": "Rumpf",
    "Rums": "Rum",
    "Rumänen": "Rumäne",
    "Rumäniens": "Rumänien",
    "Rumänische": "rumänisch",
    "Rumänischen": "Rumänische",
    "Rundbeete": "Rundbeet",
    "Rundbeeten": "Rundbeet",
    "Rundbeets": "Rundbeet",
    "Rundblicke": "Rundblick",
    "Rundblicken": "Rundblick",
    "Rundblicks": "Rundblick",
    "Rundbogens": "Rundbogen",
    "Rundbriefe": "Rundbrief",
    "Rundbriefen": "Rundbrief",
    "Rundbriefs": "Rundbrief",
    "Rundbänke": "Rundbank",
    "Rundbänken": "Rundbank",
    "Runde": "Rund",
    "Runden": "Runde",
    "Rundenden": "Rundende",
    "Rundens": "Runden",
    "Runderen": "Rundere",
    "Runderneuerungen": "Runderneuerung",
    "Rundes": "Rund",
    "Rundesten": "Rundeste",
    "Rundfahrkarten": "Rundfahrkarte",
    "Rundfeilen": "Rundfeile",
    "Rundfunks": "Rundfunk",
    "Rundliche": "rundlich",
    "Rundlichen": "Rundliche",
    "Rundlicheren": "Rundlichere",
    "Rundlichsten": "Rundlichste",
    "Runds": "Rund",
    "Rundungen": "Rundung",
    "Runtergesetzten": "Runtergesetzte",
    "Runtergesetzteren": "Runtergesetztere",
    "Runtergezogenen": "Runtergezogene",
    "Runtersetzenden": "Runtersetzende",
    "Runtersetzens": "Runtersetzen",
    "Runterziehenden": "Runterziehende",
    "Runterziehens": "Runterziehen",
    "Runzeligen": "Runzelige",
    "Runzeligeren": "Runzeligere",
    "Runzeligsten": "Runzeligste",
    "Runzelnden": "Runzelnde",
    "Runzelnderen": "Runzelndere",
    "Runzelndsten": "Runzelndste",
    "Runzelns": "Runzeln",
    "Runzligen": "Runzlige",
    "Runzligeren": "Runzligere",
    "Runzligsten": "Runzligste",
    "Rupfenden": "Rupfende",
    "Rupfenderen": "Rupfendere",
    "Rupfendsten": "Rupfendste",
    "Rupfens": "Rupfen",
    "Ruppigen": "Ruppige",
    "Ruppigeren": "Ruppigere",
    "Ruppigsten": "Ruppigste",
    "Rushdies": "Rushdie",
    "Russen": "Russe",
    "Russische": "russisch",
    "Russischen": "Russische",
    "Rustikalen": "Rustikale",
    "Rustikaleren": "Rustikalere",
    "Rustikalsten": "Rustikalste",
    "Ruten": "Rute",
    "Ruths": "Ruth",
    "Rutsche": "rutschen",
    "Rutschen": "Rutsche",
    "Rutschenden": "Rutschende",
    "Rutschens": "Rutschen",
    "Rutschfesten": "Rutschfeste",
    "Rutschfesteren": "Rutschfestere",
    "Rutschfestesten": "Rutschfesteste",
    "Rutschigen": "Rutschige",
    "Rutschigeren": "Rutschigere",
    "Rutschigsten": "Rutschigste",
    "Rutschpartien": "Rutschpartie",
    "Rutschsichere": "rutschsicher",
    "Rutschsicheren": "Rutschsichere",
    "Rutschsichereren": "Rutschsicherere",
    "Rutschsichersten": "Rutschsicherste",
    "Ruße": "Ruß",
    "Rußes": "Ruß",
    "Rußlands": "Rußland",
    "Rybikowas": "Rybikowa",
    "Rächenden": "Rächende",
    "Rächens": "Rächen",
    "Rädchens": "Rädchen",
    "Räder": "rädern",
    "Rädern": "Rad",
    "Rädernden": "Rädernde",
    "Räderns": "Rädern",
    "Räkelnden": "Räkelnde",
    "Räkelnderen": "Räkelndere",
    "Räkelndsten": "Räkelndste",
    "Räkelns": "Räkeln",
    "Ränder": "Rand",
    "Rändern": "Rand",
    "Ränge": "ringen",
    "Rängen": "ringen",
    "Ränzchens": "Ränzchen",
    "Räte": "Rat",
    "Räten": "Rat",
    "Rätsel": "rätseln",
    "Rätselhaften": "Rätselhafte",
    "Rätselhafteren": "Rätselhaftere",
    "Rätselhaftesten": "Rätselhafteste",
    "Rätseln": "Rätsel",
    "Rätselnden": "Rätselnde",
    "Rätselnderen": "Rätselndere",
    "Rätselndsten": "Rätselndste",
    "Rätselns": "Rätseln",
    "Rätsels": "Rätsel",
    "Räuberische": "räuberisch",
    "Räuberischen": "Räuberische",
    "Räubern": "Räuber",
    "Räubers": "Räuber",
    "Räuchernden": "Räuchernde",
    "Räucherns": "Räuchern",
    "Räucherwaren": "Räucherware",
    "Räudige": "räudig",
    "Räudigen": "Räudige",
    "Räudigeren": "Räudigere",
    "Räudigsten": "Räudigste",
    "Räumchens": "Räumchen",
    "Räume": "räumen",
    "Räumen": "Raum",
    "Räumenden": "Räumende",
    "Räumens": "Räumen",
    "Räumern": "Räumer",
    "Räumers": "Räumer",
    "Räumliche": "räumlich",
    "Räumlichen": "Räumliche",
    "Räumlichkeiten": "Räumlichkeit",
    "Räumungen": "Räumung",
    "Räusche": "Rausch",
    "Räuschen": "Rausch",
    "Räuspernden": "Räuspernde",
    "Räuspernderen": "Räusperndere",
    "Räusperndsten": "Räusperndste",
    "Räusperns": "Räuspern",
    "Röchelnden": "Röchelnde",
    "Röchelnderen": "Röchelndere",
    "Röchelndsten": "Röchelndste",
    "Röchelns": "Röcheln",
    "Röcke": "Rock",
    "Röcken": "Rock",
    "Rödelheimern": "Rödelheimer",
    "Rödelheimers": "Rödelheimer",
    "Rödelheims": "Rödelheim",
    "Röhrchens": "Röhrchen",
    "Röhren": "Röhre",
    "Röhrs": "Röhr",
    "Römerinnen": "Römerin",
    "Römern": "Römer",
    "Römers": "Römer",
    "Römische": "römisch",
    "Römischen": "Römische",
    "Röntgenaufnahmen": "Röntgenaufnahme",
    "Röntgenbilde": "Röntgenbild",
    "Röntgenbilder": "Röntgenbild",
    "Röntgenbildern": "Röntgenbild",
    "Röntgenbildes": "Röntgenbild",
    "Röntgenbilds": "Röntgenbild",
    "Röntgenden": "Röntgende",
    "Röntgenologen": "Röntgenologe",
    "Röntgens": "Röntgen",
    "Röschens": "Röschen",
    "Rösleins": "Röslein",
    "Röstende": "röstend",
    "Röstenden": "Röstende",
    "Röstendere": "röstend",
    "Röstenderen": "Röstendere",
    "Röstendste": "röstend",
    "Röstendsten": "Röstendste",
    "Röstens": "Rösten",
    "Röstereien": "Rösterei",
    "Röstfrischen": "Röstfrische",
    "Rötenden": "Rötende",
    "Rötenderen": "Rötendere",
    "Rötendsten": "Rötendste",
    "Rötens": "Röten",
    "Rötliche": "rötlich",
    "Rötlichen": "Rötliche",
    "Röttingens": "Röttingen",
    "Rötungen": "Rötung",
    "Rößchens": "Rößchen",
    "Rübchens": "Rübchen",
    "Rüben": "Rübe",
    "Rückantworten": "Rückantwort",
    "Rückbewegungen": "Rückbewegung",
    "Rückbildungen": "Rückbildung",
    "Rückblenden": "Rückblende",
    "Rückblicke": "rückblicken",
    "Rückblicken": "Rückblick",
    "Rückblickenden": "Rückblickende",
    "Rückblickens": "Rückblicken",
    "Rückblickes": "Rückblick",
    "Rückblicks": "Rückblick",
    "Rückbuchungen": "Rückbuchung",
    "Rückbürgschaften": "Rückbürgschaft",
    "Rückdatierenden": "Rückdatierende",
    "Rückdatierens": "Rückdatieren",
    "Rückdatierte": "rückdatiert",
    "Rückdatierten": "Rückdatierte",
    "Rückenden": "Rückende",
    "Rückens": "Rücken",
    "Rückentwicklungen": "Rückentwicklung",
    "Rückerinnerungen": "Rückerinnerung",
    "Rückerstattenden": "Rückerstattende",
    "Rückerstattens": "Rückerstatten",
    "Rückerstattete": "rückerstattet",
    "Rückerstatteten": "Rückerstattete",
    "Rückfahrscheinwerfern": "Rückfahrscheinwerfer",
    "Rückfahrscheinwerfers": "Rückfahrscheinwerfer",
    "Rückfalle": "Rückfall",
    "Rückfalles": "Rückfall",
    "Rückfalls": "Rückfall",
    "Rückfrachten": "Rückfracht",
    "Rückfragen": "Rückfrage",
    "Rückfälle": "Rückfall",
    "Rückfällen": "Rückfall",
    "Rückfällige": "rückfällig",
    "Rückfälligen": "Rückfällige",
    "Rückfälligeren": "Rückfälligere",
    "Rückfälligsten": "Rückfälligste",
    "Rückführungen": "Rückführung",
    "Rückgange": "Rückgang",
    "Rückgangs": "Rückgang",
    "Rückgebildete": "rückgebildet",
    "Rückgebildeten": "Rückgebildete",
    "Rückgeblickten": "Rückgeblickte",
    "Rückgekoppelten": "Rückgekoppelte",
    "Rückgrate": "Rückgrat",
    "Rückgraten": "Rückgrat",
    "Rückgrats": "Rückgrat",
    "Rückgriffe": "Rückgriff",
    "Rückgriffen": "Rückgriff",
    "Rückgriffs": "Rückgriff",
    "Rückgänge": "Rückgang",
    "Rückgängen": "Rückgang",
    "Rückgängige": "rückgängig",
    "Rückgängigen": "Rückgängige",
    "Rückhalts": "Rückhalt",
    "Rückkaufe": "Rückkauf",
    "Rückkaufs": "Rückkauf",
    "Rückkreuzungen": "Rückkreuzung",
    "Rückkäufe": "Rückkauf",
    "Rückkäufen": "Rückkauf",
    "Rückladungen": "Rückladung",
    "Rücklaufbremsen": "Rücklaufbremse",
    "Rücklaufe": "Rücklauf",
    "Rücklaufs": "Rücklauf",
    "Rücklauftasten": "Rücklauftaste",
    "Rücklichte": "Rücklicht",
    "Rücklichter": "Rücklicht",
    "Rücklichtern": "Rücklicht",
    "Rücklichtes": "Rücklicht",
    "Rücklichts": "Rücklicht",
    "Rückläufe": "Rücklauf",
    "Rückläufen": "Rücklauf",
    "Rückläufern": "Rückläufer",
    "Rückläufers": "Rückläufer",
    "Rückläufige": "rückläufig",
    "Rückläufigen": "Rückläufige",
    "Rückmarsche": "Rückmarsch",
    "Rückmarschs": "Rückmarsch",
    "Rückmeldungen": "Rückmeldung",
    "Rückmärsche": "Rückmarsch",
    "Rückmärschen": "Rückmarsch",
    "Rücknahmen": "Rücknahme",
    "Rückprojektionen": "Rückprojektion",
    "Rückrufe": "Rückruf",
    "Rückrufen": "Rückruf",
    "Rückrufs": "Rückruf",
    "Rückschalttasten": "Rückschalttaste",
    "Rückschlage": "Rückschlag",
    "Rückschlags": "Rückschlag",
    "Rückschläge": "Rückschlag",
    "Rückschlägen": "Rückschlag",
    "Rückschritte": "Rückschritt",
    "Rückschritten": "Rückschritt",
    "Rückschrittlern": "Rückschrittler",
    "Rückschrittlers": "Rückschrittler",
    "Rückschrittliche": "rückschrittlich",
    "Rückschrittlichen": "Rückschrittliche",
    "Rückschritts": "Rückschritt",
    "Rückseiten": "Rückseite",
    "Rückseitige": "rückseitig",
    "Rückseitigen": "Rückseitige",
    "Rücksendungen": "Rücksendung",
    "Rücksichten": "Rücksicht",
    "Rücksichtslose": "rücksichtslos",
    "Rücksichtslosen": "Rücksichtslose",
    "Rücksichtsloseren": "Rücksichtslosere",
    "Rücksichtsvollen": "Rücksichtsvolle",
    "Rücksichtsvolleren": "Rücksichtsvollere",
    "Rückspiegeln": "Rückspiegel",
    "Rückspiegels": "Rückspiegel",
    "Rücksprunge": "Rücksprung",
    "Rücksprungs": "Rücksprung",
    "Rücksprünge": "Rücksprung",
    "Rücksprüngen": "Rücksprung",
    "Rückstande": "Rückstand",
    "Rückstands": "Rückstand",
    "Rückstelltasten": "Rückstelltaste",
    "Rückstellungen": "Rückstellung",
    "Rückstrome": "Rückstrom",
    "Rückstroms": "Rückstrom",
    "Rückströme": "Rückstrom",
    "Rückströmen": "Rückstrom",
    "Rückstände": "Rückstand",
    "Rückständen": "Rückstand",
    "Rückständige": "rückständig",
    "Rückständigen": "Rückständige",
    "Rücktasten": "Rücktaste",
    "Rücktritte": "Rücktritt",
    "Rücktritten": "Rücktritt",
    "Rücktritts": "Rücktritt",
    "Rückversichernden": "Rückversichernde",
    "Rückversicherns": "Rückversichern",
    "Rückversicherte": "rückversichert",
    "Rückversicherten": "Rückversicherte",
    "Rückversicherungen": "Rückversicherung",
    "Rückwanderern": "Rückwanderer",
    "Rückwanderers": "Rückwanderer",
    "Rückwege": "Rückweg",
    "Rückwegen": "Rückweg",
    "Rückwegs": "Rückweg",
    "Rückwirkende": "rückwirkend",
    "Rückwirkenden": "Rückwirkende",
    "Rückwirkungen": "Rückwirkung",
    "Rückwände": "Rückwand",
    "Rückwänden": "Rückwand",
    "Rückwärtige": "rückwärtig",
    "Rückwärtigen": "Rückwärtige",
    "Rückwärtsgegangenen": "Rückwärtsgegangene",
    "Rückwärtsgehenden": "Rückwärtsgehende",
    "Rückwärtsgehens": "Rückwärtsgehen",
    "Rückzahlungen": "Rückzahlung",
    "Rückziehern": "Rückzieher",
    "Rückziehers": "Rückzieher",
    "Rückzolle": "Rückzoll",
    "Rückzolls": "Rückzoll",
    "Rückzuge": "Rückzug",
    "Rückzuges": "Rückzug",
    "Rückzugs": "Rückzug",
    "Rückzölle": "Rückzoll",
    "Rückzöllen": "Rückzoll",
    "Rückzüge": "Rückzug",
    "Rückzügen": "Rückzug",
    "Rückäußerungen": "Rückäußerung",
    "Rückübersetzungen": "Rückübersetzung",
    "Rüderen": "Rüdere",
    "Rüdesten": "Rüdeste",
    "Rüdigers": "Rüdiger",
    "Rüffeln": "Rüffel",
    "Rüffels": "Rüffel",
    "Rügen": "Rüge",
    "Rügenden": "Rügende",
    "Rügenderen": "Rügendere",
    "Rügendsten": "Rügendste",
    "Rügens": "Rügen",
    "Rühes": "Rühe",
    "Rühmenden": "Rühmende",
    "Rühmenderen": "Rühmendere",
    "Rühmendsten": "Rühmendste",
    "Rühmens": "Rühmen",
    "Rühmlichen": "Rühmliche",
    "Rühmlicheren": "Rühmlichere",
    "Rühmlichsten": "Rühmlichste",
    "Rührenden": "Rührende",
    "Rührenderen": "Rührendere",
    "Rührendsten": "Rührendste",
    "Rührens": "Rühren",
    "Rührigen": "Rührige",
    "Rührigeren": "Rührigere",
    "Rührigsten": "Rührigste",
    "Rührseligen": "Rührselige",
    "Rührseligeren": "Rührseligere",
    "Rührseligsten": "Rührseligste",
    "Rülpsenden": "Rülpsende",
    "Rülpsenderen": "Rülpsendere",
    "Rülpsendsten": "Rülpsendste",
    "Rülpsens": "Rülpsen",
    "Rümpfe": "rümpfen",
    "Rümpfen": "Rumpf",
    "Rümpfenden": "Rümpfende",
    "Rümpfens": "Rümpfen",
    "Rüpelhaften": "Rüpelhafte",
    "Rüpelhafteren": "Rüpelhaftere",
    "Rüpelhaftesten": "Rüpelhafteste",
    "Rüsseln": "Rüssel",
    "Rüssels": "Rüssel",
    "Rüsselsheimern": "Rüsselsheimer",
    "Rüsselsheimers": "Rüsselsheimer",
    "Rüsselsheims": "Rüsselsheim",
    "Rüstbalkens": "Rüstbalken",
    "Rüstenden": "Rüstende",
    "Rüstenderen": "Rüstendere",
    "Rüstendsten": "Rüstendste",
    "Rüstens": "Rüsten",
    "Rüstigen": "Rüstige",
    "Rüstigeren": "Rüstigere",
    "Rüstigsten": "Rüstigste",
    "Rüststangen": "Rüststange",
    "Rüstungen": "Rüstung",
    "Rüstzeuge": "Rüstzeug",
    "Rüstzeugen": "Rüstzeug",
    "Rüstzeugs": "Rüstzeug",
    "Rüttelnden": "Rüttelnde",
    "Rüttelns": "Rütteln",
    "Saals": "Saal",
    "Saarbrückens": "Saarbrücken",
    "Saarbrückern": "Saarbrücker",
    "Saarbrückers": "Saarbrücker",
    "Saarlands": "Saarland",
    "Saarländern": "Saarländer",
    "Saarländers": "Saarländer",
    "Saarländische": "saarländisch",
    "Saarländischen": "Saarländische",
    "Saaten": "Saat",
    "Saatgute": "Saatgut",
    "Saatgutes": "Saatgut",
    "Saatguts": "Saatgut",
    "Saatgüter": "Saatgut",
    "Saatgütern": "Saatgut",
    "Sabbatjahre": "Sabbatjahr",
    "Sabbatjahren": "Sabbatjahr",
    "Sabbatjahrs": "Sabbatjahr",
    "Sabbelkopfe": "Sabbelkopf",
    "Sabbelkopfs": "Sabbelkopf",
    "Sabbelköpfe": "Sabbelkopf",
    "Sabbelköpfen": "Sabbelkopf",
    "Sabbelnden": "Sabbelnde",
    "Sabbelnderen": "Sabbelndere",
    "Sabbelndsten": "Sabbelndste",
    "Sabbelns": "Sabbeln",
    "Sabber": "sabbern",
    "Sabbernden": "Sabbernde",
    "Sabbernderen": "Sabberndere",
    "Sabberndsten": "Sabberndste",
    "Sabberns": "Sabbern",
    "Sabbers": "Sabber",
    "Sabines": "Sabine",
    "Sabotagen": "Sabotage",
    "Sabotierenden": "Sabotierende",
    "Sabotierens": "Sabotieren",
    "Sabotierte": "sabotiert",
    "Sabotierten": "Sabotierte",
    "Sachbearbeitern": "Sachbearbeiter",
    "Sachbearbeiters": "Sachbearbeiter",
    "Sachbeschädigungen": "Sachbeschädigung",
    "Sachbuche": "Sachbuch",
    "Sachbuches": "Sachbuch",
    "Sachbuchs": "Sachbuch",
    "Sachbücher": "Sachbuch",
    "Sachbüchern": "Sachbuch",
    "Sachdienliche": "sachdienlich",
    "Sachdienlichen": "Sachdienliche",
    "Sachen": "Sache",
    "Sachgebiete": "Sachgebiet",
    "Sachgebieten": "Sachgebiet",
    "Sachgebiets": "Sachgebiet",
    "Sachgemäße": "sachgemäß",
    "Sachgemäßen": "Sachgemäße",
    "Sachgründungen": "Sachgründung",
    "Sachkennern": "Sachkenner",
    "Sachkenners": "Sachkenner",
    "Sachkundige": "sachkundig",
    "Sachkundigen": "Sachkundige",
    "Sachkundigeren": "Sachkundigere",
    "Sachkundigsten": "Sachkundigste",
    "Sachlichen": "Sachliche",
    "Sachlicheren": "Sachlichere",
    "Sachlichsten": "Sachlichste",
    "Sachschadens": "Sachschaden",
    "Sachschäden": "Sachschaden",
    "Sachsenhausens": "Sachsenhausen",
    "Sachsenhausers": "Sachsenhauser",
    "Sachsenhäuser": "Sachsenhauser",
    "Sachsenhäusern": "Sachsenhauser",
    "Sachsens": "Sachsen",
    "Sachverhalte": "Sachverhalt",
    "Sachverhalten": "Sachverhalt",
    "Sachverhaltes": "Sachverhalt",
    "Sachverhalts": "Sachverhalt",
    "Sachverständige": "sachverständig",
    "Sachverständigen": "Sachverständige",
    "Sachwerte": "Sachwert",
    "Sachwerten": "Sachwert",
    "Sachwerts": "Sachwert",
    "Sachwissens": "Sachwissen",
    "Sacke": "Sack",
    "Sackes": "Sack",
    "Sackgassen": "Sackgasse",
    "Sacks": "Sack",
    "Saddams": "Saddam",
    "Sadisten": "Sadist",
    "Sadistische": "sadistisch",
    "Sadistischen": "Sadistische",
    "Sadistischeren": "Sadistischere",
    "Sadistischsten": "Sadistischste",
    "Safaris": "Safari",
    "Safes": "Safe",
    "Safte": "saften",
    "Saftenden": "Saftende",
    "Saftens": "Saften",
    "Saftes": "Saft",
    "Saftigen": "Saftige",
    "Saftigeren": "Saftigere",
    "Saftigsten": "Saftigste",
    "Saftlosen": "Saftlose",
    "Saftloseren": "Saftlosere",
    "Saftlosesten": "Saftloseste",
    "Safts": "Saft",
    "Sagas": "Saga",
    "Sage": "sagen",
    "Sagen": "Sage",
    "Sagenden": "Sagende",
    "Sagenhaften": "Sagenhafte",
    "Sagenhafteren": "Sagenhaftere",
    "Sagenhaftesten": "Sagenhafteste",
    "Sagens": "Sagen",
    "Sagittalebenen": "Sagittalebene",
    "Sahne": "sahnen",
    "Sahnenden": "Sahnende",
    "Sahnens": "Sahnen",
    "Sahnigen": "Sahnige",
    "Sahnigeren": "Sahnigere",
    "Sahnigsten": "Sahnigste",
    "Saisons": "Saison",
    "Saiten": "Saite",
    "Sakkos": "Sakko",
    "Sakrale": "sakral",
    "Sakralen": "Sakrale",
    "Sakramentalen": "Sakramentale",
    "Sakristeien": "Sakristei",
    "Salate": "Salat",
    "Salaten": "Salat",
    "Salates": "Salat",
    "Salats": "Salat",
    "Salbe": "salben",
    "Salben": "Salbe",
    "Salbenden": "Salbende",
    "Salbens": "Salben",
    "Salbungsvollen": "Salbungsvolle",
    "Salbungsvolleren": "Salbungsvollere",
    "Salbungsvollsten": "Salbungsvollste",
    "Saldos": "Saldo",
    "Saldoübertrage": "Saldoübertrag",
    "Saldoübertrags": "Saldoübertrag",
    "Saldoüberträge": "Saldoübertrag",
    "Saldoüberträgen": "Saldoübertrag",
    "Salische": "salisch",
    "Salischen": "Salische",
    "Salmans": "Salman",
    "Salmünsters": "Salmünster",
    "Salomonische": "salomonisch",
    "Salomonischen": "Salomonische",
    "Salons": "Salon",
    "Saloppe": "salopp",
    "Saloppen": "Saloppe",
    "Salopperen": "Saloppere",
    "Saloppsten": "Saloppste",
    "Salpeters": "Salpeter",
    "Saltos": "Salto",
    "Salute": "Salut",
    "Saluten": "Salut",
    "Salutierenden": "Salutierende",
    "Salutierenderen": "Salutierendere",
    "Salutierendsten": "Salutierendste",
    "Salutierens": "Salutieren",
    "Salutierte": "salutiert",
    "Salutierten": "Salutierte",
    "Saluts": "Salut",
    "Salvadors": "Salvador",
    "Salvatore": "Salvator",
    "Salvatoren": "Salvator",
    "Salvators": "Salvator",
    "Salven": "Salve",
    "Salz": "salzen",
    "Salzburgs": "Salzburg",
    "Salze": "salzen",
    "Salzen": "Salz",
    "Salzenden": "Salzende",
    "Salzens": "Salzen",
    "Salzes": "Salz",
    "Salzhausens": "Salzhausen",
    "Salzige": "salzig",
    "Salzigen": "Salzige",
    "Salzigeren": "Salzigere",
    "Salzigsten": "Salzigste",
    "Salzletten": "Salzlette",
    "Salzlose": "salzlos",
    "Salzlosen": "Salzlose",
    "Salzloseren": "Salzlosere",
    "Salzlosesten": "Salzloseste",
    "Salzmanns": "Salzmann",
    "Salzsiedereien": "Salzsiederei",
    "Salzstangen": "Salzstange",
    "Samaritanische": "samaritanisch",
    "Samaritanischen": "Samaritanische",
    "Samaritern": "Samariter",
    "Samariters": "Samariter",
    "Sambas": "Samba",
    "Samenden": "Samende",
    "Samens": "Samen",
    "Sammelauftrage": "Sammelauftrag",
    "Sammelauftrags": "Sammelauftrag",
    "Sammelaufträge": "Sammelauftrag",
    "Sammelaufträgen": "Sammelauftrag",
    "Sammelbande": "Sammelband",
    "Sammelbandes": "Sammelband",
    "Sammelbands": "Sammelband",
    "Sammelbänder": "Sammelband",
    "Sammelbändern": "Sammelband",
    "Sammelgute": "Sammelgut",
    "Sammelgutes": "Sammelgut",
    "Sammelguts": "Sammelgut",
    "Sammelgüter": "Sammelgut",
    "Sammelgütern": "Sammelgut",
    "Sammelheizungen": "Sammelheizung",
    "Sammellinsen": "Sammellinse",
    "Sammelnden": "Sammelnde",
    "Sammelns": "Sammeln",
    "Sammelstellen": "Sammelstelle",
    "Sammeltouren": "Sammeltour",
    "Sammelwerke": "Sammelwerk",
    "Sammelwerken": "Sammelwerk",
    "Sammelwerks": "Sammelwerk",
    "Sammelüberweisungen": "Sammelüberweisung",
    "Sammlern": "Sammler",
    "Sammlers": "Sammler",
    "Sammlungen": "Sammlung",
    "Samstage": "Samstag",
    "Samstagen": "Samstag",
    "Samstags": "Samstag",
    "Samt": "samen",
    "Samtgemeinden": "Samtgemeinde",
    "Samtige": "samtig",
    "Samtigen": "Samtige",
    "Samtigeren": "Samtigere",
    "Samtigsten": "Samtigste",
    "Samtpfötchens": "Samtpfötchen",
    "Samts": "Samt",
    "Samtweiche": "samtweich",
    "Samtweichen": "Samtweiche",
    "Sandalen": "Sandale",
    "Sandaletten": "Sandalette",
    "Sande": "Sand",
    "Sandes": "Sand",
    "Sandfarbene": "sandfarben",
    "Sandfarbenen": "Sandfarbene",
    "Sandigen": "Sandige",
    "Sandigeren": "Sandigere",
    "Sandigsten": "Sandigste",
    "Sandras": "Sandra",
    "Sandregenpfeifern": "Sandregenpfeifer",
    "Sandregenpfeifers": "Sandregenpfeifer",
    "Sands": "Sand",
    "Sandwiches": "Sandwich",
    "Sanfte": "sanft",
    "Sanften": "Sanfte",
    "Sanfteren": "Sanftere",
    "Sanftesten": "Sanfteste",
    "Sanftmütige": "sanftmütig",
    "Sanftmütigen": "Sanftmütige",
    "Sanftmütigeren": "Sanftmütigere",
    "Sanftmütigsten": "Sanftmütigste",
    "Sangeslustige": "sangeslustig",
    "Sangeslustigen": "Sangeslustige",
    "Sangeslustigeren": "Sangeslustigere",
    "Sangeslustigsten": "Sangeslustigste",
    "Sanglichen": "Sangliche",
    "Sanierenden": "Sanierende",
    "Sanierens": "Sanieren",
    "Sanierte": "saniert",
    "Sanierten": "Sanierte",
    "Sanierungen": "Sanierung",
    "Sanitäre": "sanitär",
    "Sanitären": "Sanitäre",
    "Sanitätsdienstlichen": "Sanitätsdienstliche",
    "Sanktionen": "Sanktion",
    "Sanktioniere": "sanktionieren",
    "Sanktionierenden": "Sanktionierende",
    "Sanktionierenderen": "Sanktionierendere",
    "Sanktionierens": "Sanktionieren",
    "Sanktionierte": "sanktioniert",
    "Sanktionierten": "Sanktionierte",
    "Sanktionierteren": "Sanktioniertere",
    "Sanktioniertesten": "Sanktionierteste",
    "Sanktissimums": "Sanktissimum",
    "Santiagos": "Santiago",
    "Sarajevos": "Sarajevo",
    "Sarajewos": "Sarajewo",
    "Sardinen": "Sardine",
    "Sardinische": "sardinisch",
    "Sardinischen": "Sardinische",
    "Sarg": "sargen",
    "Sarge": "sargen",
    "Sargenden": "Sargende",
    "Sargens": "Sargen",
    "Sargs": "Sarg",
    "Sarkastischen": "Sarkastische",
    "Sarkastischeren": "Sarkastischere",
    "Sarkastischsten": "Sarkastischste",
    "Saschas": "Sascha",
    "Satanischen": "Satanische",
    "Satansbratens": "Satansbraten",
    "Satelliten": "Satellit",
    "Satiren": "Satire",
    "Satirikern": "Satiriker",
    "Satirikers": "Satiriker",
    "Satirische": "satirisch",
    "Satirischen": "Satirische",
    "Satirischeren": "Satirischere",
    "Satirischsten": "Satirischste",
    "Satisfaktionen": "Satisfaktion",
    "Satte": "satt",
    "Sattel": "satteln",
    "Sattelfesten": "Sattelfeste",
    "Sattelfesteren": "Sattelfestere",
    "Sattelfestesten": "Sattelfesteste",
    "Satteln": "Sattel",
    "Sattelnden": "Sattelnde",
    "Sattelns": "Satteln",
    "Sattels": "Sattel",
    "Satten": "Satte",
    "Satteren": "Sattere",
    "Sattesten": "Satteste",
    "Saturationen": "Saturation",
    "Saturierenden": "Saturierende",
    "Saturierenderen": "Saturierendere",
    "Saturierendsten": "Saturierendste",
    "Saturierens": "Saturieren",
    "Saturierte": "saturiert",
    "Saturierten": "Saturierte",
    "Saturierteren": "Saturiertere",
    "Saturiertesten": "Saturierteste",
    "Satzaussagen": "Satzaussage",
    "Satze": "Satz",
    "Satzes": "Satz",
    "Satzungen": "Satzung",
    "Satzungsgemäße": "satzungsgemäß",
    "Satzungsgemäßen": "Satzungsgemäße",
    "Sau": "sauen",
    "Saubere": "sauber",
    "Sauberen": "Saubere",
    "Saubereren": "Sauberere",
    "Saubergehaltenen": "Saubergehaltene",
    "Saubergehalteneren": "Saubergehaltenere",
    "Sauberhaltenden": "Sauberhaltende",
    "Sauberhaltenderen": "Sauberhaltendere",
    "Sauberhaltendsten": "Sauberhaltendste",
    "Sauberhaltens": "Sauberhalten",
    "Saubermanne": "Saubermann",
    "Saubermannes": "Saubermann",
    "Saubermanns": "Saubermann",
    "Saubermänner": "Saubermann",
    "Saubermännern": "Saubermann",
    "Sauberste": "sauber",
    "Saubersten": "Sauberste",
    "Saublöden": "Saublöde",
    "Saudis": "Saudi",
    "Saudumme": "saudumm",
    "Saudummen": "Saudumme",
    "Sauenden": "Sauende",
    "Sauenderen": "Sauendere",
    "Sauendsten": "Sauendste",
    "Sauens": "Sauen",
    "Sauernden": "Sauernde",
    "Sauernderen": "Sauerndere",
    "Sauerndsten": "Sauerndste",
    "Sauerns": "Sauern",
    "Sauersten": "Sauerste",
    "Sauerstoffe": "Sauerstoff",
    "Sauerstoffen": "Sauerstoff",
    "Sauerstoffes": "Sauerstoff",
    "Sauerstoffs": "Sauerstoff",
    "Sauersüße": "sauersüß",
    "Sauersüßen": "Sauersüße",
    "Saufenden": "Saufende",
    "Saufenderen": "Saufendere",
    "Saufendsten": "Saufendste",
    "Saufens": "Saufen",
    "Saufgelagen": "Saufgelage",
    "Saufgelages": "Saufgelage",
    "Sauftouren": "Sauftour",
    "Saugbohnernden": "Saugbohnernde",
    "Saugbohnerns": "Saugbohnern",
    "Saugenden": "Saugende",
    "Saugens": "Saugen",
    "Saugern": "Sauger",
    "Saugers": "Sauger",
    "Saugflaschen": "Saugflasche",
    "Saugfähige": "saugfähig",
    "Saugfähigen": "Saugfähige",
    "Saugfähigeren": "Saugfähigere",
    "Saugfähigsten": "Saugfähigste",
    "Saugkräftige": "saugkräftig",
    "Saugkräftigen": "Saugkräftige",
    "Saugkräftigeren": "Saugkräftigere",
    "Saugkräftigsten": "Saugkräftigste",
    "Saugnapfe": "Saugnapf",
    "Saugnapfs": "Saugnapf",
    "Saugnäpfe": "Saugnapf",
    "Saugnäpfen": "Saugnapf",
    "Saugrohre": "Saugrohr",
    "Saugrohren": "Saugrohr",
    "Saugrohrs": "Saugrohr",
    "Saukomischen": "Saukomische",
    "Saume": "Saum",
    "Saumes": "Saum",
    "Saums": "Saum",
    "Saumäßige": "saumäßig",
    "Saumäßigen": "Saumäßige",
    "Saunas": "Sauna",
    "Saunenden": "Saunende",
    "Saunens": "Saunen",
    "Sauren": "Saure",
    "Saureren": "Saurere",
    "Sauriern": "Saurier",
    "Sauriers": "Saurier",
    "Saurolithen": "Saurolith",
    "Saurs": "Saur",
    "Sausenden": "Sausende",
    "Sausenderen": "Sausendere",
    "Sausendsten": "Sausendste",
    "Sausens": "Sausen",
    "Saxofonisten": "Saxofonist",
    "Saxophone": "Saxophon",
    "Saxophonen": "Saxophon",
    "Saxophons": "Saxophon",
    "Scenes": "Scene",
    "Schabenden": "Schabende",
    "Schabens": "Schaben",
    "Schablonen": "Schablone",
    "Schabracken": "Schabracke",
    "Schachbrettartigen": "Schachbrettartige",
    "Schache": "Schach",
    "Schachernden": "Schachernde",
    "Schacherns": "Schachern",
    "Schaches": "Schach",
    "Schachs": "Schach",
    "Schachte": "schachten",
    "Schachtel": "schachteln",
    "Schachteln": "Schachtel",
    "Schachtelnden": "Schachtelnde",
    "Schachtelnderen": "Schachtelndere",
    "Schachtelndsten": "Schachtelndste",
    "Schachtelns": "Schachteln",
    "Schachtenden": "Schachtende",
    "Schachtens": "Schachten",
    "Schachts": "Schacht",
    "Schadenden": "Schadende",
    "Schadenderen": "Schadendere",
    "Schadendsten": "Schadendste",
    "Schadenfrohen": "Schadenfrohe",
    "Schadenfroheren": "Schadenfrohere",
    "Schadenfrohesten": "Schadenfroheste",
    "Schadens": "Schaden",
    "Schadhaften": "Schadhafte",
    "Schadhafteren": "Schadhaftere",
    "Schadhaftesten": "Schadhafteste",
    "Schadinsekte": "Schadinsekt",
    "Schadinsekten": "Schadinsekt",
    "Schadinsekts": "Schadinsekt",
    "Schadstoffarme": "schadstoffarm",
    "Schadstoffarmen": "Schadstoffarme",
    "Schadstoffe": "Schadstoff",
    "Schadstoffen": "Schadstoff",
    "Schadstoffes": "Schadstoff",
    "Schadstoffs": "Schadstoff",
    "Schadstoffärmeren": "Schadstoffärmere",
    "Schafe": "Schaf",
    "Schafen": "Schaf",
    "Schaffenden": "Schaffende",
    "Schaffens": "Schaffen",
    "Schaffnerinnen": "Schaffnerin",
    "Schaffnern": "Schaffner",
    "Schaffners": "Schaffner",
    "Schaffungen": "Schaffung",
    "Schafotte": "Schafott",
    "Schafotten": "Schafott",
    "Schafotts": "Schafott",
    "Schafs": "Schaf",
    "Schakale": "Schakal",
    "Schakalen": "Schakal",
    "Schakals": "Schakal",
    "Schal": "schalen",
    "Schalcks": "Schalck",
    "Schale": "schalen",
    "Schalen": "Schale",
    "Schalenblenden": "Schalenblende",
    "Schalenden": "Schalende",
    "Schalens": "Schalen",
    "Schales": "Schal",
    "Schalkes": "Schalke",
    "Schalkhafte": "schalkhaft",
    "Schalkhaften": "Schalkhafte",
    "Schalkhafteren": "Schalkhaftere",
    "Schalkhaftesten": "Schalkhafteste",
    "Schall": "schallen",
    "Schalldichte": "schalldicht",
    "Schalldichten": "Schalldichte",
    "Schalldichteren": "Schalldichtere",
    "Schalldichtesten": "Schalldichteste",
    "Schallenden": "Schallende",
    "Schallenderen": "Schallendere",
    "Schallendsten": "Schallendste",
    "Schallens": "Schallen",
    "Schallplatten": "Schallplatte",
    "Schalls": "Schall",
    "Schallsichere": "schallsicher",
    "Schallsicheren": "Schallsichere",
    "Schallsichereren": "Schallsicherere",
    "Schallsichersten": "Schallsicherste",
    "Schals": "Schal",
    "Schaltanlagen": "Schaltanlage",
    "Schaltbilde": "Schaltbild",
    "Schaltbilder": "Schaltbild",
    "Schaltbildern": "Schaltbild",
    "Schaltbildes": "Schaltbild",
    "Schaltbilds": "Schaltbild",
    "Schalten": "schelten",
    "Schaltenden": "Schaltende",
    "Schaltens": "Schalten",
    "Schaltern": "Schalter",
    "Schalters": "Schalter",
    "Schaltjahre": "Schaltjahr",
    "Schaltjahren": "Schaltjahr",
    "Schaltjahrs": "Schaltjahr",
    "Schaltskizzen": "Schaltskizze",
    "Schaltstellen": "Schaltstelle",
    "Schaltzeichens": "Schaltzeichen",
    "Schamanen": "Schamane",
    "Schambeine": "Schambein",
    "Schambeinen": "Schambein",
    "Schambeins": "Schambein",
    "Schamgrenzen": "Schamgrenze",
    "Schamhaare": "Schamhaar",
    "Schamhaaren": "Schamhaar",
    "Schamhaars": "Schamhaar",
    "Schamhafte": "schamhaft",
    "Schamhaften": "Schamhafte",
    "Schamhafteren": "Schamhaftere",
    "Schamhaftesten": "Schamhafteste",
    "Schamirs": "Schamir",
    "Schamlose": "schamlos",
    "Schamlosen": "Schamlose",
    "Schamloseren": "Schamlosere",
    "Schamlosesten": "Schamloseste",
    "Schamponierenden": "Schamponierende",
    "Schamponierens": "Schamponieren",
    "Schamponierte": "schamponiert",
    "Schamponierten": "Schamponierte",
    "Schanden": "Schande",
    "Schandkerle": "Schandkerl",
    "Schandkerlen": "Schandkerl",
    "Schandkerls": "Schandkerl",
    "Schankstuben": "Schankstube",
    "Schanze": "schanzen",
    "Schanzen": "Schanze",
    "Schanzenden": "Schanzende",
    "Schanzens": "Schanzen",
    "Schapkas": "Schapka",
    "Schar": "scharen",
    "Scharaden": "Scharade",
    "Scharen": "Schar",
    "Scharenden": "Scharende",
    "Scharens": "Scharen",
    "Scharfen": "Scharfe",
    "Scharfgestellten": "Scharfgestellte",
    "Scharfgestellteren": "Scharfgestelltere",
    "Scharfkantigen": "Scharfkantige",
    "Scharfkantigeren": "Scharfkantigere",
    "Scharfkantigsten": "Scharfkantigste",
    "Scharfmachern": "Scharfmacher",
    "Scharfmachers": "Scharfmacher",
    "Scharfrichtern": "Scharfrichter",
    "Scharfrichters": "Scharfrichter",
    "Scharfschießens": "Scharfschießen",
    "Scharfschützen": "Scharfschütze",
    "Scharfsichtige": "scharfsichtig",
    "Scharfsichtigen": "Scharfsichtige",
    "Scharfsichtigeren": "Scharfsichtigere",
    "Scharfsichtigsten": "Scharfsichtigste",
    "Scharfsinnigen": "Scharfsinnige",
    "Scharfsinnigeren": "Scharfsinnigere",
    "Scharfsinnigsten": "Scharfsinnigste",
    "Scharfsinns": "Scharfsinn",
    "Scharfstelle": "scharfstellen",
    "Scharfstellenden": "Scharfstellende",
    "Scharfstellenderen": "Scharfstellendere",
    "Scharfstellens": "Scharfstellen",
    "Scharlatane": "Scharlatan",
    "Scharlatanen": "Scharlatan",
    "Scharlatanerien": "Scharlatanerie",
    "Scharlatans": "Scharlatan",
    "Scharmante": "scharmant",
    "Scharmanten": "Scharmante",
    "Scharmanteren": "Scharmantere",
    "Scharmantesten": "Scharmanteste",
    "Scharmützel": "scharmützeln",
    "Scharmützeln": "Scharmützel",
    "Scharmützelnden": "Scharmützelnde",
    "Scharmützelns": "Scharmützeln",
    "Scharmützels": "Scharmützel",
    "Scharmützelte": "scharmützelt",
    "Scharmützelten": "Scharmützelte",
    "Scharniere": "Scharnier",
    "Scharnieren": "Scharnier",
    "Scharniers": "Scharnier",
    "Scharpings": "Scharping",
    "Scharrenden": "Scharrende",
    "Scharrens": "Scharren",
    "Schattenhaften": "Schattenhafte",
    "Schattenhafteren": "Schattenhaftere",
    "Schattenhaftesten": "Schattenhafteste",
    "Schattens": "Schatten",
    "Schattenseiten": "Schattenseite",
    "Schattierenden": "Schattierende",
    "Schattierens": "Schattieren",
    "Schattierte": "schattiert",
    "Schattierten": "Schattierte",
    "Schattierungen": "Schattierung",
    "Schattige": "schattig",
    "Schattigen": "Schattige",
    "Schattigeren": "Schattigere",
    "Schattigsten": "Schattigste",
    "Schatullen": "Schatulle",
    "Schatzamte": "Schatzamt",
    "Schatzamtes": "Schatzamt",
    "Schatzamts": "Schatzamt",
    "Schatze": "Schatz",
    "Schatzes": "Schatz",
    "Schatzs": "Schatz",
    "Schatzämter": "Schatzamt",
    "Schatzämtern": "Schatzamt",
    "Schau": "schauen",
    "Schauderhaften": "Schauderhafte",
    "Schauderhafteren": "Schauderhaftere",
    "Schauderhaftesten": "Schauderhafteste",
    "Schaudernden": "Schaudernde",
    "Schaudernderen": "Schauderndere",
    "Schauderndsten": "Schauderndste",
    "Schauderns": "Schaudern",
    "Schauen": "Schau",
    "Schauenden": "Schauende",
    "Schauens": "Schauen",
    "Schauerliche": "schauerlich",
    "Schauerlichen": "Schauerliche",
    "Schauerlicheren": "Schauerlichere",
    "Schauerlichsten": "Schauerlichste",
    "Schauern": "Schauer",
    "Schauers": "Schauer",
    "Schaufel": "schaufeln",
    "Schaufeln": "Schaufel",
    "Schaufelnden": "Schaufelnde",
    "Schaufelnderen": "Schaufelndere",
    "Schaufelndsten": "Schaufelndste",
    "Schaufelns": "Schaufeln",
    "Schaugeschäfte": "Schaugeschäft",
    "Schaugeschäften": "Schaugeschäft",
    "Schaugeschäfts": "Schaugeschäft",
    "Schaukampfe": "Schaukampf",
    "Schaukampfs": "Schaukampf",
    "Schaukelnden": "Schaukelnde",
    "Schaukelns": "Schaukeln",
    "Schaukämpfe": "Schaukampf",
    "Schaukämpfen": "Schaukampf",
    "Schaulustigen": "Schaulustige",
    "Schaulustigeren": "Schaulustigere",
    "Schaulustigsten": "Schaulustigste",
    "Schaume": "Schaum",
    "Schaumes": "Schaum",
    "Schaumige": "schaumig",
    "Schaumigen": "Schaumige",
    "Schaumigeren": "Schaumigere",
    "Schaumigsten": "Schaumigste",
    "Schaums": "Schaum",
    "Schaurige": "schaurig",
    "Schaurigen": "Schaurige",
    "Schaurigeren": "Schaurigere",
    "Schaurigsten": "Schaurigste",
    "Schauseiten": "Schauseite",
    "Schauspieler": "schauspielern",
    "Schauspielerinnen": "Schauspielerin",
    "Schauspielerische": "schauspielerisch",
    "Schauspielerischen": "Schauspielerische",
    "Schauspielern": "Schauspieler",
    "Schauspielernden": "Schauspielernde",
    "Schauspielerns": "Schauspielern",
    "Schauspielers": "Schauspieler",
    "Schaustellern": "Schausteller",
    "Schaustellers": "Schausteller",
    "Schaustücke": "Schaustück",
    "Schaustücken": "Schaustück",
    "Schaustücks": "Schaustück",
    "Schecks": "Scheck",
    "Scheels": "Scheel",
    "Scheelste": "scheel",
    "Scheelsten": "Scheelste",
    "Scheffel": "scheffeln",
    "Scheffeln": "Scheffel",
    "Scheffelnden": "Scheffelnde",
    "Scheffelnderen": "Scheffelndere",
    "Scheffelndsten": "Scheffelndste",
    "Scheffelns": "Scheffeln",
    "Scheffels": "Scheffel",
    "Scheiben": "Scheibe",
    "Scheiche": "Scheich",
    "Scheichen": "Scheich",
    "Scheiches": "Scheich",
    "Scheichs": "Scheich",
    "Scheide": "scheiden",
    "Scheiden": "Scheide",
    "Scheidenden": "Scheidende",
    "Scheidens": "Scheiden",
    "Scheidepunkte": "Scheidepunkt",
    "Scheidepunkten": "Scheidepunkt",
    "Scheidepunkts": "Scheidepunkt",
    "Scheidewege": "Scheideweg",
    "Scheidewegen": "Scheideweg",
    "Scheidewegs": "Scheideweg",
    "Scheidungen": "Scheidung",
    "Schein": "scheinen",
    "Scheinbare": "scheinbar",
    "Scheinbaren": "Scheinbare",
    "Scheinbareren": "Scheinbarere",
    "Scheinbarsten": "Scheinbarste",
    "Scheinenden": "Scheinende",
    "Scheinenderen": "Scheinendere",
    "Scheinendsten": "Scheinendste",
    "Scheinens": "Scheinen",
    "Scheinheiligen": "Scheinheilige",
    "Scheinheiligeren": "Scheinheiligere",
    "Scheinheiligsten": "Scheinheiligste",
    "Scheins": "Schein",
    "Scheintoten": "Scheintote",
    "Scheinwerfern": "Scheinwerfer",
    "Scheinwerfers": "Scheinwerfer",
    "Scheite": "Scheit",
    "Scheiteln": "Scheitel",
    "Scheitels": "Scheitel",
    "Scheiten": "Scheit",
    "Scheiternden": "Scheiternde",
    "Scheiterns": "Scheitern",
    "Scheites": "Scheit",
    "Scheits": "Scheit",
    "Scheißenden": "Scheißende",
    "Scheißens": "Scheißen",
    "Scheißfreundlichen": "Scheißfreundliche",
    "Schele": "scheel",
    "Schelen": "Schele",
    "Scheleren": "Schelere",
    "Schellen": "Schelle",
    "Schellenden": "Schellende",
    "Schellens": "Schellen",
    "Schellings": "Schelling",
    "Schelmereien": "Schelmerei",
    "Schelminnen": "Schelmin",
    "Schelmische": "schelmisch",
    "Schelmischen": "Schelmische",
    "Schelmischeren": "Schelmischere",
    "Schelmischsten": "Schelmischste",
    "Schelten": "Schelte",
    "Scheltenden": "Scheltende",
    "Scheltens": "Schelten",
    "Schelzkes": "Schelzke",
    "Schemas": "Schema",
    "Schemata": "Schema",
    "Schematische": "schematisch",
    "Schematischen": "Schematische",
    "Schematischeren": "Schematischere",
    "Schematischsten": "Schematischste",
    "Schematisierenden": "Schematisierende",
    "Schematisierenderen": "Schematisierendere",
    "Schematisierens": "Schematisieren",
    "Schematisierte": "schematisiert",
    "Schematisierten": "Schematisierte",
    "Schematisierteren": "Schematisiertere",
    "Schematisierteste": "schematisiert",
    "Schemeln": "Schemel",
    "Schemels": "Schemel",
    "Schemenhafte": "schemenhaft",
    "Schemenhaften": "Schemenhafte",
    "Schemenhafteren": "Schemenhaftere",
    "Schemenhaftesten": "Schemenhafteste",
    "Schenkeln": "Schenkel",
    "Schenkels": "Schenkel",
    "Schenkenden": "Schenkende",
    "Schenkens": "Schenken",
    "Schenkungen": "Schenkung",
    "Scheppernden": "Scheppernde",
    "Scheppernderen": "Schepperndere",
    "Schepperndsten": "Schepperndste",
    "Schepperns": "Scheppern",
    "Scherben": "Scherbe",
    "Schere": "scheren",
    "Scheren": "Schere",
    "Scherenden": "Scherende",
    "Scherens": "Scheren",
    "Scherereien": "Schererei",
    "Scherfs": "Scherf",
    "Scheriffs": "Scheriff",
    "Scherz": "scherzen",
    "Scherze": "scherzen",
    "Scherzen": "Scherz",
    "Scherzenden": "Scherzende",
    "Scherzenderen": "Scherzendere",
    "Scherzendsten": "Scherzendste",
    "Scherzens": "Scherzen",
    "Scherzes": "Scherz",
    "Scherzhaften": "Scherzhafte",
    "Scherzhafteren": "Scherzhaftere",
    "Scherzhaftesten": "Scherzhafteste",
    "Scheuchenden": "Scheuchende",
    "Scheuchenderen": "Scheuchendere",
    "Scheuchendsten": "Scheuchendste",
    "Scheuchens": "Scheuchen",
    "Scheuenden": "Scheuende",
    "Scheuens": "Scheuen",
    "Scheuernden": "Scheuernde",
    "Scheuernderen": "Scheuerndere",
    "Scheuerndsten": "Scheuerndste",
    "Scheuerns": "Scheuern",
    "Scheunen": "Scheune",
    "Scheußliche": "scheußlich",
    "Scheußlichen": "Scheußliche",
    "Scheußlicheren": "Scheußlichere",
    "Scheußlichsten": "Scheußlichste",
    "Schewardnadses": "Schewardnadse",
    "Schichten": "Schicht",
    "Schichtenden": "Schichtende",
    "Schichtens": "Schichten",
    "Schichtern": "Schichter",
    "Schichters": "Schichter",
    "Schicke": "schicken",
    "Schicken": "Schicke",
    "Schickenden": "Schickende",
    "Schickens": "Schicken",
    "Schickeren": "Schickere",
    "Schicksale": "Schicksal",
    "Schicksalen": "Schicksal",
    "Schicksales": "Schicksal",
    "Schicksalhafte": "schicksalhaft",
    "Schicksalhaften": "Schicksalhafte",
    "Schicksals": "Schicksal",
    "Schicksen": "Schickse",
    "Schicksten": "Schickste",
    "Schiebebetriebe": "Schiebebetrieb",
    "Schiebebetrieben": "Schiebebetrieb",
    "Schiebebetriebes": "Schiebebetrieb",
    "Schiebebetriebs": "Schiebebetrieb",
    "Schiebebühnen": "Schiebebühne",
    "Schiebedache": "Schiebedach",
    "Schiebedachs": "Schiebedach",
    "Schiebedächer": "Schiebedach",
    "Schiebedächern": "Schiebedach",
    "Schiebefenstern": "Schiebefenster",
    "Schiebefensters": "Schiebefenster",
    "Schiebenden": "Schiebende",
    "Schiebens": "Schieben",
    "Schiebern": "Schieber",
    "Schiebers": "Schieber",
    "Schiebfache": "Schiebfach",
    "Schiebfaches": "Schiebfach",
    "Schiebfachs": "Schiebfach",
    "Schiebfächer": "Schiebfach",
    "Schiebfächern": "Schiebfach",
    "Schiebkarren": "Schiebkarre",
    "Schiebungen": "Schiebung",
    "Schiedsgerichte": "Schiedsgericht",
    "Schiedsgerichten": "Schiedsgericht",
    "Schiedsgerichtes": "Schiedsgericht",
    "Schiedsgerichts": "Schiedsgericht",
    "Schiedsrichterliche": "schiedsrichterlich",
    "Schiedsrichterlichen": "Schiedsrichterliche",
    "Schiedsrichtern": "Schiedsrichter",
    "Schiedsrichters": "Schiedsrichter",
    "Schiedsspruche": "Schiedsspruch",
    "Schiedsspruches": "Schiedsspruch",
    "Schiedsspruchs": "Schiedsspruch",
    "Schiedssprüche": "Schiedsspruch",
    "Schiedssprüchen": "Schiedsspruch",
    "Schiefblatte": "Schiefblatt",
    "Schiefblattes": "Schiefblatt",
    "Schiefblatts": "Schiefblatt",
    "Schiefblätter": "Schiefblatt",
    "Schiefblättern": "Schiefblatt",
    "Schiefer": "schiefern",
    "Schiefern": "Schiefer",
    "Schiefernden": "Schiefernde",
    "Schieferns": "Schiefern",
    "Schiefers": "Schiefer",
    "Schiefgegangenen": "Schiefgegangene",
    "Schiefgehenden": "Schiefgehende",
    "Schiefgehens": "Schiefgehen",
    "Schiefgelachten": "Schiefgelachte",
    "Schiefgelegenen": "Schiefgelegene",
    "Schieflachenden": "Schieflachende",
    "Schieflachens": "Schieflachen",
    "Schiefliegenden": "Schiefliegende",
    "Schiefliegens": "Schiefliegen",
    "Schiefwinkligen": "Schiefwinklige",
    "Schielaugen": "Schielauge",
    "Schielauges": "Schielauge",
    "Schielenden": "Schielende",
    "Schielenderen": "Schielendere",
    "Schielendsten": "Schielendste",
    "Schielens": "Schielen",
    "Schienbeine": "Schienbein",
    "Schienbeinen": "Schienbein",
    "Schienbeins": "Schienbein",
    "Schiene": "scheinen",
    "Schienen": "Schiene",
    "Schieren": "Schiere",
    "Schießenden": "Schießende",
    "Schießens": "Schießen",
    "Schießereien": "Schießerei",
    "Schießgewehre": "Schießgewehr",
    "Schießgewehren": "Schießgewehr",
    "Schießgewehrs": "Schießgewehr",
    "Schießscheiben": "Schießscheibe",
    "Schießsporte": "Schießsport",
    "Schießsportes": "Schießsport",
    "Schießsports": "Schießsport",
    "Schiff": "schiffen",
    "Schiffbrüchige": "schiffbrüchig",
    "Schiffbrüchigen": "Schiffbrüchige",
    "Schiffbrüchigeren": "Schiffbrüchigere",
    "Schiffbrüchigsten": "Schiffbrüchigste",
    "Schiffe": "schiffen",
    "Schiffen": "Schiff",
    "Schiffenden": "Schiffende",
    "Schiffenderen": "Schiffendere",
    "Schiffendsten": "Schiffendste",
    "Schiffens": "Schiffen",
    "Schifferknotens": "Schifferknoten",
    "Schiffes": "Schiff",
    "Schiffs": "Schiff",
    "Schiftern": "Schifter",
    "Schifters": "Schifter",
    "Schiiten": "Schiit",
    "Schiitische": "schiitisch",
    "Schiitischen": "Schiitische",
    "Schikanen": "Schikane",
    "Schikanierenden": "Schikanierende",
    "Schikanierenderen": "Schikanierendere",
    "Schikanierendsten": "Schikanierendste",
    "Schikanierens": "Schikanieren",
    "Schikanierte": "schikaniert",
    "Schikanierten": "Schikanierte",
    "Schikanierteren": "Schikaniertere",
    "Schikaniertesten": "Schikanierteste",
    "Schikanösen": "Schikanöse",
    "Schikanöseren": "Schikanösere",
    "Schikanösesten": "Schikanöseste",
    "Schilddrüsen": "Schilddrüse",
    "Schilde": "Schild",
    "Schilden": "Schild",
    "Schildern": "Schild",
    "Schildernden": "Schildernde",
    "Schilderns": "Schildern",
    "Schildes": "Schild",
    "Schilds": "Schild",
    "Schilfe": "Schilf",
    "Schilfen": "Schilf",
    "Schilfige": "schilfig",
    "Schilfigen": "Schilfige",
    "Schilfigeren": "Schilfigere",
    "Schilfigsten": "Schilfigste",
    "Schilfs": "Schilf",
    "Schiller": "schillern",
    "Schillernden": "Schillernde",
    "Schillernderen": "Schillerndere",
    "Schillerndsten": "Schillerndste",
    "Schillerns": "Schillern",
    "Schillers": "Schiller",
    "Schillinge": "Schilling",
    "Schillingen": "Schilling",
    "Schillings": "Schilling",
    "Schimmel": "schimmeln",
    "Schimmeligen": "Schimmelige",
    "Schimmeligeren": "Schimmeligere",
    "Schimmeligsten": "Schimmeligste",
    "Schimmeln": "Schimmel",
    "Schimmelnden": "Schimmelnde",
    "Schimmelnderen": "Schimmelndere",
    "Schimmelndsten": "Schimmelndste",
    "Schimmelns": "Schimmeln",
    "Schimmels": "Schimmel",
    "Schimmer": "schimmern",
    "Schimmern": "Schimmer",
    "Schimmernden": "Schimmernde",
    "Schimmernderen": "Schimmerndere",
    "Schimmerndsten": "Schimmerndste",
    "Schimmerns": "Schimmern",
    "Schimmers": "Schimmer",
    "Schimmligen": "Schimmlige",
    "Schimmligeren": "Schimmligere",
    "Schimmligsten": "Schimmligste",
    "Schimpansen": "Schimpanse",
    "Schimpfenden": "Schimpfende",
    "Schimpfens": "Schimpfen",
    "Schindenden": "Schindende",
    "Schindens": "Schinden",
    "Schinkens": "Schinken",
    "Schirm": "schirmen",
    "Schirme": "schirmen",
    "Schirmen": "Schirm",
    "Schirmenden": "Schirmende",
    "Schirmens": "Schirmen",
    "Schirms": "Schirm",
    "Schirrenden": "Schirrende",
    "Schirrens": "Schirren",
    "Schizoiden": "Schizoide",
    "Schizoideren": "Schizoidere",
    "Schizoidesten": "Schizoideste",
    "Schizophrenen": "Schizophrene",
    "Schizophreneren": "Schizophrenere",
    "Schizophrenien": "Schizophrenie",
    "Schizophrenste": "schizophren",
    "Schizophrensten": "Schizophrenste",
    "Schlabberigen": "Schlabberige",
    "Schlabberigeren": "Schlabberigere",
    "Schlabberigsten": "Schlabberigste",
    "Schlabbernden": "Schlabbernde",
    "Schlabbernderen": "Schlabberndere",
    "Schlabberndsten": "Schlabberndste",
    "Schlabberns": "Schlabbern",
    "Schlachtbänke": "Schlachtbank",
    "Schlachtbänken": "Schlachtbank",
    "Schlachten": "Schlacht",
    "Schlachtenden": "Schlachtende",
    "Schlachtens": "Schlachten",
    "Schlachtereien": "Schlachterei",
    "Schlachthofe": "Schlachthof",
    "Schlachthofes": "Schlachthof",
    "Schlachthofs": "Schlachthof",
    "Schlachthöfe": "Schlachthof",
    "Schlachthöfen": "Schlachthof",
    "Schlachtreife": "schlachtreif",
    "Schlachtreifen": "Schlachtreife",
    "Schlachtreiferen": "Schlachtreifere",
    "Schlachtreifsten": "Schlachtreifste",
    "Schlachtungen": "Schlachtung",
    "Schlaf": "schlafen",
    "Schlafe": "schlafen",
    "Schlafenden": "Schlafende",
    "Schlafens": "Schlafen",
    "Schlafes": "Schlaf",
    "Schlaffenden": "Schlaffende",
    "Schlaffens": "Schlaffen",
    "Schlafgemache": "Schlafgemach",
    "Schlafgemaches": "Schlafgemach",
    "Schlafgemachs": "Schlafgemach",
    "Schlafgemächer": "Schlafgemach",
    "Schlafgemächern": "Schlafgemach",
    "Schlafittchens": "Schlafittchen",
    "Schlaflose": "schlaflos",
    "Schlaflosen": "Schlaflose",
    "Schlafloseren": "Schlaflosere",
    "Schlaflosesten": "Schlafloseste",
    "Schlafmäuse": "Schlafmaus",
    "Schlafmäusen": "Schlafmaus",
    "Schlafmützige": "schlafmützig",
    "Schlafmützigen": "Schlafmützige",
    "Schlafmützigeren": "Schlafmützigere",
    "Schlafmützigsten": "Schlafmützigste",
    "Schlafs": "Schlaf",
    "Schlafstädte": "Schlafstadt",
    "Schlafstädten": "Schlafstadt",
    "Schlafsüchtige": "schlafsüchtig",
    "Schlafsüchtigen": "Schlafsüchtige",
    "Schlafsüchtigeren": "Schlafsüchtigere",
    "Schlafsüchtigsten": "Schlafsüchtigste",
    "Schlaftrunkenen": "Schlaftrunkene",
    "Schlaftrunkeneren": "Schlaftrunkenere",
    "Schlaftrunkensten": "Schlaftrunkenste",
    "Schlafwandelnden": "Schlafwandelnde",
    "Schlafwandelns": "Schlafwandeln",
    "Schlafwandlerischen": "Schlafwandlerische",
    "Schlafwandlern": "Schlafwandler",
    "Schlafwandlers": "Schlafwandler",
    "Schlag": "schlagen",
    "Schlaganfalle": "Schlaganfall",
    "Schlaganfalls": "Schlaganfall",
    "Schlaganfälle": "Schlaganfall",
    "Schlaganfällen": "Schlaganfall",
    "Schlagartige": "schlagartig",
    "Schlagartigen": "Schlagartige",
    "Schlagbaren": "Schlagbare",
    "Schlagbohrern": "Schlagbohrer",
    "Schlagbohrers": "Schlagbohrer",
    "Schlage": "schlagen",
    "Schlagenden": "Schlagende",
    "Schlagens": "Schlagen",
    "Schlagern": "Schlager",
    "Schlagers": "Schlager",
    "Schlages": "Schlag",
    "Schlagfertigen": "Schlagfertige",
    "Schlagfertigeren": "Schlagfertigere",
    "Schlagfertigsten": "Schlagfertigste",
    "Schlagkräftigen": "Schlagkräftige",
    "Schlagkräftigeren": "Schlagkräftigere",
    "Schlagkräftigsten": "Schlagkräftigste",
    "Schlags": "Schlag",
    "Schlagwettern": "Schlagwetter",
    "Schlagwetters": "Schlagwetter",
    "Schlagwunden": "Schlagwunde",
    "Schlagzeilen": "Schlagzeile",
    "Schlaksige": "schlaksig",
    "Schlaksigen": "Schlaksige",
    "Schlaksigeren": "Schlaksigere",
    "Schlaksigsten": "Schlaksigste",
    "Schlamasseln": "Schlamassel",
    "Schlamassels": "Schlamassel",
    "Schlamme": "Schlamm",
    "Schlammes": "Schlamm",
    "Schlammigen": "Schlammige",
    "Schlammigeren": "Schlammigere",
    "Schlammigsten": "Schlammigste",
    "Schlamms": "Schlamm",
    "Schlampen": "Schlampe",
    "Schlampenden": "Schlampende",
    "Schlampenderen": "Schlampendere",
    "Schlampendsten": "Schlampendste",
    "Schlampens": "Schlampen",
    "Schlampigen": "Schlampige",
    "Schlampigeren": "Schlampigere",
    "Schlampigsten": "Schlampigste",
    "Schlangen": "schlingen",
    "Schlangenhaften": "Schlangenhafte",
    "Schlangenhafteren": "Schlangenhaftere",
    "Schlanken": "Schlanke",
    "Schlankeren": "Schlankere",
    "Schlanksten": "Schlankste",
    "Schlappen": "Schlappe",
    "Schlappenden": "Schlappende",
    "Schlappens": "Schlappen",
    "Schlappgemachten": "Schlappgemachte",
    "Schlappmachenden": "Schlappmachende",
    "Schlappmachenderen": "Schlappmachendere",
    "Schlappmachens": "Schlappmachen",
    "Schlappners": "Schlappner",
    "Schlaraffenlands": "Schlaraffenland",
    "Schlauch": "schlauchen",
    "Schlauche": "schlauchen",
    "Schlauchenden": "Schlauchende",
    "Schlauchenderen": "Schlauchendere",
    "Schlauchendsten": "Schlauchendste",
    "Schlauchens": "Schlauchen",
    "Schlauches": "Schlauch",
    "Schlauchs": "Schlauch",
    "Schlauen": "Schlaue",
    "Schlaueren": "Schlauere",
    "Schlausten": "Schlauste",
    "Schlechten": "Schlechte",
    "Schlechteren": "Schlechtere",
    "Schlechtesten": "Schlechteste",
    "Schleckernden": "Schleckernde",
    "Schleckernderen": "Schleckerndere",
    "Schleckerndsten": "Schleckerndste",
    "Schleckerns": "Schleckern",
    "Schleichenden": "Schleichende",
    "Schleichenderen": "Schleichendere",
    "Schleichendsten": "Schleichendste",
    "Schleichens": "Schleichen",
    "Schleichern": "Schleicher",
    "Schleichers": "Schleicher",
    "Schleichpfade": "Schleichpfad",
    "Schleichpfaden": "Schleichpfad",
    "Schleichpfads": "Schleichpfad",
    "Schleichverkehrs": "Schleichverkehr",
    "Schleierhafte": "schleierhaft",
    "Schleierhaften": "Schleierhafte",
    "Schleierhafteren": "Schleierhaftere",
    "Schleierhaftesten": "Schleierhafteste",
    "Schleiermachers": "Schleiermacher",
    "Schleiern": "Schleier",
    "Schleiers": "Schleier",
    "Schleife": "schleifen",
    "Schleifen": "Schleife",
    "Schleifenden": "Schleifende",
    "Schleifens": "Schleifen",
    "Schleifkontakte": "Schleifkontakt",
    "Schleifkontakten": "Schleifkontakt",
    "Schleifkontakts": "Schleifkontakt",
    "Schleifpapiere": "Schleifpapier",
    "Schleifpapieren": "Schleifpapier",
    "Schleifpapiers": "Schleifpapier",
    "Schleifrade": "Schleifrad",
    "Schleifrades": "Schleifrad",
    "Schleifrads": "Schleifrad",
    "Schleifriemens": "Schleifriemen",
    "Schleifräder": "Schleifrad",
    "Schleifrädern": "Schleifrad",
    "Schleifsteine": "Schleifstein",
    "Schleifsteinen": "Schleifstein",
    "Schleifsteins": "Schleifstein",
    "Schleim": "schleimen",
    "Schleime": "schleimen",
    "Schleimen": "Schleim",
    "Schleimenden": "Schleimende",
    "Schleimenderen": "Schleimendere",
    "Schleimendsten": "Schleimendste",
    "Schleimens": "Schleimen",
    "Schleimigen": "Schleimige",
    "Schleimigeren": "Schleimigere",
    "Schleimigsten": "Schleimigste",
    "Schleims": "Schleim",
    "Schleißenden": "Schleißende",
    "Schleißens": "Schleißen",
    "Schlemmenden": "Schlemmende",
    "Schlemmenderen": "Schlemmendere",
    "Schlemmendsten": "Schlemmendste",
    "Schlemmens": "Schlemmen",
    "Schlendernden": "Schlendernde",
    "Schlendernderen": "Schlenderndere",
    "Schlenderndsten": "Schlenderndste",
    "Schlenderns": "Schlendern",
    "Schlendrians": "Schlendrian",
    "Schlenkernden": "Schlenkernde",
    "Schlenkernderen": "Schlenkerndere",
    "Schlenkerndsten": "Schlenkerndste",
    "Schlenkerns": "Schlenkern",
    "Schlenzenden": "Schlenzende",
    "Schlenzens": "Schlenzen",
    "Schleppen": "Schleppe",
    "Schleppenden": "Schleppende",
    "Schleppens": "Schleppen",
    "Schleppern": "Schlepper",
    "Schleppers": "Schlepper",
    "Schlepplifte": "Schlepplift",
    "Schleppliften": "Schlepplift",
    "Schlepplifts": "Schlepplift",
    "Schleppnetze": "Schleppnetz",
    "Schleppnetzen": "Schleppnetz",
    "Schleppnetzes": "Schleppnetz",
    "Schleppschiffe": "Schleppschiff",
    "Schleppschiffen": "Schleppschiff",
    "Schleppschiffs": "Schleppschiff",
    "Schleppseile": "Schleppseil",
    "Schleppseilen": "Schleppseil",
    "Schleppseils": "Schleppseil",
    "Schlepptaue": "Schlepptau",
    "Schlepptauen": "Schlepptau",
    "Schlepptaus": "Schlepptau",
    "Schlesischen": "Schlesische",
    "Schleswigs": "Schleswig",
    "Schleuder": "schleudern",
    "Schleudermaschinen": "Schleudermaschine",
    "Schleudern": "Schleuder",
    "Schleudernden": "Schleudernde",
    "Schleudernderen": "Schleuderndere",
    "Schleuderndsten": "Schleuderndste",
    "Schleuderns": "Schleudern",
    "Schleuderwaren": "Schleuderware",
    "Schleuse": "schleusen",
    "Schleusen": "Schleuse",
    "Schleusenden": "Schleusende",
    "Schleusens": "Schleusen",
    "Schlichten": "Schlichte",
    "Schlichteren": "Schlichtere",
    "Schlichtesten": "Schlichteste",
    "Schlichthammers": "Schlichthammer",
    "Schlichthämmer": "Schlichthammer",
    "Schlichthämmern": "Schlichthammer",
    "Schlicks": "Schlick",
    "Schlieren": "Schliere",
    "Schlierige": "schlierig",
    "Schlierigen": "Schlierige",
    "Schlierigeren": "Schlierigere",
    "Schlierigsten": "Schlierigste",
    "Schliers": "Schlier",
    "Schließenden": "Schließende",
    "Schließens": "Schließen",
    "Schließern": "Schließer",
    "Schließers": "Schließer",
    "Schließungen": "Schließung",
    "Schliff": "schleifen",
    "Schliffe": "Schliff",
    "Schliffen": "Schliff",
    "Schliffs": "Schliff",
    "Schlimmen": "Schlimme",
    "Schlimmeren": "Schlimmere",
    "Schlimmsten": "Schlimmste",
    "Schlingenden": "Schlingende",
    "Schlingenderen": "Schlingendere",
    "Schlingendsten": "Schlingendste",
    "Schlingens": "Schlingen",
    "Schlingernden": "Schlingernde",
    "Schlingernderen": "Schlingerndere",
    "Schlingerndsten": "Schlingerndste",
    "Schlingerns": "Schlingern",
    "Schlipse": "Schlips",
    "Schlipsen": "Schlips",
    "Schlipses": "Schlips",
    "Schlittens": "Schlitten",
    "Schlitternden": "Schlitternde",
    "Schlitterns": "Schlittern",
    "Schlittschuhe": "Schlittschuh",
    "Schlittschuhen": "Schlittschuh",
    "Schlittschuhes": "Schlittschuh",
    "Schlittschuhs": "Schlittschuh",
    "Schlitzaugen": "Schlitzauge",
    "Schlitzauges": "Schlitzauge",
    "Schlitzenden": "Schlitzende",
    "Schlitzens": "Schlitzen",
    "Schlitzohre": "Schlitzohr",
    "Schlitzohren": "Schlitzohr",
    "Schlitzohrige": "schlitzohrig",
    "Schlitzohrigen": "Schlitzohrige",
    "Schlitzohrigeren": "Schlitzohrigere",
    "Schlitzohrigsten": "Schlitzohrigste",
    "Schlitzohrs": "Schlitzohr",
    "Schlitzäugige": "schlitzäugig",
    "Schlitzäugigen": "Schlitzäugige",
    "Schlosse": "Schloß",
    "Schlosser": "schlossern",
    "Schlossern": "Schlosser",
    "Schlossernden": "Schlossernde",
    "Schlosserns": "Schlossern",
    "Schlossers": "Schlosser",
    "Schlosses": "Schloß",
    "Schlote": "Schlot",
    "Schloten": "Schlot",
    "Schlots": "Schlot",
    "Schlotterigen": "Schlotterige",
    "Schlotterigeren": "Schlotterigere",
    "Schlotterigsten": "Schlotterigste",
    "Schlotternden": "Schlotternde",
    "Schlotternderen": "Schlotterndere",
    "Schlotterndsten": "Schlotterndste",
    "Schlotterns": "Schlottern",
    "Schluchten": "Schlucht",
    "Schluchzenden": "Schluchzende",
    "Schluchzenderen": "Schluchzendere",
    "Schluchzendsten": "Schluchzendste",
    "Schluchzens": "Schluchzen",
    "Schluck": "schlucken",
    "Schluckaufs": "Schluckauf",
    "Schlucke": "schlucken",
    "Schlucken": "Schluck",
    "Schluckenden": "Schluckende",
    "Schluckens": "Schlucken",
    "Schluckern": "Schlucker",
    "Schluckers": "Schlucker",
    "Schlucks": "Schluck",
    "Schluderigen": "Schluderige",
    "Schluderigeren": "Schluderigere",
    "Schluderigsten": "Schluderigste",
    "Schludernden": "Schludernde",
    "Schludernderen": "Schluderndere",
    "Schluderndsten": "Schluderndste",
    "Schluderns": "Schludern",
    "Schludriane": "Schludrian",
    "Schludrianen": "Schludrian",
    "Schludrians": "Schludrian",
    "Schludrige": "schludrig",
    "Schludrigen": "Schludrige",
    "Schludrigeren": "Schludrigere",
    "Schludrigsten": "Schludrigste",
    "Schluffen": "Schluff",
    "Schlummer": "schlummern",
    "Schlummerliede": "Schlummerlied",
    "Schlummerlieder": "Schlummerlied",
    "Schlummerliedern": "Schlummerlied",
    "Schlummerliedes": "Schlummerlied",
    "Schlummerlieds": "Schlummerlied",
    "Schlummern": "Schlummer",
    "Schlummernden": "Schlummernde",
    "Schlummernderen": "Schlummerndere",
    "Schlummerndsten": "Schlummerndste",
    "Schlummerns": "Schlummern",
    "Schlummers": "Schlummer",
    "Schlumpen": "Schlumpe",
    "Schlumpfe": "Schlumpf",
    "Schlumpfs": "Schlumpf",
    "Schlunzige": "schlunzig",
    "Schlunzigen": "Schlunzige",
    "Schlunzigeren": "Schlunzigere",
    "Schlunzigsten": "Schlunzigste",
    "Schlupfloche": "Schlupfloch",
    "Schlupflochs": "Schlupfloch",
    "Schlupflöcher": "Schlupfloch",
    "Schlupflöchern": "Schlupfloch",
    "Schlusse": "Schluß",
    "Schlusses": "Schluß",
    "Schlußketten": "Schlußkette",
    "Schlußverkaufe": "Schlußverkauf",
    "Schlußverkaufs": "Schlußverkauf",
    "Schlußverkäufe": "Schlußverkauf",
    "Schlußverkäufen": "Schlußverkauf",
    "Schläfchens": "Schläfchen",
    "Schläfen": "Schläfe",
    "Schläfenpyramiden": "Schläfenpyramide",
    "Schläfernden": "Schläfernde",
    "Schläferns": "Schläfern",
    "Schläfrigen": "Schläfrige",
    "Schläfrigeren": "Schläfrigere",
    "Schläfrigsten": "Schläfrigste",
    "Schläge": "Schlag",
    "Schlägen": "Schlag",
    "Schlägereien": "Schlägerei",
    "Schlägern": "Schläger",
    "Schlägers": "Schläger",
    "Schlämmenden": "Schlämmende",
    "Schlämmenderen": "Schlämmendere",
    "Schlämmendsten": "Schlämmendste",
    "Schlämmens": "Schlämmen",
    "Schlängelnden": "Schlängelnde",
    "Schlängelnderen": "Schlängelndere",
    "Schlängelndsten": "Schlängelndste",
    "Schlängelns": "Schlängeln",
    "Schlängleins": "Schlänglein",
    "Schläuche": "Schlauch",
    "Schläuchen": "Schlauch",
    "Schlösser": "Schloß",
    "Schlössern": "Schloß",
    "Schlößleins": "Schlößlein",
    "Schlüchterns": "Schlüchtern",
    "Schlückchens": "Schlückchen",
    "Schlümpfe": "Schlumpf",
    "Schlümpfen": "Schlumpf",
    "Schlüpfenden": "Schlüpfende",
    "Schlüpfens": "Schlüpfen",
    "Schlüpfrige": "schlüpfrig",
    "Schlüpfrigen": "Schlüpfrige",
    "Schlüpfrigeren": "Schlüpfrigere",
    "Schlüpfrigsten": "Schlüpfrigste",
    "Schlürfenden": "Schlürfende",
    "Schlürfenderen": "Schlürfendere",
    "Schlürfendsten": "Schlürfendste",
    "Schlürfens": "Schlürfen",
    "Schlüsse": "Schluß",
    "Schlüssel": "schlüsseln",
    "Schlüsselbeine": "Schlüsselbein",
    "Schlüsselbeinen": "Schlüsselbein",
    "Schlüsselbeins": "Schlüsselbein",
    "Schlüsselchens": "Schlüsselchen",
    "Schlüsselfertigen": "Schlüsselfertige",
    "Schlüsseln": "Schlüssel",
    "Schlüsselnden": "Schlüsselnde",
    "Schlüsselns": "Schlüsseln",
    "Schlüssels": "Schlüssel",
    "Schlüssen": "Schluß",
    "Schlüssige": "schlüssig",
    "Schlüssigen": "Schlüssige",
    "Schlüssigeren": "Schlüssigere",
    "Schlüssigsten": "Schlüssigste",
    "Schmachtenden": "Schmachtende",
    "Schmachtenderen": "Schmachtendere",
    "Schmachtendsten": "Schmachtendste",
    "Schmachtens": "Schmachten",
    "Schmachvollen": "Schmachvolle",
    "Schmachvolleren": "Schmachvollere",
    "Schmachvollsten": "Schmachvollste",
    "Schmackhaften": "Schmackhafte",
    "Schmackhafteren": "Schmackhaftere",
    "Schmackhaftesten": "Schmackhafteste",
    "Schmalbrüstigen": "Schmalbrüstige",
    "Schmalbrüstigeren": "Schmalbrüstigere",
    "Schmalbrüstigsten": "Schmalbrüstigste",
    "Schmalen": "Schmale",
    "Schmaleren": "Schmalere",
    "Schmalspurigen": "Schmalspurige",
    "Schmalspurigeren": "Schmalspurigere",
    "Schmalspurigsten": "Schmalspurigste",
    "Schmalsten": "Schmalste",
    "Schmalviehs": "Schmalvieh",
    "Schmalzige": "schmalzig",
    "Schmalzigen": "Schmalzige",
    "Schmalzigeren": "Schmalzigere",
    "Schmalzigsten": "Schmalzigste",
    "Schmankerln": "Schmankerl",
    "Schmankerls": "Schmankerl",
    "Schmarotzenden": "Schmarotzende",
    "Schmarotzenderen": "Schmarotzendere",
    "Schmarotzendsten": "Schmarotzendste",
    "Schmarotzens": "Schmarotzen",
    "Schmarotzerische": "schmarotzerisch",
    "Schmarotzerischen": "Schmarotzerische",
    "Schmarotzerischeren": "Schmarotzerischere",
    "Schmarotzte": "schmarotzt",
    "Schmarotzten": "Schmarotzte",
    "Schmatzenden": "Schmatzende",
    "Schmatzenderen": "Schmatzendere",
    "Schmatzendsten": "Schmatzendste",
    "Schmatzens": "Schmatzen",
    "Schmatzern": "Schmatzer",
    "Schmatzers": "Schmatzer",
    "Schmeckenden": "Schmeckende",
    "Schmeckens": "Schmecken",
    "Schmeicheleien": "Schmeichelei",
    "Schmeichelhafte": "schmeichelhaft",
    "Schmeichelhaften": "Schmeichelhafte",
    "Schmeichelhafteren": "Schmeichelhaftere",
    "Schmeichelnden": "Schmeichelnde",
    "Schmeichelnderen": "Schmeichelndere",
    "Schmeichelndsten": "Schmeichelndste",
    "Schmeichelns": "Schmeicheln",
    "Schmeichlerischen": "Schmeichlerische",
    "Schmeichlerischeren": "Schmeichlerischere",
    "Schmeichlern": "Schmeichler",
    "Schmeichlers": "Schmeichler",
    "Schmeißenden": "Schmeißende",
    "Schmeißenderen": "Schmeißendere",
    "Schmeißendsten": "Schmeißendste",
    "Schmeißens": "Schmeißen",
    "Schmeißfliegen": "Schmeißfliege",
    "Schmelzbaren": "Schmelzbare",
    "Schmelzen": "Schmelze",
    "Schmelzenden": "Schmelzende",
    "Schmelzenderen": "Schmelzendere",
    "Schmelzendsten": "Schmelzendste",
    "Schmelzens": "Schmelzen",
    "Schmelzkäsen": "Schmelzkäse",
    "Schmelzkäses": "Schmelzkäse",
    "Schmelzofens": "Schmelzofen",
    "Schmelztiegeln": "Schmelztiegel",
    "Schmelztiegels": "Schmelztiegel",
    "Schmelzwassers": "Schmelzwasser",
    "Schmelzöfen": "Schmelzofen",
    "Schmerz": "schmerzen",
    "Schmerze": "schmerzen",
    "Schmerzempfindlichen": "Schmerzempfindliche",
    "Schmerzempfindlicheren": "Schmerzempfindlichere",
    "Schmerzen": "Schmerz",
    "Schmerzenden": "Schmerzende",
    "Schmerzenderen": "Schmerzendere",
    "Schmerzendsten": "Schmerzendste",
    "Schmerzens": "Schmerzen",
    "Schmerzensreiche": "schmerzensreich",
    "Schmerzensreichen": "Schmerzensreiche",
    "Schmerzensreicheren": "Schmerzensreichere",
    "Schmerzes": "Schmerz",
    "Schmerzfreien": "Schmerzfreie",
    "Schmerzhaften": "Schmerzhafte",
    "Schmerzhafteren": "Schmerzhaftere",
    "Schmerzhaftesten": "Schmerzhafteste",
    "Schmerzlichen": "Schmerzliche",
    "Schmerzlicheren": "Schmerzlichere",
    "Schmerzlichsten": "Schmerzlichste",
    "Schmerzlosen": "Schmerzlose",
    "Schmerzloseren": "Schmerzlosere",
    "Schmerzlosesten": "Schmerzloseste",
    "Schmerzstillenden": "Schmerzstillende",
    "Schmerzvollen": "Schmerzvolle",
    "Schmerzvolleren": "Schmerzvollere",
    "Schmerzvollsten": "Schmerzvollste",
    "Schmetterballe": "Schmetterball",
    "Schmetterballs": "Schmetterball",
    "Schmetterbälle": "Schmetterball",
    "Schmetterbällen": "Schmetterball",
    "Schmetterlinge": "Schmetterling",
    "Schmetterlingen": "Schmetterling",
    "Schmetterlinges": "Schmetterling",
    "Schmetterlings": "Schmetterling",
    "Schmetternden": "Schmetternde",
    "Schmetternderen": "Schmetterndere",
    "Schmetterndsten": "Schmetterndste",
    "Schmetterns": "Schmettern",
    "Schmids": "Schmid",
    "Schmidts": "Schmidt",
    "Schmiede": "schmieden",
    "Schmiedeeisens": "Schmiedeeisen",
    "Schmiedefeuern": "Schmiedefeuer",
    "Schmiedefeuers": "Schmiedefeuer",
    "Schmiedehammers": "Schmiedehammer",
    "Schmiedehämmer": "Schmiedehammer",
    "Schmiedehämmern": "Schmiedehammer",
    "Schmieden": "Schmiede",
    "Schmiedenden": "Schmiedende",
    "Schmiedens": "Schmieden",
    "Schmiedes": "Schmied",
    "Schmieds": "Schmied",
    "Schmiegenden": "Schmiegende",
    "Schmiegenderen": "Schmiegendere",
    "Schmiegendsten": "Schmiegendste",
    "Schmiegens": "Schmiegen",
    "Schmiegsamen": "Schmiegsame",
    "Schmiegsameren": "Schmiegsamere",
    "Schmiegsamsten": "Schmiegsamste",
    "Schmieren": "Schmiere",
    "Schmierenden": "Schmierende",
    "Schmierenderen": "Schmierendere",
    "Schmierendsten": "Schmierendste",
    "Schmierens": "Schmieren",
    "Schmierereien": "Schmiererei",
    "Schmierfette": "Schmierfett",
    "Schmierfetten": "Schmierfett",
    "Schmierfetts": "Schmierfett",
    "Schmiergelde": "Schmiergeld",
    "Schmiergelder": "Schmiergeld",
    "Schmiergeldern": "Schmiergeld",
    "Schmiergeldes": "Schmiergeld",
    "Schmiergelds": "Schmiergeld",
    "Schmierhefte": "Schmierheft",
    "Schmierheften": "Schmierheft",
    "Schmierhefts": "Schmierheft",
    "Schmierige": "schmierig",
    "Schmierigen": "Schmierige",
    "Schmierigeren": "Schmierigere",
    "Schmierigsten": "Schmierigste",
    "Schmierkäsen": "Schmierkäse",
    "Schmierkäses": "Schmierkäse",
    "Schmierungen": "Schmierung",
    "Schmierzetteln": "Schmierzettel",
    "Schmierzettels": "Schmierzettel",
    "Schminken": "Schminke",
    "Schminkenden": "Schminkende",
    "Schminkenderen": "Schminkendere",
    "Schminkendsten": "Schminkendste",
    "Schminkens": "Schminken",
    "Schmirgel": "schmirgeln",
    "Schmirgeln": "Schmirgel",
    "Schmirgelnden": "Schmirgelnde",
    "Schmirgelnderen": "Schmirgelndere",
    "Schmirgelndsten": "Schmirgelndste",
    "Schmirgelns": "Schmirgeln",
    "Schmirgels": "Schmirgel",
    "Schmirgelscheiben": "Schmirgelscheibe",
    "Schmissigen": "Schmissige",
    "Schmissigeren": "Schmissigere",
    "Schmissigsten": "Schmissigste",
    "Schmitts": "Schmitt",
    "Schmollenden": "Schmollende",
    "Schmollenderen": "Schmollendere",
    "Schmollendsten": "Schmollendste",
    "Schmollens": "Schmollen",
    "Schmollwinkeln": "Schmollwinkel",
    "Schmollwinkels": "Schmollwinkel",
    "Schmonzetten": "Schmonzette",
    "Schmorbratens": "Schmorbraten",
    "Schmorenden": "Schmorende",
    "Schmorenderen": "Schmorendere",
    "Schmorendsten": "Schmorendste",
    "Schmorens": "Schmoren",
    "Schmorfleische": "Schmorfleisch",
    "Schmorfleisches": "Schmorfleisch",
    "Schmorfleischs": "Schmorfleisch",
    "Schmucken": "Schmucke",
    "Schmuckeren": "Schmuckere",
    "Schmucklosen": "Schmucklose",
    "Schmuckloseren": "Schmucklosere",
    "Schmucklosesten": "Schmuckloseste",
    "Schmucks": "Schmuck",
    "Schmucksten": "Schmuckste",
    "Schmuddeligen": "Schmuddelige",
    "Schmuddeligeren": "Schmuddeligere",
    "Schmuddeligsten": "Schmuddeligste",
    "Schmuddelkinde": "Schmuddelkind",
    "Schmuddelkinder": "Schmuddelkind",
    "Schmuddelkindern": "Schmuddelkind",
    "Schmuddelkindes": "Schmuddelkind",
    "Schmuddelkinds": "Schmuddelkind",
    "Schmuddelnden": "Schmuddelnde",
    "Schmuddelns": "Schmuddeln",
    "Schmuddelwetters": "Schmuddelwetter",
    "Schmuddligen": "Schmuddlige",
    "Schmuddligeren": "Schmuddligere",
    "Schmuddligsten": "Schmuddligste",
    "Schmuggel": "schmuggeln",
    "Schmuggeln": "Schmuggel",
    "Schmuggelnden": "Schmuggelnde",
    "Schmuggelns": "Schmuggeln",
    "Schmuggels": "Schmuggel",
    "Schmuggelwaren": "Schmuggelware",
    "Schmugglern": "Schmuggler",
    "Schmugglers": "Schmuggler",
    "Schmunzelnden": "Schmunzelnde",
    "Schmunzelnderen": "Schmunzelndere",
    "Schmunzelndsten": "Schmunzelndste",
    "Schmunzelns": "Schmunzeln",
    "Schmusenden": "Schmusende",
    "Schmusenderen": "Schmusendere",
    "Schmusendsten": "Schmusendste",
    "Schmusens": "Schmusen",
    "Schmusereien": "Schmuserei",
    "Schmutzblatte": "Schmutzblatt",
    "Schmutzblatts": "Schmutzblatt",
    "Schmutzblätter": "Schmutzblatt",
    "Schmutzblättern": "Schmutzblatt",
    "Schmutze": "Schmutz",
    "Schmutzereien": "Schmutzerei",
    "Schmutzes": "Schmutz",
    "Schmutzige": "schmutzig",
    "Schmutzigen": "Schmutzige",
    "Schmutzigeren": "Schmutzigere",
    "Schmutzigsten": "Schmutzigste",
    "Schmutzwassers": "Schmutzwasser",
    "Schmächtigen": "Schmächtige",
    "Schmächtigeren": "Schmächtigere",
    "Schmächtigsten": "Schmächtigste",
    "Schmählichen": "Schmähliche",
    "Schmälernden": "Schmälernde",
    "Schmälerns": "Schmälern",
    "Schmätzchens": "Schmätzchen",
    "Schmökernden": "Schmökernde",
    "Schmökernderen": "Schmökerndere",
    "Schmökerndsten": "Schmökerndste",
    "Schmökerns": "Schmökern",
    "Schmückenden": "Schmückende",
    "Schmückens": "Schmücken",
    "Schnabels": "Schnabel",
    "Schnaken": "Schnake",
    "Schnalle": "schnallen",
    "Schnallen": "Schnalle",
    "Schnallenden": "Schnallende",
    "Schnallens": "Schnallen",
    "Schnalzenden": "Schnalzende",
    "Schnalzenderen": "Schnalzendere",
    "Schnalzendsten": "Schnalzendste",
    "Schnalzens": "Schnalzen",
    "Schnappenden": "Schnappende",
    "Schnappenderen": "Schnappendere",
    "Schnappendsten": "Schnappendste",
    "Schnappens": "Schnappen",
    "Schnappmessern": "Schnappmesser",
    "Schnappmessers": "Schnappmesser",
    "Schnapse": "Schnaps",
    "Schnapses": "Schnaps",
    "Schnapsideen": "Schnapsidee",
    "Schnarchenden": "Schnarchende",
    "Schnarchenderen": "Schnarchendere",
    "Schnarchendsten": "Schnarchendste",
    "Schnarchens": "Schnarchen",
    "Schnarrenbergern": "Schnarrenberger",
    "Schnarrenbergers": "Schnarrenberger",
    "Schnatterenten": "Schnatterente",
    "Schnattergänse": "Schnattergans",
    "Schnattergänsen": "Schnattergans",
    "Schnatterliesen": "Schnatterliese",
    "Schnatternden": "Schnatternde",
    "Schnatternderen": "Schnatterndere",
    "Schnatterndsten": "Schnatterndste",
    "Schnatterns": "Schnattern",
    "Schnaubenden": "Schnaubende",
    "Schnaubens": "Schnauben",
    "Schnaufenden": "Schnaufende",
    "Schnaufenderen": "Schnaufendere",
    "Schnaufendsten": "Schnaufendste",
    "Schnaufens": "Schnaufen",
    "Schnaufern": "Schnaufer",
    "Schnaufers": "Schnaufer",
    "Schnauze": "schnauzen",
    "Schnauzen": "Schnauze",
    "Schnauzenden": "Schnauzende",
    "Schnauzens": "Schnauzen",
    "Schnauzern": "Schnauzer",
    "Schnauzers": "Schnauzer",
    "Schneefreien": "Schneefreie",
    "Schnees": "Schnee",
    "Schneesichere": "schneesicher",
    "Schneesicheren": "Schneesichere",
    "Schneeweben": "Schneewebe",
    "Schneeweiße": "schneeweiß",
    "Schneeweißen": "Schneeweiße",
    "Schneewittchens": "Schneewittchen",
    "Schneidenden": "Schneidende",
    "Schneidens": "Schneiden",
    "Schneider": "schneidern",
    "Schneiderinnen": "Schneiderin",
    "Schneidern": "Schneider",
    "Schneidernden": "Schneidernde",
    "Schneiderns": "Schneidern",
    "Schneiders": "Schneider",
    "Schneidigen": "Schneidige",
    "Schneidigeren": "Schneidigere",
    "Schneidigsten": "Schneidigste",
    "Schneienden": "Schneiende",
    "Schneienderen": "Schneiendere",
    "Schneiendsten": "Schneiendste",
    "Schneiens": "Schneien",
    "Schneisen": "Schneise",
    "Schnellbahnen": "Schnellbahn",
    "Schnelldienste": "Schnelldienst",
    "Schnelldiensten": "Schnelldienst",
    "Schnelldiensts": "Schnelldienst",
    "Schnelle": "schnell",
    "Schnellen": "Schnelle",
    "Schnellenden": "Schnellende",
    "Schnellens": "Schnellen",
    "Schnelleren": "Schnellere",
    "Schnellfüßigen": "Schnellfüßige",
    "Schnellfüßigeren": "Schnellfüßigere",
    "Schnellfüßigsten": "Schnellfüßigste",
    "Schnellheftern": "Schnellhefter",
    "Schnellhefters": "Schnellhefter",
    "Schnelligkeiten": "Schnelligkeit",
    "Schnellpakete": "Schnellpaket",
    "Schnellpaketen": "Schnellpaket",
    "Schnellpakets": "Schnellpaket",
    "Schnellschriften": "Schnellschrift",
    "Schnellsten": "Schnellste",
    "Schnellstmöglichen": "Schnellstmögliche",
    "Schnellstmöglicheren": "Schnellstmöglichere",
    "Schnellverfahrens": "Schnellverfahren",
    "Schnellwählern": "Schnellwähler",
    "Schnellwählers": "Schnellwähler",
    "Schnellzuge": "Schnellzug",
    "Schnellzugs": "Schnellzug",
    "Schnellzüge": "Schnellzug",
    "Schnellzügen": "Schnellzug",
    "Schnepfen": "Schnepfe",
    "Schneppern": "Schnepper",
    "Schneppers": "Schnepper",
    "Schneuze": "schneuzen",
    "Schneuzen": "Schneuze",
    "Schneuzenden": "Schneuzende",
    "Schneuzenderen": "Schneuzendere",
    "Schneuzendsten": "Schneuzendste",
    "Schneuzens": "Schneuzen",
    "Schnickschnacks": "Schnickschnack",
    "Schniefenden": "Schniefende",
    "Schniefenderen": "Schniefendere",
    "Schniefendsten": "Schniefendste",
    "Schniefens": "Schniefen",
    "Schnippchens": "Schnippchen",
    "Schnippenden": "Schnippende",
    "Schnippens": "Schnippen",
    "Schnippischen": "Schnippische",
    "Schnippischeren": "Schnippischere",
    "Schnippischsten": "Schnippischste",
    "Schnipsel": "schnipseln",
    "Schnipseln": "Schnipsel",
    "Schnipselnden": "Schnipselnde",
    "Schnipselns": "Schnipseln",
    "Schnipsels": "Schnipsel",
    "Schnittchens": "Schnittchen",
    "Schnitte": "Schnitt",
    "Schnitten": "Schnitte",
    "Schnittes": "Schnitt",
    "Schnittgrüns": "Schnittgrün",
    "Schnittige": "schnittig",
    "Schnittigen": "Schnittige",
    "Schnittigeren": "Schnittigere",
    "Schnittigsten": "Schnittigste",
    "Schnittlauchs": "Schnittlauch",
    "Schnittmengen": "Schnittmenge",
    "Schnitts": "Schnitt",
    "Schnitzeln": "Schnitzel",
    "Schnitzels": "Schnitzel",
    "Schnitzenden": "Schnitzende",
    "Schnitzens": "Schnitzen",
    "Schnitzereien": "Schnitzerei",
    "Schnitzern": "Schnitzer",
    "Schnitzers": "Schnitzer",
    "Schnitzwerke": "Schnitzwerk",
    "Schnitzwerken": "Schnitzwerk",
    "Schnitzwerks": "Schnitzwerk",
    "Schnodderige": "schnodderig",
    "Schnodderigen": "Schnodderige",
    "Schnodderigeren": "Schnodderigere",
    "Schnodderigsten": "Schnodderigste",
    "Schnoddrigen": "Schnoddrige",
    "Schnoddrigeren": "Schnoddrigere",
    "Schnoddrigsten": "Schnoddrigste",
    "Schnoors": "Schnoor",
    "Schnorchel": "schnorcheln",
    "Schnorcheln": "Schnorchel",
    "Schnorchelnden": "Schnorchelnde",
    "Schnorchelnderen": "Schnorchelndere",
    "Schnorchelndsten": "Schnorchelndste",
    "Schnorchelns": "Schnorcheln",
    "Schnorchels": "Schnorchel",
    "Schnorrenden": "Schnorrende",
    "Schnorrenderen": "Schnorrendere",
    "Schnorrendsten": "Schnorrendste",
    "Schnorrens": "Schnorren",
    "Schnuckligen": "Schnucklige",
    "Schnuckligeren": "Schnuckligere",
    "Schnuckligsten": "Schnuckligste",
    "Schnulzen": "Schnulze",
    "Schnupfens": "Schnupfen",
    "Schnuppernden": "Schnuppernde",
    "Schnupperns": "Schnuppern",
    "Schnurrbarte": "Schnurrbart",
    "Schnurrbarts": "Schnurrbart",
    "Schnurrbärte": "Schnurrbart",
    "Schnurrbärten": "Schnurrbart",
    "Schnurrenden": "Schnurrende",
    "Schnurrens": "Schnurren",
    "Schnurrige": "schnurrig",
    "Schnurrigen": "Schnurrige",
    "Schnurrigeren": "Schnurrigere",
    "Schnurrigsten": "Schnurrigste",
    "Schnurrpfeifereien": "Schnurrpfeiferei",
    "Schnuten": "Schnute",
    "Schnäbel": "Schnabel",
    "Schnäbeln": "Schnabel",
    "Schnäbleins": "Schnäblein",
    "Schnäppchens": "Schnäppchen",
    "Schnäppern": "Schnäpper",
    "Schnäppers": "Schnäpper",
    "Schnäpse": "Schnaps",
    "Schnäpsen": "Schnaps",
    "Schnäuzchens": "Schnäuzchen",
    "Schnäuzende": "schnäuzend",
    "Schnäuzenden": "Schnäuzende",
    "Schnäuzenderen": "Schnäuzendere",
    "Schnäuzendsten": "Schnäuzendste",
    "Schnäuzens": "Schnäuzen",
    "Schnäuzleins": "Schnäuzlein",
    "Schnöden": "Schnöde",
    "Schnöderen": "Schnödere",
    "Schnödesten": "Schnödeste",
    "Schnörkeligen": "Schnörkelige",
    "Schnörkeligeren": "Schnörkeligere",
    "Schnörkeligsten": "Schnörkeligste",
    "Schnörkeln": "Schnörkel",
    "Schnörkels": "Schnörkel",
    "Schnöseligen": "Schnöselige",
    "Schnöseligeren": "Schnöseligere",
    "Schnöseligsten": "Schnöseligste",
    "Schnüffelnden": "Schnüffelnde",
    "Schnüffelnderen": "Schnüffelndere",
    "Schnüffelndsten": "Schnüffelndste",
    "Schnüffelns": "Schnüffeln",
    "Schnüfflern": "Schnüffler",
    "Schnüfflers": "Schnüffler",
    "Schnürbande": "Schnürband",
    "Schnürbandes": "Schnürband",
    "Schnürbands": "Schnürband",
    "Schnürbänder": "Schnürband",
    "Schnürbändern": "Schnürband",
    "Schnüre": "schnüren",
    "Schnüren": "Schnur",
    "Schnürenden": "Schnürende",
    "Schnürens": "Schnüren",
    "Schnürriemens": "Schnürriemen",
    "Schnürschuhe": "Schnürschuh",
    "Schnürschuhen": "Schnürschuh",
    "Schnürschuhs": "Schnürschuh",
    "Schnürsenkeln": "Schnürsenkel",
    "Schnürsenkels": "Schnürsenkel",
    "Schnürstiefeln": "Schnürstiefel",
    "Schnürstiefels": "Schnürstiefel",
    "Schnütchens": "Schnütchen",
    "Schock": "schocken",
    "Schockenden": "Schockende",
    "Schockenderen": "Schockendere",
    "Schockendsten": "Schockendste",
    "Schockens": "Schocken",
    "Schocks": "Schock",
    "Schoelers": "Schoeler",
    "Schokoladen": "Schokolade",
    "Schokoladene": "schokoladen",
    "Schokoladenen": "Schokoladene",
    "Schollen": "Scholle",
    "Scholls": "Scholl",
    "Schonarbeiten": "Schonarbeit",
    "Schonenden": "Schonende",
    "Schonenderen": "Schonendere",
    "Schonendsten": "Schonendste",
    "Schonens": "Schonen",
    "Schonern": "Schoner",
    "Schoners": "Schoner",
    "Schonfristen": "Schonfrist",
    "Schonungen": "Schonung",
    "Schonungsbedürftige": "schonungsbedürftig",
    "Schonungsbedürftigen": "Schonungsbedürftige",
    "Schonungsbedürftigeren": "Schonungsbedürftigere",
    "Schonungslosen": "Schonungslose",
    "Schonungsloseren": "Schonungslosere",
    "Schonungslosesten": "Schonungsloseste",
    "Schonzeiten": "Schonzeit",
    "Schopfe": "Schopf",
    "Schopfes": "Schopf",
    "Schopfs": "Schopf",
    "Schoppenden": "Schoppende",
    "Schoppens": "Schoppen",
    "Schorlen": "Schorle",
    "Schornsteine": "Schornstein",
    "Schornsteinen": "Schornstein",
    "Schornsteines": "Schornstein",
    "Schornsteins": "Schornstein",
    "Schosen": "Schose",
    "Schoten": "Schote",
    "Schotten": "Schotte",
    "Schotternden": "Schotternde",
    "Schotternderen": "Schotterndere",
    "Schotterndsten": "Schotterndste",
    "Schotterns": "Schottern",
    "Schottinnen": "Schottin",
    "Schottische": "schottisch",
    "Schottischen": "Schottische",
    "Schotts": "Schott",
    "Schraffierenden": "Schraffierende",
    "Schraffierens": "Schraffieren",
    "Schraffierte": "schraffiert",
    "Schraffierten": "Schraffierte",
    "Schrammenden": "Schrammende",
    "Schrammens": "Schrammen",
    "Schrammigen": "Schrammige",
    "Schrammigeren": "Schrammigere",
    "Schrammigsten": "Schrammigste",
    "Schranke": "Schrank",
    "Schranken": "Schranke",
    "Schrankenlosen": "Schrankenlose",
    "Schrankes": "Schrank",
    "Schranks": "Schrank",
    "Schrauben": "Schraube",
    "Schraubenden": "Schraubende",
    "Schraubens": "Schrauben",
    "Schrebergartens": "Schrebergarten",
    "Schrebergärten": "Schrebergarten",
    "Schrebergärtnern": "Schrebergärtner",
    "Schrebergärtners": "Schrebergärtner",
    "Schreck": "schrecken",
    "Schrecke": "schrecken",
    "Schrecken": "Schreck",
    "Schreckenden": "Schreckende",
    "Schreckens": "Schrecken",
    "Schreckhaften": "Schreckhafte",
    "Schreckhafteren": "Schreckhaftere",
    "Schreckhaftesten": "Schreckhafteste",
    "Schrecklichen": "Schreckliche",
    "Schrecklicheren": "Schrecklichere",
    "Schrecklichsten": "Schrecklichste",
    "Schrecks": "Schreck",
    "Schreckschrauben": "Schreckschraube",
    "Schreddern": "Schredder",
    "Schredders": "Schredder",
    "Schreibenden": "Schreibende",
    "Schreibens": "Schreiben",
    "Schreibern": "Schreiber",
    "Schreibers": "Schreiber",
    "Schreibfaulen": "Schreibfaule",
    "Schreibfauleren": "Schreibfaulere",
    "Schreibfaulsten": "Schreibfaulste",
    "Schreibfedern": "Schreibfeder",
    "Schreibgeräte": "Schreibgerät",
    "Schreibgeräten": "Schreibgerät",
    "Schreibgerätes": "Schreibgerät",
    "Schreibgeräts": "Schreibgerät",
    "Schreibgewandte": "schreibgewandt",
    "Schreibgewandten": "Schreibgewandte",
    "Schreibhefte": "Schreibheft",
    "Schreibheften": "Schreibheft",
    "Schreibhefts": "Schreibheft",
    "Schreibkräfte": "Schreibkraft",
    "Schreibkräften": "Schreibkraft",
    "Schreibmappen": "Schreibmappe",
    "Schreibmaschinen": "Schreibmaschine",
    "Schreibmotive": "Schreibmotiv",
    "Schreibmotiven": "Schreibmotiv",
    "Schreibmotives": "Schreibmotiv",
    "Schreibmotivs": "Schreibmotiv",
    "Schreibpapiere": "Schreibpapier",
    "Schreibpapieren": "Schreibpapier",
    "Schreibpapiers": "Schreibpapier",
    "Schreibschriften": "Schreibschrift",
    "Schreibstifte": "Schreibstift",
    "Schreibstiften": "Schreibstift",
    "Schreibstifts": "Schreibstift",
    "Schreibstoffe": "Schreibstoff",
    "Schreibstoffen": "Schreibstoff",
    "Schreibstoffs": "Schreibstoff",
    "Schreibstuben": "Schreibstube",
    "Schreibtische": "Schreibtisch",
    "Schreibtischen": "Schreibtisch",
    "Schreibtisches": "Schreibtisch",
    "Schreibtischs": "Schreibtisch",
    "Schreibungen": "Schreibung",
    "Schreibwaren": "Schreibware",
    "Schreibweisen": "Schreibweise",
    "Schreibzeuge": "Schreibzeug",
    "Schreibzeugen": "Schreibzeug",
    "Schreibzeugs": "Schreibzeug",
    "Schreienden": "Schreiende",
    "Schreienderen": "Schreiendere",
    "Schreiendsten": "Schreiendste",
    "Schreiens": "Schreien",
    "Schreihalse": "Schreihals",
    "Schreihalss": "Schreihals",
    "Schreihälse": "Schreihals",
    "Schreihälsen": "Schreihals",
    "Schreiner": "schreinern",
    "Schreinereien": "Schreinerei",
    "Schreinern": "Schreiner",
    "Schreinernden": "Schreinernde",
    "Schreinerns": "Schreinern",
    "Schreiners": "Schreiner",
    "Schreitenden": "Schreitende",
    "Schreitens": "Schreiten",
    "Schreyers": "Schreyer",
    "Schriften": "Schrift",
    "Schriftgelehrten": "Schriftgelehrte",
    "Schriftgießereien": "Schriftgießerei",
    "Schriftgläubige": "schriftgläubig",
    "Schriftgläubigen": "Schriftgläubige",
    "Schriftgläubigeren": "Schriftgläubigere",
    "Schriftlichen": "Schriftliche",
    "Schriftsprachlichen": "Schriftsprachliche",
    "Schriftstellerinnen": "Schriftstellerin",
    "Schriftstellerische": "schriftstellerisch",
    "Schriftstellerischen": "Schriftstellerische",
    "Schriftstellern": "Schriftsteller",
    "Schriftstellers": "Schriftsteller",
    "Schrille": "schrill",
    "Schrillen": "Schrille",
    "Schrilleren": "Schrillere",
    "Schrillsten": "Schrillste",
    "Schrimpegassen": "Schrimpegasse",
    "Schritt": "schreiten",
    "Schritte": "Schritt",
    "Schritten": "Schritt",
    "Schrittes": "Schritt",
    "Schritts": "Schritt",
    "Schroffe": "schroff",
    "Schroffen": "Schroffe",
    "Schrofferen": "Schroffere",
    "Schroffsten": "Schroffste",
    "Schrots": "Schrot",
    "Schrotte": "Schrott",
    "Schrotten": "Schrott",
    "Schrottes": "Schrott",
    "Schrottreife": "schrottreif",
    "Schrottreifen": "Schrottreife",
    "Schrottreiferen": "Schrottreifere",
    "Schrottreifsten": "Schrottreifste",
    "Schrotts": "Schrott",
    "Schrubbenden": "Schrubbende",
    "Schrubbens": "Schrubben",
    "Schrullenhaften": "Schrullenhafte",
    "Schrullenhafteren": "Schrullenhaftere",
    "Schrulligen": "Schrullige",
    "Schrulligeren": "Schrulligere",
    "Schrulligsten": "Schrulligste",
    "Schrumpeligen": "Schrumpelige",
    "Schrumpeligeren": "Schrumpeligere",
    "Schrumpeligsten": "Schrumpeligste",
    "Schrumpelnden": "Schrumpelnde",
    "Schrumpelnderen": "Schrumpelndere",
    "Schrumpelndsten": "Schrumpelndste",
    "Schrumpelns": "Schrumpeln",
    "Schrumpfenden": "Schrumpfende",
    "Schrumpfens": "Schrumpfen",
    "Schrumpfnieren": "Schrumpfniere",
    "Schrumpligen": "Schrumplige",
    "Schrumpligeren": "Schrumpligere",
    "Schrumpligsten": "Schrumpligste",
    "Schrägen": "Schräge",
    "Schrägenden": "Schrägende",
    "Schrägens": "Schrägen",
    "Schräghecks": "Schrägheck",
    "Schräglaufende": "schräglaufend",
    "Schräglaufenden": "Schräglaufende",
    "Schrägstreifens": "Schrägstreifen",
    "Schrägstriche": "Schrägstrich",
    "Schrägstrichen": "Schrägstrich",
    "Schrägstrichs": "Schrägstrich",
    "Schränkchens": "Schränkchen",
    "Schränke": "schränken",
    "Schränken": "Schrank",
    "Schränkenden": "Schränkende",
    "Schränkens": "Schränken",
    "Schröders": "Schröder",
    "Schröpfenden": "Schröpfende",
    "Schröpfenderen": "Schröpfendere",
    "Schröpfendsten": "Schröpfendste",
    "Schröpfens": "Schröpfen",
    "Schröpfern": "Schröpfer",
    "Schröpfers": "Schröpfer",
    "Schube": "Schub",
    "Schuberts": "Schubert",
    "Schubes": "Schub",
    "Schubfache": "Schubfach",
    "Schubfaches": "Schubfach",
    "Schubfachs": "Schubfach",
    "Schubfächer": "Schubfach",
    "Schubfächern": "Schubfach",
    "Schubladen": "Schublade",
    "Schubs": "schubsen",
    "Schubsenden": "Schubsende",
    "Schubsens": "Schubsen",
    "Schuckelnden": "Schuckelnde",
    "Schuckelns": "Schuckeln",
    "Schuftenden": "Schuftende",
    "Schuftenderen": "Schuftendere",
    "Schuftendsten": "Schuftendste",
    "Schuftens": "Schuften",
    "Schuhbande": "Schuhband",
    "Schuhbandes": "Schuhband",
    "Schuhbands": "Schuhband",
    "Schuhbänder": "Schuhband",
    "Schuhbändern": "Schuhband",
    "Schuhchens": "Schuhchen",
    "Schuhe": "Schuh",
    "Schuhen": "Schuh",
    "Schuhkrems": "Schuhkrem",
    "Schuhmachereien": "Schuhmacherei",
    "Schuhplattlern": "Schuhplattler",
    "Schuhplattlers": "Schuhplattler",
    "Schuhs": "Schuh",
    "Schulamte": "Schulamt",
    "Schulamtes": "Schulamt",
    "Schulamts": "Schulamt",
    "Schularbeiten": "Schularbeit",
    "Schulbänke": "Schulbank",
    "Schulbänken": "Schulbank",
    "Schulbüchereien": "Schulbücherei",
    "Schuldbeladene": "schuldbeladen",
    "Schuldbeladenen": "Schuldbeladene",
    "Schuldbewußten": "Schuldbewußte",
    "Schuldbewußteren": "Schuldbewußtere",
    "Schuldbewußtesten": "Schuldbewußteste",
    "Schulden": "Schulde",
    "Schuldenden": "Schuldende",
    "Schuldenfreien": "Schuldenfreie",
    "Schuldens": "Schulden",
    "Schuldfähigen": "Schuldfähige",
    "Schuldfähigeren": "Schuldfähigere",
    "Schuldfähigsten": "Schuldfähigste",
    "Schuldigen": "Schuldige",
    "Schuldigeren": "Schuldigere",
    "Schuldigsten": "Schuldigste",
    "Schuldlosen": "Schuldlose",
    "Schuldnern": "Schuldner",
    "Schuldners": "Schuldner",
    "Schuldunfähige": "schuldunfähig",
    "Schuldunfähigen": "Schuldunfähige",
    "Schuldunfähigeren": "Schuldunfähigere",
    "Schuldunfähigsten": "Schuldunfähigste",
    "Schuldzuweisungen": "Schuldzuweisung",
    "Schule": "schulen",
    "Schulen": "Schule",
    "Schulenden": "Schulende",
    "Schulens": "Schulen",
    "Schulerfolge": "Schulerfolg",
    "Schulerfolgen": "Schulerfolg",
    "Schulerfolges": "Schulerfolg",
    "Schulerfolgs": "Schulerfolg",
    "Schulfreie": "schulfrei",
    "Schulfreien": "Schulfreie",
    "Schulfähige": "schulfähig",
    "Schulfähigen": "Schulfähige",
    "Schulfähigeren": "Schulfähigere",
    "Schulfähigsten": "Schulfähigste",
    "Schulhefte": "Schulheft",
    "Schulheften": "Schulheft",
    "Schulhefts": "Schulheft",
    "Schulhofe": "Schulhof",
    "Schulhofes": "Schulhof",
    "Schulhofs": "Schulhof",
    "Schulhöfe": "Schulhof",
    "Schulhöfen": "Schulhof",
    "Schulische": "schulisch",
    "Schulischen": "Schulische",
    "Schuljahre": "Schuljahr",
    "Schuljahren": "Schuljahr",
    "Schuljahres": "Schuljahr",
    "Schuljahrs": "Schuljahr",
    "Schulkinde": "Schulkind",
    "Schulkinder": "Schulkind",
    "Schulkindern": "Schulkind",
    "Schulkindes": "Schulkind",
    "Schulkinds": "Schulkind",
    "Schulleiterinnen": "Schulleiterin",
    "Schulleitern": "Schulleiter",
    "Schulleiters": "Schulleiter",
    "Schulmeisterliche": "schulmeisterlich",
    "Schulmeisterlichen": "Schulmeisterliche",
    "Schulmeisterlicheren": "Schulmeisterlichere",
    "Schulmäßige": "schulmäßig",
    "Schulmäßigen": "Schulmäßige",
    "Schulmäßigeren": "Schulmäßigere",
    "Schulmäßigsten": "Schulmäßigste",
    "Schulpflichtige": "schulpflichtig",
    "Schulpflichtigen": "Schulpflichtige",
    "Schulphobien": "Schulphobie",
    "Schulranzens": "Schulranzen",
    "Schulreife": "schulreif",
    "Schulreifen": "Schulreife",
    "Schulreisen": "Schulreise",
    "Schulschiffe": "Schulschiff",
    "Schulschiffen": "Schulschiff",
    "Schulschiffs": "Schulschiff",
    "Schulsprecherinnen": "Schulsprecherin",
    "Schulstraßen": "Schulstraße",
    "Schulstresse": "Schulstreß",
    "Schulstresses": "Schulstreß",
    "Schultage": "Schultag",
    "Schultagen": "Schultag",
    "Schultages": "Schultag",
    "Schultags": "Schultag",
    "Schulter": "schultern",
    "Schulterfreien": "Schulterfreie",
    "Schulterlangen": "Schulterlange",
    "Schultern": "Schulter",
    "Schulternden": "Schulternde",
    "Schulterns": "Schultern",
    "Schultzes": "Schultze",
    "Schulungen": "Schulung",
    "Schulwesens": "Schulwesen",
    "Schulzes": "Schulze",
    "Schulzeugnisse": "Schulzeugnis",
    "Schulzeugnissen": "Schulzeugnis",
    "Schulzeugnisses": "Schulzeugnis",
    "Schulzimmern": "Schulzimmer",
    "Schulzimmers": "Schulzimmer",
    "Schulämter": "Schulamt",
    "Schulämtern": "Schulamt",
    "Schulängste": "Schulangst",
    "Schulängsten": "Schulangst",
    "Schumachers": "Schumacher",
    "Schumanns": "Schumann",
    "Schummelnden": "Schummelnde",
    "Schummelnderen": "Schummelndere",
    "Schummelndsten": "Schummelndste",
    "Schummelns": "Schummeln",
    "Schummerigen": "Schummerige",
    "Schummerigeren": "Schummerigere",
    "Schummerigsten": "Schummerigste",
    "Schummers": "Schummer",
    "Schummrigen": "Schummrige",
    "Schummrigeren": "Schummrigere",
    "Schummrigsten": "Schummrigste",
    "Schunde": "Schund",
    "Schundes": "Schund",
    "Schunds": "Schund",
    "Schunkelnden": "Schunkelnde",
    "Schunkelnderen": "Schunkelndere",
    "Schunkelndsten": "Schunkelndste",
    "Schunkelns": "Schunkeln",
    "Schuppige": "schuppig",
    "Schuppigen": "Schuppige",
    "Schuppigeren": "Schuppigere",
    "Schuppigsten": "Schuppigste",
    "Schupps": "Schupp",
    "Schurigeleien": "Schurigelei",
    "Schurken": "Schurke",
    "Schurkinnen": "Schurkin",
    "Schurkische": "schurkisch",
    "Schurkischen": "Schurkische",
    "Schusse": "Schuß",
    "Schusselige": "schusselig",
    "Schusseligen": "Schusselige",
    "Schusseligeren": "Schusseligere",
    "Schusseligsten": "Schusseligste",
    "Schusseln": "Schussel",
    "Schussels": "Schussel",
    "Schusses": "Schuß",
    "Schuster": "schustern",
    "Schustereien": "Schusterei",
    "Schustern": "Schuster",
    "Schusternden": "Schusternde",
    "Schusterns": "Schustern",
    "Schusters": "Schuster",
    "Schutts": "Schutt",
    "Schutze": "Schutz",
    "Schutzes": "Schutz",
    "Schutzlose": "schutzlos",
    "Schutzlosen": "Schutzlose",
    "Schutzloseren": "Schutzlosere",
    "Schutzlosesten": "Schutzloseste",
    "Schutzs": "Schutz",
    "Schußbereite": "schußbereit",
    "Schußbereiten": "Schußbereite",
    "Schußfeste": "schußfest",
    "Schußfesten": "Schußfeste",
    "Schußfesteren": "Schußfestere",
    "Schußfestesten": "Schußfesteste",
    "Schußsicheren": "Schußsichere",
    "Schußsichereren": "Schußsicherere",
    "Schußsichersten": "Schußsicherste",
    "Schußwaffen": "Schußwaffe",
    "Schwabbeligen": "Schwabbelige",
    "Schwabbeligeren": "Schwabbeligere",
    "Schwabbeligsten": "Schwabbeligste",
    "Schwabbelnden": "Schwabbelnde",
    "Schwabbelnderen": "Schwabbelndere",
    "Schwabbelndsten": "Schwabbelndste",
    "Schwabbelns": "Schwabbeln",
    "Schwaben": "Schwabe",
    "Schwabs": "Schwab",
    "Schwache": "schwach",
    "Schwachen": "Schwache",
    "Schwachkopfe": "Schwachkopf",
    "Schwachkopfs": "Schwachkopf",
    "Schwachköpfe": "Schwachkopf",
    "Schwachköpfen": "Schwachkopf",
    "Schwachköpfige": "schwachköpfig",
    "Schwachköpfigen": "Schwachköpfige",
    "Schwachköpfigeren": "Schwachköpfigere",
    "Schwachköpfigsten": "Schwachköpfigste",
    "Schwachsinne": "Schwachsinn",
    "Schwachsinnen": "Schwachsinn",
    "Schwachsinnes": "Schwachsinn",
    "Schwachsinnige": "schwachsinnig",
    "Schwachsinnigen": "Schwachsinnige",
    "Schwachsinnigeren": "Schwachsinnigere",
    "Schwachsinnigsten": "Schwachsinnigste",
    "Schwachsinns": "Schwachsinn",
    "Schwafelnden": "Schwafelnde",
    "Schwafelnderen": "Schwafelndere",
    "Schwafelndsten": "Schwafelndste",
    "Schwafelns": "Schwafeln",
    "Schwalbachern": "Schwalbacher",
    "Schwalbachers": "Schwalbacher",
    "Schwalbachs": "Schwalbach",
    "Schwalben": "Schwalbe",
    "Schwalle": "Schwall",
    "Schwallen": "Schwall",
    "Schwalls": "Schwall",
    "Schwamm": "schwimmen",
    "Schwamme": "Schwamm",
    "Schwammerln": "Schwammerl",
    "Schwammerls": "Schwammerl",
    "Schwammes": "Schwamm",
    "Schwammige": "schwammig",
    "Schwammigen": "Schwammige",
    "Schwammigeren": "Schwammigere",
    "Schwammigsten": "Schwammigste",
    "Schwamms": "Schwamm",
    "Schwammähnlichen": "Schwammähnliche",
    "Schwammähnlicheren": "Schwammähnlichere",
    "Schwan": "schwanen",
    "Schwane": "schwanen",
    "Schwanenden": "Schwanende",
    "Schwanenhalse": "Schwanenhals",
    "Schwanenhalses": "Schwanenhals",
    "Schwanenhälse": "Schwanenhals",
    "Schwanenhälsen": "Schwanenhals",
    "Schwanenjungfrauen": "Schwanenjungfrau",
    "Schwanens": "Schwanen",
    "Schwangeren": "Schwangere",
    "Schwangerschaften": "Schwangerschaft",
    "Schwanheimern": "Schwanheimer",
    "Schwanheimers": "Schwanheimer",
    "Schwanheims": "Schwanheim",
    "Schwankenden": "Schwankende",
    "Schwankenderen": "Schwankendere",
    "Schwankendsten": "Schwankendste",
    "Schwankens": "Schwanken",
    "Schwankungen": "Schwankung",
    "Schwans": "Schwan",
    "Schwanze": "Schwanz",
    "Schwanzes": "Schwanz",
    "Schwanzlastige": "schwanzlastig",
    "Schwanzlastigen": "Schwanzlastige",
    "Schwanzlastigeren": "Schwanzlastigere",
    "Schwanzlastigsten": "Schwanzlastigste",
    "Schwanzwedelnde": "schwanzwedelnd",
    "Schwanzwedelnden": "Schwanzwedelnde",
    "Schwappenden": "Schwappende",
    "Schwappenderen": "Schwappendere",
    "Schwappendsten": "Schwappendste",
    "Schwappens": "Schwappen",
    "Schwarten": "Schwarte",
    "Schwarzarbeitenden": "Schwarzarbeitende",
    "Schwarzarbeitens": "Schwarzarbeiten",
    "Schwarzbachs": "Schwarzbach",
    "Schwarzbrote": "Schwarzbrot",
    "Schwarzbroten": "Schwarzbrot",
    "Schwarzbrots": "Schwarzbrot",
    "Schwarze": "schwarz",
    "Schwarzen": "Schwarze",
    "Schwarzerlenwegs": "Schwarzerlenweg",
    "Schwarzfahrern": "Schwarzfahrer",
    "Schwarzfahrers": "Schwarzfahrer",
    "Schwarzfahrten": "Schwarzfahrt",
    "Schwarzgearbeiteten": "Schwarzgearbeitete",
    "Schwarzgehörten": "Schwarzgehörte",
    "Schwarzgemalten": "Schwarzgemalte",
    "Schwarzgemalteren": "Schwarzgemaltere",
    "Schwarzgeschlachteten": "Schwarzgeschlachtete",
    "Schwarzgesehenen": "Schwarzgesehene",
    "Schwarzhandels": "Schwarzhandel",
    "Schwarzhändlern": "Schwarzhändler",
    "Schwarzhändlers": "Schwarzhändler",
    "Schwarzhörenden": "Schwarzhörende",
    "Schwarzhörens": "Schwarzhören",
    "Schwarzkitteln": "Schwarzkittel",
    "Schwarzkittels": "Schwarzkittel",
    "Schwarzkäfern": "Schwarzkäfer",
    "Schwarzkäfers": "Schwarzkäfer",
    "Schwarzkümmeln": "Schwarzkümmel",
    "Schwarzkümmels": "Schwarzkümmel",
    "Schwarzmalenden": "Schwarzmalende",
    "Schwarzmalenderen": "Schwarzmalendere",
    "Schwarzmalendsten": "Schwarzmalendste",
    "Schwarzmalens": "Schwarzmalen",
    "Schwarzmarkte": "Schwarzmarkt",
    "Schwarzmarktes": "Schwarzmarkt",
    "Schwarzmarkts": "Schwarzmarkt",
    "Schwarzmärkte": "Schwarzmarkt",
    "Schwarzmärkten": "Schwarzmarkt",
    "Schwarzpappeln": "Schwarzpappel",
    "Schwarzrocke": "Schwarzrock",
    "Schwarzrocks": "Schwarzrock",
    "Schwarzröcke": "Schwarzrock",
    "Schwarzröcken": "Schwarzrock",
    "Schwarzschlachtenden": "Schwarzschlachtende",
    "Schwarzschlachtens": "Schwarzschlachten",
    "Schwarzschlachtungen": "Schwarzschlachtung",
    "Schwarzsehenden": "Schwarzsehende",
    "Schwarzsehenderen": "Schwarzsehendere",
    "Schwarzsehendsten": "Schwarzsehendste",
    "Schwarzsehens": "Schwarzsehen",
    "Schwarzsehern": "Schwarzseher",
    "Schwarzsehers": "Schwarzseher",
    "Schwarzwalds": "Schwarzwald",
    "Schwarzweißzeichnungen": "Schwarzweißzeichnung",
    "Schwarzwilde": "Schwarzwild",
    "Schwarzwildes": "Schwarzwild",
    "Schwarzwilds": "Schwarzwild",
    "Schwatzenden": "Schwatzende",
    "Schwatzenderen": "Schwatzendere",
    "Schwatzendsten": "Schwatzendste",
    "Schwatzens": "Schwatzen",
    "Schwatzhaften": "Schwatzhafte",
    "Schwatzhafteren": "Schwatzhaftere",
    "Schwatzhaftesten": "Schwatzhafteste",
    "Schwatzliesen": "Schwatzliese",
    "Schwebebahnen": "Schwebebahn",
    "Schwebebalkens": "Schwebebalken",
    "Schwebenden": "Schwebende",
    "Schwebens": "Schweben",
    "Schwebungen": "Schwebung",
    "Schweden": "Schwede",
    "Schwedens": "Schweden",
    "Schwedische": "schwedisch",
    "Schwedischen": "Schwedische",
    "Schwedischeren": "Schwedischere",
    "Schwedischsten": "Schwedischste",
    "Schwefel": "schwefeln",
    "Schwefelartige": "schwefelartig",
    "Schwefelartigen": "Schwefelartige",
    "Schwefeldioxide": "Schwefeldioxid",
    "Schwefeldioxiden": "Schwefeldioxid",
    "Schwefeldioxids": "Schwefeldioxid",
    "Schwefelhaltigen": "Schwefelhaltige",
    "Schwefelhaltigeren": "Schwefelhaltigere",
    "Schwefeligen": "Schwefelige",
    "Schwefeligeren": "Schwefeligere",
    "Schwefeligsten": "Schwefeligste",
    "Schwefeln": "Schwefel",
    "Schwefelnden": "Schwefelnde",
    "Schwefelns": "Schwefeln",
    "Schwefels": "Schwefel",
    "Schweif": "schweifen",
    "Schweife": "schweifen",
    "Schweifen": "Schweif",
    "Schweifenden": "Schweifende",
    "Schweifenderen": "Schweifendere",
    "Schweifendsten": "Schweifendste",
    "Schweifens": "Schweifen",
    "Schweifs": "Schweif",
    "Schweigeminuten": "Schweigeminute",
    "Schweigenden": "Schweigende",
    "Schweigenderen": "Schweigendere",
    "Schweigendsten": "Schweigendste",
    "Schweigens": "Schweigen",
    "Schweigsamen": "Schweigsame",
    "Schweigsameren": "Schweigsamere",
    "Schweigsamsten": "Schweigsamste",
    "Schweine": "Schwein",
    "Schweinen": "Schwein",
    "Schweinereien": "Schweinerei",
    "Schweines": "Schwein",
    "Schweinische": "schweinisch",
    "Schweinischen": "Schweinische",
    "Schweinischeren": "Schweinischere",
    "Schweinischsten": "Schweinischste",
    "Schweins": "Schwein",
    "Schweizerische": "schweizerisch",
    "Schweizerischen": "Schweizerische",
    "Schweizerischeren": "Schweizerischere",
    "Schweizerischsten": "Schweizerischste",
    "Schweizern": "Schweizer",
    "Schweizers": "Schweizer",
    "Schweiß": "schweißen",
    "Schweißblatte": "Schweißblatt",
    "Schweißblattes": "Schweißblatt",
    "Schweißblatts": "Schweißblatt",
    "Schweißblätter": "Schweißblatt",
    "Schweißblättern": "Schweißblatt",
    "Schweißenden": "Schweißende",
    "Schweißens": "Schweißen",
    "Schweißnähte": "Schweißnaht",
    "Schweißnähten": "Schweißnaht",
    "Schweißtreibenden": "Schweißtreibende",
    "Schweißtreibenderen": "Schweißtreibendere",
    "Schweißtriefenden": "Schweißtriefende",
    "Schweißtriefenderen": "Schweißtriefendere",
    "Schwelenden": "Schwelende",
    "Schwelens": "Schwelen",
    "Schwelgenden": "Schwelgende",
    "Schwelgens": "Schwelgen",
    "Schwellen": "Schwelle",
    "Schwellenden": "Schwellende",
    "Schwellenderen": "Schwellendere",
    "Schwellendsten": "Schwellendste",
    "Schwellens": "Schwellen",
    "Schwellkörpern": "Schwellkörper",
    "Schwellkörpers": "Schwellkörper",
    "Schwellungen": "Schwellung",
    "Schwellwerke": "Schwellwerk",
    "Schwellwerken": "Schwellwerk",
    "Schwellwerks": "Schwellwerk",
    "Schwemmen": "Schwemme",
    "Schwemmenden": "Schwemmende",
    "Schwemmenderen": "Schwemmendere",
    "Schwemmendsten": "Schwemmendste",
    "Schwemmens": "Schwemmen",
    "Schwemmlands": "Schwemmland",
    "Schwenk": "schwenken",
    "Schwenke": "schwenken",
    "Schwenken": "Schwenk",
    "Schwenkenden": "Schwenkende",
    "Schwenkens": "Schwenken",
    "Schwenkern": "Schwenker",
    "Schwenkers": "Schwenker",
    "Schwenkes": "Schwenk",
    "Schwenks": "Schwenk",
    "Schwenkungen": "Schwenkung",
    "Schwerbehinderte": "schwerbehindert",
    "Schwerbehinderten": "Schwerbehinderte",
    "Schwerbehinderteren": "Schwerbehindertere",
    "Schwerbenzine": "Schwerbenzin",
    "Schwerbenzinen": "Schwerbenzin",
    "Schwerbenzins": "Schwerbenzin",
    "Schwerbeschädigte": "schwerbeschädigt",
    "Schwerbeschädigten": "Schwerbeschädigte",
    "Schwerbewaffneten": "Schwerbewaffnete",
    "Schwereanomalien": "Schwereanomalie",
    "Schwerelose": "schwerelos",
    "Schwerelosen": "Schwerelose",
    "Schweren": "Schwere",
    "Schwereren": "Schwerere",
    "Schwererziehbaren": "Schwererziehbare",
    "Schwerfallenden": "Schwerfallende",
    "Schwerfallenderen": "Schwerfallendere",
    "Schwerfallendsten": "Schwerfallendste",
    "Schwerfallens": "Schwerfallen",
    "Schwerfälligen": "Schwerfällige",
    "Schwerfälligeren": "Schwerfälligere",
    "Schwerfälligsten": "Schwerfälligste",
    "Schwergefallenen": "Schwergefallene",
    "Schwergefalleneren": "Schwergefallenere",
    "Schwergewichte": "Schwergewicht",
    "Schwergewichten": "Schwergewicht",
    "Schwergewichtlern": "Schwergewichtler",
    "Schwergewichtlers": "Schwergewichtler",
    "Schwergewichts": "Schwergewicht",
    "Schwerhörige": "schwerhörig",
    "Schwerhörigen": "Schwerhörige",
    "Schwerindustrien": "Schwerindustrie",
    "Schwerinern": "Schweriner",
    "Schweriners": "Schweriner",
    "Schwerins": "Schwerin",
    "Schwerkranke": "schwerkrank",
    "Schwerkranken": "Schwerkranke",
    "Schwerkräfte": "Schwerkraft",
    "Schwerkräften": "Schwerkraft",
    "Schwermetalle": "Schwermetall",
    "Schwermetallen": "Schwermetall",
    "Schwermetalls": "Schwermetall",
    "Schwermütige": "schwermütig",
    "Schwermütigen": "Schwermütige",
    "Schwermütigeren": "Schwermütigere",
    "Schwermütigsten": "Schwermütigste",
    "Schwerpunkte": "Schwerpunkt",
    "Schwerpunkten": "Schwerpunkt",
    "Schwerpunktes": "Schwerpunkt",
    "Schwerpunkts": "Schwerpunkt",
    "Schwerreiche": "schwerreich",
    "Schwerreichen": "Schwerreiche",
    "Schwersten": "Schwerste",
    "Schwerte": "Schwert",
    "Schwerter": "Schwert",
    "Schwertern": "Schwert",
    "Schwertes": "Schwert",
    "Schwerverbrechern": "Schwerverbrecher",
    "Schwerverbrechers": "Schwerverbrecher",
    "Schwerverdauliche": "schwerverdaulich",
    "Schwerverdaulichen": "Schwerverdauliche",
    "Schwerverletzten": "Schwerverletzte",
    "Schwerverständlichen": "Schwerverständliche",
    "Schwerverwundeten": "Schwerverwundete",
    "Schwerwiegenden": "Schwerwiegende",
    "Schweröle": "Schweröl",
    "Schwerölen": "Schweröl",
    "Schweröls": "Schweröl",
    "Schwesterlichen": "Schwesterliche",
    "Schwestern": "Schwester",
    "Schwiegern": "Schwieger",
    "Schwiegers": "Schwieger",
    "Schwiegertöchter": "Schwiegertochter",
    "Schwiegertöchtern": "Schwiegertochter",
    "Schwielen": "Schwiele",
    "Schwierige": "schwierig",
    "Schwierigen": "Schwierige",
    "Schwierigeren": "Schwierigere",
    "Schwierigkeiten": "Schwierigkeit",
    "Schwierigste": "schwierig",
    "Schwierigsten": "Schwierigste",
    "Schwimmbade": "Schwimmbad",
    "Schwimmbades": "Schwimmbad",
    "Schwimmbads": "Schwimmbad",
    "Schwimmbeckens": "Schwimmbecken",
    "Schwimmbäder": "Schwimmbad",
    "Schwimmbädern": "Schwimmbad",
    "Schwimmenden": "Schwimmende",
    "Schwimmens": "Schwimmen",
    "Schwimmfähigen": "Schwimmfähige",
    "Schwimmfähigeren": "Schwimmfähigere",
    "Schwimmfähigsten": "Schwimmfähigste",
    "Schwimmhallen": "Schwimmhalle",
    "Schwimmunterrichte": "Schwimmunterricht",
    "Schwimmunterrichten": "Schwimmunterricht",
    "Schwimmunterrichtes": "Schwimmunterricht",
    "Schwimmunterrichts": "Schwimmunterricht",
    "Schwindel": "schwindeln",
    "Schwindeleien": "Schwindelei",
    "Schwindelerregende": "schwindelerregend",
    "Schwindelerregenden": "Schwindelerregende",
    "Schwindelerregenderen": "Schwindelerregendere",
    "Schwindelfreien": "Schwindelfreie",
    "Schwindeligen": "Schwindelige",
    "Schwindeligeren": "Schwindeligere",
    "Schwindeligsten": "Schwindeligste",
    "Schwindeln": "Schwindel",
    "Schwindelnden": "Schwindelnde",
    "Schwindelnderen": "Schwindelndere",
    "Schwindelndsten": "Schwindelndste",
    "Schwindelns": "Schwindeln",
    "Schwindels": "Schwindel",
    "Schwindenden": "Schwindende",
    "Schwindenderen": "Schwindendere",
    "Schwindendsten": "Schwindendste",
    "Schwindens": "Schwinden",
    "Schwindlern": "Schwindler",
    "Schwindlers": "Schwindler",
    "Schwindlige": "schwindlig",
    "Schwindligen": "Schwindlige",
    "Schwindligeren": "Schwindligere",
    "Schwindligsten": "Schwindligste",
    "Schwingenden": "Schwingende",
    "Schwingenderen": "Schwingendere",
    "Schwingendsten": "Schwingendste",
    "Schwingens": "Schwingen",
    "Schwingflügeln": "Schwingflügel",
    "Schwingflügels": "Schwingflügel",
    "Schwingkölbchens": "Schwingkölbchen",
    "Schwingmessern": "Schwingmesser",
    "Schwingmessers": "Schwingmesser",
    "Schwingungen": "Schwingung",
    "Schwippschwagern": "Schwippschwager",
    "Schwippschwagers": "Schwippschwager",
    "Schwippschwägerinnen": "Schwippschwägerin",
    "Schwirrenden": "Schwirrende",
    "Schwirrenderen": "Schwirrendere",
    "Schwirrendsten": "Schwirrendste",
    "Schwirrens": "Schwirren",
    "Schwitzbläschens": "Schwitzbläschen",
    "Schwitze": "schwitzen",
    "Schwitzen": "Schwitze",
    "Schwitzenden": "Schwitzende",
    "Schwitzenderen": "Schwitzendere",
    "Schwitzendsten": "Schwitzendste",
    "Schwitzens": "Schwitzen",
    "Schwitzigen": "Schwitzige",
    "Schwitzigeren": "Schwitzigere",
    "Schwitzigsten": "Schwitzigste",
    "Schwitzkastens": "Schwitzkasten",
    "Schwitzkuren": "Schwitzkur",
    "Schwitzkästen": "Schwitzkasten",
    "Schwulen": "Schwule",
    "Schwuleren": "Schwulere",
    "Schwulitäten": "Schwulität",
    "Schwulste": "schwul",
    "Schwulsten": "Schwulste",
    "Schwunge": "Schwung",
    "Schwunges": "Schwung",
    "Schwunghafte": "schwunghaft",
    "Schwunghaften": "Schwunghafte",
    "Schwunghafteren": "Schwunghaftere",
    "Schwunghaftesten": "Schwunghafteste",
    "Schwunglosen": "Schwunglose",
    "Schwungloseren": "Schwunglosere",
    "Schwunglosesten": "Schwungloseste",
    "Schwungs": "Schwung",
    "Schwungvolle": "schwungvoll",
    "Schwungvollen": "Schwungvolle",
    "Schwungvolleren": "Schwungvollere",
    "Schwungvollsten": "Schwungvollste",
    "Schwure": "Schwur",
    "Schwurs": "Schwur",
    "Schwäbelnden": "Schwäbelnde",
    "Schwäbelnderen": "Schwäbelndere",
    "Schwäbelndsten": "Schwäbelndste",
    "Schwäbelns": "Schwäbeln",
    "Schwäbische": "schwäbisch",
    "Schwäbischen": "Schwäbische",
    "Schwäche": "schwächen",
    "Schwächen": "Schwäche",
    "Schwächenden": "Schwächende",
    "Schwächenderen": "Schwächendere",
    "Schwächendsten": "Schwächendste",
    "Schwächens": "Schwächen",
    "Schwächeren": "Schwächere",
    "Schwächliche": "schwächlich",
    "Schwächlichen": "Schwächliche",
    "Schwächlicheren": "Schwächlichere",
    "Schwächlichsten": "Schwächlichste",
    "Schwächsten": "Schwächste",
    "Schwälmern": "Schwälmer",
    "Schwälmers": "Schwälmer",
    "Schwämmchens": "Schwämmchen",
    "Schwämme": "schwimmen",
    "Schwämmen": "schwimmen",
    "Schwänchens": "Schwänchen",
    "Schwäne": "Schwan",
    "Schwänen": "Schwan",
    "Schwängernden": "Schwängernde",
    "Schwängerns": "Schwängern",
    "Schwänkchens": "Schwänkchen",
    "Schwänze": "schwänzen",
    "Schwänzen": "Schwanz",
    "Schwänzenden": "Schwänzende",
    "Schwänzenderen": "Schwänzendere",
    "Schwänzendsten": "Schwänzendste",
    "Schwänzens": "Schwänzen",
    "Schwänzleins": "Schwänzlein",
    "Schwärenden": "Schwärende",
    "Schwärens": "Schwären",
    "Schwärmenden": "Schwärmende",
    "Schwärmens": "Schwärmen",
    "Schwärmereien": "Schwärmerei",
    "Schwärmerische": "schwärmerisch",
    "Schwärmerischen": "Schwärmerische",
    "Schwärmerischeren": "Schwärmerischere",
    "Schwärmerischsten": "Schwärmerischste",
    "Schwärmern": "Schwärmer",
    "Schwärmers": "Schwärmer",
    "Schwärze": "schwärzen",
    "Schwärzen": "Schwärze",
    "Schwärzenden": "Schwärzende",
    "Schwärzenderen": "Schwärzendere",
    "Schwärzendsten": "Schwärzendste",
    "Schwärzens": "Schwärzen",
    "Schwärzeren": "Schwärzere",
    "Schwärzesten": "Schwärzeste",
    "Schwätzchens": "Schwätzchen",
    "Schwätzern": "Schwätzer",
    "Schwätzers": "Schwätzer",
    "Schwörenden": "Schwörende",
    "Schwörens": "Schwören",
    "Schwüle": "schwül",
    "Schwülen": "Schwüle",
    "Schwülere": "schwül",
    "Schwüleren": "Schwülere",
    "Schwülsten": "Schwülste",
    "Schwülstigen": "Schwülstige",
    "Schwülstigeren": "Schwülstigere",
    "Schwülstigsten": "Schwülstigste",
    "Schwünge": "Schwung",
    "Schwüngen": "Schwung",
    "Schwüre": "Schwur",
    "Schwüren": "Schwur",
    "Schäbige": "schäbig",
    "Schäbigen": "Schäbige",
    "Schäbigeren": "Schäbigere",
    "Schäbigsten": "Schäbigste",
    "Schächte": "Schacht",
    "Schächtelchens": "Schächtelchen",
    "Schächten": "Schacht",
    "Schächtleins": "Schächtlein",
    "Schächtungen": "Schächtung",
    "Schädeln": "Schädel",
    "Schädels": "Schädel",
    "Schäden": "Schaden",
    "Schädigenden": "Schädigende",
    "Schädigens": "Schädigen",
    "Schädigungen": "Schädigung",
    "Schädliche": "schädlich",
    "Schädlichen": "Schädliche",
    "Schädlicheren": "Schädlichere",
    "Schädlichsten": "Schädlichste",
    "Schädlinge": "Schädling",
    "Schädlingen": "Schädling",
    "Schädlings": "Schädling",
    "Schäfern": "Schäfer",
    "Schäfers": "Schäfer",
    "Schälende": "schälend",
    "Schälenden": "Schälende",
    "Schälens": "Schälen",
    "Schälmaschinen": "Schälmaschine",
    "Schämenden": "Schämende",
    "Schämenderen": "Schämendere",
    "Schämendsten": "Schämendste",
    "Schämens": "Schämen",
    "Schändenden": "Schändende",
    "Schändenderen": "Schändendere",
    "Schändendsten": "Schändendste",
    "Schändens": "Schänden",
    "Schändern": "Schänder",
    "Schänders": "Schänder",
    "Schändliche": "schändlich",
    "Schändlichen": "Schändliche",
    "Schändlicheren": "Schändlichere",
    "Schändlichkeiten": "Schändlichkeit",
    "Schändlichste": "schändlich",
    "Schändlichsten": "Schändlichste",
    "Schänken": "Schänke",
    "Schärfe": "schärfen",
    "Schärfen": "Schärfe",
    "Schärfenden": "Schärfende",
    "Schärfenderen": "Schärfendere",
    "Schärfendsten": "Schärfendste",
    "Schärfens": "Schärfen",
    "Schärferen": "Schärfere",
    "Schärfsten": "Schärfste",
    "Schärpen": "Schärpe",
    "Schätzbare": "schätzbar",
    "Schätzbaren": "Schätzbare",
    "Schätzbareren": "Schätzbarere",
    "Schätzbarsten": "Schätzbarste",
    "Schätzchens": "Schätzchen",
    "Schätze": "schätzen",
    "Schätzen": "Schatz",
    "Schätzenden": "Schätzende",
    "Schätzens": "Schätzen",
    "Schätzenswerte": "schätzenswert",
    "Schätzenswerten": "Schätzenswerte",
    "Schätzenswerteren": "Schätzenswertere",
    "Schätzleins": "Schätzlein",
    "Schätzungen": "Schätzung",
    "Schätzwerte": "Schätzwert",
    "Schätzwerten": "Schätzwert",
    "Schätzwerts": "Schätzwert",
    "Schäubles": "Schäuble",
    "Schäume": "schäumen",
    "Schäumen": "Schaum",
    "Schäumenden": "Schäumende",
    "Schäumenderen": "Schäumendere",
    "Schäumendsten": "Schäumendste",
    "Schäumens": "Schäumen",
    "Schöffen": "Schöffe",
    "Schönbergs": "Schönberg",
    "Schöne": "schön",
    "Schönebergs": "Schöneberg",
    "Schönefelds": "Schönefeld",
    "Schönen": "Schöne",
    "Schöneren": "Schönere",
    "Schönfärbenden": "Schönfärbende",
    "Schönfärbenderen": "Schönfärbendere",
    "Schönfärbendsten": "Schönfärbendste",
    "Schönfärbens": "Schönfärben",
    "Schönfärbern": "Schönfärber",
    "Schönfärbers": "Schönfärber",
    "Schöngefärbten": "Schöngefärbte",
    "Schöngefärbteren": "Schöngefärbtere",
    "Schöngefärbtesten": "Schöngefärbteste",
    "Schöngeiste": "Schöngeist",
    "Schöngeister": "Schöngeist",
    "Schöngeistern": "Schöngeist",
    "Schöngeistes": "Schöngeist",
    "Schöngeistige": "schöngeistig",
    "Schöngeistigen": "Schöngeistige",
    "Schöngeistigeren": "Schöngeistigere",
    "Schöngeistigsten": "Schöngeistigste",
    "Schöngeists": "Schöngeist",
    "Schönheiten": "Schönheit",
    "Schönhubers": "Schönhuber",
    "Schönlinge": "Schönling",
    "Schönlingen": "Schönling",
    "Schönlings": "Schönling",
    "Schönrednerische": "schönrednerisch",
    "Schönrednerischen": "Schönrednerische",
    "Schönrednern": "Schönredner",
    "Schönredners": "Schönredner",
    "Schönste": "schön",
    "Schönsten": "Schönste",
    "Schönwetterwolken": "Schönwetterwolke",
    "Schöpfe": "schöpfen",
    "Schöpfeimern": "Schöpfeimer",
    "Schöpfeimers": "Schöpfeimer",
    "Schöpfen": "Schopf",
    "Schöpfenden": "Schöpfende",
    "Schöpfenderen": "Schöpfendere",
    "Schöpfendsten": "Schöpfendste",
    "Schöpfens": "Schöpfen",
    "Schöpferische": "schöpferisch",
    "Schöpferischen": "Schöpferische",
    "Schöpferischeren": "Schöpferischere",
    "Schöpferischsten": "Schöpferischste",
    "Schöpfern": "Schöpfer",
    "Schöpfers": "Schöpfer",
    "Schöpfungen": "Schöpfung",
    "Schübe": "Schub",
    "Schüben": "Schub",
    "Schüchterne": "schüchtern",
    "Schüchternen": "Schüchterne",
    "Schüchterneren": "Schüchternere",
    "Schüchternsten": "Schüchternste",
    "Schühleins": "Schühlein",
    "Schülerhafte": "schülerhaft",
    "Schülerhaften": "Schülerhafte",
    "Schülerhafteren": "Schülerhaftere",
    "Schülerhaftesten": "Schülerhafteste",
    "Schülerinnen": "Schülerin",
    "Schülermitverwaltungen": "Schülermitverwaltung",
    "Schülern": "Schüler",
    "Schülers": "Schüler",
    "Schüppchens": "Schüppchen",
    "Schürenden": "Schürende",
    "Schürens": "Schüren",
    "Schürfeisens": "Schürfeisen",
    "Schürfenden": "Schürfende",
    "Schürfens": "Schürfen",
    "Schürfgruben": "Schürfgrube",
    "Schürzen": "Schürze",
    "Schüsse": "Schuß",
    "Schüsseln": "Schüssel",
    "Schüssen": "Schuß",
    "Schütte": "schütten",
    "Schüttelnden": "Schüttelnde",
    "Schüttelnderen": "Schüttelndere",
    "Schüttelndsten": "Schüttelndste",
    "Schüttelns": "Schütteln",
    "Schütten": "Schütte",
    "Schüttenden": "Schüttende",
    "Schüttens": "Schütten",
    "Schüttere": "schüttern",
    "Schütteren": "Schüttere",
    "Schüttereren": "Schütterere",
    "Schütternden": "Schütternde",
    "Schütterns": "Schüttern",
    "Schüttersten": "Schütterste",
    "Schütz": "schützen",
    "Schütze": "schützen",
    "Schützen": "Schütze",
    "Schützenden": "Schützende",
    "Schützenderen": "Schützendere",
    "Schützendsten": "Schützendste",
    "Schützens": "Schützen",
    "Schützern": "Schützer",
    "Schützers": "Schützer",
    "Schützlinge": "Schützling",
    "Schützlingen": "Schützling",
    "Schützlinges": "Schützling",
    "Schützlings": "Schützling",
    "Seancen": "Seance",
    "Sebastians": "Sebastian",
    "Sechsmonatige": "sechsmonatig",
    "Sechsmonatigen": "Sechsmonatige",
    "Sechzehnteln": "Sechzehntel",
    "Sechzehntelnoten": "Sechzehntelnote",
    "Sechzehntels": "Sechzehntel",
    "Seckbachern": "Seckbacher",
    "Seckbachers": "Seckbacher",
    "Seckbachs": "Seckbach",
    "Sedimente": "Sediment",
    "Sedimenten": "Sediment",
    "Sediments": "Sediment",
    "Seefahrenden": "Seefahrende",
    "Seefähige": "seefähig",
    "Seefähigen": "Seefähige",
    "Seefähigeren": "Seefähigere",
    "Seefähigsten": "Seefähigste",
    "Seegangs": "Seegang",
    "Seegurken": "Seegurke",
    "Seehofers": "Seehofer",
    "Seekranke": "seekrank",
    "Seekranken": "Seekranke",
    "Seelen": "Seele",
    "Seelenlose": "seelenlos",
    "Seelenlosen": "Seelenlose",
    "Seelenloseren": "Seelenlosere",
    "Seelenlosesten": "Seelenloseste",
    "Seelenverwandten": "Seelenverwandte",
    "Seelischen": "Seelische",
    "Seelsorgen": "Seelsorge",
    "Seelsorgerische": "seelsorgerisch",
    "Seelsorgerischen": "Seelsorgerische",
    "Seelsorgern": "Seelsorger",
    "Seelsorgers": "Seelsorger",
    "Seemännische": "seemännisch",
    "Seemännischen": "Seemännische",
    "Seen": "See",
    "Seetangs": "Seetang",
    "Seetüchtige": "seetüchtig",
    "Seetüchtigen": "Seetüchtige",
    "Seeuntüchtigen": "Seeuntüchtige",
    "Segel": "segeln",
    "Segelfertigen": "Segelfertige",
    "Segelflugzeuge": "Segelflugzeug",
    "Segelflugzeugen": "Segelflugzeug",
    "Segelflugzeugs": "Segelflugzeug",
    "Segeln": "Segel",
    "Segelnden": "Segelnde",
    "Segelns": "Segeln",
    "Segels": "Segel",
    "Segeltuche": "Segeltuch",
    "Segeltuchen": "Segeltuch",
    "Segeltuchs": "Segeltuch",
    "Segenbringende": "segenbringend",
    "Segenbringenden": "Segenbringende",
    "Segens": "Segen",
    "Segensreiche": "segensreich",
    "Segensreichen": "Segensreiche",
    "Segensreicheren": "Segensreichere",
    "Segensreichsten": "Segensreichste",
    "Seglern": "Segler",
    "Seglers": "Segler",
    "Segmente": "Segment",
    "Segmenten": "Segment",
    "Segmentes": "Segment",
    "Segmentierenden": "Segmentierende",
    "Segmentierens": "Segmentieren",
    "Segmentierte": "segmentiert",
    "Segmentierten": "Segmentierte",
    "Segments": "Segment",
    "Segnenden": "Segnende",
    "Segnens": "Segnen",
    "Sehenden": "Sehende",
    "Sehens": "Sehen",
    "Sehenswerte": "sehenswert",
    "Sehenswerten": "Sehenswerte",
    "Sehenswerteren": "Sehenswertere",
    "Sehenswertesten": "Sehenswerteste",
    "Sehenswürdigen": "Sehenswürdige",
    "Sehenswürdigeren": "Sehenswürdigere",
    "Sehenswürdigsten": "Sehenswürdigste",
    "Sehfehlern": "Sehfehler",
    "Sehfehlers": "Sehfehler",
    "Sehne": "sehnen",
    "Sehnen": "Sehne",
    "Sehnenden": "Sehnende",
    "Sehnenderen": "Sehnendere",
    "Sehnendsten": "Sehnendste",
    "Sehnens": "Sehnen",
    "Sehnigen": "Sehnige",
    "Sehnigeren": "Sehnigere",
    "Sehnigsten": "Sehnigste",
    "Sehnlichen": "Sehnliche",
    "Sehnlicheren": "Sehnlichere",
    "Sehnlichsten": "Sehnlichste",
    "Sehnsuchtsvollen": "Sehnsuchtsvolle",
    "Sehnsuchtsvolleren": "Sehnsuchtsvollere",
    "Sehnsüchte": "Sehnsucht",
    "Sehnsüchten": "Sehnsucht",
    "Sehnsüchtige": "sehnsüchtig",
    "Sehnsüchtigen": "Sehnsüchtige",
    "Sehnsüchtigeren": "Sehnsüchtigere",
    "Sehnsüchtigsten": "Sehnsüchtigste",
    "Sehrohre": "Sehrohr",
    "Sehrohren": "Sehrohr",
    "Sehrohrs": "Sehrohr",
    "Sehweisen": "Sehweise",
    "Sehwerkzeuge": "Sehwerkzeug",
    "Sehwerkzeugen": "Sehwerkzeug",
    "Sehwerkzeugs": "Sehwerkzeug",
    "Sehwinkeln": "Sehwinkel",
    "Sehwinkels": "Sehwinkel",
    "Seichten": "Seichte",
    "Seichteren": "Seichtere",
    "Seichtesten": "Seichteste",
    "Seidels": "Seidel",
    "Seiden": "Seide",
    "Seidene": "seiden",
    "Seidenen": "Seidene",
    "Seidenmatten": "Seidenmatte",
    "Seifen": "Seife",
    "Seifenden": "Seifende",
    "Seifenopern": "Seifenoper",
    "Seifens": "Seifen",
    "Seifensiedereien": "Seifensiederei",
    "Seiferts": "Seifert",
    "Seifigen": "Seifige",
    "Seifigeren": "Seifigere",
    "Seifigsten": "Seifigste",
    "Seil": "seilen",
    "Seile": "seilen",
    "Seilen": "Seil",
    "Seilenden": "Seilende",
    "Seilens": "Seilen",
    "Seiles": "Seil",
    "Seils": "Seil",
    "Seins": "Sein",
    "Seismische": "seismisch",
    "Seismischen": "Seismische",
    "Seismogramme": "Seismogramm",
    "Seismogrammen": "Seismogramm",
    "Seismogramms": "Seismogramm",
    "Seismographen": "Seismograph",
    "Seismologische": "seismologisch",
    "Seismologischen": "Seismologische",
    "Seismometern": "Seismometer",
    "Seismometers": "Seismometer",
    "Seiten": "Seite",
    "Seitenbühnen": "Seitenbühne",
    "Seitenlange": "seitenlang",
    "Seitenlangen": "Seitenlange",
    "Seitenscheiteln": "Seitenscheitel",
    "Seitenscheitels": "Seitenscheitel",
    "Seitenschneidern": "Seitenschneider",
    "Seitenschneiders": "Seitenschneider",
    "Seitenschwimmern": "Seitenschwimmer",
    "Seitenschwimmers": "Seitenschwimmer",
    "Seitenstechens": "Seitenstechen",
    "Seitenverkehrte": "seitenverkehrt",
    "Seitenverkehrten": "Seitenverkehrte",
    "Seitlichen": "Seitliche",
    "Sekrete": "Sekret",
    "Sekreten": "Sekret",
    "Sekretierenden": "Sekretierende",
    "Sekretierens": "Sekretieren",
    "Sekretierte": "sekretiert",
    "Sekretierten": "Sekretierte",
    "Sekrets": "Sekret",
    "Sekretäre": "Sekretär",
    "Sekretären": "Sekretär",
    "Sekretärinnen": "Sekretärin",
    "Sekretärs": "Sekretär",
    "Sekte": "Sekt",
    "Sekten": "Sekt",
    "Sektes": "Sekt",
    "Sektionen": "Sektion",
    "Sektore": "Sektor",
    "Sektoren": "Sektor",
    "Sektores": "Sektor",
    "Sektors": "Sektor",
    "Sekts": "Sekt",
    "Sekundanten": "Sekundant",
    "Sekundarlehrern": "Sekundarlehrer",
    "Sekundarlehrers": "Sekundarlehrer",
    "Sekundarschulen": "Sekundarschule",
    "Sekundarstufen": "Sekundarstufe",
    "Sekunden": "Sekunde",
    "Sekundenlange": "sekundenlang",
    "Sekundenlangen": "Sekundenlange",
    "Sekundäre": "sekundär",
    "Sekundären": "Sekundäre",
    "Sekundärinfektionen": "Sekundärinfektion",
    "Sekundärrohstoffe": "Sekundärrohstoff",
    "Sekundärrohstoffen": "Sekundärrohstoff",
    "Sekundärrohstoffs": "Sekundärrohstoff",
    "Sekundärstrome": "Sekundärstrom",
    "Sekundärstroms": "Sekundärstrom",
    "Sekundärströme": "Sekundärstrom",
    "Sekundärströmen": "Sekundärstrom",
    "Sekundärtugenden": "Sekundärtugend",
    "Selbstanalysen": "Selbstanalyse",
    "Selbstanklagen": "Selbstanklage",
    "Selbstanzeigen": "Selbstanzeige",
    "Selbstaufnahmen": "Selbstaufnahme",
    "Selbstauslösern": "Selbstauslöser",
    "Selbstauslösers": "Selbstauslöser",
    "Selbstbedienungen": "Selbstbedienung",
    "Selbstbeeinflussungen": "Selbstbeeinflussung",
    "Selbstbefriedigungen": "Selbstbefriedigung",
    "Selbstbefruchtungen": "Selbstbefruchtung",
    "Selbstbehauptungen": "Selbstbehauptung",
    "Selbstbestimmungen": "Selbstbestimmung",
    "Selbstbestätigungen": "Selbstbestätigung",
    "Selbstbestäubungen": "Selbstbestäubung",
    "Selbstbewußte": "selbstbewußt",
    "Selbstbewußten": "Selbstbewußte",
    "Selbstbewußteren": "Selbstbewußtere",
    "Selbstbewußtesten": "Selbstbewußteste",
    "Selbstbewußtseins": "Selbstbewußtsein",
    "Selbstbiografien": "Selbstbiografie",
    "Selbstbiographien": "Selbstbiographie",
    "Selbstdarstellungen": "Selbstdarstellung",
    "Selbstdisziplinen": "Selbstdisziplin",
    "Selbstentladern": "Selbstentlader",
    "Selbstentladers": "Selbstentlader",
    "Selbstfahrern": "Selbstfahrer",
    "Selbstfahrers": "Selbstfahrer",
    "Selbstgefällige": "selbstgefällig",
    "Selbstgefälligen": "Selbstgefällige",
    "Selbstgefälligeren": "Selbstgefälligere",
    "Selbstgefälligkeiten": "Selbstgefälligkeit",
    "Selbstgefälligste": "selbstgefällig",
    "Selbstgemachten": "Selbstgemachte",
    "Selbstgerechten": "Selbstgerechte",
    "Selbstgerechteren": "Selbstgerechtere",
    "Selbstgeschriebenen": "Selbstgeschriebene",
    "Selbstgespräche": "Selbstgespräch",
    "Selbstgesprächen": "Selbstgespräch",
    "Selbstgesprächs": "Selbstgespräch",
    "Selbsthasse": "Selbsthaß",
    "Selbsthasses": "Selbsthaß",
    "Selbstherrliche": "selbstherrlich",
    "Selbstherrlichen": "Selbstherrliche",
    "Selbstherrlicheren": "Selbstherrlichere",
    "Selbsthilfen": "Selbsthilfe",
    "Selbstklebende": "selbstklebend",
    "Selbstklebenden": "Selbstklebende",
    "Selbstkontrollen": "Selbstkontrolle",
    "Selbstkritische": "selbstkritisch",
    "Selbstkritischen": "Selbstkritische",
    "Selbstkritischeren": "Selbstkritischere",
    "Selbstladern": "Selbstlader",
    "Selbstladers": "Selbstlader",
    "Selbstlobe": "Selbstlob",
    "Selbstloben": "Selbstlob",
    "Selbstlobs": "Selbstlob",
    "Selbstlose": "selbstlos",
    "Selbstlosen": "Selbstlose",
    "Selbstloseren": "Selbstlosere",
    "Selbstlosesten": "Selbstloseste",
    "Selbstmorde": "Selbstmord",
    "Selbstmorden": "Selbstmord",
    "Selbstmordes": "Selbstmord",
    "Selbstmords": "Selbstmord",
    "Selbstmördern": "Selbstmörder",
    "Selbstmörders": "Selbstmörder",
    "Selbstquälereien": "Selbstquälerei",
    "Selbstschutze": "Selbstschutz",
    "Selbstschutzes": "Selbstschutz",
    "Selbstschutzs": "Selbstschutz",
    "Selbstsichere": "selbstsicher",
    "Selbstsicheren": "Selbstsichere",
    "Selbstsichereren": "Selbstsicherere",
    "Selbstsichersten": "Selbstsicherste",
    "Selbststeuerungen": "Selbststeuerung",
    "Selbststudiums": "Selbststudium",
    "Selbstthematisierungen": "Selbstthematisierung",
    "Selbsttätige": "selbsttätig",
    "Selbsttätigen": "Selbsttätige",
    "Selbsttäuschungen": "Selbsttäuschung",
    "Selbsttötungen": "Selbsttötung",
    "Selbstunterrichts": "Selbstunterricht",
    "Selbstverlage": "Selbstverlag",
    "Selbstverlagen": "Selbstverlag",
    "Selbstverlages": "Selbstverlag",
    "Selbstverlags": "Selbstverlag",
    "Selbstverleugnungen": "Selbstverleugnung",
    "Selbstversorgern": "Selbstversorger",
    "Selbstversorgers": "Selbstversorger",
    "Selbstverständliche": "selbstverständlich",
    "Selbstverständlichen": "Selbstverständliche",
    "Selbstverständlicheren": "Selbstverständlichere",
    "Selbstverständnisse": "Selbstverständnis",
    "Selbstverständnisses": "Selbstverständnis",
    "Selbstverstümmelungen": "Selbstverstümmelung",
    "Selbstversuche": "Selbstversuch",
    "Selbstversuchen": "Selbstversuch",
    "Selbstversuchs": "Selbstversuch",
    "Selbstvertrauens": "Selbstvertrauen",
    "Selbstverwaltungen": "Selbstverwaltung",
    "Selbstwerte": "Selbstwert",
    "Selbstwerten": "Selbstwert",
    "Selbstwertes": "Selbstwert",
    "Selbstwerts": "Selbstwert",
    "Selbstzufriedene": "selbstzufrieden",
    "Selbstzufriedenen": "Selbstzufriedene",
    "Selbstzufriedeneren": "Selbstzufriedenere",
    "Selbständige": "selbständig",
    "Selbständigen": "Selbständige",
    "Selbständigeren": "Selbständigere",
    "Selbständigsten": "Selbständigste",
    "Selektierenden": "Selektierende",
    "Selektierens": "Selektieren",
    "Selektierte": "selektiert",
    "Selektierten": "Selektierte",
    "Selektionen": "Selektion",
    "Selektive": "selektiv",
    "Selektiven": "Selektive",
    "Selektiveren": "Selektivere",
    "Selektivsten": "Selektivste",
    "Seligenstadts": "Seligenstadt",
    "Seligenstädtern": "Seligenstädter",
    "Seligenstädters": "Seligenstädter",
    "Seliggepriesenen": "Seliggepriesene",
    "Seliggesprochenen": "Seliggesprochene",
    "Seligkeiten": "Seligkeit",
    "Seligpreisenden": "Seligpreisende",
    "Seligpreisens": "Seligpreisen",
    "Seligpreisungen": "Seligpreisung",
    "Seligsprechenden": "Seligsprechende",
    "Seligsprechens": "Seligsprechen",
    "Seligsprechungen": "Seligsprechung",
    "Sellafields": "Sellafield",
    "Seltene": "selten",
    "Seltenen": "Seltene",
    "Selteneren": "Seltenere",
    "Seltenheiten": "Seltenheit",
    "Seltenheitswerts": "Seltenheitswert",
    "Seltenste": "selten",
    "Seltensten": "Seltenste",
    "Seltsamen": "Seltsame",
    "Seltsameren": "Seltsamere",
    "Seltsamsten": "Seltsamste",
    "Semantischen": "Semantische",
    "Semaphorischen": "Semaphorische",
    "Semestern": "Semester",
    "Semesters": "Semester",
    "Semifinalen": "Semifinale",
    "Semifinales": "Semifinale",
    "Seminare": "Seminar",
    "Seminaren": "Seminar",
    "Seminars": "Seminar",
    "Semitische": "semitisch",
    "Semitischen": "Semitische",
    "Semmeln": "Semmel",
    "Senatore": "Senator",
    "Senatoren": "Senator",
    "Senatorinnen": "Senatorin",
    "Senatorische": "senatorisch",
    "Senatorischen": "Senatorische",
    "Senators": "Senator",
    "Senats": "Senat",
    "Sendeanlagen": "Sendeanlage",
    "Sendebereiche": "Sendebereich",
    "Sendebereichen": "Sendebereich",
    "Sendebereichs": "Sendebereich",
    "Sendefolgen": "Sendefolge",
    "Sendegebiete": "Sendegebiet",
    "Sendegebieten": "Sendegebiet",
    "Sendegebietes": "Sendegebiet",
    "Sendegebiets": "Sendegebiet",
    "Sendeleitern": "Sendeleiter",
    "Sendeleiters": "Sendeleiter",
    "Sendenden": "Sendende",
    "Sendens": "Senden",
    "Senderaume": "Senderaum",
    "Senderaums": "Senderaum",
    "Sendereihen": "Sendereihe",
    "Sendern": "Sender",
    "Senders": "Sender",
    "Senderäume": "Senderaum",
    "Senderäumen": "Senderaum",
    "Sendezeichens": "Sendezeichen",
    "Sendschreibens": "Sendschreiben",
    "Sendungen": "Sendung",
    "Senegalesische": "senegalesisch",
    "Senegalesischen": "Senegalesische",
    "Senfe": "Senf",
    "Senfen": "Senf",
    "Senfkorne": "Senfkorn",
    "Senfkornes": "Senfkorn",
    "Senfkorns": "Senfkorn",
    "Senfkörner": "Senfkorn",
    "Senfkörnern": "Senfkorn",
    "Senfs": "Senf",
    "Sengenden": "Sengende",
    "Sengenderen": "Sengendere",
    "Sengendsten": "Sengendste",
    "Sengens": "Sengen",
    "Senilen": "Senile",
    "Senileren": "Senilere",
    "Senilsten": "Senilste",
    "Seniore": "Senior",
    "Senioren": "Senior",
    "Seniorinnen": "Seniorin",
    "Seniors": "Senior",
    "Senkeln": "Senkel",
    "Senkels": "Senkel",
    "Senkenden": "Senkende",
    "Senkens": "Senken",
    "Senkkastens": "Senkkasten",
    "Senkkästen": "Senkkasten",
    "Senkrechte": "senkrecht",
    "Senkrechten": "Senkrechte",
    "Senkrechtstartern": "Senkrechtstarter",
    "Senkrechtstarters": "Senkrechtstarter",
    "Senkungen": "Senkung",
    "Sensationelle": "sensationell",
    "Sensationellen": "Sensationelle",
    "Sensationelleren": "Sensationellere",
    "Sensationellsten": "Sensationellste",
    "Sensationen": "Sensation",
    "Sensationshungrige": "sensationshungrig",
    "Sensationshungrigen": "Sensationshungrige",
    "Sensationshungrigeren": "Sensationshungrigere",
    "Sensationslüsternen": "Sensationslüsterne",
    "Sensationslüsterneren": "Sensationslüsternere",
    "Sensen": "Sense",
    "Sensibelste": "sensibel",
    "Sensibelsten": "Sensibelste",
    "Sensibilisatore": "Sensibilisator",
    "Sensibilisatoren": "Sensibilisator",
    "Sensibilisators": "Sensibilisator",
    "Sensibilisierenden": "Sensibilisierende",
    "Sensibilisierenderen": "Sensibilisierendere",
    "Sensibilisierens": "Sensibilisieren",
    "Sensibilisierte": "sensibilisiert",
    "Sensibilisierten": "Sensibilisierte",
    "Sensibilisierteren": "Sensibilisiertere",
    "Sensiblen": "Sensible",
    "Sensibleren": "Sensiblere",
    "Sensitiven": "Sensitive",
    "Sensore": "Sensor",
    "Sensoren": "Sensor",
    "Sensors": "Sensor",
    "Sentimentale": "sentimental",
    "Sentimentalen": "Sentimentale",
    "Sentimentaleren": "Sentimentalere",
    "Sentimentalischen": "Sentimentalische",
    "Sentimentalischeren": "Sentimentalischere",
    "Sentimentalitäten": "Sentimentalität",
    "Sentimentalste": "sentimental",
    "Sentimentalsten": "Sentimentalste",
    "Seouls": "Seoul",
    "Separatabdrucke": "Separatabdruck",
    "Separatabdrucken": "Separatabdruck",
    "Separatabdrucks": "Separatabdruck",
    "Separatdrucke": "Separatdruck",
    "Separatdrucken": "Separatdruck",
    "Separatdrucks": "Separatdruck",
    "Separate": "separat",
    "Separaten": "Separate",
    "Separateren": "Separatere",
    "Separatesten": "Separateste",
    "Separationen": "Separation",
    "Separatisten": "Separatist",
    "Separatistische": "separatistisch",
    "Separatistischen": "Separatistische",
    "Separatore": "Separator",
    "Separatoren": "Separator",
    "Separators": "Separator",
    "Separierenden": "Separierende",
    "Separierens": "Separieren",
    "Separierte": "separiert",
    "Separierten": "Separierte",
    "Septembers": "September",
    "Septische": "septisch",
    "Septischen": "Septische",
    "Septolen": "Septole",
    "Sequentielle": "sequentiell",
    "Sequentiellen": "Sequentielle",
    "Sequenzen": "Sequenz",
    "Serben": "Serbe",
    "Serbiens": "Serbien",
    "Serbische": "serbisch",
    "Serbischen": "Serbische",
    "Serenaden": "Serenade",
    "Serielle": "seriell",
    "Seriellen": "Serielle",
    "Serien": "Serie",
    "Serienmäßige": "serienmäßig",
    "Serienmäßigen": "Serienmäßige",
    "Serifen": "Serife",
    "Seriöse": "seriös",
    "Seriösen": "Seriöse",
    "Seriöseren": "Seriösere",
    "Seriösesten": "Seriöseste",
    "Serpentinen": "Serpentine",
    "Services": "Service",
    "Servierenden": "Servierende",
    "Servierens": "Servieren",
    "Servierte": "serviert",
    "Servierten": "Servierte",
    "Servolenkungen": "Servolenkung",
    "Sesams": "Sesam",
    "Sesseln": "Sessel",
    "Sessels": "Sessel",
    "Sessionen": "Session",
    "Sets": "Set",
    "Settings": "Setting",
    "Setzenden": "Setzende",
    "Setzens": "Setzen",
    "Setzereien": "Setzerei",
    "Setzern": "Setzer",
    "Setzers": "Setzer",
    "Setzfehlern": "Setzfehler",
    "Setzfehlers": "Setzfehler",
    "Setzgeschwindigkeiten": "Setzgeschwindigkeit",
    "Setzlatten": "Setzlatte",
    "Setzlinge": "Setzling",
    "Setzlingen": "Setzling",
    "Setzlings": "Setzling",
    "Setzmaschinen": "Setzmaschine",
    "Seuchen": "Seuche",
    "Seufzenden": "Seufzende",
    "Seufzenderen": "Seufzendere",
    "Seufzendsten": "Seufzendste",
    "Seufzens": "Seufzen",
    "Seulbergern": "Seulberger",
    "Seulbergers": "Seulberger",
    "Seulbergs": "Seulberg",
    "Sexistische": "sexistisch",
    "Sexistischen": "Sexistische",
    "Sexistischeren": "Sexistischere",
    "Sexistischsten": "Sexistischste",
    "Sexten": "Sexte",
    "Sextette": "Sextett",
    "Sextetten": "Sextett",
    "Sextetts": "Sextett",
    "Sexualentwicklungen": "Sexualentwicklung",
    "Sexualerziehungen": "Sexualerziehung",
    "Sexualforschungen": "Sexualforschung",
    "Sexualhormone": "Sexualhormon",
    "Sexualhormonen": "Sexualhormon",
    "Sexualhormons": "Sexualhormon",
    "Sexualneurosen": "Sexualneurose",
    "Sexualobjekte": "Sexualobjekt",
    "Sexualobjekten": "Sexualobjekt",
    "Sexualobjekts": "Sexualobjekt",
    "Sexualproportionen": "Sexualproportion",
    "Sexualtheorien": "Sexualtheorie",
    "Sexuelle": "sexuell",
    "Sexuellen": "Sexuelle",
    "Sezierenden": "Sezierende",
    "Sezierens": "Sezieren",
    "Sezierte": "seziert",
    "Sezierten": "Sezierte",
    "Seßhafte": "seßhaft",
    "Seßhaften": "Seßhafte",
    "Shakespeares": "Shakespeare",
    "Sherryn": "Sherry",
    "Sherrys": "Sherry",
    "Shirts": "Shirt",
    "Shows": "Show",
    "Siamesen": "Siamese",
    "Siamesische": "siamesisch",
    "Siamesischen": "Siamesische",
    "Sibirischen": "Sibirische",
    "Sicheln": "Sichel",
    "Sichere": "sichern",
    "Sicheren": "Sichere",
    "Sichereren": "Sicherere",
    "Sichergestellten": "Sichergestellte",
    "Sicherheiten": "Sicherheit",
    "Sicherheitsbewußte": "sicherheitsbewußt",
    "Sicherheitsbewußten": "Sicherheitsbewußte",
    "Sicherheitsbewußteren": "Sicherheitsbewußtere",
    "Sicherheitspolitischen": "Sicherheitspolitische",
    "Sicherheitsrelevanten": "Sicherheitsrelevante",
    "Sicherheitsrelevanteren": "Sicherheitsrelevantere",
    "Sichernden": "Sichernde",
    "Sichernderen": "Sicherndere",
    "Sicherndsten": "Sicherndste",
    "Sicherns": "Sichern",
    "Sicherstellenden": "Sicherstellende",
    "Sicherstellens": "Sicherstellen",
    "Sichersten": "Sicherste",
    "Sicherungen": "Sicherung",
    "Sichtbaren": "Sichtbare",
    "Sichtbareren": "Sichtbarere",
    "Sichtbarsten": "Sichtbarste",
    "Sichtenden": "Sichtende",
    "Sichtens": "Sichten",
    "Sichtkarteien": "Sichtkartei",
    "Sichtliche": "sichtlich",
    "Sichtlichen": "Sichtliche",
    "Sichtungen": "Sichtung",
    "Sichtvermerke": "Sichtvermerk",
    "Sichtvermerken": "Sichtvermerk",
    "Sichtvermerks": "Sichtvermerk",
    "Siderolithen": "Siderolith",
    "Sieb": "sieben",
    "Siebe": "sieben",
    "Sieben": "Sieb",
    "Siebenbürgens": "Siebenbürgen",
    "Siebenden": "Siebende",
    "Siebens": "Sieben",
    "Siebs": "Sieb",
    "Siebteln": "Siebtel",
    "Siebtels": "Siebtel",
    "Siechenden": "Siechende",
    "Siechenderen": "Siechendere",
    "Siechendsten": "Siechendste",
    "Siechens": "Siechen",
    "Siedelnden": "Siedelnde",
    "Siedelns": "Siedeln",
    "Siedenden": "Siedende",
    "Siedens": "Sieden",
    "Siedlern": "Siedler",
    "Siedlers": "Siedler",
    "Siedlungen": "Siedlung",
    "Sieg": "siegen",
    "Siege": "siegen",
    "Siegel": "siegeln",
    "Siegeln": "Siegel",
    "Siegelnden": "Siegelnde",
    "Siegelns": "Siegeln",
    "Siegels": "Siegel",
    "Siegen": "Sieg",
    "Siegenden": "Siegende",
    "Siegens": "Siegen",
    "Siegerinnen": "Siegerin",
    "Siegern": "Sieger",
    "Siegers": "Sieger",
    "Sieges": "Sieg",
    "Siegesgewisse": "siegesgewiß",
    "Siegesgewissen": "Siegesgewisse",
    "Siegesgewisseren": "Siegesgewissere",
    "Siegesgewissesten": "Siegesgewisseste",
    "Siegessicheren": "Siegessichere",
    "Siegessichereren": "Siegessicherere",
    "Siegessichersten": "Siegessicherste",
    "Siegfrieds": "Siegfried",
    "Siegreichen": "Siegreiche",
    "Siegreicheren": "Siegreichere",
    "Siegreichsten": "Siegreichste",
    "Siegs": "Sieg",
    "Siestas": "Siesta",
    "Sieverts": "Sievert",
    "Siezenden": "Siezende",
    "Siezens": "Siezen",
    "Sigmas": "Sigma",
    "Signale": "Signal",
    "Signalen": "Signal",
    "Signalisierenden": "Signalisierende",
    "Signalisierens": "Signalisieren",
    "Signalisierte": "signalisiert",
    "Signalisierten": "Signalisierte",
    "Signals": "Signal",
    "Signifikante": "signifikant",
    "Signifikanten": "Signifikante",
    "Signifikanteren": "Signifikantere",
    "Signifikantesten": "Signifikanteste",
    "Sigrids": "Sigrid",
    "Silben": "Silbe",
    "Silberfischchens": "Silberfischchen",
    "Silberlöwen": "Silberlöwe",
    "Silbern": "Silber",
    "Silberne": "silbern",
    "Silbernen": "Silberne",
    "Silberpappeln": "Silberpappel",
    "Silbers": "Silber",
    "Silberzwiebeln": "Silberzwiebel",
    "Silikone": "Silikon",
    "Silikonen": "Silikon",
    "Silikons": "Silikon",
    "Silkes": "Silke",
    "Silos": "Silo",
    "Silvestern": "Silvester",
    "Silvesters": "Silvester",
    "Simazins": "Simazin",
    "Simones": "Simone",
    "Simons": "Simon",
    "Simpelste": "simpel",
    "Simpelsten": "Simpelste",
    "Simplen": "Simple",
    "Simpleren": "Simplere",
    "Simulierenden": "Simulierende",
    "Simulierens": "Simulieren",
    "Simulierte": "simuliert",
    "Simulierten": "Simulierte",
    "Simultanen": "Simultane",
    "Simultanspiele": "Simultanspiel",
    "Simultanspielen": "Simultanspiel",
    "Simultanspiels": "Simultanspiel",
    "Sindlingens": "Sindlingen",
    "Sindlingern": "Sindlinger",
    "Sindlingers": "Sindlinger",
    "Sinfonien": "Sinfonie",
    "Sinfonikern": "Sinfoniker",
    "Sinfonikers": "Sinfoniker",
    "Singdrosseln": "Singdrossel",
    "Singenden": "Singende",
    "Singens": "Singen",
    "Singkreise": "Singkreis",
    "Singkreisen": "Singkreis",
    "Singkreises": "Singkreis",
    "Singles": "Single",
    "Singschulen": "Singschule",
    "Singspiele": "Singspiel",
    "Singspielen": "Singspiel",
    "Singspieles": "Singspiel",
    "Singspiels": "Singspiel",
    "Singstimmen": "Singstimme",
    "Singulars": "Singular",
    "Singulären": "Singuläre",
    "Singvogels": "Singvogel",
    "Singvögel": "Singvogel",
    "Singvögeln": "Singvogel",
    "Sinkenden": "Sinkende",
    "Sinkenderen": "Sinkendere",
    "Sinkendsten": "Sinkendste",
    "Sinkens": "Sinken",
    "Sinkkastens": "Sinkkasten",
    "Sinkkästen": "Sinkkasten",
    "Sinkstoffe": "Sinkstoff",
    "Sinkstoffen": "Sinkstoff",
    "Sinkstoffs": "Sinkstoff",
    "Sinn": "sinnen",
    "Sinnbildhafte": "sinnbildhaft",
    "Sinnbildhaften": "Sinnbildhafte",
    "Sinnbildhafteren": "Sinnbildhaftere",
    "Sinnbildhaftesten": "Sinnbildhafteste",
    "Sinnbildlichen": "Sinnbildliche",
    "Sinne": "sinnen",
    "Sinnen": "Sinn",
    "Sinnenden": "Sinnende",
    "Sinnenfreuden": "Sinnenfreude",
    "Sinnens": "Sinnen",
    "Sinngemäßen": "Sinngemäße",
    "Sinnierenden": "Sinnierende",
    "Sinnierens": "Sinnieren",
    "Sinnierte": "sinniert",
    "Sinnierten": "Sinnierte",
    "Sinnigen": "Sinnige",
    "Sinnlichen": "Sinnliche",
    "Sinnlicheren": "Sinnlichere",
    "Sinnlichsten": "Sinnlichste",
    "Sinnlosen": "Sinnlose",
    "Sinnloseren": "Sinnlosere",
    "Sinnlosesten": "Sinnloseste",
    "Sinns": "Sinn",
    "Sinnvollen": "Sinnvolle",
    "Sinnvolleren": "Sinnvollere",
    "Sinnvollsten": "Sinnvollste",
    "Sinnwidrigen": "Sinnwidrige",
    "Sinnwidrigeren": "Sinnwidrigere",
    "Sinnwidrigsten": "Sinnwidrigste",
    "Sippen": "Sippe",
    "Sirenen": "Sirene",
    "Sirs": "Sir",
    "Sitten": "Sitte",
    "Sittenlose": "sittenlos",
    "Sittenlosen": "Sittenlose",
    "Sittenloseren": "Sittenlosere",
    "Sittenlosesten": "Sittenloseste",
    "Sittenwidrigen": "Sittenwidrige",
    "Sittiche": "Sittich",
    "Sittichen": "Sittich",
    "Sittiches": "Sittich",
    "Sittichs": "Sittich",
    "Sittsame": "sittsam",
    "Sittsamen": "Sittsame",
    "Sittsameren": "Sittsamere",
    "Sittsamsten": "Sittsamste",
    "Situationen": "Situation",
    "Situative": "situativ",
    "Situativen": "Situative",
    "Sitze": "sitzen",
    "Sitzen": "Sitz",
    "Sitzenden": "Sitzende",
    "Sitzens": "Sitzen",
    "Sitzes": "Sitz",
    "Sitzfleische": "Sitzfleisch",
    "Sitzfleisches": "Sitzfleisch",
    "Sitzfleischs": "Sitzfleisch",
    "Sitzungen": "Sitzung",
    "Skalare": "Skalar",
    "Skalaren": "Skalare",
    "Skalars": "Skalar",
    "Skalen": "Skala",
    "Skalpe": "Skalp",
    "Skalpelle": "Skalpell",
    "Skalpellen": "Skalpell",
    "Skalpelles": "Skalpell",
    "Skalpells": "Skalpell",
    "Skalpen": "Skalp",
    "Skalpierenden": "Skalpierende",
    "Skalpierens": "Skalpieren",
    "Skalpierte": "skalpiert",
    "Skalpierten": "Skalpierte",
    "Skalps": "Skalp",
    "Skandale": "Skandal",
    "Skandalen": "Skandal",
    "Skandalnudeln": "Skandalnudel",
    "Skandals": "Skandal",
    "Skandalöse": "skandalös",
    "Skandalösen": "Skandalöse",
    "Skandalöseren": "Skandalösere",
    "Skandalösesten": "Skandalöseste",
    "Skandierenden": "Skandierende",
    "Skandierens": "Skandieren",
    "Skandierte": "skandiert",
    "Skandierten": "Skandierte",
    "Skandinavischen": "Skandinavische",
    "Skatern": "Skater",
    "Skaters": "Skater",
    "Skats": "Skat",
    "Skelette": "Skelett",
    "Skeletten": "Skelett",
    "Skelettes": "Skelett",
    "Skelettierenden": "Skelettierende",
    "Skelettierens": "Skelettieren",
    "Skelettierte": "skelettiert",
    "Skelettierten": "Skelettierte",
    "Skeletts": "Skelett",
    "Skeptische": "skeptisch",
    "Skeptischen": "Skeptische",
    "Skeptischeren": "Skeptischere",
    "Skeptischsten": "Skeptischste",
    "Sketche": "Sketch",
    "Sketchen": "Sketch",
    "Sketches": "Sketch",
    "Sketchs": "Sketch",
    "Skie": "Ski",
    "Skier": "Ski",
    "Skiern": "Ski",
    "Skinheads": "Skinhead",
    "Skins": "Skin",
    "Skis": "Ski",
    "Skizzen": "Skizze",
    "Skizzenhafte": "skizzenhaft",
    "Skizzenhaften": "Skizzenhafte",
    "Skizzenhafteren": "Skizzenhaftere",
    "Skizzenhaftesten": "Skizzenhafteste",
    "Skizzierenden": "Skizzierende",
    "Skizzierens": "Skizzieren",
    "Skizzierte": "skizziert",
    "Skizzierten": "Skizzierte",
    "Sklaven": "Sklave",
    "Sklavinnen": "Sklavin",
    "Sklavische": "sklavisch",
    "Sklavischen": "Sklavische",
    "Sklerosen": "Sklerose",
    "Skontos": "Skonto",
    "Skorbute": "Skorbut",
    "Skorbutes": "Skorbut",
    "Skorpione": "Skorpion",
    "Skorpionen": "Skorpion",
    "Skorpions": "Skorpion",
    "Skrupellose": "skrupellos",
    "Skrupellosen": "Skrupellose",
    "Skrupelloseren": "Skrupellosere",
    "Skrupellosesten": "Skrupelloseste",
    "Skrupellosigkeiten": "Skrupellosigkeit",
    "Skrupeln": "Skrupel",
    "Skrupels": "Skrupel",
    "Skulpturen": "Skulptur",
    "Skurrile": "skurril",
    "Skurrilen": "Skurrile",
    "Skurrileren": "Skurrilere",
    "Skurrilsten": "Skurrilste",
    "Slaloms": "Slalom",
    "Slangs": "Slang",
    "Slawinnen": "Slawin",
    "Slippern": "Slipper",
    "Slippers": "Slipper",
    "Slips": "Slip",
    "Slogans": "Slogan",
    "Slowaken": "Slowake",
    "Slowenen": "Slowene",
    "Sloweniens": "Slowenien",
    "Slowenische": "slowenisch",
    "Slowenischen": "Slowenische",
    "Smaragde": "Smaragd",
    "Smaragden": "Smaragd",
    "Smaragds": "Smaragd",
    "Smarte": "smart",
    "Smarten": "Smarte",
    "Smarteren": "Smartere",
    "Smartesten": "Smarteste",
    "Smogs": "Smog",
    "Smokings": "Smoking",
    "Snacks": "Snack",
    "Snobs": "Snob",
    "Sockeln": "Sockel",
    "Sockels": "Sockel",
    "Socken": "Socke",
    "Sockens": "Socken",
    "Sodenern": "Sodener",
    "Sodeners": "Sodener",
    "Sofas": "Sofa",
    "Sofortigen": "Sofortige",
    "Sofortprogramme": "Sofortprogramm",
    "Sofortprogrammen": "Sofortprogramm",
    "Sofortprogrammes": "Sofortprogramm",
    "Sofortprogramms": "Sofortprogramm",
    "Sog": "saugen",
    "Soge": "Sog",
    "Sogen": "Sog",
    "Sogenannten": "Sogenannte",
    "Sogs": "Sog",
    "Sohlen": "Sohle",
    "Sohlenden": "Sohlende",
    "Sohlens": "Sohlen",
    "Sohne": "Sohn",
    "Sohns": "Sohn",
    "Sojasoßen": "Sojasoße",
    "Solaranlagen": "Solaranlage",
    "Solare": "Solar",
    "Solaren": "Solar",
    "Solares": "Solar",
    "Solarfarmen": "Solarfarm",
    "Solargeneratore": "Solargenerator",
    "Solargeneratoren": "Solargenerator",
    "Solargenerators": "Solargenerator",
    "Solarheizungen": "Solarheizung",
    "Solarkollektore": "Solarkollektor",
    "Solarkollektoren": "Solarkollektor",
    "Solarkollektors": "Solarkollektor",
    "Solars": "Solar",
    "Solarwinde": "Solarwind",
    "Solarwinden": "Solarwind",
    "Solarwinds": "Solarwind",
    "Solche": "solch",
    "Solchen": "Solche",
    "Soldaten": "Soldat",
    "Solds": "Sold",
    "Solidarische": "solidarisch",
    "Solidarischen": "Solidarische",
    "Solidarischeren": "Solidarischere",
    "Solidarischsten": "Solidarischste",
    "Solidarisierenden": "Solidarisierende",
    "Solidarisierenderen": "Solidarisierendere",
    "Solidarisierens": "Solidarisieren",
    "Solidarisierte": "solidarisiert",
    "Solidarisierten": "Solidarisierte",
    "Solidarisierteren": "Solidarisiertere",
    "Solidarisierteste": "solidarisiert",
    "Solideren": "Solidere",
    "Solidesten": "Solideste",
    "Solingens": "Solingen",
    "Solisten": "Solist",
    "Soll": "sollen",
    "Solles": "Soll",
    "Solls": "Soll",
    "Solospiele": "Solospiel",
    "Solospielen": "Solospiel",
    "Solospiels": "Solospiel",
    "Solosängern": "Solosänger",
    "Solosängers": "Solosänger",
    "Solotänzern": "Solotänzer",
    "Solotänzers": "Solotänzer",
    "Solquellen": "Solquelle",
    "Somalias": "Somalia",
    "Sommerliche": "sommerlich",
    "Sommerlichen": "Sommerliche",
    "Sommern": "Sommer",
    "Sommers": "Sommer",
    "Sommerschlußverkaufe": "Sommerschlußverkauf",
    "Sommerschlußverkaufs": "Sommerschlußverkauf",
    "Sommerschlußverkäufe": "Sommerschlußverkauf",
    "Sommerschlußverkäufen": "Sommerschlußverkauf",
    "Sommersprossen": "Sommersprosse",
    "Sonden": "Sonde",
    "Sonderausgaben": "Sonderausgabe",
    "Sonderausstellungen": "Sonderausstellung",
    "Sonderbare": "sonderbar",
    "Sonderbaren": "Sonderbare",
    "Sonderbareren": "Sonderbarere",
    "Sonderbarsten": "Sonderbarste",
    "Sonderfalle": "Sonderfall",
    "Sonderfalles": "Sonderfall",
    "Sonderfalls": "Sonderfall",
    "Sonderfälle": "Sonderfall",
    "Sonderfällen": "Sonderfall",
    "Sondergenehmigungen": "Sondergenehmigung",
    "Sonderliche": "sonderlich",
    "Sonderlichen": "Sonderliche",
    "Sonderlicheren": "Sonderlichere",
    "Sonderlichsten": "Sonderlichste",
    "Sondermülls": "Sondermüll",
    "Sondernden": "Sondernde",
    "Sonderns": "Sondern",
    "Sondernummern": "Sondernummer",
    "Sonderschichten": "Sonderschicht",
    "Sonderschulen": "Sonderschule",
    "Sondersituationen": "Sondersituation",
    "Sondersitzungen": "Sondersitzung",
    "Sondersprachen": "Sondersprache",
    "Sonderstellungen": "Sonderstellung",
    "Sonderstempeln": "Sonderstempel",
    "Sonderstempels": "Sonderstempel",
    "Sonderwunsche": "Sonderwunsch",
    "Sonderwunschs": "Sonderwunsch",
    "Sonderwünsche": "Sonderwunsch",
    "Sonderwünschen": "Sonderwunsch",
    "Sonderzuge": "Sonderzug",
    "Sonderzugs": "Sonderzug",
    "Sonderzüge": "Sonderzug",
    "Sonderzügen": "Sonderzug",
    "Sondierenden": "Sondierende",
    "Sondierens": "Sondieren",
    "Sondierte": "sondiert",
    "Sondierten": "Sondierte",
    "Sondierungen": "Sondierung",
    "Sonette": "Sonett",
    "Sonetten": "Sonett",
    "Sonetts": "Sonett",
    "Songs": "Song",
    "Sonjas": "Sonja",
    "Sonnabende": "Sonnabend",
    "Sonnabenden": "Sonnabend",
    "Sonnabends": "Sonnabend",
    "Sonne": "sonnen",
    "Sonnen": "Sonne",
    "Sonnenarme": "sonnenarm",
    "Sonnenarmen": "Sonnenarme",
    "Sonnenaufgange": "Sonnenaufgang",
    "Sonnenaufgangs": "Sonnenaufgang",
    "Sonnenaufgänge": "Sonnenaufgang",
    "Sonnenaufgängen": "Sonnenaufgang",
    "Sonnenden": "Sonnende",
    "Sonnengebräunten": "Sonnengebräunte",
    "Sonnengebräunteren": "Sonnengebräuntere",
    "Sonnenklaren": "Sonnenklare",
    "Sonnens": "Sonnen",
    "Sonnenscheins": "Sonnenschein",
    "Sonnenärmeren": "Sonnenärmere",
    "Sonnigen": "Sonnige",
    "Sonnigeren": "Sonnigere",
    "Sonnigsten": "Sonnigste",
    "Sonntage": "Sonntag",
    "Sonntagen": "Sonntag",
    "Sonntages": "Sonntag",
    "Sonntags": "Sonntag",
    "Sonntägliche": "sonntäglich",
    "Sonntäglichen": "Sonntägliche",
    "Sonstigen": "Sonstige",
    "Soprane": "Sopran",
    "Sopranen": "Sopran",
    "Soprans": "Sopran",
    "Sorge": "sorgen",
    "Sorgen": "Sorge",
    "Sorgenden": "Sorgende",
    "Sorgenfreien": "Sorgenfreie",
    "Sorgenfreieren": "Sorgenfreiere",
    "Sorgenfreiesten": "Sorgenfreieste",
    "Sorgenlosen": "Sorgenlose",
    "Sorgenloseren": "Sorgenlosere",
    "Sorgenlosesten": "Sorgenloseste",
    "Sorgens": "Sorgen",
    "Sorgenvolle": "sorgenvoll",
    "Sorgenvollen": "Sorgenvolle",
    "Sorgenvolleren": "Sorgenvollere",
    "Sorgenvollsten": "Sorgenvollste",
    "Sorgfältigen": "Sorgfältige",
    "Sorgfältigeren": "Sorgfältigere",
    "Sorgfältigsten": "Sorgfältigste",
    "Sorglosen": "Sorglose",
    "Sorgloseren": "Sorglosere",
    "Sorglosesten": "Sorgloseste",
    "Sorgsamen": "Sorgsame",
    "Sorgsameren": "Sorgsamere",
    "Sorgsamsten": "Sorgsamste",
    "Sorten": "Sorte",
    "Sortierenden": "Sortierende",
    "Sortierens": "Sortieren",
    "Sortierern": "Sortierer",
    "Sortierers": "Sortierer",
    "Sortiermaschinen": "Sortiermaschine",
    "Sortierte": "sortiert",
    "Sortierten": "Sortierte",
    "Sortimente": "Sortiment",
    "Sortimenten": "Sortiment",
    "Sortiments": "Sortiment",
    "Sossenheimern": "Sossenheimer",
    "Sossenheimers": "Sossenheimer",
    "Sossenheims": "Sossenheim",
    "Sounds": "Sound",
    "Souterrains": "Souterrain",
    "Souvenirs": "Souvenir",
    "Souveräne": "souverän",
    "Souveränen": "Souveräne",
    "Souveräneren": "Souveränere",
    "Souveränitäten": "Souveränität",
    "Souveränste": "souverän",
    "Souveränsten": "Souveränste",
    "Sowjetischen": "Sowjetische",
    "Sowjets": "Sowjet",
    "Sozialamte": "Sozialamt",
    "Sozialamtes": "Sozialamt",
    "Sozialamts": "Sozialamt",
    "Sozialarbeiten": "Sozialarbeit",
    "Sozialarbeitern": "Sozialarbeiter",
    "Sozialarbeiters": "Sozialarbeiter",
    "Sozialbehörden": "Sozialbehörde",
    "Sozialbereiche": "Sozialbereich",
    "Sozialbereichen": "Sozialbereich",
    "Sozialbereiches": "Sozialbereich",
    "Sozialbereichs": "Sozialbereich",
    "Sozialdemokraten": "Sozialdemokrat",
    "Sozialdemokratien": "Sozialdemokratie",
    "Sozialdemokratinnen": "Sozialdemokratin",
    "Sozialdemokratische": "sozialdemokratisch",
    "Sozialdemokratischen": "Sozialdemokratische",
    "Sozialdezernenten": "Sozialdezernent",
    "Sozialdienste": "Sozialdienst",
    "Sozialdiensten": "Sozialdienst",
    "Sozialdienstes": "Sozialdienst",
    "Soziale": "sozial",
    "Sozialen": "Soziale",
    "Sozialeren": "Sozialere",
    "Sozialfonds": "Sozialfond",
    "Sozialhilfen": "Sozialhilfe",
    "Sozialisationen": "Sozialisation",
    "Sozialisiere": "sozialisieren",
    "Sozialisierenden": "Sozialisierende",
    "Sozialisierenderen": "Sozialisierendere",
    "Sozialisierens": "Sozialisieren",
    "Sozialisierte": "sozialisiert",
    "Sozialisierten": "Sozialisierte",
    "Sozialisierteren": "Sozialisiertere",
    "Sozialisiertesten": "Sozialisierteste",
    "Sozialisierungen": "Sozialisierung",
    "Sozialisten": "Sozialist",
    "Sozialistische": "sozialistisch",
    "Sozialistischen": "Sozialistische",
    "Sozialistischeren": "Sozialistischere",
    "Sozialistischsten": "Sozialistischste",
    "Sozialliberalen": "Sozialliberale",
    "Sozialpolitischen": "Sozialpolitische",
    "Sozialprodukte": "Sozialprodukt",
    "Sozialprodukten": "Sozialprodukt",
    "Sozialprodukts": "Sozialprodukt",
    "Sozialpädagogischen": "Sozialpädagogische",
    "Sozialrate": "Sozialrat",
    "Sozialrates": "Sozialrat",
    "Sozialrats": "Sozialrat",
    "Sozialreformerische": "sozialreformerisch",
    "Sozialreformerischen": "Sozialreformerische",
    "Sozialreformerischeren": "Sozialreformerischere",
    "Sozialrentnern": "Sozialrentner",
    "Sozialrentners": "Sozialrentner",
    "Sozialräte": "Sozialrat",
    "Sozialräten": "Sozialrat",
    "Sozialschichten": "Sozialschicht",
    "Sozialsenatorinnen": "Sozialsenatorin",
    "Sozialstaate": "Sozialstaat",
    "Sozialstaaten": "Sozialstaat",
    "Sozialstaats": "Sozialstaat",
    "Sozialstationen": "Sozialstation",
    "Sozialste": "sozial",
    "Sozialsten": "Sozialste",
    "Sozialstrukturen": "Sozialstruktur",
    "Sozialverhältnisse": "Sozialverhältnis",
    "Sozialverhältnissen": "Sozialverhältnis",
    "Sozialverhältnisses": "Sozialverhältnis",
    "Sozialversicherungen": "Sozialversicherung",
    "Sozialverträgliche": "sozialverträglich",
    "Sozialverträglichen": "Sozialverträgliche",
    "Sozialverträglicheren": "Sozialverträglichere",
    "Sozialwissenschaften": "Sozialwissenschaft",
    "Sozialwohnungen": "Sozialwohnung",
    "Sozialämter": "Sozialamt",
    "Sozialämtern": "Sozialamt",
    "Soziogenesen": "Soziogenese",
    "Soziographien": "Soziographie",
    "Soziokulturelle": "soziokulturell",
    "Soziokulturellen": "Soziokulturelle",
    "Soziologen": "Soziologe",
    "Soziologische": "soziologisch",
    "Soziologischen": "Soziologische",
    "Soziotherapien": "Soziotherapie",
    "Sozis": "Sozi",
    "Soßen": "Soße",
    "Spachtel": "spachteln",
    "Spachteln": "Spachtel",
    "Spachtelnden": "Spachtelnde",
    "Spachtelns": "Spachteln",
    "Spachtels": "Spachtel",
    "Spagats": "Spagat",
    "Spaliere": "Spalier",
    "Spalieren": "Spalier",
    "Spaliers": "Spalier",
    "Spalt": "spalten",
    "Spaltbare": "spaltbar",
    "Spaltbaren": "Spaltbare",
    "Spalte": "spalten",
    "Spalten": "Spalte",
    "Spaltenden": "Spaltende",
    "Spaltenderen": "Spaltendere",
    "Spaltendsten": "Spaltendste",
    "Spaltens": "Spalten",
    "Spaltmaterials": "Spaltmaterial",
    "Spaltpflanzen": "Spaltpflanze",
    "Spalts": "Spalt",
    "Spaltungen": "Spaltung",
    "Spandaus": "Spandau",
    "Spane": "Span",
    "Spanes": "Span",
    "Spangen": "Spange",
    "Spaniels": "Spaniel",
    "Spaniens": "Spanien",
    "Spaniern": "Spanier",
    "Spaniers": "Spanier",
    "Spanische": "spanisch",
    "Spanischen": "Spanische",
    "Spannen": "spinnen",
    "Spannenden": "Spannende",
    "Spannenderen": "Spannendere",
    "Spannendsten": "Spannendste",
    "Spannens": "Spannen",
    "Spannern": "Spanner",
    "Spanners": "Spanner",
    "Spannfuttern": "Spannfutter",
    "Spannfutters": "Spannfutter",
    "Spannungen": "Spannung",
    "Spannweiten": "Spannweite",
    "Spans": "Span",
    "Spante": "Spant",
    "Spanten": "Spant",
    "Spants": "Spant",
    "Sparbuche": "Sparbuch",
    "Sparbuches": "Sparbuch",
    "Sparbuchs": "Sparbuch",
    "Sparbücher": "Sparbuch",
    "Sparbüchern": "Sparbuch",
    "Sparenden": "Sparende",
    "Sparens": "Sparen",
    "Sparern": "Sparer",
    "Sparers": "Sparer",
    "Spargelde": "Spargeld",
    "Spargelder": "Spargeld",
    "Spargeldern": "Spargeld",
    "Spargeldes": "Spargeld",
    "Spargelds": "Spargeld",
    "Spargels": "Spargel",
    "Sparkassen": "Sparkasse",
    "Sparkurse": "Sparkurs",
    "Sparkursen": "Sparkurs",
    "Sparkurses": "Sparkurs",
    "Sparmaßnahmen": "Sparmaßnahme",
    "Sparsame": "sparsam",
    "Sparsamen": "Sparsame",
    "Sparsameren": "Sparsamere",
    "Sparsamsten": "Sparsamste",
    "Sparschweine": "Sparschwein",
    "Sparschweinen": "Sparschwein",
    "Sparschweins": "Sparschwein",
    "Spartanischen": "Spartanische",
    "Spartanischeren": "Spartanischere",
    "Spartanischsten": "Spartanischste",
    "Spartasten": "Spartaste",
    "Sparvorlagen": "Sparvorlage",
    "Spatens": "Spaten",
    "Spatzen": "Spatz",
    "Spazierenden": "Spazierende",
    "Spazierenderen": "Spazierendere",
    "Spazierendsten": "Spazierendste",
    "Spazierenführenden": "Spazierenführende",
    "Spazierenführens": "Spazierenführen",
    "Spazierengeführten": "Spazierengeführte",
    "Spazierengegangenen": "Spazierengegangene",
    "Spazierengehenden": "Spazierengehende",
    "Spazierengehens": "Spazierengehen",
    "Spazierens": "Spazieren",
    "Spaziergange": "Spaziergang",
    "Spazierganges": "Spaziergang",
    "Spaziergangs": "Spaziergang",
    "Spaziergänge": "Spaziergang",
    "Spaziergängen": "Spaziergang",
    "Spaziergängern": "Spaziergänger",
    "Spaziergängers": "Spaziergänger",
    "Spazierte": "spaziert",
    "Spazierten": "Spazierte",
    "Spazierwege": "Spazierweg",
    "Spazierwegen": "Spazierweg",
    "Spazierwegs": "Spazierweg",
    "Spaß": "spaßen",
    "Spaße": "spaßen",
    "Spaßenden": "Spaßende",
    "Spaßenderen": "Spaßendere",
    "Spaßendsten": "Spaßendste",
    "Spaßens": "Spaßen",
    "Spaßes": "Spaß",
    "Spaßigen": "Spaßige",
    "Spaßigeren": "Spaßigere",
    "Spaßigsten": "Spaßigste",
    "Spaßmachern": "Spaßmacher",
    "Spaßmachers": "Spaßmacher",
    "Spechte": "Specht",
    "Spechten": "Specht",
    "Spechts": "Specht",
    "Specke": "Speck",
    "Specken": "Speck",
    "Speckes": "Speck",
    "Specks": "Speck",
    "Spediteure": "Spediteur",
    "Spediteuren": "Spediteur",
    "Spediteures": "Spediteur",
    "Spediteurs": "Spediteur",
    "Speditionen": "Spedition",
    "Speeds": "Speed",
    "Speere": "Speer",
    "Speeren": "Speer",
    "Speers": "Speer",
    "Speicheln": "Speichel",
    "Speichels": "Speichel",
    "Speichen": "Speiche",
    "Speicher": "speichern",
    "Speichern": "Speicher",
    "Speichernden": "Speichernde",
    "Speicherns": "Speichern",
    "Speichers": "Speicher",
    "Speicherungen": "Speicherung",
    "Speienden": "Speiende",
    "Speiens": "Speien",
    "Speisekarten": "Speisekarte",
    "Speisen": "Speise",
    "Speisenden": "Speisende",
    "Speisens": "Speisen",
    "Speisungen": "Speisung",
    "Speiüblen": "Speiüble",
    "Spektakeln": "Spektakel",
    "Spektakels": "Spektakel",
    "Spektakuläre": "spektakulär",
    "Spektakulären": "Spektakuläre",
    "Spektakuläreren": "Spektakulärere",
    "Spektakulärsten": "Spektakulärste",
    "Spektralanalysen": "Spektralanalyse",
    "Spektralfarben": "Spektralfarbe",
    "Spektren": "Spektrum",
    "Spektrographische": "spektrographisch",
    "Spektrographischen": "Spektrographische",
    "Spektrums": "Spektrum",
    "Spekulanten": "Spekulant",
    "Spekulationen": "Spekulation",
    "Spekulative": "spekulativ",
    "Spekulativen": "Spekulative",
    "Spekulierenden": "Spekulierende",
    "Spekulierenderen": "Spekulierendere",
    "Spekulierendsten": "Spekulierendste",
    "Spekulierens": "Spekulieren",
    "Spekulierte": "spekuliert",
    "Spekulierten": "Spekulierte",
    "Spekulierteren": "Spekuliertere",
    "Spekuliertesten": "Spekulierteste",
    "Spendabelsten": "Spendabelste",
    "Spendablen": "Spendable",
    "Spendableren": "Spendablere",
    "Spenden": "Spende",
    "Spendenden": "Spendende",
    "Spendens": "Spenden",
    "Spendern": "Spender",
    "Spenders": "Spender",
    "Spendierenden": "Spendierende",
    "Spendierens": "Spendieren",
    "Spendierte": "spendiert",
    "Spendierten": "Spendierte",
    "Sperbern": "Sperber",
    "Sperbers": "Sperber",
    "Sperlinge": "Sperling",
    "Sperlingen": "Sperling",
    "Sperlings": "Sperling",
    "Spermizide": "Spermizid",
    "Spermiziden": "Spermizide",
    "Spermizids": "Spermizid",
    "Sperrangelweite": "sperrangelweit",
    "Sperrangelweiten": "Sperrangelweite",
    "Sperren": "Sperre",
    "Sperrenden": "Sperrende",
    "Sperrenderen": "Sperrendere",
    "Sperrendsten": "Sperrendste",
    "Sperrens": "Sperren",
    "Sperrfedern": "Sperrfeder",
    "Sperrfeuers": "Sperrfeuer",
    "Sperrfristen": "Sperrfrist",
    "Sperrgebiete": "Sperrgebiet",
    "Sperrgebieten": "Sperrgebiet",
    "Sperrgebiets": "Sperrgebiet",
    "Sperrguthabens": "Sperrguthaben",
    "Sperrige": "sperrig",
    "Sperrigen": "Sperrige",
    "Sperrigeren": "Sperrigere",
    "Sperrigsten": "Sperrigste",
    "Sperrketten": "Sperrkette",
    "Sperrmauern": "Sperrmauer",
    "Sperrmülle": "Sperrmüll",
    "Sperrmülles": "Sperrmüll",
    "Sperrmülls": "Sperrmüll",
    "Sperrschichten": "Sperrschicht",
    "Sperrstunden": "Sperrstunde",
    "Sperrungen": "Sperrung",
    "Sperrzolle": "Sperrzoll",
    "Sperrzolls": "Sperrzoll",
    "Sperrzölle": "Sperrzoll",
    "Sperrzöllen": "Sperrzoll",
    "Spesenfreie": "spesenfrei",
    "Spesenfreien": "Spesenfreie",
    "Spessarts": "Spessart",
    "Speyers": "Speyer",
    "Spezialfache": "Spezialfach",
    "Spezialfaches": "Spezialfach",
    "Spezialfachs": "Spezialfach",
    "Spezialfächer": "Spezialfach",
    "Spezialfächern": "Spezialfach",
    "Spezialgeschäfte": "Spezialgeschäft",
    "Spezialgeschäften": "Spezialgeschäft",
    "Spezialgeschäfts": "Spezialgeschäft",
    "Spezialisierenden": "Spezialisierende",
    "Spezialisierenderen": "Spezialisierendere",
    "Spezialisierens": "Spezialisieren",
    "Spezialisierte": "spezialisiert",
    "Spezialisierten": "Spezialisierte",
    "Spezialisierteren": "Spezialisiertere",
    "Spezialisierteste": "spezialisiert",
    "Spezialisten": "Spezialist",
    "Spezialistentums": "Spezialistentum",
    "Spezialistinnen": "Spezialistin",
    "Spezialitäten": "Spezialität",
    "Spezialkarten": "Spezialkarte",
    "Spezialkataloge": "Spezialkatalog",
    "Spezialkatalogen": "Spezialkatalog",
    "Spezialkataloges": "Spezialkatalog",
    "Spezialkatalogs": "Spezialkatalog",
    "Spezialvollmachten": "Spezialvollmacht",
    "Spezielle": "speziell",
    "Speziellen": "Spezielle",
    "Spezielleren": "Speziellere",
    "Speziellsten": "Speziellste",
    "Spezifikationen": "Spezifikation",
    "Spezifische": "spezifisch",
    "Spezifischen": "Spezifische",
    "Spezifizierenden": "Spezifizierende",
    "Spezifizierens": "Spezifizieren",
    "Spezifizierte": "spezifiziert",
    "Spezifizierten": "Spezifizierte",
    "Spezifizierungen": "Spezifizierung",
    "Sphären": "Sphäre",
    "Sphärische": "sphärisch",
    "Sphärischen": "Sphärische",
    "Sphäroide": "Sphäroid",
    "Sphäroiden": "Sphäroid",
    "Sphäroids": "Sphäroid",
    "Spickenden": "Spickende",
    "Spickens": "Spicken",
    "Spicknadeln": "Spicknadel",
    "Spickzetteln": "Spickzettel",
    "Spickzettels": "Spickzettel",
    "Spiegel": "spiegeln",
    "Spiegelbildliche": "spiegelbildlich",
    "Spiegelbildlichen": "Spiegelbildliche",
    "Spiegelblanken": "Spiegelblanke",
    "Spiegelglatten": "Spiegelglatte",
    "Spiegeln": "Spiegel",
    "Spiegelnden": "Spiegelnde",
    "Spiegelnderen": "Spiegelndere",
    "Spiegelndsten": "Spiegelndste",
    "Spiegelns": "Spiegeln",
    "Spiegels": "Spiegel",
    "Spiegelungen": "Spiegelung",
    "Spiel": "spielen",
    "Spielbüchereien": "Spielbücherei",
    "Spielchens": "Spielchen",
    "Spiele": "spielen",
    "Spielen": "Spiel",
    "Spielenden": "Spielende",
    "Spielens": "Spielen",
    "Spielereien": "Spielerei",
    "Spielerinnen": "Spielerin",
    "Spielerische": "spielerisch",
    "Spielerischen": "Spielerische",
    "Spielerischeren": "Spielerischere",
    "Spielerischsten": "Spielerischste",
    "Spielern": "Spieler",
    "Spielers": "Spieler",
    "Spieles": "Spiel",
    "Spielfreien": "Spielfreie",
    "Spielführern": "Spielführer",
    "Spielführers": "Spielführer",
    "Spielhöllen": "Spielhölle",
    "Spielklassen": "Spielklasse",
    "Spiels": "Spiel",
    "Spielschulden": "Spielschuld",
    "Spielzeuge": "Spielzeug",
    "Spielzeugen": "Spielzeug",
    "Spielzeuges": "Spielzeug",
    "Spielzeugs": "Spielzeug",
    "Spießbürgerlichen": "Spießbürgerliche",
    "Spießbürgerlicheren": "Spießbürgerlichere",
    "Spießenden": "Spießende",
    "Spießens": "Spießen",
    "Spießigen": "Spießige",
    "Spießigeren": "Spießigere",
    "Spießigsten": "Spießigste",
    "Spinate": "Spinat",
    "Spinaten": "Spinat",
    "Spinates": "Spinat",
    "Spinats": "Spinat",
    "Spinde": "Spind",
    "Spindeldürre": "spindeldürr",
    "Spindeldürren": "Spindeldürre",
    "Spindeldürreren": "Spindeldürrere",
    "Spindeldürrsten": "Spindeldürrste",
    "Spindelöle": "Spindelöl",
    "Spindelölen": "Spindelöl",
    "Spindelöls": "Spindelöl",
    "Spinden": "Spind",
    "Spindes": "Spind",
    "Spinds": "Spind",
    "Spinne": "spinnen",
    "Spinnen": "Spinne",
    "Spinnenden": "Spinnende",
    "Spinnens": "Spinnen",
    "Spinnereien": "Spinnerei",
    "Spinnerinnen": "Spinnerin",
    "Spinnern": "Spinner",
    "Spinners": "Spinner",
    "Spinnrade": "Spinnrad",
    "Spinnrades": "Spinnrad",
    "Spinnrads": "Spinnrad",
    "Spinnräder": "Spinnrad",
    "Spinnrädern": "Spinnrad",
    "Spinnweben": "Spinnwebe",
    "Spione": "Spion",
    "Spionen": "Spion",
    "Spiones": "Spion",
    "Spionierenden": "Spionierende",
    "Spionierenderen": "Spionierendere",
    "Spionierendsten": "Spionierendste",
    "Spionierens": "Spionieren",
    "Spionierte": "spioniert",
    "Spionierten": "Spionierte",
    "Spions": "Spion",
    "Spiralbohrern": "Spiralbohrer",
    "Spiralbohrers": "Spiralbohrer",
    "Spiralen": "Spirale",
    "Spiralfedern": "Spiralfeder",
    "Spiralige": "spiralig",
    "Spiraligen": "Spiralige",
    "Spiritisten": "Spiritist",
    "Spiritistische": "spiritistisch",
    "Spiritistischen": "Spiritistische",
    "Spiritualen": "Spirituale",
    "Spirituellen": "Spirituelle",
    "Spirituskochern": "Spirituskocher",
    "Spirituskochers": "Spirituskocher",
    "Spitzbarte": "Spitzbart",
    "Spitzbarts": "Spitzbart",
    "Spitzbekommenden": "Spitzbekommende",
    "Spitzbekommenen": "Spitzbekommene",
    "Spitzbekommens": "Spitzbekommen",
    "Spitzbogens": "Spitzbogen",
    "Spitzbogige": "spitzbogig",
    "Spitzbogigen": "Spitzbogige",
    "Spitzbohrern": "Spitzbohrer",
    "Spitzbohrers": "Spitzbohrer",
    "Spitzbuben": "Spitzbube",
    "Spitzbärte": "Spitzbart",
    "Spitzbärten": "Spitzbart",
    "Spitzbübereien": "Spitzbüberei",
    "Spitzbübische": "spitzbübisch",
    "Spitzbübischen": "Spitzbübische",
    "Spitzbübischeren": "Spitzbübischere",
    "Spitzbübischsten": "Spitzbübischste",
    "Spitze": "spitzen",
    "Spitzel": "spitzeln",
    "Spitzeln": "Spitzel",
    "Spitzelnden": "Spitzelnde",
    "Spitzelns": "Spitzeln",
    "Spitzels": "Spitzel",
    "Spitzen": "Spitze",
    "Spitzenden": "Spitzende",
    "Spitzenderen": "Spitzendere",
    "Spitzendsten": "Spitzendste",
    "Spitzenmäßigen": "Spitzenmäßige",
    "Spitzenreitern": "Spitzenreiter",
    "Spitzenreiters": "Spitzenreiter",
    "Spitzens": "Spitzen",
    "Spitzentänzerinnen": "Spitzentänzerin",
    "Spitzer": "spitz",
    "Spitzeren": "Spitzere",
    "Spitzern": "Spitzer",
    "Spitzers": "Spitzer",
    "Spitzesten": "Spitzeste",
    "Spitzfeilen": "Spitzfeile",
    "Spitzfindige": "spitzfindig",
    "Spitzfindigen": "Spitzfindige",
    "Spitzfindigeren": "Spitzfindigere",
    "Spitzfindigkeiten": "Spitzfindigkeit",
    "Spitzfindigste": "spitzfindig",
    "Spitzfindigsten": "Spitzfindigste",
    "Spitzgekriegten": "Spitzgekriegte",
    "Spitzkehren": "Spitzkehre",
    "Spitzkletten": "Spitzklette",
    "Spitzkopfe": "Spitzkopf",
    "Spitzkopfs": "Spitzkopf",
    "Spitzkriegenden": "Spitzkriegende",
    "Spitzkriegens": "Spitzkriegen",
    "Spitzkugeln": "Spitzkugel",
    "Spitzköpfe": "Spitzkopf",
    "Spitzköpfen": "Spitzkopf",
    "Spitzmarken": "Spitzmarke",
    "Spitzmäuschens": "Spitzmäuschen",
    "Spitzmäuse": "Spitzmaus",
    "Spitzmäusen": "Spitzmaus",
    "Spitznamen": "Spitzname",
    "Spleißenden": "Spleißende",
    "Spleißens": "Spleißen",
    "Splits": "Split",
    "Splitterfasernackten": "Splitterfasernackte",
    "Splitterfreien": "Splitterfreie",
    "Splitternackten": "Splitternackte",
    "Splitternden": "Splitternde",
    "Splitternderen": "Splitterndere",
    "Splitterndsten": "Splitterndste",
    "Splitterns": "Splittern",
    "Splitterparteien": "Splitterpartei",
    "Spoilern": "Spoiler",
    "Spoilers": "Spoiler",
    "Sponsernden": "Sponsernde",
    "Sponsernderen": "Sponserndere",
    "Sponserndsten": "Sponserndste",
    "Sponserns": "Sponsern",
    "Sponsore": "Sponsor",
    "Sponsoren": "Sponsor",
    "Sponsorings": "Sponsoring",
    "Sponsors": "Sponsor",
    "Spontane": "spontan",
    "Spontanen": "Spontane",
    "Spontaneren": "Spontanere",
    "Spontansten": "Spontanste",
    "Sporadischen": "Sporadische",
    "Sporen": "Spore",
    "Spornenden": "Spornende",
    "Spornens": "Spornen",
    "Sporte": "Sport",
    "Sportes": "Sport",
    "Sportgrößen": "Sportgröße",
    "Sportive": "sportiv",
    "Sportiven": "Sportive",
    "Sportiveren": "Sportivere",
    "Sportivsten": "Sportivste",
    "Sportkanonen": "Sportkanone",
    "Sportlern": "Sportler",
    "Sportlers": "Sportler",
    "Sportliche": "sportlich",
    "Sportlichen": "Sportliche",
    "Sportlicheren": "Sportlichere",
    "Sportlichsten": "Sportlichste",
    "Sports": "Sport",
    "Spottbillige": "spottbillig",
    "Spottbilligen": "Spottbillige",
    "Spottenden": "Spottende",
    "Spottenderen": "Spottendere",
    "Spottendsten": "Spottendste",
    "Spottens": "Spotten",
    "Sprachbarrieren": "Sprachbarriere",
    "Sprachen": "sprechen",
    "Sprachgewandten": "Sprachgewandte",
    "Sprachgewandteren": "Sprachgewandtere",
    "Sprachlabors": "Sprachlabor",
    "Sprachlehrern": "Sprachlehrer",
    "Sprachlehrers": "Sprachlehrer",
    "Sprachliche": "sprachlich",
    "Sprachlichen": "Sprachliche",
    "Sprachlosen": "Sprachlose",
    "Sprachloseren": "Sprachlosere",
    "Sprachlosesten": "Sprachloseste",
    "Sprachschulen": "Sprachschule",
    "Sprachunbegabten": "Sprachunbegabte",
    "Sprachunbegabteren": "Sprachunbegabtere",
    "Sprachverarbeitungen": "Sprachverarbeitung",
    "Sprays": "Spray",
    "Sprechakte": "Sprechakt",
    "Sprechakten": "Sprechakt",
    "Sprechakts": "Sprechakt",
    "Sprechanlagen": "Sprechanlage",
    "Sprechblasen": "Sprechblase",
    "Sprechenden": "Sprechende",
    "Sprechenderen": "Sprechendere",
    "Sprechendsten": "Sprechendste",
    "Sprechens": "Sprechen",
    "Sprecherinnen": "Sprecherin",
    "Sprechern": "Sprecher",
    "Sprechers": "Sprecher",
    "Sprechfenstern": "Sprechfenster",
    "Sprechfensters": "Sprechfenster",
    "Sprechfunks": "Sprechfunk",
    "Sprechrollen": "Sprechrolle",
    "Sprechsilben": "Sprechsilbe",
    "Sprechstunden": "Sprechstunde",
    "Sprechstundenhilfen": "Sprechstundenhilfe",
    "Sprechungen": "Sprechung",
    "Sprechweisen": "Sprechweise",
    "Sprechzeiten": "Sprechzeit",
    "Sprechzimmern": "Sprechzimmer",
    "Sprechzimmers": "Sprechzimmer",
    "Spreizdübeln": "Spreizdübel",
    "Spreizdübels": "Spreizdübel",
    "Spreizenden": "Spreizende",
    "Spreizens": "Spreizen",
    "Sprendlingens": "Sprendlingen",
    "Sprendlingern": "Sprendlinger",
    "Sprendlingers": "Sprendlinger",
    "Sprengbomben": "Sprengbombe",
    "Sprengenden": "Sprengende",
    "Sprengens": "Sprengen",
    "Sprengkammern": "Sprengkammer",
    "Sprengkapseln": "Sprengkapsel",
    "Sprengkommandos": "Sprengkommando",
    "Sprengkopfe": "Sprengkopf",
    "Sprengkopfs": "Sprengkopf",
    "Sprengköpfe": "Sprengkopf",
    "Sprengköpfen": "Sprengkopf",
    "Sprengkörpern": "Sprengkörper",
    "Sprengkörpers": "Sprengkörper",
    "Sprengladungen": "Sprengladung",
    "Sprengstoffe": "Sprengstoff",
    "Sprengstoffen": "Sprengstoff",
    "Sprengstoffs": "Sprengstoff",
    "Sprengungen": "Sprengung",
    "Sprengwagens": "Sprengwagen",
    "Sprengwerke": "Sprengwerk",
    "Sprengwerken": "Sprengwerk",
    "Sprengwerks": "Sprengwerk",
    "Sprenkel": "sprenkeln",
    "Sprenkeln": "Sprenkel",
    "Sprenkelnden": "Sprenkelnde",
    "Sprenkelnderen": "Sprenkelndere",
    "Sprenkelndsten": "Sprenkelndste",
    "Sprenkelns": "Sprenkeln",
    "Sprenkels": "Sprenkel",
    "Sprichworte": "Sprichwort",
    "Sprichwortes": "Sprichwort",
    "Sprichworts": "Sprichwort",
    "Sprichwörter": "Sprichwort",
    "Sprichwörtern": "Sprichwort",
    "Sprichwörtliche": "sprichwörtlich",
    "Sprichwörtlichen": "Sprichwörtliche",
    "Sprießenden": "Sprießende",
    "Sprießenderen": "Sprießendere",
    "Sprießendsten": "Sprießendste",
    "Sprießens": "Sprießen",
    "Springblenden": "Springblende",
    "Springbrunnens": "Springbrunnen",
    "Springenden": "Springende",
    "Springens": "Springen",
    "Springerln": "Springerl",
    "Springerls": "Springerl",
    "Springern": "Springer",
    "Springers": "Springer",
    "Springfluten": "Springflut",
    "Springformen": "Springform",
    "Springfrüchte": "Springfrucht",
    "Springfrüchten": "Springfrucht",
    "Springinsfelds": "Springinsfeld",
    "Springläuse": "Springlaus",
    "Springläusen": "Springlaus",
    "Springmessern": "Springmesser",
    "Springmessers": "Springmesser",
    "Springmäuse": "Springmaus",
    "Springmäusen": "Springmaus",
    "Springpferde": "Springpferd",
    "Springpferden": "Springpferd",
    "Springpferds": "Springpferd",
    "Springseile": "Springseil",
    "Springseilen": "Springseil",
    "Springseils": "Springseil",
    "Springwurme": "Springwurm",
    "Springwurmes": "Springwurm",
    "Springwurms": "Springwurm",
    "Springwürmer": "Springwurm",
    "Springwürmern": "Springwurm",
    "Sprinte": "sprinten",
    "Sprinten": "Sprint",
    "Sprintenden": "Sprintende",
    "Sprintenderen": "Sprintendere",
    "Sprintendsten": "Sprintendste",
    "Sprintens": "Sprinten",
    "Sprintern": "Sprinter",
    "Sprinters": "Sprinter",
    "Sprints": "Sprint",
    "Sprite": "Sprit",
    "Spriten": "Sprit",
    "Sprits": "Sprit",
    "Spritzdüsen": "Spritzdüse",
    "Spritze": "spritzen",
    "Spritzen": "Spritze",
    "Spritzenden": "Spritzende",
    "Spritzenderen": "Spritzendere",
    "Spritzendsten": "Spritzendste",
    "Spritzens": "Spritzen",
    "Spritzern": "Spritzer",
    "Spritzers": "Spritzer",
    "Spritzfahrten": "Spritzfahrt",
    "Spritzflaschen": "Spritzflasche",
    "Spritzgebäcks": "Spritzgebäck",
    "Spritzgurken": "Spritzgurke",
    "Spritzige": "spritzig",
    "Spritzigen": "Spritzige",
    "Spritzigeren": "Spritzigere",
    "Spritzigsten": "Spritzigste",
    "Spritzkuchens": "Spritzkuchen",
    "Spritzmalereien": "Spritzmalerei",
    "Spritzpistolen": "Spritzpistole",
    "Spritzwagens": "Spritzwagen",
    "Sprossen": "Sprosse",
    "Spruchbande": "Spruchband",
    "Spruchbands": "Spruchband",
    "Spruchbänder": "Spruchband",
    "Spruchbändern": "Spruchband",
    "Spruche": "Spruch",
    "Spruches": "Spruch",
    "Spruchreife": "spruchreif",
    "Spruchreifen": "Spruchreife",
    "Spruchs": "Spruch",
    "Sprudel": "sprudeln",
    "Sprudeln": "Sprudel",
    "Sprudelnden": "Sprudelnde",
    "Sprudelnderen": "Sprudelndere",
    "Sprudelndsten": "Sprudelndste",
    "Sprudelns": "Sprudeln",
    "Sprudels": "Sprudel",
    "Sprungbeine": "Sprungbein",
    "Sprungbeinen": "Sprungbein",
    "Sprungbeins": "Sprungbein",
    "Sprungbereite": "sprungbereit",
    "Sprungbereiten": "Sprungbereite",
    "Sprungbereiteren": "Sprungbereitere",
    "Sprungbereitesten": "Sprungbereiteste",
    "Sprunge": "Sprung",
    "Sprunghafte": "sprunghaft",
    "Sprunghaften": "Sprunghafte",
    "Sprunghafteren": "Sprunghaftere",
    "Sprunghaftesten": "Sprunghafteste",
    "Sprungs": "Sprung",
    "Spröderen": "Sprödere",
    "Sprödesten": "Sprödeste",
    "Sprößchens": "Sprößchen",
    "Sprüche": "Spruch",
    "Sprüchen": "Spruch",
    "Sprüchleins": "Sprüchlein",
    "Sprühdosen": "Sprühdose",
    "Sprühenden": "Sprühende",
    "Sprühens": "Sprühen",
    "Sprühregens": "Sprühregen",
    "Sprünge": "Sprung",
    "Sprüngen": "Sprung",
    "Spuckenden": "Spuckende",
    "Spuckenderen": "Spuckendere",
    "Spuckendsten": "Spuckendste",
    "Spuckens": "Spucken",
    "Spukenden": "Spukende",
    "Spukenderen": "Spukendere",
    "Spukendsten": "Spukendste",
    "Spukens": "Spuken",
    "Spukgeiste": "Spukgeist",
    "Spukgeister": "Spukgeist",
    "Spukgeistern": "Spukgeist",
    "Spukgeistes": "Spukgeist",
    "Spukgeists": "Spukgeist",
    "Spukgeschichten": "Spukgeschichte",
    "Spukhafte": "spukhaft",
    "Spukhaften": "Spukhafte",
    "Spukhafteren": "Spukhaftere",
    "Spukhaftesten": "Spukhafteste",
    "Spulen": "Spule",
    "Spulenden": "Spulende",
    "Spulens": "Spulen",
    "Spulern": "Spuler",
    "Spulers": "Spuler",
    "Spur": "spuren",
    "Spuren": "Spur",
    "Spurenden": "Spurende",
    "Spurenderen": "Spurendere",
    "Spurendsten": "Spurendste",
    "Spurens": "Spuren",
    "Spurlosen": "Spurlose",
    "Spurtenden": "Spurtende",
    "Spurtenderen": "Spurtendere",
    "Spurtendsten": "Spurtendste",
    "Spurtens": "Spurten",
    "Sputenden": "Sputende",
    "Sputenderen": "Sputendere",
    "Sputendsten": "Sputendste",
    "Sputens": "Sputen",
    "Spähenden": "Spähende",
    "Spähens": "Spähen",
    "Spähtrupps": "Spähtrupp",
    "Spänchens": "Spänchen",
    "Späne": "Span",
    "Spänen": "Span",
    "Spärliche": "spärlich",
    "Spärlichen": "Spärliche",
    "Spärlicheren": "Spärlichere",
    "Spärlichsten": "Spärlichste",
    "Späten": "Späte",
    "Späteren": "Spätere",
    "Spätesten": "Späteste",
    "Spätfrüchte": "Spätfrucht",
    "Spätfrüchten": "Spätfrucht",
    "Spätgotische": "spätgotisch",
    "Spätgotischen": "Spätgotische",
    "Spätherbsts": "Spätherbst",
    "Späths": "Späth",
    "Spätlesen": "Spätlese",
    "Spätschadens": "Spätschaden",
    "Spätschichten": "Spätschicht",
    "Spätschäden": "Spätschaden",
    "Spätwinters": "Spätwinter",
    "Spätzchens": "Spätzchen",
    "Spätzeiten": "Spätzeit",
    "Spätzündern": "Spätzünder",
    "Spätzünders": "Spätzünder",
    "Spätzündungen": "Spätzündung",
    "Späße": "Spaß",
    "Späßen": "Spaß",
    "Spöttischen": "Spöttische",
    "Spöttischeren": "Spöttischere",
    "Spöttischsten": "Spöttischste",
    "Spüle": "spülen",
    "Spülen": "Spüle",
    "Spülende": "spülend",
    "Spülenden": "Spülende",
    "Spülens": "Spülen",
    "Spülerinnen": "Spülerin",
    "Spülern": "Spüler",
    "Spülers": "Spüler",
    "Spülkastens": "Spülkasten",
    "Spülkästen": "Spülkasten",
    "Spülmaschinen": "Spülmaschine",
    "Spülmaschinenfeste": "spülmaschinenfest",
    "Spülmaschinenfesten": "Spülmaschinenfeste",
    "Spülmaschinenfesteren": "Spülmaschinenfestere",
    "Spülsteine": "Spülstein",
    "Spülsteinen": "Spülstein",
    "Spülsteines": "Spülstein",
    "Spülsteins": "Spülstein",
    "Spültoiletten": "Spültoilette",
    "Spülungen": "Spülung",
    "Spürbare": "spürbar",
    "Spürbaren": "Spürbare",
    "Spürbareren": "Spürbarere",
    "Spürbarsten": "Spürbarste",
    "Spürende": "spürend",
    "Spürenden": "Spürende",
    "Spürens": "Spüren",
    "Spürnasen": "Spürnase",
    "Spürsinns": "Spürsinn",
    "Staate": "Staat",
    "Staaten": "Staat",
    "Staatenlose": "staatenlos",
    "Staatenlosen": "Staatenlose",
    "Staates": "Staat",
    "Staatliche": "staatlich",
    "Staatlichen": "Staatliche",
    "Staats": "Staat",
    "Staatsanwaltschaften": "Staatsanwaltschaft",
    "Staatsbeamten": "Staatsbeamte",
    "Staatsbürgerliche": "staatsbürgerlich",
    "Staatsbürgerlichen": "Staatsbürgerliche",
    "Staatseigenen": "Staatseigene",
    "Staatsfeindlichen": "Staatsfeindliche",
    "Staatsmännischen": "Staatsmännische",
    "Staatsrechtlichen": "Staatsrechtliche",
    "Stabe": "Stab",
    "Stabes": "Stab",
    "Stabhochsprunge": "Stabhochsprung",
    "Stabhochsprungs": "Stabhochsprung",
    "Stabhochsprünge": "Stabhochsprung",
    "Stabhochsprüngen": "Stabhochsprung",
    "Stabile": "stabil",
    "Stabilen": "Stabile",
    "Stabileren": "Stabilere",
    "Stabilisatore": "Stabilisator",
    "Stabilisatoren": "Stabilisator",
    "Stabilisators": "Stabilisator",
    "Stabilisiere": "stabilisieren",
    "Stabilisierenden": "Stabilisierende",
    "Stabilisierenderen": "Stabilisierendere",
    "Stabilisierens": "Stabilisieren",
    "Stabilisierte": "stabilisiert",
    "Stabilisierten": "Stabilisierte",
    "Stabilisierteren": "Stabilisiertere",
    "Stabilisiertesten": "Stabilisierteste",
    "Stabilisierungen": "Stabilisierung",
    "Stabilitäten": "Stabilität",
    "Stabilste": "stabil",
    "Stabilsten": "Stabilste",
    "Stabs": "Stab",
    "Stachel": "stacheln",
    "Stacheligen": "Stachelige",
    "Stacheligeren": "Stacheligere",
    "Stacheligsten": "Stacheligste",
    "Stacheln": "Stachel",
    "Stachelnden": "Stachelnde",
    "Stachelnderen": "Stachelndere",
    "Stachelndsten": "Stachelndste",
    "Stachelns": "Stacheln",
    "Stachels": "Stachel",
    "Stadien": "Stadium",
    "Stadions": "Stadion",
    "Stadiums": "Stadium",
    "Stadlern": "Stadler",
    "Stadlers": "Stadler",
    "Stadtbekannte": "stadtbekannt",
    "Stadtbekannten": "Stadtbekannte",
    "Stadträtinnen": "Stadträtin",
    "Staffel": "staffeln",
    "Staffeln": "Staffel",
    "Staffelnden": "Staffelnde",
    "Staffelns": "Staffeln",
    "Staffierenden": "Staffierende",
    "Staffierens": "Staffieren",
    "Staffierte": "staffiert",
    "Staffierten": "Staffierte",
    "Stagnationen": "Stagnation",
    "Stagnierenden": "Stagnierende",
    "Stagnierens": "Stagnieren",
    "Stagnierte": "stagniert",
    "Stagnierten": "Stagnierte",
    "Stahlharten": "Stahlharte",
    "Stahls": "Stahl",
    "Staksigen": "Staksige",
    "Staksigeren": "Staksigere",
    "Staksigsten": "Staksigste",
    "Stalagmiten": "Stalagmit",
    "Stalinistische": "stalinistisch",
    "Stalinistischen": "Stalinistische",
    "Stalins": "Stalin",
    "Stalle": "Stall",
    "Stalles": "Stall",
    "Stalls": "Stall",
    "Stamm": "stammen",
    "Stamme": "stammen",
    "Stammelnden": "Stammelnde",
    "Stammelnderen": "Stammelndere",
    "Stammelndsten": "Stammelndste",
    "Stammelns": "Stammeln",
    "Stammenden": "Stammende",
    "Stammens": "Stammen",
    "Stammes": "Stamm",
    "Stammhaltern": "Stammhalter",
    "Stammhalters": "Stammhalter",
    "Stamms": "Stamm",
    "Stammverwandten": "Stammverwandte",
    "Stampfenden": "Stampfende",
    "Stampfenderen": "Stampfendere",
    "Stampfendsten": "Stampfendste",
    "Stampfens": "Stampfen",
    "Standardisierenden": "Standardisierende",
    "Standardisierens": "Standardisieren",
    "Standardisierte": "standardisiert",
    "Standardisierten": "Standardisierte",
    "Standardisierteren": "Standardisiertere",
    "Standards": "Standard",
    "Standarts": "Standart",
    "Stande": "Stand",
    "Standes": "Stand",
    "Standesamtliche": "standesamtlich",
    "Standesamtlichen": "Standesamtliche",
    "Standesbewußten": "Standesbewußte",
    "Standesbewußteren": "Standesbewußtere",
    "Standesgemäßen": "Standesgemäße",
    "Standfesten": "Standfeste",
    "Standfesteren": "Standfestere",
    "Standfestesten": "Standfesteste",
    "Standgehaltenen": "Standgehaltene",
    "Standhaften": "Standhafte",
    "Standhafteren": "Standhaftere",
    "Standhaftesten": "Standhafteste",
    "Standhaltenden": "Standhaltende",
    "Standhaltenderen": "Standhaltendere",
    "Standhaltendsten": "Standhaltendste",
    "Standhaltens": "Standhalten",
    "Standorte": "Standort",
    "Standorten": "Standort",
    "Standortes": "Standort",
    "Standortfremde": "standortfremd",
    "Standortfremden": "Standortfremde",
    "Standorts": "Standort",
    "Standpunkte": "Standpunkt",
    "Standpunkten": "Standpunkt",
    "Standpunkts": "Standpunkt",
    "Standrechtliche": "standrechtlich",
    "Standrechtlichen": "Standrechtliche",
    "Stands": "Stand",
    "Standsichere": "standsicher",
    "Standsicheren": "Standsichere",
    "Standsichereren": "Standsicherere",
    "Standsichersten": "Standsicherste",
    "Stangen": "Stange",
    "Stanzenden": "Stanzende",
    "Stanzens": "Stanzen",
    "Stapel": "stapeln",
    "Stapeln": "Stapel",
    "Stapelnden": "Stapelnde",
    "Stapelns": "Stapeln",
    "Stapels": "Stapel",
    "Stapfenden": "Stapfende",
    "Stapfens": "Stapfen",
    "Staplern": "Stapler",
    "Staplers": "Stapler",
    "Stare": "Star",
    "Staren": "Star",
    "Stares": "Star",
    "Starke": "stark",
    "Starken": "Starke",
    "Starkenburgs": "Starkenburg",
    "Starlets": "Starlet",
    "Starrenden": "Starrende",
    "Starrenderen": "Starrendere",
    "Starrendsten": "Starrendste",
    "Starrens": "Starren",
    "Starrköpfigen": "Starrköpfige",
    "Starrköpfigeren": "Starrköpfigere",
    "Starrköpfigsten": "Starrköpfigste",
    "Starrsinnigen": "Starrsinnige",
    "Starrsinnigeren": "Starrsinnigere",
    "Starrsinnigsten": "Starrsinnigste",
    "Starrsüchtigen": "Starrsüchtige",
    "Starrsüchtigeren": "Starrsüchtigere",
    "Starrsüchtigsten": "Starrsüchtigste",
    "Stars": "Star",
    "Startbereite": "startbereit",
    "Startbereiten": "Startbereite",
    "Startenden": "Startende",
    "Startens": "Starten",
    "Startern": "Starter",
    "Starters": "Starter",
    "Startklaren": "Startklare",
    "Starts": "Start",
    "Stasis": "Stasi",
    "Statements": "Statement",
    "Statikern": "Statiker",
    "Statikers": "Statiker",
    "Stationen": "Station",
    "Stationierenden": "Stationierende",
    "Stationierens": "Stationieren",
    "Stationierte": "stationiert",
    "Stationierten": "Stationierte",
    "Stationierungen": "Stationierung",
    "Stationäre": "stationär",
    "Stationären": "Stationäre",
    "Statische": "statisch",
    "Statischen": "Statische",
    "Statischeren": "Statischere",
    "Statischsten": "Statischste",
    "Statisten": "Statist",
    "Statistiken": "Statistik",
    "Statistische": "statistisch",
    "Statistischen": "Statistische",
    "Stattenden": "Stattende",
    "Stattens": "Statten",
    "Stattfindenden": "Stattfindende",
    "Stattfindens": "Stattfinden",
    "Stattgebenden": "Stattgebende",
    "Stattgebens": "Stattgeben",
    "Stattgefundenen": "Stattgefundene",
    "Stattgegebenen": "Stattgegebene",
    "Statthaften": "Statthafte",
    "Statthafteren": "Statthaftere",
    "Statthaftesten": "Statthafteste",
    "Stattlichen": "Stattliche",
    "Stattlicheren": "Stattlichere",
    "Stattlichsten": "Stattlichste",
    "Statuen": "Statue",
    "Staturen": "Statur",
    "Stau": "stauen",
    "Staub": "stauben",
    "Staubecken": "Staubecke",
    "Staubeckens": "Staubecken",
    "Staubenden": "Staubende",
    "Staubenderen": "Staubendere",
    "Staubendsten": "Staubendste",
    "Staubens": "Stauben",
    "Staubfreie": "staubfrei",
    "Staubfreien": "Staubfreie",
    "Staubfängern": "Staubfänger",
    "Staubfängers": "Staubfänger",
    "Staubgesaugten": "Staubgesaugte",
    "Staubgesogenen": "Staubgesogene",
    "Staubigen": "Staubige",
    "Staubigeren": "Staubigere",
    "Staubigsten": "Staubigste",
    "Staubs": "Staub",
    "Staubsaugenden": "Staubsaugende",
    "Staubsaugenderen": "Staubsaugendere",
    "Staubsaugendsten": "Staubsaugendste",
    "Staubsaugens": "Staubsaugen",
    "Stauchenden": "Stauchende",
    "Stauchenderen": "Stauchendere",
    "Stauchendsten": "Stauchendste",
    "Stauchens": "Stauchen",
    "Stauchungen": "Stauchung",
    "Staue": "stauen",
    "Stauen": "Stau",
    "Stauenden": "Stauende",
    "Stauenderen": "Stauendere",
    "Stauendsten": "Stauendste",
    "Stauens": "Stauen",
    "Staues": "Stau",
    "Staunenden": "Staunende",
    "Staunens": "Staunen",
    "Staunenswerte": "staunenswert",
    "Staunenswerten": "Staunenswerte",
    "Staunenswerteren": "Staunenswertere",
    "Staunenswertesten": "Staunenswerteste",
    "Staus": "Stau",
    "Steaks": "Steak",
    "Stechenden": "Stechende",
    "Stechenderen": "Stechendere",
    "Stechendsten": "Stechendste",
    "Stechens": "Stechen",
    "Stechern": "Stecher",
    "Stechers": "Stecher",
    "Stechfliegen": "Stechfliege",
    "Stechmücken": "Stechmücke",
    "Stechpaddeln": "Stechpaddel",
    "Stechpaddels": "Stechpaddel",
    "Stechpalmen": "Stechpalme",
    "Stechuhren": "Stechuhr",
    "Stechwinden": "Stechwinde",
    "Steckbriefliche": "steckbrieflich",
    "Steckbrieflichen": "Steckbriefliche",
    "Steckdosen": "Steckdose",
    "Steckenden": "Steckende",
    "Steckens": "Stecken",
    "Steckern": "Stecker",
    "Steckers": "Stecker",
    "Steckmuscheln": "Steckmuschel",
    "Stecknadeln": "Stecknadel",
    "Steckschlüsseln": "Steckschlüssel",
    "Steckschlüssels": "Steckschlüssel",
    "Steckzwiebeln": "Steckzwiebel",
    "Steebs": "Steeb",
    "Stefans": "Stefan",
    "Steffens": "Steffen",
    "Steffis": "Steffi",
    "Stege": "Steg",
    "Stegen": "Steg",
    "Steges": "Steg",
    "Stegosauriern": "Stegosaurier",
    "Stegosauriers": "Stegosaurier",
    "Stegs": "Steg",
    "Stehenbleibenden": "Stehenbleibende",
    "Stehenbleibens": "Stehenbleiben",
    "Stehenden": "Stehende",
    "Stehengebliebenen": "Stehengebliebene",
    "Stehens": "Stehen",
    "Stehern": "Steher",
    "Stehers": "Steher",
    "Stehgeigern": "Stehgeiger",
    "Stehgeigers": "Stehgeiger",
    "Stehkragens": "Stehkragen",
    "Stehlampen": "Stehlampe",
    "Stehleitern": "Stehleiter",
    "Stehlenden": "Stehlende",
    "Stehlens": "Stehlen",
    "Stehpulte": "Stehpult",
    "Stehpulten": "Stehpult",
    "Stehpults": "Stehpult",
    "Stehvermögens": "Stehvermögen",
    "Steifenden": "Steifende",
    "Steifenderen": "Steifendere",
    "Steifendsten": "Steifendste",
    "Steifens": "Steifen",
    "Steigbügeln": "Steigbügel",
    "Steigbügels": "Steigbügel",
    "Steigeisens": "Steigeisen",
    "Steigenden": "Steigende",
    "Steigens": "Steigen",
    "Steiger": "steigern",
    "Steigern": "Steiger",
    "Steigernden": "Steigernde",
    "Steigerns": "Steigern",
    "Steigers": "Steiger",
    "Steigerungen": "Steigerung",
    "Steigungen": "Steigung",
    "Steile": "steil",
    "Steilen": "Steile",
    "Steileren": "Steilere",
    "Steilhange": "Steilhang",
    "Steilhangs": "Steilhang",
    "Steilhänge": "Steilhang",
    "Steilhängen": "Steilhang",
    "Steilküsten": "Steilküste",
    "Steilste": "steil",
    "Steilsten": "Steilste",
    "Steinalten": "Steinalte",
    "Steinaus": "Steinau",
    "Steinbachern": "Steinbacher",
    "Steinbachers": "Steinbacher",
    "Steinbruche": "Steinbruch",
    "Steinbruches": "Steinbruch",
    "Steinbruchs": "Steinbruch",
    "Steinbrüche": "Steinbruch",
    "Steinbrüchen": "Steinbruch",
    "Steinchens": "Steinchen",
    "Steine": "Stein",
    "Steinen": "Stein",
    "Steinerne": "steinern",
    "Steinernen": "Steinerne",
    "Steinerneren": "Steinernere",
    "Steinernsten": "Steinernste",
    "Steiners": "Steiner",
    "Steinfurths": "Steinfurth",
    "Steinhausens": "Steinhausen",
    "Steinheimern": "Steinheimer",
    "Steinheimers": "Steinheimer",
    "Steinhägern": "Steinhäger",
    "Steinhägers": "Steinhäger",
    "Steinigenden": "Steinigende",
    "Steinigens": "Steinigen",
    "Steinigungen": "Steinigung",
    "Steinklees": "Steinklee",
    "Steinkühlers": "Steinkühler",
    "Steinreiche": "steinreich",
    "Steinreichen": "Steinreiche",
    "Steins": "Stein",
    "Stelle": "stellen",
    "Stellen": "Stelle",
    "Stellenden": "Stellende",
    "Stellens": "Stellen",
    "Stellmachereien": "Stellmacherei",
    "Stellplatze": "Stellplatz",
    "Stellplatzes": "Stellplatz",
    "Stellplätze": "Stellplatz",
    "Stellplätzen": "Stellplatz",
    "Stellproben": "Stellprobe",
    "Stellschrauben": "Stellschraube",
    "Stellungen": "Stellung",
    "Stellungnahmen": "Stellungnahme",
    "Stellvertretende": "stellvertretend",
    "Stellvertretenden": "Stellvertretende",
    "Stellvertreterinnen": "Stellvertreterin",
    "Stellvertretern": "Stellvertreter",
    "Stellvertreters": "Stellvertreter",
    "Stellvertretungen": "Stellvertretung",
    "Stellwerke": "Stellwerk",
    "Stellwerken": "Stellwerk",
    "Stellwerks": "Stellwerk",
    "Stelzen": "Stelze",
    "Stemmenden": "Stemmende",
    "Stemmens": "Stemmen",
    "Stempel": "stempeln",
    "Stempeln": "Stempel",
    "Stempelnden": "Stempelnde",
    "Stempelns": "Stempeln",
    "Stempels": "Stempel",
    "Stendals": "Stendal",
    "Stengeln": "Stengel",
    "Stengels": "Stengel",
    "Stenografien": "Stenografie",
    "Stenogramme": "Stenogramm",
    "Stenogrammen": "Stenogramm",
    "Stenogramms": "Stenogramm",
    "Stenotypistinnen": "Stenotypistin",
    "Stepanakerts": "Stepanakert",
    "Stepanovics": "Stepanovic",
    "Stephans": "Stephan",
    "Steppe": "steppen",
    "Steppen": "Steppe",
    "Steppenden": "Steppende",
    "Steppenderen": "Steppendere",
    "Steppendsten": "Steppendste",
    "Steppens": "Steppen",
    "Steps": "Step",
    "Sterbegelde": "Sterbegeld",
    "Sterbegelder": "Sterbegeld",
    "Sterbegeldern": "Sterbegeld",
    "Sterbegeldes": "Sterbegeld",
    "Sterbegelds": "Sterbegeld",
    "Sterbenden": "Sterbende",
    "Sterbens": "Sterben",
    "Sterbenskranke": "sterbenskrank",
    "Sterbenskranken": "Sterbenskranke",
    "Sterbenswörtchens": "Sterbenswörtchen",
    "Sterbeurkunden": "Sterbeurkunde",
    "Sterbezimmern": "Sterbezimmer",
    "Sterbezimmers": "Sterbezimmer",
    "Sterbliche": "sterblich",
    "Sterblichen": "Sterbliche",
    "Sterblicheren": "Sterblichere",
    "Sterblichsten": "Sterblichste",
    "Stereoanlagen": "Stereoanlage",
    "Stereodecodern": "Stereodecoder",
    "Stereodecoders": "Stereodecoder",
    "Stereofotografien": "Stereofotografie",
    "Stereokameras": "Stereokamera",
    "Stereometern": "Stereometer",
    "Stereometers": "Stereometer",
    "Stereoplatten": "Stereoplatte",
    "Stereotype": "stereotyp",
    "Stereotypen": "Stereotype",
    "Sterilen": "Sterile",
    "Sterileren": "Sterilere",
    "Sterilisationen": "Sterilisation",
    "Sterilisatore": "Sterilisator",
    "Sterilisatoren": "Sterilisator",
    "Sterilisators": "Sterilisator",
    "Sterilisiere": "sterilisieren",
    "Sterilisierenden": "Sterilisierende",
    "Sterilisierenderen": "Sterilisierendere",
    "Sterilisierens": "Sterilisieren",
    "Sterilisierte": "sterilisiert",
    "Sterilisierten": "Sterilisierte",
    "Sterilisierteren": "Sterilisiertere",
    "Sterilisiertesten": "Sterilisierteste",
    "Sterilisierungen": "Sterilisierung",
    "Sterilste": "steril",
    "Sterilsten": "Sterilste",
    "Sternchens": "Sternchen",
    "Sterne": "Stern",
    "Sternen": "Stern",
    "Sternes": "Stern",
    "Sterns": "Stern",
    "Sternschnuppen": "Sternschnuppe",
    "Stetige": "stetig",
    "Stetigen": "Stetige",
    "Stetigeren": "Stetigere",
    "Stetigsten": "Stetigste",
    "Steuer": "steuern",
    "Steuerfreien": "Steuerfreie",
    "Steuerlichen": "Steuerliche",
    "Steuern": "Steuer",
    "Steuernden": "Steuernde",
    "Steuerns": "Steuern",
    "Steuerpflichtige": "steuerpflichtig",
    "Steuerpflichtigen": "Steuerpflichtige",
    "Steuers": "Steuer",
    "Steuerschuldnern": "Steuerschuldner",
    "Steuerschuldners": "Steuerschuldner",
    "Steuerungen": "Steuerung",
    "Steuerzahlern": "Steuerzahler",
    "Steuerzahlers": "Steuerzahler",
    "Steves": "Steve",
    "Stibitzenden": "Stibitzende",
    "Stibitzens": "Stibitzen",
    "Stibitzte": "stibitzt",
    "Stibitzten": "Stibitzte",
    "Stiche": "Stich",
    "Stichelnden": "Stichelnde",
    "Stichelnderen": "Stichelndere",
    "Stichelndsten": "Stichelndste",
    "Stichelns": "Sticheln",
    "Stichen": "Stich",
    "Stiches": "Stich",
    "Stichhaltige": "stichhaltig",
    "Stichhaltigen": "Stichhaltige",
    "Stichproben": "Stichprobe",
    "Stichs": "Stich",
    "Stichwaffen": "Stichwaffe",
    "Stichworte": "Stichwort",
    "Stichworten": "Stichwort",
    "Stichwortes": "Stichwort",
    "Stichworts": "Stichwort",
    "Stickoxide": "Stickoxid",
    "Stickoxiden": "Stickoxid",
    "Stickoxids": "Stickoxid",
    "Stickrahmens": "Stickrahmen",
    "Sticks": "Stick",
    "Stickstoffs": "Stickstoff",
    "Stiebenden": "Stiebende",
    "Stiebenderen": "Stiebendere",
    "Stiebendsten": "Stiebendste",
    "Stiebens": "Stieben",
    "Stiefel": "stiefeln",
    "Stiefeletten": "Stiefelette",
    "Stiefeln": "Stiefel",
    "Stiefelnden": "Stiefelnde",
    "Stiefelns": "Stiefeln",
    "Stiefels": "Stiefel",
    "Stiefkinde": "Stiefkind",
    "Stiefkinder": "Stiefkind",
    "Stiefkindern": "Stiefkind",
    "Stiefkindes": "Stiefkind",
    "Stiefkinds": "Stiefkind",
    "Stiefmütterchens": "Stiefmütterchen",
    "Stiefmütterliche": "stiefmütterlich",
    "Stiefmütterlichen": "Stiefmütterliche",
    "Stielenden": "Stielende",
    "Stielens": "Stielen",
    "Stier": "stieren",
    "Stiere": "stieren",
    "Stieren": "Stier",
    "Stierenden": "Stierende",
    "Stierenderen": "Stierendere",
    "Stierendsten": "Stierendste",
    "Stierens": "Stieren",
    "Stieres": "Stier",
    "Stiers": "Stier",
    "Stierstadts": "Stierstadt",
    "Stieseligen": "Stieselige",
    "Stieseligeren": "Stieseligere",
    "Stieseligsten": "Stieseligste",
    "Stieseln": "Stiesel",
    "Stiesels": "Stiesel",
    "Stifte": "stiften",
    "Stiften": "Stift",
    "Stiftenden": "Stiftende",
    "Stiftenderen": "Stiftendere",
    "Stiftendsten": "Stiftendste",
    "Stiftens": "Stiften",
    "Stiftern": "Stifter",
    "Stifters": "Stifter",
    "Stifts": "Stift",
    "Stiftungen": "Stiftung",
    "Stigmatisationen": "Stigmatisation",
    "Stigmatisierenden": "Stigmatisierende",
    "Stigmatisierenderen": "Stigmatisierendere",
    "Stigmatisierens": "Stigmatisieren",
    "Stigmatisierte": "stigmatisiert",
    "Stigmatisierten": "Stigmatisierte",
    "Stigmatisierteren": "Stigmatisiertere",
    "Stigmatisierteste": "stigmatisiert",
    "Stile": "Stil",
    "Stilechte": "stilecht",
    "Stilechten": "Stilechte",
    "Stilen": "Stil",
    "Stiles": "Stil",
    "Stilgerechte": "stilgerecht",
    "Stilgerechten": "Stilgerechte",
    "Stilisierenden": "Stilisierende",
    "Stilisierenderen": "Stilisierendere",
    "Stilisierendsten": "Stilisierendste",
    "Stilisierens": "Stilisieren",
    "Stilisierte": "stilisiert",
    "Stilisierten": "Stilisierte",
    "Stilisierteren": "Stilisiertere",
    "Stilisiertesten": "Stilisierteste",
    "Stilisierungen": "Stilisierung",
    "Stilisten": "Stilist",
    "Stilistische": "stilistisch",
    "Stilistischen": "Stilistische",
    "Stille": "stillen",
    "Stillegungen": "Stillegung",
    "Stillen": "Stille",
    "Stillenden": "Stillende",
    "Stillens": "Stillen",
    "Stilleren": "Stillere",
    "Stillgelegten": "Stillgelegte",
    "Stillgeschwiegenen": "Stillgeschwiegene",
    "Stillgeschwiegeneren": "Stillgeschwiegenere",
    "Stilllegenden": "Stilllegende",
    "Stilllegens": "Stilllegen",
    "Stillosen": "Stillose",
    "Stilloseren": "Stillosere",
    "Stillosesten": "Stilloseste",
    "Stillschweigenden": "Stillschweigende",
    "Stillschweigenderen": "Stillschweigendere",
    "Stillschweigens": "Stillschweigen",
    "Stillstande": "Stillstand",
    "Stillstandes": "Stillstand",
    "Stillstands": "Stillstand",
    "Stillste": "still",
    "Stillsten": "Stillste",
    "Stillstände": "Stillstand",
    "Stillständen": "Stillstand",
    "Stils": "Stil",
    "Stilvolle": "stilvoll",
    "Stilvollen": "Stilvolle",
    "Stilvolleren": "Stilvollere",
    "Stilvollsten": "Stilvollste",
    "Stimmberechtigten": "Stimmberechtigte",
    "Stimmchens": "Stimmchen",
    "Stimme": "stimmen",
    "Stimmen": "Stimme",
    "Stimmenden": "Stimmende",
    "Stimmens": "Stimmen",
    "Stimmfehlern": "Stimmfehler",
    "Stimmfehlers": "Stimmfehler",
    "Stimmgewaltige": "stimmgewaltig",
    "Stimmgewaltigen": "Stimmgewaltige",
    "Stimmigen": "Stimmige",
    "Stimmigeren": "Stimmigere",
    "Stimmigsten": "Stimmigste",
    "Stimmlagen": "Stimmlage",
    "Stimmliche": "stimmlich",
    "Stimmlichen": "Stimmliche",
    "Stimmungen": "Stimmung",
    "Stimmungsvolle": "stimmungsvoll",
    "Stimmungsvollen": "Stimmungsvolle",
    "Stimmungsvolleren": "Stimmungsvollere",
    "Stimmungsvollsten": "Stimmungsvollste",
    "Stimulanzen": "Stimulanz",
    "Stimulatore": "Stimulator",
    "Stimulatoren": "Stimulator",
    "Stimulators": "Stimulator",
    "Stimulierenden": "Stimulierende",
    "Stimulierenderen": "Stimulierendere",
    "Stimulierendsten": "Stimulierendste",
    "Stimulierens": "Stimulieren",
    "Stimulierte": "stimuliert",
    "Stimulierten": "Stimulierte",
    "Stimulierteren": "Stimuliertere",
    "Stimuliertesten": "Stimulierteste",
    "Stinkbomben": "Stinkbombe",
    "Stinkenden": "Stinkende",
    "Stinkenderen": "Stinkendere",
    "Stinkendsten": "Stinkendste",
    "Stinkens": "Stinken",
    "Stinkfaulen": "Stinkfaule",
    "Stinkigen": "Stinkige",
    "Stinkigeren": "Stinkigere",
    "Stinkigsten": "Stinkigste",
    "Stinklangweiligen": "Stinklangweilige",
    "Stinknasen": "Stinknase",
    "Stinkreiche": "stinkreich",
    "Stinkreichen": "Stinkreiche",
    "Stinkstiefeln": "Stinkstiefel",
    "Stinkstiefels": "Stinkstiefel",
    "Stinktiere": "Stinktier",
    "Stinktieren": "Stinktier",
    "Stinktiers": "Stinktier",
    "Stinkwanzen": "Stinkwanze",
    "Stipendiaten": "Stipendiat",
    "Stipendien": "Stipendium",
    "Stipendiums": "Stipendium",
    "Stippenden": "Stippende",
    "Stippens": "Stippen",
    "Stirne": "Stirn",
    "Stirnen": "Stirn",
    "Stochernden": "Stochernde",
    "Stocherns": "Stochern",
    "Stock": "stocken",
    "Stocke": "stocken",
    "Stockenden": "Stockende",
    "Stockenderen": "Stockendere",
    "Stockendsten": "Stockendste",
    "Stockens": "Stocken",
    "Stockenten": "Stockente",
    "Stockes": "Stock",
    "Stockhausens": "Stockhausen",
    "Stockholms": "Stockholm",
    "Stocknüchterne": "stocknüchtern",
    "Stocknüchternen": "Stocknüchterne",
    "Stocks": "Stock",
    "Stocksaure": "stocksauer",
    "Stocksauren": "Stocksaure",
    "Stockscheren": "Stockschere",
    "Stocksteifen": "Stocksteife",
    "Stockwerke": "Stockwerk",
    "Stockwerken": "Stockwerk",
    "Stockwerkes": "Stockwerk",
    "Stockwerks": "Stockwerk",
    "Stoffe": "Stoff",
    "Stoffelige": "stoffelig",
    "Stoffeligen": "Stoffelige",
    "Stoffeligeren": "Stoffeligere",
    "Stoffeligsten": "Stoffeligste",
    "Stoffeln": "Stoffel",
    "Stoffels": "Stoffel",
    "Stoffen": "Stoff",
    "Stoffes": "Stoff",
    "Stoffliche": "stofflich",
    "Stofflichen": "Stoffliche",
    "Stoffs": "Stoff",
    "Stoibers": "Stoiber",
    "Stollen": "Stolle",
    "Stollens": "Stollen",
    "Stolpernden": "Stolpernde",
    "Stolperns": "Stolpern",
    "Stolpersteine": "Stolperstein",
    "Stolpersteinen": "Stolperstein",
    "Stolpersteins": "Stolperstein",
    "Stolpes": "Stolpe",
    "Stoltenbergs": "Stoltenberg",
    "Stoltzes": "Stoltze",
    "Stolze": "Stolz",
    "Stolzen": "Stolze",
    "Stolzeren": "Stolzere",
    "Stolzeste": "stolz",
    "Stolzesten": "Stolzeste",
    "Stolzierenden": "Stolzierende",
    "Stolzierens": "Stolzieren",
    "Stolzierte": "stolziert",
    "Stolzierten": "Stolzierte",
    "Stopfenden": "Stopfende",
    "Stopfenderen": "Stopfendere",
    "Stopfendsten": "Stopfendste",
    "Stopfens": "Stopfen",
    "Stopfern": "Stopfer",
    "Stopfers": "Stopfer",
    "Stopfgarne": "Stopfgarn",
    "Stopfgarnen": "Stopfgarn",
    "Stopfgarns": "Stopfgarn",
    "Stoppeligen": "Stoppelige",
    "Stoppeligeren": "Stoppeligere",
    "Stoppeligsten": "Stoppeligste",
    "Stoppelnden": "Stoppelnde",
    "Stoppelns": "Stoppeln",
    "Stoppenden": "Stoppende",
    "Stoppens": "Stoppen",
    "Stopptasten": "Stopptaste",
    "Stops": "Stop",
    "Stopworte": "Stopwort",
    "Stopwortes": "Stopwort",
    "Stopworts": "Stopwort",
    "Stopwörter": "Stopwort",
    "Stopwörtern": "Stopwort",
    "Storche": "Storch",
    "Storches": "Storch",
    "Storchs": "Storch",
    "Stories": "Story",
    "Storms": "Storm",
    "Stornierenden": "Stornierende",
    "Stornierens": "Stornieren",
    "Stornierte": "storniert",
    "Stornierten": "Stornierte",
    "Stotterern": "Stotterer",
    "Stotterers": "Stotterer",
    "Stotternden": "Stotternde",
    "Stotternderen": "Stotterndere",
    "Stotterndsten": "Stotterndste",
    "Stotterns": "Stottern",
    "Stoß": "stoßen",
    "Stoße": "stoßen",
    "Stoßempfindliche": "stoßempfindlich",
    "Stoßempfindlichen": "Stoßempfindliche",
    "Stoßenden": "Stoßende",
    "Stoßens": "Stoßen",
    "Stoßern": "Stoßer",
    "Stoßers": "Stoßer",
    "Stoßes": "Stoß",
    "Stoßfesten": "Stoßfeste",
    "Stoßfesteren": "Stoßfestere",
    "Stoßfestesten": "Stoßfesteste",
    "Stoßsicheren": "Stoßsichere",
    "Stoßsichereren": "Stoßsicherere",
    "Stoßsichersten": "Stoßsicherste",
    "Stoßstangen": "Stoßstange",
    "Strafanzeigen": "Strafanzeige",
    "Strafbare": "strafbar",
    "Strafbaren": "Strafbare",
    "Strafbareren": "Strafbarere",
    "Strafbarsten": "Strafbarste",
    "Strafbefehle": "Strafbefehl",
    "Strafbefehlen": "Strafbefehl",
    "Strafbefehls": "Strafbefehl",
    "Strafe": "strafen",
    "Strafen": "Strafe",
    "Strafenden": "Strafende",
    "Strafenderen": "Strafendere",
    "Strafendsten": "Strafendste",
    "Strafens": "Strafen",
    "Straffen": "Straffe",
    "Strafferen": "Straffere",
    "Straffreien": "Straffreie",
    "Straffsten": "Straffste",
    "Straffälligen": "Straffällige",
    "Strafgerichte": "Strafgericht",
    "Strafgerichten": "Strafgericht",
    "Strafgerichts": "Strafgericht",
    "Strafkammern": "Strafkammer",
    "Strafmildernden": "Strafmildernde",
    "Strafmündigen": "Strafmündige",
    "Strafpunkte": "Strafpunkt",
    "Strafpunkten": "Strafpunkt",
    "Strafpunkts": "Strafpunkt",
    "Strafrahmens": "Strafrahmen",
    "Strafraume": "Strafraum",
    "Strafraumes": "Strafraum",
    "Strafraums": "Strafraum",
    "Strafrechte": "Strafrecht",
    "Strafrechten": "Strafrecht",
    "Strafrechtliche": "strafrechtlich",
    "Strafrechtlichen": "Strafrechtliche",
    "Strafrechts": "Strafrecht",
    "Strafräume": "Strafraum",
    "Strafräumen": "Strafraum",
    "Strafsachen": "Strafsache",
    "Strafschärfungen": "Strafschärfung",
    "Strafsteuern": "Strafsteuer",
    "Strafstoße": "Strafstoß",
    "Strafstoßes": "Strafstoß",
    "Strafstöße": "Strafstoß",
    "Strafstößen": "Strafstoß",
    "Straftaten": "Straftat",
    "Strafverschärfenden": "Strafverschärfende",
    "Strafvollzugs": "Strafvollzug",
    "Strafzetteln": "Strafzettel",
    "Strafzettels": "Strafzettel",
    "Strahl": "strahlen",
    "Strahle": "strahlen",
    "Strahlen": "Strahl",
    "Strahlenden": "Strahlende",
    "Strahlenderen": "Strahlendere",
    "Strahlendsten": "Strahlendste",
    "Strahlens": "Strahlen",
    "Strahlern": "Strahler",
    "Strahlers": "Strahler",
    "Strahls": "Strahl",
    "Strahlungen": "Strahlung",
    "Strammgestandenen": "Strammgestandene",
    "Strammgestandeneren": "Strammgestandenere",
    "Strammstehenden": "Strammstehende",
    "Strammstehenderen": "Strammstehendere",
    "Strammstehendsten": "Strammstehendste",
    "Strammstehens": "Strammstehen",
    "Strampelnden": "Strampelnde",
    "Strampelns": "Strampeln",
    "Strande": "stranden",
    "Strandenden": "Strandende",
    "Strandens": "Stranden",
    "Strandes": "Strand",
    "Strands": "Strand",
    "Strangulationen": "Strangulation",
    "Strangulierenden": "Strangulierende",
    "Strangulierens": "Strangulieren",
    "Strangulierte": "stranguliert",
    "Strangulierten": "Strangulierte",
    "Strangulierungen": "Strangulierung",
    "Strapazen": "Strapaze",
    "Strapazierenden": "Strapazierende",
    "Strapazierenderen": "Strapazierendere",
    "Strapazierendsten": "Strapazierendste",
    "Strapazierens": "Strapazieren",
    "Strapazierfähigen": "Strapazierfähige",
    "Strapazierfähigeren": "Strapazierfähigere",
    "Strapazierte": "strapaziert",
    "Strapazierten": "Strapazierte",
    "Strapazierteren": "Strapaziertere",
    "Strapaziertesten": "Strapazierteste",
    "Strapaziösen": "Strapaziöse",
    "Strapaziöseren": "Strapaziösere",
    "Strapaziösesten": "Strapaziöseste",
    "Strategien": "Strategie",
    "Strategische": "strategisch",
    "Strategischen": "Strategische",
    "Strauchelnden": "Strauchelnde",
    "Strauchelnderen": "Strauchelndere",
    "Strauchelndsten": "Strauchelndste",
    "Strauchelns": "Straucheln",
    "Strauße": "Strauß",
    "Straußes": "Strauß",
    "Strawinskys": "Strawinsky",
    "Straßburgern": "Straßburger",
    "Straßburgers": "Straßburger",
    "Straßburgs": "Straßburg",
    "Straßen": "Straße",
    "Straßenmeistereien": "Straßenmeisterei",
    "Strebenden": "Strebende",
    "Strebenderen": "Strebendere",
    "Strebendsten": "Strebendste",
    "Strebens": "Streben",
    "Strebsamen": "Strebsame",
    "Strebsameren": "Strebsamere",
    "Strebsamsten": "Strebsamste",
    "Strecken": "Strecke",
    "Streckenden": "Streckende",
    "Streckenderen": "Streckendere",
    "Streckendsten": "Streckendste",
    "Streckens": "Strecken",
    "Streckungen": "Streckung",
    "Streckverbande": "Streckverband",
    "Streckverbands": "Streckverband",
    "Streckverbände": "Streckverband",
    "Streckverbänden": "Streckverband",
    "Streibls": "Streibl",
    "Streich": "streichen",
    "Streichbrette": "Streichbrett",
    "Streichbretter": "Streichbrett",
    "Streichbrettern": "Streichbrett",
    "Streichbrettes": "Streichbrett",
    "Streichbretts": "Streichbrett",
    "Streiche": "streichen",
    "Streicheleinheiten": "Streicheleinheit",
    "Streichelnden": "Streichelnde",
    "Streichelns": "Streicheln",
    "Streichen": "Streich",
    "Streichenden": "Streichende",
    "Streichens": "Streichen",
    "Streichern": "Streicher",
    "Streichers": "Streicher",
    "Streiches": "Streich",
    "Streichkäsen": "Streichkäse",
    "Streichkäses": "Streichkäse",
    "Streichmusiken": "Streichmusik",
    "Streichquintette": "Streichquintett",
    "Streichquintetten": "Streichquintett",
    "Streichquintetts": "Streichquintett",
    "Streichs": "Streich",
    "Streichungen": "Streichung",
    "Streichwürste": "Streichwurst",
    "Streichwürsten": "Streichwurst",
    "Streifchens": "Streifchen",
    "Streife": "streifen",
    "Streifen": "Streife",
    "Streifenden": "Streifende",
    "Streifens": "Streifen",
    "Streifjagden": "Streifjagd",
    "Streiflichte": "Streiflicht",
    "Streiflichter": "Streiflicht",
    "Streiflichtern": "Streiflicht",
    "Streiflichtes": "Streiflicht",
    "Streiflichts": "Streiflicht",
    "Streifzuge": "Streifzug",
    "Streifzugs": "Streifzug",
    "Streifzüge": "Streifzug",
    "Streifzügen": "Streifzug",
    "Streik": "streiken",
    "Streikenden": "Streikende",
    "Streikens": "Streiken",
    "Streiks": "Streik",
    "Streit": "streiten",
    "Streite": "streiten",
    "Streitenden": "Streitende",
    "Streitenderen": "Streitendere",
    "Streitendsten": "Streitendste",
    "Streitens": "Streiten",
    "Streiterinnen": "Streiterin",
    "Streitern": "Streiter",
    "Streiters": "Streiter",
    "Streites": "Streit",
    "Streitigkeiten": "Streitigkeit",
    "Streitlustige": "streitlustig",
    "Streitlustigen": "Streitlustige",
    "Streitlustigeren": "Streitlustigere",
    "Streitlustigsten": "Streitlustigste",
    "Streitmächte": "Streitmacht",
    "Streitmächten": "Streitmacht",
    "Streits": "Streit",
    "Streitsüchtige": "streitsüchtig",
    "Streitsüchtigen": "Streitsüchtige",
    "Streitsüchtigeren": "Streitsüchtigere",
    "Streitsüchtigsten": "Streitsüchtigste",
    "Streitwagens": "Streitwagen",
    "Strenge": "strengen",
    "Strengen": "Strenge",
    "Strengens": "Strengen",
    "Strengeren": "Strengere",
    "Strenggläubigen": "Strenggläubige",
    "Strengsten": "Strengste",
    "Stresse": "stressen",
    "Stressenden": "Stressende",
    "Stressenderen": "Stressendere",
    "Stressendsten": "Stressendste",
    "Stressens": "Stressen",
    "Stresses": "Streß",
    "Stressore": "Stressor",
    "Stressoren": "Stressor",
    "Stressors": "Stressor",
    "Streu": "streuen",
    "Streuenden": "Streuende",
    "Streuens": "Streuen",
    "Streuern": "Streuer",
    "Streuers": "Streuer",
    "Streunenden": "Streunende",
    "Streunenderen": "Streunendere",
    "Streunendsten": "Streunendste",
    "Streunens": "Streunen",
    "Streuobsts": "Streuobst",
    "Streuselnden": "Streuselnde",
    "Streuselns": "Streuseln",
    "Streß": "stressen",
    "Striche": "Strich",
    "Strichelchens": "Strichelchen",
    "Strichen": "Strich",
    "Striches": "Strich",
    "Strichs": "Strich",
    "Stricke": "Strick",
    "Stricken": "Strick",
    "Strickes": "Strick",
    "Strickkleide": "Strickkleid",
    "Strickkleider": "Strickkleid",
    "Strickkleidern": "Strickkleid",
    "Strickkleides": "Strickkleid",
    "Strickkleids": "Strickkleid",
    "Stricks": "Strick",
    "Strickstrumpfe": "Strickstrumpf",
    "Strickstrumpfs": "Strickstrumpf",
    "Strickstrümpfe": "Strickstrumpf",
    "Strickstrümpfen": "Strickstrumpf",
    "Strickwesten": "Strickweste",
    "Strickzeuge": "Strickzeug",
    "Strickzeugen": "Strickzeug",
    "Strickzeugs": "Strickzeug",
    "Striegelnden": "Striegelnde",
    "Striegelnderen": "Striegelndere",
    "Striegelndsten": "Striegelndste",
    "Striegelns": "Striegeln",
    "Striemen": "Strieme",
    "Strikte": "strikt",
    "Strikten": "Strikte",
    "Strikteren": "Striktere",
    "Striktesten": "Strikteste",
    "Striktionen": "Striktion",
    "Stringente": "stringent",
    "Stringenten": "Stringente",
    "Stringhams": "Stringham",
    "Strippe": "strippen",
    "Strippen": "Strippe",
    "Strippenden": "Strippende",
    "Strippenderen": "Strippendere",
    "Strippendsten": "Strippendste",
    "Strippens": "Strippen",
    "Strippern": "Stripper",
    "Strippers": "Stripper",
    "Strippings": "Stripping",
    "Strips": "Strip",
    "Strittigen": "Strittige",
    "Strittigeren": "Strittigere",
    "Strittigsten": "Strittigste",
    "Strohdummen": "Strohdumme",
    "Strohe": "Stroh",
    "Strohes": "Stroh",
    "Strohige": "strohig",
    "Strohigen": "Strohige",
    "Strohigeren": "Strohigere",
    "Strohigsten": "Strohigste",
    "Strohs": "Stroh",
    "Strohwitwen": "Strohwitwe",
    "Strohwitwern": "Strohwitwer",
    "Strohwitwers": "Strohwitwer",
    "Strolch": "strolchen",
    "Strolche": "strolchen",
    "Strolchen": "Strolch",
    "Strolchenden": "Strolchende",
    "Strolchenderen": "Strolchendere",
    "Strolchendsten": "Strolchendste",
    "Strolchens": "Strolchen",
    "Strolchs": "Strolch",
    "Strome": "Strom",
    "Stromernden": "Stromernde",
    "Stromernderen": "Stromerndere",
    "Stromerndsten": "Stromerndste",
    "Stromerns": "Stromern",
    "Stromes": "Strom",
    "Stroms": "Strom",
    "Strontiums": "Strontium",
    "Strophen": "Strophe",
    "Strothmanns": "Strothmann",
    "Strotzenden": "Strotzende",
    "Strotzenderen": "Strotzendere",
    "Strotzendsten": "Strotzendste",
    "Strotzens": "Strotzen",
    "Strubbeligen": "Strubbelige",
    "Strubbeligeren": "Strubbeligere",
    "Strubbeligsten": "Strubbeligste",
    "Strubbelkopfe": "Strubbelkopf",
    "Strubbelkopfs": "Strubbelkopf",
    "Strubbelköpfe": "Strubbelkopf",
    "Strubbelköpfen": "Strubbelkopf",
    "Strudel": "strudeln",
    "Strudeln": "Strudel",
    "Strudelnden": "Strudelnde",
    "Strudelnderen": "Strudelndere",
    "Strudelndsten": "Strudelndste",
    "Strudelns": "Strudeln",
    "Strudels": "Strudel",
    "Strukturellen": "Strukturelle",
    "Strukturelleren": "Strukturellere",
    "Strukturellsten": "Strukturellste",
    "Strukturen": "Struktur",
    "Strukturiere": "strukturieren",
    "Strukturierenden": "Strukturierende",
    "Strukturierenderen": "Strukturierendere",
    "Strukturierens": "Strukturieren",
    "Strukturierte": "strukturiert",
    "Strukturierten": "Strukturierte",
    "Strukturierteren": "Strukturiertere",
    "Strukturiertesten": "Strukturierteste",
    "Strukturschwachen": "Strukturschwache",
    "Strukturschwächeren": "Strukturschwächere",
    "Strullenden": "Strullende",
    "Strullens": "Strullen",
    "Strumpfe": "Strumpf",
    "Strumpfes": "Strumpf",
    "Strumpfs": "Strumpf",
    "Struppige": "struppig",
    "Struppigen": "Struppige",
    "Struppigeren": "Struppigere",
    "Struppigsten": "Struppigste",
    "Struwwelpetern": "Struwwelpeter",
    "Struwwelpeters": "Struwwelpeter",
    "Sträfliche": "sträflich",
    "Sträflichen": "Sträfliche",
    "Strähnen": "Strähne",
    "Strähnige": "strähnig",
    "Strähnigen": "Strähnige",
    "Strände": "Strand",
    "Stränden": "Strand",
    "Sträubenden": "Sträubende",
    "Sträubenderen": "Sträubendere",
    "Sträubendsten": "Sträubendste",
    "Sträubens": "Sträuben",
    "Sträuße": "Strauß",
    "Sträußen": "Strauß",
    "Ströme": "strömen",
    "Strömen": "Strom",
    "Strömenden": "Strömende",
    "Strömens": "Strömen",
    "Strömungen": "Strömung",
    "Strümpfe": "Strumpf",
    "Strümpfen": "Strumpf",
    "Strümpfleins": "Strümpflein",
    "Stuben": "Stube",
    "Stubenreine": "stubenrein",
    "Stubenreinen": "Stubenreine",
    "Stucks": "Stuck",
    "Studente": "Student",
    "Studenten": "Student",
    "Studentes": "Student",
    "Studentinnen": "Studentin",
    "Studentische": "studentisch",
    "Studentischen": "Studentische",
    "Students": "Student",
    "Studien": "Studie",
    "Studienassessore": "Studienassessor",
    "Studienassessoren": "Studienassessor",
    "Studienassessors": "Studienassessor",
    "Studienberatungen": "Studienberatung",
    "Studiendirektore": "Studiendirektor",
    "Studiendirektoren": "Studiendirektor",
    "Studiendirektors": "Studiendirektor",
    "Studienfreunde": "Studienfreund",
    "Studienfreunden": "Studienfreund",
    "Studienfreunds": "Studienfreund",
    "Studierenden": "Studierende",
    "Studierens": "Studieren",
    "Studierte": "studiert",
    "Studierten": "Studierte",
    "Studierteren": "Studiertere",
    "Studiertesten": "Studierteste",
    "Studios": "Studio",
    "Studiums": "Studium",
    "Stufe": "stufen",
    "Stufen": "Stufe",
    "Stufenden": "Stufende",
    "Stufenhecks": "Stufenheck",
    "Stufenlose": "stufenlos",
    "Stufenlosen": "Stufenlose",
    "Stufenloseren": "Stufenlosere",
    "Stufenlosesten": "Stufenloseste",
    "Stufens": "Stufen",
    "Stufigen": "Stufige",
    "Stuhle": "Stuhl",
    "Stuhles": "Stuhl",
    "Stuhls": "Stuhl",
    "Stullen": "Stulle",
    "Stummeln": "Stummel",
    "Stummels": "Stummel",
    "Stummen": "Stumme",
    "Stummeren": "Stummere",
    "Stummfilme": "Stummfilm",
    "Stummfilmen": "Stummfilm",
    "Stummfilms": "Stummfilm",
    "Stummsten": "Stummste",
    "Stumpenn": "Stumpen",
    "Stumpens": "Stumpen",
    "Stumpfenden": "Stumpfende",
    "Stumpfens": "Stumpfen",
    "Stumpfsinnigen": "Stumpfsinnige",
    "Stumpfsinnigeren": "Stumpfsinnigere",
    "Stumpfsinnigsten": "Stumpfsinnigste",
    "Stumpfsinns": "Stumpfsinn",
    "Stumpfwinkeligen": "Stumpfwinkelige",
    "Stunden": "Stunde",
    "Stundenden": "Stundende",
    "Stundenkilometern": "Stundenkilometer",
    "Stundenkilometers": "Stundenkilometer",
    "Stundenlange": "stundenlang",
    "Stundenlangen": "Stundenlange",
    "Stundens": "Stunden",
    "Stundungen": "Stundung",
    "Stunks": "Stunk",
    "Stupide": "stupid",
    "Stupiden": "Stupide",
    "Stupideren": "Stupidere",
    "Stupidesten": "Stupideste",
    "Stupsnasen": "Stupsnase",
    "Sture": "stur",
    "Sturen": "Sture",
    "Stureren": "Sturere",
    "Sturme": "Sturm",
    "Sturmfreien": "Sturmfreie",
    "Sturms": "Sturm",
    "Stursten": "Sturste",
    "Sturze": "Sturz",
    "Sturzes": "Sturz",
    "Sturzs": "Sturz",
    "Stuten": "Stute",
    "Stuttgartern": "Stuttgarter",
    "Stuttgarters": "Stuttgarter",
    "Stuttgarts": "Stuttgart",
    "Stutzenden": "Stutzende",
    "Stutzenderen": "Stutzendere",
    "Stutzendsten": "Stutzendste",
    "Stutzens": "Stutzen",
    "Stutzige": "stutzig",
    "Stutzigen": "Stutzige",
    "Stutzigeren": "Stutzigere",
    "Stutzigsten": "Stutzigste",
    "Styropors": "Styropor",
    "Stäbchens": "Stäbchen",
    "Stäbe": "Stab",
    "Stäben": "Stab",
    "Städeln": "Städel",
    "Städels": "Städel",
    "Städtchens": "Städtchen",
    "Städte": "Stadt",
    "Städtebauliche": "städtebaulich",
    "Städtebaulichen": "Städtebauliche",
    "Städtebunde": "Städtebund",
    "Städtebunds": "Städtebund",
    "Städtebünde": "Städtebund",
    "Städtebünden": "Städtebund",
    "Städten": "Stadt",
    "Städtische": "städtisch",
    "Städtischen": "Städtische",
    "Stählernen": "Stählerne",
    "Stählerneren": "Stählernere",
    "Stählernsten": "Stählernste",
    "Ställchens": "Ställchen",
    "Ställe": "Stall",
    "Ställen": "Stall",
    "Stämme": "Stamm",
    "Stämmen": "Stamm",
    "Stämmige": "stämmig",
    "Stämmigen": "Stämmige",
    "Stämmigeren": "Stämmigere",
    "Stämmigsten": "Stämmigste",
    "Stände": "Stand",
    "Ständen": "Stand",
    "Ständern": "Ständer",
    "Ständers": "Ständer",
    "Ständigen": "Ständige",
    "Stänkernden": "Stänkernde",
    "Stänkernderen": "Stänkerndere",
    "Stänkerndsten": "Stänkerndste",
    "Stänkerns": "Stänkern",
    "Stärkenden": "Stärkende",
    "Stärkenderen": "Stärkendere",
    "Stärkendsten": "Stärkendste",
    "Stärkens": "Stärken",
    "Stärkeren": "Stärkere",
    "Stärksten": "Stärkste",
    "Stärkungen": "Stärkung",
    "Stätten": "Stätte",
    "Stöbernden": "Stöbernde",
    "Stöberns": "Stöbern",
    "Stöckchens": "Stöckchen",
    "Stöcke": "Stock",
    "Stöckeln": "Stöckel",
    "Stöckels": "Stöckel",
    "Stöcken": "Stock",
    "Stöckleins": "Stöcklein",
    "Stöcklis": "Stöckli",
    "Stöhnenden": "Stöhnende",
    "Stöhnenderen": "Stöhnendere",
    "Stöhnendsten": "Stöhnendste",
    "Stöhnens": "Stöhnen",
    "Stöpselnden": "Stöpselnde",
    "Stöpselns": "Stöpseln",
    "Störche": "Storch",
    "Störchen": "Storch",
    "Störenden": "Störende",
    "Störenderen": "Störendere",
    "Störendsten": "Störendste",
    "Störens": "Stören",
    "Störfaktore": "Störfaktor",
    "Störfaktoren": "Störfaktor",
    "Störfaktors": "Störfaktor",
    "Störrischen": "Störrische",
    "Störrischeren": "Störrischere",
    "Störrischsten": "Störrischste",
    "Störsendern": "Störsender",
    "Störsenders": "Störsender",
    "Störstellen": "Störstelle",
    "Störsuchern": "Störsucher",
    "Störsuchers": "Störsucher",
    "Störungen": "Störung",
    "Störungsfreie": "störungsfrei",
    "Störungsfreien": "Störungsfreie",
    "Stöße": "Stoß",
    "Stößen": "Stoß",
    "Stübchens": "Stübchen",
    "Stücke": "Stück",
    "Stückelnden": "Stückelnde",
    "Stückelns": "Stückeln",
    "Stücken": "Stück",
    "Stückes": "Stück",
    "Stückgute": "Stückgut",
    "Stückguts": "Stückgut",
    "Stückgüter": "Stückgut",
    "Stückgütern": "Stückgut",
    "Stücks": "Stück",
    "Stühle": "Stuhl",
    "Stühlen": "Stuhl",
    "Stülpenden": "Stülpende",
    "Stülpens": "Stülpen",
    "Stümmelnden": "Stümmelnde",
    "Stümmelns": "Stümmeln",
    "Stümperhaften": "Stümperhafte",
    "Stümperhafteren": "Stümperhaftere",
    "Stümperhaftesten": "Stümperhafteste",
    "Stümpernden": "Stümpernde",
    "Stümpernderen": "Stümperndere",
    "Stümperndsten": "Stümperndste",
    "Stümperns": "Stümpern",
    "Stündleins": "Stündlein",
    "Stündliche": "stündlich",
    "Stündlichen": "Stündliche",
    "Stürme": "stürmen",
    "Stürmen": "Sturm",
    "Stürmenden": "Stürmende",
    "Stürmens": "Stürmen",
    "Stürmern": "Stürmer",
    "Stürmers": "Stürmer",
    "Stürmischen": "Stürmische",
    "Stürmischeren": "Stürmischere",
    "Stürmischsten": "Stürmischste",
    "Stürze": "stürzen",
    "Stürzen": "Sturz",
    "Stürzenden": "Stürzende",
    "Stürzens": "Stürzen",
    "Stützende": "stützend",
    "Stützenden": "Stützende",
    "Stützendere": "stützend",
    "Stützenderen": "Stützendere",
    "Stützendste": "stützend",
    "Stützendsten": "Stützendste",
    "Stützens": "Stützen",
    "Stützgeweben": "Stützgewebe",
    "Stützgewebes": "Stützgewebe",
    "Stützpunkte": "Stützpunkt",
    "Stützpunkten": "Stützpunkt",
    "Stützpunktes": "Stützpunkt",
    "Stützpunkts": "Stützpunkt",
    "Subatomare": "subatomar",
    "Subatomaren": "Subatomare",
    "Subjekte": "Subjekt",
    "Subjekten": "Subjekt",
    "Subjektes": "Subjekt",
    "Subjektive": "subjektiv",
    "Subjektiven": "Subjektive",
    "Subjektiveren": "Subjektivere",
    "Subjektivsten": "Subjektivste",
    "Subjekts": "Subjekt",
    "Subjunktive": "Subjunktiv",
    "Subjunktiven": "Subjunktiv",
    "Subjunktivs": "Subjunktiv",
    "Subkontinente": "Subkontinent",
    "Subkontinenten": "Subkontinent",
    "Subkontinents": "Subkontinent",
    "Subkulturen": "Subkultur",
    "Submissionen": "Submission",
    "Subordinationen": "Subordination",
    "Subsistenzen": "Subsistenz",
    "Substantielle": "substantiell",
    "Substantiellen": "Substantielle",
    "Substantive": "Substantiv",
    "Substantiven": "Substantiv",
    "Substantivs": "Substantiv",
    "Substanzen": "Substanz",
    "Substituenten": "Substituent",
    "Substituierenden": "Substituierende",
    "Substituierens": "Substituieren",
    "Substituierte": "substituiert",
    "Substituierten": "Substituierte",
    "Substituierungen": "Substituierung",
    "Substitute": "Substitut",
    "Substituten": "Substitut",
    "Substitutes": "Substitut",
    "Substitutinnen": "Substitutin",
    "Substitutionen": "Substitution",
    "Substituts": "Substitut",
    "Subsumierenden": "Subsumierende",
    "Subsumierens": "Subsumieren",
    "Subsumierte": "subsumiert",
    "Subsumierten": "Subsumierte",
    "Subsumtionen": "Subsumtion",
    "Subtile": "subtil",
    "Subtilen": "Subtile",
    "Subtileren": "Subtilere",
    "Subtilsten": "Subtilste",
    "Subtrahierenden": "Subtrahierende",
    "Subtrahierens": "Subtrahieren",
    "Subtrahierte": "subtrahiert",
    "Subtrahierten": "Subtrahierte",
    "Subtraktionen": "Subtraktion",
    "Subtropische": "subtropisch",
    "Subtropischen": "Subtropische",
    "Subunternehmern": "Subunternehmer",
    "Subunternehmers": "Subunternehmer",
    "Subventionen": "Subvention",
    "Subversionen": "Subversion",
    "Suchdienste": "Suchdienst",
    "Suchdiensten": "Suchdienst",
    "Suchdiensts": "Suchdienst",
    "Suche": "suchen",
    "Suchen": "Suche",
    "Suchenden": "Suchende",
    "Suchens": "Suchen",
    "Suchern": "Sucher",
    "Suchers": "Sucher",
    "Suchlisten": "Suchliste",
    "Suchmeldungen": "Suchmeldung",
    "Suchscheinwerfern": "Suchscheinwerfer",
    "Suchscheinwerfers": "Suchscheinwerfer",
    "Suchthaften": "Suchthafte",
    "Suchthafteren": "Suchthaftere",
    "Suchthaftesten": "Suchthafteste",
    "Suchtkranken": "Suchtkranke",
    "Sudanern": "Sudaner",
    "Sudaners": "Sudaner",
    "Sudans": "Sudan",
    "Sudeleien": "Sudelei",
    "Sudelnden": "Sudelnde",
    "Sudelnderen": "Sudelndere",
    "Sudelndsten": "Sudelndste",
    "Sudelns": "Sudeln",
    "Sudetische": "sudetisch",
    "Sudetischen": "Sudetische",
    "Suffigierenden": "Suffigierende",
    "Suffigierens": "Suffigieren",
    "Suffigierte": "suffigiert",
    "Suffigierten": "Suffigierte",
    "Suffs": "Suff",
    "Suggerierenden": "Suggerierende",
    "Suggerierens": "Suggerieren",
    "Suggerierte": "suggeriert",
    "Suggerierten": "Suggerierte",
    "Suggestionen": "Suggestion",
    "Suggestive": "suggestiv",
    "Suggestiven": "Suggestive",
    "Suggestivfragen": "Suggestivfrage",
    "Suhle": "suhlen",
    "Suhlen": "Suhle",
    "Suhlenden": "Suhlende",
    "Suhlens": "Suhlen",
    "Suhrkamps": "Suhrkamp",
    "Suizide": "Suizid",
    "Suiziden": "Suizid",
    "Suizids": "Suizid",
    "Sukzessionen": "Sukzession",
    "Sukzessive": "sukzessiv",
    "Sukzessiven": "Sukzessive",
    "Sukzessore": "Sukzessor",
    "Sukzessoren": "Sukzessor",
    "Sukzessors": "Sukzessor",
    "Sulfate": "Sulfat",
    "Sulfaten": "Sulfat",
    "Sulfats": "Sulfat",
    "Sulfide": "Sulfid",
    "Sulfiden": "Sulfid",
    "Sulfids": "Sulfid",
    "Sultaninnen": "Sultanin",
    "Sulzbachern": "Sulzbacher",
    "Sulzbachers": "Sulzbacher",
    "Sulzbachs": "Sulzbach",
    "Summarischen": "Summarische",
    "Summationen": "Summation",
    "Summen": "Summe",
    "Summierenden": "Summierende",
    "Summierens": "Summieren",
    "Summierte": "summiert",
    "Summierten": "Summierte",
    "Summierungen": "Summierung",
    "Summtone": "Summton",
    "Summtons": "Summton",
    "Summtöne": "Summton",
    "Summtönen": "Summton",
    "Sumpf": "sumpfen",
    "Sumpfblüten": "Sumpfblüte",
    "Sumpfdotterblumen": "Sumpfdotterblume",
    "Sumpfe": "sumpfen",
    "Sumpfenden": "Sumpfende",
    "Sumpfenderen": "Sumpfendere",
    "Sumpfendsten": "Sumpfendste",
    "Sumpfens": "Sumpfen",
    "Sumpfes": "Sumpf",
    "Sumpfigen": "Sumpfige",
    "Sumpfigeren": "Sumpfigere",
    "Sumpfigsten": "Sumpfigste",
    "Sumpflands": "Sumpfland",
    "Sumpfs": "Sumpf",
    "Superintendenten": "Superintendent",
    "Supermarkte": "Supermarkt",
    "Supermarktes": "Supermarkt",
    "Supermarkts": "Supermarkt",
    "Supermärkte": "Supermarkt",
    "Supermärkten": "Supermarkt",
    "Supers": "Super",
    "Suppen": "Suppe",
    "Supplemente": "Supplement",
    "Supplementen": "Supplement",
    "Supplements": "Supplement",
    "Supplementäre": "supplementär",
    "Supplementären": "Supplementäre",
    "Supplikationen": "Supplikation",
    "Supporte": "Support",
    "Supporten": "Support",
    "Supports": "Support",
    "Surjektive": "surjektiv",
    "Surjektiven": "Surjektive",
    "Surrenden": "Surrende",
    "Surrenderen": "Surrendere",
    "Surrendsten": "Surrendste",
    "Surrens": "Surren",
    "Susannes": "Susanne",
    "Suspendierenden": "Suspendierende",
    "Suspendierens": "Suspendieren",
    "Suspendierte": "suspendiert",
    "Suspendierten": "Suspendierte",
    "Sutanellen": "Sutanelle",
    "Sutters": "Sutter",
    "Svens": "Sven",
    "Sweethearts": "Sweetheart",
    "Swing": "swingen",
    "Swingenden": "Swingende",
    "Swingenderen": "Swingendere",
    "Swingendsten": "Swingendste",
    "Swingens": "Swingen",
    "Swings": "Swing",
    "Sylts": "Sylt",
    "Sylvias": "Sylvia",
    "Symbole": "Symbol",
    "Symbolen": "Symbol",
    "Symbolische": "symbolisch",
    "Symbolischen": "Symbolische",
    "Symbolisierenden": "Symbolisierende",
    "Symbolisierens": "Symbolisieren",
    "Symbolisierte": "symbolisiert",
    "Symbolisierten": "Symbolisierte",
    "Symbolisierungen": "Symbolisierung",
    "Symbolisten": "Symbolist",
    "Symbols": "Symbol",
    "Symbolträchtige": "symbolträchtig",
    "Symbolträchtigen": "Symbolträchtige",
    "Symbolträchtigeren": "Symbolträchtigere",
    "Symmetrien": "Symmetrie",
    "Sympathien": "Sympathie",
    "Sympathisanten": "Sympathisant",
    "Sympathische": "sympathisch",
    "Sympathischen": "Sympathische",
    "Sympathischeren": "Sympathischere",
    "Sympathischsten": "Sympathischste",
    "Sympathisierenden": "Sympathisierende",
    "Sympathisierenderen": "Sympathisierendere",
    "Sympathisierens": "Sympathisieren",
    "Sympathisierte": "sympathisiert",
    "Sympathisierten": "Sympathisierte",
    "Symphonien": "Symphonie",
    "Symphonikern": "Symphoniker",
    "Symphonikers": "Symphoniker",
    "Symposien": "Symposium",
    "Symposiums": "Symposium",
    "Symptome": "Symptom",
    "Symptomen": "Symptom",
    "Symptomes": "Symptom",
    "Symptoms": "Symptom",
    "Synagogen": "Synagoge",
    "Syndikate": "Syndikat",
    "Syndikaten": "Syndikat",
    "Syndikates": "Syndikat",
    "Syndikats": "Syndikat",
    "Syndroms": "Syndrom",
    "Synoden": "Synode",
    "Syntagmatische": "syntagmatisch",
    "Syntagmatischen": "Syntagmatische",
    "Syntaktischen": "Syntaktische",
    "Synthesen": "Synthese",
    "Synthetische": "synthetisch",
    "Synthetischen": "Synthetische",
    "Synthetisierenden": "Synthetisierende",
    "Synthetisierenderen": "Synthetisierendere",
    "Synthetisierens": "Synthetisieren",
    "Synthetisierte": "synthetisiert",
    "Synthetisierten": "Synthetisierte",
    "Synthetisierteren": "Synthetisiertere",
    "Synthetisierteste": "synthetisiert",
    "Syrern": "Syrer",
    "Syrers": "Syrer",
    "Syriens": "Syrien",
    "Syrische": "syrisch",
    "Syrischen": "Syrische",
    "Systemanalysen": "Systemanalyse",
    "Systematiken": "Systematik",
    "Systematikern": "Systematiker",
    "Systematikers": "Systematiker",
    "Systematische": "systematisch",
    "Systematischen": "Systematische",
    "Systematischeren": "Systematischere",
    "Systematischsten": "Systematischste",
    "Systematisierenden": "Systematisierende",
    "Systematisierenderen": "Systematisierendere",
    "Systematisierens": "Systematisieren",
    "Systematisierte": "systematisiert",
    "Systematisierten": "Systematisierte",
    "Systematisierteren": "Systematisiertere",
    "Systeme": "System",
    "Systemen": "System",
    "Systemes": "System",
    "Systemkonforme": "systemkonform",
    "Systemkonformen": "Systemkonforme",
    "Systemlosen": "Systemlose",
    "Systems": "System",
    "Szenarien": "Szenarium",
    "Szenarios": "Szenario",
    "Szenariums": "Szenarium",
    "Szenen": "Szene",
    "Szenerien": "Szenerie",
    "Szenische": "szenisch",
    "Szenischen": "Szenische",
    "Szeptern": "Szepter",
    "Szepters": "Szepter",
    "Säbel": "säbeln",
    "Säbeln": "Säbel",
    "Säbelnden": "Säbelnde",
    "Säbelns": "Säbeln",
    "Säbels": "Säbel",
    "Sächliche": "sächlich",
    "Sächlichen": "Sächliche",
    "Sächsische": "sächsisch",
    "Sächsischen": "Sächsische",
    "Säckchens": "Säckchen",
    "Säcke": "Sack",
    "Säcken": "Sack",
    "Säckleins": "Säcklein",
    "Säenden": "Säende",
    "Säens": "Säen",
    "Säftchens": "Säftchen",
    "Säfte": "Saft",
    "Säften": "Saft",
    "Säge": "sägen",
    "Sägebocke": "Sägebock",
    "Sägebocks": "Sägebock",
    "Sägeböcke": "Sägebock",
    "Sägeböcken": "Sägebock",
    "Sägemehle": "Sägemehl",
    "Sägemehlen": "Sägemehl",
    "Sägemehls": "Sägemehl",
    "Sägen": "Säge",
    "Sägende": "sägend",
    "Sägenden": "Sägende",
    "Sägens": "Sägen",
    "Sägereien": "Sägerei",
    "Sägespane": "Sägespan",
    "Sägespanes": "Sägespan",
    "Sägespans": "Sägespan",
    "Sägespäne": "Sägespan",
    "Sägespänen": "Sägespan",
    "Sähen": "sehen",
    "Sähenden": "Sähende",
    "Sähens": "Sähen",
    "Säkulare": "säkular",
    "Säkularen": "Säkulare",
    "Säkularisierenden": "Säkularisierende",
    "Säkularisierenderen": "Säkularisierendere",
    "Säkularisierens": "Säkularisieren",
    "Säkularisierte": "säkularisiert",
    "Säkularisierten": "Säkularisierte",
    "Säkularisierteren": "Säkularisiertere",
    "Säkularisierteste": "säkularisiert",
    "Säle": "Saal",
    "Sälen": "Saal",
    "Sämanns": "Sämann",
    "Sämereien": "Sämerei",
    "Sämtliche": "sämtlich",
    "Sämtlichen": "Sämtliche",
    "Sänftigenden": "Sänftigende",
    "Sänftigenderen": "Sänftigendere",
    "Sänftigendsten": "Sänftigendste",
    "Sänftigens": "Sänftigen",
    "Sängerinnen": "Sängerin",
    "Sängern": "Sänger",
    "Sängers": "Sänger",
    "Särge": "Sarg",
    "Särgen": "Sarg",
    "Särgleins": "Särglein",
    "Sättel": "Sattel",
    "Sättelchens": "Sättelchen",
    "Sätteln": "Sattel",
    "Sättigenden": "Sättigende",
    "Sättigenderen": "Sättigendere",
    "Sättigendsten": "Sättigendste",
    "Sättigens": "Sättigen",
    "Sättigungen": "Sättigung",
    "Sätze": "Satz",
    "Sätzen": "Satz",
    "Säuberliche": "säuberlich",
    "Säuberlichen": "Säuberliche",
    "Säuberlicheren": "Säuberlichere",
    "Säuberlichsten": "Säuberlichste",
    "Säubernden": "Säubernde",
    "Säubernderen": "Säuberndere",
    "Säuberndsten": "Säuberndste",
    "Säuberns": "Säubern",
    "Säuberungen": "Säuberung",
    "Säue": "Sau",
    "Säuen": "Sau",
    "Säuerlichen": "Säuerliche",
    "Säuerlicheren": "Säuerlichere",
    "Säuerlichsten": "Säuerlichste",
    "Säuernde": "säuernd",
    "Säuernden": "Säuernde",
    "Säuerndere": "säuernd",
    "Säuernderen": "Säuerndere",
    "Säuerndste": "säuernd",
    "Säuerndsten": "Säuerndste",
    "Säuerns": "Säuern",
    "Säufern": "Säufer",
    "Säufers": "Säufer",
    "Säugetiere": "Säugetier",
    "Säugetieren": "Säugetier",
    "Säugetiers": "Säugetier",
    "Säuglinge": "Säugling",
    "Säuglingen": "Säugling",
    "Säuglings": "Säugling",
    "Säulchens": "Säulchen",
    "Säuleins": "Säulein",
    "Säulen": "Säule",
    "Säumchens": "Säumchen",
    "Säume": "säumen",
    "Säumen": "Saum",
    "Säumenden": "Säumende",
    "Säumens": "Säumen",
    "Säumigen": "Säumige",
    "Säumigeren": "Säumigere",
    "Säumigsten": "Säumigste",
    "Säumnisse": "Säumnis",
    "Säumnissen": "Säumnis",
    "Säurebeständige": "säurebeständig",
    "Säurebeständigen": "Säurebeständige",
    "Säurebeständigeren": "Säurebeständigere",
    "Säurefesten": "Säurefeste",
    "Säurefesteren": "Säurefestere",
    "Säurefestesten": "Säurefesteste",
    "Säurefreien": "Säurefreie",
    "Säuren": "Säure",
    "Säuselnden": "Säuselnde",
    "Säuselnderen": "Säuselndere",
    "Säuselndsten": "Säuselndste",
    "Säuselns": "Säuseln",
    "Söhne": "söhnen",
    "Söhnen": "Sohn",
    "Söhnenden": "Söhnende",
    "Söhnens": "Söhnen",
    "Söhnleins": "Söhnlein",
    "Söldnern": "Söldner",
    "Söldners": "Söldner",
    "Süchte": "Sucht",
    "Süchten": "Sucht",
    "Süchtigen": "Süchtige",
    "Süchtigeren": "Süchtigere",
    "Süchtigsten": "Süchtigste",
    "Südafrikanischen": "Südafrikanische",
    "Südafrikas": "Südafrika",
    "Südamerikas": "Südamerika",
    "Süddeutsche": "süddeutsch",
    "Süddeutschen": "Süddeutsche",
    "Süde": "Süd",
    "Südene": "Süden",
    "Südens": "Süden",
    "Südes": "Süd",
    "Südhessens": "Südhessen",
    "Südkoreas": "Südkorea",
    "Südlichen": "Südliche",
    "Südlicheren": "Südlichere",
    "Südlichsten": "Südlichste",
    "Südlichte": "Südlicht",
    "Südlichter": "Südlicht",
    "Südlichtern": "Südlicht",
    "Südlichtes": "Südlicht",
    "Südlichts": "Südlicht",
    "Südländern": "Südländer",
    "Südländers": "Südländer",
    "Südländische": "südländisch",
    "Südländischen": "Südländische",
    "Südostens": "Südosten",
    "Südostwinde": "Südostwind",
    "Südostwinden": "Südostwind",
    "Südostwinds": "Südostwind",
    "Süds": "Süd",
    "Südseiten": "Südseite",
    "Südsüdwestens": "Südsüdwesten",
    "Südwestens": "Südwesten",
    "Südwestliche": "südwestlich",
    "Südwestlichen": "Südwestliche",
    "Südwestwinde": "Südwestwind",
    "Südwestwinden": "Südwestwind",
    "Südwestwinds": "Südwestwind",
    "Südöstliche": "südöstlich",
    "Südöstlichen": "Südöstliche",
    "Süffelnden": "Süffelnde",
    "Süffelns": "Süffeln",
    "Süffigen": "Süffige",
    "Süffigeren": "Süffigere",
    "Süffigsten": "Süffigste",
    "Süffisanten": "Süffisante",
    "Süffisanteren": "Süffisantere",
    "Süffisantesten": "Süffisanteste",
    "Sühnegelde": "Sühnegeld",
    "Sühnegelder": "Sühnegeld",
    "Sühnegeldern": "Sühnegeld",
    "Sühnegeldes": "Sühnegeld",
    "Sühnegelds": "Sühnegeld",
    "Sühnen": "Sühne",
    "Sühnenden": "Sühnende",
    "Sühnens": "Sühnen",
    "Sülze": "sülzen",
    "Sülzen": "Sülze",
    "Sülzenden": "Sülzende",
    "Sülzenderen": "Sülzendere",
    "Sülzendsten": "Sülzendste",
    "Sülzens": "Sülzen",
    "Sümmchens": "Sümmchen",
    "Sümpfchens": "Sümpfchen",
    "Sümpfe": "Sumpf",
    "Sümpfen": "Sumpf",
    "Sünden": "Sünde",
    "Sündenbocke": "Sündenbock",
    "Sündenbocks": "Sündenbock",
    "Sündenböcke": "Sündenbock",
    "Sündenböcken": "Sündenbock",
    "Sündern": "Sünder",
    "Sünders": "Sünder",
    "Sündhafte": "sündhaft",
    "Sündhaften": "Sündhafte",
    "Sündhafteren": "Sündhaftere",
    "Sündhaftesten": "Sündhafteste",
    "Sündige": "sündigen",
    "Sündigen": "Sündige",
    "Sündigenden": "Sündigende",
    "Sündigenderen": "Sündigendere",
    "Sündigendsten": "Sündigendste",
    "Sündigens": "Sündigen",
    "Sündigeren": "Sündigere",
    "Sündigsten": "Sündigste",
    "Süppchens": "Süppchen",
    "Süppleins": "Süpplein",
    "Süssmuths": "Süssmuth",
    "Süße": "süßen",
    "Süßen": "Süße",
    "Süßenden": "Süßende",
    "Süßenderen": "Süßendere",
    "Süßendsten": "Süßendste",
    "Süßens": "Süßen",
    "Süßeren": "Süßere",
    "Süßesten": "Süßeste",
    "Süßholzrasplern": "Süßholzraspler",
    "Süßholzrasplers": "Süßholzraspler",
    "Süßigkeiten": "Süßigkeit",
    "Süßkartoffeln": "Süßkartoffel",
    "Süßkirschen": "Süßkirsche",
    "Süßklees": "Süßklee",
    "Süßliche": "süßlich",
    "Süßlichen": "Süßliche",
    "Süßlicheren": "Süßlichere",
    "Süßlichsten": "Süßlichste",
    "Süßmostereien": "Süßmosterei",
    "Süßsaure": "süßsauer",
    "Süßsauren": "Süßsaure",
    "Süßspeisen": "Süßspeise",
    "Süßstoffe": "Süßstoff",
    "Süßstoffen": "Süßstoff",
    "Süßstoffs": "Süßstoff",
    "Süßwaren": "Süßware",
    "Süßwassers": "Süßwasser",
    "TUs": "TU",
    "Tabake": "Tabak",
    "Tabaken": "Tabak",
    "Tabakes": "Tabak",
    "Tabaks": "Tabak",
    "Tabalugas": "Tabaluga",
    "Tabellarische": "tabellarisch",
    "Tabellarischen": "Tabellarische",
    "Tabellarisierenden": "Tabellarisierende",
    "Tabellarisierenderen": "Tabellarisierendere",
    "Tabellarisierens": "Tabellarisieren",
    "Tabellarisierte": "tabellarisiert",
    "Tabellarisierten": "Tabellarisierte",
    "Tabellarisierteren": "Tabellarisiertere",
    "Tabellen": "Tabelle",
    "Tabellierenden": "Tabellierende",
    "Tabellierenderen": "Tabellierendere",
    "Tabellierendsten": "Tabellierendste",
    "Tabellierens": "Tabellieren",
    "Tabellierte": "tabelliert",
    "Tabellierten": "Tabellierte",
    "Tabellierteren": "Tabelliertere",
    "Tabelliertesten": "Tabellierteste",
    "Tabletten": "Tablette",
    "Tabuierenden": "Tabuierende",
    "Tabuierenderen": "Tabuierendere",
    "Tabuierendsten": "Tabuierendste",
    "Tabuierens": "Tabuieren",
    "Tabuierte": "tabuiert",
    "Tabuierten": "Tabuierte",
    "Tabuierteren": "Tabuiertere",
    "Tabuiertesten": "Tabuierteste",
    "Tabulatore": "Tabulator",
    "Tabulatoren": "Tabulator",
    "Tabulators": "Tabulator",
    "Tabus": "Tabu",
    "Tachometers": "Tachometer",
    "Tachos": "Tacho",
    "Tachömeter": "Tachometer",
    "Tachömetern": "Tachometer",
    "Tadel": "tadeln",
    "Tadellosen": "Tadellose",
    "Tadelloseren": "Tadellosere",
    "Tadellosesten": "Tadelloseste",
    "Tadeln": "Tadel",
    "Tadelnden": "Tadelnde",
    "Tadelnderen": "Tadelndere",
    "Tadelndsten": "Tadelndste",
    "Tadelns": "Tadeln",
    "Tadels": "Tadel",
    "Tafeln": "Tafel",
    "Tafelrunden": "Tafelrunde",
    "Tag": "tagen",
    "Tage": "tagen",
    "Tagen": "Tag",
    "Tagenden": "Tagende",
    "Tagenderen": "Tagendere",
    "Tagendsten": "Tagendste",
    "Tagens": "Tagen",
    "Tages": "Tag",
    "Tagfaltern": "Tagfalter",
    "Tagfalters": "Tagfalter",
    "Tags": "Tag",
    "Tagtäglichen": "Tagtägliche",
    "Tagungen": "Tagung",
    "Taillen": "Taille",
    "Taiwans": "Taiwan",
    "Takelnden": "Takelnde",
    "Takelns": "Takeln",
    "Takte": "Takt",
    "Takten": "Takt",
    "Taktes": "Takt",
    "Taktierenden": "Taktierende",
    "Taktierenderen": "Taktierendere",
    "Taktierendsten": "Taktierendste",
    "Taktierens": "Taktieren",
    "Taktierte": "taktiert",
    "Taktierten": "Taktierte",
    "Taktierteren": "Taktiertere",
    "Taktiertesten": "Taktierteste",
    "Taktiken": "Taktik",
    "Taktische": "taktisch",
    "Taktischen": "Taktische",
    "Taktlosen": "Taktlose",
    "Taktloseren": "Taktlosere",
    "Taktlosesten": "Taktloseste",
    "Taktlosigkeiten": "Taktlosigkeit",
    "Takts": "Takt",
    "Tale": "Tal",
    "Talente": "Talent",
    "Talenten": "Talent",
    "Talentes": "Talent",
    "Talentierte": "talentiert",
    "Talentierten": "Talentierte",
    "Talentierteren": "Talentiertere",
    "Talentiertesten": "Talentierteste",
    "Talents": "Talent",
    "Talern": "Taler",
    "Talers": "Taler",
    "Tales": "Tal",
    "Talge": "Talg",
    "Talgen": "Talg",
    "Talges": "Talg",
    "Talgs": "Talg",
    "Talismane": "Talisman",
    "Talismanen": "Talisman",
    "Talismans": "Talisman",
    "Taljen": "Talje",
    "Talks": "Talk",
    "Tals": "Tal",
    "Tamilische": "tamilisch",
    "Tamilischen": "Tamilische",
    "Tamponierenden": "Tamponierende",
    "Tamponierens": "Tamponieren",
    "Tamponierte": "tamponiert",
    "Tamponierten": "Tamponierte",
    "Tandems": "Tandem",
    "Tangenten": "Tangente",
    "Tangentiale": "tangential",
    "Tangentialebenen": "Tangentialebene",
    "Tangentialen": "Tangentiale",
    "Tangierenden": "Tangierende",
    "Tangierens": "Tangieren",
    "Tangierte": "tangiert",
    "Tangierten": "Tangierte",
    "Tangos": "Tango",
    "Tank": "tanken",
    "Tankenden": "Tankende",
    "Tankens": "Tanken",
    "Tankern": "Tanker",
    "Tankers": "Tanker",
    "Tanks": "Tank",
    "Tankstellen": "Tankstelle",
    "Tankwagens": "Tankwagen",
    "Tankwarte": "Tankwart",
    "Tankwarten": "Tankwart",
    "Tankwarts": "Tankwart",
    "Tannen": "Tanne",
    "Tannenzapfens": "Tannenzapfen",
    "Tantchens": "Tantchen",
    "Tanten": "Tante",
    "Tanz": "tanzen",
    "Tanzbegeisterte": "tanzbegeistert",
    "Tanzbegeisterten": "Tanzbegeisterte",
    "Tanzbegeisterteren": "Tanzbegeistertere",
    "Tanze": "tanzen",
    "Tanzenden": "Tanzende",
    "Tanzens": "Tanzen",
    "Tanzes": "Tanz",
    "Tanzkapellen": "Tanzkapelle",
    "Tanzlehrern": "Tanzlehrer",
    "Tanzlehrers": "Tanzlehrer",
    "Tanzlustige": "tanzlustig",
    "Tanzlustigen": "Tanzlustige",
    "Tanzlustigeren": "Tanzlustigere",
    "Tanzlustigsten": "Tanzlustigste",
    "Tanzplatten": "Tanzplatte",
    "Tanzschulen": "Tanzschule",
    "Tapernden": "Tapernde",
    "Tapernderen": "Taperndere",
    "Taperndsten": "Taperndste",
    "Taperns": "Tapern",
    "Tapeten": "Tapete",
    "Tapezierenden": "Tapezierende",
    "Tapezierens": "Tapezieren",
    "Tapezierte": "tapeziert",
    "Tapezierten": "Tapezierte",
    "Tapferen": "Tapfere",
    "Tapfereren": "Tapferere",
    "Tapfersten": "Tapferste",
    "Tappenden": "Tappende",
    "Tappens": "Tappen",
    "Tapsenden": "Tapsende",
    "Tapsenderen": "Tapsendere",
    "Tapsendsten": "Tapsendste",
    "Tapsens": "Tapsen",
    "Tapsigen": "Tapsige",
    "Tarierenden": "Tarierende",
    "Tarierens": "Tarieren",
    "Tarierte": "tariert",
    "Tarierten": "Tarierte",
    "Tarife": "Tarif",
    "Tarifen": "Tarif",
    "Tarifes": "Tarif",
    "Tarifliche": "tariflich",
    "Tariflichen": "Tarifliche",
    "Tarifs": "Tarif",
    "Tarnenden": "Tarnende",
    "Tarnenderen": "Tarnendere",
    "Tarnendsten": "Tarnendste",
    "Tarnens": "Tarnen",
    "Tartare": "Tartar",
    "Tartaren": "Tartar",
    "Tartars": "Tartar",
    "Taschen": "Tasche",
    "Tassen": "Tasse",
    "Tastaturen": "Tastatur",
    "Taste": "tasten",
    "Tastempfindungen": "Tastempfindung",
    "Tasten": "Taste",
    "Tastenden": "Tastende",
    "Tastens": "Tasten",
    "Taten": "tun",
    "Tatendurstigen": "Tatendurstige",
    "Tatendurstigeren": "Tatendurstigere",
    "Tatendurstigsten": "Tatendurstigste",
    "Tatenlosen": "Tatenlose",
    "Tatkräftigen": "Tatkräftige",
    "Tatsachen": "Tatsache",
    "Tatschen": "Tatsche",
    "Tatschenden": "Tatschende",
    "Tatschens": "Tatschen",
    "Tatsächliche": "tatsächlich",
    "Tatsächlichen": "Tatsächliche",
    "Tatteriche": "Tatterich",
    "Tatterichen": "Tatterich",
    "Tatterichs": "Tatterich",
    "Tatterige": "tatterig",
    "Tatterigen": "Tatterige",
    "Tatterigeren": "Tatterigere",
    "Tatterigsten": "Tatterigste",
    "Tatzen": "Tatze",
    "Tau": "tauen",
    "Taube": "taub",
    "Tauben": "Taube",
    "Tauber": "taub",
    "Tauberbischofsheims": "Tauberbischofsheim",
    "Taubertals": "Taubertal",
    "Taubstummen": "Taubstumme",
    "Taubstummenschulen": "Taubstummenschule",
    "Tauchenden": "Tauchende",
    "Tauchens": "Tauchen",
    "Tauchenten": "Tauchente",
    "Tauchern": "Taucher",
    "Tauchers": "Taucher",
    "Tauchgruppen": "Tauchgruppe",
    "Tauchkolbens": "Tauchkolben",
    "Tauchsiedern": "Tauchsieder",
    "Tauchsieders": "Tauchsieder",
    "Tauenden": "Tauende",
    "Tauens": "Tauen",
    "Taufen": "Taufe",
    "Taufenden": "Taufende",
    "Taufens": "Taufen",
    "Taufnamen": "Taufname",
    "Taufpatinnen": "Taufpatin",
    "Taufregistern": "Taufregister",
    "Taufregisters": "Taufregister",
    "Taufrische": "taufrisch",
    "Taufrischen": "Taufrische",
    "Taufscheine": "Taufschein",
    "Taufscheinen": "Taufschein",
    "Taufscheins": "Taufschein",
    "Taufspruche": "Taufspruch",
    "Taufspruchs": "Taufspruch",
    "Taufsprüche": "Taufspruch",
    "Taufsprüchen": "Taufspruch",
    "Taufsteine": "Taufstein",
    "Taufsteinen": "Taufstein",
    "Taufsteins": "Taufstein",
    "Taufwassers": "Taufwasser",
    "Taufzeuginnen": "Taufzeugin",
    "Taugenden": "Taugende",
    "Taugenderen": "Taugendere",
    "Taugendsten": "Taugendste",
    "Taugens": "Taugen",
    "Tauglichen": "Taugliche",
    "Tauglicheren": "Tauglichere",
    "Tauglichkeiten": "Tauglichkeit",
    "Tauglichste": "tauglich",
    "Tauglichsten": "Tauglichste",
    "Taumeligen": "Taumelige",
    "Taumeligeren": "Taumeligere",
    "Taumeligsten": "Taumeligste",
    "Taumelnden": "Taumelnde",
    "Taumelnderen": "Taumelndere",
    "Taumelndsten": "Taumelndste",
    "Taumelns": "Taumeln",
    "Taus": "Tau",
    "Tausch": "tauschen",
    "Tausche": "tauschen",
    "Tauschen": "Tausch",
    "Tauschenden": "Tauschende",
    "Tauschens": "Tauschen",
    "Tauschs": "Tausch",
    "Tauschwerts": "Tauschwert",
    "Tausendblatts": "Tausendblatt",
    "Tausenden": "Tausende",
    "Tausendern": "Tausender",
    "Tausenders": "Tausender",
    "Tausendfache": "tausendfach",
    "Tausendfachen": "Tausendfache",
    "Tausendjahrfeiern": "Tausendjahrfeier",
    "Tausendjährige": "tausendjährig",
    "Tausendjährigen": "Tausendjährige",
    "Tausendschöne": "Tausendschön",
    "Tausendschönen": "Tausendschön",
    "Tausendschöns": "Tausendschön",
    "Tausendsteln": "Tausendstel",
    "Tausendstels": "Tausendstel",
    "Tautologien": "Tautologie",
    "Tautologische": "tautologisch",
    "Tautologischen": "Tautologische",
    "Tauwetters": "Tauwetter",
    "Taxametern": "Taxameter",
    "Taxameters": "Taxameter",
    "Taxationen": "Taxation",
    "Taxen": "Taxi",
    "Taxierenden": "Taxierende",
    "Taxierens": "Taxieren",
    "Taxierte": "taxiert",
    "Taxierten": "Taxierte",
    "Taxis": "Taxi",
    "Taxonomische": "taxonomisch",
    "Taxonomischen": "Taxonomische",
    "Taylors": "Taylor",
    "Teams": "Team",
    "Technicolors": "Technicolor",
    "Techniken": "Technik",
    "Technikern": "Techniker",
    "Technikers": "Techniker",
    "Technische": "technisch",
    "Technischen": "Technische",
    "Technischeren": "Technischere",
    "Technischsten": "Technischste",
    "Technisierenden": "Technisierende",
    "Technisierenderen": "Technisierendere",
    "Technisierendsten": "Technisierendste",
    "Technisierens": "Technisieren",
    "Technisierte": "technisiert",
    "Technisierten": "Technisierte",
    "Technisierteren": "Technisiertere",
    "Technisiertesten": "Technisierteste",
    "Technisierungen": "Technisierung",
    "Technokraten": "Technokrat",
    "Technokratische": "technokratisch",
    "Technokratischen": "Technokratische",
    "Technologien": "Technologie",
    "Technologische": "technologisch",
    "Technologischen": "Technologische",
    "Techtelmechteln": "Techtelmechtel",
    "Techtelmechtels": "Techtelmechtel",
    "Teddybären": "Teddybär",
    "Teddys": "Teddy",
    "Teds": "Ted",
    "Teenagern": "Teenager",
    "Teenagers": "Teenager",
    "Teer": "teeren",
    "Teere": "teeren",
    "Teeren": "Teer",
    "Teerenden": "Teerende",
    "Teerenderen": "Teerendere",
    "Teerendsten": "Teerendste",
    "Teerens": "Teeren",
    "Teeres": "Teer",
    "Teers": "Teer",
    "Tees": "Tee",
    "Tegels": "Tegel",
    "Teherans": "Teheran",
    "Teiche": "Teich",
    "Teichen": "Teich",
    "Teiches": "Teich",
    "Teichfrosche": "Teichfrosch",
    "Teichfroschs": "Teichfrosch",
    "Teichfrösche": "Teichfrosch",
    "Teichfröschen": "Teichfrosch",
    "Teichs": "Teich",
    "Teige": "Teig",
    "Teigen": "Teig",
    "Teiges": "Teig",
    "Teigs": "Teig",
    "Teil": "teilen",
    "Teilbare": "teilbar",
    "Teilbaren": "Teilbare",
    "Teile": "teilen",
    "Teilen": "Teil",
    "Teilenden": "Teilende",
    "Teilens": "Teilen",
    "Teilerfolge": "Teilerfolg",
    "Teilerfolgen": "Teilerfolg",
    "Teilerfolgs": "Teilerfolg",
    "Teilerfremde": "teilerfremd",
    "Teilerfremden": "Teilerfremde",
    "Teiles": "Teil",
    "Teilgenommenen": "Teilgenommene",
    "Teilhaftigen": "Teilhaftige",
    "Teilnahmen": "teilnehmen",
    "Teilnahmslosen": "Teilnahmslose",
    "Teilnehmenden": "Teilnehmende",
    "Teilnehmenderen": "Teilnehmendere",
    "Teilnehmendsten": "Teilnehmendste",
    "Teilnehmens": "Teilnehmen",
    "Teilnehmerinnen": "Teilnehmerin",
    "Teilnehmern": "Teilnehmer",
    "Teilnehmers": "Teilnehmer",
    "Teilpunkte": "Teilpunkt",
    "Teilpunkten": "Teilpunkt",
    "Teilpunkts": "Teilpunkt",
    "Teils": "Teil",
    "Teilungen": "Teilung",
    "Teilweise": "teilweis",
    "Teilweisen": "Teilweise",
    "Teilzahlungen": "Teilzahlung",
    "Tekknos": "Tekkno",
    "Telediscs": "Teledisc",
    "Telefone": "Telefon",
    "Telefonen": "Telefon",
    "Telefones": "Telefon",
    "Telefonierenden": "Telefonierende",
    "Telefonierens": "Telefonieren",
    "Telefonierte": "telefoniert",
    "Telefonierten": "Telefonierte",
    "Telefonischen": "Telefonische",
    "Telefonisten": "Telefonist",
    "Telefons": "Telefon",
    "Telegene": "telegen",
    "Telegenen": "Telegene",
    "Telegeneren": "Telegenere",
    "Telegensten": "Telegenste",
    "Telegramme": "Telegramm",
    "Telegrammen": "Telegramm",
    "Telegrammes": "Telegramm",
    "Telegramms": "Telegramm",
    "Telekinesen": "Telekinese",
    "Telekollegs": "Telekolleg",
    "Telekommunikationen": "Telekommunikation",
    "Telekonferenzen": "Telekonferenz",
    "Telekopierern": "Telekopierer",
    "Telekopierers": "Telekopierer",
    "Telemarks": "Telemark",
    "Teleobjektive": "Teleobjektiv",
    "Teleobjektiven": "Teleobjektiv",
    "Teleobjektivs": "Teleobjektiv",
    "Telepathen": "Telepath",
    "Telephone": "Telephon",
    "Telephonen": "Telephon",
    "Telephons": "Telephon",
    "Teleskope": "Teleskop",
    "Teleskopen": "Teleskop",
    "Teleskopes": "Teleskop",
    "Teleskops": "Teleskop",
    "Tellern": "Teller",
    "Tellers": "Teller",
    "Tempeln": "Tempel",
    "Tempels": "Tempel",
    "Tempelsees": "Tempelsee",
    "Temperamente": "Temperament",
    "Temperamenten": "Temperament",
    "Temperamentlose": "temperamentlos",
    "Temperamentlosen": "Temperamentlose",
    "Temperamentloseren": "Temperamentlosere",
    "Temperaments": "Temperament",
    "Temperamentvolle": "temperamentvoll",
    "Temperamentvollen": "Temperamentvolle",
    "Temperamentvolleren": "Temperamentvollere",
    "Temperaturbeständigen": "Temperaturbeständige",
    "Temperaturbeständigeren": "Temperaturbeständigere",
    "Temperaturen": "Temperatur",
    "Temperierenden": "Temperierende",
    "Temperierenderen": "Temperierendere",
    "Temperierendsten": "Temperierendste",
    "Temperierens": "Temperieren",
    "Temperierte": "temperiert",
    "Temperierten": "Temperierte",
    "Temperierteren": "Temperiertere",
    "Temperiertesten": "Temperierteste",
    "Tempora": "Tempus",
    "Temporale": "temporal",
    "Temporalen": "Temporale",
    "Temporären": "Temporäre",
    "Tempos": "Tempo",
    "Tempotaschentuche": "Tempotaschentuch",
    "Tempotaschentuchs": "Tempotaschentuch",
    "Tempotaschentücher": "Tempotaschentuch",
    "Tempotaschentüchern": "Tempotaschentuch",
    "Tendenzen": "Tendenz",
    "Tendenzielle": "tendenziell",
    "Tendenziellen": "Tendenzielle",
    "Tendenziösen": "Tendenziöse",
    "Tendierenden": "Tendierende",
    "Tendierens": "Tendieren",
    "Tendierte": "tendiert",
    "Tendierten": "Tendierte",
    "Tenoralen": "Tenorale",
    "Tenore": "Tenor",
    "Tenores": "Tenor",
    "Tenors": "Tenor",
    "Tensiometern": "Tensiometer",
    "Tensiometers": "Tensiometer",
    "Tenöre": "Tenor",
    "Tenören": "Tenor",
    "Teppiche": "Teppich",
    "Teppichen": "Teppich",
    "Teppiches": "Teppich",
    "Teppichs": "Teppich",
    "Terassen": "Terasse",
    "Terbutylazins": "Terbutylazin",
    "Terminale": "terminal",
    "Terminalen": "Terminale",
    "Terminationen": "Termination",
    "Termine": "Termin",
    "Terminen": "Termin",
    "Termingemäße": "termingemäß",
    "Termingemäßen": "Termingemäße",
    "Termini": "Terminus",
    "Terminierenden": "Terminierende",
    "Terminierens": "Terminieren",
    "Terminierte": "terminiert",
    "Terminierten": "Terminierte",
    "Terminologien": "Terminologie",
    "Terminologische": "terminologisch",
    "Terminologischen": "Terminologische",
    "Termins": "Termin",
    "Termiten": "Termite",
    "Ternen": "Terne",
    "Terpentine": "Terpentin",
    "Terpentinen": "Terpentin",
    "Terpentins": "Terpentin",
    "Terrains": "Terrain",
    "Terrassen": "Terrasse",
    "Terriern": "Terrier",
    "Terriers": "Terrier",
    "Terrines": "Terrine",
    "Territoriale": "territorial",
    "Territorialen": "Territoriale",
    "Territorien": "Territorium",
    "Territoriums": "Territorium",
    "Terrorisiere": "terrorisieren",
    "Terrorisierenden": "Terrorisierende",
    "Terrorisierenderen": "Terrorisierendere",
    "Terrorisierens": "Terrorisieren",
    "Terrorisierte": "terrorisiert",
    "Terrorisierten": "Terrorisierte",
    "Terrorisierteren": "Terrorisiertere",
    "Terrorisiertesten": "Terrorisierteste",
    "Terroristen": "Terrorist",
    "Terroristinnen": "Terroristin",
    "Terroristische": "terroristisch",
    "Terroristischen": "Terroristische",
    "Terrors": "Terror",
    "Tertiäre": "tertiär",
    "Tertiären": "Tertiäre",
    "Terzette": "Terzett",
    "Terzetten": "Terzett",
    "Terzetts": "Terzett",
    "Tesafilme": "Tesafilm",
    "Tesafilmen": "Tesafilm",
    "Tesafilmes": "Tesafilm",
    "Tesafilms": "Tesafilm",
    "Testamentarische": "testamentarisch",
    "Testamentarischen": "Testamentarische",
    "Testamente": "Testament",
    "Testamenten": "Testament",
    "Testamentes": "Testament",
    "Testaments": "Testament",
    "Testate": "Testat",
    "Testaten": "Testat",
    "Testatore": "Testator",
    "Testatoren": "Testator",
    "Testators": "Testator",
    "Testats": "Testat",
    "Testenden": "Testende",
    "Testens": "Testen",
    "Testern": "Tester",
    "Testers": "Tester",
    "Testfalle": "Testfall",
    "Testfalls": "Testfall",
    "Testfälle": "Testfall",
    "Testfällen": "Testfall",
    "Testierenden": "Testierende",
    "Testierens": "Testieren",
    "Testierte": "testiert",
    "Testierten": "Testierte",
    "Tests": "Test",
    "Teuerste": "teuer",
    "Teuersten": "Teuerste",
    "Teuerungen": "Teuerung",
    "Teuerungsraten": "Teuerungsrate",
    "Teufeleien": "Teufelei",
    "Teufelinnen": "Teufelin",
    "Teufeln": "Teufel",
    "Teufels": "Teufel",
    "Teuflische": "teuflisch",
    "Teuflischen": "Teuflische",
    "Teuflischeren": "Teuflischere",
    "Teuflischsten": "Teuflischste",
    "Teuren": "Teure",
    "Teureren": "Teurere",
    "Teutonischen": "Teutonische",
    "Texte": "texten",
    "Texten": "Text",
    "Textenden": "Textende",
    "Textens": "Texten",
    "Textern": "Texter",
    "Texters": "Texter",
    "Textes": "Text",
    "Textkorpora": "Textkorpus",
    "Texts": "Text",
    "Texturen": "Textur",
    "Thailands": "Thailand",
    "Thatchers": "Thatcher",
    "Theatern": "Theater",
    "Theaters": "Theater",
    "Theken": "Theke",
    "Themas": "Thema",
    "Thematische": "thematisch",
    "Thematischen": "Thematische",
    "Thematisierenden": "Thematisierende",
    "Thematisierens": "Thematisieren",
    "Thematisierte": "thematisiert",
    "Thematisierten": "Thematisierte",
    "Themen": "Thema",
    "Theodors": "Theodor",
    "Theologen": "Theologe",
    "Theologische": "theologisch",
    "Theologischen": "Theologische",
    "Theoreme": "Theorem",
    "Theoremen": "Theorem",
    "Theorems": "Theorem",
    "Theoretikern": "Theoretiker",
    "Theoretikers": "Theoretiker",
    "Theoretische": "theoretisch",
    "Theoretischen": "Theoretische",
    "Theoretischeren": "Theoretischere",
    "Theoretischsten": "Theoretischste",
    "Theoretisierenden": "Theoretisierende",
    "Theoretisierens": "Theoretisieren",
    "Theoretisierte": "theoretisiert",
    "Theoretisierten": "Theoretisierte",
    "Theorien": "Theorie",
    "Theos": "Theo",
    "Therapeuten": "Therapeut",
    "Therapeutinnen": "Therapeutin",
    "Therapeutische": "therapeutisch",
    "Therapeutischen": "Therapeutische",
    "Therapien": "Therapie",
    "Therapierenden": "Therapierende",
    "Therapierenderen": "Therapierendere",
    "Therapierendsten": "Therapierendste",
    "Therapierens": "Therapieren",
    "Therapierte": "therapiert",
    "Therapierten": "Therapierte",
    "Therapierteren": "Therapiertere",
    "Therapiertesten": "Therapierteste",
    "Theresienstadts": "Theresienstadt",
    "Thermalbade": "Thermalbad",
    "Thermalbades": "Thermalbad",
    "Thermalbads": "Thermalbad",
    "Thermalbäder": "Thermalbad",
    "Thermalbädern": "Thermalbad",
    "Thermale": "thermal",
    "Thermalen": "Thermale",
    "Thermalquellen": "Thermalquelle",
    "Thermen": "Therme",
    "Thermische": "thermisch",
    "Thermischen": "Thermische",
    "Thermodynamischen": "Thermodynamische",
    "Thermogramme": "Thermogramm",
    "Thermogrammen": "Thermogramm",
    "Thermogramms": "Thermogramm",
    "Thermographen": "Thermograph",
    "Thermohosen": "Thermohose",
    "Thermometern": "Thermometer",
    "Thermometers": "Thermometer",
    "Thermorezeptore": "Thermorezeptor",
    "Thermorezeptoren": "Thermorezeptor",
    "Thermorezeptors": "Thermorezeptor",
    "Thermotherapien": "Thermotherapie",
    "Thesaurierenden": "Thesaurierende",
    "Thesaurierens": "Thesaurieren",
    "Thesaurierte": "thesauriert",
    "Thesaurierten": "Thesaurierte",
    "Thesen": "These",
    "Thierses": "Thierse",
    "Thomas": "Thoma",
    "Thoms": "Thom",
    "Thons": "Thon",
    "Thorstens": "Thorsten",
    "Thrillern": "Thriller",
    "Thrillers": "Thriller",
    "Thrombosen": "Thrombose",
    "Thrombotische": "thrombotisch",
    "Thrombotischen": "Thrombotische",
    "Thrombozytolysen": "Thrombozytolyse",
    "Thrombozytosen": "Thrombozytose",
    "Thron": "thronen",
    "Thronen": "Thron",
    "Thronenden": "Thronende",
    "Thronens": "Thronen",
    "Thronfolgern": "Thronfolger",
    "Thronfolgers": "Thronfolger",
    "Throns": "Thron",
    "Thunfische": "Thunfisch",
    "Thunfischen": "Thunfisch",
    "Thunfisches": "Thunfisch",
    "Thunfischs": "Thunfisch",
    "Thyssens": "Thyssen",
    "Thüringens": "Thüringen",
    "Thüringern": "Thüringer",
    "Thüringers": "Thüringer",
    "Thüringische": "thüringisch",
    "Thüringischen": "Thüringische",
    "Tibetanern": "Tibetaner",
    "Tibetaners": "Tibetaner",
    "Tibetanische": "tibetanisch",
    "Tibetanischen": "Tibetanische",
    "Ticks": "Tick",
    "Tiefbaue": "Tiefbau",
    "Tiefbaues": "Tiefbau",
    "Tiefbaus": "Tiefbau",
    "Tiefbetrübte": "tiefbetrübt",
    "Tiefbetrübten": "Tiefbetrübte",
    "Tiefbewegten": "Tiefbewegte",
    "Tiefbohrern": "Tiefbohrer",
    "Tiefbohrers": "Tiefbohrer",
    "Tiefe": "tief",
    "Tiefen": "Tiefe",
    "Tieferen": "Tiefere",
    "Tieffluge": "Tiefflug",
    "Tiefflugs": "Tiefflug",
    "Tiefflüge": "Tiefflug",
    "Tiefflügen": "Tiefflug",
    "Tiefgangs": "Tiefgang",
    "Tiefgefrorene": "tiefgefroren",
    "Tiefgefrorenen": "Tiefgefrorene",
    "Tiefgehenden": "Tiefgehende",
    "Tiefgehenderen": "Tiefgehendere",
    "Tiefgehendsten": "Tiefgehendste",
    "Tiefgekühlten": "Tiefgekühlte",
    "Tiefgreifenden": "Tiefgreifende",
    "Tiefgreifenderen": "Tiefgreifendere",
    "Tiefgreifendsten": "Tiefgreifendste",
    "Tiefgründigen": "Tiefgründige",
    "Tiefgründigeren": "Tiefgründigere",
    "Tiefgründigsten": "Tiefgründigste",
    "Tiefkühlfache": "Tiefkühlfach",
    "Tiefkühlfaches": "Tiefkühlfach",
    "Tiefkühlfachs": "Tiefkühlfach",
    "Tiefkühlfächer": "Tiefkühlfach",
    "Tiefkühlfächern": "Tiefkühlfach",
    "Tiefkühltruhen": "Tiefkühltruhe",
    "Tiefkühlungen": "Tiefkühlung",
    "Tiefladern": "Tieflader",
    "Tiefladers": "Tieflader",
    "Tieflands": "Tiefland",
    "Tiefpunkte": "Tiefpunkt",
    "Tiefpunkten": "Tiefpunkt",
    "Tiefpunkts": "Tiefpunkt",
    "Tiefs": "Tief",
    "Tiefschlafe": "Tiefschlaf",
    "Tiefschlafes": "Tiefschlaf",
    "Tiefschlafs": "Tiefschlaf",
    "Tiefschlage": "Tiefschlag",
    "Tiefschlags": "Tiefschlag",
    "Tiefschläge": "Tiefschlag",
    "Tiefschlägen": "Tiefschlag",
    "Tiefschwarzen": "Tiefschwarze",
    "Tiefschürfende": "tiefschürfend",
    "Tiefschürfenden": "Tiefschürfende",
    "Tiefsinnigen": "Tiefsinnige",
    "Tiefsinnigeren": "Tiefsinnigere",
    "Tiefsinnigsten": "Tiefsinnigste",
    "Tiefsinns": "Tiefsinn",
    "Tiefstande": "Tiefstand",
    "Tiefstands": "Tiefstand",
    "Tiefste": "tief",
    "Tiefsten": "Tiefste",
    "Tiefstrahlern": "Tiefstrahler",
    "Tiefstrahlers": "Tiefstrahler",
    "Tiefstände": "Tiefstand",
    "Tiefständen": "Tiefstand",
    "Tieftraurige": "tieftraurig",
    "Tieftraurigen": "Tieftraurige",
    "Tiegeln": "Tiegel",
    "Tiegels": "Tiegel",
    "Tiere": "Tier",
    "Tieren": "Tier",
    "Tieres": "Tier",
    "Tierische": "tierisch",
    "Tierischen": "Tierische",
    "Tierischeren": "Tierischere",
    "Tierischsten": "Tierischste",
    "Tierliebenden": "Tierliebende",
    "Tierliebenderen": "Tierliebendere",
    "Tierliebendsten": "Tierliebendste",
    "Tiers": "Tier",
    "Tierärztliche": "tierärztlich",
    "Tierärztlichen": "Tierärztliche",
    "Tiger": "tigern",
    "Tigerinnen": "Tigerin",
    "Tigern": "Tiger",
    "Tigernden": "Tigernde",
    "Tigerns": "Tigern",
    "Tigers": "Tiger",
    "Tilden": "Tilde",
    "Tilgbare": "tilgbar",
    "Tilgbaren": "Tilgbare",
    "Tilgenden": "Tilgende",
    "Tilgens": "Tilgen",
    "Tims": "Tim",
    "Tingelnden": "Tingelnde",
    "Tingelnderen": "Tingelndere",
    "Tingelndsten": "Tingelndste",
    "Tingelns": "Tingeln",
    "Tinkturen": "Tinktur",
    "Tinten": "Tinte",
    "Tippelnden": "Tippelnde",
    "Tippelnderen": "Tippelndere",
    "Tippelndsten": "Tippelndste",
    "Tippelns": "Tippeln",
    "Tippenden": "Tippende",
    "Tippenderen": "Tippendere",
    "Tippendsten": "Tippendste",
    "Tippens": "Tippen",
    "Tips": "Tip",
    "Tiraden": "Tirade",
    "Tisch": "tischen",
    "Tische": "tischen",
    "Tischen": "Tisch",
    "Tischenden": "Tischende",
    "Tischens": "Tischen",
    "Tisches": "Tisch",
    "Tischfertigen": "Tischfertige",
    "Tischler": "tischlern",
    "Tischlern": "Tischler",
    "Tischlernden": "Tischlernde",
    "Tischlerns": "Tischlern",
    "Tischlers": "Tischler",
    "Tischs": "Tisch",
    "Titelanwärtern": "Titelanwärter",
    "Titelanwärters": "Titelanwärter",
    "Titeln": "Titel",
    "Titels": "Titel",
    "Titschenden": "Titschende",
    "Titschens": "Titschen",
    "Toastenden": "Toastende",
    "Toastens": "Toasten",
    "Toastern": "Toaster",
    "Toasters": "Toaster",
    "Toasts": "Toast",
    "Tobake": "Tobak",
    "Tobaken": "Tobak",
    "Tobaks": "Tobak",
    "Tobenden": "Tobende",
    "Tobenderen": "Tobendere",
    "Tobendsten": "Tobendste",
    "Tobens": "Toben",
    "Tobsüchtigen": "Tobsüchtige",
    "Tode": "Tod",
    "Todes": "Tod",
    "Todesmutige": "todesmutig",
    "Todesmutigen": "Todesmutige",
    "Todesmutigeren": "Todesmutigere",
    "Todesmutigsten": "Todesmutigste",
    "Todesspiralen": "Todesspirale",
    "Todgeweihte": "todgeweiht",
    "Todgeweihten": "Todgeweihte",
    "Todkranken": "Todkranke",
    "Tods": "Tod",
    "Todschicke": "todschick",
    "Todschicken": "Todschicke",
    "Todsicheren": "Todsichere",
    "Todunglücklichen": "Todunglückliche",
    "Toiletten": "Toilette",
    "Tokios": "Tokio",
    "Tolerante": "tolerant",
    "Toleranten": "Tolerante",
    "Toleranteren": "Tolerantere",
    "Tolerantesten": "Toleranteste",
    "Toleranzen": "Toleranz",
    "Tolerierenden": "Tolerierende",
    "Tolerierens": "Tolerieren",
    "Tolerierte": "toleriert",
    "Tolerierten": "Tolerierte",
    "Tolkiens": "Tolkien",
    "Tolle": "tollen",
    "Tollen": "Tolle",
    "Tollenden": "Tollende",
    "Tollens": "Tollen",
    "Tolleren": "Tollere",
    "Tollkühnen": "Tollkühne",
    "Tollkühneren": "Tollkühnere",
    "Tollkühnsten": "Tollkühnste",
    "Tollpatschigen": "Tollpatschige",
    "Tollpatschigeren": "Tollpatschigere",
    "Tollpatschigsten": "Tollpatschigste",
    "Tollsten": "Tollste",
    "Tollwütigen": "Tollwütige",
    "Tollwütigeren": "Tollwütigere",
    "Tollwütigsten": "Tollwütigste",
    "Tolpatschigen": "Tolpatschige",
    "Tolpatschigeren": "Tolpatschigere",
    "Tolpatschigsten": "Tolpatschigste",
    "Tomaten": "Tomate",
    "Tomografien": "Tomografie",
    "Tomographien": "Tomographie",
    "Toms": "Tom",
    "Tonabnehmern": "Tonabnehmer",
    "Tonabnehmers": "Tonabnehmer",
    "Tonangebende": "tonangebend",
    "Tonangebenden": "Tonangebende",
    "Tone": "Ton",
    "Tonern": "Toner",
    "Toners": "Toner",
    "Tongebungen": "Tongebung",
    "Tonis": "Toni",
    "Tonkabinen": "Tonkabine",
    "Tonkameras": "Tonkamera",
    "Tonlagen": "Tonlage",
    "Tonnen": "Tonne",
    "Tons": "Ton",
    "Tonungen": "Tonung",
    "Tonys": "Tony",
    "Topf": "topfen",
    "Topfe": "topfen",
    "Topfenden": "Topfende",
    "Topfens": "Topfen",
    "Topfes": "Topf",
    "Topfs": "Topf",
    "Topografien": "Topografie",
    "Toppenden": "Toppende",
    "Toppenderen": "Toppendere",
    "Toppendsten": "Toppendste",
    "Toppens": "Toppen",
    "Toppsegeln": "Toppsegel",
    "Toppsegels": "Toppsegel",
    "Topspins": "Topspin",
    "Topstars": "Topstar",
    "Tore": "Tor",
    "Toren": "Tor",
    "Toreros": "Torero",
    "Torkelnden": "Torkelnde",
    "Torkelnderen": "Torkelndere",
    "Torkelndsten": "Torkelndste",
    "Torkelns": "Torkeln",
    "Tornados": "Tornado",
    "Tornistern": "Tornister",
    "Tornisters": "Tornister",
    "Torpedierenden": "Torpedierende",
    "Torpedierenderen": "Torpedierendere",
    "Torpedierendsten": "Torpedierendste",
    "Torpedierens": "Torpedieren",
    "Torpedierte": "torpediert",
    "Torpedierten": "Torpedierte",
    "Torpedierteren": "Torpediertere",
    "Torpediertesten": "Torpedierteste",
    "Torpedos": "Torpedo",
    "Tors": "Tor",
    "Torsionen": "Torsion",
    "Torsos": "Torso",
    "Torstens": "Torsten",
    "Torten": "Torte",
    "Tortenhebern": "Tortenheber",
    "Tortenhebers": "Tortenheber",
    "Torwarte": "Torwart",
    "Torwarten": "Torwart",
    "Torwartes": "Torwart",
    "Torwarts": "Torwart",
    "Torwächtern": "Torwächter",
    "Torwächters": "Torwächter",
    "Tosenden": "Tosende",
    "Tosenderen": "Tosendere",
    "Tosendsten": "Tosendste",
    "Tosens": "Tosen",
    "Totalansichten": "Totalansicht",
    "Totale": "total",
    "Totalen": "Totale",
    "Totalisierenden": "Totalisierende",
    "Totalisierenderen": "Totalisierendere",
    "Totalisierendsten": "Totalisierendste",
    "Totalisierens": "Totalisieren",
    "Totalisierte": "totalisiert",
    "Totalisierten": "Totalisierte",
    "Totalisierteren": "Totalisiertere",
    "Totalisiertesten": "Totalisierteste",
    "Totalitären": "Totalitäre",
    "Totalitäten": "Totalität",
    "Totalumzuge": "Totalumzug",
    "Totalumzuges": "Totalumzug",
    "Totalumzugs": "Totalumzug",
    "Totalumzüge": "Totalumzug",
    "Totalumzügen": "Totalumzug",
    "Totarbeitenden": "Totarbeitende",
    "Totarbeitenderen": "Totarbeitendere",
    "Totarbeitendsten": "Totarbeitendste",
    "Totarbeitens": "Totarbeiten",
    "Toten": "Tote",
    "Totenblasse": "totenblaß",
    "Totenblassen": "Totenblasse",
    "Totenbleichen": "Totenbleiche",
    "Totenfrauen": "Totenfrau",
    "Totenschauen": "Totenschau",
    "Totenschädeln": "Totenschädel",
    "Totenschädels": "Totenschädel",
    "Toteren": "Totere",
    "Totesten": "Toteste",
    "Totgearbeiteten": "Totgearbeitete",
    "Totgearbeiteteren": "Totgearbeitetere",
    "Totgeborenen": "Totgeborene",
    "Totgeburten": "Totgeburt",
    "Totgelachten": "Totgelachte",
    "Totgesagten": "Totgesagte",
    "Totgeschlagenen": "Totgeschlagene",
    "Totgeschwiegenen": "Totgeschwiegene",
    "Totgeschwiegeneren": "Totgeschwiegenere",
    "Totgestellten": "Totgestellte",
    "Totgestochenen": "Totgestochene",
    "Totgetretenen": "Totgetretene",
    "Totgeärgerten": "Totgeärgerte",
    "Totlachenden": "Totlachende",
    "Totlachenderen": "Totlachendere",
    "Totlachendsten": "Totlachendste",
    "Totlachens": "Totlachen",
    "Totos": "Toto",
    "Totsagenden": "Totsagende",
    "Totsagens": "Totsagen",
    "Totschlagenden": "Totschlagende",
    "Totschlagens": "Totschlagen",
    "Totschlägern": "Totschläger",
    "Totschlägers": "Totschläger",
    "Totschweigenden": "Totschweigende",
    "Totschweigenderen": "Totschweigendere",
    "Totschweigendsten": "Totschweigendste",
    "Totschweigens": "Totschweigen",
    "Totstechenden": "Totstechende",
    "Totstechens": "Totstechen",
    "Totstellenden": "Totstellende",
    "Totstellens": "Totstellen",
    "Tottretenden": "Tottretende",
    "Tottretens": "Tottreten",
    "Totärgernden": "Totärgernde",
    "Totärgerns": "Totärgern",
    "Touren": "Tour",
    "Touristen": "Tourist",
    "Tourneen": "Tournee",
    "Toxikologische": "toxikologisch",
    "Toxikologischen": "Toxikologische",
    "Toxischen": "Toxische",
    "Toyotas": "Toyota",
    "Trabenden": "Trabende",
    "Trabenderen": "Trabendere",
    "Trabendsten": "Trabendste",
    "Trabens": "Traben",
    "Trachten": "Tracht",
    "Trachtenden": "Trachtende",
    "Trachtenderen": "Trachtendere",
    "Trachtendsten": "Trachtendste",
    "Trachtens": "Trachten",
    "Tradierenden": "Tradierende",
    "Tradierens": "Tradieren",
    "Tradierte": "tradiert",
    "Tradierten": "Tradierte",
    "Traditionellen": "Traditionelle",
    "Traditionelleren": "Traditionellere",
    "Traditionellsten": "Traditionellste",
    "Traditionen": "Tradition",
    "Traditionsbewußte": "traditionsbewußt",
    "Traditionsbewußten": "Traditionsbewußte",
    "Traditionsbewußteren": "Traditionsbewußtere",
    "Traditionsreichen": "Traditionsreiche",
    "Traditionsreicheren": "Traditionsreichere",
    "Trafos": "Trafo",
    "Tragbahren": "Tragbahre",
    "Tragbare": "tragbar",
    "Tragbaren": "Tragbare",
    "Tragbareren": "Tragbarere",
    "Tragbarsten": "Tragbarste",
    "Tragen": "Trage",
    "Tragenden": "Tragende",
    "Tragens": "Tragen",
    "Tragezeiten": "Tragezeit",
    "Tragfähige": "tragfähig",
    "Tragfähigen": "Tragfähige",
    "Tragischen": "Tragische",
    "Tragischeren": "Tragischere",
    "Tragischsten": "Tragischste",
    "Tragkorbe": "Tragkorb",
    "Tragkorbs": "Tragkorb",
    "Tragkräftige": "tragkräftig",
    "Tragkräftigen": "Tragkräftige",
    "Tragkräftigeren": "Tragkräftigere",
    "Tragkräftigsten": "Tragkräftigste",
    "Tragkörbe": "Tragkorb",
    "Tragkörben": "Tragkorb",
    "Tragseile": "Tragseil",
    "Tragseilen": "Tragseil",
    "Tragseils": "Tragseil",
    "Tragweiten": "Tragweite",
    "Tragödien": "Tragödie",
    "Trainern": "Trainer",
    "Trainers": "Trainer",
    "Trainierenden": "Trainierende",
    "Trainierenderen": "Trainierendere",
    "Trainierendsten": "Trainierendste",
    "Trainierens": "Trainieren",
    "Trainierte": "trainiert",
    "Trainierten": "Trainierte",
    "Trainierteren": "Trainiertere",
    "Trainiertesten": "Trainierteste",
    "Trainings": "Training",
    "Traktierenden": "Traktierende",
    "Traktierens": "Traktieren",
    "Traktierte": "traktiert",
    "Traktierten": "Traktierte",
    "Traktore": "Traktor",
    "Traktoren": "Traktor",
    "Traktoristen": "Traktorist",
    "Traktors": "Traktor",
    "Trakturen": "Traktur",
    "Trampel": "trampeln",
    "Trampeln": "Trampel",
    "Trampelnden": "Trampelnde",
    "Trampelnderen": "Trampelndere",
    "Trampelndsten": "Trampelndste",
    "Trampelns": "Trampeln",
    "Trampelpfade": "Trampelpfad",
    "Trampelpfaden": "Trampelpfad",
    "Trampelpfads": "Trampelpfad",
    "Trampels": "Trampel",
    "Trampern": "Tramper",
    "Trampers": "Tramper",
    "Trampoline": "Trampolin",
    "Trampolinen": "Trampolin",
    "Trampolins": "Trampolin",
    "Trams": "Tram",
    "Tranigen": "Tranige",
    "Tranigeren": "Tranigere",
    "Tranigsten": "Tranigste",
    "Transaktionen": "Transaktion",
    "Transalpine": "transalpin",
    "Transalpinen": "Transalpine",
    "Transchierbestecks": "Transchierbesteck",
    "Transchierenden": "Transchierende",
    "Transchierenderen": "Transchierendere",
    "Transchierendsten": "Transchierendste",
    "Transchierens": "Transchieren",
    "Transchierte": "transchiert",
    "Transchierten": "Transchierte",
    "Transferenzen": "Transferenz",
    "Transferierenden": "Transferierende",
    "Transferierens": "Transferieren",
    "Transferierte": "transferiert",
    "Transferierten": "Transferierte",
    "Transfers": "Transfer",
    "Transformationen": "Transformation",
    "Transformatore": "Transformator",
    "Transformatoren": "Transformator",
    "Transformators": "Transformator",
    "Transformierenden": "Transformierende",
    "Transformierens": "Transformieren",
    "Transformierte": "transformiert",
    "Transformierten": "Transformierte",
    "Transistore": "Transistor",
    "Transistoren": "Transistor",
    "Transistores": "Transistor",
    "Transistors": "Transistor",
    "Transitive": "transitiv",
    "Transitiven": "Transitive",
    "Transkontinentalen": "Transkontinentale",
    "Transmissionen": "Transmission",
    "Transmittern": "Transmitter",
    "Transmitters": "Transmitter",
    "Transparente": "transparent",
    "Transparenten": "Transparente",
    "Transparenteren": "Transparentere",
    "Transparentesten": "Transparenteste",
    "Transparentpapiere": "Transparentpapier",
    "Transparentpapieren": "Transparentpapier",
    "Transparentpapiers": "Transparentpapier",
    "Transplantationen": "Transplantation",
    "Transplantierenden": "Transplantierende",
    "Transplantierens": "Transplantieren",
    "Transplantierte": "transplantiert",
    "Transplantierten": "Transplantierte",
    "Transpondern": "Transponder",
    "Transponders": "Transponder",
    "Transponierenden": "Transponierende",
    "Transponierens": "Transponieren",
    "Transponierte": "transponiert",
    "Transponierten": "Transponierte",
    "Transponierungen": "Transponierung",
    "Transportable": "transportabel",
    "Transportablen": "Transportable",
    "Transporte": "Transport",
    "Transporten": "Transport",
    "Transportern": "Transporter",
    "Transporters": "Transporter",
    "Transportfähige": "transportfähig",
    "Transportfähigen": "Transportfähige",
    "Transportierenden": "Transportierende",
    "Transportierens": "Transportieren",
    "Transportierte": "transportiert",
    "Transportierten": "Transportierte",
    "Transports": "Transport",
    "Transportwesens": "Transportwesen",
    "Transpositionen": "Transposition",
    "Transsibirische": "transsibirisch",
    "Transsibirischen": "Transsibirische",
    "Transvestiten": "Transvestit",
    "Trappen": "Trappe",
    "Trappenden": "Trappende",
    "Trappens": "Trappen",
    "Trappern": "Trapper",
    "Trappers": "Trapper",
    "Trapsenden": "Trapsende",
    "Trapsenderen": "Trapsendere",
    "Trapsendsten": "Trapsendste",
    "Trapsens": "Trapsen",
    "Trassen": "Trasse",
    "Trassierenden": "Trassierende",
    "Trassierens": "Trassieren",
    "Trassierte": "trassiert",
    "Trassierten": "Trassierte",
    "Trauben": "Traube",
    "Trauenden": "Trauende",
    "Trauens": "Trauen",
    "Trauer": "trauern",
    "Trauern": "Trauer",
    "Trauernden": "Trauernde",
    "Trauernderen": "Trauerndere",
    "Trauerndsten": "Trauerndste",
    "Trauerns": "Trauern",
    "Trauformeln": "Trauformel",
    "Traumatischen": "Traumatische",
    "Traumatischeren": "Traumatischere",
    "Traumatischsten": "Traumatischste",
    "Traume": "Traum",
    "Traumes": "Traum",
    "Traumhaften": "Traumhafte",
    "Traumhafteren": "Traumhaftere",
    "Traumhaftesten": "Traumhafteste",
    "Traums": "Traum",
    "Traumwandelnden": "Traumwandelnde",
    "Traumwandelnderen": "Traumwandelndere",
    "Traumwandelndsten": "Traumwandelndste",
    "Traumwandelns": "Traumwandeln",
    "Traurigen": "Traurige",
    "Traurigeren": "Traurigere",
    "Traurigsten": "Traurigste",
    "Trauscheine": "Trauschein",
    "Trauscheinen": "Trauschein",
    "Trauscheins": "Trauschein",
    "Trauungen": "Trauung",
    "Treckern": "Trecker",
    "Treckers": "Trecker",
    "Trecks": "Treck",
    "Treffenden": "Treffende",
    "Treffenderen": "Treffendere",
    "Treffendsten": "Treffendste",
    "Treffens": "Treffen",
    "Treffern": "Treffer",
    "Treffers": "Treffer",
    "Trefflichen": "Treffliche",
    "Treffpunkte": "Treffpunkt",
    "Treffpunkten": "Treffpunkt",
    "Treffpunkts": "Treffpunkt",
    "Treffs": "Treff",
    "Treffsichere": "treffsicher",
    "Treffsicheren": "Treffsichere",
    "Treffsichereren": "Treffsicherere",
    "Treffsichersten": "Treffsicherste",
    "Treibenden": "Treibende",
    "Treibens": "Treiben",
    "Treibhause": "Treibhaus",
    "Treibhauses": "Treibhaus",
    "Treibhäuser": "Treibhaus",
    "Treibhäusern": "Treibhaus",
    "Treibladungen": "Treibladung",
    "Treibminen": "Treibmine",
    "Treibmitteln": "Treibmittel",
    "Treibmittels": "Treibmittel",
    "Treibnetze": "Treibnetz",
    "Treibnetzen": "Treibnetz",
    "Treibnetzes": "Treibnetz",
    "Treibnetzs": "Treibnetz",
    "Treibsands": "Treibsand",
    "Treibscheiben": "Treibscheibe",
    "Treibschlage": "Treibschlag",
    "Treibschlags": "Treibschlag",
    "Treibschläge": "Treibschlag",
    "Treibschlägen": "Treibschlag",
    "Treibstoffe": "Treibstoff",
    "Treibstoffen": "Treibstoff",
    "Treibstoffs": "Treibstoff",
    "Treiböle": "Treiböl",
    "Treibölen": "Treiböl",
    "Treiböls": "Treiböl",
    "Trends": "Trend",
    "Trennbare": "trennbar",
    "Trennbaren": "Trennbare",
    "Trennenden": "Trennende",
    "Trennens": "Trennen",
    "Trennmessern": "Trennmesser",
    "Trennmessers": "Trennmesser",
    "Trennmitteln": "Trennmittel",
    "Trennmittels": "Trennmittel",
    "Trennscharfe": "trennscharf",
    "Trennscharfen": "Trennscharfe",
    "Trennungen": "Trennung",
    "Trennwände": "Trennwand",
    "Trennwänden": "Trennwand",
    "Treosre": "Tresor",
    "Treppen": "Treppe",
    "Tresens": "Tresen",
    "Tresore": "Tresor",
    "Tresoren": "Tresor",
    "Tresors": "Tresor",
    "Tretanlagen": "Tretanlage",
    "Tretautos": "Tretauto",
    "Tretenden": "Tretende",
    "Tretens": "Treten",
    "Tretern": "Treter",
    "Treters": "Treter",
    "Tretkurbeln": "Tretkurbel",
    "Tretminen": "Tretmine",
    "Tretmühlen": "Tretmühle",
    "Tretrade": "Tretrad",
    "Tretrades": "Tretrad",
    "Tretrads": "Tretrad",
    "Treträder": "Tretrad",
    "Treträdern": "Tretrad",
    "Tretwerke": "Tretwerk",
    "Tretwerken": "Tretwerk",
    "Tretwerks": "Tretwerk",
    "Treue": "treu",
    "Treuen": "Treue",
    "Treueren": "Treuere",
    "Treuhandanstalten": "Treuhandanstalt",
    "Treuhandgesellschaften": "Treuhandgesellschaft",
    "Treuherzige": "treuherzig",
    "Treuherzigen": "Treuherzige",
    "Treuherzigeren": "Treuherzigere",
    "Treuherzigsten": "Treuherzigste",
    "Treuhändern": "Treuhänder",
    "Treuhänders": "Treuhänder",
    "Treulosen": "Treulose",
    "Treuloseren": "Treulosere",
    "Treulosesten": "Treuloseste",
    "Treusten": "Treuste",
    "Treutels": "Treutel",
    "Triangeln": "Triangel",
    "Triangels": "Triangel",
    "Triathlone": "Triathlon",
    "Triathlones": "Triathlon",
    "Triathlons": "Triathlon",
    "Tribunale": "Tribunal",
    "Tribunalen": "Tribunal",
    "Tribunals": "Tribunal",
    "Tribünen": "Tribüne",
    "Trichinen": "Trichine",
    "Trichosen": "Trichose",
    "Trichter": "trichtern",
    "Trichtern": "Trichter",
    "Trichternden": "Trichternde",
    "Trichterns": "Trichtern",
    "Trichters": "Trichter",
    "Tricke": "Trick",
    "Tricken": "Trick",
    "Trickes": "Trick",
    "Tricks": "tricksen",
    "Tricksenden": "Tricksende",
    "Tricksenderen": "Tricksendere",
    "Tricksendsten": "Tricksendste",
    "Tricksens": "Tricksen",
    "Triebe": "Trieb",
    "Trieben": "Trieb",
    "Triebes": "Trieb",
    "Triebfedern": "Triebfeder",
    "Triebhafte": "triebhaft",
    "Triebhaften": "Triebhafte",
    "Triebhafteren": "Triebhaftere",
    "Triebhaftesten": "Triebhafteste",
    "Triebkräfte": "Triebkraft",
    "Triebkräften": "Triebkraft",
    "Triebrade": "Triebrad",
    "Triebrades": "Triebrad",
    "Triebrads": "Triebrad",
    "Triebräder": "Triebrad",
    "Triebrädern": "Triebrad",
    "Triebs": "Trieb",
    "Triebwagens": "Triebwagen",
    "Triebwerke": "Triebwerk",
    "Triebwerken": "Triebwerk",
    "Triebwerkes": "Triebwerk",
    "Triebwerks": "Triebwerk",
    "Triefaugen": "Triefauge",
    "Triefauges": "Triefauge",
    "Triefenden": "Triefende",
    "Triefens": "Triefen",
    "Triers": "Trier",
    "Triezenden": "Triezende",
    "Triezenderen": "Triezendere",
    "Triezendsten": "Triezendste",
    "Triezens": "Triezen",
    "Triftigen": "Triftige",
    "Triftigkeiten": "Triftigkeit",
    "Trikots": "Trikot",
    "Triller": "trillern",
    "Trillern": "Triller",
    "Trillernden": "Trillernde",
    "Trillernderen": "Trillerndere",
    "Trillerndsten": "Trillerndste",
    "Trillerns": "Trillern",
    "Trillerpfeifen": "Trillerpfeife",
    "Trillers": "Triller",
    "Trilliarden": "Trilliarde",
    "Trillionen": "Trillion",
    "Trimmenden": "Trimmende",
    "Trimmenderen": "Trimmendere",
    "Trimmendsten": "Trimmendste",
    "Trimmens": "Trimmen",
    "Trinen": "Trine",
    "Trinkenden": "Trinkende",
    "Trinkens": "Trinken",
    "Trinkern": "Trinker",
    "Trinkers": "Trinker",
    "Trinkfesten": "Trinkfeste",
    "Trinkfesteren": "Trinkfestere",
    "Trinkfestesten": "Trinkfesteste",
    "Trinkgelagen": "Trinkgelage",
    "Trinkgelages": "Trinkgelage",
    "Trinkgelde": "Trinkgeld",
    "Trinkgelder": "Trinkgeld",
    "Trinkgeldern": "Trinkgeld",
    "Trinkgeldes": "Trinkgeld",
    "Trinkgelds": "Trinkgeld",
    "Trinkhallen": "Trinkhalle",
    "Trinkhalme": "Trinkhalm",
    "Trinkhalmen": "Trinkhalm",
    "Trinkhalms": "Trinkhalm",
    "Trinkliede": "Trinklied",
    "Trinklieder": "Trinklied",
    "Trinkliedern": "Trinklied",
    "Trinkliedes": "Trinklied",
    "Trinklieds": "Trinklied",
    "Trinkspruche": "Trinkspruch",
    "Trinkspruchs": "Trinkspruch",
    "Trinksprüche": "Trinkspruch",
    "Trinksprüchen": "Trinkspruch",
    "Trinkstuben": "Trinkstube",
    "Trinkwassers": "Trinkwasser",
    "Trios": "Trio",
    "Tripelfugen": "Tripelfuge",
    "Tripeln": "Tripel",
    "Tripels": "Tripel",
    "Trippelnden": "Trippelnde",
    "Trippelnderen": "Trippelndere",
    "Trippelndsten": "Trippelndste",
    "Trippelns": "Trippeln",
    "Trippern": "Tripper",
    "Trippers": "Tripper",
    "Trips": "Trip",
    "Trisomien": "Trisomie",
    "Triste": "trist",
    "Tristen": "Triste",
    "Tristeren": "Tristere",
    "Tristesten": "Tristeste",
    "Tritiums": "Tritium",
    "Tritt": "treten",
    "Trittbrette": "Trittbrett",
    "Trittbretter": "Trittbrett",
    "Trittbrettern": "Trittbrett",
    "Trittbrettes": "Trittbrett",
    "Trittbretts": "Trittbrett",
    "Tritte": "Tritt",
    "Tritten": "Tritt",
    "Trittes": "Tritt",
    "Trittleitern": "Trittleiter",
    "Trittmaschinen": "Trittmaschine",
    "Tritts": "Tritt",
    "Triumphalen": "Triumphale",
    "Triumphatore": "Triumphator",
    "Triumphatoren": "Triumphator",
    "Triumphators": "Triumphator",
    "Triumphe": "Triumph",
    "Triumphen": "Triumph",
    "Triumphes": "Triumph",
    "Triumphierenden": "Triumphierende",
    "Triumphierenderen": "Triumphierendere",
    "Triumphierendsten": "Triumphierendste",
    "Triumphierens": "Triumphieren",
    "Triumphierte": "triumphiert",
    "Triumphierten": "Triumphierte",
    "Triumphs": "Triumph",
    "Trockene": "trocken",
    "Trockenen": "Trockene",
    "Trockeneren": "Trockenere",
    "Trockenobsts": "Trockenobst",
    "Trockenpflaumen": "Trockenpflaume",
    "Trockenste": "trocken",
    "Trockensten": "Trockenste",
    "Trocknenden": "Trocknende",
    "Trocknenderen": "Trocknendere",
    "Trocknendsten": "Trocknendste",
    "Trocknens": "Trocknen",
    "Troge": "Trog",
    "Trogs": "Trog",
    "Trojanern": "Trojaner",
    "Trojaners": "Trojaner",
    "Trojanische": "trojanisch",
    "Trojanischen": "Trojanische",
    "Trolle": "Troll",
    "Trollen": "Troll",
    "Trolls": "Troll",
    "Trommel": "trommeln",
    "Trommeln": "Trommel",
    "Trommelnden": "Trommelnde",
    "Trommelnderen": "Trommelndere",
    "Trommelndsten": "Trommelndste",
    "Trommelns": "Trommeln",
    "Trompeten": "Trompete",
    "Trompetenden": "Trompetende",
    "Trompetens": "Trompeten",
    "Trompetern": "Trompeter",
    "Trompeters": "Trompeter",
    "Trompetete": "trompetet",
    "Trompeteten": "Trompetete",
    "Tropf": "tropfen",
    "Tropfe": "tropfen",
    "Tropfenden": "Tropfende",
    "Tropfenderen": "Tropfendere",
    "Tropfendsten": "Tropfendste",
    "Tropfens": "Tropfen",
    "Tropfes": "Tropf",
    "Tropfs": "Tropf",
    "Trophäen": "Trophäe",
    "Tropische": "tropisch",
    "Tropischen": "Tropische",
    "Trossen": "Trosse",
    "Troste": "Trost",
    "Trostes": "Trost",
    "Trostlosen": "Trostlose",
    "Trostloseren": "Trostlosere",
    "Trostlosesten": "Trostloseste",
    "Trotteligen": "Trottelige",
    "Trotteligeren": "Trotteligere",
    "Trotteligsten": "Trotteligste",
    "Trottenden": "Trottende",
    "Trottenderen": "Trottendere",
    "Trottendsten": "Trottendste",
    "Trottens": "Trotten",
    "Trotts": "Trott",
    "Trotzenden": "Trotzende",
    "Trotzenderen": "Trotzendere",
    "Trotzendsten": "Trotzendste",
    "Trotzens": "Trotzen",
    "Trotzern": "Trotzer",
    "Trotzers": "Trotzer",
    "Trotzigen": "Trotzige",
    "Trotzigeren": "Trotzigere",
    "Trotzigsten": "Trotzigste",
    "Trubels": "Trubel",
    "Trudelnden": "Trudelnde",
    "Trudelnderen": "Trudelndere",
    "Trudelndsten": "Trudelndste",
    "Trudelns": "Trudeln",
    "Truhen": "Truhe",
    "Trumpf": "trumpfen",
    "Trumpfe": "trumpfen",
    "Trumpfenden": "Trumpfende",
    "Trumpfenderen": "Trumpfendere",
    "Trumpfendsten": "Trumpfendste",
    "Trumpfens": "Trumpfen",
    "Trumpfes": "Trumpf",
    "Trumpfs": "Trumpf",
    "Trunkenheiten": "Trunkenheit",
    "Trunks": "Trunk",
    "Truppen": "Truppe",
    "Trupps": "Trupp",
    "Truthennen": "Truthenne",
    "Trächtigen": "Trächtige",
    "Trächtigeren": "Trächtigere",
    "Trächtigsten": "Trächtigste",
    "Trägen": "träge",
    "Träger": "träge",
    "Trägeren": "Trägere",
    "Trägern": "Träger",
    "Trägerraketen": "Trägerrakete",
    "Trägers": "Träger",
    "Trägerwellen": "Trägerwelle",
    "Trägesten": "Trägeste",
    "Trällernden": "Trällernde",
    "Trällernderen": "Trällerndere",
    "Trällerndsten": "Trällerndste",
    "Trällerns": "Trällern",
    "Tränchens": "Tränchen",
    "Träne": "tränen",
    "Tränen": "Träne",
    "Tränenden": "Tränende",
    "Tränenderen": "Tränendere",
    "Tränendsten": "Tränendste",
    "Tränenreichen": "Tränenreiche",
    "Tränenreicheren": "Tränenreichere",
    "Tränenreichsten": "Tränenreichste",
    "Tränens": "Tränen",
    "Tränken": "trinken",
    "Tränleins": "Tränlein",
    "Träubleins": "Träublein",
    "Träufelnden": "Träufelnde",
    "Träufelnderen": "Träufelndere",
    "Träufelndsten": "Träufelndste",
    "Träufelns": "Träufeln",
    "Träufenden": "Träufende",
    "Träufenderen": "Träufendere",
    "Träufendsten": "Träufendste",
    "Träufens": "Träufen",
    "Träume": "träumen",
    "Träumen": "Traum",
    "Träumenden": "Träumende",
    "Träumenderen": "Träumendere",
    "Träumendsten": "Träumendste",
    "Träumens": "Träumen",
    "Träumerische": "träumerisch",
    "Träumerischen": "Träumerische",
    "Träumern": "Träumer",
    "Träumers": "Träumer",
    "Trödel": "trödeln",
    "Trödeleien": "Trödelei",
    "Trödelige": "trödelig",
    "Trödeligen": "Trödelige",
    "Trödeligeren": "Trödeligere",
    "Trödeligsten": "Trödeligste",
    "Trödelladens": "Trödelladen",
    "Trödelläden": "Trödelladen",
    "Trödelmarkte": "Trödelmarkt",
    "Trödelmarkts": "Trödelmarkt",
    "Trödelmärkte": "Trödelmarkt",
    "Trödelmärkten": "Trödelmarkt",
    "Trödeln": "Trödel",
    "Trödelnden": "Trödelnde",
    "Trödelnderen": "Trödelndere",
    "Trödelndsten": "Trödelndste",
    "Trödelns": "Trödeln",
    "Trödels": "Trödel",
    "Trödlern": "Trödler",
    "Trödlers": "Trödler",
    "Tröge": "trügen",
    "Trögen": "trügen",
    "Tröpfchens": "Tröpfchen",
    "Tröpfe": "Tropf",
    "Tröpfelnden": "Tröpfelnde",
    "Tröpfelnderen": "Tröpfelndere",
    "Tröpfelndsten": "Tröpfelndste",
    "Tröpfelns": "Tröpfeln",
    "Tröpfen": "Tropf",
    "Tröstenden": "Tröstende",
    "Tröstenderen": "Tröstendere",
    "Tröstendsten": "Tröstendste",
    "Tröstens": "Trösten",
    "Tröstern": "Tröster",
    "Trösters": "Tröster",
    "Tröstlichen": "Tröstliche",
    "Tröstlicheren": "Tröstlichere",
    "Tröstlichsten": "Tröstlichste",
    "Trübe": "trüben",
    "Trüben": "Trübe",
    "Trübenden": "Trübende",
    "Trübenderen": "Trübendere",
    "Trübendsten": "Trübendste",
    "Trübens": "Trüben",
    "Trüberen": "Trübere",
    "Trübnisse": "Trübnis",
    "Trübnissen": "Trübnis",
    "Trübselige": "trübselig",
    "Trübseligen": "Trübselige",
    "Trübseligeren": "Trübseligere",
    "Trübseligsten": "Trübseligste",
    "Trübsinnigen": "Trübsinnige",
    "Trübsinnigeren": "Trübsinnigere",
    "Trübsinnigsten": "Trübsinnigste",
    "Trübsinns": "Trübsinn",
    "Trübsten": "Trübste",
    "Trüffeln": "Trüffel",
    "Trügenden": "Trügende",
    "Trügenderen": "Trügendere",
    "Trügendsten": "Trügendste",
    "Trügens": "Trügen",
    "Trügerische": "trügerisch",
    "Trügerischen": "Trügerische",
    "Trügerischeren": "Trügerischere",
    "Trügerischsten": "Trügerischste",
    "Trümmerfelde": "Trümmerfeld",
    "Trümmerfelder": "Trümmerfeld",
    "Trümmerfeldern": "Trümmerfeld",
    "Trümmerfeldes": "Trümmerfeld",
    "Trümmerfelds": "Trümmerfeld",
    "Trümmerfrauen": "Trümmerfrau",
    "Trümmern": "Trümmer",
    "Trümpfe": "Trumpf",
    "Trümpfen": "Trumpf",
    "Trüppchens": "Trüppchen",
    "Tsantsas": "Tsantsa",
    "Tschechen": "Tscheche",
    "Tschechische": "tschechisch",
    "Tschechischen": "Tschechische",
    "Tschechischeren": "Tschechischere",
    "Tschechischsten": "Tschechischste",
    "Tschernobyls": "Tschernobyl",
    "Tsetsefliegen": "Tsetsefliege",
    "Tuben": "Tube",
    "Tuche": "Tuch",
    "Tuches": "Tuch",
    "Tuchs": "Tuch",
    "Tuckernden": "Tuckernde",
    "Tuckernderen": "Tuckerndere",
    "Tuckerndsten": "Tuckerndste",
    "Tuckerns": "Tuckern",
    "Tuckerte": "tuckert",
    "Tuckerten": "Tuckerte",
    "Tuenden": "Tuende",
    "Tugenden": "Tugend",
    "Tugendhafte": "tugendhaft",
    "Tugendhaften": "Tugendhafte",
    "Tugendhafteren": "Tugendhaftere",
    "Tugendhaftesten": "Tugendhafteste",
    "Tugendsamen": "Tugendsame",
    "Tugendsameren": "Tugendsamere",
    "Tugendsamsten": "Tugendsamste",
    "Tulpen": "Tulpe",
    "Tummelnden": "Tummelnde",
    "Tummelnderen": "Tummelndere",
    "Tummelndsten": "Tummelndste",
    "Tummelns": "Tummeln",
    "Tumore": "Tumor",
    "Tumoren": "Tumor",
    "Tumors": "Tumor",
    "Tumulte": "Tumult",
    "Tumulten": "Tumult",
    "Tumultes": "Tumult",
    "Tumults": "Tumult",
    "Tunken": "Tunke",
    "Tunkenden": "Tunkende",
    "Tunkens": "Tunken",
    "Tunnels": "Tunnel",
    "Tuns": "Tun",
    "Tunten": "Tunte",
    "Tuntige": "tuntig",
    "Tuntigen": "Tuntige",
    "Tuntigeren": "Tuntigere",
    "Tuntigsten": "Tuntigste",
    "Tupfenden": "Tupfende",
    "Tupfens": "Tupfen",
    "Tupperwaren": "Tupperware",
    "Turbinen": "Turbine",
    "Turbogeneratore": "Turbogenerator",
    "Turbogeneratoren": "Turbogenerator",
    "Turbogenerators": "Turbogenerator",
    "Turboladern": "Turbolader",
    "Turboladers": "Turbolader",
    "Turbulente": "turbulent",
    "Turbulenten": "Turbulente",
    "Turbulenteren": "Turbulentere",
    "Turbulentesten": "Turbulenteste",
    "Turbulenzen": "Turbulenz",
    "Turins": "Turin",
    "Turme": "Turm",
    "Turmes": "Turm",
    "Turms": "Turm",
    "Turnenden": "Turnende",
    "Turnens": "Turnen",
    "Turnerinnen": "Turnerin",
    "Turnern": "Turner",
    "Turners": "Turner",
    "Turnerschaften": "Turnerschaft",
    "Turngemeinden": "Turngemeinde",
    "Turnhallen": "Turnhalle",
    "Turniere": "Turnier",
    "Turnieren": "Turnier",
    "Turnieres": "Turnier",
    "Turniers": "Turnier",
    "Turnschuhe": "Turnschuh",
    "Turnschuhen": "Turnschuh",
    "Turnschuhes": "Turnschuh",
    "Turnschuhs": "Turnschuh",
    "Turnzeuge": "Turnzeug",
    "Turnzeugen": "Turnzeug",
    "Turnzeugs": "Turnzeug",
    "Turnübungen": "Turnübung",
    "Turtelnden": "Turtelnde",
    "Turtelnderen": "Turtelndere",
    "Turtelndsten": "Turtelndste",
    "Turtelns": "Turteln",
    "Turteltauben": "Turteltaube",
    "Tusche": "Tusch",
    "Tuschelnden": "Tuschelnde",
    "Tuschelnderen": "Tuschelndere",
    "Tuschelndsten": "Tuschelndste",
    "Tuschelns": "Tuscheln",
    "Tuschen": "Tusch",
    "Tusches": "Tusch",
    "Tuschierenden": "Tuschierende",
    "Tuschierens": "Tuschieren",
    "Tuschierte": "tuschiert",
    "Tuschierten": "Tuschierte",
    "Tuschs": "Tusch",
    "Tute": "tuten",
    "Tuten": "Tute",
    "Tutenden": "Tutende",
    "Tutenderen": "Tutendere",
    "Tutendsten": "Tutendste",
    "Tutens": "Tuten",
    "Type": "Typ",
    "Typen": "Typus",
    "Typische": "typisch",
    "Typischen": "Typische",
    "Typischeren": "Typischere",
    "Typischsten": "Typischste",
    "Typisierenden": "Typisierende",
    "Typisierens": "Typisieren",
    "Typisierte": "typisiert",
    "Typisierten": "Typisierte",
    "Typisierungen": "Typisierung",
    "Typogenesen": "Typogenese",
    "Typographische": "typographisch",
    "Typographischen": "Typographische",
    "Typologien": "Typologie",
    "Typologische": "typologisch",
    "Typologischen": "Typologische",
    "Typs": "Typ",
    "Tyranneien": "Tyrannei",
    "Tyrannen": "Tyrann",
    "Tyrannische": "tyrannisch",
    "Tyrannischen": "Tyrannische",
    "Tyrannischeren": "Tyrannischere",
    "Tyrannischsten": "Tyrannischste",
    "Tyrannisierenden": "Tyrannisierende",
    "Tyrannisierenderen": "Tyrannisierendere",
    "Tyrannisierens": "Tyrannisieren",
    "Tyrannisierte": "tyrannisiert",
    "Tyrannisierten": "Tyrannisierte",
    "Tyrannisierteren": "Tyrannisiertere",
    "Tyrannisiertesten": "Tyrannisierteste",
    "Täfelnden": "Täfelnde",
    "Täfelns": "Täfeln",
    "Täfelungen": "Täfelung",
    "Täflungen": "Täflung",
    "Tägliche": "täglich",
    "Täglichen": "Tägliche",
    "Täler": "Tal",
    "Tälern": "Tal",
    "Tändelnden": "Tändelnde",
    "Tändelnderen": "Tändelndere",
    "Tändelndsten": "Tändelndste",
    "Tändelns": "Tändeln",
    "Tännchens": "Tännchen",
    "Tännleins": "Tännlein",
    "Tänze": "Tanz",
    "Tänzelnden": "Tänzelnde",
    "Tänzelnderen": "Tänzelndere",
    "Tänzelndsten": "Tänzelndste",
    "Tänzelns": "Tänzeln",
    "Tänzen": "Tanz",
    "Tänzerinnen": "Tänzerin",
    "Tänzerische": "tänzerisch",
    "Tänzerischen": "Tänzerische",
    "Tänzern": "Tänzer",
    "Tänzers": "Tänzer",
    "Täschchens": "Täschchen",
    "Täschleins": "Täschlein",
    "Tätern": "Täter",
    "Täters": "Täter",
    "Tätige": "tätigen",
    "Tätigen": "Tätige",
    "Tätigenden": "Tätigende",
    "Tätigens": "Tätigen",
    "Tätigkeiten": "Tätigkeit",
    "Tätlichen": "Tätliche",
    "Tätlichkeiten": "Tätlichkeit",
    "Tätowierenden": "Tätowierende",
    "Tätowierenderen": "Tätowierendere",
    "Tätowierendsten": "Tätowierendste",
    "Tätowierens": "Tätowieren",
    "Tätowierte": "tätowiert",
    "Tätowierten": "Tätowierte",
    "Tätowierteren": "Tätowiertere",
    "Tätowiertesten": "Tätowierteste",
    "Tätowierungen": "Tätowierung",
    "Tätschelnden": "Tätschelnde",
    "Tätschelns": "Tätscheln",
    "Täubchens": "Täubchen",
    "Täufern": "Täufer",
    "Täufers": "Täufer",
    "Täuschende": "täuschend",
    "Täuschenden": "Täuschende",
    "Täuschenderen": "Täuschendere",
    "Täuschendsten": "Täuschendste",
    "Täuschens": "Täuschen",
    "Täuschungen": "Täuschung",
    "Täßchens": "Täßchen",
    "Töchter": "Tochter",
    "Töchterchens": "Töchterchen",
    "Töchtern": "Tochter",
    "Tödlichen": "Tödliche",
    "Tödlicheren": "Tödlichere",
    "Tödlichsten": "Tödlichste",
    "Tölpelhaften": "Tölpelhafte",
    "Tölpelhafteren": "Tölpelhaftere",
    "Tölpelhaftesten": "Tölpelhafteste",
    "Töne": "tönen",
    "Tönen": "Ton",
    "Tönenden": "Tönende",
    "Tönenderen": "Tönendere",
    "Tönendsten": "Tönendste",
    "Tönens": "Tönen",
    "Tönerne": "tönern",
    "Tönernen": "Tönerne",
    "Tönungen": "Tönung",
    "Töpfe": "Topf",
    "Töpfen": "Topf",
    "Töpfer": "töpfern",
    "Töpfernden": "Töpfernde",
    "Töpferns": "Töpfern",
    "Töpfers": "Töpfer",
    "Törichte": "töricht",
    "Törichten": "Törichte",
    "Törichteren": "Törichtere",
    "Törichtesten": "Törichteste",
    "Törn": "törnen",
    "Törnenden": "Törnende",
    "Törnens": "Törnen",
    "Törns": "Törn",
    "Törtchens": "Törtchen",
    "Tötenden": "Tötende",
    "Tötenderen": "Tötendere",
    "Tötendsten": "Tötendste",
    "Tötens": "Töten",
    "Tötungen": "Tötung",
    "Tübingens": "Tübingen",
    "Tücher": "Tuch",
    "Tüchern": "Tuch",
    "Tüchleins": "Tüchlein",
    "Tüchtige": "tüchtig",
    "Tüchtigen": "Tüchtige",
    "Tüchtigeren": "Tüchtigere",
    "Tüchtigsten": "Tüchtigste",
    "Tückischen": "Tückische",
    "Tückischeren": "Tückischere",
    "Tückischsten": "Tückischste",
    "Tüdeligen": "Tüdelige",
    "Tüdeligeren": "Tüdeligere",
    "Tüdeligsten": "Tüdeligste",
    "Tüfteleien": "Tüftelei",
    "Tüftelige": "tüftelig",
    "Tüfteligen": "Tüftelige",
    "Tüfteligeren": "Tüfteligere",
    "Tüfteligsten": "Tüfteligste",
    "Tüftelnden": "Tüftelnde",
    "Tüftelnderen": "Tüftelndere",
    "Tüftelndsten": "Tüftelndste",
    "Tüftelns": "Tüfteln",
    "Tüftlern": "Tüftler",
    "Tüftlers": "Tüftler",
    "Tümmlern": "Tümmler",
    "Tümmlers": "Tümmler",
    "Tümpeln": "Tümpel",
    "Tümpels": "Tümpel",
    "Tünche": "tünchen",
    "Tünchen": "Tünche",
    "Tünchenden": "Tünchende",
    "Tünchenderen": "Tünchendere",
    "Tünchendsten": "Tünchendste",
    "Tünchens": "Tünchen",
    "Tüpfelchens": "Tüpfelchen",
    "Tüpfeln": "Tüpfel",
    "Tüpfels": "Tüpfel",
    "Türen": "Türe",
    "Türke": "türken",
    "Türkeis": "Türkei",
    "Türken": "Türke",
    "Türkenden": "Türkende",
    "Türkenderen": "Türkendere",
    "Türkendsten": "Türkendste",
    "Türkens": "Türken",
    "Türkischen": "Türkische",
    "Türme": "türmen",
    "Türmen": "Turm",
    "Türmenden": "Türmende",
    "Türmenderen": "Türmendere",
    "Türmendsten": "Türmendste",
    "Türmens": "Türmen",
    "Türmern": "Türmer",
    "Türmers": "Türmer",
    "Tütchens": "Tütchen",
    "Tüten": "Tüte",
    "Tütende": "tütend",
    "Tütenden": "Tütende",
    "Tütens": "Tüten",
    "Tüvs": "Tüv",
    "US": "US-amerikanischen",
    "Udos": "Udo",
    "Uerdingens": "Uerdingen",
    "Ufer": "ufern",
    "Uferlosen": "Uferlose",
    "Ufern": "Ufer",
    "Ufernden": "Ufernde",
    "Uferns": "Ufern",
    "Ufers": "Ufer",
    "Uhren": "Uhr",
    "Ukrainische": "ukrainisch",
    "Ukrainischen": "Ukrainische",
    "Ukuleles": "Ukulele",
    "Ulfs": "Ulf",
    "Ulis": "Uli",
    "Ulkenden": "Ulkende",
    "Ulkenderen": "Ulkendere",
    "Ulkendsten": "Ulkendste",
    "Ulkens": "Ulken",
    "Ulkigen": "Ulkige",
    "Ulkigeren": "Ulkigere",
    "Ulkigsten": "Ulkigste",
    "Ulmen": "Ulme",
    "Ulms": "Ulm",
    "Ulrichs": "Ulrich",
    "Ulrikes": "Ulrike",
    "Ultimative": "ultimativ",
    "Ultimativen": "Ultimative",
    "Ultimatums": "Ultimatum",
    "Ultraschalls": "Ultraschall",
    "Umarbeitenden": "Umarbeitende",
    "Umarbeitens": "Umarbeiten",
    "Umarmenden": "Umarmende",
    "Umarmens": "Umarmen",
    "Umarmte": "umarmt",
    "Umarmten": "Umarmte",
    "Umarmungen": "Umarmung",
    "Umbauenden": "Umbauende",
    "Umbauens": "Umbauen",
    "Umbaus": "Umbau",
    "Umbauten": "umbauen",
    "Umbehaltenden": "Umbehaltende",
    "Umbehaltenen": "Umbehaltene",
    "Umbehaltens": "Umbehalten",
    "Umbesetzenden": "Umbesetzende",
    "Umbesetzens": "Umbesetzen",
    "Umbesetzte": "umbesetzt",
    "Umbesetzten": "Umbesetzte",
    "Umbesetzungen": "Umbesetzung",
    "Umbettenden": "Umbettende",
    "Umbettens": "Umbetten",
    "Umbettungen": "Umbettung",
    "Umbiegenden": "Umbiegende",
    "Umbiegens": "Umbiegen",
    "Umbildenden": "Umbildende",
    "Umbildens": "Umbilden",
    "Umbildungen": "Umbildung",
    "Umbindenden": "Umbindende",
    "Umbindens": "Umbinden",
    "Umblasenden": "Umblasende",
    "Umblasens": "Umblasen",
    "Umblätternden": "Umblätternde",
    "Umblätterns": "Umblättern",
    "Umbrechenden": "Umbrechende",
    "Umbrechens": "Umbrechen",
    "Umbringenden": "Umbringende",
    "Umbringens": "Umbringen",
    "Umbruche": "Umbruch",
    "Umbruchs": "Umbruch",
    "Umbrüche": "Umbruch",
    "Umbrüchen": "Umbruch",
    "Umbuchenden": "Umbuchende",
    "Umbuchens": "Umbuchen",
    "Umbuchungen": "Umbuchung",
    "Umdenkenden": "Umdenkende",
    "Umdenkens": "Umdenken",
    "Umdeutenden": "Umdeutende",
    "Umdeutens": "Umdeuten",
    "Umdichtenden": "Umdichtende",
    "Umdichtens": "Umdichten",
    "Umdisponierenden": "Umdisponierende",
    "Umdisponierens": "Umdisponieren",
    "Umdisponierte": "umdisponiert",
    "Umdisponierten": "Umdisponierte",
    "Umdrehenden": "Umdrehende",
    "Umdrehens": "Umdrehen",
    "Umdrehungen": "Umdrehung",
    "Umerziehenden": "Umerziehende",
    "Umerziehens": "Umerziehen",
    "Umerzogenen": "Umerzogene",
    "Umfahrenden": "Umfahrende",
    "Umfahrenen": "Umfahrene",
    "Umfahrens": "Umfahren",
    "Umfallenden": "Umfallende",
    "Umfallens": "Umfallen",
    "Umfange": "Umfang",
    "Umfangreiche": "umfangreich",
    "Umfangreichen": "Umfangreiche",
    "Umfangreicheren": "Umfangreichere",
    "Umfangreichsten": "Umfangreichste",
    "Umfangs": "Umfang",
    "Umfassenden": "Umfassende",
    "Umfassenderen": "Umfassendere",
    "Umfassendsten": "Umfassendste",
    "Umfassens": "Umfassen",
    "Umfaßte": "umfaßt",
    "Umfaßten": "Umfaßte",
    "Umfelde": "Umfeld",
    "Umfeldes": "Umfeld",
    "Umfelds": "Umfeld",
    "Umfliegenden": "Umfliegende",
    "Umfliegens": "Umfliegen",
    "Umfließenden": "Umfließende",
    "Umfließens": "Umfließen",
    "Umflogenen": "Umflogene",
    "Umflossenen": "Umflossene",
    "Umformenden": "Umformende",
    "Umformens": "Umformen",
    "Umformern": "Umformer",
    "Umformers": "Umformer",
    "Umformungen": "Umformung",
    "Umfrage": "umfragen",
    "Umfragen": "Umfrage",
    "Umfragenden": "Umfragende",
    "Umfragens": "Umfragen",
    "Umfunktionierenden": "Umfunktionierende",
    "Umfunktionierens": "Umfunktionieren",
    "Umfunktionierte": "umfunktioniert",
    "Umfunktionierten": "Umfunktionierte",
    "Umfänge": "Umfang",
    "Umfängen": "Umfang",
    "Umfärbenden": "Umfärbende",
    "Umfärbens": "Umfärben",
    "Umfüllenden": "Umfüllende",
    "Umfüllens": "Umfüllen",
    "Umgange": "Umgang",
    "Umganges": "Umgang",
    "Umgangs": "Umgang",
    "Umgangssprachliche": "umgangssprachlich",
    "Umgangssprachlichen": "Umgangssprachliche",
    "Umgarnenden": "Umgarnende",
    "Umgarnenderen": "Umgarnendere",
    "Umgarnendsten": "Umgarnendste",
    "Umgarnens": "Umgarnen",
    "Umgarnte": "umgarnt",
    "Umgarnten": "Umgarnte",
    "Umgarnteren": "Umgarntere",
    "Umgarntesten": "Umgarnteste",
    "Umgearbeiteten": "Umgearbeitete",
    "Umgebauten": "Umgebaute",
    "Umgebenden": "Umgebende",
    "Umgebenen": "Umgebene",
    "Umgebens": "Umgeben",
    "Umgebetteten": "Umgebettete",
    "Umgebildeten": "Umgebildete",
    "Umgeblasenen": "Umgeblasene",
    "Umgeblätterten": "Umgeblätterte",
    "Umgebogenen": "Umgebogene",
    "Umgebogeneren": "Umgebogenere",
    "Umgebogensten": "Umgebogenste",
    "Umgebrachten": "Umgebrachte",
    "Umgebrochenen": "Umgebrochene",
    "Umgebuchten": "Umgebuchte",
    "Umgebundenen": "Umgebundene",
    "Umgedachten": "Umgedachte",
    "Umgedeuteten": "Umgedeutete",
    "Umgedichteten": "Umgedichtete",
    "Umgedrehten": "Umgedrehte",
    "Umgefahrenen": "Umgefahrene",
    "Umgefallenen": "Umgefallene",
    "Umgeflogenen": "Umgeflogene",
    "Umgeformten": "Umgeformte",
    "Umgefragten": "Umgefragte",
    "Umgefärbten": "Umgefärbte",
    "Umgefüllten": "Umgefüllte",
    "Umgegangenen": "Umgegangene",
    "Umgegossenen": "Umgegossene",
    "Umgegrabenen": "Umgegrabene",
    "Umgegrätschten": "Umgegrätschte",
    "Umgegrätschteren": "Umgegrätschtere",
    "Umgegrätschtesten": "Umgegrätschteste",
    "Umgehangenen": "Umgehangene",
    "Umgehauenen": "Umgehauene",
    "Umgehenden": "Umgehende",
    "Umgehens": "Umgehen",
    "Umgehungen": "Umgehung",
    "Umgehängten": "Umgehängte",
    "Umgehörten": "Umgehörte",
    "Umgekehrten": "Umgekehrte",
    "Umgekippten": "Umgekippte",
    "Umgeklappten": "Umgeklappte",
    "Umgekleideten": "Umgekleidete",
    "Umgeknickten": "Umgeknickte",
    "Umgekommenen": "Umgekommene",
    "Umgekreisten": "Umgekreiste",
    "Umgekrempelten": "Umgekrempelte",
    "Umgekrempelteren": "Umgekrempeltere",
    "Umgekrempeltesten": "Umgekrempelteste",
    "Umgeladenen": "Umgeladene",
    "Umgelagerten": "Umgelagerte",
    "Umgelaufenen": "Umgelaufene",
    "Umgelauteten": "Umgelautete",
    "Umgelegten": "Umgelegte",
    "Umgeleiteten": "Umgeleitete",
    "Umgelenkten": "Umgelenkte",
    "Umgelernten": "Umgelernte",
    "Umgemeldeten": "Umgemeldete",
    "Umgemodelten": "Umgemodelte",
    "Umgemodelteren": "Umgemodeltere",
    "Umgemodeltesten": "Umgemodelteste",
    "Umgenähten": "Umgenähte",
    "Umgepflanzten": "Umgepflanzte",
    "Umgepflügten": "Umgepflügte",
    "Umgepolten": "Umgepolte",
    "Umgerannten": "Umgerannte",
    "Umgerechneten": "Umgerechnete",
    "Umgerissenen": "Umgerissene",
    "Umgerittenen": "Umgerittene",
    "Umgeräumten": "Umgeräumte",
    "Umgerührten": "Umgerührte",
    "Umgerüsteten": "Umgerüstete",
    "Umgesattelten": "Umgesattelte",
    "Umgeschalteten": "Umgeschaltete",
    "Umgeschauten": "Umgeschaute",
    "Umgeschichteten": "Umgeschichtete",
    "Umgeschlagenen": "Umgeschlagene",
    "Umgeschmissenen": "Umgeschmissene",
    "Umgeschnallten": "Umgeschnallte",
    "Umgeschriebenen": "Umgeschriebene",
    "Umgeschuldeten": "Umgeschuldete",
    "Umgeschulten": "Umgeschulte",
    "Umgeschwenkten": "Umgeschwenkte",
    "Umgeschütteten": "Umgeschüttete",
    "Umgesehenen": "Umgesehene",
    "Umgesetzten": "Umgesetzte",
    "Umgesiedelten": "Umgesiedelte",
    "Umgespannten": "Umgespannte",
    "Umgesprungenen": "Umgesprungene",
    "Umgespulten": "Umgespulte",
    "Umgestaltenden": "Umgestaltende",
    "Umgestaltens": "Umgestalten",
    "Umgestaltete": "umgestaltet",
    "Umgestalteten": "Umgestaltete",
    "Umgestaltungen": "Umgestaltung",
    "Umgestellten": "Umgestellte",
    "Umgestiegenen": "Umgestiegene",
    "Umgestimmten": "Umgestimmte",
    "Umgestochenen": "Umgestochene",
    "Umgestoßenen": "Umgestoßene",
    "Umgestülpten": "Umgestülpte",
    "Umgestürzten": "Umgestürzte",
    "Umgesunkenen": "Umgesunkene",
    "Umgesäumten": "Umgesäumte",
    "Umgetankten": "Umgetankte",
    "Umgetauften": "Umgetaufte",
    "Umgetauschten": "Umgetauschte",
    "Umgetopften": "Umgetopfte",
    "Umgetriebenen": "Umgetriebene",
    "Umgewandelten": "Umgewandelte",
    "Umgewandelteren": "Umgewandeltere",
    "Umgewandeltesten": "Umgewandelteste",
    "Umgewandten": "Umgewandte",
    "Umgewendeten": "Umgewendete",
    "Umgewerteten": "Umgewertete",
    "Umgeworfenen": "Umgeworfene",
    "Umgewälzten": "Umgewälzte",
    "Umgewälzteren": "Umgewälztere",
    "Umgewälztesten": "Umgewälzteste",
    "Umgewühlten": "Umgewühlte",
    "Umgezeichneten": "Umgezeichnete",
    "Umgezogenen": "Umgezogene",
    "Umgeänderten": "Umgeänderte",
    "Umgeänderteren": "Umgeändertere",
    "Umgeändertesten": "Umgeänderteste",
    "Umgießenden": "Umgießende",
    "Umgießens": "Umgießen",
    "Umgrabenden": "Umgrabende",
    "Umgrabens": "Umgraben",
    "Umgruppierenden": "Umgruppierende",
    "Umgruppierens": "Umgruppieren",
    "Umgruppierte": "umgruppiert",
    "Umgruppierten": "Umgruppierte",
    "Umgruppierungen": "Umgruppierung",
    "Umgrätschenden": "Umgrätschende",
    "Umgrätschenderen": "Umgrätschendere",
    "Umgrätschendsten": "Umgrätschendste",
    "Umgrätschens": "Umgrätschen",
    "Umgängliche": "umgänglich",
    "Umgänglichen": "Umgängliche",
    "Umgänglicheren": "Umgänglichere",
    "Umgänglichsten": "Umgänglichste",
    "Umhange": "Umhang",
    "Umhangs": "Umhang",
    "Umhauenden": "Umhauende",
    "Umhauens": "Umhauen",
    "Umherfahrenden": "Umherfahrende",
    "Umherfahrenderen": "Umherfahrendere",
    "Umherfahrendsten": "Umherfahrendste",
    "Umherfahrens": "Umherfahren",
    "Umherflatternden": "Umherflatternde",
    "Umherflatterns": "Umherflattern",
    "Umherfliegenden": "Umherfliegende",
    "Umherfliegens": "Umherfliegen",
    "Umhergefahrenen": "Umhergefahrene",
    "Umhergeflatterten": "Umhergeflatterte",
    "Umhergeflogenen": "Umhergeflogene",
    "Umhergeirrten": "Umhergeirrte",
    "Umhergeirrteren": "Umhergeirrtere",
    "Umhergeirrtesten": "Umhergeirrteste",
    "Umhergejagten": "Umhergejagte",
    "Umhergekrochenen": "Umhergekrochene",
    "Umhergereisten": "Umhergereiste",
    "Umhergerittenen": "Umhergerittene",
    "Umhergeschauten": "Umhergeschaute",
    "Umhergeschlenderten": "Umhergeschlenderte",
    "Umhergeschlichenen": "Umhergeschlichene",
    "Umhergestreiften": "Umhergestreifte",
    "Umhergestreifteren": "Umhergestreiftere",
    "Umhergetappten": "Umhergetappte",
    "Umhergetasteten": "Umhergetastete",
    "Umhergetriebenen": "Umhergetriebene",
    "Umhergewanderten": "Umhergewanderte",
    "Umhergewimmelten": "Umhergewimmelte",
    "Umhergezogenen": "Umhergezogene",
    "Umherirrenden": "Umherirrende",
    "Umherirrenderen": "Umherirrendere",
    "Umherirrendsten": "Umherirrendste",
    "Umherirrens": "Umherirren",
    "Umherjagenden": "Umherjagende",
    "Umherjagens": "Umherjagen",
    "Umherkriechenden": "Umherkriechende",
    "Umherkriechens": "Umherkriechen",
    "Umherreisenden": "Umherreisende",
    "Umherreisens": "Umherreisen",
    "Umherreitenden": "Umherreitende",
    "Umherreitens": "Umherreiten",
    "Umherschauenden": "Umherschauende",
    "Umherschauens": "Umherschauen",
    "Umherschleichenden": "Umherschleichende",
    "Umherschleichens": "Umherschleichen",
    "Umherschlendernden": "Umherschlendernde",
    "Umherschlenderns": "Umherschlendern",
    "Umherstreifenden": "Umherstreifende",
    "Umherstreifenderen": "Umherstreifendere",
    "Umherstreifens": "Umherstreifen",
    "Umhertappenden": "Umhertappende",
    "Umhertappens": "Umhertappen",
    "Umhertastenden": "Umhertastende",
    "Umhertastens": "Umhertasten",
    "Umhertreibenden": "Umhertreibende",
    "Umhertreibens": "Umhertreiben",
    "Umherwandernden": "Umherwandernde",
    "Umherwanderns": "Umherwandern",
    "Umherwimmelnden": "Umherwimmelnde",
    "Umherwimmelns": "Umherwimmeln",
    "Umherziehenden": "Umherziehende",
    "Umherziehens": "Umherziehen",
    "Umhänge": "umhängen",
    "Umhängen": "Umhang",
    "Umhängenden": "Umhängende",
    "Umhängens": "Umhängen",
    "Umhängetaschen": "Umhängetasche",
    "Umhörenden": "Umhörende",
    "Umhörens": "Umhören",
    "Umhüllenden": "Umhüllende",
    "Umhüllenderen": "Umhüllendere",
    "Umhüllendsten": "Umhüllendste",
    "Umhüllens": "Umhüllen",
    "Umhüllte": "umhüllt",
    "Umhüllten": "Umhüllte",
    "Umhüllteren": "Umhülltere",
    "Umhülltesten": "Umhüllteste",
    "Umhüllungen": "Umhüllung",
    "Uminterpretierenden": "Uminterpretierende",
    "Uminterpretierens": "Uminterpretieren",
    "Uminterpretierte": "uminterpretiert",
    "Uminterpretierten": "Uminterpretierte",
    "Umkehrbaren": "Umkehrbare",
    "Umkehrenden": "Umkehrende",
    "Umkehrens": "Umkehren",
    "Umkehrungen": "Umkehrung",
    "Umkippenden": "Umkippende",
    "Umkippens": "Umkippen",
    "Umklammernden": "Umklammernde",
    "Umklammernderen": "Umklammerndere",
    "Umklammerndsten": "Umklammerndste",
    "Umklammerns": "Umklammern",
    "Umklammerte": "umklammert",
    "Umklammerten": "Umklammerte",
    "Umklammerteren": "Umklammertere",
    "Umklammertesten": "Umklammerteste",
    "Umklappenden": "Umklappende",
    "Umklappens": "Umklappen",
    "Umkleidekabinen": "Umkleidekabine",
    "Umkleidenden": "Umkleidende",
    "Umkleidens": "Umkleiden",
    "Umkleideraume": "Umkleideraum",
    "Umkleideraums": "Umkleideraum",
    "Umkleideräume": "Umkleideraum",
    "Umkleideräumen": "Umkleideraum",
    "Umkleidungen": "Umkleidung",
    "Umknickenden": "Umknickende",
    "Umknickens": "Umknicken",
    "Umkommenden": "Umkommende",
    "Umkommens": "Umkommen",
    "Umkreise": "umkreisen",
    "Umkreisen": "Umkreis",
    "Umkreisenden": "Umkreisende",
    "Umkreisens": "Umkreisen",
    "Umkreises": "Umkreis",
    "Umkrempelnden": "Umkrempelnde",
    "Umkrempelnderen": "Umkrempelndere",
    "Umkrempelndsten": "Umkrempelndste",
    "Umkrempelns": "Umkrempeln",
    "Umkämpften": "Umkämpfte",
    "Umkämpfteren": "Umkämpftere",
    "Umkämpftesten": "Umkämpfteste",
    "Umladenden": "Umladende",
    "Umladens": "Umladen",
    "Umlagen": "Umlage",
    "Umlagernden": "Umlagernde",
    "Umlagernderen": "Umlagerndere",
    "Umlagerndsten": "Umlagerndste",
    "Umlagerns": "Umlagern",
    "Umlagerte": "umlagert",
    "Umlagerten": "Umlagerte",
    "Umlagerteren": "Umlagertere",
    "Umlagertesten": "Umlagerteste",
    "Umlande": "Umland",
    "Umlandes": "Umland",
    "Umlands": "Umland",
    "Umlaufe": "umlaufen",
    "Umlaufenden": "Umlaufende",
    "Umlaufens": "Umlaufen",
    "Umlaufmitteln": "Umlaufmittel",
    "Umlaufmittels": "Umlaufmittel",
    "Umlaufs": "Umlauf",
    "Umlaute": "umlauten",
    "Umlauten": "Umlaut",
    "Umlautenden": "Umlautende",
    "Umlautens": "Umlauten",
    "Umlauts": "Umlaut",
    "Umlautungen": "Umlautung",
    "Umlegenden": "Umlegende",
    "Umlegens": "Umlegen",
    "Umleitenden": "Umleitende",
    "Umleitens": "Umleiten",
    "Umlenkenden": "Umlenkende",
    "Umlenkens": "Umlenken",
    "Umlernenden": "Umlernende",
    "Umlernens": "Umlernen",
    "Umliegenden": "Umliegende",
    "Umländer": "Umland",
    "Umländern": "Umland",
    "Umläufe": "Umlauf",
    "Umläufen": "Umlauf",
    "Ummeldenden": "Ummeldende",
    "Ummeldens": "Ummelden",
    "Ummodelnden": "Ummodelnde",
    "Ummodelnderen": "Ummodelndere",
    "Ummodelndsten": "Ummodelndste",
    "Ummodelns": "Ummodeln",
    "Umnachteten": "Umnachtete",
    "Umnähenden": "Umnähende",
    "Umnähens": "Umnähen",
    "Umorganisierenden": "Umorganisierende",
    "Umorganisierens": "Umorganisieren",
    "Umorganisierte": "umorganisiert",
    "Umorganisierten": "Umorganisierte",
    "Umpflanzenden": "Umpflanzende",
    "Umpflanzens": "Umpflanzen",
    "Umpflügenden": "Umpflügende",
    "Umpflügens": "Umpflügen",
    "Umpolenden": "Umpolende",
    "Umpolens": "Umpolen",
    "Umprogrammierenden": "Umprogrammierende",
    "Umprogrammierens": "Umprogrammieren",
    "Umprogrammierte": "umprogrammiert",
    "Umprogrammierten": "Umprogrammierte",
    "Umquartierenden": "Umquartierende",
    "Umquartierens": "Umquartieren",
    "Umquartierte": "umquartiert",
    "Umquartierten": "Umquartierte",
    "Umrahmenden": "Umrahmende",
    "Umrahmens": "Umrahmen",
    "Umrahmte": "umrahmt",
    "Umrahmten": "Umrahmte",
    "Umrandenden": "Umrandende",
    "Umrandens": "Umranden",
    "Umrandete": "umrandet",
    "Umrandeten": "Umrandete",
    "Umrandungen": "Umrandung",
    "Umrankenden": "Umrankende",
    "Umrankens": "Umranken",
    "Umrankte": "umrankt",
    "Umrankten": "Umrankte",
    "Umrechnenden": "Umrechnende",
    "Umrechnens": "Umrechnen",
    "Umrechnungen": "Umrechnung",
    "Umreitenden": "Umreitende",
    "Umreitens": "Umreiten",
    "Umreißenden": "Umreißende",
    "Umreißens": "Umreißen",
    "Umrennenden": "Umrennende",
    "Umrennens": "Umrennen",
    "Umrisse": "Umriß",
    "Umrissen": "Umriß",
    "Umrisses": "Umriß",
    "Umräumenden": "Umräumende",
    "Umräumens": "Umräumen",
    "Umrührenden": "Umrührende",
    "Umrührens": "Umrühren",
    "Umrüstenden": "Umrüstende",
    "Umrüstens": "Umrüsten",
    "Umsattelnden": "Umsattelnde",
    "Umsattelns": "Umsatteln",
    "Umsatze": "Umsatz",
    "Umsatzes": "Umsatz",
    "Umschaltenden": "Umschaltende",
    "Umschaltens": "Umschalten",
    "Umschaltern": "Umschalter",
    "Umschalters": "Umschalter",
    "Umschaltungen": "Umschaltung",
    "Umschauen": "Umschau",
    "Umschauenden": "Umschauende",
    "Umschauens": "Umschauen",
    "Umschichtenden": "Umschichtende",
    "Umschichtens": "Umschichten",
    "Umschichtungen": "Umschichtung",
    "Umschiffenden": "Umschiffende",
    "Umschiffens": "Umschiffen",
    "Umschiffte": "umschifft",
    "Umschifften": "Umschiffte",
    "Umschlage": "umschlagen",
    "Umschlagenden": "Umschlagende",
    "Umschlagens": "Umschlagen",
    "Umschlages": "Umschlag",
    "Umschlaghafens": "Umschlaghafen",
    "Umschlaghäfen": "Umschlaghafen",
    "Umschlags": "Umschlag",
    "Umschläge": "Umschlag",
    "Umschlägen": "Umschlag",
    "Umschmeißenden": "Umschmeißende",
    "Umschmeißens": "Umschmeißen",
    "Umschnallenden": "Umschnallende",
    "Umschnallens": "Umschnallen",
    "Umschreibenden": "Umschreibende",
    "Umschreibens": "Umschreiben",
    "Umschuldenden": "Umschuldende",
    "Umschuldens": "Umschulden",
    "Umschuldungen": "Umschuldung",
    "Umschulenden": "Umschulende",
    "Umschulens": "Umschulen",
    "Umschulungen": "Umschulung",
    "Umschwenkenden": "Umschwenkende",
    "Umschwenkens": "Umschwenken",
    "Umschwunge": "Umschwung",
    "Umschwungs": "Umschwung",
    "Umschwärmenden": "Umschwärmende",
    "Umschwärmenderen": "Umschwärmendere",
    "Umschwärmendsten": "Umschwärmendste",
    "Umschwärmens": "Umschwärmen",
    "Umschwärmte": "umschwärmt",
    "Umschwärmten": "Umschwärmte",
    "Umschwärmteren": "Umschwärmtere",
    "Umschwärmtesten": "Umschwärmteste",
    "Umschwünge": "Umschwung",
    "Umschwüngen": "Umschwung",
    "Umschülern": "Umschüler",
    "Umschülers": "Umschüler",
    "Umschüttenden": "Umschüttende",
    "Umschüttens": "Umschütten",
    "Umsegelnden": "Umsegelnde",
    "Umsegelns": "Umsegeln",
    "Umsegelte": "umsegelt",
    "Umsegelten": "Umsegelte",
    "Umsegelungen": "Umsegelung",
    "Umsehenden": "Umsehende",
    "Umsehens": "Umsehen",
    "Umseitigen": "Umseitige",
    "Umsetzenden": "Umsetzende",
    "Umsetzens": "Umsetzen",
    "Umsetzungen": "Umsetzung",
    "Umsichtige": "umsichtig",
    "Umsichtigen": "Umsichtige",
    "Umsichtigeren": "Umsichtigere",
    "Umsichtigsten": "Umsichtigste",
    "Umsiedelnden": "Umsiedelnde",
    "Umsiedelns": "Umsiedeln",
    "Umsiedlungen": "Umsiedlung",
    "Umsinkenden": "Umsinkende",
    "Umsinkens": "Umsinken",
    "Umsorgenden": "Umsorgende",
    "Umsorgenderen": "Umsorgendere",
    "Umsorgendsten": "Umsorgendste",
    "Umsorgens": "Umsorgen",
    "Umsorgte": "umsorgt",
    "Umsorgten": "Umsorgte",
    "Umsorgteren": "Umsorgtere",
    "Umsorgtesten": "Umsorgteste",
    "Umspannenden": "Umspannende",
    "Umspannens": "Umspannen",
    "Umspannern": "Umspanner",
    "Umspanners": "Umspanner",
    "Umspannte": "umspannt",
    "Umspannten": "Umspannte",
    "Umspannwerke": "Umspannwerk",
    "Umspannwerken": "Umspannwerk",
    "Umspannwerks": "Umspannwerk",
    "Umspielenden": "Umspielende",
    "Umspielens": "Umspielen",
    "Umspielte": "umspielt",
    "Umspielten": "Umspielte",
    "Umspringenden": "Umspringende",
    "Umspringens": "Umspringen",
    "Umspulenden": "Umspulende",
    "Umspulens": "Umspulen",
    "Umstande": "Umstand",
    "Umstandes": "Umstand",
    "Umstands": "Umstand",
    "Umstechenden": "Umstechende",
    "Umstechens": "Umstechen",
    "Umstehenden": "Umstehende",
    "Umsteigenden": "Umsteigende",
    "Umsteigens": "Umsteigen",
    "Umstellenden": "Umstellende",
    "Umstellens": "Umstellen",
    "Umstellte": "umstellt",
    "Umstellten": "Umstellte",
    "Umstellungen": "Umstellung",
    "Umstimmenden": "Umstimmende",
    "Umstimmens": "Umstimmen",
    "Umstoßenden": "Umstoßende",
    "Umstoßens": "Umstoßen",
    "Umstrittenen": "Umstrittene",
    "Umstritteneren": "Umstrittenere",
    "Umstrittensten": "Umstrittenste",
    "Umstrukturierenden": "Umstrukturierende",
    "Umstrukturierenderen": "Umstrukturierendere",
    "Umstrukturierens": "Umstrukturieren",
    "Umstrukturierte": "umstrukturiert",
    "Umstrukturierten": "Umstrukturierte",
    "Umstrukturierteren": "Umstrukturiertere",
    "Umstrukturierungen": "Umstrukturierung",
    "Umsturze": "Umsturz",
    "Umsturzes": "Umsturz",
    "Umsturzs": "Umsturz",
    "Umstädte": "Umstadt",
    "Umstädten": "Umstadt",
    "Umstände": "Umstand",
    "Umständen": "Umstand",
    "Umständliche": "umständlich",
    "Umständlichen": "Umständliche",
    "Umständlicheren": "Umständlichere",
    "Umständlichsten": "Umständlichste",
    "Umstülpenden": "Umstülpende",
    "Umstülpens": "Umstülpen",
    "Umstürze": "umstürzen",
    "Umstürzen": "Umsturz",
    "Umstürzenden": "Umstürzende",
    "Umstürzens": "Umstürzen",
    "Umstürzlerischen": "Umstürzlerische",
    "Umsätze": "Umsatz",
    "Umsätzen": "Umsatz",
    "Umsäumenden": "Umsäumende",
    "Umsäumens": "Umsäumen",
    "Umtankenden": "Umtankende",
    "Umtankens": "Umtanken",
    "Umtaufenden": "Umtaufende",
    "Umtaufens": "Umtaufen",
    "Umtauschenden": "Umtauschende",
    "Umtauschens": "Umtauschen",
    "Umtauschs": "Umtausch",
    "Umtopfenden": "Umtopfende",
    "Umtopfens": "Umtopfen",
    "Umtreibenden": "Umtreibende",
    "Umtreibens": "Umtreiben",
    "Umwandelnden": "Umwandelnde",
    "Umwandelns": "Umwandeln",
    "Umwandlungen": "Umwandlung",
    "Umwege": "Umweg",
    "Umwegen": "Umweg",
    "Umwegs": "Umweg",
    "Umweltbewußte": "umweltbewußt",
    "Umweltbewußten": "Umweltbewußte",
    "Umweltbewußteren": "Umweltbewußtere",
    "Umweltbewußtesten": "Umweltbewußteste",
    "Umweltfeindlichen": "Umweltfeindliche",
    "Umweltfeindlicheren": "Umweltfeindlichere",
    "Umweltfreundlichen": "Umweltfreundliche",
    "Umweltfreundlicheren": "Umweltfreundlichere",
    "Umweltschädlichen": "Umweltschädliche",
    "Umweltschädlicheren": "Umweltschädlichere",
    "Umweltsenatorinnen": "Umweltsenatorin",
    "Umwendenden": "Umwendende",
    "Umwendens": "Umwenden",
    "Umwerbenden": "Umwerbende",
    "Umwerbenderen": "Umwerbendere",
    "Umwerbendsten": "Umwerbendste",
    "Umwerbens": "Umwerben",
    "Umwerfenden": "Umwerfende",
    "Umwerfenderen": "Umwerfendere",
    "Umwerfendsten": "Umwerfendste",
    "Umwerfens": "Umwerfen",
    "Umwertenden": "Umwertende",
    "Umwertens": "Umwerten",
    "Umwertungen": "Umwertung",
    "Umworbenen": "Umworbene",
    "Umworbeneren": "Umworbenere",
    "Umworbensten": "Umworbenste",
    "Umwälzenden": "Umwälzende",
    "Umwälzenderen": "Umwälzendere",
    "Umwälzendsten": "Umwälzendste",
    "Umwälzens": "Umwälzen",
    "Umwühlenden": "Umwühlende",
    "Umwühlens": "Umwühlen",
    "Umzeichnenden": "Umzeichnende",
    "Umzeichnens": "Umzeichnen",
    "Umzeichnungen": "Umzeichnung",
    "Umziehenden": "Umziehende",
    "Umziehens": "Umziehen",
    "Umzingelnden": "Umzingelnde",
    "Umzingelns": "Umzingeln",
    "Umzingelte": "umzingelt",
    "Umzingelten": "Umzingelte",
    "Umzingelungen": "Umzingelung",
    "Umzuge": "Umzug",
    "Umzuges": "Umzug",
    "Umzugs": "Umzug",
    "Umzäunenden": "Umzäunende",
    "Umzäunens": "Umzäunen",
    "Umzäunte": "umzäunt",
    "Umzäunten": "Umzäunte",
    "Umzäunungen": "Umzäunung",
    "Umzüge": "Umzug",
    "Umzügen": "Umzug",
    "Umändernden": "Umändernde",
    "Umändernderen": "Umänderndere",
    "Umänderndsten": "Umänderndste",
    "Umänderns": "Umändern",
    "Unabdingbaren": "Unabdingbare",
    "Unabdingbareren": "Unabdingbarere",
    "Unabdingbarsten": "Unabdingbarste",
    "Unabgegoltenen": "Unabgegoltene",
    "Unabgegolteneren": "Unabgegoltenere",
    "Unabgegoltensten": "Unabgegoltenste",
    "Unabhängigen": "Unabhängige",
    "Unabhängigeren": "Unabhängigere",
    "Unabhängigkeiten": "Unabhängigkeit",
    "Unabhängigste": "unabhängig",
    "Unabhängigsten": "Unabhängigste",
    "Unabkömmlichen": "Unabkömmliche",
    "Unabsehbaren": "Unabsehbare",
    "Unabsichtlichen": "Unabsichtliche",
    "Unachtsamen": "Unachtsame",
    "Unachtsameren": "Unachtsamere",
    "Unachtsamsten": "Unachtsamste",
    "Unangebrachten": "Unangebrachte",
    "Unangebrachteren": "Unangebrachtere",
    "Unangebrachtesten": "Unangebrachteste",
    "Unangefochtenen": "Unangefochtene",
    "Unangemeldeten": "Unangemeldete",
    "Unangemessenen": "Unangemessene",
    "Unangemesseneren": "Unangemessenere",
    "Unangemessensten": "Unangemessenste",
    "Unangenehmen": "Unangenehme",
    "Unangenehmeren": "Unangenehmere",
    "Unangenehmsten": "Unangenehmste",
    "Unangetasteten": "Unangetastete",
    "Unannehmlichkeiten": "Unannehmlichkeit",
    "Unansehnliche": "unansehnlich",
    "Unansehnlichen": "Unansehnliche",
    "Unanständigen": "Unanständige",
    "Unanständigeren": "Unanständigere",
    "Unanständigsten": "Unanständigste",
    "Unappetitlichen": "Unappetitliche",
    "Unappetitlicheren": "Unappetitlichere",
    "Unappetitlichsten": "Unappetitlichste",
    "Unartigen": "Unartige",
    "Unaufdringlichen": "Unaufdringliche",
    "Unaufdringlicheren": "Unaufdringlichere",
    "Unauffälligen": "Unauffällige",
    "Unauffälligeren": "Unauffälligere",
    "Unauffälligsten": "Unauffälligste",
    "Unaufgeforderten": "Unaufgeforderte",
    "Unaufhaltsamen": "Unaufhaltsame",
    "Unaufhaltsameren": "Unaufhaltsamere",
    "Unaufhaltsamsten": "Unaufhaltsamste",
    "Unaufmerksamen": "Unaufmerksame",
    "Unaufmerksameren": "Unaufmerksamere",
    "Unaufmerksamsten": "Unaufmerksamste",
    "Unaufrichtigen": "Unaufrichtige",
    "Unaufrichtigeren": "Unaufrichtigere",
    "Unaufrichtigsten": "Unaufrichtigste",
    "Unaufschieblichen": "Unaufschiebliche",
    "Unausgeglichenen": "Unausgeglichene",
    "Unausgeglicheneren": "Unausgeglichenere",
    "Unausgegorenen": "Unausgegorene",
    "Unausgegoreneren": "Unausgegorenere",
    "Unausgegorensten": "Unausgegorenste",
    "Unbarmherzigen": "Unbarmherzige",
    "Unbarmherzigeren": "Unbarmherzigere",
    "Unbarmherzigsten": "Unbarmherzigste",
    "Unbeabsichtigten": "Unbeabsichtigte",
    "Unbeachteten": "Unbeachtete",
    "Unbeachteteren": "Unbeachtetere",
    "Unbeachtetesten": "Unbeachteteste",
    "Unbedenklichen": "Unbedenkliche",
    "Unbedenklicheren": "Unbedenklichere",
    "Unbedenklichkeiten": "Unbedenklichkeit",
    "Unbedenklichste": "unbedenklich",
    "Unbedenklichsten": "Unbedenklichste",
    "Unbedeutenden": "Unbedeutende",
    "Unbedeutenderen": "Unbedeutendere",
    "Unbedeutendsten": "Unbedeutendste",
    "Unbedingten": "Unbedingte",
    "Unbefangenen": "Unbefangene",
    "Unbefangeneren": "Unbefangenere",
    "Unbefangensten": "Unbefangenste",
    "Unbefleckten": "Unbefleckte",
    "Unbefleckteren": "Unbeflecktere",
    "Unbeflecktesten": "Unbefleckteste",
    "Unbefriedigenden": "Unbefriedigende",
    "Unbefriedigenderen": "Unbefriedigendere",
    "Unbefriedigten": "Unbefriedigte",
    "Unbefriedigteren": "Unbefriedigtere",
    "Unbefriedigtesten": "Unbefriedigteste",
    "Unbefristeten": "Unbefristete",
    "Unbegabten": "Unbegabte",
    "Unbegabteren": "Unbegabtere",
    "Unbegabtesten": "Unbegabteste",
    "Unbegleiteten": "Unbegleitete",
    "Unbegrenzten": "Unbegrenzte",
    "Unbegrenzteren": "Unbegrenztere",
    "Unbegrenztesten": "Unbegrenzteste",
    "Unbegründeten": "Unbegründete",
    "Unbegründeteren": "Unbegründetere",
    "Unbegründetesten": "Unbegründeteste",
    "Unbehagens": "Unbehagen",
    "Unbehagliche": "unbehaglich",
    "Unbehaglichen": "Unbehagliche",
    "Unbehaglicheren": "Unbehaglichere",
    "Unbehaglichsten": "Unbehaglichste",
    "Unbehelligten": "Unbehelligte",
    "Unbeherrschten": "Unbeherrschte",
    "Unbeherrschteren": "Unbeherrschtere",
    "Unbeherrschtesten": "Unbeherrschteste",
    "Unbeholfenen": "Unbeholfene",
    "Unbeholfeneren": "Unbeholfenere",
    "Unbeholfensten": "Unbeholfenste",
    "Unbekannten": "Unbekannte",
    "Unbekannteren": "Unbekanntere",
    "Unbekanntesten": "Unbekannteste",
    "Unbekleideten": "Unbekleidete",
    "Unbekümmerten": "Unbekümmerte",
    "Unbekümmerteren": "Unbekümmertere",
    "Unbekümmertesten": "Unbekümmerteste",
    "Unbelasteten": "Unbelastete",
    "Unbelasteteren": "Unbelastetere",
    "Unbelastetsten": "Unbelastetste",
    "Unbeliebten": "Unbeliebte",
    "Unbeliebteren": "Unbeliebtere",
    "Unbeliebtesten": "Unbeliebteste",
    "Unbemannten": "Unbemannte",
    "Unbemerkten": "Unbemerkte",
    "Unbenutzten": "Unbenutzte",
    "Unbequemen": "Unbequeme",
    "Unbequemeren": "Unbequemere",
    "Unbequemsten": "Unbequemste",
    "Unberechtigten": "Unberechtigte",
    "Unberücksichtigten": "Unberücksichtigte",
    "Unberührten": "Unberührte",
    "Unberührteren": "Unberührtere",
    "Unberührtesten": "Unberührteste",
    "Unbescheidenen": "Unbescheidene",
    "Unbescheideneren": "Unbescheidenere",
    "Unbescheidensten": "Unbescheidenste",
    "Unbescholtenen": "Unbescholtene",
    "Unbeschwerten": "Unbeschwerte",
    "Unbeschwerteren": "Unbeschwertere",
    "Unbeschwertesten": "Unbeschwerteste",
    "Unbeschädigten": "Unbeschädigte",
    "Unbesonnenen": "Unbesonnene",
    "Unbespielten": "Unbespielte",
    "Unbestimmten": "Unbestimmte",
    "Unbeständigen": "Unbeständige",
    "Unbeständigeren": "Unbeständigere",
    "Unbeständigsten": "Unbeständigste",
    "Unbestätigten": "Unbestätigte",
    "Unbeteiligten": "Unbeteiligte",
    "Unbewachten": "Unbewachte",
    "Unbewaffneten": "Unbewaffnete",
    "Unbewohnten": "Unbewohnte",
    "Unbewußten": "Unbewußte",
    "Unbewußteren": "Unbewußtere",
    "Unbewußtesten": "Unbewußteste",
    "Unbezahlbaren": "Unbezahlbare",
    "Unbezahlbareren": "Unbezahlbarere",
    "Unbezahlbarsten": "Unbezahlbarste",
    "Unbezahlten": "Unbezahlte",
    "Unblutigen": "Unblutige",
    "Unbürokratischen": "Unbürokratische",
    "Uncharakteristischen": "Uncharakteristische",
    "Undankbaren": "Undankbare",
    "Undankbareren": "Undankbarere",
    "Undankbarsten": "Undankbarste",
    "Undanke": "Undank",
    "Undankes": "Undank",
    "Undanks": "Undank",
    "Undenkbare": "undenkbar",
    "Undenkbaren": "Undenkbare",
    "Understatements": "Understatement",
    "Undeutliche": "undeutlich",
    "Undeutlichen": "Undeutliche",
    "Undeutlicheren": "Undeutlichere",
    "Undeutlichsten": "Undeutlichste",
    "Undichten": "Undichte",
    "Undichteren": "Undichtere",
    "Undichtesten": "Undichteste",
    "Undinge": "Unding",
    "Undingen": "Unding",
    "Undings": "Unding",
    "Undurchführbare": "undurchführbar",
    "Undurchführbaren": "Undurchführbare",
    "Undurchführbareren": "Undurchführbarere",
    "Undurchlässigen": "Undurchlässige",
    "Undurchlässigeren": "Undurchlässigere",
    "Undurchlässigsten": "Undurchlässigste",
    "Undurchschaubaren": "Undurchschaubare",
    "Undurchschaubareren": "Undurchschaubarere",
    "Undurchsichtigen": "Undurchsichtige",
    "Undurchsichtigeren": "Undurchsichtigere",
    "Unebenen": "Unebene",
    "Unebeneren": "Unebenere",
    "Unebenheiten": "Unebenheit",
    "Unebenste": "uneben",
    "Unebensten": "Unebenste",
    "Unechten": "Unechte",
    "Unehelichen": "Uneheliche",
    "Unehrenhaften": "Unehrenhafte",
    "Unehrlichen": "Unehrliche",
    "Uneigennützigen": "Uneigennützige",
    "Uneingeschränkten": "Uneingeschränkte",
    "Unempfindlichen": "Unempfindliche",
    "Unempfindlicheren": "Unempfindlichere",
    "Unempfindlichsten": "Unempfindlichste",
    "Unentbehrlichen": "Unentbehrliche",
    "Unentbehrlicheren": "Unentbehrlichere",
    "Unentbehrlichsten": "Unentbehrlichste",
    "Unentschiedenen": "Unentschiedene",
    "Unentschiedeneren": "Unentschiedenere",
    "Unentschiedensten": "Unentschiedenste",
    "Unentschlossenen": "Unentschlossene",
    "Unentschlosseneren": "Unentschlossenere",
    "Unentschuldigten": "Unentschuldigte",
    "Unerfahrenen": "Unerfahrene",
    "Unerfahreneren": "Unerfahrenere",
    "Unerfahrensten": "Unerfahrenste",
    "Unerfreulichen": "Unerfreuliche",
    "Unerfreulicheren": "Unerfreulichere",
    "Unerfreulichsten": "Unerfreulichste",
    "Unerfüllten": "Unerfüllte",
    "Unerfüllteren": "Unerfülltere",
    "Unerfülltesten": "Unerfüllteste",
    "Unergiebigen": "Unergiebige",
    "Unergiebigeren": "Unergiebigere",
    "Unergiebigsten": "Unergiebigste",
    "Unerheblichen": "Unerhebliche",
    "Unerhörten": "Unerhörte",
    "Unerkannten": "Unerkannte",
    "Unerledigten": "Unerledigte",
    "Unerläßlichen": "Unerläßliche",
    "Unermeßlichen": "Unermeßliche",
    "Unermüdlichen": "Unermüdliche",
    "Unerschrockenen": "Unerschrockene",
    "Unerschrockeneren": "Unerschrockenere",
    "Unerschrockensten": "Unerschrockenste",
    "Unerschütterlichen": "Unerschütterliche",
    "Unerschütterlicheren": "Unerschütterlichere",
    "Unersetzlichen": "Unersetzliche",
    "Unersetzlicheren": "Unersetzlichere",
    "Unersetzlichsten": "Unersetzlichste",
    "Unerträglichen": "Unerträgliche",
    "Unerträglicheren": "Unerträglichere",
    "Unerträglichsten": "Unerträglichste",
    "Unerwarteten": "Unerwartete",
    "Unerwarteteren": "Unerwartetere",
    "Unerwartetesten": "Unerwarteteste",
    "Unerwünschten": "Unerwünschte",
    "Unerwünschteren": "Unerwünschtere",
    "Unerwünschtesten": "Unerwünschteste",
    "Unfairen": "Unfaire",
    "Unfaireren": "Unfairere",
    "Unfairsten": "Unfairste",
    "Unfalle": "Unfall",
    "Unfallfreie": "unfallfrei",
    "Unfallfreien": "Unfallfreie",
    "Unfalls": "Unfall",
    "Unfallträchtige": "unfallträchtig",
    "Unfallträchtigen": "Unfallträchtige",
    "Unfallträchtigeren": "Unfallträchtigere",
    "Unfehlbaren": "Unfehlbare",
    "Unfehlbareren": "Unfehlbarere",
    "Unfehlbarsten": "Unfehlbarste",
    "Unfeinen": "Unfeine",
    "Unfertigen": "Unfertige",
    "Unflätigen": "Unflätige",
    "Unflätigeren": "Unflätigere",
    "Unflätigsten": "Unflätigste",
    "Unfreiwilligen": "Unfreiwillige",
    "Unfreundlichen": "Unfreundliche",
    "Unfreundlicheren": "Unfreundlichere",
    "Unfreundlichkeiten": "Unfreundlichkeit",
    "Unfreundlichste": "unfreundlich",
    "Unfreundlichsten": "Unfreundlichste",
    "Unfriedens": "Unfrieden",
    "Unfromme": "unfromm",
    "Unfrommen": "Unfromme",
    "Unfrommeren": "Unfrommere",
    "Unfrommsten": "Unfrommste",
    "Unfruchtbaren": "Unfruchtbare",
    "Unfruchtbareren": "Unfruchtbarere",
    "Unfruchtbarmachungen": "Unfruchtbarmachung",
    "Unfruchtbarste": "unfruchtbar",
    "Unfruchtbarsten": "Unfruchtbarste",
    "Unfugs": "Unfug",
    "Unfähigen": "Unfähige",
    "Unfähigeren": "Unfähigere",
    "Unfähigsten": "Unfähigste",
    "Unfälle": "Unfall",
    "Unfällen": "Unfall",
    "Ungarische": "ungarisch",
    "Ungarischen": "Ungarische",
    "Ungarns": "Ungarn",
    "Ungebetene": "ungebeten",
    "Ungebetenen": "Ungebetene",
    "Ungebildeten": "Ungebildete",
    "Ungebildeteren": "Ungebildetere",
    "Ungebildetesten": "Ungebildeteste",
    "Ungeborenen": "Ungeborene",
    "Ungebrauchten": "Ungebrauchte",
    "Ungebrochenen": "Ungebrochene",
    "Ungebrocheneren": "Ungebrochenere",
    "Ungebrochensten": "Ungebrochenste",
    "Ungebräuchlichen": "Ungebräuchliche",
    "Ungebräuchlicheren": "Ungebräuchlichere",
    "Ungebundenen": "Ungebundene",
    "Ungebundeneren": "Ungebundenere",
    "Ungebundensten": "Ungebundenste",
    "Ungedeckten": "Ungedeckte",
    "Ungeduldigen": "Ungeduldige",
    "Ungeduldigeren": "Ungeduldigere",
    "Ungeduldigsten": "Ungeduldigste",
    "Ungeeigneten": "Ungeeignete",
    "Ungeeigneteren": "Ungeeignetere",
    "Ungeeignetesten": "Ungeeigneteste",
    "Ungefragten": "Ungefragte",
    "Ungefragteren": "Ungefragtere",
    "Ungefragtesten": "Ungefragteste",
    "Ungefährdeten": "Ungefährdete",
    "Ungefährdeteren": "Ungefährdetere",
    "Ungefährdetesten": "Ungefährdeteste",
    "Ungefähren": "Ungefähre",
    "Ungefährlichen": "Ungefährliche",
    "Ungefährlicheren": "Ungefährlichere",
    "Ungefährlichsten": "Ungefährlichste",
    "Ungefälligen": "Ungefällige",
    "Ungefälligeren": "Ungefälligere",
    "Ungefälligsten": "Ungefälligste",
    "Ungehaltenen": "Ungehaltene",
    "Ungehalteneren": "Ungehaltenere",
    "Ungehaltensten": "Ungehaltenste",
    "Ungeheizten": "Ungeheizte",
    "Ungehemmten": "Ungehemmte",
    "Ungehemmteren": "Ungehemmtere",
    "Ungehemmtesten": "Ungehemmteste",
    "Ungeheuern": "Ungeheuer",
    "Ungeheuers": "Ungeheuer",
    "Ungehinderte": "ungehindert",
    "Ungehinderten": "Ungehinderte",
    "Ungehobelten": "Ungehobelte",
    "Ungehobelteren": "Ungehobeltere",
    "Ungehobeltesten": "Ungehobelteste",
    "Ungehorsame": "ungehorsam",
    "Ungehorsamen": "Ungehorsame",
    "Ungehorsams": "Ungehorsam",
    "Ungehörigkeiten": "Ungehörigkeit",
    "Ungehörte": "ungehört",
    "Ungehörten": "Ungehörte",
    "Ungeklärten": "Ungeklärte",
    "Ungeklärteren": "Ungeklärtere",
    "Ungeklärtesten": "Ungeklärteste",
    "Ungekürzten": "Ungekürzte",
    "Ungelegenen": "Ungelegene",
    "Ungelenkigen": "Ungelenkige",
    "Ungelenkigeren": "Ungelenkigere",
    "Ungelenkigsten": "Ungelenkigste",
    "Ungelernten": "Ungelernte",
    "Ungemütlichen": "Ungemütliche",
    "Ungemütlicheren": "Ungemütlichere",
    "Ungemütlichsten": "Ungemütlichste",
    "Ungenauen": "Ungenaue",
    "Ungenaueren": "Ungenauere",
    "Ungenauigkeiten": "Ungenauigkeit",
    "Ungenauste": "ungenau",
    "Ungenausten": "Ungenauste",
    "Ungenierten": "Ungenierte",
    "Ungenierteren": "Ungeniertere",
    "Ungeniertesten": "Ungenierteste",
    "Ungenießbaren": "Ungenießbare",
    "Ungenießbareren": "Ungenießbarere",
    "Ungenießbarsten": "Ungenießbarste",
    "Ungenutzten": "Ungenutzte",
    "Ungenügenden": "Ungenügende",
    "Ungeordneten": "Ungeordnete",
    "Ungepflegten": "Ungepflegte",
    "Ungepflegteren": "Ungepflegtere",
    "Ungepflegtesten": "Ungepflegteste",
    "Ungerechten": "Ungerechte",
    "Ungerechteren": "Ungerechtere",
    "Ungerechtesten": "Ungerechteste",
    "Ungerechtigkeiten": "Ungerechtigkeit",
    "Ungeregelte": "ungeregelt",
    "Ungeregelten": "Ungeregelte",
    "Ungereimten": "Ungereimte",
    "Ungereimtheiten": "Ungereimtheit",
    "Ungeschicklichkeiten": "Ungeschicklichkeit",
    "Ungeschicks": "Ungeschick",
    "Ungeschickte": "ungeschickt",
    "Ungeschickten": "Ungeschickte",
    "Ungeschickteren": "Ungeschicktere",
    "Ungeschicktesten": "Ungeschickteste",
    "Ungeschminkten": "Ungeschminkte",
    "Ungeschorenen": "Ungeschorene",
    "Ungeschützten": "Ungeschützte",
    "Ungesetzlichen": "Ungesetzliche",
    "Ungesetzlicheren": "Ungesetzlichere",
    "Ungesetzlichsten": "Ungesetzlichste",
    "Ungesitteten": "Ungesittete",
    "Ungesitteteren": "Ungesittetere",
    "Ungesittetesten": "Ungesitteteste",
    "Ungestraften": "Ungestrafte",
    "Ungestörten": "Ungestörte",
    "Ungestörteren": "Ungestörtere",
    "Ungestörtesten": "Ungestörteste",
    "Ungestümen": "Ungestüme",
    "Ungestümeren": "Ungestümere",
    "Ungestüms": "Ungestüm",
    "Ungestümste": "ungestüm",
    "Ungestümsten": "Ungestümste",
    "Ungesunden": "Ungesunde",
    "Ungesunderen": "Ungesundere",
    "Ungesundesten": "Ungesundeste",
    "Ungeteilten": "Ungeteilte",
    "Ungetrösteten": "Ungetröstete",
    "Ungetrübten": "Ungetrübte",
    "Ungetrübteren": "Ungetrübtere",
    "Ungetrübtesten": "Ungetrübteste",
    "Ungetüme": "Ungetüm",
    "Ungetümen": "Ungetüm",
    "Ungetüms": "Ungetüm",
    "Ungewaschene": "ungewaschen",
    "Ungewaschenen": "Ungewaschene",
    "Ungeweihten": "Ungeweihte",
    "Ungewissen": "Ungewisse",
    "Ungewittern": "Ungewitter",
    "Ungewitters": "Ungewitter",
    "Ungewollten": "Ungewollte",
    "Ungewollteren": "Ungewolltere",
    "Ungewolltesten": "Ungewollteste",
    "Ungewöhnliche": "ungewöhnlich",
    "Ungewöhnlichen": "Ungewöhnliche",
    "Ungewöhnlicheren": "Ungewöhnlichere",
    "Ungewöhnlichsten": "Ungewöhnlichste",
    "Ungeziefern": "Ungeziefer",
    "Ungeziefers": "Ungeziefer",
    "Ungezogene": "ungezogen",
    "Ungezogenen": "Ungezogene",
    "Ungezogeneren": "Ungezogenere",
    "Ungezogenheiten": "Ungezogenheit",
    "Ungezogenste": "ungezogen",
    "Ungezogensten": "Ungezogenste",
    "Ungezwungenen": "Ungezwungene",
    "Ungezwungeneren": "Ungezwungenere",
    "Ungezwungensten": "Ungezwungenste",
    "Ungezählten": "Ungezählte",
    "Ungezähmten": "Ungezähmte",
    "Ungezügelten": "Ungezügelte",
    "Ungezügelteren": "Ungezügeltere",
    "Ungezügeltesten": "Ungezügelteste",
    "Unglauben": "Unglaube",
    "Unglaublichen": "Unglaubliche",
    "Unglaublicheren": "Unglaublichere",
    "Unglaublichsten": "Unglaublichste",
    "Unglaubwürdigen": "Unglaubwürdige",
    "Unglaubwürdigeren": "Unglaubwürdigere",
    "Unglaubwürdigsten": "Unglaubwürdigste",
    "Ungleichen": "Ungleiche",
    "Ungleicheren": "Ungleichere",
    "Ungleichheiten": "Ungleichheit",
    "Ungleichmäßige": "ungleichmäßig",
    "Ungleichmäßigen": "Ungleichmäßige",
    "Ungleichmäßigeren": "Ungleichmäßigere",
    "Ungleichmäßigkeiten": "Ungleichmäßigkeit",
    "Ungleichmäßigste": "ungleichmäßig",
    "Ungleichmäßigsten": "Ungleichmäßigste",
    "Ungleichsten": "Ungleichste",
    "Ungleichungen": "Ungleichung",
    "Ungläubige": "ungläubig",
    "Ungläubigen": "Ungläubige",
    "Ungläubigeren": "Ungläubigere",
    "Ungläubigsten": "Ungläubigste",
    "Unglücke": "Unglück",
    "Unglückes": "Unglück",
    "Unglückliche": "unglücklich",
    "Unglücklichen": "Unglückliche",
    "Unglücklicheren": "Unglücklichere",
    "Unglücklichsten": "Unglücklichste",
    "Unglücks": "Unglück",
    "Unguten": "Ungute",
    "Ungültige": "ungültig",
    "Ungültigen": "Ungültige",
    "Ungünstigen": "Ungünstige",
    "Ungünstigeren": "Ungünstigere",
    "Ungünstigsten": "Ungünstigste",
    "Unhandlichen": "Unhandliche",
    "Unhandlicheren": "Unhandlichere",
    "Unhandlichsten": "Unhandlichste",
    "Unheils": "Unheil",
    "Unheilvolle": "unheilvoll",
    "Unheilvollen": "Unheilvolle",
    "Unheilvolleren": "Unheilvollere",
    "Unheilvollsten": "Unheilvollste",
    "Unheimlichen": "Unheimliche",
    "Unheimlicheren": "Unheimlichere",
    "Unheimlichsten": "Unheimlichste",
    "Unholde": "Unhold",
    "Unholden": "Unhold",
    "Unholds": "Unhold",
    "Unhöflichen": "Unhöfliche",
    "Unhöflicheren": "Unhöflichere",
    "Unhöflichsten": "Unhöflichste",
    "Unifikationen": "Unifikation",
    "Unifizierenden": "Unifizierende",
    "Unifizierens": "Unifizieren",
    "Unifizierte": "unifiziert",
    "Unifizierten": "Unifizierte",
    "Unifizierungen": "Unifizierung",
    "Uniformierenden": "Uniformierende",
    "Uniformierens": "Uniformieren",
    "Uniformierte": "uniformiert",
    "Uniformierten": "Uniformierte",
    "Unikate": "Unikat",
    "Unikaten": "Unikat",
    "Unikats": "Unikat",
    "Unipolarmaschinen": "Unipolarmaschine",
    "Unis": "Uni",
    "Unitaristen": "Unitarist",
    "Universitäre": "universitär",
    "Universitären": "Universitäre",
    "Universitäreren": "Universitärere",
    "Universitärsten": "Universitärste",
    "Universitäten": "Universität",
    "Unkameradschaftliche": "unkameradschaftlich",
    "Unkameradschaftlichen": "Unkameradschaftliche",
    "Unkameradschaftlicheren": "Unkameradschaftlichere",
    "Unkenden": "Unkende",
    "Unkenderen": "Unkendere",
    "Unkendsten": "Unkendste",
    "Unkenntlichen": "Unkenntliche",
    "Unkenntlicheren": "Unkenntlichere",
    "Unkenntlichsten": "Unkenntlichste",
    "Unkenntnisse": "Unkenntnis",
    "Unkenntnissen": "Unkenntnis",
    "Unkens": "Unken",
    "Unklaren": "Unklare",
    "Unklareren": "Unklarere",
    "Unklarheiten": "Unklarheit",
    "Unklarste": "unklar",
    "Unklarsten": "Unklarste",
    "Unklugen": "Unkluge",
    "Unkollegialen": "Unkollegiale",
    "Unkollegialeren": "Unkollegialere",
    "Unkollegialsten": "Unkollegialste",
    "Unkomfortabelsten": "Unkomfortabelste",
    "Unkomfortablen": "Unkomfortable",
    "Unkomfortableren": "Unkomfortablere",
    "Unkonzentrierten": "Unkonzentrierte",
    "Unkonzentrierteren": "Unkonzentriertere",
    "Unkorrekten": "Unkorrekte",
    "Unkorrekteren": "Unkorrektere",
    "Unkorrektesten": "Unkorrekteste",
    "Unkorrektheiten": "Unkorrektheit",
    "Unkorrupte": "unkorrupt",
    "Unkorrupten": "Unkorrupte",
    "Unkorrupteren": "Unkorruptere",
    "Unkorruptesten": "Unkorrupteste",
    "Unkraute": "Unkraut",
    "Unkrautes": "Unkraut",
    "Unkrauts": "Unkraut",
    "Unkritische": "unkritisch",
    "Unkritischen": "Unkritische",
    "Unkritischeren": "Unkritischere",
    "Unkritischsten": "Unkritischste",
    "Unkräuter": "Unkraut",
    "Unkräutern": "Unkraut",
    "Unkundigen": "Unkundige",
    "Unkundigeren": "Unkundigere",
    "Unkundigsten": "Unkundigste",
    "Unlands": "Unland",
    "Unlautere": "unlauter",
    "Unlauteren": "Unlautere",
    "Unleserlichen": "Unleserliche",
    "Unleserlicheren": "Unleserlichere",
    "Unleserlichsten": "Unleserlichste",
    "Unlieben": "Unliebe",
    "Unliebsamen": "Unliebsame",
    "Unliebsameren": "Unliebsamere",
    "Unliebsamsten": "Unliebsamste",
    "Unlimitierten": "Unlimitierte",
    "Unlöslichen": "Unlösliche",
    "Unlüste": "Unlust",
    "Unlüsten": "Unlust",
    "Unmaßgeblichen": "Unmaßgebliche",
    "Unmengen": "Unmenge",
    "Unmenschen": "Unmensch",
    "Unmittelbaren": "Unmittelbare",
    "Unmittelbareren": "Unmittelbarere",
    "Unmittelbarsten": "Unmittelbarste",
    "Unmißverständliche": "unmißverständlich",
    "Unmißverständlichen": "Unmißverständliche",
    "Unmodernen": "Unmoderne",
    "Unmoderneren": "Unmodernere",
    "Unmodernsten": "Unmodernste",
    "Unmoralischen": "Unmoralische",
    "Unmoralischeren": "Unmoralischere",
    "Unmoralischsten": "Unmoralischste",
    "Unmusikalischen": "Unmusikalische",
    "Unmusikalischeren": "Unmusikalischere",
    "Unmusikalischsten": "Unmusikalischste",
    "Unmute": "Unmut",
    "Unmutes": "Unmut",
    "Unmuts": "Unmut",
    "Unmännliche": "unmännlich",
    "Unmännlichen": "Unmännliche",
    "Unmännlicheren": "Unmännlichere",
    "Unmännlichsten": "Unmännlichste",
    "Unmöglichen": "Unmögliche",
    "Unmöglicheren": "Unmöglichere",
    "Unmöglichkeiten": "Unmöglichkeit",
    "Unmöglichste": "unmöglich",
    "Unmöglichsten": "Unmöglichste",
    "Unmündigen": "Unmündige",
    "Unnachgiebige": "unnachgiebig",
    "Unnachgiebigen": "Unnachgiebige",
    "Unnachgiebigeren": "Unnachgiebigere",
    "Unnachgiebigsten": "Unnachgiebigste",
    "Unnachsichtigen": "Unnachsichtige",
    "Unnachsichtigeren": "Unnachsichtigere",
    "Unnachsichtigsten": "Unnachsichtigste",
    "Unnahbaren": "Unnahbare",
    "Unnahbareren": "Unnahbarere",
    "Unnahbarsten": "Unnahbarste",
    "Unnatürlichen": "Unnatürliche",
    "Unnatürlicheren": "Unnatürlichere",
    "Unnatürlichsten": "Unnatürlichste",
    "Unnormalen": "Unnormale",
    "Unnötigen": "Unnötige",
    "Unnötigeren": "Unnötigere",
    "Unnötigsten": "Unnötigste",
    "Unnützen": "Unnütze",
    "Unordentlichen": "Unordentliche",
    "Unordentlicheren": "Unordentlichere",
    "Unordentlichsten": "Unordentlichste",
    "Unordnungen": "Unordnung",
    "Unorthodoxe": "unorthodox",
    "Unorthodoxen": "Unorthodoxe",
    "Unorthodoxeren": "Unorthodoxere",
    "Unorthodoxesten": "Unorthodoxeste",
    "Unparteiischen": "Unparteiische",
    "Unparteiischeren": "Unparteiischere",
    "Unparteiischsten": "Unparteiischste",
    "Unpassenden": "Unpassende",
    "Unpassenderen": "Unpassendere",
    "Unpassendsten": "Unpassendste",
    "Unpersonen": "Unperson",
    "Unpersönliche": "unpersönlich",
    "Unpersönlichen": "Unpersönliche",
    "Unpersönlicheren": "Unpersönlichere",
    "Unpersönlichsten": "Unpersönlichste",
    "Unpolitischen": "Unpolitische",
    "Unpolitischeren": "Unpolitischere",
    "Unpolitischsten": "Unpolitischste",
    "Unpopulären": "Unpopuläre",
    "Unpopuläreren": "Unpopulärere",
    "Unpopulärsten": "Unpopulärste",
    "Unpraktikabelsten": "Unpraktikabelste",
    "Unpraktikablen": "Unpraktikable",
    "Unpraktikableren": "Unpraktikablere",
    "Unpraktischen": "Unpraktische",
    "Unpraktischeren": "Unpraktischere",
    "Unpraktischsten": "Unpraktischste",
    "Unproblematischen": "Unproblematische",
    "Unproblematischeren": "Unproblematischere",
    "Unproduktiven": "Unproduktive",
    "Unproduktiveren": "Unproduktivere",
    "Unproduktivsten": "Unproduktivste",
    "Unpräzisen": "Unpräzise",
    "Unpräziseren": "Unpräzisere",
    "Unpräzisesten": "Unpräziseste",
    "Unpäßlichen": "Unpäßliche",
    "Unpäßlichkeiten": "Unpäßlichkeit",
    "Unpünktlichen": "Unpünktliche",
    "Unpünktlicheren": "Unpünktlichere",
    "Unpünktlichsten": "Unpünktlichste",
    "Unqualifizierten": "Unqualifizierte",
    "Unqualifizierteren": "Unqualifiziertere",
    "Unrasierten": "Unrasierte",
    "Unrasierteren": "Unrasiertere",
    "Unrasiertesten": "Unrasierteste",
    "Unrats": "Unrat",
    "Unrealistische": "unrealistisch",
    "Unrealistischen": "Unrealistische",
    "Unrealistischeren": "Unrealistischere",
    "Unrealistischsten": "Unrealistischste",
    "Unrechten": "Unrechte",
    "Unrechteren": "Unrechtere",
    "Unrechteste": "unrecht",
    "Unrechtesten": "Unrechteste",
    "Unrechtmäßigen": "Unrechtmäßige",
    "Unrechts": "Unrecht",
    "Unreflektierte": "unreflektiert",
    "Unreflektierten": "Unreflektierte",
    "Unreflektierteren": "Unreflektiertere",
    "Unregelmäßigen": "Unregelmäßige",
    "Unregelmäßigeren": "Unregelmäßigere",
    "Unregelmäßigkeiten": "Unregelmäßigkeit",
    "Unregelmäßigste": "unregelmäßig",
    "Unregelmäßigsten": "Unregelmäßigste",
    "Unreifen": "Unreife",
    "Unreiferen": "Unreifere",
    "Unreifsten": "Unreifste",
    "Unreinen": "Unreine",
    "Unreineren": "Unreinere",
    "Unreinsten": "Unreinste",
    "Unrentablen": "Unrentable",
    "Unrichtigkeiten": "Unrichtigkeit",
    "Unruhen": "Unruhe",
    "Unruhige": "unruhig",
    "Unruhigen": "Unruhige",
    "Unruhigeren": "Unruhigere",
    "Unruhigsten": "Unruhigste",
    "Unrunden": "Unrunde",
    "Unrunderen": "Unrundere",
    "Unrundesten": "Unrundeste",
    "Unrühmlichen": "Unrühmliche",
    "Unrühmlicheren": "Unrühmlichere",
    "Unrühmlichsten": "Unrühmlichste",
    "Unsachgemäßen": "Unsachgemäße",
    "Unsachlichen": "Unsachliche",
    "Unsachlicheren": "Unsachlichere",
    "Unsachlichsten": "Unsachlichste",
    "Unsagbaren": "Unsagbare",
    "Unsagbareren": "Unsagbarere",
    "Unsagbarsten": "Unsagbarste",
    "Unsanften": "Unsanfte",
    "Unsanfteren": "Unsanftere",
    "Unsanftesten": "Unsanfteste",
    "Unsauberen": "Unsaubere",
    "Unscharfen": "Unscharfe",
    "Unscheinbaren": "Unscheinbare",
    "Unscheinbareren": "Unscheinbarere",
    "Unscheinbarsten": "Unscheinbarste",
    "Unschlagbaren": "Unschlagbare",
    "Unschlüssigen": "Unschlüssige",
    "Unschlüssigeren": "Unschlüssigere",
    "Unschlüssigsten": "Unschlüssigste",
    "Unschuldigen": "Unschuldige",
    "Unschuldigeren": "Unschuldigere",
    "Unschuldigsten": "Unschuldigste",
    "Unschuldsbeteuerungen": "Unschuldsbeteuerung",
    "Unschädlichen": "Unschädliche",
    "Unschönen": "Unschöne",
    "Unschöneren": "Unschönere",
    "Unschönsten": "Unschönste",
    "Unselbständige": "unselbständig",
    "Unselbständigen": "Unselbständige",
    "Unselbständigeren": "Unselbständigere",
    "Unselbständigsten": "Unselbständigste",
    "Unsicheren": "Unsichere",
    "Unsichereren": "Unsicherere",
    "Unsicherheiten": "Unsicherheit",
    "Unsicherste": "unsicher",
    "Unsichersten": "Unsicherste",
    "Unsichtbaren": "Unsichtbare",
    "Unsichtbareren": "Unsichtbarere",
    "Unsichtbarsten": "Unsichtbarste",
    "Unsinnigen": "Unsinnige",
    "Unsinnigeren": "Unsinnigere",
    "Unsinnigsten": "Unsinnigste",
    "Unsinns": "Unsinn",
    "Unsitten": "Unsitte",
    "Unsittliche": "unsittlich",
    "Unsittlichen": "Unsittliche",
    "Unsittlicheren": "Unsittlichere",
    "Unsittlichsten": "Unsittlichste",
    "Unsozialen": "Unsoziale",
    "Unsozialeren": "Unsozialere",
    "Unsozialsten": "Unsozialste",
    "Unsportlichen": "Unsportliche",
    "Unsportlicheren": "Unsportlichere",
    "Unsportlichsten": "Unsportlichste",
    "Unsterblichen": "Unsterbliche",
    "Unsterblicheren": "Unsterblichere",
    "Unsterblichsten": "Unsterblichste",
    "Unstimmigen": "Unstimmige",
    "Unstimmigeren": "Unstimmigere",
    "Unstimmigkeiten": "Unstimmigkeit",
    "Unstimmigste": "unstimmig",
    "Unstimmigsten": "Unstimmigste",
    "Unsummen": "Unsumme",
    "Unsympathische": "unsympathisch",
    "Unsympathischen": "Unsympathische",
    "Unsympathischeren": "Unsympathischere",
    "Unsympathischsten": "Unsympathischste",
    "Unsystematischen": "Unsystematische",
    "Unsystematischeren": "Unsystematischere",
    "Untalentierten": "Untalentierte",
    "Untalentierteren": "Untalentiertere",
    "Untalentiertesten": "Untalentierteste",
    "Untaten": "Untat",
    "Untauglichen": "Untaugliche",
    "Untauglicheren": "Untauglichere",
    "Untauglichsten": "Untauglichste",
    "Untenliegenden": "Untenliegende",
    "Untenstehenden": "Untenstehende",
    "Unterabteilungen": "Unterabteilung",
    "Unterarme": "Unterarm",
    "Unterarmen": "Unterarm",
    "Unterarms": "Unterarm",
    "Unterarten": "Unterart",
    "Unterbaus": "Unterbau",
    "Unterbauten": "Unterbau",
    "Unterbegriffe": "Unterbegriff",
    "Unterbegriffen": "Unterbegriff",
    "Unterbegriffs": "Unterbegriff",
    "Unterbelegte": "unterbelegt",
    "Unterbelegten": "Unterbelegte",
    "Unterbelichtungen": "Unterbelichtung",
    "Unterbette": "Unterbett",
    "Unterbetten": "Unterbett",
    "Unterbetts": "Unterbett",
    "Unterbewerte": "unterbewerten",
    "Unterbewertenden": "Unterbewertende",
    "Unterbewertenderen": "Unterbewertendere",
    "Unterbewertens": "Unterbewerten",
    "Unterbewertete": "unterbewertet",
    "Unterbewerteten": "Unterbewertete",
    "Unterbewerteteren": "Unterbewertetere",
    "Unterbewerteteste": "unterbewertet",
    "Unterbewertungen": "Unterbewertung",
    "Unterbewußte": "unterbewußt",
    "Unterbewußten": "Unterbewußte",
    "Unterbewußtseins": "Unterbewußtsein",
    "Unterbezahlte": "unterbezahlt",
    "Unterbezahlten": "Unterbezahlte",
    "Unterbietenden": "Unterbietende",
    "Unterbietens": "Unterbieten",
    "Unterbilanzen": "Unterbilanz",
    "Unterbindenden": "Unterbindende",
    "Unterbindens": "Unterbinden",
    "Unterbleibenden": "Unterbleibende",
    "Unterbleibens": "Unterbleiben",
    "Unterbliebenen": "Unterbliebene",
    "Unterbodens": "Unterboden",
    "Unterbotenen": "Unterbotene",
    "Unterbrechenden": "Unterbrechende",
    "Unterbrechens": "Unterbrechen",
    "Unterbrechern": "Unterbrecher",
    "Unterbrechers": "Unterbrecher",
    "Unterbrechungen": "Unterbrechung",
    "Unterbreitenden": "Unterbreitende",
    "Unterbreitens": "Unterbreiten",
    "Unterbreitete": "unterbreitet",
    "Unterbreiteten": "Unterbreitete",
    "Unterbringenden": "Unterbringende",
    "Unterbringens": "Unterbringen",
    "Unterbringungen": "Unterbringung",
    "Unterbrochenen": "Unterbrochene",
    "Unterbundenen": "Unterbundene",
    "Unterböden": "Unterboden",
    "Unterdominanten": "Unterdominante",
    "Unterdrückenden": "Unterdrückende",
    "Unterdrückenderen": "Unterdrückendere",
    "Unterdrückendsten": "Unterdrückendste",
    "Unterdrückens": "Unterdrücken",
    "Unterdrückte": "unterdrückt",
    "Unterdrückten": "Unterdrückte",
    "Unterdrückteren": "Unterdrücktere",
    "Unterdrücktesten": "Unterdrückteste",
    "Unterdrückungen": "Unterdrückung",
    "Untere": "unter",
    "Unteren": "Untere",
    "Unterentwickelte": "unterentwickelt",
    "Unterentwickelten": "Unterentwickelte",
    "Unterentwickelteren": "Unterentwickeltere",
    "Untereren": "Unterere",
    "Unterernährten": "Unterernährte",
    "Unterernährungen": "Unterernährung",
    "Unterfangens": "Unterfangen",
    "Unterfassenden": "Unterfassende",
    "Unterfassens": "Unterfassen",
    "Unterfunktionen": "Unterfunktion",
    "Unterfutters": "Unterfutter",
    "Unterführungen": "Unterführung",
    "Untergange": "Untergang",
    "Unterganges": "Untergang",
    "Untergangs": "Untergang",
    "Untergattungen": "Untergattung",
    "Untergebene": "untergeben",
    "Untergebenen": "Untergebene",
    "Untergebrachten": "Untergebrachte",
    "Untergefaßten": "Untergefaßte",
    "Untergegangenen": "Untergegangene",
    "Untergehakten": "Untergehakte",
    "Untergehenden": "Untergehende",
    "Untergehens": "Untergehen",
    "Untergejubelten": "Untergejubelte",
    "Untergejubelteren": "Untergejubeltere",
    "Untergekommenen": "Untergekommene",
    "Untergekriegten": "Untergekriegte",
    "Untergekrochenen": "Untergekrochene",
    "Untergemengten": "Untergemengte",
    "Untergemischten": "Untergemischte",
    "Untergeordneten": "Untergeordnete",
    "Untergeordneteren": "Untergeordnetere",
    "Untergepflügten": "Untergepflügte",
    "Untergeschlagenen": "Untergeschlagene",
    "Untergeschlüpften": "Untergeschlüpfte",
    "Untergeschobenen": "Untergeschobene",
    "Untergesetzten": "Untergesetzte",
    "Untergestelle": "Untergestell",
    "Untergestellen": "Untergestell",
    "Untergestells": "Untergestell",
    "Untergestellten": "Untergestellte",
    "Untergestreuten": "Untergestreute",
    "Untergesunkenen": "Untergesunkene",
    "Untergetauchten": "Untergetauchte",
    "Untergetauchteren": "Untergetauchtere",
    "Untergetretenen": "Untergetretene",
    "Untergewande": "Untergewand",
    "Untergewandes": "Untergewand",
    "Untergewands": "Untergewand",
    "Untergewänder": "Untergewand",
    "Untergewändern": "Untergewand",
    "Untergliedernden": "Untergliedernde",
    "Untergliederns": "Untergliedern",
    "Untergliederte": "untergliedert",
    "Untergliederten": "Untergliederte",
    "Untergliederungen": "Untergliederung",
    "Untergrabenden": "Untergrabende",
    "Untergrabenderen": "Untergrabendere",
    "Untergrabendsten": "Untergrabendste",
    "Untergrabenen": "Untergrabene",
    "Untergrabeneren": "Untergrabenere",
    "Untergrabens": "Untergraben",
    "Untergrabenste": "untergraben",
    "Untergrabensten": "Untergrabenste",
    "Untergrunds": "Untergrund",
    "Untergruppen": "Untergruppe",
    "Untergründigen": "Untergründige",
    "Untergründigeren": "Untergründigere",
    "Untergründigsten": "Untergründigste",
    "Untergänge": "Untergang",
    "Untergängen": "Untergang",
    "Unterhachings": "Unterhaching",
    "Unterhakenden": "Unterhakende",
    "Unterhakens": "Unterhaken",
    "Unterhalt": "unterhalten",
    "Unterhalte": "unterhalten",
    "Unterhaltenden": "Unterhaltende",
    "Unterhaltenderen": "Unterhaltendere",
    "Unterhaltendsten": "Unterhaltendste",
    "Unterhaltenen": "Unterhaltene",
    "Unterhaltens": "Unterhalten",
    "Unterhaltern": "Unterhalter",
    "Unterhalters": "Unterhalter",
    "Unterhaltes": "Unterhalt",
    "Unterhalts": "Unterhalt",
    "Unterhaltsame": "unterhaltsam",
    "Unterhaltsamen": "Unterhaltsame",
    "Unterhaltsameren": "Unterhaltsamere",
    "Unterhaltsamsten": "Unterhaltsamste",
    "Unterhaltsberechtigten": "Unterhaltsberechtigte",
    "Unterhaltspflichtigen": "Unterhaltspflichtige",
    "Unterhaltungen": "Unterhaltung",
    "Unterhandlungen": "Unterhandlung",
    "Unterhemde": "Unterhemd",
    "Unterhemden": "Unterhemd",
    "Unterhemds": "Unterhemd",
    "Unterhosen": "Unterhose",
    "Unterhändlern": "Unterhändler",
    "Unterhändlers": "Unterhändler",
    "Unterjubelnden": "Unterjubelnde",
    "Unterjubelnderen": "Unterjubelndere",
    "Unterjubelndsten": "Unterjubelndste",
    "Unterjubelns": "Unterjubeln",
    "Unterkellernden": "Unterkellernde",
    "Unterkellerns": "Unterkellern",
    "Unterkellerte": "unterkellert",
    "Unterkellerten": "Unterkellerte",
    "Unterkinne": "Unterkinn",
    "Unterkinnen": "Unterkinn",
    "Unterkinns": "Unterkinn",
    "Unterkleide": "Unterkleid",
    "Unterkleider": "Unterkleid",
    "Unterkleidern": "Unterkleid",
    "Unterkleides": "Unterkleid",
    "Unterkleids": "Unterkleid",
    "Unterkommenden": "Unterkommende",
    "Unterkommens": "Unterkommen",
    "Unterkriechenden": "Unterkriechende",
    "Unterkriechens": "Unterkriechen",
    "Unterkriegenden": "Unterkriegende",
    "Unterkriegens": "Unterkriegen",
    "Unterkörpern": "Unterkörper",
    "Unterkörpers": "Unterkörper",
    "Unterkühlenden": "Unterkühlende",
    "Unterkühlenderen": "Unterkühlendere",
    "Unterkühlendsten": "Unterkühlendste",
    "Unterkühlens": "Unterkühlen",
    "Unterkühlte": "unterkühlt",
    "Unterkühlten": "Unterkühlte",
    "Unterkühlteren": "Unterkühltere",
    "Unterkühltesten": "Unterkühlteste",
    "Unterkünfte": "Unterkunft",
    "Unterkünften": "Unterkunft",
    "Unterlagen": "unterliegen",
    "Unterlands": "Unterland",
    "Unterlassenden": "Unterlassende",
    "Unterlassenen": "Unterlassene",
    "Unterlassens": "Unterlassen",
    "Unterlassungsklagen": "Unterlassungsklage",
    "Unterlaufenden": "Unterlaufende",
    "Unterlaufenen": "Unterlaufene",
    "Unterlaufens": "Unterlaufen",
    "Unterlegenen": "Unterlegene",
    "Unterlegeneren": "Unterlegenere",
    "Unterlegensten": "Unterlegenste",
    "Unterleibe": "Unterleib",
    "Unterleiber": "Unterleib",
    "Unterleibern": "Unterleib",
    "Unterleibes": "Unterleib",
    "Unterleibs": "Unterleib",
    "Unterlide": "Unterlid",
    "Unterlider": "Unterlid",
    "Unterlidern": "Unterlid",
    "Unterlides": "Unterlid",
    "Unterlids": "Unterlid",
    "Unterliegenden": "Unterliegende",
    "Unterliegens": "Unterliegen",
    "Unterlippen": "Unterlippe",
    "Untermalenden": "Untermalende",
    "Untermalens": "Untermalen",
    "Untermalte": "untermalt",
    "Untermalten": "Untermalte",
    "Untermanne": "Untermann",
    "Untermannes": "Untermann",
    "Untermanns": "Untermann",
    "Untermauernden": "Untermauernde",
    "Untermauerns": "Untermauern",
    "Untermauerte": "untermauert",
    "Untermauerten": "Untermauerte",
    "Untermengenden": "Untermengende",
    "Untermengens": "Untermengen",
    "Untermietern": "Untermieter",
    "Untermieters": "Untermieter",
    "Unterminierungen": "Unterminierung",
    "Untermischenden": "Untermischende",
    "Untermischens": "Untermischen",
    "Untermänner": "Untermann",
    "Untermännern": "Untermann",
    "Unternehmenden": "Unternehmende",
    "Unternehmenderen": "Unternehmendere",
    "Unternehmendsten": "Unternehmendste",
    "Unternehmens": "Unternehmen",
    "Unternehmern": "Unternehmer",
    "Unternehmers": "Unternehmer",
    "Unternehmertums": "Unternehmertum",
    "Unternehmungen": "Unternehmung",
    "Unternehmungslustige": "unternehmungslustig",
    "Unternehmungslustigen": "Unternehmungslustige",
    "Unternehmungslustigeren": "Unternehmungslustigere",
    "Unternommenen": "Unternommene",
    "Unteroffiziere": "Unteroffizier",
    "Unteroffizieren": "Unteroffizier",
    "Unteroffiziers": "Unteroffizier",
    "Unterordnenden": "Unterordnende",
    "Unterordnenderen": "Unterordnendere",
    "Unterordnendsten": "Unterordnendste",
    "Unterordnens": "Unterordnen",
    "Unterordnungen": "Unterordnung",
    "Unterpflügenden": "Unterpflügende",
    "Unterpflügens": "Unterpflügen",
    "Unterquerenden": "Unterquerende",
    "Unterquerens": "Unterqueren",
    "Unterquerte": "unterquert",
    "Unterquerten": "Unterquerte",
    "Unterrepräsentierten": "Unterrepräsentierte",
    "Unterrichte": "unterrichten",
    "Unterrichten": "Unterricht",
    "Unterrichtenden": "Unterrichtende",
    "Unterrichtens": "Unterrichten",
    "Unterrichtete": "unterrichtet",
    "Unterrichteten": "Unterrichtete",
    "Unterrichtlichen": "Unterrichtliche",
    "Unterrichts": "Unterricht",
    "Unterrichtungen": "Unterrichtung",
    "Unterrocke": "Unterrock",
    "Unterrocks": "Unterrock",
    "Unterröcke": "Unterrock",
    "Unterröcken": "Unterrock",
    "Untersagenden": "Untersagende",
    "Untersagens": "Untersagen",
    "Untersagte": "untersagt",
    "Untersagten": "Untersagte",
    "Unterscheidbaren": "Unterscheidbare",
    "Unterscheidenden": "Unterscheidende",
    "Unterscheidens": "Unterscheiden",
    "Unterscheidungen": "Unterscheidung",
    "Unterschenkeln": "Unterschenkel",
    "Unterschenkels": "Unterschenkel",
    "Unterschichten": "Unterschicht",
    "Unterschiebenden": "Unterschiebende",
    "Unterschiebens": "Unterschieben",
    "Unterschiede": "Unterschied",
    "Unterschieden": "Unterschied",
    "Unterschiedene": "unterschieden",
    "Unterschiedenen": "Unterschiedene",
    "Unterschiedeneren": "Unterschiedenere",
    "Unterschiedensten": "Unterschiedenste",
    "Unterschiedes": "Unterschied",
    "Unterschiedlichen": "Unterschiedliche",
    "Unterschiedlicheren": "Unterschiedlichere",
    "Unterschieds": "Unterschied",
    "Unterschlagenden": "Unterschlagende",
    "Unterschlagenen": "Unterschlagene",
    "Unterschlagens": "Unterschlagen",
    "Unterschlagungen": "Unterschlagung",
    "Unterschlüpfenden": "Unterschlüpfende",
    "Unterschlüpfens": "Unterschlüpfen",
    "Unterschreibenden": "Unterschreibende",
    "Unterschreibens": "Unterschreiben",
    "Unterschreitenden": "Unterschreitende",
    "Unterschreitens": "Unterschreiten",
    "Unterschriebenen": "Unterschriebene",
    "Unterschriften": "Unterschrift",
    "Unterschrittenen": "Unterschrittene",
    "Unterschwelligen": "Unterschwellige",
    "Unterschätzenden": "Unterschätzende",
    "Unterschätzens": "Unterschätzen",
    "Unterschätzte": "unterschätzt",
    "Unterschätzten": "Unterschätzte",
    "Unterschätzteren": "Unterschätztere",
    "Unterschätztesten": "Unterschätzteste",
    "Unterseiten": "Unterseite",
    "Untersetzenden": "Untersetzende",
    "Untersetzens": "Untersetzen",
    "Untersetzern": "Untersetzer",
    "Untersetzers": "Untersetzer",
    "Untersinkenden": "Untersinkende",
    "Untersinkens": "Untersinken",
    "Unterspülenden": "Unterspülende",
    "Unterspülens": "Unterspülen",
    "Unterspülte": "unterspült",
    "Unterspülten": "Unterspülte",
    "Unterstandenen": "Unterstandene",
    "Unterstehenden": "Unterstehende",
    "Unterstehens": "Unterstehen",
    "Unterstellenden": "Unterstellende",
    "Unterstellenderen": "Unterstellendere",
    "Unterstellendsten": "Unterstellendste",
    "Unterstellens": "Unterstellen",
    "Unterstellte": "unterstellt",
    "Unterstellten": "Unterstellte",
    "Unterstellungen": "Unterstellung",
    "Untersten": "Unterste",
    "Unterstreichenden": "Unterstreichende",
    "Unterstreichens": "Unterstreichen",
    "Unterstreuenden": "Unterstreuende",
    "Unterstreuens": "Unterstreuen",
    "Unterstrichenen": "Unterstrichene",
    "Unterstützenden": "Unterstützende",
    "Unterstützenderen": "Unterstützendere",
    "Unterstützendsten": "Unterstützendste",
    "Unterstützens": "Unterstützen",
    "Unterstützte": "unterstützt",
    "Unterstützten": "Unterstützte",
    "Unterstützteren": "Unterstütztere",
    "Unterstütztesten": "Unterstützteste",
    "Unterstützungen": "Unterstützung",
    "Untersuchenden": "Untersuchende",
    "Untersuchens": "Untersuchen",
    "Untersuchte": "untersucht",
    "Untersuchten": "Untersuchte",
    "Untersuchungen": "Untersuchung",
    "Untertassen": "Untertasse",
    "Untertauchenden": "Untertauchende",
    "Untertauchenderen": "Untertauchendere",
    "Untertauchendsten": "Untertauchendste",
    "Untertauchens": "Untertauchen",
    "Unterteilenden": "Unterteilende",
    "Unterteilens": "Unterteilen",
    "Unterteilte": "unterteilt",
    "Unterteilten": "Unterteilte",
    "Unterteilungen": "Unterteilung",
    "Untertiteln": "Untertitel",
    "Untertitels": "Untertitel",
    "Untertone": "Unterton",
    "Untertons": "Unterton",
    "Untertreibenden": "Untertreibende",
    "Untertreibens": "Untertreiben",
    "Untertretenden": "Untertretende",
    "Untertretens": "Untertreten",
    "Untertriebenen": "Untertriebene",
    "Untertunnelnden": "Untertunnelnde",
    "Untertunnelns": "Untertunneln",
    "Untertunnelte": "untertunnelt",
    "Untertunnelten": "Untertunnelte",
    "Untertöne": "Unterton",
    "Untertönen": "Unterton",
    "Untervermietenden": "Untervermietende",
    "Untervermietens": "Untervermieten",
    "Untervermietete": "untervermietet",
    "Untervermieteten": "Untervermietete",
    "Unterversichernden": "Unterversichernde",
    "Unterversicherns": "Unterversichern",
    "Unterversicherte": "unterversichert",
    "Unterversicherten": "Unterversicherte",
    "Unterversorgungen": "Unterversorgung",
    "Unterwandernden": "Unterwandernde",
    "Unterwanderns": "Unterwandern",
    "Unterwanderte": "unterwandert",
    "Unterwanderten": "Unterwanderte",
    "Unterwanderungen": "Unterwanderung",
    "Unterwasserkameras": "Unterwasserkamera",
    "Unterweisenden": "Unterweisende",
    "Unterweisens": "Unterweisen",
    "Unterweisungen": "Unterweisung",
    "Unterwerfenden": "Unterwerfende",
    "Unterwerfens": "Unterwerfen",
    "Unterwiesenen": "Unterwiesene",
    "Unterworfenen": "Unterworfene",
    "Unterwürfigen": "Unterwürfige",
    "Unterwürfigeren": "Unterwürfigere",
    "Unterwürfigsten": "Unterwürfigste",
    "Unterzeichnenden": "Unterzeichnende",
    "Unterzeichnens": "Unterzeichnen",
    "Unterzeichnete": "unterzeichnet",
    "Unterzeichneten": "Unterzeichnete",
    "Unterzeichnungen": "Unterzeichnung",
    "Unterziehenden": "Unterziehende",
    "Unterziehens": "Unterziehen",
    "Unterzogenen": "Unterzogene",
    "Unterzuge": "Unterzug",
    "Unterzugs": "Unterzug",
    "Unterzüge": "Unterzug",
    "Unterzügen": "Unterzug",
    "Untiefen": "Untiefe",
    "Untragbare": "untragbar",
    "Untragbaren": "Untragbare",
    "Untragbareren": "Untragbarere",
    "Untragbarsten": "Untragbarste",
    "Untreuen": "Untreue",
    "Untreueren": "Untreuere",
    "Untreusten": "Untreuste",
    "Untugenden": "Untugend",
    "Untätige": "untätig",
    "Untätigen": "Untätige",
    "Untüchtigen": "Untüchtige",
    "Untüchtigeren": "Untüchtigere",
    "Untüchtigsten": "Untüchtigste",
    "Unumstrittenen": "Unumstrittene",
    "Unumstritteneren": "Unumstrittenere",
    "Unumstrittensten": "Unumstrittenste",
    "Ununterbrochenen": "Ununterbrochene",
    "Unverantwortlichen": "Unverantwortliche",
    "Unverantwortlicheren": "Unverantwortlichere",
    "Unverbindlichen": "Unverbindliche",
    "Unverbindlicheren": "Unverbindlichere",
    "Unverbindlichsten": "Unverbindlichste",
    "Unverdaulichen": "Unverdauliche",
    "Unverdauten": "Unverdaute",
    "Unverdienten": "Unverdiente",
    "Unverdienteren": "Unverdientere",
    "Unverdientesten": "Unverdienteste",
    "Unverdorbenen": "Unverdorbene",
    "Unverdorbeneren": "Unverdorbenere",
    "Unverdorbensten": "Unverdorbenste",
    "Unverdächtigen": "Unverdächtige",
    "Unverdächtigeren": "Unverdächtigere",
    "Unverdächtigsten": "Unverdächtigste",
    "Unverdünnten": "Unverdünnte",
    "Unverdünnteren": "Unverdünntere",
    "Unverdünntesten": "Unverdünnteste",
    "Unverfrorenen": "Unverfrorene",
    "Unverfroreneren": "Unverfrorenere",
    "Unverfrorensten": "Unverfrorenste",
    "Unverfälschten": "Unverfälschte",
    "Unverfänglichen": "Unverfängliche",
    "Unvergessenen": "Unvergessene",
    "Unvergleichlichen": "Unvergleichliche",
    "Unvergleichlicheren": "Unvergleichlichere",
    "Unverheirateten": "Unverheiratete",
    "Unverhofften": "Unverhoffte",
    "Unverhältnismäßigen": "Unverhältnismäßige",
    "Unverhüllten": "Unverhüllte",
    "Unverkrampften": "Unverkrampfte",
    "Unverkrampfteren": "Unverkrampftere",
    "Unverkrampftesten": "Unverkrampfteste",
    "Unverletzten": "Unverletzte",
    "Unverletzteren": "Unverletztere",
    "Unverletztesten": "Unverletzteste",
    "Unverläßlichen": "Unverläßliche",
    "Unverläßlicheren": "Unverläßlichere",
    "Unverläßlichsten": "Unverläßlichste",
    "Unvermeidbaren": "Unvermeidbare",
    "Unvermeidlichen": "Unvermeidliche",
    "Unvermeidlicheren": "Unvermeidlichere",
    "Unvermeidlichsten": "Unvermeidlichste",
    "Unverminderten": "Unverminderte",
    "Unverminderteren": "Unvermindertere",
    "Unvermindertesten": "Unverminderteste",
    "Unvermittelten": "Unvermittelte",
    "Unvermutete": "unvermutet",
    "Unvermuteten": "Unvermutete",
    "Unvermählten": "Unvermählte",
    "Unvermögens": "Unvermögen",
    "Unvernünftigen": "Unvernünftige",
    "Unvernünftigeren": "Unvernünftigere",
    "Unvernünftigsten": "Unvernünftigste",
    "Unverrichteten": "Unverrichtete",
    "Unverschämten": "Unverschämte",
    "Unverschämteren": "Unverschämtere",
    "Unverschämtesten": "Unverschämteste",
    "Unverschämtheiten": "Unverschämtheit",
    "Unverstande": "Unverstand",
    "Unverstandene": "unverstanden",
    "Unverstandenen": "Unverstandene",
    "Unverstandeneren": "Unverstandenere",
    "Unverstandensten": "Unverstandenste",
    "Unverstandes": "Unverstand",
    "Unverstands": "Unverstand",
    "Unversteuerte": "unversteuert",
    "Unversteuerten": "Unversteuerte",
    "Unverständliche": "unverständlich",
    "Unverständlichen": "Unverständliche",
    "Unverständlicheren": "Unverständlichere",
    "Unverständnisse": "Unverständnis",
    "Unverständnissen": "Unverständnis",
    "Unverständnisses": "Unverständnis",
    "Unversuchten": "Unversuchte",
    "Unverträglichen": "Unverträgliche",
    "Unverträglicheren": "Unverträglichere",
    "Unverträglichkeiten": "Unverträglichkeit",
    "Unverträglichste": "unverträglich",
    "Unverträglichsten": "Unverträglichste",
    "Unverwechselbaren": "Unverwechselbare",
    "Unverwechselbareren": "Unverwechselbarere",
    "Unverzichtbaren": "Unverzichtbare",
    "Unverzichtbareren": "Unverzichtbarere",
    "Unverzichtbarsten": "Unverzichtbarste",
    "Unverzinslichen": "Unverzinsliche",
    "Unverzollten": "Unverzollte",
    "Unverzüglichen": "Unverzügliche",
    "Unverzüglicheren": "Unverzüglichere",
    "Unverzüglichsten": "Unverzüglichste",
    "Unveränderten": "Unveränderte",
    "Unveröffentlichten": "Unveröffentlichte",
    "Unvollkommenen": "Unvollkommene",
    "Unvollkommeneren": "Unvollkommenere",
    "Unvollkommenheiten": "Unvollkommenheit",
    "Unvollkommenste": "unvollkommen",
    "Unvollkommensten": "Unvollkommenste",
    "Unvollständigen": "Unvollständige",
    "Unvollständigeren": "Unvollständigere",
    "Unvollständigsten": "Unvollständigste",
    "Unvorbereiteten": "Unvorbereitete",
    "Unvoreingenommenen": "Unvoreingenommene",
    "Unvorhergesehenen": "Unvorhergesehene",
    "Unvorschriftsmäßigen": "Unvorschriftsmäßige",
    "Unvorsichtigen": "Unvorsichtige",
    "Unvorsichtigeren": "Unvorsichtigere",
    "Unvorsichtigsten": "Unvorsichtigste",
    "Unvorstellbaren": "Unvorstellbare",
    "Unvorstellbareren": "Unvorstellbarere",
    "Unvorstellbarsten": "Unvorstellbarste",
    "Unvorteilhaften": "Unvorteilhafte",
    "Unvorteilhafteren": "Unvorteilhaftere",
    "Unwahren": "Unwahre",
    "Unwahrscheinlichen": "Unwahrscheinliche",
    "Unwahrscheinlicheren": "Unwahrscheinlichere",
    "Unwegsamen": "Unwegsame",
    "Unweigerlichen": "Unweigerliche",
    "Unweigerlicheren": "Unweigerlichere",
    "Unweigerlichsten": "Unweigerlichste",
    "Unwesens": "Unwesen",
    "Unwesentliche": "unwesentlich",
    "Unwesentlichen": "Unwesentliche",
    "Unwettern": "Unwetter",
    "Unwetters": "Unwetter",
    "Unwichtige": "unwichtig",
    "Unwichtigen": "Unwichtige",
    "Unwichtigeren": "Unwichtigere",
    "Unwichtigsten": "Unwichtigste",
    "Unwiderruflichen": "Unwiderrufliche",
    "Unwillen": "Unwille",
    "Unwillige": "unwillig",
    "Unwilligen": "Unwillige",
    "Unwillkommenen": "Unwillkommene",
    "Unwillkommeneren": "Unwillkommenere",
    "Unwillkommensten": "Unwillkommenste",
    "Unwirklichen": "Unwirkliche",
    "Unwirklicheren": "Unwirklichere",
    "Unwirklichsten": "Unwirklichste",
    "Unwirksamen": "Unwirksame",
    "Unwirksameren": "Unwirksamere",
    "Unwirksamsten": "Unwirksamste",
    "Unwirschen": "Unwirsche",
    "Unwirscheren": "Unwirschere",
    "Unwirschsten": "Unwirschste",
    "Unwirtschaftlichen": "Unwirtschaftliche",
    "Unwirtschaftlicheren": "Unwirtschaftlichere",
    "Unwissenden": "Unwissende",
    "Unwissens": "Unwissen",
    "Unwissenschaftliche": "unwissenschaftlich",
    "Unwissenschaftlichen": "Unwissenschaftliche",
    "Unwissentlichen": "Unwissentliche",
    "Unwohlen": "Unwohle",
    "Unwohleren": "Unwohlere",
    "Unwohlseins": "Unwohlsein",
    "Unwohlste": "unwohl",
    "Unwohlsten": "Unwohlste",
    "Unwohnlichen": "Unwohnliche",
    "Unwürdigen": "Unwürdige",
    "Unwürdigeren": "Unwürdigere",
    "Unwürdigsten": "Unwürdigste",
    "Unzahlen": "Unzahl",
    "Unzeitgemäßen": "Unzeitgemäße",
    "Unzeitgemäßeren": "Unzeitgemäßere",
    "Unzeitgemäßesten": "Unzeitgemäßeste",
    "Unzen": "Unze",
    "Unzertrennlichen": "Unzertrennliche",
    "Unzufriedene": "unzufrieden",
    "Unzufriedenen": "Unzufriedene",
    "Unzufriedeneren": "Unzufriedenere",
    "Unzufriedenheiten": "Unzufriedenheit",
    "Unzufriedenste": "unzufrieden",
    "Unzufriedensten": "Unzufriedenste",
    "Unzugänglichen": "Unzugängliche",
    "Unzugänglicheren": "Unzugänglichere",
    "Unzugänglichsten": "Unzugänglichste",
    "Unzulänglichen": "Unzulängliche",
    "Unzulänglichkeiten": "Unzulänglichkeit",
    "Unzulässige": "unzulässig",
    "Unzulässigen": "Unzulässige",
    "Unzulässigeren": "Unzulässigere",
    "Unzulässigsten": "Unzulässigste",
    "Unzurechnungsfähigen": "Unzurechnungsfähige",
    "Unzureichenden": "Unzureichende",
    "Unzureichenderen": "Unzureichendere",
    "Unzureichendsten": "Unzureichendste",
    "Unzusammenhängenden": "Unzusammenhängende",
    "Unzustellbaren": "Unzustellbare",
    "Unzutreffenden": "Unzutreffende",
    "Unzuverlässigen": "Unzuverlässige",
    "Unzuverlässigeren": "Unzuverlässigere",
    "Unzuverlässigkeiten": "Unzuverlässigkeit",
    "Unzuverlässigste": "unzuverlässig",
    "Unzuverlässigsten": "Unzuverlässigste",
    "Unzweckmäßigen": "Unzweckmäßige",
    "Unzweckmäßigeren": "Unzweckmäßigere",
    "Unzweckmäßigsten": "Unzweckmäßigste",
    "Unzählige": "unzählig",
    "Unzähligen": "Unzählige",
    "Unästhetischen": "Unästhetische",
    "Unüberbrückbare": "unüberbrückbar",
    "Unüberbrückbaren": "Unüberbrückbare",
    "Unüberlegten": "Unüberlegte",
    "Unübersehbaren": "Unübersehbare",
    "Unübersehbareren": "Unübersehbarere",
    "Unübersehbarsten": "Unübersehbarste",
    "Unübersichtlichen": "Unübersichtliche",
    "Unübersichtlicheren": "Unübersichtlichere",
    "Unüberwindlichen": "Unüberwindliche",
    "Unüberwindlicheren": "Unüberwindlichere",
    "Unüblichen": "Unübliche",
    "Urabstimmungen": "Urabstimmung",
    "Uradels": "Uradel",
    "Urahnen": "Urahne",
    "Uralte": "uralt",
    "Uralten": "Uralte",
    "Uranlagen": "Uranlage",
    "Urans": "Uran",
    "Uraufführungen": "Uraufführung",
    "Urbane": "urban",
    "Urbanen": "Urbane",
    "Urbanisierenden": "Urbanisierende",
    "Urbanisierens": "Urbanisieren",
    "Urbanisierte": "urbanisiert",
    "Urbanisierten": "Urbanisierte",
    "Urbarisierungen": "Urbarisierung",
    "Urbedeutungen": "Urbedeutung",
    "Urberachs": "Urberach",
    "Urbestandteile": "Urbestandteil",
    "Urbestandteilen": "Urbestandteil",
    "Urbestandteils": "Urbestandteil",
    "Urbevölkerungen": "Urbevölkerung",
    "Urdarme": "Urdarm",
    "Urdarms": "Urdarm",
    "Urdeutsche": "urdeutsch",
    "Urdeutschen": "Urdeutsche",
    "Urdärme": "Urdarm",
    "Urdärmen": "Urdarm",
    "Ureigenen": "Ureigene",
    "Ureigeneren": "Ureigenere",
    "Ureigensten": "Ureigenste",
    "Urenkelinnen": "Urenkelin",
    "Urenkeln": "Urenkel",
    "Urenkels": "Urenkel",
    "Urfehden": "Urfehde",
    "Urfelsen": "Urfels",
    "Urformen": "Urform",
    "Urgemütliche": "urgemütlich",
    "Urgemütlichen": "Urgemütliche",
    "Urgermanischen": "Urgermanische",
    "Urgeschichtlern": "Urgeschichtler",
    "Urgeschichtlers": "Urgeschichtler",
    "Urgeschichtliche": "urgeschichtlich",
    "Urgeschichtlichen": "Urgeschichtliche",
    "Urgeschlechtszellen": "Urgeschlechtszelle",
    "Urgestalten": "Urgestalt",
    "Urgesteine": "Urgestein",
    "Urgesteinen": "Urgestein",
    "Urgesteins": "Urgestein",
    "Urgewalten": "Urgewalt",
    "Urgroßvaters": "Urgroßvater",
    "Urgroßväter": "Urgroßvater",
    "Urgroßvätern": "Urgroßvater",
    "Urgrunde": "Urgrund",
    "Urgrunds": "Urgrund",
    "Urgründe": "Urgrund",
    "Urgründen": "Urgrund",
    "Urhebern": "Urheber",
    "Urheberrechte": "Urheberrecht",
    "Urheberrechten": "Urheberrecht",
    "Urheberrechts": "Urheberrecht",
    "Urhebers": "Urheber",
    "Urige": "urig",
    "Urigen": "Urige",
    "Urigeren": "Urigere",
    "Urigsten": "Urigste",
    "Urinalen": "Urinale",
    "Urinals": "Urinal",
    "Urine": "Urin",
    "Urinen": "Urin",
    "Urinierenden": "Urinierende",
    "Urinierenderen": "Urinierendere",
    "Urinierendsten": "Urinierendste",
    "Urinierens": "Urinieren",
    "Urinierte": "uriniert",
    "Urinierten": "Urinierte",
    "Urins": "Urin",
    "Urinösen": "Urinöse",
    "Urkeimzellen": "Urkeimzelle",
    "Urknalls": "Urknall",
    "Urkomische": "urkomisch",
    "Urkomischen": "Urkomische",
    "Urkräfte": "Urkraft",
    "Urkräften": "Urkraft",
    "Urkunden": "Urkunde",
    "Urkundliche": "urkundlich",
    "Urkundlichen": "Urkundliche",
    "Urlaubern": "Urlauber",
    "Urlaubers": "Urlauber",
    "Urlaubs": "Urlaub",
    "Urlaubsreife": "urlaubsreif",
    "Urlaubsreifen": "Urlaubsreife",
    "Urlaubsreiferen": "Urlaubsreifere",
    "Urlaubsreifsten": "Urlaubsreifste",
    "Urlinden": "Urlinde",
    "Urmenschen": "Urmensch",
    "Urnen": "Urne",
    "Urolithen": "Urolith",
    "Urologen": "Urologe",
    "Uromas": "Uroma",
    "Uropas": "Uropa",
    "Urplötzliche": "urplötzlich",
    "Urplötzlichen": "Urplötzliche",
    "Ursachen": "Ursache",
    "Ursprunge": "Ursprung",
    "Ursprungs": "Ursprung",
    "Ursprünge": "Ursprung",
    "Ursprüngen": "Ursprung",
    "Ursprüngliche": "ursprünglich",
    "Ursprünglichen": "Ursprüngliche",
    "Urstoffe": "Urstoff",
    "Urstoffen": "Urstoff",
    "Urstoffs": "Urstoff",
    "Ursulas": "Ursula",
    "Ursächliche": "ursächlich",
    "Ursächlichen": "Ursächliche",
    "Urteil": "urteilen",
    "Urteile": "urteilen",
    "Urteilen": "Urteil",
    "Urteilenden": "Urteilende",
    "Urteilens": "Urteilen",
    "Urteiles": "Urteil",
    "Urteils": "Urteil",
    "Urteilsfähige": "urteilsfähig",
    "Urteilsfähigen": "Urteilsfähige",
    "Urtexte": "Urtext",
    "Urtexten": "Urtext",
    "Urtexts": "Urtext",
    "Urtierchens": "Urtierchen",
    "Urtiere": "Urtier",
    "Urtieren": "Urtier",
    "Urtiers": "Urtier",
    "Urtype": "Urtyp",
    "Urtypen": "Urtyp",
    "Urtyps": "Urtyp",
    "Ururenkelinnen": "Ururenkelin",
    "Ururenkeln": "Ururenkel",
    "Ururenkels": "Ururenkel",
    "Ururgroßvaters": "Ururgroßvater",
    "Ururgroßväter": "Ururgroßvater",
    "Ururgroßvätern": "Ururgroßvater",
    "Urvaters": "Urvater",
    "Urvieche": "Urviech",
    "Urviecher": "Urviech",
    "Urviechern": "Urviech",
    "Urvieches": "Urviech",
    "Urviechs": "Urviech",
    "Urväter": "Urvater",
    "Urvätern": "Urvater",
    "Urwahlen": "Urwahl",
    "Urwalde": "Urwald",
    "Urwaldes": "Urwald",
    "Urwalds": "Urwald",
    "Urwählern": "Urwähler",
    "Urwählers": "Urwähler",
    "Urwälder": "Urwald",
    "Urwäldern": "Urwald",
    "Urzellen": "Urzelle",
    "Urzustande": "Urzustand",
    "Urzustands": "Urzustand",
    "Urzustände": "Urzustand",
    "Urzuständen": "Urzustand",
    "Usambaraveilchens": "Usambaraveilchen",
    "Usbeken": "Usbeke",
    "Usingens": "Usingen",
    "Usurpationen": "Usurpation",
    "Utas": "Uta",
    "Utensilien": "Utensil",
    "Utensils": "Utensil",
    "Utes": "Ute",
    "Utilisierenden": "Utilisierende",
    "Utilisierens": "Utilisieren",
    "Utilisierte": "utilisiert",
    "Utilisierten": "Utilisierte",
    "Utopielosigkeiten": "Utopielosigkeit",
    "Utopien": "Utopie",
    "Utopische": "utopisch",
    "Utopischen": "Utopische",
    "Utopischeren": "Utopischere",
    "Utopischsten": "Utopischste",
    "Utopisten": "Utopist",
    "Uwes": "Uwe",
    "Uzereien": "Uzerei",
    "VWs": "VW",
    "Vakuums": "Vakuum",
    "Valenzen": "Valenz",
    "Vampire": "Vampir",
    "Vampiren": "Vampir",
    "Vampires": "Vampir",
    "Vampirs": "Vampir",
    "Vamps": "Vamp",
    "Variabelste": "variabel",
    "Variabelsten": "Variabelste",
    "Variablen": "Variable",
    "Variableren": "Variablere",
    "Varianten": "Variante",
    "Variationen": "Variation",
    "Varietes": "Variete",
    "Variierenden": "Variierende",
    "Variierens": "Variieren",
    "Variierte": "variiert",
    "Variierten": "Variierte",
    "Vasen": "Vase",
    "Vaterlosen": "Vaterlose",
    "Vaterländische": "vaterländisch",
    "Vaterländischen": "Vaterländische",
    "Vaters": "Vater",
    "Vaterunsern": "Vaterunser",
    "Vaterunsers": "Vaterunser",
    "Vatikans": "Vatikan",
    "Vatis": "Vati",
    "Vegetariern": "Vegetarier",
    "Vegetariers": "Vegetarier",
    "Vegetationen": "Vegetation",
    "Vegetationsarme": "vegetationsarm",
    "Vegetationsarmen": "Vegetationsarme",
    "Vegetationsärmeren": "Vegetationsärmere",
    "Vehementen": "Vehemente",
    "Vehementeren": "Vehementere",
    "Vehementesten": "Vehementeste",
    "Veilchens": "Veilchen",
    "Venedigs": "Venedig",
    "Ventile": "Ventil",
    "Ventilen": "Ventil",
    "Ventiles": "Ventil",
    "Ventils": "Ventil",
    "Verabredenden": "Verabredende",
    "Verabredens": "Verabreden",
    "Verabredete": "verabredet",
    "Verabredeten": "Verabredete",
    "Verabredungen": "Verabredung",
    "Verabreichenden": "Verabreichende",
    "Verabreichens": "Verabreichen",
    "Verabreichte": "verabreicht",
    "Verabreichten": "Verabreichte",
    "Verabscheuenden": "Verabscheuende",
    "Verabscheuenderen": "Verabscheuendere",
    "Verabscheuendsten": "Verabscheuendste",
    "Verabscheuens": "Verabscheuen",
    "Verabscheuenswerte": "verabscheuenswert",
    "Verabscheuenswerten": "Verabscheuenswerte",
    "Verabscheuenswerteren": "Verabscheuenswertere",
    "Verabscheute": "verabscheut",
    "Verabscheuten": "Verabscheute",
    "Verabscheuteren": "Verabscheutere",
    "Verabscheutesten": "Verabscheuteste",
    "Verabschiedenden": "Verabschiedende",
    "Verabschiedens": "Verabschieden",
    "Verabschiedete": "verabschiedet",
    "Verabschiedeten": "Verabschiedete",
    "Verabschiedungen": "Verabschiedung",
    "Verabsolutierenden": "Verabsolutierende",
    "Verabsolutierens": "Verabsolutieren",
    "Verabsolutierte": "verabsolutiert",
    "Verabsolutierten": "Verabsolutierte",
    "Verachtenden": "Verachtende",
    "Verachtenderen": "Verachtendere",
    "Verachtendsten": "Verachtendste",
    "Verachtens": "Verachten",
    "Verachtenswerte": "verachtenswert",
    "Verachtenswerten": "Verachtenswerte",
    "Verachtenswerteren": "Verachtenswertere",
    "Verachtete": "verachtet",
    "Verachteten": "Verachtete",
    "Verachteteren": "Verachtetere",
    "Verachtetesten": "Verachteteste",
    "Veraes": "Vera",
    "Veralbernden": "Veralbernde",
    "Veralbernderen": "Veralberndere",
    "Veralberndsten": "Veralberndste",
    "Veralberns": "Veralbern",
    "Veralberte": "veralbert",
    "Veralberten": "Veralberte",
    "Veralberteren": "Veralbertere",
    "Veralbertesten": "Veralberteste",
    "Veralberungen": "Veralberung",
    "Verallgemeinernden": "Verallgemeinernde",
    "Verallgemeinernderen": "Verallgemeinerndere",
    "Verallgemeinerns": "Verallgemeinern",
    "Verallgemeinerte": "verallgemeinert",
    "Verallgemeinerten": "Verallgemeinerte",
    "Verallgemeinerteren": "Verallgemeinertere",
    "Verallgemeinerungen": "Verallgemeinerung",
    "Veraltenden": "Veraltende",
    "Veraltenderen": "Veraltendere",
    "Veraltendsten": "Veraltendste",
    "Veraltens": "Veralten",
    "Veralternden": "Veralternde",
    "Veralternderen": "Veralterndere",
    "Veralterndsten": "Veralterndste",
    "Veralterns": "Veraltern",
    "Veralterte": "veraltert",
    "Veralterten": "Veralterte",
    "Veralterteren": "Veraltertere",
    "Veraltertesten": "Veralterteste",
    "Veraltete": "veraltet",
    "Veralteten": "Veraltete",
    "Verandas": "Veranda",
    "Verankernden": "Verankernde",
    "Verankernderen": "Verankerndere",
    "Verankerndsten": "Verankerndste",
    "Verankerns": "Verankern",
    "Verankerte": "verankert",
    "Verankerten": "Verankerte",
    "Verankerteren": "Verankertere",
    "Verankertesten": "Verankerteste",
    "Veranlagenden": "Veranlagende",
    "Veranlagens": "Veranlagen",
    "Veranlagte": "veranlagt",
    "Veranlagten": "Veranlagte",
    "Veranlassenden": "Veranlassende",
    "Veranlassens": "Veranlassen",
    "Veranlaßte": "veranlaßt",
    "Veranlaßten": "Veranlaßte",
    "Veranschaulichenden": "Veranschaulichende",
    "Veranschaulichenderen": "Veranschaulichendere",
    "Veranschaulichens": "Veranschaulichen",
    "Veranschaulichte": "veranschaulicht",
    "Veranschaulichten": "Veranschaulichte",
    "Veranschaulichteren": "Veranschaulichtere",
    "Veranschlagenden": "Veranschlagende",
    "Veranschlagens": "Veranschlagen",
    "Veranschlagte": "veranschlagt",
    "Veranschlagten": "Veranschlagte",
    "Veranstaltenden": "Veranstaltende",
    "Veranstaltens": "Veranstalten",
    "Veranstaltern": "Veranstalter",
    "Veranstalters": "Veranstalter",
    "Veranstaltete": "veranstaltet",
    "Veranstalteten": "Veranstaltete",
    "Veranstaltungen": "Veranstaltung",
    "Verantwortenden": "Verantwortende",
    "Verantwortens": "Verantworten",
    "Verantwortete": "verantwortet",
    "Verantworteten": "Verantwortete",
    "Verantwortlichen": "Verantwortliche",
    "Verantwortlicheren": "Verantwortlichere",
    "Verantwortungen": "Verantwortung",
    "Verantwortungsbewußte": "verantwortungsbewußt",
    "Verantwortungsbewußten": "Verantwortungsbewußte",
    "Verantwortungsbewußteren": "Verantwortungsbewußtere",
    "Verantwortungslosen": "Verantwortungslose",
    "Verantwortungsloseren": "Verantwortungslosere",
    "Verantwortungsvollen": "Verantwortungsvolle",
    "Verantwortungsvolleren": "Verantwortungsvollere",
    "Verarbeitenden": "Verarbeitende",
    "Verarbeitens": "Verarbeiten",
    "Verarbeitete": "verarbeitet",
    "Verarbeiteten": "Verarbeitete",
    "Verarbeitungen": "Verarbeitung",
    "Verarmenden": "Verarmende",
    "Verarmens": "Verarmen",
    "Verarmte": "verarmt",
    "Verarmten": "Verarmte",
    "Verarmteren": "Verarmtere",
    "Verarmtesten": "Verarmteste",
    "Verarmungen": "Verarmung",
    "Verarschenden": "Verarschende",
    "Verarschenderen": "Verarschendere",
    "Verarschendsten": "Verarschendste",
    "Verarschens": "Verarschen",
    "Verarschte": "verarscht",
    "Verarschten": "Verarschte",
    "Verarschteren": "Verarschtere",
    "Verarschtesten": "Verarschteste",
    "Verarztenden": "Verarztende",
    "Verarztens": "Verarzten",
    "Verarztete": "verarztet",
    "Verarzteten": "Verarztete",
    "Verausgabenden": "Verausgabende",
    "Verausgabenderen": "Verausgabendere",
    "Verausgabendsten": "Verausgabendste",
    "Verausgabens": "Verausgaben",
    "Verausgabte": "verausgabt",
    "Verausgabten": "Verausgabte",
    "Verausgabteren": "Verausgabtere",
    "Verausgabtesten": "Verausgabteste",
    "Verbalen": "Verbale",
    "Verballernden": "Verballernde",
    "Verballernderen": "Verballerndere",
    "Verballerndsten": "Verballerndste",
    "Verballerns": "Verballern",
    "Verballerte": "verballert",
    "Verballerten": "Verballerte",
    "Verbande": "Verband",
    "Verbandes": "Verband",
    "Verbands": "Verband",
    "Verbannenden": "Verbannende",
    "Verbannenderen": "Verbannendere",
    "Verbannendsten": "Verbannendste",
    "Verbannens": "Verbannen",
    "Verbannte": "verbannt",
    "Verbannten": "Verbannte",
    "Verbannteren": "Verbanntere",
    "Verbanntesten": "Verbannteste",
    "Verbarrikadierenden": "Verbarrikadierende",
    "Verbarrikadierenderen": "Verbarrikadierendere",
    "Verbarrikadierens": "Verbarrikadieren",
    "Verbarrikadierte": "verbarrikadiert",
    "Verbarrikadierten": "Verbarrikadierte",
    "Verbarrikadierteren": "Verbarrikadiertere",
    "Verbauenden": "Verbauende",
    "Verbauens": "Verbauen",
    "Verbaute": "verbaut",
    "Verbauten": "Verbaute",
    "Verbauteren": "Verbautere",
    "Verbautesten": "Verbauteste",
    "Verbe": "Verb",
    "Verbeamtenden": "Verbeamtende",
    "Verbeamtens": "Verbeamten",
    "Verbeamtete": "verbeamtet",
    "Verbeamteten": "Verbeamtete",
    "Verbeißenden": "Verbeißende",
    "Verbeißenderen": "Verbeißendere",
    "Verbeißendsten": "Verbeißendste",
    "Verbeißens": "Verbeißen",
    "Verben": "Verb",
    "Verbergenden": "Verbergende",
    "Verbergens": "Verbergen",
    "Verbessernden": "Verbessernde",
    "Verbessernderen": "Verbesserndere",
    "Verbesserndsten": "Verbesserndste",
    "Verbesserns": "Verbessern",
    "Verbesserte": "verbessert",
    "Verbesserten": "Verbesserte",
    "Verbesserteren": "Verbessertere",
    "Verbessertesten": "Verbesserteste",
    "Verbesserungen": "Verbesserung",
    "Verbesserungsfähige": "verbesserungsfähig",
    "Verbesserungsfähigen": "Verbesserungsfähige",
    "Verbesserungsfähigeren": "Verbesserungsfähigere",
    "Verbeulenden": "Verbeulende",
    "Verbeulenderen": "Verbeulendere",
    "Verbeulendsten": "Verbeulendste",
    "Verbeulens": "Verbeulen",
    "Verbeulte": "verbeult",
    "Verbeulten": "Verbeulte",
    "Verbeulteren": "Verbeultere",
    "Verbeultesten": "Verbeulteste",
    "Verbformen": "Verbform",
    "Verbiegenden": "Verbiegende",
    "Verbiegens": "Verbiegen",
    "Verbiesterten": "Verbiesterte",
    "Verbiesterteren": "Verbiestertere",
    "Verbiestertesten": "Verbiesterteste",
    "Verbietenden": "Verbietende",
    "Verbietens": "Verbieten",
    "Verbilligenden": "Verbilligende",
    "Verbilligenderen": "Verbilligendere",
    "Verbilligendsten": "Verbilligendste",
    "Verbilligens": "Verbilligen",
    "Verbilligte": "verbilligt",
    "Verbilligten": "Verbilligte",
    "Verbilligteren": "Verbilligtere",
    "Verbilligtesten": "Verbilligteste",
    "Verbindenden": "Verbindende",
    "Verbindens": "Verbinden",
    "Verbindlichen": "Verbindliche",
    "Verbindlicheren": "Verbindlichere",
    "Verbindlichkeiten": "Verbindlichkeit",
    "Verbindlichste": "verbindlich",
    "Verbindlichsten": "Verbindlichste",
    "Verbindungen": "Verbindung",
    "Verbindungsleuten": "Verbindungsleute",
    "Verbindungsmanne": "Verbindungsmann",
    "Verbindungsmannes": "Verbindungsmann",
    "Verbindungsmanns": "Verbindungsmann",
    "Verbindungsmänner": "Verbindungsmann",
    "Verbindungsmännern": "Verbindungsmann",
    "Verbinfinitive": "Verbinfinitiv",
    "Verbinfinitiven": "Verbinfinitiv",
    "Verbinfinitives": "Verbinfinitiv",
    "Verbinfinitivs": "Verbinfinitiv",
    "Verbissenen": "Verbissene",
    "Verbisseneren": "Verbissenere",
    "Verbissenheiten": "Verbissenheit",
    "Verbissenste": "verbissen",
    "Verbissensten": "Verbissenste",
    "Verbitternden": "Verbitternde",
    "Verbitternderen": "Verbitterndere",
    "Verbitterndsten": "Verbitterndste",
    "Verbitterns": "Verbittern",
    "Verbitterte": "verbittert",
    "Verbitterten": "Verbitterte",
    "Verbitterteren": "Verbittertere",
    "Verbittertesten": "Verbitterteste",
    "Verbitterungen": "Verbitterung",
    "Verblassenden": "Verblassende",
    "Verblassenderen": "Verblassendere",
    "Verblassendsten": "Verblassendste",
    "Verblassens": "Verblassen",
    "Verblaßte": "verblaßt",
    "Verblaßten": "Verblaßte",
    "Verblaßteren": "Verblaßtere",
    "Verblaßtesten": "Verblaßteste",
    "Verbleibenden": "Verbleibende",
    "Verbleibens": "Verbleiben",
    "Verbleichenden": "Verbleichende",
    "Verbleichenderen": "Verbleichendere",
    "Verbleichendsten": "Verbleichendste",
    "Verbleichens": "Verbleichen",
    "Verblendenden": "Verblendende",
    "Verblendenderen": "Verblendendere",
    "Verblendendsten": "Verblendendste",
    "Verblendens": "Verblenden",
    "Verblendete": "verblendet",
    "Verblendeten": "Verblendete",
    "Verblendeteren": "Verblendetere",
    "Verblendetesten": "Verblendeteste",
    "Verblichenen": "Verblichene",
    "Verblicheneren": "Verblichenere",
    "Verblichensten": "Verblichenste",
    "Verbliebenen": "Verbliebene",
    "Verblutenden": "Verblutende",
    "Verblutenderen": "Verblutendere",
    "Verblutendsten": "Verblutendste",
    "Verblutens": "Verbluten",
    "Verblutete": "verblutet",
    "Verbluteten": "Verblutete",
    "Verbluteteren": "Verblutetere",
    "Verblutetesten": "Verbluteteste",
    "Verblödenden": "Verblödende",
    "Verblödenderen": "Verblödendere",
    "Verblödendsten": "Verblödendste",
    "Verblödens": "Verblöden",
    "Verblödete": "verblödet",
    "Verblödeten": "Verblödete",
    "Verblödeteren": "Verblödetere",
    "Verblödetesten": "Verblödeteste",
    "Verblüffenden": "Verblüffende",
    "Verblüffenderen": "Verblüffendere",
    "Verblüffendsten": "Verblüffendste",
    "Verblüffens": "Verblüffen",
    "Verblüffte": "verblüfft",
    "Verblüfften": "Verblüffte",
    "Verblüffteren": "Verblüfftere",
    "Verblüfftesten": "Verblüffteste",
    "Verblühenden": "Verblühende",
    "Verblühenderen": "Verblühendere",
    "Verblühendsten": "Verblühendste",
    "Verblühens": "Verblühen",
    "Verblühte": "verblüht",
    "Verblühten": "Verblühte",
    "Verblühteren": "Verblühtere",
    "Verblühtesten": "Verblühteste",
    "Verbogenen": "Verbogene",
    "Verbogeneren": "Verbogenere",
    "Verbogensten": "Verbogenste",
    "Verbohrenden": "Verbohrende",
    "Verbohrenderen": "Verbohrendere",
    "Verbohrendsten": "Verbohrendste",
    "Verbohrens": "Verbohren",
    "Verbohrte": "verbohrt",
    "Verbohrten": "Verbohrte",
    "Verbohrteren": "Verbohrtere",
    "Verbohrtesten": "Verbohrteste",
    "Verborgenen": "Verborgene",
    "Verborgeneren": "Verborgenere",
    "Verborgensten": "Verborgenste",
    "Verbote": "Verbot",
    "Verboten": "Verbot",
    "Verbotenen": "Verbotene",
    "Verboteneren": "Verbotenere",
    "Verbotensten": "Verbotenste",
    "Verbots": "Verbot",
    "Verbrachte": "verbringen",
    "Verbrachten": "verbringen",
    "Verbrannte": "verbrennen",
    "Verbrannten": "verbrennen",
    "Verbrannteren": "Verbranntere",
    "Verbranntesten": "Verbrannteste",
    "Verbratenden": "Verbratende",
    "Verbratenderen": "Verbratendere",
    "Verbratendsten": "Verbratendste",
    "Verbratenen": "Verbratene",
    "Verbrateneren": "Verbratenere",
    "Verbratens": "Verbraten",
    "Verbratenste": "verbraten",
    "Verbratensten": "Verbratenste",
    "Verbrauch": "verbrauchen",
    "Verbrauche": "verbrauchen",
    "Verbrauchenden": "Verbrauchende",
    "Verbrauchenderen": "Verbrauchendere",
    "Verbrauchendsten": "Verbrauchendste",
    "Verbrauchens": "Verbrauchen",
    "Verbrauchern": "Verbraucher",
    "Verbrauchers": "Verbraucher",
    "Verbrauches": "Verbrauch",
    "Verbrauchs": "Verbrauch",
    "Verbrauchte": "verbraucht",
    "Verbrauchten": "Verbrauchte",
    "Verbrauchteren": "Verbrauchtere",
    "Verbrauchtesten": "Verbrauchteste",
    "Verbrechenden": "Verbrechende",
    "Verbrechens": "Verbrechen",
    "Verbrecherische": "verbrecherisch",
    "Verbrecherischen": "Verbrecherische",
    "Verbrechern": "Verbrecher",
    "Verbrechers": "Verbrecher",
    "Verbreitenden": "Verbreitende",
    "Verbreitens": "Verbreiten",
    "Verbreiternden": "Verbreiternde",
    "Verbreiterns": "Verbreitern",
    "Verbreiterte": "verbreitert",
    "Verbreiterten": "Verbreiterte",
    "Verbreitete": "verbreitet",
    "Verbreiteten": "Verbreitete",
    "Verbreiteteren": "Verbreitetere",
    "Verbreitetesten": "Verbreiteteste",
    "Verbreitungen": "Verbreitung",
    "Verbremsenden": "Verbremsende",
    "Verbremsens": "Verbremsen",
    "Verbremste": "verbremst",
    "Verbremsten": "Verbremste",
    "Verbrennenden": "Verbrennende",
    "Verbrennenderen": "Verbrennendere",
    "Verbrennendsten": "Verbrennendste",
    "Verbrennens": "Verbrennen",
    "Verbrennungen": "Verbrennung",
    "Verbringenden": "Verbringende",
    "Verbringens": "Verbringen",
    "Verbrochenen": "Verbrochene",
    "Verbrüdernden": "Verbrüdernde",
    "Verbrüderns": "Verbrüdern",
    "Verbrüderte": "verbrüdert",
    "Verbrüderten": "Verbrüderte",
    "Verbrühenden": "Verbrühende",
    "Verbrühens": "Verbrühen",
    "Verbrühte": "verbrüht",
    "Verbrühten": "Verbrühte",
    "Verbs": "Verb",
    "Verbuchenden": "Verbuchende",
    "Verbuchens": "Verbuchen",
    "Verbuchte": "verbucht",
    "Verbuchten": "Verbuchte",
    "Verbuddelnden": "Verbuddelnde",
    "Verbuddelnderen": "Verbuddelndere",
    "Verbuddelndsten": "Verbuddelndste",
    "Verbuddelns": "Verbuddeln",
    "Verbuddelte": "verbuddelt",
    "Verbuddelten": "Verbuddelte",
    "Verbuddelteren": "Verbuddeltere",
    "Verbuddeltesten": "Verbuddelteste",
    "Verbummelnden": "Verbummelnde",
    "Verbummelns": "Verbummeln",
    "Verbummelte": "verbummelt",
    "Verbummelten": "Verbummelte",
    "Verbunde": "Verbund",
    "Verbunden": "Verbund",
    "Verbundenen": "Verbundene",
    "Verbundeneren": "Verbundenere",
    "Verbundenste": "verbunden",
    "Verbundensten": "Verbundenste",
    "Verbundmaschinen": "Verbundmaschine",
    "Verbunds": "Verbund",
    "Verbände": "verbinden",
    "Verbänden": "verbinden",
    "Verböllernden": "Verböllernde",
    "Verböllernderen": "Verböllerndere",
    "Verböllerndsten": "Verböllerndste",
    "Verböllerns": "Verböllern",
    "Verböllerte": "verböllert",
    "Verböllerten": "Verböllerte",
    "Verböllerteren": "Verböllertere",
    "Verböllertesten": "Verböllerteste",
    "Verbündenden": "Verbündende",
    "Verbündens": "Verbünden",
    "Verbündete": "verbündet",
    "Verbündeten": "Verbündete",
    "Verbürgenden": "Verbürgende",
    "Verbürgens": "Verbürgen",
    "Verbürgte": "verbürgt",
    "Verbürgten": "Verbürgte",
    "Verbüßenden": "Verbüßende",
    "Verbüßens": "Verbüßen",
    "Verbüßte": "verbüßt",
    "Verbüßten": "Verbüßte",
    "Verdachte": "verdacht",
    "Verdachten": "verdenken",
    "Verdachts": "Verdacht",
    "Verdammenden": "Verdammende",
    "Verdammens": "Verdammen",
    "Verdammte": "verdammt",
    "Verdammten": "Verdammte",
    "Verdammteren": "Verdammtere",
    "Verdammtesten": "Verdammteste",
    "Verdampfenden": "Verdampfende",
    "Verdampfenderen": "Verdampfendere",
    "Verdampfendsten": "Verdampfendste",
    "Verdampfens": "Verdampfen",
    "Verdampfte": "verdampft",
    "Verdampften": "Verdampfte",
    "Verdampfteren": "Verdampftere",
    "Verdampftesten": "Verdampfteste",
    "Verdankenden": "Verdankende",
    "Verdankens": "Verdanken",
    "Verdankte": "verdankt",
    "Verdankten": "Verdankte",
    "Verdatterten": "Verdatterte",
    "Verdatterteren": "Verdattertere",
    "Verdattertesten": "Verdatterteste",
    "Verdauenden": "Verdauende",
    "Verdauens": "Verdauen",
    "Verdaulichen": "Verdauliche",
    "Verdaute": "verdaut",
    "Verdauten": "Verdaute",
    "Verdeck": "verdecken",
    "Verdecke": "verdecken",
    "Verdecken": "Verdeck",
    "Verdeckenden": "Verdeckende",
    "Verdeckenderen": "Verdeckendere",
    "Verdeckendsten": "Verdeckendste",
    "Verdeckens": "Verdecken",
    "Verdecks": "Verdeck",
    "Verdeckte": "verdeckt",
    "Verdeckten": "Verdeckte",
    "Verdeckteren": "Verdecktere",
    "Verdecktesten": "Verdeckteste",
    "Verdenkenden": "Verdenkende",
    "Verdenkens": "Verdenken",
    "Verderbenden": "Verderbende",
    "Verderbens": "Verderben",
    "Verderblichen": "Verderbliche",
    "Verderblicheren": "Verderblichere",
    "Verderblichsten": "Verderblichste",
    "Verderbs": "Verderb",
    "Verdeutlichenden": "Verdeutlichende",
    "Verdeutlichens": "Verdeutlichen",
    "Verdeutlichte": "verdeutlicht",
    "Verdeutlichten": "Verdeutlichte",
    "Verdeutschungen": "Verdeutschung",
    "Verdichtenden": "Verdichtende",
    "Verdichtens": "Verdichten",
    "Verdichtete": "verdichtet",
    "Verdichteten": "Verdichtete",
    "Verdienenden": "Verdienende",
    "Verdienens": "Verdienen",
    "Verdienern": "Verdiener",
    "Verdieners": "Verdiener",
    "Verdienste": "Verdienst",
    "Verdiensten": "Verdienst",
    "Verdienstes": "Verdienst",
    "Verdiensts": "Verdienst",
    "Verdiente": "verdient",
    "Verdienten": "Verdiente",
    "Verdienteren": "Verdientere",
    "Verdientesten": "Verdienteste",
    "Verdingenden": "Verdingende",
    "Verdingens": "Verdingen",
    "Verdingte": "verdingt",
    "Verdingten": "Verdingte",
    "Verdis": "Verdi",
    "Verdonnernden": "Verdonnernde",
    "Verdonnernderen": "Verdonnerndere",
    "Verdonnerndsten": "Verdonnerndste",
    "Verdonnerns": "Verdonnern",
    "Verdonnerte": "verdonnert",
    "Verdonnerten": "Verdonnerte",
    "Verdoppelnden": "Verdoppelnde",
    "Verdoppelns": "Verdoppeln",
    "Verdoppelte": "verdoppelt",
    "Verdoppelten": "Verdoppelte",
    "Verdoppelungen": "Verdoppelung",
    "Verdorbenen": "Verdorbene",
    "Verdorbeneren": "Verdorbenere",
    "Verdorbensten": "Verdorbenste",
    "Verdrahtenden": "Verdrahtende",
    "Verdrahtenderen": "Verdrahtendere",
    "Verdrahtendsten": "Verdrahtendste",
    "Verdrahtens": "Verdrahten",
    "Verdrahtete": "verdrahtet",
    "Verdrahteten": "Verdrahtete",
    "Verdrahteteren": "Verdrahtetere",
    "Verdrahtetesten": "Verdrahteteste",
    "Verdreckenden": "Verdreckende",
    "Verdreckenderen": "Verdreckendere",
    "Verdreckendsten": "Verdreckendste",
    "Verdreckens": "Verdrecken",
    "Verdreckte": "verdreckt",
    "Verdreckten": "Verdreckte",
    "Verdreckteren": "Verdrecktere",
    "Verdrecktesten": "Verdreckteste",
    "Verdrehenden": "Verdrehende",
    "Verdrehens": "Verdrehen",
    "Verdrehte": "verdreht",
    "Verdrehten": "Verdrehte",
    "Verdrehteren": "Verdrehtere",
    "Verdrehtesten": "Verdrehteste",
    "Verdreifachenden": "Verdreifachende",
    "Verdreifachens": "Verdreifachen",
    "Verdreifachte": "verdreifacht",
    "Verdreifachten": "Verdreifachte",
    "Verdreschenden": "Verdreschende",
    "Verdreschens": "Verdreschen",
    "Verdribbelnden": "Verdribbelnde",
    "Verdribbelns": "Verdribbeln",
    "Verdribbelte": "verdribbelt",
    "Verdribbelten": "Verdribbelte",
    "Verdrießenden": "Verdrießende",
    "Verdrießens": "Verdrießen",
    "Verdroschenen": "Verdroschene",
    "Verdroscheneren": "Verdroschenere",
    "Verdroschensten": "Verdroschenste",
    "Verdrossenen": "Verdrossene",
    "Verdrosseneren": "Verdrossenere",
    "Verdrossensten": "Verdrossenste",
    "Verdrängenden": "Verdrängende",
    "Verdrängens": "Verdrängen",
    "Verdrängte": "verdrängt",
    "Verdrängten": "Verdrängte",
    "Verdrängungen": "Verdrängung",
    "Verdrückenden": "Verdrückende",
    "Verdrückens": "Verdrücken",
    "Verdrückte": "verdrückt",
    "Verdrückten": "Verdrückte",
    "Verduftenden": "Verduftende",
    "Verduftenderen": "Verduftendere",
    "Verduftendsten": "Verduftendste",
    "Verduftens": "Verduften",
    "Verduftete": "verduftet",
    "Verdufteten": "Verduftete",
    "Verdufteteren": "Verduftetere",
    "Verduftetesten": "Verdufteteste",
    "Verdummenden": "Verdummende",
    "Verdummenderen": "Verdummendere",
    "Verdummendsten": "Verdummendste",
    "Verdummens": "Verdummen",
    "Verdummte": "verdummt",
    "Verdummten": "Verdummte",
    "Verdummteren": "Verdummtere",
    "Verdummtesten": "Verdummteste",
    "Verdunkelnden": "Verdunkelnde",
    "Verdunkelnderen": "Verdunkelndere",
    "Verdunkelndsten": "Verdunkelndste",
    "Verdunkelns": "Verdunkeln",
    "Verdunkelte": "verdunkelt",
    "Verdunkelten": "Verdunkelte",
    "Verdunkelteren": "Verdunkeltere",
    "Verdunkeltesten": "Verdunkelteste",
    "Verdunkelungen": "Verdunkelung",
    "Verdunklungen": "Verdunklung",
    "Verdunstenden": "Verdunstende",
    "Verdunstenderen": "Verdunstendere",
    "Verdunstendsten": "Verdunstendste",
    "Verdunstens": "Verdunsten",
    "Verdunstete": "verdunstet",
    "Verdunsteten": "Verdunstete",
    "Verdunsteteren": "Verdunstetere",
    "Verdunstetesten": "Verdunsteteste",
    "Verdurstenden": "Verdurstende",
    "Verdurstenderen": "Verdurstendere",
    "Verdurstendsten": "Verdurstendste",
    "Verdurstens": "Verdursten",
    "Verdurstete": "verdurstet",
    "Verdursteten": "Verdurstete",
    "Verdursteteren": "Verdurstetere",
    "Verdurstetesten": "Verdursteteste",
    "Verdutzten": "Verdutzte",
    "Verdutzteren": "Verdutztere",
    "Verdutztesten": "Verdutzteste",
    "Verdächtigenden": "Verdächtigende",
    "Verdächtigens": "Verdächtigen",
    "Verdächtigte": "verdächtigt",
    "Verdächtigten": "Verdächtigte",
    "Verdünnenden": "Verdünnende",
    "Verdünnenderen": "Verdünnendere",
    "Verdünnendsten": "Verdünnendste",
    "Verdünnens": "Verdünnen",
    "Verdünnisierenden": "Verdünnisierende",
    "Verdünnisierens": "Verdünnisieren",
    "Verdünnisierte": "verdünnisiert",
    "Verdünnisierten": "Verdünnisierte",
    "Verdünnte": "verdünnt",
    "Verdünnten": "Verdünnte",
    "Verdünnteren": "Verdünntere",
    "Verdünntesten": "Verdünnteste",
    "Verdünstende": "verdünstend",
    "Verdünstenden": "Verdünstende",
    "Verdünstendere": "verdünstend",
    "Verdünstenderen": "Verdünstendere",
    "Verdünstendste": "verdünstend",
    "Verdünstendsten": "Verdünstendste",
    "Verdünstens": "Verdünsten",
    "Verdünstete": "verdünstet",
    "Verdünsteten": "Verdünstete",
    "Verdünstetere": "verdünstet",
    "Verdünsteteren": "Verdünstetere",
    "Verdünsteteste": "verdünstet",
    "Verdünstetesten": "Verdünsteteste",
    "Verebbenden": "Verebbende",
    "Verebbens": "Verebben",
    "Verebbte": "verebbt",
    "Verebbten": "Verebbte",
    "Veredelnden": "Veredelnde",
    "Veredelnderen": "Veredelndere",
    "Veredelndsten": "Veredelndste",
    "Veredelns": "Veredeln",
    "Veredelte": "veredelt",
    "Veredelten": "Veredelte",
    "Veredelteren": "Veredeltere",
    "Veredeltesten": "Veredelteste",
    "Verehelichungen": "Verehelichung",
    "Verehrenden": "Verehrende",
    "Verehrenderen": "Verehrendere",
    "Verehrendsten": "Verehrendste",
    "Verehrens": "Verehren",
    "Verehrern": "Verehrer",
    "Verehrers": "Verehrer",
    "Verehrte": "verehrt",
    "Verehrten": "Verehrte",
    "Verehrteren": "Verehrtere",
    "Verehrtesten": "Verehrteste",
    "Verehrungen": "Verehrung",
    "Vereidenden": "Vereidende",
    "Vereidens": "Vereiden",
    "Vereidete": "vereidet",
    "Vereideten": "Vereidete",
    "Vereidigenden": "Vereidigende",
    "Vereidigens": "Vereidigen",
    "Vereidigte": "vereidigt",
    "Vereidigten": "Vereidigte",
    "Vereidigungen": "Vereidigung",
    "Verein": "vereinen",
    "Vereinbarende": "vereinbarend",
    "Vereinbarenden": "Vereinbarende",
    "Vereinbarens": "Vereinbaren",
    "Vereinbarte": "vereinbart",
    "Vereinbarten": "Vereinbarte",
    "Vereinbarungen": "Vereinbarung",
    "Vereine": "vereinen",
    "Vereinen": "Verein",
    "Vereinenden": "Vereinende",
    "Vereinens": "Vereinen",
    "Vereinfachenden": "Vereinfachende",
    "Vereinfachenderen": "Vereinfachendere",
    "Vereinfachendsten": "Vereinfachendste",
    "Vereinfachens": "Vereinfachen",
    "Vereinfachte": "vereinfacht",
    "Vereinfachten": "Vereinfachte",
    "Vereinfachteren": "Vereinfachtere",
    "Vereinfachtesten": "Vereinfachteste",
    "Vereinheitlichenden": "Vereinheitlichende",
    "Vereinheitlichenderen": "Vereinheitlichendere",
    "Vereinheitlichens": "Vereinheitlichen",
    "Vereinheitlichte": "vereinheitlicht",
    "Vereinheitlichten": "Vereinheitlichte",
    "Vereinheitlichteren": "Vereinheitlichtere",
    "Vereinigenden": "Vereinigende",
    "Vereinigens": "Vereinigen",
    "Vereinigte": "vereinigt",
    "Vereinigten": "Vereinigte",
    "Vereinigungen": "Vereinigung",
    "Vereinnahmenden": "Vereinnahmende",
    "Vereinnahmenderen": "Vereinnahmendere",
    "Vereinnahmendsten": "Vereinnahmendste",
    "Vereinnahmens": "Vereinnahmen",
    "Vereinnahmte": "vereinnahmt",
    "Vereinnahmten": "Vereinnahmte",
    "Vereinnahmteren": "Vereinnahmtere",
    "Vereinnahmtesten": "Vereinnahmteste",
    "Vereins": "Verein",
    "Vereinsamenden": "Vereinsamende",
    "Vereinsamenderen": "Vereinsamendere",
    "Vereinsamendsten": "Vereinsamendste",
    "Vereinsamens": "Vereinsamen",
    "Vereinsamte": "vereinsamt",
    "Vereinsamten": "Vereinsamte",
    "Vereinsamteren": "Vereinsamtere",
    "Vereinsamtesten": "Vereinsamteste",
    "Vereinte": "vereint",
    "Vereinten": "Vereinte",
    "Vereinzelnden": "Vereinzelnde",
    "Vereinzelns": "Vereinzeln",
    "Vereinzelte": "vereinzelt",
    "Vereinzelten": "Vereinzelte",
    "Vereisenden": "Vereisende",
    "Vereisenderen": "Vereisendere",
    "Vereisendsten": "Vereisendste",
    "Vereisens": "Vereisen",
    "Vereiste": "vereist",
    "Vereisten": "Vereiste",
    "Vereisteren": "Vereistere",
    "Vereistesten": "Vereisteste",
    "Vereisungen": "Vereisung",
    "Vereitelnden": "Vereitelnde",
    "Vereitelns": "Vereiteln",
    "Vereitelte": "vereitelt",
    "Vereitelten": "Vereitelte",
    "Vereiternden": "Vereiternde",
    "Vereiternderen": "Vereiterndere",
    "Vereiterndsten": "Vereiterndste",
    "Vereiterns": "Vereitern",
    "Vereiterte": "vereitert",
    "Vereiterten": "Vereiterte",
    "Vereiterteren": "Vereitertere",
    "Vereitertesten": "Vereiterteste",
    "Vereiterungen": "Vereiterung",
    "Verelendenden": "Verelendende",
    "Verelendenderen": "Verelendendere",
    "Verelendendsten": "Verelendendste",
    "Verelendens": "Verelenden",
    "Verelendete": "verelendet",
    "Verelendeten": "Verelendete",
    "Verelendeteren": "Verelendetere",
    "Verelendetesten": "Verelendeteste",
    "Verenas": "Verena",
    "Verendenden": "Verendende",
    "Verendens": "Verenden",
    "Verendete": "verendet",
    "Verendeten": "Verendete",
    "Verengenden": "Verengende",
    "Verengenderen": "Verengendere",
    "Verengendsten": "Verengendste",
    "Verengens": "Verengen",
    "Verengte": "verengt",
    "Verengten": "Verengte",
    "Verengteren": "Verengtere",
    "Verengtesten": "Verengteste",
    "Verengungen": "Verengung",
    "Vererbenden": "Vererbende",
    "Vererbens": "Vererben",
    "Vererbte": "vererbt",
    "Vererbten": "Vererbte",
    "Veresterungen": "Veresterung",
    "Verewigenden": "Verewigende",
    "Verewigens": "Verewigen",
    "Verewigte": "verewigt",
    "Verewigten": "Verewigte",
    "Verfahrenden": "Verfahrende",
    "Verfahrenen": "Verfahrene",
    "Verfahreneren": "Verfahrenere",
    "Verfahrens": "Verfahren",
    "Verfahrenste": "verfahren",
    "Verfahrensten": "Verfahrenste",
    "Verfalle": "verfallen",
    "Verfallenden": "Verfallende",
    "Verfallenen": "Verfallene",
    "Verfalleneren": "Verfallenere",
    "Verfallens": "Verfallen",
    "Verfallenste": "verfallen",
    "Verfallensten": "Verfallenste",
    "Verfalles": "Verfall",
    "Verfalls": "Verfall",
    "Verfangenden": "Verfangende",
    "Verfangenen": "Verfangene",
    "Verfangens": "Verfangen",
    "Verfassenden": "Verfassende",
    "Verfassens": "Verfassen",
    "Verfassern": "Verfasser",
    "Verfassers": "Verfasser",
    "Verfassungen": "Verfassung",
    "Verfassunggebende": "verfassunggebend",
    "Verfassunggebenden": "Verfassunggebende",
    "Verfassungsmäßigen": "Verfassungsmäßige",
    "Verfassungspolitischen": "Verfassungspolitische",
    "Verfassungspolitischeren": "Verfassungspolitischere",
    "Verfassungsrechtlichen": "Verfassungsrechtliche",
    "Verfassungsrechtlicheren": "Verfassungsrechtlichere",
    "Verfassungswidrigen": "Verfassungswidrige",
    "Verfaulenden": "Verfaulende",
    "Verfaulenderen": "Verfaulendere",
    "Verfaulendsten": "Verfaulendste",
    "Verfaulens": "Verfaulen",
    "Verfaulte": "verfault",
    "Verfaulten": "Verfaulte",
    "Verfaulteren": "Verfaultere",
    "Verfaultesten": "Verfaulteste",
    "Verfaßte": "verfaßt",
    "Verfaßten": "Verfaßte",
    "Verfechtenden": "Verfechtende",
    "Verfechtens": "Verfechten",
    "Verfechtern": "Verfechter",
    "Verfechters": "Verfechter",
    "Verfehlenden": "Verfehlende",
    "Verfehlenderen": "Verfehlendere",
    "Verfehlendsten": "Verfehlendste",
    "Verfehlens": "Verfehlen",
    "Verfehlte": "verfehlt",
    "Verfehlten": "Verfehlte",
    "Verfehlteren": "Verfehltere",
    "Verfehltesten": "Verfehlteste",
    "Verfehlungen": "Verfehlung",
    "Verfeindenden": "Verfeindende",
    "Verfeindens": "Verfeinden",
    "Verfeindete": "verfeindet",
    "Verfeindeten": "Verfeindete",
    "Verfeindeteren": "Verfeindetere",
    "Verfeindetesten": "Verfeindeteste",
    "Verfeinernden": "Verfeinernde",
    "Verfeinerns": "Verfeinern",
    "Verfeinerte": "verfeinert",
    "Verfeinerten": "Verfeinerte",
    "Verfeinerteren": "Verfeinertere",
    "Verfeinertesten": "Verfeinerteste",
    "Verfertigungen": "Verfertigung",
    "Verfestigenden": "Verfestigende",
    "Verfestigenderen": "Verfestigendere",
    "Verfestigendsten": "Verfestigendste",
    "Verfestigens": "Verfestigen",
    "Verfestigte": "verfestigt",
    "Verfestigten": "Verfestigte",
    "Verfestigteren": "Verfestigtere",
    "Verfestigtesten": "Verfestigteste",
    "Verfestigungen": "Verfestigung",
    "Verfeuernden": "Verfeuernde",
    "Verfeuernderen": "Verfeuerndere",
    "Verfeuerndsten": "Verfeuerndste",
    "Verfeuerns": "Verfeuern",
    "Verfeuerte": "verfeuert",
    "Verfeuerten": "Verfeuerte",
    "Verfeuerteren": "Verfeuertere",
    "Verfeuertesten": "Verfeuerteste",
    "Verfilmenden": "Verfilmende",
    "Verfilmens": "Verfilmen",
    "Verfilmte": "verfilmt",
    "Verfilmten": "Verfilmte",
    "Verfilmungen": "Verfilmung",
    "Verflachenden": "Verflachende",
    "Verflachenderen": "Verflachendere",
    "Verflachendsten": "Verflachendste",
    "Verflachens": "Verflachen",
    "Verflachte": "verflacht",
    "Verflachten": "Verflachte",
    "Verflachteren": "Verflachtere",
    "Verflachtesten": "Verflachteste",
    "Verflechtenden": "Verflechtende",
    "Verflechtenderen": "Verflechtendere",
    "Verflechtendsten": "Verflechtendste",
    "Verflechtens": "Verflechten",
    "Verfliegenden": "Verfliegende",
    "Verfliegens": "Verfliegen",
    "Verfließenden": "Verfließende",
    "Verfließens": "Verfließen",
    "Verflochtenen": "Verflochtene",
    "Verflochteneren": "Verflochtenere",
    "Verflochtensten": "Verflochtenste",
    "Verflogenen": "Verflogene",
    "Verflogeneren": "Verflogenere",
    "Verflogensten": "Verflogenste",
    "Verflossenen": "Verflossene",
    "Verfluchenden": "Verfluchende",
    "Verfluchenderen": "Verfluchendere",
    "Verfluchendsten": "Verfluchendste",
    "Verfluchens": "Verfluchen",
    "Verfluchte": "verflucht",
    "Verfluchten": "Verfluchte",
    "Verfluchteren": "Verfluchtere",
    "Verfluchtesten": "Verfluchteste",
    "Verflüchtigenden": "Verflüchtigende",
    "Verflüchtigens": "Verflüchtigen",
    "Verflüchtigte": "verflüchtigt",
    "Verflüchtigten": "Verflüchtigte",
    "Verflüssigenden": "Verflüssigende",
    "Verflüssigens": "Verflüssigen",
    "Verflüssigte": "verflüssigt",
    "Verflüssigten": "Verflüssigte",
    "Verfochtenen": "Verfochtene",
    "Verfolgenden": "Verfolgende",
    "Verfolgens": "Verfolgen",
    "Verfolgern": "Verfolger",
    "Verfolgers": "Verfolger",
    "Verfolgte": "verfolgt",
    "Verfolgten": "Verfolgte",
    "Verfolgteren": "Verfolgtere",
    "Verfolgtesten": "Verfolgteste",
    "Verfolgungen": "Verfolgung",
    "Verformenden": "Verformende",
    "Verformens": "Verformen",
    "Verformte": "verformt",
    "Verformten": "Verformte",
    "Verformteren": "Verformtere",
    "Verformtesten": "Verformteste",
    "Verformungen": "Verformung",
    "Verfrachtenden": "Verfrachtende",
    "Verfrachtens": "Verfrachten",
    "Verfrachtern": "Verfrachter",
    "Verfrachters": "Verfrachter",
    "Verfrachtete": "verfrachtet",
    "Verfrachteten": "Verfrachtete",
    "Verfransenden": "Verfransende",
    "Verfransenderen": "Verfransendere",
    "Verfransendsten": "Verfransendste",
    "Verfransens": "Verfransen",
    "Verfranste": "verfranst",
    "Verfransten": "Verfranste",
    "Verfransteren": "Verfranstere",
    "Verfranstesten": "Verfransteste",
    "Verfranzenden": "Verfranzende",
    "Verfranzenderen": "Verfranzendere",
    "Verfranzendsten": "Verfranzendste",
    "Verfranzens": "Verfranzen",
    "Verfranzte": "verfranzt",
    "Verfranzten": "Verfranzte",
    "Verfranzteren": "Verfranztere",
    "Verfranztesten": "Verfranzteste",
    "Verfremdenden": "Verfremdende",
    "Verfremdenderen": "Verfremdendere",
    "Verfremdendsten": "Verfremdendste",
    "Verfremdens": "Verfremden",
    "Verfremdete": "verfremdet",
    "Verfremdeten": "Verfremdete",
    "Verfremdeteren": "Verfremdetere",
    "Verfremdetesten": "Verfremdeteste",
    "Verfremdungen": "Verfremdung",
    "Verfrorene": "verfroren",
    "Verfrorenen": "Verfrorene",
    "Verfroreneren": "Verfrorenere",
    "Verfrorensten": "Verfrorenste",
    "Verfrühenden": "Verfrühende",
    "Verfrühenderen": "Verfrühendere",
    "Verfrühendsten": "Verfrühendste",
    "Verfrühens": "Verfrühen",
    "Verfrühte": "verfrüht",
    "Verfrühten": "Verfrühte",
    "Verfrühteren": "Verfrühtere",
    "Verfrühtesten": "Verfrühteste",
    "Verfugenden": "Verfugende",
    "Verfugenderen": "Verfugendere",
    "Verfugendsten": "Verfugendste",
    "Verfugens": "Verfugen",
    "Verfugte": "verfugt",
    "Verfugten": "Verfugte",
    "Verfugteren": "Verfugtere",
    "Verfugtesten": "Verfugteste",
    "Verfummelnden": "Verfummelnde",
    "Verfummelnderen": "Verfummelndere",
    "Verfummelndsten": "Verfummelndste",
    "Verfummelns": "Verfummeln",
    "Verfummelte": "verfummelt",
    "Verfummelten": "Verfummelte",
    "Verfummelteren": "Verfummeltere",
    "Verfummeltesten": "Verfummelteste",
    "Verfutternden": "Verfutternde",
    "Verfutterns": "Verfuttern",
    "Verfutterte": "verfuttert",
    "Verfutterten": "Verfutterte",
    "Verfutterteren": "Verfuttertere",
    "Verfuttertesten": "Verfutterteste",
    "Verfälschenden": "Verfälschende",
    "Verfälschens": "Verfälschen",
    "Verfälschte": "verfälscht",
    "Verfälschten": "Verfälschte",
    "Verfälschteren": "Verfälschtere",
    "Verfälschtesten": "Verfälschteste",
    "Verfälschungen": "Verfälschung",
    "Verfänglichen": "Verfängliche",
    "Verfänglicheren": "Verfänglichere",
    "Verfänglichsten": "Verfänglichste",
    "Verfärbenden": "Verfärbende",
    "Verfärbenderen": "Verfärbendere",
    "Verfärbendsten": "Verfärbendste",
    "Verfärbens": "Verfärben",
    "Verfärbte": "verfärbt",
    "Verfärbten": "Verfärbte",
    "Verfärbteren": "Verfärbtere",
    "Verfärbtesten": "Verfärbteste",
    "Verfärbungen": "Verfärbung",
    "Verfügbaren": "Verfügbare",
    "Verfügbareren": "Verfügbarere",
    "Verfügbarsten": "Verfügbarste",
    "Verfügende": "verfügend",
    "Verfügenden": "Verfügende",
    "Verfügens": "Verfügen",
    "Verfügte": "verfügt",
    "Verfügten": "Verfügte",
    "Verfügungen": "Verfügung",
    "Verfügungsberechtigte": "verfügungsberechtigt",
    "Verfügungsberechtigten": "Verfügungsberechtigte",
    "Verführenden": "Verführende",
    "Verführenderen": "Verführendere",
    "Verführendsten": "Verführendste",
    "Verführens": "Verführen",
    "Verführerische": "verführerisch",
    "Verführerischen": "Verführerische",
    "Verführerischeren": "Verführerischere",
    "Verführerischsten": "Verführerischste",
    "Verführern": "Verführer",
    "Verführers": "Verführer",
    "Verführte": "verführt",
    "Verführten": "Verführte",
    "Verführteren": "Verführtere",
    "Verführtesten": "Verführteste",
    "Verführungen": "Verführung",
    "Verfütternde": "verfütternd",
    "Verfütternden": "Verfütternde",
    "Verfütternderen": "Verfütterndere",
    "Verfütterndsten": "Verfütterndste",
    "Verfütterns": "Verfüttern",
    "Verfütterte": "verfüttert",
    "Verfütterten": "Verfütterte",
    "Vergammelnden": "Vergammelnde",
    "Vergammelnderen": "Vergammelndere",
    "Vergammelndsten": "Vergammelndste",
    "Vergammelns": "Vergammeln",
    "Vergammelte": "vergammelt",
    "Vergammelten": "Vergammelte",
    "Vergammelteren": "Vergammeltere",
    "Vergammeltesten": "Vergammelteste",
    "Vergangenen": "Vergangene",
    "Vergangenheiten": "Vergangenheit",
    "Vergasenden": "Vergasende",
    "Vergasens": "Vergasen",
    "Vergasern": "Vergaser",
    "Vergasers": "Vergaser",
    "Vergaste": "vergast",
    "Vergasten": "Vergaste",
    "Vergebenden": "Vergebende",
    "Vergebenen": "Vergebene",
    "Vergebens": "Vergeben",
    "Vergeblichen": "Vergebliche",
    "Vergebungen": "Vergebung",
    "Vergegenwärtigenden": "Vergegenwärtigende",
    "Vergegenwärtigens": "Vergegenwärtigen",
    "Vergegenwärtigte": "vergegenwärtigt",
    "Vergegenwärtigten": "Vergegenwärtigte",
    "Vergegenwärtigungen": "Vergegenwärtigung",
    "Vergehenden": "Vergehende",
    "Vergehens": "Vergehen",
    "Vergeigenden": "Vergeigende",
    "Vergeigens": "Vergeigen",
    "Vergeigte": "vergeigt",
    "Vergeigten": "Vergeigte",
    "Vergeltenden": "Vergeltende",
    "Vergeltens": "Vergelten",
    "Vergessenden": "Vergessende",
    "Vergessenen": "Vergessene",
    "Vergessens": "Vergessen",
    "Vergeudenden": "Vergeudende",
    "Vergeudenderen": "Vergeudendere",
    "Vergeudendsten": "Vergeudendste",
    "Vergeudens": "Vergeuden",
    "Vergeudete": "vergeudet",
    "Vergeudeten": "Vergeudete",
    "Vergeudeteren": "Vergeudetere",
    "Vergeudetesten": "Vergeudeteste",
    "Vergewaltigenden": "Vergewaltigende",
    "Vergewaltigens": "Vergewaltigen",
    "Vergewaltigte": "vergewaltigt",
    "Vergewaltigten": "Vergewaltigte",
    "Vergewaltigungen": "Vergewaltigung",
    "Vergewissernden": "Vergewissernde",
    "Vergewisserns": "Vergewissern",
    "Vergewisserte": "vergewissert",
    "Vergewisserten": "Vergewisserte",
    "Vergeßlichen": "Vergeßliche",
    "Vergeßlicheren": "Vergeßlichere",
    "Vergeßlichsten": "Vergeßlichste",
    "Vergießenden": "Vergießende",
    "Vergießens": "Vergießen",
    "Vergiftenden": "Vergiftende",
    "Vergiftenderen": "Vergiftendere",
    "Vergiftendsten": "Vergiftendste",
    "Vergiftens": "Vergiften",
    "Vergiftete": "vergiftet",
    "Vergifteten": "Vergiftete",
    "Vergifteteren": "Vergiftetere",
    "Vergiftetesten": "Vergifteteste",
    "Vergiftungen": "Vergiftung",
    "Vergilbenden": "Vergilbende",
    "Vergilbenderen": "Vergilbendere",
    "Vergilbendsten": "Vergilbendste",
    "Vergilbens": "Vergilben",
    "Vergilbte": "vergilbt",
    "Vergilbten": "Vergilbte",
    "Vergilbteren": "Vergilbtere",
    "Vergilbtesten": "Vergilbteste",
    "Vergitternden": "Vergitternde",
    "Vergitternderen": "Vergitterndere",
    "Vergitterndsten": "Vergitterndste",
    "Vergitterns": "Vergittern",
    "Vergitterte": "vergittert",
    "Vergitterten": "Vergitterte",
    "Vergitterteren": "Vergittertere",
    "Vergittertesten": "Vergitterteste",
    "Verglasenden": "Verglasende",
    "Verglasenderen": "Verglasendere",
    "Verglasendsten": "Verglasendste",
    "Verglasens": "Verglasen",
    "Verglaste": "verglast",
    "Verglasten": "Verglaste",
    "Verglasteren": "Verglastere",
    "Verglastesten": "Verglasteste",
    "Vergleich": "vergleichen",
    "Vergleichbare": "vergleichbar",
    "Vergleichbaren": "Vergleichbare",
    "Vergleichbareren": "Vergleichbarere",
    "Vergleichbarsten": "Vergleichbarste",
    "Vergleiche": "vergleichen",
    "Vergleichen": "Vergleich",
    "Vergleichenden": "Vergleichende",
    "Vergleichens": "Vergleichen",
    "Vergleiches": "Vergleich",
    "Vergleichs": "Vergleich",
    "Vergletscherungen": "Vergletscherung",
    "Verglichenen": "Verglichene",
    "Verglimmenden": "Verglimmende",
    "Verglimmenderen": "Verglimmendere",
    "Verglimmendsten": "Verglimmendste",
    "Verglimmens": "Verglimmen",
    "Verglommenen": "Verglommene",
    "Verglommeneren": "Verglommenere",
    "Verglommensten": "Verglommenste",
    "Verglühenden": "Verglühende",
    "Verglühens": "Verglühen",
    "Verglühte": "verglüht",
    "Verglühten": "Verglühte",
    "Vergnügenden": "Vergnügende",
    "Vergnügens": "Vergnügen",
    "Vergnüglichen": "Vergnügliche",
    "Vergnüglicheren": "Vergnüglichere",
    "Vergnüglichsten": "Vergnüglichste",
    "Vergnügte": "vergnügt",
    "Vergnügten": "Vergnügte",
    "Vergnügteren": "Vergnügtere",
    "Vergnügtesten": "Vergnügteste",
    "Vergnügungen": "Vergnügung",
    "Vergnügungssüchtige": "vergnügungssüchtig",
    "Vergnügungssüchtigen": "Vergnügungssüchtige",
    "Vergnügungssüchtigeren": "Vergnügungssüchtigere",
    "Vergoldenden": "Vergoldende",
    "Vergoldenderen": "Vergoldendere",
    "Vergoldendsten": "Vergoldendste",
    "Vergoldens": "Vergolden",
    "Vergoldete": "vergoldet",
    "Vergoldeten": "Vergoldete",
    "Vergoldeteren": "Vergoldetere",
    "Vergoldetesten": "Vergoldeteste",
    "Vergoldungen": "Vergoldung",
    "Vergoltenen": "Vergoltene",
    "Vergossenen": "Vergossene",
    "Vergosseneren": "Vergossenere",
    "Vergossensten": "Vergossenste",
    "Vergrabenden": "Vergrabende",
    "Vergrabenen": "Vergrabene",
    "Vergrabens": "Vergraben",
    "Vergraulenden": "Vergraulende",
    "Vergraulenderen": "Vergraulendere",
    "Vergraulendsten": "Vergraulendste",
    "Vergraulens": "Vergraulen",
    "Vergraulte": "vergrault",
    "Vergraulten": "Vergraulte",
    "Vergraulteren": "Vergraultere",
    "Vergraultesten": "Vergraulteste",
    "Vergreifenden": "Vergreifende",
    "Vergreifens": "Vergreifen",
    "Vergriffenen": "Vergriffene",
    "Vergriffeneren": "Vergriffenere",
    "Vergriffensten": "Vergriffenste",
    "Vergrämenden": "Vergrämende",
    "Vergrämenderen": "Vergrämendere",
    "Vergrämendsten": "Vergrämendste",
    "Vergrämens": "Vergrämen",
    "Vergrämte": "vergrämt",
    "Vergrämten": "Vergrämte",
    "Vergrämteren": "Vergrämtere",
    "Vergrämtesten": "Vergrämteste",
    "Vergröbernden": "Vergröbernde",
    "Vergröbernderen": "Vergröberndere",
    "Vergröberndsten": "Vergröberndste",
    "Vergröberns": "Vergröbern",
    "Vergröberte": "vergröbert",
    "Vergröberten": "Vergröberte",
    "Vergröberteren": "Vergröbertere",
    "Vergröbertesten": "Vergröberteste",
    "Vergrößernden": "Vergrößernde",
    "Vergrößerns": "Vergrößern",
    "Vergrößerte": "vergrößert",
    "Vergrößerten": "Vergrößerte",
    "Vergrößerteren": "Vergrößertere",
    "Vergrößertesten": "Vergrößerteste",
    "Vergrößerungen": "Vergrößerung",
    "Vergrößerungsfähige": "vergrößerungsfähig",
    "Vergrößerungsfähigen": "Vergrößerungsfähige",
    "Vergrößerungsfähigeren": "Vergrößerungsfähigere",
    "Verguckenden": "Verguckende",
    "Verguckens": "Vergucken",
    "Verguckte": "verguckt",
    "Verguckten": "Verguckte",
    "Vergängliche": "vergänglich",
    "Vergänglichen": "Vergängliche",
    "Vergänglicheren": "Vergänglichere",
    "Vergänglichsten": "Vergänglichste",
    "Vergönnenden": "Vergönnende",
    "Vergönnens": "Vergönnen",
    "Vergönnte": "vergönnt",
    "Vergönnten": "Vergönnte",
    "Vergötternden": "Vergötternde",
    "Vergötterns": "Vergöttern",
    "Vergötterte": "vergöttert",
    "Vergötterten": "Vergötterte",
    "Vergünstigenden": "Vergünstigende",
    "Vergünstigens": "Vergünstigen",
    "Vergünstigte": "vergünstigt",
    "Vergünstigten": "Vergünstigte",
    "Vergünstigungen": "Vergünstigung",
    "Vergütenden": "Vergütende",
    "Vergütenderen": "Vergütendere",
    "Vergütendsten": "Vergütendste",
    "Vergütens": "Vergüten",
    "Vergütete": "vergütet",
    "Vergüteten": "Vergütete",
    "Vergütungen": "Vergütung",
    "Verhaftenden": "Verhaftende",
    "Verhaftens": "Verhaften",
    "Verhaftete": "verhaftet",
    "Verhafteten": "Verhaftete",
    "Verhaftungen": "Verhaftung",
    "Verhagelnden": "Verhagelnde",
    "Verhagelnderen": "Verhagelndere",
    "Verhagelndsten": "Verhagelndste",
    "Verhagelns": "Verhageln",
    "Verhagelte": "verhagelt",
    "Verhagelten": "Verhagelte",
    "Verhagelteren": "Verhageltere",
    "Verhageltesten": "Verhagelteste",
    "Verhallenden": "Verhallende",
    "Verhallenderen": "Verhallendere",
    "Verhallendsten": "Verhallendste",
    "Verhallens": "Verhallen",
    "Verhallte": "verhallt",
    "Verhallten": "Verhallte",
    "Verhallteren": "Verhalltere",
    "Verhalltesten": "Verhallteste",
    "Verhaltenden": "Verhaltende",
    "Verhaltenen": "Verhaltene",
    "Verhaltens": "Verhalten",
    "Verhaltensweisen": "Verhaltensweise",
    "Verhaltungen": "Verhaltung",
    "Verhandelnden": "Verhandelnde",
    "Verhandelns": "Verhandeln",
    "Verhandelte": "verhandelt",
    "Verhandelten": "Verhandelte",
    "Verhandlungen": "Verhandlung",
    "Verhangenen": "Verhangene",
    "Verharmlosenden": "Verharmlosende",
    "Verharmlosenderen": "Verharmlosendere",
    "Verharmlosendsten": "Verharmlosendste",
    "Verharmlosens": "Verharmlosen",
    "Verharmloste": "verharmlost",
    "Verharmlosten": "Verharmloste",
    "Verharmlosteren": "Verharmlostere",
    "Verharmlostesten": "Verharmlosteste",
    "Verharrenden": "Verharrende",
    "Verharrens": "Verharren",
    "Verharrte": "verharrt",
    "Verharrten": "Verharrte",
    "Verhaspelnden": "Verhaspelnde",
    "Verhaspelnderen": "Verhaspelndere",
    "Verhaspelndsten": "Verhaspelndste",
    "Verhaspelns": "Verhaspeln",
    "Verhaspelte": "verhaspelt",
    "Verhaspelten": "Verhaspelte",
    "Verhaspelteren": "Verhaspeltere",
    "Verhaspeltesten": "Verhaspelteste",
    "Verhau": "verhauen",
    "Verhaue": "verhauen",
    "Verhauen": "Verhau",
    "Verhauenden": "Verhauende",
    "Verhauenen": "Verhauene",
    "Verhaueneren": "Verhauenere",
    "Verhauens": "Verhauen",
    "Verhauenste": "verhauen",
    "Verhauensten": "Verhauenste",
    "Verhaues": "Verhau",
    "Verhaus": "Verhau",
    "Verhebenden": "Verhebende",
    "Verhebens": "Verheben",
    "Verheddernden": "Verheddernde",
    "Verheddernderen": "Verhedderndere",
    "Verhedderndsten": "Verhedderndste",
    "Verhedderns": "Verheddern",
    "Verhedderte": "verheddert",
    "Verhedderten": "Verhedderte",
    "Verhedderteren": "Verheddertere",
    "Verheddertesten": "Verhedderteste",
    "Verheerenden": "Verheerende",
    "Verheerenderen": "Verheerendere",
    "Verheerendesten": "Verheerendeste",
    "Verheerens": "Verheeren",
    "Verheerte": "verheert",
    "Verheerten": "Verheerte",
    "Verheerteren": "Verheertere",
    "Verheertesten": "Verheerteste",
    "Verheerungen": "Verheerung",
    "Verheilenden": "Verheilende",
    "Verheilens": "Verheilen",
    "Verheilte": "verheilt",
    "Verheilten": "Verheilte",
    "Verheimlichenden": "Verheimlichende",
    "Verheimlichenderen": "Verheimlichendere",
    "Verheimlichens": "Verheimlichen",
    "Verheimlichte": "verheimlicht",
    "Verheimlichten": "Verheimlichte",
    "Verheimlichteren": "Verheimlichtere",
    "Verheimlichtesten": "Verheimlichteste",
    "Verheiratenden": "Verheiratende",
    "Verheiratens": "Verheiraten",
    "Verheiratete": "verheiratet",
    "Verheirateten": "Verheiratete",
    "Verheiratungen": "Verheiratung",
    "Verheizenden": "Verheizende",
    "Verheizenderen": "Verheizendere",
    "Verheizendsten": "Verheizendste",
    "Verheizens": "Verheizen",
    "Verheizte": "verheizt",
    "Verheizten": "Verheizte",
    "Verheizteren": "Verheiztere",
    "Verheiztesten": "Verheizteste",
    "Verheiß": "verheißen",
    "Verheißenden": "Verheißende",
    "Verheißenen": "Verheißene",
    "Verheißens": "Verheißen",
    "Verheißungen": "Verheißung",
    "Verheißungsvolle": "verheißungsvoll",
    "Verheißungsvollen": "Verheißungsvolle",
    "Verheißungsvolleren": "Verheißungsvollere",
    "Verhelfenden": "Verhelfende",
    "Verhelfens": "Verhelfen",
    "Verherrlichenden": "Verherrlichende",
    "Verherrlichenderen": "Verherrlichendere",
    "Verherrlichens": "Verherrlichen",
    "Verherrlichte": "verherrlicht",
    "Verherrlichten": "Verherrlichte",
    "Verherrlichteren": "Verherrlichtere",
    "Verherrlichtesten": "Verherrlichteste",
    "Verherrlichungen": "Verherrlichung",
    "Verhexenden": "Verhexende",
    "Verhexenderen": "Verhexendere",
    "Verhexendsten": "Verhexendste",
    "Verhexens": "Verhexen",
    "Verhexte": "verhext",
    "Verhexten": "Verhexte",
    "Verhexteren": "Verhextere",
    "Verhextesten": "Verhexteste",
    "Verhindernden": "Verhindernde",
    "Verhinderns": "Verhindern",
    "Verhinderte": "verhindert",
    "Verhinderten": "Verhinderte",
    "Verhinderungen": "Verhinderung",
    "Verhobenen": "Verhobene",
    "Verhohnepiepelnden": "Verhohnepiepelnde",
    "Verhohnepiepelns": "Verhohnepiepeln",
    "Verhohnepiepelte": "verhohnepiepelt",
    "Verhohnepiepelten": "Verhohnepiepelte",
    "Verholfenen": "Verholfene",
    "Verhungernden": "Verhungernde",
    "Verhungernderen": "Verhungerndere",
    "Verhungerndsten": "Verhungerndste",
    "Verhungerns": "Verhungern",
    "Verhungerte": "verhungert",
    "Verhungerten": "Verhungerte",
    "Verhunzenden": "Verhunzende",
    "Verhunzenderen": "Verhunzendere",
    "Verhunzendsten": "Verhunzendste",
    "Verhunzens": "Verhunzen",
    "Verhunzte": "verhunzt",
    "Verhunzten": "Verhunzte",
    "Verhunzteren": "Verhunztere",
    "Verhunztesten": "Verhunzteste",
    "Verhältnismäßigen": "Verhältnismäßige",
    "Verhältnisse": "Verhältnis",
    "Verhältnissen": "Verhältnis",
    "Verhältnisses": "Verhältnis",
    "Verhängenden": "Verhängende",
    "Verhängens": "Verhängen",
    "Verhängnisvollen": "Verhängnisvolle",
    "Verhängnisvolleren": "Verhängnisvollere",
    "Verhängte": "verhängt",
    "Verhängten": "Verhängte",
    "Verhärtenden": "Verhärtende",
    "Verhärtenderen": "Verhärtendere",
    "Verhärtendsten": "Verhärtendste",
    "Verhärtens": "Verhärten",
    "Verhärtete": "verhärtet",
    "Verhärteten": "Verhärtete",
    "Verhärteteren": "Verhärtetere",
    "Verhärtetesten": "Verhärteteste",
    "Verhärtungen": "Verhärtung",
    "Verhätschelnden": "Verhätschelnde",
    "Verhätschelnderen": "Verhätschelndere",
    "Verhätschelndsten": "Verhätschelndste",
    "Verhätschelns": "Verhätscheln",
    "Verhätschelte": "verhätschelt",
    "Verhätschelten": "Verhätschelte",
    "Verhätschelteren": "Verhätscheltere",
    "Verhätscheltesten": "Verhätschelteste",
    "Verhöhnenden": "Verhöhnende",
    "Verhöhnenderen": "Verhöhnendere",
    "Verhöhnendsten": "Verhöhnendste",
    "Verhöhnens": "Verhöhnen",
    "Verhöhnte": "verhöhnt",
    "Verhöhnten": "Verhöhnte",
    "Verhöhnteren": "Verhöhntere",
    "Verhöhntesten": "Verhöhnteste",
    "Verhökernden": "Verhökernde",
    "Verhökerns": "Verhökern",
    "Verhökerte": "verhökert",
    "Verhökerten": "Verhökerte",
    "Verhör": "verhören",
    "Verhöre": "verhören",
    "Verhören": "Verhör",
    "Verhörenden": "Verhörende",
    "Verhörens": "Verhören",
    "Verhörs": "Verhör",
    "Verhörte": "verhört",
    "Verhörten": "Verhörte",
    "Verhüllenden": "Verhüllende",
    "Verhüllenderen": "Verhüllendere",
    "Verhüllendsten": "Verhüllendste",
    "Verhüllens": "Verhüllen",
    "Verhüllte": "verhüllt",
    "Verhüllten": "Verhüllte",
    "Verhüllteren": "Verhülltere",
    "Verhülltesten": "Verhüllteste",
    "Verhütenden": "Verhütende",
    "Verhütens": "Verhüten",
    "Verhütete": "verhütet",
    "Verhüteten": "Verhütete",
    "Verinnerlichenden": "Verinnerlichende",
    "Verinnerlichens": "Verinnerlichen",
    "Verinnerlichte": "verinnerlicht",
    "Verinnerlichten": "Verinnerlichte",
    "Verirrenden": "Verirrende",
    "Verirrens": "Verirren",
    "Verirrte": "verirrt",
    "Verirrten": "Verirrte",
    "Verirrteren": "Verirrtere",
    "Verirrtesten": "Verirrteste",
    "Verjagenden": "Verjagende",
    "Verjagenderen": "Verjagendere",
    "Verjagendsten": "Verjagendste",
    "Verjagens": "Verjagen",
    "Verjagte": "verjagt",
    "Verjagten": "Verjagte",
    "Verjagteren": "Verjagtere",
    "Verjagtesten": "Verjagteste",
    "Verjubelnden": "Verjubelnde",
    "Verjubelnderen": "Verjubelndere",
    "Verjubelndsten": "Verjubelndste",
    "Verjubelns": "Verjubeln",
    "Verjubelte": "verjubelt",
    "Verjubelten": "Verjubelte",
    "Verjubelteren": "Verjubeltere",
    "Verjubeltesten": "Verjubelteste",
    "Verjährenden": "Verjährende",
    "Verjährens": "Verjähren",
    "Verjährte": "verjährt",
    "Verjährten": "Verjährte",
    "Verjüngenden": "Verjüngende",
    "Verjüngenderen": "Verjüngendere",
    "Verjüngendsten": "Verjüngendste",
    "Verjüngens": "Verjüngen",
    "Verjüngte": "verjüngt",
    "Verjüngten": "Verjüngte",
    "Verjüngteren": "Verjüngtere",
    "Verjüngtesten": "Verjüngteste",
    "Verkabelnden": "Verkabelnde",
    "Verkabelns": "Verkabeln",
    "Verkabelte": "verkabelt",
    "Verkabelten": "Verkabelte",
    "Verkabelteren": "Verkabeltere",
    "Verkabeltesten": "Verkabelteste",
    "Verkabelungen": "Verkabelung",
    "Verkachelnden": "Verkachelnde",
    "Verkachelns": "Verkacheln",
    "Verkachelte": "verkachelt",
    "Verkachelten": "Verkachelte",
    "Verkachelteren": "Verkacheltere",
    "Verkacheltesten": "Verkachelteste",
    "Verkalkenden": "Verkalkende",
    "Verkalkenderen": "Verkalkendere",
    "Verkalkendsten": "Verkalkendste",
    "Verkalkens": "Verkalken",
    "Verkalkte": "verkalkt",
    "Verkalkten": "Verkalkte",
    "Verkalkteren": "Verkalktere",
    "Verkalktesten": "Verkalkteste",
    "Verkalkulierenden": "Verkalkulierende",
    "Verkalkulierens": "Verkalkulieren",
    "Verkalkulierte": "verkalkuliert",
    "Verkalkulierten": "Verkalkulierte",
    "Verkannte": "verkennen",
    "Verkannten": "verkennen",
    "Verkannteren": "Verkanntere",
    "Verkanntesten": "Verkannteste",
    "Verkantenden": "Verkantende",
    "Verkantenderen": "Verkantendere",
    "Verkantendsten": "Verkantendste",
    "Verkantens": "Verkanten",
    "Verkantete": "verkantet",
    "Verkanteten": "Verkantete",
    "Verkanteteren": "Verkantetere",
    "Verkantetesten": "Verkanteteste",
    "Verkappenden": "Verkappende",
    "Verkappenderen": "Verkappendere",
    "Verkappendsten": "Verkappendste",
    "Verkappens": "Verkappen",
    "Verkappte": "verkappt",
    "Verkappten": "Verkappte",
    "Verkappteren": "Verkapptere",
    "Verkapptesten": "Verkappteste",
    "Verkaterten": "Verkaterte",
    "Verkaterteren": "Verkatertere",
    "Verkatertesten": "Verkaterteste",
    "Verkauf": "verkaufen",
    "Verkaufe": "verkaufen",
    "Verkaufenden": "Verkaufende",
    "Verkaufens": "Verkaufen",
    "Verkaufes": "Verkauf",
    "Verkaufs": "Verkauf",
    "Verkaufsfördernde": "verkaufsfördernd",
    "Verkaufsfördernden": "Verkaufsfördernde",
    "Verkaufsfördernderen": "Verkaufsförderndere",
    "Verkaufsoffenen": "Verkaufsoffene",
    "Verkaufte": "verkauft",
    "Verkauften": "Verkaufte",
    "Verkehr": "verkehren",
    "Verkehrenden": "Verkehrende",
    "Verkehrens": "Verkehren",
    "Verkehrs": "Verkehr",
    "Verkehrsberuhigte": "verkehrsberuhigt",
    "Verkehrsberuhigten": "Verkehrsberuhigte",
    "Verkehrsberuhigteren": "Verkehrsberuhigtere",
    "Verkehrsreichen": "Verkehrsreiche",
    "Verkehrsreicheren": "Verkehrsreichere",
    "Verkehrsreichsten": "Verkehrsreichste",
    "Verkehrsschwachen": "Verkehrsschwache",
    "Verkehrsschwächeren": "Verkehrsschwächere",
    "Verkehrswidrigen": "Verkehrswidrige",
    "Verkehrte": "verkehrt",
    "Verkehrten": "Verkehrte",
    "Verkehrteren": "Verkehrtere",
    "Verkehrtesten": "Verkehrteste",
    "Verkeilenden": "Verkeilende",
    "Verkeilenderen": "Verkeilendere",
    "Verkeilendsten": "Verkeilendste",
    "Verkeilens": "Verkeilen",
    "Verkeilte": "verkeilt",
    "Verkeilten": "Verkeilte",
    "Verkeilteren": "Verkeiltere",
    "Verkeiltesten": "Verkeilteste",
    "Verkennenden": "Verkennende",
    "Verkennens": "Verkennen",
    "Verkettenden": "Verkettende",
    "Verkettenderen": "Verkettendere",
    "Verkettendsten": "Verkettendste",
    "Verkettens": "Verketten",
    "Verkettete": "verkettet",
    "Verketteten": "Verkettete",
    "Verketteteren": "Verkettetere",
    "Verkettetesten": "Verketteteste",
    "Verkittenden": "Verkittende",
    "Verkittens": "Verkitten",
    "Verkittete": "verkittet",
    "Verkitteten": "Verkittete",
    "Verklagenden": "Verklagende",
    "Verklagens": "Verklagen",
    "Verklagte": "verklagt",
    "Verklagten": "Verklagte",
    "Verklammernden": "Verklammernde",
    "Verklammernderen": "Verklammerndere",
    "Verklammerndsten": "Verklammerndste",
    "Verklammerns": "Verklammern",
    "Verklammerte": "verklammert",
    "Verklammerten": "Verklammerte",
    "Verklammerteren": "Verklammertere",
    "Verklammertesten": "Verklammerteste",
    "Verklauselnden": "Verklauselnde",
    "Verklauselnderen": "Verklauselndere",
    "Verklauselndsten": "Verklauselndste",
    "Verklauselns": "Verklauseln",
    "Verklauselte": "verklauselt",
    "Verklauselten": "Verklauselte",
    "Verklauselteren": "Verklauseltere",
    "Verklauseltesten": "Verklauselteste",
    "Verklebenden": "Verklebende",
    "Verklebenderen": "Verklebendere",
    "Verklebendsten": "Verklebendste",
    "Verklebens": "Verkleben",
    "Verklebte": "verklebt",
    "Verklebten": "Verklebte",
    "Verklebteren": "Verklebtere",
    "Verklebtesten": "Verklebteste",
    "Verkleidenden": "Verkleidende",
    "Verkleidenderen": "Verkleidendere",
    "Verkleidendsten": "Verkleidendste",
    "Verkleidens": "Verkleiden",
    "Verkleidete": "verkleidet",
    "Verkleideten": "Verkleidete",
    "Verkleideteren": "Verkleidetere",
    "Verkleidetesten": "Verkleideteste",
    "Verkleinernden": "Verkleinernde",
    "Verkleinerns": "Verkleinern",
    "Verkleinerte": "verkleinert",
    "Verkleinerten": "Verkleinerte",
    "Verkleinerteren": "Verkleinertere",
    "Verkleinertesten": "Verkleinerteste",
    "Verkleinerungen": "Verkleinerung",
    "Verkleisternden": "Verkleisternde",
    "Verkleisterns": "Verkleistern",
    "Verkleisterte": "verkleistert",
    "Verkleisterten": "Verkleisterte",
    "Verklemmenden": "Verklemmende",
    "Verklemmenderen": "Verklemmendere",
    "Verklemmendsten": "Verklemmendste",
    "Verklemmens": "Verklemmen",
    "Verklemmte": "verklemmt",
    "Verklemmten": "Verklemmte",
    "Verklemmteren": "Verklemmtere",
    "Verklemmtesten": "Verklemmteste",
    "Verklingenden": "Verklingende",
    "Verklingens": "Verklingen",
    "Verkloppenden": "Verkloppende",
    "Verkloppens": "Verkloppen",
    "Verkloppte": "verkloppt",
    "Verkloppten": "Verkloppte",
    "Verklumpenden": "Verklumpende",
    "Verklumpenderen": "Verklumpendere",
    "Verklumpendsten": "Verklumpendste",
    "Verklumpens": "Verklumpen",
    "Verklumpte": "verklumpt",
    "Verklumpten": "Verklumpte",
    "Verklumpteren": "Verklumptere",
    "Verklumptesten": "Verklumpteste",
    "Verklungenen": "Verklungene",
    "Verklärenden": "Verklärende",
    "Verklärenderen": "Verklärendere",
    "Verklärendsten": "Verklärendste",
    "Verklärens": "Verklären",
    "Verklärte": "verklärt",
    "Verklärten": "Verklärte",
    "Verklärteren": "Verklärtere",
    "Verklärtesten": "Verklärteste",
    "Verklüngelnden": "Verklüngelnde",
    "Verklüngelnderen": "Verklüngelndere",
    "Verklüngelndsten": "Verklüngelndste",
    "Verklüngelns": "Verklüngeln",
    "Verklüngelte": "verklüngelt",
    "Verklüngelten": "Verklüngelte",
    "Verklüngelteren": "Verklüngeltere",
    "Verklüngeltesten": "Verklüngelteste",
    "Verknackenden": "Verknackende",
    "Verknackens": "Verknacken",
    "Verknacksenden": "Verknacksende",
    "Verknacksens": "Verknacksen",
    "Verknackste": "verknackst",
    "Verknacksten": "Verknackste",
    "Verknackte": "verknackt",
    "Verknackten": "Verknackte",
    "Verknallenden": "Verknallende",
    "Verknallenderen": "Verknallendere",
    "Verknallendsten": "Verknallendste",
    "Verknallens": "Verknallen",
    "Verknallte": "verknallt",
    "Verknallten": "Verknallte",
    "Verknallteren": "Verknalltere",
    "Verknalltesten": "Verknallteste",
    "Verknappenden": "Verknappende",
    "Verknappens": "Verknappen",
    "Verknappte": "verknappt",
    "Verknappten": "Verknappte",
    "Verkneifenden": "Verkneifende",
    "Verkneifens": "Verkneifen",
    "Verknetenden": "Verknetende",
    "Verknetenderen": "Verknetendere",
    "Verknetendsten": "Verknetendste",
    "Verknetens": "Verkneten",
    "Verknetete": "verknetet",
    "Verkneteten": "Verknetete",
    "Verkneteteren": "Verknetetere",
    "Verknetetesten": "Verkneteteste",
    "Verkniffenen": "Verkniffene",
    "Verknitternden": "Verknitternde",
    "Verknitternderen": "Verknitterndere",
    "Verknitterndsten": "Verknitterndste",
    "Verknitterns": "Verknittern",
    "Verknitterte": "verknittert",
    "Verknitterten": "Verknitterte",
    "Verknitterteren": "Verknittertere",
    "Verknittertesten": "Verknitterteste",
    "Verknorpelnden": "Verknorpelnde",
    "Verknorpelnderen": "Verknorpelndere",
    "Verknorpelndsten": "Verknorpelndste",
    "Verknorpelns": "Verknorpeln",
    "Verknorpelte": "verknorpelt",
    "Verknorpelten": "Verknorpelte",
    "Verknorpelteren": "Verknorpeltere",
    "Verknorpeltesten": "Verknorpelteste",
    "Verknotenden": "Verknotende",
    "Verknotens": "Verknoten",
    "Verknotete": "verknotet",
    "Verknoteten": "Verknotete",
    "Verknoteteren": "Verknotetere",
    "Verknotetesten": "Verknoteteste",
    "Verknüpfenden": "Verknüpfende",
    "Verknüpfens": "Verknüpfen",
    "Verknüpfte": "verknüpft",
    "Verknüpften": "Verknüpfte",
    "Verknüpfungen": "Verknüpfung",
    "Verkohlenden": "Verkohlende",
    "Verkohlenderen": "Verkohlendere",
    "Verkohlendsten": "Verkohlendste",
    "Verkohlens": "Verkohlen",
    "Verkohlte": "verkohlt",
    "Verkohlten": "Verkohlte",
    "Verkohlteren": "Verkohltere",
    "Verkohltesten": "Verkohlteste",
    "Verkokelnden": "Verkokelnde",
    "Verkokelnderen": "Verkokelndere",
    "Verkokelndsten": "Verkokelndste",
    "Verkokelns": "Verkokeln",
    "Verkokelte": "verkokelt",
    "Verkokelten": "Verkokelte",
    "Verkokelteren": "Verkokeltere",
    "Verkokeltesten": "Verkokelteste",
    "Verkommenden": "Verkommende",
    "Verkommenen": "Verkommene",
    "Verkommeneren": "Verkommenere",
    "Verkommens": "Verkommen",
    "Verkommenste": "verkommen",
    "Verkommensten": "Verkommenste",
    "Verkonsumierenden": "Verkonsumierende",
    "Verkonsumierens": "Verkonsumieren",
    "Verkonsumierte": "verkonsumiert",
    "Verkonsumierten": "Verkonsumierte",
    "Verkorksenden": "Verkorksende",
    "Verkorksenderen": "Verkorksendere",
    "Verkorksendsten": "Verkorksendste",
    "Verkorksens": "Verkorksen",
    "Verkorkste": "verkorkst",
    "Verkorksten": "Verkorkste",
    "Verkorksteren": "Verkorkstere",
    "Verkorkstesten": "Verkorksteste",
    "Verkostenden": "Verkostende",
    "Verkostens": "Verkosten",
    "Verkostete": "verkostet",
    "Verkosteten": "Verkostete",
    "Verkrachenden": "Verkrachende",
    "Verkrachenderen": "Verkrachendere",
    "Verkrachendsten": "Verkrachendste",
    "Verkrachens": "Verkrachen",
    "Verkrachte": "verkracht",
    "Verkrachten": "Verkrachte",
    "Verkrachteren": "Verkrachtere",
    "Verkrachtesten": "Verkrachteste",
    "Verkraftbaren": "Verkraftbare",
    "Verkraftenden": "Verkraftende",
    "Verkraftens": "Verkraften",
    "Verkraftete": "verkraftet",
    "Verkrafteten": "Verkraftete",
    "Verkrampfenden": "Verkrampfende",
    "Verkrampfenderen": "Verkrampfendere",
    "Verkrampfendsten": "Verkrampfendste",
    "Verkrampfens": "Verkrampfen",
    "Verkrampfte": "verkrampft",
    "Verkrampften": "Verkrampfte",
    "Verkrampfteren": "Verkrampftere",
    "Verkrampftesten": "Verkrampfteste",
    "Verkratzenden": "Verkratzende",
    "Verkratzenderen": "Verkratzendere",
    "Verkratzendsten": "Verkratzendste",
    "Verkratzens": "Verkratzen",
    "Verkratzte": "verkratzt",
    "Verkratzten": "Verkratzte",
    "Verkratzteren": "Verkratztere",
    "Verkratztesten": "Verkratzteste",
    "Verkriechenden": "Verkriechende",
    "Verkriechenderen": "Verkriechendere",
    "Verkriechendsten": "Verkriechendste",
    "Verkriechens": "Verkriechen",
    "Verkrochenen": "Verkrochene",
    "Verkrocheneren": "Verkrochenere",
    "Verkrochensten": "Verkrochenste",
    "Verkrustenden": "Verkrustende",
    "Verkrustenderen": "Verkrustendere",
    "Verkrustendsten": "Verkrustendste",
    "Verkrustens": "Verkrusten",
    "Verkrustete": "verkrustet",
    "Verkrusteten": "Verkrustete",
    "Verkrusteteren": "Verkrustetere",
    "Verkrustetesten": "Verkrusteteste",
    "Verkrümelnden": "Verkrümelnde",
    "Verkrümelnderen": "Verkrümelndere",
    "Verkrümelndsten": "Verkrümelndste",
    "Verkrümelns": "Verkrümeln",
    "Verkrümelte": "verkrümelt",
    "Verkrümelten": "Verkrümelte",
    "Verkrümelteren": "Verkrümeltere",
    "Verkrümeltesten": "Verkrümelteste",
    "Verkrümmenden": "Verkrümmende",
    "Verkrümmenderen": "Verkrümmendere",
    "Verkrümmendsten": "Verkrümmendste",
    "Verkrümmens": "Verkrümmen",
    "Verkrümmte": "verkrümmt",
    "Verkrümmten": "Verkrümmte",
    "Verkrümmteren": "Verkrümmtere",
    "Verkrümmtesten": "Verkrümmteste",
    "Verkrüppelnden": "Verkrüppelnde",
    "Verkrüppelnderen": "Verkrüppelndere",
    "Verkrüppelndsten": "Verkrüppelndste",
    "Verkrüppelns": "Verkrüppeln",
    "Verkrüppelte": "verkrüppelt",
    "Verkrüppelten": "Verkrüppelte",
    "Verkrüppelteren": "Verkrüppeltere",
    "Verkrüppeltesten": "Verkrüppelteste",
    "Verkuppelnden": "Verkuppelnde",
    "Verkuppelns": "Verkuppeln",
    "Verkuppelte": "verkuppelt",
    "Verkuppelten": "Verkuppelte",
    "Verkäufe": "Verkauf",
    "Verkäufen": "Verkauf",
    "Verkäuferinnen": "Verkäuferin",
    "Verkäufern": "Verkäufer",
    "Verkäufers": "Verkäufer",
    "Verkäuflichen": "Verkäufliche",
    "Verkörpernden": "Verkörpernde",
    "Verkörperns": "Verkörpern",
    "Verkörperte": "verkörpert",
    "Verkörperten": "Verkörperte",
    "Verköstigenden": "Verköstigende",
    "Verköstigens": "Verköstigen",
    "Verköstigte": "verköstigt",
    "Verköstigten": "Verköstigte",
    "Verkühlenden": "Verkühlende",
    "Verkühlenderen": "Verkühlendere",
    "Verkühlendsten": "Verkühlendste",
    "Verkühlens": "Verkühlen",
    "Verkühlte": "verkühlt",
    "Verkühlten": "Verkühlte",
    "Verkühlteren": "Verkühltere",
    "Verkühltesten": "Verkühlteste",
    "Verkümmernden": "Verkümmernde",
    "Verkümmernderen": "Verkümmerndere",
    "Verkümmerndsten": "Verkümmerndste",
    "Verkümmerns": "Verkümmern",
    "Verkümmerte": "verkümmert",
    "Verkümmerten": "Verkümmerte",
    "Verkümmerteren": "Verkümmertere",
    "Verkümmertesten": "Verkümmerteste",
    "Verkündenden": "Verkündende",
    "Verkündens": "Verkünden",
    "Verkündete": "verkündet",
    "Verkündeten": "Verkündete",
    "Verkündigenden": "Verkündigende",
    "Verkündigens": "Verkündigen",
    "Verkündigte": "verkündigt",
    "Verkündigten": "Verkündigte",
    "Verkürzenden": "Verkürzende",
    "Verkürzens": "Verkürzen",
    "Verkürzte": "verkürzt",
    "Verkürzten": "Verkürzte",
    "Verladenden": "Verladende",
    "Verladenen": "Verladene",
    "Verladens": "Verladen",
    "Verladungen": "Verladung",
    "Verlage": "Verlag",
    "Verlagen": "Verlag",
    "Verlagernden": "Verlagernde",
    "Verlagerns": "Verlagern",
    "Verlagerte": "verlagert",
    "Verlagerten": "Verlagerte",
    "Verlagerteren": "Verlagertere",
    "Verlagertesten": "Verlagerteste",
    "Verlagerungen": "Verlagerung",
    "Verlages": "Verlag",
    "Verlags": "Verlag",
    "Verlangenden": "Verlangende",
    "Verlangenderen": "Verlangendere",
    "Verlangendsten": "Verlangendste",
    "Verlangens": "Verlangen",
    "Verlangsamenden": "Verlangsamende",
    "Verlangsamenderen": "Verlangsamendere",
    "Verlangsamendsten": "Verlangsamendste",
    "Verlangsamens": "Verlangsamen",
    "Verlangsamte": "verlangsamt",
    "Verlangsamten": "Verlangsamte",
    "Verlangsamteren": "Verlangsamtere",
    "Verlangsamtesten": "Verlangsamteste",
    "Verlangte": "verlangt",
    "Verlangten": "Verlangte",
    "Verlangteren": "Verlangtere",
    "Verlangtesten": "Verlangteste",
    "Verlassenden": "Verlassende",
    "Verlassenen": "Verlassene",
    "Verlasseneren": "Verlassenere",
    "Verlassens": "Verlassen",
    "Verlassenste": "verlassen",
    "Verlassensten": "Verlassenste",
    "Verlauf": "verlaufen",
    "Verlaufe": "verlaufen",
    "Verlaufenden": "Verlaufende",
    "Verlaufenen": "Verlaufene",
    "Verlaufens": "Verlaufen",
    "Verlaufes": "Verlauf",
    "Verlaufs": "Verlauf",
    "Verlautbarungen": "Verlautbarung",
    "Verlautenden": "Verlautende",
    "Verlautens": "Verlauten",
    "Verlautete": "verlautet",
    "Verlauteten": "Verlautete",
    "Verlebenden": "Verlebende",
    "Verlebens": "Verleben",
    "Verlebte": "verlebt",
    "Verlebten": "Verlebte",
    "Verlegenden": "Verlegende",
    "Verlegenheiten": "Verlegenheit",
    "Verlegens": "Verlegen",
    "Verlegern": "Verleger",
    "Verlegers": "Verleger",
    "Verlegte": "verlegt",
    "Verlegten": "Verlegte",
    "Verlegungen": "Verlegung",
    "Verleibenden": "Verleibende",
    "Verleibens": "Verleiben",
    "Verleibte": "verleibt",
    "Verleibten": "Verleibte",
    "Verleih": "verleihen",
    "Verleihe": "verleihen",
    "Verleihen": "Verleih",
    "Verleihenden": "Verleihende",
    "Verleihens": "Verleihen",
    "Verleihern": "Verleiher",
    "Verleihers": "Verleiher",
    "Verleihs": "Verleih",
    "Verleihungen": "Verleihung",
    "Verleimenden": "Verleimende",
    "Verleimens": "Verleimen",
    "Verleimte": "verleimt",
    "Verleimten": "Verleimte",
    "Verleitenden": "Verleitende",
    "Verleitens": "Verleiten",
    "Verleitete": "verleitet",
    "Verleiteten": "Verleitete",
    "Verlernenden": "Verlernende",
    "Verlernens": "Verlernen",
    "Verlernte": "verlernt",
    "Verlernten": "Verlernte",
    "Verlernteren": "Verlerntere",
    "Verlerntesten": "Verlernteste",
    "Verlesenden": "Verlesende",
    "Verlesenen": "Verlesene",
    "Verlesens": "Verlesen",
    "Verlesungen": "Verlesung",
    "Verletzbare": "verletzbar",
    "Verletzbaren": "Verletzbare",
    "Verletzbareren": "Verletzbarere",
    "Verletzbarsten": "Verletzbarste",
    "Verletzenden": "Verletzende",
    "Verletzenderen": "Verletzendere",
    "Verletzendsten": "Verletzendste",
    "Verletzens": "Verletzen",
    "Verletzte": "verletzt",
    "Verletzten": "Verletzte",
    "Verletzteren": "Verletztere",
    "Verletztesten": "Verletzteste",
    "Verletzungen": "Verletzung",
    "Verleugnenden": "Verleugnende",
    "Verleugnens": "Verleugnen",
    "Verleugnete": "verleugnet",
    "Verleugneten": "Verleugnete",
    "Verleugnungen": "Verleugnung",
    "Verleumdenden": "Verleumdende",
    "Verleumdens": "Verleumden",
    "Verleumderische": "verleumderisch",
    "Verleumderischen": "Verleumderische",
    "Verleumderischeren": "Verleumderischere",
    "Verleumdern": "Verleumder",
    "Verleumders": "Verleumder",
    "Verleumdete": "verleumdet",
    "Verleumdeten": "Verleumdete",
    "Verliebenden": "Verliebende",
    "Verliebens": "Verlieben",
    "Verliebte": "verliebt",
    "Verliebten": "Verliebte",
    "Verliebteren": "Verliebtere",
    "Verliebtesten": "Verliebteste",
    "Verliehenen": "Verliehene",
    "Verlierenden": "Verlierende",
    "Verlierens": "Verlieren",
    "Verlierern": "Verlierer",
    "Verlierers": "Verlierer",
    "Verlobenden": "Verlobende",
    "Verlobens": "Verloben",
    "Verlobte": "verlobt",
    "Verlobten": "Verlobte",
    "Verlockenden": "Verlockende",
    "Verlockenderen": "Verlockendere",
    "Verlockendsten": "Verlockendste",
    "Verlockens": "Verlocken",
    "Verlockte": "verlockt",
    "Verlockten": "Verlockte",
    "Verlogenen": "Verlogene",
    "Verlogeneren": "Verlogenere",
    "Verlogenheiten": "Verlogenheit",
    "Verlogenste": "verlogen",
    "Verlogensten": "Verlogenste",
    "Verlorenen": "Verlorene",
    "Verloreneren": "Verlorenere",
    "Verlorensten": "Verlorenste",
    "Verloschenen": "Verloschene",
    "Verloscheneren": "Verloschenere",
    "Verloschenste": "verloschen",
    "Verloschensten": "Verloschenste",
    "Verlosenden": "Verlosende",
    "Verlosens": "Verlosen",
    "Verloste": "verlost",
    "Verlosten": "Verloste",
    "Verlotternden": "Verlotternde",
    "Verlotternderen": "Verlotterndere",
    "Verlotterndsten": "Verlotterndste",
    "Verlotterns": "Verlottern",
    "Verlotterte": "verlottert",
    "Verlotterten": "Verlotterte",
    "Verlotterteren": "Verlottertere",
    "Verlottertesten": "Verlotterteste",
    "Verludernden": "Verludernde",
    "Verludernderen": "Verluderndere",
    "Verluderndsten": "Verluderndste",
    "Verluderns": "Verludern",
    "Verluderte": "verludert",
    "Verluderten": "Verluderte",
    "Verluderteren": "Verludertere",
    "Verludertesten": "Verluderteste",
    "Verluste": "Verlust",
    "Verlusten": "Verlust",
    "Verlustes": "Verlust",
    "Verlusts": "Verlust",
    "Verlängernden": "Verlängernde",
    "Verlängerns": "Verlängern",
    "Verlängerte": "verlängert",
    "Verlängerten": "Verlängerte",
    "Verlängerteren": "Verlängertere",
    "Verlängertesten": "Verlängerteste",
    "Verlängerungen": "Verlängerung",
    "Verläufe": "Verlauf",
    "Verläufen": "Verlauf",
    "Verläßlichen": "Verläßliche",
    "Verläßlicheren": "Verläßlichere",
    "Verläßlichsten": "Verläßlichste",
    "Verlöschenden": "Verlöschende",
    "Verlöschens": "Verlöschen",
    "Verlötenden": "Verlötende",
    "Verlötens": "Verlöten",
    "Verlötete": "verlötet",
    "Verlöteten": "Verlötete",
    "Vermachenden": "Vermachende",
    "Vermachens": "Vermachen",
    "Vermachte": "vermacht",
    "Vermachten": "Vermachte",
    "Vermalenden": "Vermalende",
    "Vermalens": "Vermalen",
    "Vermalte": "vermalt",
    "Vermalten": "Vermalte",
    "Vermampfenden": "Vermampfende",
    "Vermampfenderen": "Vermampfendere",
    "Vermampfendsten": "Vermampfendste",
    "Vermampfens": "Vermampfen",
    "Vermampfte": "vermampft",
    "Vermampften": "Vermampfte",
    "Vermarktenden": "Vermarktende",
    "Vermarktenderen": "Vermarktendere",
    "Vermarktendsten": "Vermarktendste",
    "Vermarktens": "Vermarkten",
    "Vermarktete": "vermarktet",
    "Vermarkteten": "Vermarktete",
    "Vermarkteteren": "Vermarktetere",
    "Vermarktetesten": "Vermarkteteste",
    "Vermarktungen": "Vermarktung",
    "Vermarkungen": "Vermarkung",
    "Vermasselnden": "Vermasselnde",
    "Vermasselnderen": "Vermasselndere",
    "Vermasselndsten": "Vermasselndste",
    "Vermasselns": "Vermasseln",
    "Vermasselte": "vermasselt",
    "Vermasselten": "Vermasselte",
    "Vermasselteren": "Vermasseltere",
    "Vermasseltesten": "Vermasselteste",
    "Vermehrenden": "Vermehrende",
    "Vermehrens": "Vermehren",
    "Vermehrte": "vermehrt",
    "Vermehrten": "Vermehrte",
    "Vermeidbaren": "Vermeidbare",
    "Vermeidenden": "Vermeidende",
    "Vermeidens": "Vermeiden",
    "Vermeidungen": "Vermeidung",
    "Vermeintliche": "vermeintlich",
    "Vermeintlichen": "Vermeintliche",
    "Vermeldenden": "Vermeldende",
    "Vermeldens": "Vermelden",
    "Vermeldete": "vermeldet",
    "Vermeldeten": "Vermeldete",
    "Vermengenden": "Vermengende",
    "Vermengens": "Vermengen",
    "Vermengte": "vermengt",
    "Vermengten": "Vermengte",
    "Vermenschlichenden": "Vermenschlichende",
    "Vermenschlichenderen": "Vermenschlichendere",
    "Vermenschlichens": "Vermenschlichen",
    "Vermenschlichte": "vermenschlicht",
    "Vermenschlichten": "Vermenschlichte",
    "Vermenschlichteren": "Vermenschlichtere",
    "Vermerk": "vermerken",
    "Vermerke": "vermerken",
    "Vermerken": "Vermerk",
    "Vermerkenden": "Vermerkende",
    "Vermerkens": "Vermerken",
    "Vermerks": "Vermerk",
    "Vermerkte": "vermerkt",
    "Vermerkten": "Vermerkte",
    "Vermessenden": "Vermessende",
    "Vermessenen": "Vermessene",
    "Vermessens": "Vermessen",
    "Vermessern": "Vermesser",
    "Vermessers": "Vermesser",
    "Vermessungen": "Vermessung",
    "Vermiedenen": "Vermiedene",
    "Vermiedeneren": "Vermiedenere",
    "Vermiedensten": "Vermiedenste",
    "Vermiefenden": "Vermiefende",
    "Vermiefenderen": "Vermiefendere",
    "Vermiefendsten": "Vermiefendste",
    "Vermiefens": "Vermiefen",
    "Vermiefte": "vermieft",
    "Vermieften": "Vermiefte",
    "Vermiefteren": "Vermieftere",
    "Vermieftesten": "Vermiefteste",
    "Vermiesenden": "Vermiesende",
    "Vermiesenderen": "Vermiesendere",
    "Vermiesendsten": "Vermiesendste",
    "Vermiesens": "Vermiesen",
    "Vermieste": "vermiest",
    "Vermiesten": "Vermieste",
    "Vermiesteren": "Vermiestere",
    "Vermiestesten": "Vermiesteste",
    "Vermietenden": "Vermietende",
    "Vermietens": "Vermieten",
    "Vermietern": "Vermieter",
    "Vermieters": "Vermieter",
    "Vermietete": "vermietet",
    "Vermieteten": "Vermietete",
    "Vermietungen": "Vermietung",
    "Vermimenden": "Vermimende",
    "Vermimenderen": "Vermimendere",
    "Vermimendsten": "Vermimendste",
    "Vermimens": "Vermimen",
    "Vermimte": "vermimt",
    "Vermimten": "Vermimte",
    "Vermimteren": "Vermimtere",
    "Vermimtesten": "Vermimteste",
    "Vermindernden": "Vermindernde",
    "Verminderns": "Vermindern",
    "Verminderte": "vermindert",
    "Verminderten": "Verminderte",
    "Verminderungen": "Verminderung",
    "Verminenden": "Verminende",
    "Verminenderen": "Verminendere",
    "Verminendsten": "Verminendste",
    "Verminens": "Verminen",
    "Verminte": "vermint",
    "Verminten": "Verminte",
    "Verminteren": "Vermintere",
    "Vermintesten": "Verminteste",
    "Vermischenden": "Vermischende",
    "Vermischens": "Vermischen",
    "Vermischte": "vermischt",
    "Vermischten": "Vermischte",
    "Vermischteren": "Vermischtere",
    "Vermischtesten": "Vermischteste",
    "Vermissenden": "Vermissende",
    "Vermissens": "Vermissen",
    "Vermittelnden": "Vermittelnde",
    "Vermittelns": "Vermitteln",
    "Vermittelte": "vermittelt",
    "Vermittelten": "Vermittelte",
    "Vermittlern": "Vermittler",
    "Vermittlers": "Vermittler",
    "Vermittlungen": "Vermittlung",
    "Vermißte": "vermißt",
    "Vermißten": "Vermißte",
    "Vermummenden": "Vermummende",
    "Vermummens": "Vermummen",
    "Vermummte": "vermummt",
    "Vermummten": "Vermummte",
    "Vermummteren": "Vermummtere",
    "Vermummtesten": "Vermummteste",
    "Vermummungen": "Vermummung",
    "Vermurksenden": "Vermurksende",
    "Vermurksenderen": "Vermurksendere",
    "Vermurksendsten": "Vermurksendste",
    "Vermurksens": "Vermurksen",
    "Vermurkste": "vermurkst",
    "Vermurksten": "Vermurkste",
    "Vermurksteren": "Vermurkstere",
    "Vermurkstesten": "Vermurksteste",
    "Vermutenden": "Vermutende",
    "Vermutens": "Vermuten",
    "Vermutete": "vermutet",
    "Vermuteten": "Vermutete",
    "Vermutlichen": "Vermutliche",
    "Vermutungen": "Vermutung",
    "Vermählenden": "Vermählende",
    "Vermählens": "Vermählen",
    "Vermählte": "vermählt",
    "Vermählten": "Vermählte",
    "Vermöbelnden": "Vermöbelnde",
    "Vermöbelns": "Vermöbeln",
    "Vermöbelte": "vermöbelt",
    "Vermöbelten": "Vermöbelte",
    "Vermögenden": "Vermögende",
    "Vermögenderen": "Vermögendere",
    "Vermögendsten": "Vermögendste",
    "Vermögens": "Vermögen",
    "Vermögenswirksame": "vermögenswirksam",
    "Vermögenswirksamen": "Vermögenswirksame",
    "Vernachlässigenden": "Vernachlässigende",
    "Vernachlässigens": "Vernachlässigen",
    "Vernachlässigte": "vernachlässigt",
    "Vernachlässigten": "Vernachlässigte",
    "Vernachlässigteren": "Vernachlässigtere",
    "Vernagelnden": "Vernagelnde",
    "Vernagelns": "Vernageln",
    "Vernagelte": "vernagelt",
    "Vernagelten": "Vernagelte",
    "Vernagelteren": "Vernageltere",
    "Vernageltesten": "Vernagelteste",
    "Vernarbenden": "Vernarbende",
    "Vernarbenderen": "Vernarbendere",
    "Vernarbendsten": "Vernarbendste",
    "Vernarbens": "Vernarben",
    "Vernarbte": "vernarbt",
    "Vernarbten": "Vernarbte",
    "Vernarbteren": "Vernarbtere",
    "Vernarbtesten": "Vernarbteste",
    "Vernarrenden": "Vernarrende",
    "Vernarrenderen": "Vernarrendere",
    "Vernarrendsten": "Vernarrendste",
    "Vernarrens": "Vernarren",
    "Vernarrte": "vernarrt",
    "Vernarrten": "Vernarrte",
    "Vernarrteren": "Vernarrtere",
    "Vernarrtesten": "Vernarrteste",
    "Vernaschenden": "Vernaschende",
    "Vernaschenderen": "Vernaschendere",
    "Vernaschendsten": "Vernaschendste",
    "Vernaschens": "Vernaschen",
    "Vernaschte": "vernascht",
    "Vernaschten": "Vernaschte",
    "Vernaschteren": "Vernaschtere",
    "Vernaschtesten": "Vernaschteste",
    "Vernebelnden": "Vernebelnde",
    "Vernebelnderen": "Vernebelndere",
    "Vernebelndsten": "Vernebelndste",
    "Vernebelns": "Vernebeln",
    "Vernebelte": "vernebelt",
    "Vernebelten": "Vernebelte",
    "Vernebelteren": "Vernebeltere",
    "Vernebeltesten": "Vernebelteste",
    "Vernehmenden": "Vernehmende",
    "Vernehmens": "Vernehmen",
    "Vernehmungen": "Vernehmung",
    "Vernehmungsfähige": "vernehmungsfähig",
    "Vernehmungsfähigen": "Vernehmungsfähige",
    "Verneigenden": "Verneigende",
    "Verneigens": "Verneigen",
    "Verneigte": "verneigt",
    "Verneigten": "Verneigte",
    "Verneigungen": "Verneigung",
    "Verneinenden": "Verneinende",
    "Verneinens": "Verneinen",
    "Verneinte": "verneint",
    "Verneinten": "Verneinte",
    "Vernetzenden": "Vernetzende",
    "Vernetzenderen": "Vernetzendere",
    "Vernetzendsten": "Vernetzendste",
    "Vernetzens": "Vernetzen",
    "Vernetzte": "vernetzt",
    "Vernetzten": "Vernetzte",
    "Vernetzteren": "Vernetztere",
    "Vernetztesten": "Vernetzteste",
    "Vernichtenden": "Vernichtende",
    "Vernichtenderen": "Vernichtendere",
    "Vernichtendsten": "Vernichtendste",
    "Vernichtens": "Vernichten",
    "Vernichtete": "vernichtet",
    "Vernichteten": "Vernichtete",
    "Vernichtungen": "Vernichtung",
    "Verniedliche": "verniedlichen",
    "Verniedlichenden": "Verniedlichende",
    "Verniedlichenderen": "Verniedlichendere",
    "Verniedlichens": "Verniedlichen",
    "Verniedlichte": "verniedlicht",
    "Verniedlichten": "Verniedlichte",
    "Verniedlichteren": "Verniedlichtere",
    "Verniedlichtesten": "Verniedlichteste",
    "Vernietenden": "Vernietende",
    "Vernietens": "Vernieten",
    "Vernietete": "vernietet",
    "Vernieteten": "Vernietete",
    "Vernommenen": "Vernommene",
    "Vernommeneren": "Vernommenere",
    "Vernommensten": "Vernommenste",
    "Vernähenden": "Vernähende",
    "Vernähens": "Vernähen",
    "Vernähte": "vernäht",
    "Vernähten": "Vernähte",
    "Vernünftigen": "Vernünftige",
    "Vernünftigeren": "Vernünftigere",
    "Vernünftigsten": "Vernünftigste",
    "Verordnenden": "Verordnende",
    "Verordnens": "Verordnen",
    "Verordnete": "verordnet",
    "Verordneten": "Verordnete",
    "Verordnungen": "Verordnung",
    "Verpachtenden": "Verpachtende",
    "Verpachtens": "Verpachten",
    "Verpachtete": "verpachtet",
    "Verpachteten": "Verpachtete",
    "Verpackenden": "Verpackende",
    "Verpackens": "Verpacken",
    "Verpackte": "verpackt",
    "Verpackten": "Verpackte",
    "Verpackteren": "Verpacktere",
    "Verpacktesten": "Verpackteste",
    "Verpackungen": "Verpackung",
    "Verpassenden": "Verpassende",
    "Verpassens": "Verpassen",
    "Verpatzenden": "Verpatzende",
    "Verpatzenderen": "Verpatzendere",
    "Verpatzendsten": "Verpatzendste",
    "Verpatzens": "Verpatzen",
    "Verpatzte": "verpatzt",
    "Verpatzten": "Verpatzte",
    "Verpatzteren": "Verpatztere",
    "Verpatztesten": "Verpatzteste",
    "Verpaßte": "verpaßt",
    "Verpaßten": "Verpaßte",
    "Verpennenden": "Verpennende",
    "Verpennens": "Verpennen",
    "Verpennte": "verpennt",
    "Verpennten": "Verpennte",
    "Verpestenden": "Verpestende",
    "Verpestens": "Verpesten",
    "Verpestete": "verpestet",
    "Verpesteten": "Verpestete",
    "Verpetzenden": "Verpetzende",
    "Verpetzenderen": "Verpetzendere",
    "Verpetzendsten": "Verpetzendste",
    "Verpetzens": "Verpetzen",
    "Verpetzte": "verpetzt",
    "Verpetzten": "Verpetzte",
    "Verpfeffernden": "Verpfeffernde",
    "Verpfeffernderen": "Verpfefferndere",
    "Verpfefferndsten": "Verpfefferndste",
    "Verpfefferns": "Verpfeffern",
    "Verpfefferte": "verpfeffert",
    "Verpfefferten": "Verpfefferte",
    "Verpfefferteren": "Verpfeffertere",
    "Verpfeffertesten": "Verpfefferteste",
    "Verpfeifenden": "Verpfeifende",
    "Verpfeifenderen": "Verpfeifendere",
    "Verpfeifendsten": "Verpfeifendste",
    "Verpfeifens": "Verpfeifen",
    "Verpfiffenen": "Verpfiffene",
    "Verpfiffeneren": "Verpfiffenere",
    "Verpfiffensten": "Verpfiffenste",
    "Verpflanzenden": "Verpflanzende",
    "Verpflanzens": "Verpflanzen",
    "Verpflanzte": "verpflanzt",
    "Verpflanzten": "Verpflanzte",
    "Verpflegenden": "Verpflegende",
    "Verpflegens": "Verpflegen",
    "Verpflegte": "verpflegt",
    "Verpflegten": "Verpflegte",
    "Verpflegteren": "Verpflegtere",
    "Verpflegtesten": "Verpflegteste",
    "Verpflegungen": "Verpflegung",
    "Verpflichtenden": "Verpflichtende",
    "Verpflichtens": "Verpflichten",
    "Verpflichtete": "verpflichtet",
    "Verpflichteten": "Verpflichtete",
    "Verpflichtungen": "Verpflichtung",
    "Verpfuschenden": "Verpfuschende",
    "Verpfuschenderen": "Verpfuschendere",
    "Verpfuschendsten": "Verpfuschendste",
    "Verpfuschens": "Verpfuschen",
    "Verpfuschte": "verpfuscht",
    "Verpfuschten": "Verpfuschte",
    "Verpfuschteren": "Verpfuschtere",
    "Verpfuschtesten": "Verpfuschteste",
    "Verpfändenden": "Verpfändende",
    "Verpfändens": "Verpfänden",
    "Verpfändete": "verpfändet",
    "Verpfändeten": "Verpfändete",
    "Verpissenden": "Verpissende",
    "Verpissenderen": "Verpissendere",
    "Verpissendsten": "Verpissendste",
    "Verpissens": "Verpissen",
    "Verpißte": "verpißt",
    "Verpißten": "Verpißte",
    "Verplanenden": "Verplanende",
    "Verplanens": "Verplanen",
    "Verplante": "verplant",
    "Verplanten": "Verplante",
    "Verplanteren": "Verplantere",
    "Verplantesten": "Verplanteste",
    "Verplappernden": "Verplappernde",
    "Verplappernderen": "Verplapperndere",
    "Verplapperndsten": "Verplapperndste",
    "Verplapperns": "Verplappern",
    "Verplapperte": "verplappert",
    "Verplapperten": "Verplapperte",
    "Verplaudernden": "Verplaudernde",
    "Verplaudernderen": "Verplauderndere",
    "Verplauderndsten": "Verplauderndste",
    "Verplauderns": "Verplaudern",
    "Verplauderte": "verplaudert",
    "Verplauderten": "Verplauderte",
    "Verplempernden": "Verplempernde",
    "Verplempernderen": "Verplemperndere",
    "Verplemperndsten": "Verplemperndste",
    "Verplemperns": "Verplempern",
    "Verplemperte": "verplempert",
    "Verplemperten": "Verplemperte",
    "Verplemperteren": "Verplempertere",
    "Verplempertesten": "Verplemperteste",
    "Verplombenden": "Verplombende",
    "Verplombens": "Verplomben",
    "Verplombte": "verplombt",
    "Verplombten": "Verplombte",
    "Verpokernden": "Verpokernde",
    "Verpokernderen": "Verpokerndere",
    "Verpokerndsten": "Verpokerndste",
    "Verpokerns": "Verpokern",
    "Verpokerte": "verpokert",
    "Verpokerten": "Verpokerte",
    "Verprassenden": "Verprassende",
    "Verprassenderen": "Verprassendere",
    "Verprassendsten": "Verprassendste",
    "Verprassens": "Verprassen",
    "Verpraßte": "verpraßt",
    "Verpraßten": "Verpraßte",
    "Verpraßteren": "Verpraßtere",
    "Verpraßtesten": "Verpraßteste",
    "Verprellenden": "Verprellende",
    "Verprellenderen": "Verprellendere",
    "Verprellendsten": "Verprellendste",
    "Verprellens": "Verprellen",
    "Verprellte": "verprellt",
    "Verprellten": "Verprellte",
    "Verprellteren": "Verprelltere",
    "Verprelltesten": "Verprellteste",
    "Verprügelnden": "Verprügelnde",
    "Verprügelns": "Verprügeln",
    "Verprügelte": "verprügelt",
    "Verprügelten": "Verprügelte",
    "Verpuffenden": "Verpuffende",
    "Verpuffenderen": "Verpuffendere",
    "Verpuffendsten": "Verpuffendste",
    "Verpuffens": "Verpuffen",
    "Verpuffte": "verpufft",
    "Verpufften": "Verpuffte",
    "Verpuffteren": "Verpufftere",
    "Verpufftesten": "Verpuffteste",
    "Verpulvernden": "Verpulvernde",
    "Verpulvernderen": "Verpulverndere",
    "Verpulverndsten": "Verpulverndste",
    "Verpulverns": "Verpulvern",
    "Verpulverte": "verpulvert",
    "Verpulverten": "Verpulverte",
    "Verpulverteren": "Verpulvertere",
    "Verpulvertesten": "Verpulverteste",
    "Verpuppenden": "Verpuppende",
    "Verpuppens": "Verpuppen",
    "Verpuppte": "verpuppt",
    "Verpuppten": "Verpuppte",
    "Verputz": "verputzen",
    "Verputzenden": "Verputzende",
    "Verputzenderen": "Verputzendere",
    "Verputzendsten": "Verputzendste",
    "Verputzens": "Verputzen",
    "Verputzs": "Verputz",
    "Verputzte": "verputzt",
    "Verputzten": "Verputzte",
    "Verputzteren": "Verputztere",
    "Verputztesten": "Verputzteste",
    "Verpönenden": "Verpönende",
    "Verpönenderen": "Verpönendere",
    "Verpönendsten": "Verpönendste",
    "Verpönens": "Verpönen",
    "Verpönte": "verpönt",
    "Verpönten": "Verpönte",
    "Verpönteren": "Verpöntere",
    "Verpöntesten": "Verpönteste",
    "Verqualmenden": "Verqualmende",
    "Verqualmenderen": "Verqualmendere",
    "Verqualmendsten": "Verqualmendste",
    "Verqualmens": "Verqualmen",
    "Verqualmte": "verqualmt",
    "Verqualmten": "Verqualmte",
    "Verqualmteren": "Verqualmtere",
    "Verqualmtesten": "Verqualmteste",
    "Verquatschenden": "Verquatschende",
    "Verquatschenderen": "Verquatschendere",
    "Verquatschendsten": "Verquatschendste",
    "Verquatschens": "Verquatschen",
    "Verquatschte": "verquatscht",
    "Verquatschten": "Verquatschte",
    "Verquickungen": "Verquickung",
    "Verquirlenden": "Verquirlende",
    "Verquirlens": "Verquirlen",
    "Verquirlte": "verquirlt",
    "Verquirlten": "Verquirlte",
    "Verquirlteren": "Verquirltere",
    "Verquirltesten": "Verquirlteste",
    "Verrammelnden": "Verrammelnde",
    "Verrammelnderen": "Verrammelndere",
    "Verrammelndsten": "Verrammelndste",
    "Verrammelns": "Verrammeln",
    "Verrammelte": "verrammelt",
    "Verrammelten": "Verrammelte",
    "Verrammelteren": "Verrammeltere",
    "Verrammeltesten": "Verrammelteste",
    "Verramschenden": "Verramschende",
    "Verramschenderen": "Verramschendere",
    "Verramschendsten": "Verramschendste",
    "Verramschens": "Verramschen",
    "Verramschte": "verramscht",
    "Verramschten": "Verramschte",
    "Verramschteren": "Verramschtere",
    "Verramschtesten": "Verramschteste",
    "Verrannte": "verrennen",
    "Verrannten": "verrennen",
    "Verrat": "verraten",
    "Verratenden": "Verratende",
    "Verratenen": "Verratene",
    "Verratens": "Verraten",
    "Verrats": "Verrat",
    "Verrauschenden": "Verrauschende",
    "Verrauschenderen": "Verrauschendere",
    "Verrauschendsten": "Verrauschendste",
    "Verrauschens": "Verrauschen",
    "Verrauschte": "verrauscht",
    "Verrauschten": "Verrauschte",
    "Verrauschteren": "Verrauschtere",
    "Verrauschtesten": "Verrauschteste",
    "Verrechnenden": "Verrechnende",
    "Verrechnens": "Verrechnen",
    "Verrechnete": "verrechnet",
    "Verrechneten": "Verrechnete",
    "Verregnenden": "Verregnende",
    "Verregnens": "Verregnen",
    "Verregnete": "verregnet",
    "Verregneten": "Verregnete",
    "Verregneteren": "Verregnetere",
    "Verregnetesten": "Verregneteste",
    "Verreibenden": "Verreibende",
    "Verreibenderen": "Verreibendere",
    "Verreibendsten": "Verreibendste",
    "Verreibens": "Verreiben",
    "Verreisenden": "Verreisende",
    "Verreisens": "Verreisen",
    "Verreiste": "verreist",
    "Verreisten": "Verreiste",
    "Verreißenden": "Verreißende",
    "Verreißenderen": "Verreißendere",
    "Verreißendsten": "Verreißendste",
    "Verreißens": "Verreißen",
    "Verrenkenden": "Verrenkende",
    "Verrenkenderen": "Verrenkendere",
    "Verrenkendsten": "Verrenkendste",
    "Verrenkens": "Verrenken",
    "Verrenkte": "verrenkt",
    "Verrenkten": "Verrenkte",
    "Verrenkteren": "Verrenktere",
    "Verrenktesten": "Verrenkteste",
    "Verrennenden": "Verrennende",
    "Verrennens": "Verrennen",
    "Verrichtenden": "Verrichtende",
    "Verrichtens": "Verrichten",
    "Verrichtete": "verrichtet",
    "Verrichteten": "Verrichtete",
    "Verrichtungen": "Verrichtung",
    "Verriebenen": "Verriebene",
    "Verriebeneren": "Verriebenere",
    "Verriebensten": "Verriebenste",
    "Verriegelnden": "Verriegelnde",
    "Verriegelns": "Verriegeln",
    "Verriegelte": "verriegelt",
    "Verriegelten": "Verriegelte",
    "Verringernden": "Verringernde",
    "Verringerns": "Verringern",
    "Verringerte": "verringert",
    "Verringerten": "Verringerte",
    "Verringerungen": "Verringerung",
    "Verrinnenden": "Verrinnende",
    "Verrinnens": "Verrinnen",
    "Verrissenen": "Verrissene",
    "Verrisseneren": "Verrissenere",
    "Verrissensten": "Verrissenste",
    "Verronnenen": "Verronnene",
    "Verrostenden": "Verrostende",
    "Verrostenderen": "Verrostendere",
    "Verrostendsten": "Verrostendste",
    "Verrostens": "Verrosten",
    "Verrostete": "verrostet",
    "Verrosteten": "Verrostete",
    "Verrosteteren": "Verrostetere",
    "Verrostetesten": "Verrosteteste",
    "Verrufs": "Verruf",
    "Verrutschenden": "Verrutschende",
    "Verrutschenderen": "Verrutschendere",
    "Verrutschendsten": "Verrutschendste",
    "Verrutschens": "Verrutschen",
    "Verrutschte": "verrutscht",
    "Verrutschten": "Verrutschte",
    "Verrutschteren": "Verrutschtere",
    "Verrutschtesten": "Verrutschteste",
    "Verräterische": "verräterisch",
    "Verräterischen": "Verräterische",
    "Verräterischeren": "Verräterischere",
    "Verräterischsten": "Verräterischste",
    "Verräuchernden": "Verräuchernde",
    "Verräuchernderen": "Verräucherndere",
    "Verräucherndsten": "Verräucherndste",
    "Verräucherns": "Verräuchern",
    "Verräucherte": "verräuchert",
    "Verräucherten": "Verräucherte",
    "Verräucherteren": "Verräuchertere",
    "Verräuchertesten": "Verräucherteste",
    "Verrückenden": "Verrückende",
    "Verrückens": "Verrücken",
    "Verrückte": "verrückt",
    "Verrückten": "Verrückte",
    "Verrückteren": "Verrücktere",
    "Verrücktesten": "Verrückteste",
    "Verrücktheiten": "Verrücktheit",
    "Verrührenden": "Verrührende",
    "Verrührens": "Verrühren",
    "Verrührte": "verrührt",
    "Verrührten": "Verrührte",
    "Versachlichenden": "Versachlichende",
    "Versachlichens": "Versachlichen",
    "Versachlichte": "versachlicht",
    "Versachlichten": "Versachlichte",
    "Versagenden": "Versagende",
    "Versagens": "Versagen",
    "Versagte": "versagt",
    "Versagten": "Versagte",
    "Versalzenden": "Versalzende",
    "Versalzenderen": "Versalzendere",
    "Versalzendsten": "Versalzendste",
    "Versalzenen": "Versalzene",
    "Versalzeneren": "Versalzenere",
    "Versalzens": "Versalzen",
    "Versalzenste": "versalzen",
    "Versalzensten": "Versalzenste",
    "Versammelnden": "Versammelnde",
    "Versammelns": "Versammeln",
    "Versammelte": "versammelt",
    "Versammelten": "Versammelte",
    "Versammlungen": "Versammlung",
    "Versandenden": "Versandende",
    "Versandens": "Versanden",
    "Versandete": "versandet",
    "Versandeten": "Versandete",
    "Versandfertigen": "Versandfertige",
    "Versands": "Versand",
    "Versandte": "versenden",
    "Versandten": "versenden",
    "Versauenden": "Versauende",
    "Versauenderen": "Versauendere",
    "Versauendsten": "Versauendste",
    "Versauens": "Versauen",
    "Versauernden": "Versauernde",
    "Versauernderen": "Versauerndere",
    "Versauerndsten": "Versauerndste",
    "Versauerns": "Versauern",
    "Versauerte": "versauert",
    "Versauerten": "Versauerte",
    "Versauerteren": "Versauertere",
    "Versauertesten": "Versauerteste",
    "Versaufenden": "Versaufende",
    "Versaufenderen": "Versaufendere",
    "Versaufendsten": "Versaufendste",
    "Versaufens": "Versaufen",
    "Versaute": "versaut",
    "Versauten": "Versaute",
    "Versauteren": "Versautere",
    "Versautesten": "Versauteste",
    "Verschachernden": "Verschachernde",
    "Verschacherns": "Verschachern",
    "Verschacherte": "verschachert",
    "Verschacherten": "Verschacherte",
    "Verschachtel": "verschachteln",
    "Verschachtelnden": "Verschachtelnde",
    "Verschachtelnderen": "Verschachtelndere",
    "Verschachtelns": "Verschachteln",
    "Verschachtelte": "verschachtelt",
    "Verschachtelten": "Verschachtelte",
    "Verschachtelteren": "Verschachteltere",
    "Verschachtelteste": "verschachtelt",
    "Verschaffenden": "Verschaffende",
    "Verschaffens": "Verschaffen",
    "Verschaffte": "verschafft",
    "Verschafften": "Verschaffte",
    "Verschalenden": "Verschalende",
    "Verschalens": "Verschalen",
    "Verschalte": "verschalt",
    "Verschalten": "Verschalte",
    "Verschaltenden": "Verschaltende",
    "Verschaltens": "Verschalten",
    "Verschaltete": "verschaltet",
    "Verschalteten": "Verschaltete",
    "Verschalungen": "Verschalung",
    "Verschandelnden": "Verschandelnde",
    "Verschandelnderen": "Verschandelndere",
    "Verschandelndsten": "Verschandelndste",
    "Verschandelns": "Verschandeln",
    "Verschandelte": "verschandelt",
    "Verschandelten": "Verschandelte",
    "Verschandelteren": "Verschandeltere",
    "Verschandeltesten": "Verschandelteste",
    "Verschanzenden": "Verschanzende",
    "Verschanzenderen": "Verschanzendere",
    "Verschanzendsten": "Verschanzendste",
    "Verschanzens": "Verschanzen",
    "Verschanzte": "verschanzt",
    "Verschanzten": "Verschanzte",
    "Verschanzteren": "Verschanztere",
    "Verschanztesten": "Verschanzteste",
    "Verscharrenden": "Verscharrende",
    "Verscharrens": "Verscharren",
    "Verscharrte": "verscharrt",
    "Verscharrten": "Verscharrte",
    "Verschaukelnden": "Verschaukelnde",
    "Verschaukelnderen": "Verschaukelndere",
    "Verschaukelndsten": "Verschaukelndste",
    "Verschaukelns": "Verschaukeln",
    "Verschaukelte": "verschaukelt",
    "Verschaukelten": "Verschaukelte",
    "Verschaukelteren": "Verschaukeltere",
    "Verschaukeltesten": "Verschaukelteste",
    "Verscheidenden": "Verscheidende",
    "Verscheidens": "Verscheiden",
    "Verscheißernden": "Verscheißernde",
    "Verscheißernderen": "Verscheißerndere",
    "Verscheißerndsten": "Verscheißerndste",
    "Verscheißerns": "Verscheißern",
    "Verscheißerte": "verscheißert",
    "Verscheißerten": "Verscheißerte",
    "Verscheißerteren": "Verscheißertere",
    "Verscheißertesten": "Verscheißerteste",
    "Verschenkenden": "Verschenkende",
    "Verschenkens": "Verschenken",
    "Verschenkte": "verschenkt",
    "Verschenkten": "Verschenkte",
    "Verscherbelnden": "Verscherbelnde",
    "Verscherbelns": "Verscherbeln",
    "Verscherbelte": "verscherbelt",
    "Verscherbelten": "Verscherbelte",
    "Verscherzenden": "Verscherzende",
    "Verscherzenderen": "Verscherzendere",
    "Verscherzendsten": "Verscherzendste",
    "Verscherzens": "Verscherzen",
    "Verscherzte": "verscherzt",
    "Verscherzten": "Verscherzte",
    "Verscheuchenden": "Verscheuchende",
    "Verscheuchenderen": "Verscheuchendere",
    "Verscheuchendsten": "Verscheuchendste",
    "Verscheuchens": "Verscheuchen",
    "Verscheuchte": "verscheucht",
    "Verscheuchten": "Verscheuchte",
    "Verscheuernden": "Verscheuernde",
    "Verscheuernderen": "Verscheuerndere",
    "Verscheuerndsten": "Verscheuerndste",
    "Verscheuerns": "Verscheuern",
    "Verscheuerte": "verscheuert",
    "Verscheuerten": "Verscheuerte",
    "Verschickenden": "Verschickende",
    "Verschickens": "Verschicken",
    "Verschickte": "verschickt",
    "Verschickten": "Verschickte",
    "Verschiebenden": "Verschiebende",
    "Verschiebenderen": "Verschiebendere",
    "Verschiebendsten": "Verschiebendste",
    "Verschiebens": "Verschieben",
    "Verschiebungen": "Verschiebung",
    "Verschiedenartigen": "Verschiedenartige",
    "Verschiedenartigeren": "Verschiedenartigere",
    "Verschiedenen": "Verschiedene",
    "Verschiedeneren": "Verschiedenere",
    "Verschiedenheiten": "Verschiedenheit",
    "Verschiedenste": "verschieden",
    "Verschiedensten": "Verschiedenste",
    "Verschießenden": "Verschießende",
    "Verschießens": "Verschießen",
    "Verschiffenden": "Verschiffende",
    "Verschiffenderen": "Verschiffendere",
    "Verschiffendsten": "Verschiffendste",
    "Verschiffens": "Verschiffen",
    "Verschiffte": "verschifft",
    "Verschifften": "Verschiffte",
    "Verschiffungen": "Verschiffung",
    "Verschimmelnden": "Verschimmelnde",
    "Verschimmelnderen": "Verschimmelndere",
    "Verschimmelndsten": "Verschimmelndste",
    "Verschimmelns": "Verschimmeln",
    "Verschimmelte": "verschimmelt",
    "Verschimmelten": "Verschimmelte",
    "Verschimmelteren": "Verschimmeltere",
    "Verschimmeltesten": "Verschimmelteste",
    "Verschlafenden": "Verschlafende",
    "Verschlafenen": "Verschlafene",
    "Verschlafeneren": "Verschlafenere",
    "Verschlafens": "Verschlafen",
    "Verschlafenste": "verschlafen",
    "Verschlafensten": "Verschlafenste",
    "Verschlag": "verschlagen",
    "Verschlage": "verschlagen",
    "Verschlagenden": "Verschlagende",
    "Verschlagenen": "Verschlagene",
    "Verschlageneren": "Verschlagenere",
    "Verschlagens": "Verschlagen",
    "Verschlagenste": "verschlagen",
    "Verschlagensten": "Verschlagenste",
    "Verschlags": "Verschlag",
    "Verschlammenden": "Verschlammende",
    "Verschlammens": "Verschlammen",
    "Verschlammte": "verschlammt",
    "Verschlammten": "Verschlammte",
    "Verschlampenden": "Verschlampende",
    "Verschlampenderen": "Verschlampendere",
    "Verschlampendsten": "Verschlampendste",
    "Verschlampens": "Verschlampen",
    "Verschlampte": "verschlampt",
    "Verschlampten": "Verschlampte",
    "Verschlampteren": "Verschlamptere",
    "Verschlamptesten": "Verschlampteste",
    "Verschlechternden": "Verschlechternde",
    "Verschlechterns": "Verschlechtern",
    "Verschlechterte": "verschlechtert",
    "Verschlechterten": "Verschlechterte",
    "Verschleiernden": "Verschleiernde",
    "Verschleiernderen": "Verschleierndere",
    "Verschleierndsten": "Verschleierndste",
    "Verschleierns": "Verschleiern",
    "Verschleierte": "verschleiert",
    "Verschleierten": "Verschleierte",
    "Verschleierteren": "Verschleiertere",
    "Verschleiertesten": "Verschleierteste",
    "Verschleimenden": "Verschleimende",
    "Verschleimenderen": "Verschleimendere",
    "Verschleimendsten": "Verschleimendste",
    "Verschleimens": "Verschleimen",
    "Verschleimte": "verschleimt",
    "Verschleimten": "Verschleimte",
    "Verschleimteren": "Verschleimtere",
    "Verschleimtesten": "Verschleimteste",
    "Verschleißenden": "Verschleißende",
    "Verschleißens": "Verschleißen",
    "Verschleppenden": "Verschleppende",
    "Verschleppens": "Verschleppen",
    "Verschleppte": "verschleppt",
    "Verschleppten": "Verschleppte",
    "Verschleudernden": "Verschleudernde",
    "Verschleuderns": "Verschleudern",
    "Verschleuderte": "verschleudert",
    "Verschleuderten": "Verschleuderte",
    "Verschleuderteren": "Verschleudertere",
    "Verschleuderteste": "verschleudert",
    "Verschließenden": "Verschließende",
    "Verschließens": "Verschließen",
    "Verschlimmbessernden": "Verschlimmbessernde",
    "Verschlimmbesserns": "Verschlimmbessern",
    "Verschlimmbesserte": "verschlimmbessert",
    "Verschlimmbesserten": "Verschlimmbesserte",
    "Verschlimmbesserungen": "Verschlimmbesserung",
    "Verschlimmernden": "Verschlimmernde",
    "Verschlimmerns": "Verschlimmern",
    "Verschlimmerte": "verschlimmert",
    "Verschlimmerten": "Verschlimmerte",
    "Verschlimmerungen": "Verschlimmerung",
    "Verschlingenden": "Verschlingende",
    "Verschlingenderen": "Verschlingendere",
    "Verschlingendsten": "Verschlingendste",
    "Verschlingens": "Verschlingen",
    "Verschlissenen": "Verschlissene",
    "Verschlisseneren": "Verschlissenere",
    "Verschlissensten": "Verschlissenste",
    "Verschlossenen": "Verschlossene",
    "Verschlosseneren": "Verschlossenere",
    "Verschlossensten": "Verschlossenste",
    "Verschluckenden": "Verschluckende",
    "Verschluckens": "Verschlucken",
    "Verschluckte": "verschluckt",
    "Verschluckten": "Verschluckte",
    "Verschludernden": "Verschludernde",
    "Verschluderns": "Verschludern",
    "Verschluderte": "verschludert",
    "Verschluderten": "Verschluderte",
    "Verschlungenen": "Verschlungene",
    "Verschlungeneren": "Verschlungenere",
    "Verschlungensten": "Verschlungenste",
    "Verschlusse": "Verschluß",
    "Verschlusses": "Verschluß",
    "Verschläge": "Verschlag",
    "Verschlägen": "Verschlag",
    "Verschlüsse": "Verschluß",
    "Verschlüsselnden": "Verschlüsselnde",
    "Verschlüsselns": "Verschlüsseln",
    "Verschlüsselte": "verschlüsselt",
    "Verschlüsselten": "Verschlüsselte",
    "Verschlüssen": "Verschluß",
    "Verschmelzenden": "Verschmelzende",
    "Verschmelzenderen": "Verschmelzendere",
    "Verschmelzendsten": "Verschmelzendste",
    "Verschmelzens": "Verschmelzen",
    "Verschmelzungen": "Verschmelzung",
    "Verschmerzenden": "Verschmerzende",
    "Verschmerzens": "Verschmerzen",
    "Verschmerzte": "verschmerzt",
    "Verschmerzten": "Verschmerzte",
    "Verschmierenden": "Verschmierende",
    "Verschmierenderen": "Verschmierendere",
    "Verschmierendsten": "Verschmierendste",
    "Verschmierens": "Verschmieren",
    "Verschmierte": "verschmiert",
    "Verschmierten": "Verschmierte",
    "Verschmierteren": "Verschmiertere",
    "Verschmiertesten": "Verschmierteste",
    "Verschmolzenen": "Verschmolzene",
    "Verschmolzeneren": "Verschmolzenere",
    "Verschmolzensten": "Verschmolzenste",
    "Verschmutzenden": "Verschmutzende",
    "Verschmutzenderen": "Verschmutzendere",
    "Verschmutzendsten": "Verschmutzendste",
    "Verschmutzens": "Verschmutzen",
    "Verschmutzte": "verschmutzt",
    "Verschmutzten": "Verschmutzte",
    "Verschmutzteren": "Verschmutztere",
    "Verschmutztesten": "Verschmutzteste",
    "Verschmutzungen": "Verschmutzung",
    "Verschmähenden": "Verschmähende",
    "Verschmähenderen": "Verschmähendere",
    "Verschmähendsten": "Verschmähendste",
    "Verschmähens": "Verschmähen",
    "Verschmähte": "verschmäht",
    "Verschmähten": "Verschmähte",
    "Verschmähteren": "Verschmähtere",
    "Verschmähtesten": "Verschmähteste",
    "Verschnaufenden": "Verschnaufende",
    "Verschnaufenderen": "Verschnaufendere",
    "Verschnaufendsten": "Verschnaufendste",
    "Verschnaufens": "Verschnaufen",
    "Verschnaufte": "verschnauft",
    "Verschnauften": "Verschnaufte",
    "Verschneidenden": "Verschneidende",
    "Verschneidenderen": "Verschneidendere",
    "Verschneidendsten": "Verschneidendste",
    "Verschneidens": "Verschneiden",
    "Verschneienden": "Verschneiende",
    "Verschneiens": "Verschneien",
    "Verschneite": "verschneit",
    "Verschneiten": "Verschneite",
    "Verschneiteren": "Verschneitere",
    "Verschneitesten": "Verschneiteste",
    "Verschnittenen": "Verschnittene",
    "Verschnitteneren": "Verschnittenere",
    "Verschnittensten": "Verschnittenste",
    "Verschnupfenden": "Verschnupfende",
    "Verschnupfenderen": "Verschnupfendere",
    "Verschnupfendsten": "Verschnupfendste",
    "Verschnupfens": "Verschnupfen",
    "Verschnupfte": "verschnupft",
    "Verschnupften": "Verschnupfte",
    "Verschnupfteren": "Verschnupftere",
    "Verschnupftesten": "Verschnupfteste",
    "Verschnörkel": "verschnörkeln",
    "Verschnörkelnden": "Verschnörkelnde",
    "Verschnörkelnderen": "Verschnörkelndere",
    "Verschnörkelns": "Verschnörkeln",
    "Verschnörkelte": "verschnörkelt",
    "Verschnörkelten": "Verschnörkelte",
    "Verschnörkelteren": "Verschnörkeltere",
    "Verschnörkelteste": "verschnörkelt",
    "Verschnürenden": "Verschnürende",
    "Verschnürens": "Verschnüren",
    "Verschnürte": "verschnürt",
    "Verschnürten": "Verschnürte",
    "Verschobenen": "Verschobene",
    "Verschollenen": "Verschollene",
    "Verschonenden": "Verschonende",
    "Verschonens": "Verschonen",
    "Verschonte": "verschont",
    "Verschonten": "Verschonte",
    "Verschossenen": "Verschossene",
    "Verschosseneren": "Verschossenere",
    "Verschossensten": "Verschossenste",
    "Verschrammenden": "Verschrammende",
    "Verschrammenderen": "Verschrammendere",
    "Verschrammendsten": "Verschrammendste",
    "Verschrammens": "Verschrammen",
    "Verschrammte": "verschrammt",
    "Verschrammten": "Verschrammte",
    "Verschrammteren": "Verschrammtere",
    "Verschrammtesten": "Verschrammteste",
    "Verschraubenden": "Verschraubende",
    "Verschraubens": "Verschrauben",
    "Verschraubte": "verschraubt",
    "Verschraubten": "Verschraubte",
    "Verschraubungen": "Verschraubung",
    "Verschreckenden": "Verschreckende",
    "Verschreckenderen": "Verschreckendere",
    "Verschreckendsten": "Verschreckendste",
    "Verschreckens": "Verschrecken",
    "Verschreckte": "verschreckt",
    "Verschreckten": "Verschreckte",
    "Verschreckteren": "Verschrecktere",
    "Verschrecktesten": "Verschreckteste",
    "Verschreibenden": "Verschreibende",
    "Verschreibens": "Verschreiben",
    "Verschreibungen": "Verschreibung",
    "Verschreienden": "Verschreiende",
    "Verschreiens": "Verschreien",
    "Verschriebenen": "Verschriebene",
    "Verschriebeneren": "Verschriebenere",
    "Verschriebensten": "Verschriebenste",
    "Verschrienen": "Verschriene",
    "Verschrieneren": "Verschrienere",
    "Verschriensten": "Verschrienste",
    "Verschrottenden": "Verschrottende",
    "Verschrottens": "Verschrotten",
    "Verschrottete": "verschrottet",
    "Verschrotteten": "Verschrottete",
    "Verschrumpel": "verschrumpeln",
    "Verschrumpelnden": "Verschrumpelnde",
    "Verschrumpelnderen": "Verschrumpelndere",
    "Verschrumpelns": "Verschrumpeln",
    "Verschrumpelte": "verschrumpelt",
    "Verschrumpelten": "Verschrumpelte",
    "Verschrumpelteren": "Verschrumpeltere",
    "Verschrumpelteste": "verschrumpelt",
    "Verschränkenden": "Verschränkende",
    "Verschränkens": "Verschränken",
    "Verschränkte": "verschränkt",
    "Verschränkten": "Verschränkte",
    "Verschränkungen": "Verschränkung",
    "Verschuldenden": "Verschuldende",
    "Verschuldenderen": "Verschuldendere",
    "Verschuldendsten": "Verschuldendste",
    "Verschuldens": "Verschulden",
    "Verschuldete": "verschuldet",
    "Verschuldeten": "Verschuldete",
    "Verschuldeteren": "Verschuldetere",
    "Verschuldetesten": "Verschuldeteste",
    "Verschuldungen": "Verschuldung",
    "Verschwatzenden": "Verschwatzende",
    "Verschwatzenderen": "Verschwatzendere",
    "Verschwatzendsten": "Verschwatzendste",
    "Verschwatzens": "Verschwatzen",
    "Verschwatzte": "verschwatzt",
    "Verschwatzten": "Verschwatzte",
    "Verschwatzteren": "Verschwatztere",
    "Verschwatztesten": "Verschwatzteste",
    "Verschweigenden": "Verschweigende",
    "Verschweigenderen": "Verschweigendere",
    "Verschweigendsten": "Verschweigendste",
    "Verschweigens": "Verschweigen",
    "Verschweißenden": "Verschweißende",
    "Verschweißens": "Verschweißen",
    "Verschweißte": "verschweißt",
    "Verschweißten": "Verschweißte",
    "Verschwendenden": "Verschwendende",
    "Verschwendenderen": "Verschwendendere",
    "Verschwendendsten": "Verschwendendste",
    "Verschwendens": "Verschwenden",
    "Verschwenderische": "verschwenderisch",
    "Verschwenderischen": "Verschwenderische",
    "Verschwenderischeren": "Verschwenderischere",
    "Verschwendern": "Verschwender",
    "Verschwenders": "Verschwender",
    "Verschwendete": "verschwendet",
    "Verschwendeten": "Verschwendete",
    "Verschwendeteren": "Verschwendetere",
    "Verschwendetesten": "Verschwendeteste",
    "Verschwiegenen": "Verschwiegene",
    "Verschwiegeneren": "Verschwiegenere",
    "Verschwiegensten": "Verschwiegenste",
    "Verschwimmenden": "Verschwimmende",
    "Verschwimmenderen": "Verschwimmendere",
    "Verschwimmendsten": "Verschwimmendste",
    "Verschwimmens": "Verschwimmen",
    "Verschwindenden": "Verschwindende",
    "Verschwindens": "Verschwinden",
    "Verschwitzenden": "Verschwitzende",
    "Verschwitzenderen": "Verschwitzendere",
    "Verschwitzendsten": "Verschwitzendste",
    "Verschwitzens": "Verschwitzen",
    "Verschwitzte": "verschwitzt",
    "Verschwitzten": "Verschwitzte",
    "Verschwitzteren": "Verschwitztere",
    "Verschwitztesten": "Verschwitzteste",
    "Verschwommenen": "Verschwommene",
    "Verschwommeneren": "Verschwommenere",
    "Verschwommensten": "Verschwommenste",
    "Verschworenen": "Verschworene",
    "Verschworeneren": "Verschworenere",
    "Verschworenste": "verschworen",
    "Verschworensten": "Verschworenste",
    "Verschwundenen": "Verschwundene",
    "Verschwägernden": "Verschwägernde",
    "Verschwägerns": "Verschwägern",
    "Verschwägerte": "verschwägert",
    "Verschwägerten": "Verschwägerte",
    "Verschwörenden": "Verschwörende",
    "Verschwörens": "Verschwören",
    "Verschwörern": "Verschwörer",
    "Verschwörers": "Verschwörer",
    "Verschwörungen": "Verschwörung",
    "Verschärfenden": "Verschärfende",
    "Verschärfens": "Verschärfen",
    "Verschärfte": "verschärft",
    "Verschärften": "Verschärfte",
    "Verschärfteren": "Verschärftere",
    "Verschärftesten": "Verschärfteste",
    "Verschärfungen": "Verschärfung",
    "Verschätzenden": "Verschätzende",
    "Verschätzens": "Verschätzen",
    "Verschätzte": "verschätzt",
    "Verschätzten": "Verschätzte",
    "Verschönernden": "Verschönernde",
    "Verschönerns": "Verschönern",
    "Verschönerte": "verschönert",
    "Verschönerten": "Verschönerte",
    "Verschönerteren": "Verschönertere",
    "Verschönertesten": "Verschönerteste",
    "Verschüchter": "verschüchtern",
    "Verschüchternden": "Verschüchternde",
    "Verschüchternderen": "Verschüchterndere",
    "Verschüchterns": "Verschüchtern",
    "Verschüchterte": "verschüchtert",
    "Verschüchterten": "Verschüchterte",
    "Verschüchterteren": "Verschüchtertere",
    "Verschüchterteste": "verschüchtert",
    "Verschüttenden": "Verschüttende",
    "Verschüttens": "Verschütten",
    "Verschüttete": "verschüttet",
    "Verschütteten": "Verschüttete",
    "Verschütteteren": "Verschüttetere",
    "Verschüttetesten": "Verschütteteste",
    "Verschüttgegangenen": "Verschüttgegangene",
    "Verschüttgehenden": "Verschüttgehende",
    "Verschüttgehens": "Verschüttgehen",
    "Verschüttungen": "Verschüttung",
    "Verse": "Vers",
    "Versegelnden": "Versegelnde",
    "Versegelns": "Versegeln",
    "Versegelte": "versegelt",
    "Versegelten": "Versegelte",
    "Versehenden": "Versehende",
    "Versehenen": "Versehene",
    "Versehens": "Versehen",
    "Versehrenden": "Versehrende",
    "Versehrens": "Versehren",
    "Versehrte": "versehrt",
    "Versehrten": "Versehrte",
    "Verselbständigenden": "Verselbständigende",
    "Verselbständigenderen": "Verselbständigendere",
    "Verselbständigens": "Verselbständigen",
    "Verselbständigte": "verselbständigt",
    "Verselbständigten": "Verselbständigte",
    "Verselbständigteren": "Verselbständigtere",
    "Versen": "Vers",
    "Versendenden": "Versendende",
    "Versendens": "Versenden",
    "Versendete": "versendet",
    "Versendeten": "Versendete",
    "Versendungen": "Versendung",
    "Versenkenden": "Versenkende",
    "Versenkens": "Versenken",
    "Versenkte": "versenkt",
    "Versenkten": "Versenkte",
    "Versenkungen": "Versenkung",
    "Verses": "Vers",
    "Versessene": "versessen",
    "Versessenen": "Versessene",
    "Versesseneren": "Versessenere",
    "Versessensten": "Versessenste",
    "Versetzenden": "Versetzende",
    "Versetzens": "Versetzen",
    "Versetzte": "versetzt",
    "Versetzten": "Versetzte",
    "Versetzungen": "Versetzung",
    "Verseuchenden": "Verseuchende",
    "Verseuchenderen": "Verseuchendere",
    "Verseuchendsten": "Verseuchendste",
    "Verseuchens": "Verseuchen",
    "Verseuchte": "verseucht",
    "Verseuchten": "Verseuchte",
    "Verseuchteren": "Verseuchtere",
    "Verseuchtesten": "Verseuchteste",
    "Verseuchungen": "Verseuchung",
    "Versichernden": "Versichernde",
    "Versicherns": "Versichern",
    "Versicherte": "versichert",
    "Versicherten": "Versicherte",
    "Versicherungen": "Versicherung",
    "Versiebenden": "Versiebende",
    "Versiebens": "Versieben",
    "Versiebte": "versiebt",
    "Versiebten": "Versiebte",
    "Versiechenden": "Versiechende",
    "Versiechenderen": "Versiechendere",
    "Versiechendsten": "Versiechendste",
    "Versiechens": "Versiechen",
    "Versiechte": "versiecht",
    "Versiechten": "Versiechte",
    "Versiegelnden": "Versiegelnde",
    "Versiegelns": "Versiegeln",
    "Versiegelte": "versiegelt",
    "Versiegelten": "Versiegelte",
    "Versiegenden": "Versiegende",
    "Versiegens": "Versiegen",
    "Versiegte": "versiegt",
    "Versiegten": "Versiegte",
    "Versiegteren": "Versiegtere",
    "Versiegtesten": "Versiegteste",
    "Versifften": "Versiffte",
    "Versiffteren": "Versifftere",
    "Versifftesten": "Versiffteste",
    "Versilbernden": "Versilbernde",
    "Versilberns": "Versilbern",
    "Versilberte": "versilbert",
    "Versilberten": "Versilberte",
    "Versilberungen": "Versilberung",
    "Versinkenden": "Versinkende",
    "Versinkenderen": "Versinkendere",
    "Versinkendsten": "Versinkendste",
    "Versinkens": "Versinken",
    "Versionen": "Version",
    "Versittlichenden": "Versittlichende",
    "Versittlichens": "Versittlichen",
    "Versittlichte": "versittlicht",
    "Versittlichten": "Versittlichte",
    "Versittlichteren": "Versittlichtere",
    "Versittlichtesten": "Versittlichteste",
    "Versklavenden": "Versklavende",
    "Versklavens": "Versklaven",
    "Versklavte": "versklavt",
    "Versklavten": "Versklavte",
    "Versklavungen": "Versklavung",
    "Versoffenen": "Versoffene",
    "Versoffeneren": "Versoffenere",
    "Versoffensten": "Versoffenste",
    "Versohlenden": "Versohlende",
    "Versohlens": "Versohlen",
    "Versohlte": "versohlt",
    "Versohlten": "Versohlte",
    "Versorgenden": "Versorgende",
    "Versorgens": "Versorgen",
    "Versorgte": "versorgt",
    "Versorgten": "Versorgte",
    "Verspachtelnden": "Verspachtelnde",
    "Verspachtelns": "Verspachteln",
    "Verspachtelte": "verspachtelt",
    "Verspachtelten": "Verspachtelte",
    "Verspannenden": "Verspannende",
    "Verspannens": "Verspannen",
    "Verspannte": "verspannt",
    "Verspannten": "Verspannte",
    "Verspannteren": "Verspanntere",
    "Verspanntesten": "Verspannteste",
    "Verspeisenden": "Verspeisende",
    "Verspeisens": "Verspeisen",
    "Verspeiste": "verspeist",
    "Verspeisten": "Verspeiste",
    "Verspekulierenden": "Verspekulierende",
    "Verspekulierens": "Verspekulieren",
    "Verspekulierte": "verspekuliert",
    "Verspekulierten": "Verspekulierte",
    "Versperrenden": "Versperrende",
    "Versperrenderen": "Versperrendere",
    "Versperrendsten": "Versperrendste",
    "Versperrens": "Versperren",
    "Versperrte": "versperrt",
    "Versperrten": "Versperrte",
    "Versperrteren": "Versperrtere",
    "Versperrtesten": "Versperrteste",
    "Verspielenden": "Verspielende",
    "Verspielens": "Verspielen",
    "Verspielte": "verspielt",
    "Verspielten": "Verspielte",
    "Verspielteren": "Verspieltere",
    "Verspieltesten": "Verspielteste",
    "Verspottenden": "Verspottende",
    "Verspottenderen": "Verspottendere",
    "Verspottendsten": "Verspottendste",
    "Verspottens": "Verspotten",
    "Verspottete": "verspottet",
    "Verspotteten": "Verspottete",
    "Verspotteteren": "Verspottetere",
    "Verspottetesten": "Verspotteteste",
    "Versprechenden": "Versprechende",
    "Versprechenderen": "Versprechendere",
    "Versprechendsten": "Versprechendste",
    "Versprechens": "Versprechen",
    "Versprechern": "Versprecher",
    "Versprechers": "Versprecher",
    "Versprechungen": "Versprechung",
    "Verspringenden": "Verspringende",
    "Verspringenderen": "Verspringendere",
    "Verspringendsten": "Verspringendste",
    "Verspringens": "Verspringen",
    "Verspritzenden": "Verspritzende",
    "Verspritzenderen": "Verspritzendere",
    "Verspritzendsten": "Verspritzendste",
    "Verspritzens": "Verspritzen",
    "Verspritzte": "verspritzt",
    "Verspritzten": "Verspritzte",
    "Verspritzteren": "Verspritztere",
    "Verspritztesten": "Verspritzteste",
    "Versprochenen": "Versprochene",
    "Versprocheneren": "Versprochenere",
    "Versprochensten": "Versprochenste",
    "Versprungenen": "Versprungene",
    "Versprungeneren": "Versprungenere",
    "Versprungensten": "Versprungenste",
    "Versprühenden": "Versprühende",
    "Versprühens": "Versprühen",
    "Versprühte": "versprüht",
    "Versprühten": "Versprühte",
    "Verspätenden": "Verspätende",
    "Verspätens": "Verspäten",
    "Verspätete": "verspätet",
    "Verspäteten": "Verspätete",
    "Verspäteteren": "Verspätetere",
    "Verspätetesten": "Verspäteteste",
    "Verspätungen": "Verspätung",
    "Verspürenden": "Verspürende",
    "Verspürens": "Verspüren",
    "Verspürte": "verspürt",
    "Verspürten": "Verspürte",
    "Verstaatlichenden": "Verstaatlichende",
    "Verstaatlichenderen": "Verstaatlichendere",
    "Verstaatlichens": "Verstaatlichen",
    "Verstaatlichte": "verstaatlicht",
    "Verstaatlichten": "Verstaatlichte",
    "Verstaatlichteren": "Verstaatlichtere",
    "Verstaatlichteste": "verstaatlicht",
    "Verstandenen": "Verstandene",
    "Verstandeneren": "Verstandenere",
    "Verstandensten": "Verstandenste",
    "Verstands": "Verstand",
    "Verstaubenden": "Verstaubende",
    "Verstaubenderen": "Verstaubendere",
    "Verstaubendsten": "Verstaubendste",
    "Verstaubens": "Verstauben",
    "Verstaubte": "verstaubt",
    "Verstaubten": "Verstaubte",
    "Verstaubteren": "Verstaubtere",
    "Verstaubtesten": "Verstaubteste",
    "Verstauchenden": "Verstauchende",
    "Verstauchenderen": "Verstauchendere",
    "Verstauchendsten": "Verstauchendste",
    "Verstauchens": "Verstauchen",
    "Verstauchte": "verstaucht",
    "Verstauchten": "Verstauchte",
    "Verstauchteren": "Verstauchtere",
    "Verstauchtesten": "Verstauchteste",
    "Verstauchungen": "Verstauchung",
    "Verstauenden": "Verstauende",
    "Verstauens": "Verstauen",
    "Verstaute": "verstaut",
    "Verstauten": "Verstaute",
    "Versteck": "verstecken",
    "Verstecke": "verstecken",
    "Verstecken": "Versteck",
    "Versteckenden": "Versteckende",
    "Versteckens": "Verstecken",
    "Versteckes": "Versteck",
    "Verstecks": "Versteck",
    "Versteckte": "versteckt",
    "Versteckten": "Versteckte",
    "Versteckteren": "Verstecktere",
    "Verstecktesten": "Versteckteste",
    "Verstehbaren": "Verstehbare",
    "Verstehbareren": "Verstehbarere",
    "Verstehbarsten": "Verstehbarste",
    "Verstehenden": "Verstehende",
    "Verstehenderen": "Verstehendere",
    "Verstehendsten": "Verstehendste",
    "Verstehens": "Verstehen",
    "Versteifenden": "Versteifende",
    "Versteifens": "Versteifen",
    "Versteifte": "versteift",
    "Versteiften": "Versteifte",
    "Versteifungen": "Versteifung",
    "Versteigernden": "Versteigernde",
    "Versteigerns": "Versteigern",
    "Versteigerte": "versteigert",
    "Versteigerten": "Versteigerte",
    "Versteigerungen": "Versteigerung",
    "Versteinernden": "Versteinernde",
    "Versteinernderen": "Versteinerndere",
    "Versteinerndsten": "Versteinerndste",
    "Versteinerns": "Versteinern",
    "Versteinerte": "versteinert",
    "Versteinerten": "Versteinerte",
    "Versteinerteren": "Versteinertere",
    "Versteinertesten": "Versteinerteste",
    "Versteinerungen": "Versteinerung",
    "Verstellenden": "Verstellende",
    "Verstellens": "Verstellen",
    "Verstellte": "verstellt",
    "Verstellten": "Verstellte",
    "Verstellteren": "Verstelltere",
    "Verstelltesten": "Verstellteste",
    "Versterbenden": "Versterbende",
    "Versterbens": "Versterben",
    "Versteuernden": "Versteuernde",
    "Versteuerns": "Versteuern",
    "Versteuerte": "versteuert",
    "Versteuerten": "Versteuerte",
    "Verstimmenden": "Verstimmende",
    "Verstimmens": "Verstimmen",
    "Verstimmte": "verstimmt",
    "Verstimmten": "Verstimmte",
    "Verstimmteren": "Verstimmtere",
    "Verstimmtesten": "Verstimmteste",
    "Verstohlenen": "Verstohlene",
    "Verstohleneren": "Verstohlenere",
    "Verstohlensten": "Verstohlenste",
    "Verstopfenden": "Verstopfende",
    "Verstopfenderen": "Verstopfendere",
    "Verstopfendsten": "Verstopfendste",
    "Verstopfens": "Verstopfen",
    "Verstopfte": "verstopft",
    "Verstopften": "Verstopfte",
    "Verstopfteren": "Verstopftere",
    "Verstopftesten": "Verstopfteste",
    "Verstopfungen": "Verstopfung",
    "Verstorbenen": "Verstorbene",
    "Verstoß": "verstoßen",
    "Verstoße": "verstoßen",
    "Verstoßenden": "Verstoßende",
    "Verstoßenen": "Verstoßene",
    "Verstoßens": "Verstoßen",
    "Verstoßes": "Verstoß",
    "Verstrahlenden": "Verstrahlende",
    "Verstrahlens": "Verstrahlen",
    "Verstrahlte": "verstrahlt",
    "Verstrahlten": "Verstrahlte",
    "Verstrahlteren": "Verstrahltere",
    "Verstrahltesten": "Verstrahlteste",
    "Verstrebungen": "Verstrebung",
    "Verstreichenden": "Verstreichende",
    "Verstreichens": "Verstreichen",
    "Verstreuenden": "Verstreuende",
    "Verstreuens": "Verstreuen",
    "Verstreute": "verstreut",
    "Verstreuten": "Verstreute",
    "Verstrichenen": "Verstrichene",
    "Verstromenden": "Verstromende",
    "Verstromens": "Verstromen",
    "Verstromte": "verstromt",
    "Verstromten": "Verstromte",
    "Verstummenden": "Verstummende",
    "Verstummens": "Verstummen",
    "Verstummte": "verstummt",
    "Verstummten": "Verstummte",
    "Verständigenden": "Verständigende",
    "Verständigens": "Verständigen",
    "Verständigte": "verständigt",
    "Verständigten": "Verständigte",
    "Verständigungen": "Verständigung",
    "Verständliche": "verständlich",
    "Verständlichen": "Verständliche",
    "Verständlicheren": "Verständlichere",
    "Verständlichsten": "Verständlichste",
    "Verständnislosen": "Verständnislose",
    "Verständnisloseren": "Verständnislosere",
    "Verständnisse": "Verständnis",
    "Verständnisses": "Verständnis",
    "Verständnisvolle": "verständnisvoll",
    "Verständnisvollen": "Verständnisvolle",
    "Verständnisvolleren": "Verständnisvollere",
    "Verstänkernden": "Verstänkernde",
    "Verstänkerns": "Verstänkern",
    "Verstänkerte": "verstänkert",
    "Verstänkerten": "Verstänkerte",
    "Verstärkenden": "Verstärkende",
    "Verstärkenderen": "Verstärkendere",
    "Verstärkendsten": "Verstärkendste",
    "Verstärkens": "Verstärken",
    "Verstärkte": "verstärkt",
    "Verstärkten": "Verstärkte",
    "Verstärkteren": "Verstärktere",
    "Verstärktesten": "Verstärkteste",
    "Verstärkungen": "Verstärkung",
    "Verstöße": "Verstoß",
    "Verstößen": "Verstoß",
    "Verstückelnden": "Verstückelnde",
    "Verstückelnderen": "Verstückelndere",
    "Verstückelndsten": "Verstückelndste",
    "Verstückelns": "Verstückeln",
    "Verstückelte": "verstückelt",
    "Verstückelten": "Verstückelte",
    "Verstückelteren": "Verstückeltere",
    "Verstückeltesten": "Verstückelteste",
    "Verstümmelnden": "Verstümmelnde",
    "Verstümmelnderen": "Verstümmelndere",
    "Verstümmelndsten": "Verstümmelndste",
    "Verstümmelns": "Verstümmeln",
    "Verstümmelte": "verstümmelt",
    "Verstümmelten": "Verstümmelte",
    "Verstümmelteren": "Verstümmeltere",
    "Verstümmeltesten": "Verstümmelteste",
    "Versuch": "versuchen",
    "Versuche": "versuchen",
    "Versuchen": "Versuch",
    "Versuchenden": "Versuchende",
    "Versuchens": "Versuchen",
    "Versuches": "Versuch",
    "Versuchs": "Versuch",
    "Versuchte": "versucht",
    "Versuchten": "Versuchte",
    "Versuchteren": "Versuchtere",
    "Versuchtesten": "Versuchteste",
    "Versuchungen": "Versuchung",
    "Versumpfenden": "Versumpfende",
    "Versumpfenderen": "Versumpfendere",
    "Versumpfendsten": "Versumpfendste",
    "Versumpfens": "Versumpfen",
    "Versumpfte": "versumpft",
    "Versumpften": "Versumpfte",
    "Versumpfteren": "Versumpftere",
    "Versumpftesten": "Versumpfteste",
    "Versunkenen": "Versunkene",
    "Versunkeneren": "Versunkenere",
    "Versunkensten": "Versunkenste",
    "Versäbelnden": "Versäbelnde",
    "Versäbelns": "Versäbeln",
    "Versäbelte": "versäbelt",
    "Versäbelten": "Versäbelte",
    "Versäumenden": "Versäumende",
    "Versäumens": "Versäumen",
    "Versäumnisse": "Versäumnis",
    "Versäumnissen": "Versäumnis",
    "Versäumnisses": "Versäumnis",
    "Versäumte": "versäumt",
    "Versäumten": "Versäumte",
    "Versöhnenden": "Versöhnende",
    "Versöhnens": "Versöhnen",
    "Versöhnlichen": "Versöhnliche",
    "Versöhnlicheren": "Versöhnlichere",
    "Versöhnlichsten": "Versöhnlichste",
    "Versöhnte": "versöhnt",
    "Versöhnten": "Versöhnte",
    "Versöhnungen": "Versöhnung",
    "Versühnenden": "Versühnende",
    "Versühnens": "Versühnen",
    "Versühnte": "versühnt",
    "Versühnten": "Versühnte",
    "Versündigenden": "Versündigende",
    "Versündigens": "Versündigen",
    "Versündigte": "versündigt",
    "Versündigten": "Versündigte",
    "Versüßenden": "Versüßende",
    "Versüßenderen": "Versüßendere",
    "Versüßendsten": "Versüßendste",
    "Versüßens": "Versüßen",
    "Versüßte": "versüßt",
    "Versüßten": "Versüßte",
    "Versüßteren": "Versüßtere",
    "Versüßtesten": "Versüßteste",
    "Vertagenden": "Vertagende",
    "Vertagens": "Vertagen",
    "Vertagte": "vertagt",
    "Vertagten": "Vertagte",
    "Vertagteren": "Vertagtere",
    "Vertagtesten": "Vertagteste",
    "Vertanen": "Vertane",
    "Vertaneren": "Vertanere",
    "Vertansten": "Vertanste",
    "Vertauschenden": "Vertauschende",
    "Vertauschens": "Vertauschen",
    "Vertauschte": "vertauscht",
    "Vertauschten": "Vertauschte",
    "Verteidigenden": "Verteidigende",
    "Verteidigens": "Verteidigen",
    "Verteidigern": "Verteidiger",
    "Verteidigers": "Verteidiger",
    "Verteidigte": "verteidigt",
    "Verteidigten": "Verteidigte",
    "Verteilenden": "Verteilende",
    "Verteilens": "Verteilen",
    "Verteilerkappen": "Verteilerkappe",
    "Verteilte": "verteilt",
    "Verteilten": "Verteilte",
    "Verteilungen": "Verteilung",
    "Verteuernden": "Verteuernde",
    "Verteuerns": "Verteuern",
    "Verteuerte": "verteuert",
    "Verteuerten": "Verteuerte",
    "Verteuerungen": "Verteuerung",
    "Verteufelnden": "Verteufelnde",
    "Verteufelns": "Verteufeln",
    "Verteufelte": "verteufelt",
    "Verteufelten": "Verteufelte",
    "Verteufelungen": "Verteufelung",
    "Vertiefenden": "Vertiefende",
    "Vertiefenderen": "Vertiefendere",
    "Vertiefendsten": "Vertiefendste",
    "Vertiefens": "Vertiefen",
    "Vertiefte": "vertieft",
    "Vertieften": "Vertiefte",
    "Vertiefungen": "Vertiefung",
    "Vertilgenden": "Vertilgende",
    "Vertilgenderen": "Vertilgendere",
    "Vertilgendsten": "Vertilgendste",
    "Vertilgens": "Vertilgen",
    "Vertilgte": "vertilgt",
    "Vertilgten": "Vertilgte",
    "Vertippenden": "Vertippende",
    "Vertippenderen": "Vertippendere",
    "Vertippendsten": "Vertippendste",
    "Vertippens": "Vertippen",
    "Vertippte": "vertippt",
    "Vertippten": "Vertippte",
    "Vertonenden": "Vertonende",
    "Vertonens": "Vertonen",
    "Vertonte": "vertont",
    "Vertonten": "Vertonte",
    "Vertonungen": "Vertonung",
    "Vertrackte": "vertrackt",
    "Vertrackten": "Vertrackte",
    "Vertrackteren": "Vertracktere",
    "Vertracktesten": "Vertrackteste",
    "Vertrag": "vertragen",
    "Vertrage": "vertragen",
    "Vertragenden": "Vertragende",
    "Vertragenen": "Vertragene",
    "Vertragens": "Vertragen",
    "Vertraglichen": "Vertragliche",
    "Vertrags": "Vertrag",
    "Vertragsbrüchige": "vertragsbrüchig",
    "Vertragsbrüchigen": "Vertragsbrüchige",
    "Vertragsgemäßen": "Vertragsgemäße",
    "Vertragswidrigen": "Vertragswidrige",
    "Vertrau": "vertrauen",
    "Vertrauenden": "Vertrauende",
    "Vertrauenderen": "Vertrauendere",
    "Vertrauendsten": "Vertrauendste",
    "Vertrauens": "Vertrauen",
    "Vertrauensbildende": "vertrauensbildend",
    "Vertrauensbildenden": "Vertrauensbildende",
    "Vertrauensseligen": "Vertrauensselige",
    "Vertrauensseligeren": "Vertrauensseligere",
    "Vertrauensvollen": "Vertrauensvolle",
    "Vertrauensvolleren": "Vertrauensvollere",
    "Vertrauenswürdigen": "Vertrauenswürdige",
    "Vertrauenswürdigeren": "Vertrauenswürdigere",
    "Vertraulichen": "Vertrauliche",
    "Vertraulicheren": "Vertraulichere",
    "Vertraulichkeiten": "Vertraulichkeit",
    "Vertraulichste": "vertraulich",
    "Vertraulichsten": "Vertraulichste",
    "Vertraute": "vertraut",
    "Vertrauten": "Vertraute",
    "Vertrauteren": "Vertrautere",
    "Vertrautesten": "Vertrauteste",
    "Vertreibenden": "Vertreibende",
    "Vertreibens": "Vertreiben",
    "Vertreibungen": "Vertreibung",
    "Vertretbare": "vertretbar",
    "Vertretbaren": "Vertretbare",
    "Vertretenden": "Vertretende",
    "Vertretenen": "Vertretene",
    "Vertretens": "Vertreten",
    "Vertretern": "Vertreter",
    "Vertreters": "Vertreter",
    "Vertretungen": "Vertretung",
    "Vertrieb": "vertreiben",
    "Vertriebenen": "Vertriebene",
    "Vertriebs": "Vertrieb",
    "Vertrimmenden": "Vertrimmende",
    "Vertrimmens": "Vertrimmen",
    "Vertrimmte": "vertrimmt",
    "Vertrimmten": "Vertrimmte",
    "Vertrocknenden": "Vertrocknende",
    "Vertrocknenderen": "Vertrocknendere",
    "Vertrocknendsten": "Vertrocknendste",
    "Vertrocknens": "Vertrocknen",
    "Vertrocknete": "vertrocknet",
    "Vertrockneten": "Vertrocknete",
    "Vertrockneteren": "Vertrocknetere",
    "Vertrocknetesten": "Vertrockneteste",
    "Verträge": "Vertrag",
    "Verträgen": "Vertrag",
    "Verträgliche": "verträglich",
    "Verträglichen": "Verträgliche",
    "Verträglicheren": "Verträglichere",
    "Verträglichsten": "Verträglichste",
    "Verträumenden": "Verträumende",
    "Verträumenderen": "Verträumendere",
    "Verträumendsten": "Verträumendste",
    "Verträumens": "Verträumen",
    "Verträumte": "verträumt",
    "Verträumten": "Verträumte",
    "Verträumteren": "Verträumtere",
    "Verträumtesten": "Verträumteste",
    "Vertrödelnden": "Vertrödelnde",
    "Vertrödelnderen": "Vertrödelndere",
    "Vertrödelndsten": "Vertrödelndste",
    "Vertrödelns": "Vertrödeln",
    "Vertrödelte": "vertrödelt",
    "Vertrödelten": "Vertrödelte",
    "Vertrödelteren": "Vertrödeltere",
    "Vertrödeltesten": "Vertrödelteste",
    "Vertröstenden": "Vertröstende",
    "Vertröstenderen": "Vertröstendere",
    "Vertröstendsten": "Vertröstendste",
    "Vertröstens": "Vertrösten",
    "Vertröstete": "vertröstet",
    "Vertrösteten": "Vertröstete",
    "Vertrösteteren": "Vertröstetere",
    "Vertröstetesten": "Vertrösteteste",
    "Vertuenden": "Vertuende",
    "Vertuens": "Vertuen",
    "Vertuschenden": "Vertuschende",
    "Vertuschens": "Vertuschen",
    "Vertuschte": "vertuscht",
    "Vertuschten": "Vertuschte",
    "Vertäfelnden": "Vertäfelnde",
    "Vertäfelns": "Vertäfeln",
    "Vertäfelte": "vertäfelt",
    "Vertäfelten": "Vertäfelte",
    "Vertändelnden": "Vertändelnde",
    "Vertändelnderen": "Vertändelndere",
    "Vertändelndsten": "Vertändelndste",
    "Vertändelns": "Vertändeln",
    "Vertändelte": "vertändelt",
    "Vertändelten": "Vertändelte",
    "Verulkenden": "Verulkende",
    "Verulkenderen": "Verulkendere",
    "Verulkendsten": "Verulkendste",
    "Verulkens": "Verulken",
    "Verulkte": "verulkt",
    "Verulkten": "Verulkte",
    "Verulkteren": "Verulktere",
    "Verulktesten": "Verulkteste",
    "Verunfallenden": "Verunfallende",
    "Verunfallens": "Verunfallen",
    "Verunfallte": "verunfallt",
    "Verunfallten": "Verunfallte",
    "Verunglimpfenden": "Verunglimpfende",
    "Verunglimpfens": "Verunglimpfen",
    "Verunglimpfte": "verunglimpft",
    "Verunglimpften": "Verunglimpfte",
    "Verunglimpfungen": "Verunglimpfung",
    "Verunglückenden": "Verunglückende",
    "Verunglückens": "Verunglücken",
    "Verunglückte": "verunglückt",
    "Verunglückten": "Verunglückte",
    "Verunreinigenden": "Verunreinigende",
    "Verunreinigens": "Verunreinigen",
    "Verunreinigte": "verunreinigt",
    "Verunreinigten": "Verunreinigte",
    "Verunreinigungen": "Verunreinigung",
    "Verunsichernden": "Verunsichernde",
    "Verunsichernderen": "Verunsicherndere",
    "Verunsicherndsten": "Verunsicherndste",
    "Verunsicherns": "Verunsichern",
    "Verunsicherte": "verunsichert",
    "Verunsicherten": "Verunsicherte",
    "Verunsicherteren": "Verunsichertere",
    "Verunsichertesten": "Verunsicherteste",
    "Verunsicherungen": "Verunsicherung",
    "Verunstaltenden": "Verunstaltende",
    "Verunstaltens": "Verunstalten",
    "Verunstaltete": "verunstaltet",
    "Verunstalteten": "Verunstaltete",
    "Verunstaltungen": "Verunstaltung",
    "Veruntreuenden": "Veruntreuende",
    "Veruntreuens": "Veruntreuen",
    "Veruntreute": "veruntreut",
    "Veruntreuten": "Veruntreute",
    "Veruntreuungen": "Veruntreuung",
    "Verursachenden": "Verursachende",
    "Verursachens": "Verursachen",
    "Verursachte": "verursacht",
    "Verursachten": "Verursachte",
    "Verurteilenden": "Verurteilende",
    "Verurteilens": "Verurteilen",
    "Verurteilte": "verurteilt",
    "Verurteilten": "Verurteilte",
    "Verurteilungen": "Verurteilung",
    "Vervielfachenden": "Vervielfachende",
    "Vervielfachens": "Vervielfachen",
    "Vervielfachte": "vervielfacht",
    "Vervielfachten": "Vervielfachte",
    "Vervielfältigenden": "Vervielfältigende",
    "Vervielfältigens": "Vervielfältigen",
    "Vervielfältigte": "vervielfältigt",
    "Vervielfältigten": "Vervielfältigte",
    "Vervielfältigteren": "Vervielfältigtere",
    "Vervollkommnenden": "Vervollkommnende",
    "Vervollkommnenderen": "Vervollkommnendere",
    "Vervollkommnens": "Vervollkommnen",
    "Vervollkommnete": "vervollkommnet",
    "Vervollkommneten": "Vervollkommnete",
    "Vervollkommneteren": "Vervollkommnetere",
    "Vervollständigenden": "Vervollständigende",
    "Vervollständigens": "Vervollständigen",
    "Vervollständigte": "vervollständigt",
    "Vervollständigten": "Vervollständigte",
    "Verwachsenden": "Verwachsende",
    "Verwachsenen": "Verwachsene",
    "Verwachsens": "Verwachsen",
    "Verwahrenden": "Verwahrende",
    "Verwahrens": "Verwahren",
    "Verwahrlosenden": "Verwahrlosende",
    "Verwahrlosens": "Verwahrlosen",
    "Verwahrloste": "verwahrlost",
    "Verwahrlosten": "Verwahrloste",
    "Verwahrte": "verwahrt",
    "Verwahrten": "Verwahrte",
    "Verwaisenden": "Verwaisende",
    "Verwaisens": "Verwaisen",
    "Verwaiste": "verwaist",
    "Verwaisten": "Verwaiste",
    "Verwaltenden": "Verwaltende",
    "Verwaltens": "Verwalten",
    "Verwaltern": "Verwalter",
    "Verwalters": "Verwalter",
    "Verwaltete": "verwaltet",
    "Verwalteten": "Verwaltete",
    "Verwaltungen": "Verwaltung",
    "Verwandelnden": "Verwandelnde",
    "Verwandelns": "Verwandeln",
    "Verwandelte": "verwandelt",
    "Verwandelten": "Verwandelte",
    "Verwandelteren": "Verwandeltere",
    "Verwandeltesten": "Verwandelteste",
    "Verwandlungen": "Verwandlung",
    "Verwandte": "verwenden",
    "Verwandten": "verwenden",
    "Verwandtschaften": "Verwandtschaft",
    "Verwanzte": "verwanzt",
    "Verwanzten": "Verwanzte",
    "Verwanzteren": "Verwanztere",
    "Verwanztesten": "Verwanzteste",
    "Verwarnenden": "Verwarnende",
    "Verwarnens": "Verwarnen",
    "Verwarnte": "verwarnt",
    "Verwarnten": "Verwarnte",
    "Verwaschenen": "Verwaschene",
    "Verwascheneren": "Verwaschenere",
    "Verwaschensten": "Verwaschenste",
    "Verwechselnden": "Verwechselnde",
    "Verwechselns": "Verwechseln",
    "Verwechselte": "verwechselt",
    "Verwechselten": "Verwechselte",
    "Verwechslungen": "Verwechslung",
    "Verwehenden": "Verwehende",
    "Verwehens": "Verwehen",
    "Verwehrenden": "Verwehrende",
    "Verwehrenderen": "Verwehrendere",
    "Verwehrendsten": "Verwehrendste",
    "Verwehrens": "Verwehren",
    "Verwehrte": "verwehrt",
    "Verwehrten": "Verwehrte",
    "Verwehte": "verweht",
    "Verwehten": "Verwehte",
    "Verwehteren": "Verwehtere",
    "Verwehtesten": "Verwehteste",
    "Verweichlichenden": "Verweichlichende",
    "Verweichlichenderen": "Verweichlichendere",
    "Verweichlichens": "Verweichlichen",
    "Verweichlichte": "verweichlicht",
    "Verweichlichten": "Verweichlichte",
    "Verweichlichteren": "Verweichlichtere",
    "Verweichlichteste": "verweichlicht",
    "Verweigernden": "Verweigernde",
    "Verweigernderen": "Verweigerndere",
    "Verweigerndsten": "Verweigerndste",
    "Verweigerns": "Verweigern",
    "Verweigerte": "verweigert",
    "Verweigerten": "Verweigerte",
    "Verweigerungen": "Verweigerung",
    "Verweilenden": "Verweilende",
    "Verweilens": "Verweilen",
    "Verweilte": "verweilt",
    "Verweilten": "Verweilte",
    "Verweis": "verweisen",
    "Verweise": "verweisen",
    "Verweisen": "Verweis",
    "Verweisenden": "Verweisende",
    "Verweisens": "Verweisen",
    "Verweises": "Verweis",
    "Verwelkenden": "Verwelkende",
    "Verwelkenderen": "Verwelkendere",
    "Verwelkendsten": "Verwelkendste",
    "Verwelkens": "Verwelken",
    "Verwelkte": "verwelkt",
    "Verwelkten": "Verwelkte",
    "Verwelkteren": "Verwelktere",
    "Verwelktesten": "Verwelkteste",
    "Verweltlichenden": "Verweltlichende",
    "Verweltlichens": "Verweltlichen",
    "Verweltlichte": "verweltlicht",
    "Verweltlichten": "Verweltlichte",
    "Verwendenden": "Verwendende",
    "Verwendens": "Verwenden",
    "Verwendete": "verwendet",
    "Verwendeten": "Verwendete",
    "Verwendeteren": "Verwendetere",
    "Verwendetesten": "Verwendeteste",
    "Verwendungen": "Verwendung",
    "Verwerfenden": "Verwerfende",
    "Verwerfens": "Verwerfen",
    "Verwerflichen": "Verwerfliche",
    "Verwerflicheren": "Verwerflichere",
    "Verwerflichsten": "Verwerflichste",
    "Verwerfungen": "Verwerfung",
    "Verwertbare": "verwertbar",
    "Verwertbaren": "Verwertbare",
    "Verwertenden": "Verwertende",
    "Verwertenderen": "Verwertendere",
    "Verwertendsten": "Verwertendste",
    "Verwertens": "Verwerten",
    "Verwertete": "verwertet",
    "Verwerteten": "Verwertete",
    "Verwerteteren": "Verwertetere",
    "Verwertetesten": "Verwerteteste",
    "Verwertungen": "Verwertung",
    "Verwesenden": "Verwesende",
    "Verwesenderen": "Verwesendere",
    "Verwesendsten": "Verwesendste",
    "Verwesens": "Verwesen",
    "Verweste": "verwest",
    "Verwesten": "Verweste",
    "Verwesteren": "Verwestere",
    "Verwestesten": "Verwesteste",
    "Verwettenden": "Verwettende",
    "Verwettens": "Verwetten",
    "Verwettete": "verwettet",
    "Verwetteten": "Verwettete",
    "Verwickelnden": "Verwickelnde",
    "Verwickelns": "Verwickeln",
    "Verwickelte": "verwickelt",
    "Verwickelten": "Verwickelte",
    "Verwickelteren": "Verwickeltere",
    "Verwickeltesten": "Verwickelteste",
    "Verwicklungen": "Verwicklung",
    "Verwiesenen": "Verwiesene",
    "Verwindenden": "Verwindende",
    "Verwindens": "Verwinden",
    "Verwinkelnden": "Verwinkelnde",
    "Verwinkelnderen": "Verwinkelndere",
    "Verwinkelndsten": "Verwinkelndste",
    "Verwinkelns": "Verwinkeln",
    "Verwinkelte": "verwinkelt",
    "Verwinkelten": "Verwinkelte",
    "Verwinkelteren": "Verwinkeltere",
    "Verwinkeltesten": "Verwinkelteste",
    "Verwirklichenden": "Verwirklichende",
    "Verwirklichenderen": "Verwirklichendere",
    "Verwirklichens": "Verwirklichen",
    "Verwirklichte": "verwirklicht",
    "Verwirklichten": "Verwirklichte",
    "Verwirklichteren": "Verwirklichtere",
    "Verwirklichtesten": "Verwirklichteste",
    "Verwirklichungen": "Verwirklichung",
    "Verwirrenden": "Verwirrende",
    "Verwirrenderen": "Verwirrendere",
    "Verwirrendsten": "Verwirrendste",
    "Verwirrens": "Verwirren",
    "Verwirrte": "verwirrt",
    "Verwirrten": "Verwirrte",
    "Verwirrteren": "Verwirrtere",
    "Verwirrtesten": "Verwirrteste",
    "Verwirrungen": "Verwirrung",
    "Verwischenden": "Verwischende",
    "Verwischenderen": "Verwischendere",
    "Verwischendsten": "Verwischendste",
    "Verwischens": "Verwischen",
    "Verwischte": "verwischt",
    "Verwischten": "Verwischte",
    "Verwischteren": "Verwischtere",
    "Verwischtesten": "Verwischteste",
    "Verwischungen": "Verwischung",
    "Verwitterungen": "Verwitterung",
    "Verwitwete": "verwitwet",
    "Verwitweten": "Verwitwete",
    "Verwohnenden": "Verwohnende",
    "Verwohnenderen": "Verwohnendere",
    "Verwohnendsten": "Verwohnendste",
    "Verwohnens": "Verwohnen",
    "Verwohnte": "verwohnt",
    "Verwohnten": "Verwohnte",
    "Verwohnteren": "Verwohntere",
    "Verwohntesten": "Verwohnteste",
    "Verworfenen": "Verworfene",
    "Verworfeneren": "Verworfenere",
    "Verworfensten": "Verworfenste",
    "Verwuchernden": "Verwuchernde",
    "Verwuchernderen": "Verwucherndere",
    "Verwucherndsten": "Verwucherndste",
    "Verwucherns": "Verwuchern",
    "Verwucherte": "verwuchert",
    "Verwucherten": "Verwucherte",
    "Verwucherteren": "Verwuchertere",
    "Verwuchertesten": "Verwucherteste",
    "Verwundbaren": "Verwundbare",
    "Verwundbareren": "Verwundbarere",
    "Verwundbarsten": "Verwundbarste",
    "Verwundenen": "Verwundene",
    "Verwundernden": "Verwundernde",
    "Verwunderns": "Verwundern",
    "Verwunderte": "verwundert",
    "Verwunderten": "Verwunderte",
    "Verwunderteren": "Verwundertere",
    "Verwundertesten": "Verwunderteste",
    "Verwunschenen": "Verwunschene",
    "Verwurstelnden": "Verwurstelnde",
    "Verwurstelnderen": "Verwurstelndere",
    "Verwurstelndsten": "Verwurstelndste",
    "Verwurstelns": "Verwursteln",
    "Verwurstelte": "verwurstelt",
    "Verwurstelten": "Verwurstelte",
    "Verwurstelteren": "Verwursteltere",
    "Verwursteltesten": "Verwurstelteste",
    "Verwurstenden": "Verwurstende",
    "Verwurstenderen": "Verwurstendere",
    "Verwurstendsten": "Verwurstendste",
    "Verwurstens": "Verwursten",
    "Verwurstete": "verwurstet",
    "Verwursteten": "Verwurstete",
    "Verwursteteren": "Verwurstetere",
    "Verwurstetesten": "Verwursteteste",
    "Verwurzelnden": "Verwurzelnde",
    "Verwurzelns": "Verwurzeln",
    "Verwurzelte": "verwurzelt",
    "Verwurzelten": "Verwurzelte",
    "Verwurzelteren": "Verwurzeltere",
    "Verwurzeltesten": "Verwurzelteste",
    "Verwählenden": "Verwählende",
    "Verwählens": "Verwählen",
    "Verwählte": "verwählt",
    "Verwählten": "Verwählte",
    "Verwährende": "verwährend",
    "Verwährenden": "Verwährende",
    "Verwährens": "Verwähren",
    "Verwährte": "verwährt",
    "Verwährten": "Verwährte",
    "Verwöhnende": "verwöhnend",
    "Verwöhnenden": "Verwöhnende",
    "Verwöhnendere": "verwöhnend",
    "Verwöhnenderen": "Verwöhnendere",
    "Verwöhnendste": "verwöhnend",
    "Verwöhnendsten": "Verwöhnendste",
    "Verwöhnens": "Verwöhnen",
    "Verwöhnte": "verwöhnt",
    "Verwöhnten": "Verwöhnte",
    "Verwöhntere": "verwöhnt",
    "Verwöhnteren": "Verwöhntere",
    "Verwöhnteste": "verwöhnt",
    "Verwöhntesten": "Verwöhnteste",
    "Verwünschenden": "Verwünschende",
    "Verwünschens": "Verwünschen",
    "Verwünschte": "verwünscht",
    "Verwünschten": "Verwünschte",
    "Verwüstenden": "Verwüstende",
    "Verwüstenderen": "Verwüstendere",
    "Verwüstendsten": "Verwüstendste",
    "Verwüstens": "Verwüsten",
    "Verwüstete": "verwüstet",
    "Verwüsteten": "Verwüstete",
    "Verwüsteteren": "Verwüstetere",
    "Verwüstetesten": "Verwüsteteste",
    "Verzagenden": "Verzagende",
    "Verzagenderen": "Verzagendere",
    "Verzagendsten": "Verzagendste",
    "Verzagens": "Verzagen",
    "Verzagte": "verzagt",
    "Verzagten": "Verzagte",
    "Verzagteren": "Verzagtere",
    "Verzagtesten": "Verzagteste",
    "Verzahnenden": "Verzahnende",
    "Verzahnens": "Verzahnen",
    "Verzahnte": "verzahnt",
    "Verzahnten": "Verzahnte",
    "Verzahnungen": "Verzahnung",
    "Verzapfenden": "Verzapfende",
    "Verzapfens": "Verzapfen",
    "Verzapfte": "verzapft",
    "Verzapften": "Verzapfte",
    "Verzaubernden": "Verzaubernde",
    "Verzaubernderen": "Verzauberndere",
    "Verzauberndsten": "Verzauberndste",
    "Verzauberns": "Verzaubern",
    "Verzauberte": "verzaubert",
    "Verzauberten": "Verzauberte",
    "Verzauberteren": "Verzaubertere",
    "Verzaubertesten": "Verzauberteste",
    "Verzehrenden": "Verzehrende",
    "Verzehrenderen": "Verzehrendere",
    "Verzehrendsten": "Verzehrendste",
    "Verzehrens": "Verzehren",
    "Verzehrte": "verzehrt",
    "Verzehrten": "Verzehrte",
    "Verzehrteren": "Verzehrtere",
    "Verzehrtesten": "Verzehrteste",
    "Verzeichnenden": "Verzeichnende",
    "Verzeichnens": "Verzeichnen",
    "Verzeichnete": "verzeichnet",
    "Verzeichneten": "Verzeichnete",
    "Verzeichnisse": "Verzeichnis",
    "Verzeichnissen": "Verzeichnis",
    "Verzeichnisses": "Verzeichnis",
    "Verzeichnungen": "Verzeichnung",
    "Verzeihenden": "Verzeihende",
    "Verzeihenderen": "Verzeihendere",
    "Verzeihendsten": "Verzeihendste",
    "Verzeihens": "Verzeihen",
    "Verzeihte": "verzeiht",
    "Verzeihten": "Verzeihte",
    "Verzerrenden": "Verzerrende",
    "Verzerrens": "Verzerren",
    "Verzerrte": "verzerrt",
    "Verzerrten": "Verzerrte",
    "Verzerrteren": "Verzerrtere",
    "Verzerrtesten": "Verzerrteste",
    "Verzerrungen": "Verzerrung",
    "Verzerrungsellipsen": "Verzerrungsellipse",
    "Verzettelnden": "Verzettelnde",
    "Verzettelns": "Verzetteln",
    "Verzettelte": "verzettelt",
    "Verzettelten": "Verzettelte",
    "Verzichte": "verzichten",
    "Verzichten": "Verzicht",
    "Verzichtenden": "Verzichtende",
    "Verzichtens": "Verzichten",
    "Verzichtes": "Verzicht",
    "Verzichtete": "verzichtet",
    "Verzichteten": "Verzichtete",
    "Verzichts": "Verzicht",
    "Verziehenden": "Verziehende",
    "Verziehenen": "Verziehene",
    "Verzieheneren": "Verziehenere",
    "Verziehens": "Verziehen",
    "Verziehenste": "verziehen",
    "Verziehensten": "Verziehenste",
    "Verzierenden": "Verzierende",
    "Verzierenderen": "Verzierendere",
    "Verzierendsten": "Verzierendste",
    "Verzierens": "Verzieren",
    "Verzierte": "verziert",
    "Verzierten": "Verzierte",
    "Verzierungen": "Verzierung",
    "Verzinkenden": "Verzinkende",
    "Verzinkenderen": "Verzinkendere",
    "Verzinkendsten": "Verzinkendste",
    "Verzinkens": "Verzinken",
    "Verzinkte": "verzinkt",
    "Verzinkten": "Verzinkte",
    "Verzinkteren": "Verzinktere",
    "Verzinktesten": "Verzinkteste",
    "Verzinsenden": "Verzinsende",
    "Verzinsens": "Verzinsen",
    "Verzinslichen": "Verzinsliche",
    "Verzinste": "verzinst",
    "Verzinsten": "Verzinste",
    "Verzogenen": "Verzogene",
    "Verzollenden": "Verzollende",
    "Verzollens": "Verzollen",
    "Verzollte": "verzollt",
    "Verzollten": "Verzollte",
    "Verzweifelnden": "Verzweifelnde",
    "Verzweifelnderen": "Verzweifelndere",
    "Verzweifelndsten": "Verzweifelndste",
    "Verzweifelns": "Verzweifeln",
    "Verzweifelte": "verzweifelt",
    "Verzweifelten": "Verzweifelte",
    "Verzweifelteren": "Verzweifeltere",
    "Verzweifeltesten": "Verzweifelteste",
    "Verzweigenden": "Verzweigende",
    "Verzweigenderen": "Verzweigendere",
    "Verzweigendsten": "Verzweigendste",
    "Verzweigens": "Verzweigen",
    "Verzweigte": "verzweigt",
    "Verzweigten": "Verzweigte",
    "Verzweigteren": "Verzweigtere",
    "Verzweigtesten": "Verzweigteste",
    "Verzweigungen": "Verzweigung",
    "Verzwickte": "verzwickt",
    "Verzwickten": "Verzwickte",
    "Verzwickteren": "Verzwicktere",
    "Verzwicktesten": "Verzwickteste",
    "Verzählenden": "Verzählende",
    "Verzählenderen": "Verzählendere",
    "Verzählendsten": "Verzählendste",
    "Verzählens": "Verzählen",
    "Verzählte": "verzählt",
    "Verzählten": "Verzählte",
    "Verzögernden": "Verzögernde",
    "Verzögernderen": "Verzögerndere",
    "Verzögerndsten": "Verzögerndste",
    "Verzögerns": "Verzögern",
    "Verzögerte": "verzögert",
    "Verzögerten": "Verzögerte",
    "Verzögerteren": "Verzögertere",
    "Verzögertesten": "Verzögerteste",
    "Verzögerungen": "Verzögerung",
    "Verächtern": "Verächter",
    "Verächters": "Verächter",
    "Verächtlichen": "Verächtliche",
    "Verächtlicheren": "Verächtlichere",
    "Verächtlichsten": "Verächtlichste",
    "Veränderbare": "veränderbar",
    "Veränderbaren": "Veränderbare",
    "Veränderbareren": "Veränderbarere",
    "Veränderbarsten": "Veränderbarste",
    "Verändernden": "Verändernde",
    "Verändernderen": "Veränderndere",
    "Veränderndsten": "Veränderndste",
    "Veränderns": "Verändern",
    "Veränderte": "verändert",
    "Veränderten": "Veränderte",
    "Veränderteren": "Verändertere",
    "Verändertesten": "Veränderteste",
    "Veränderungen": "Veränderung",
    "Verängstigenden": "Verängstigende",
    "Verängstigenderen": "Verängstigendere",
    "Verängstigendsten": "Verängstigendste",
    "Verängstigens": "Verängstigen",
    "Verängstigte": "verängstigt",
    "Verängstigten": "Verängstigte",
    "Verängstigteren": "Verängstigtere",
    "Verängstigtesten": "Verängstigteste",
    "Veräppelnden": "Veräppelnde",
    "Veräppelnderen": "Veräppelndere",
    "Veräppelndsten": "Veräppelndste",
    "Veräppelns": "Veräppeln",
    "Veräppelte": "veräppelt",
    "Veräppelten": "Veräppelte",
    "Veräppelteren": "Veräppeltere",
    "Veräppeltesten": "Veräppelteste",
    "Verärgernden": "Verärgernde",
    "Verärgerns": "Verärgern",
    "Verärgerte": "verärgert",
    "Verärgerten": "Verärgerte",
    "Verärgerteren": "Verärgertere",
    "Verärgertesten": "Verärgerteste",
    "Verästelnden": "Verästelnde",
    "Verästelnderen": "Verästelndere",
    "Verästelndsten": "Verästelndste",
    "Verästelns": "Verästeln",
    "Verästelte": "verästelt",
    "Verästelten": "Verästelte",
    "Verästelteren": "Verästeltere",
    "Verästeltesten": "Verästelteste",
    "Veräußernden": "Veräußernde",
    "Veräußerns": "Veräußern",
    "Veräußerte": "veräußert",
    "Veräußerten": "Veräußerte",
    "Verödenden": "Verödende",
    "Verödens": "Veröden",
    "Verödete": "verödet",
    "Verödeten": "Verödete",
    "Veröffentlichenden": "Veröffentlichende",
    "Veröffentlichens": "Veröffentlichen",
    "Veröffentlichte": "veröffentlicht",
    "Veröffentlichten": "Veröffentlichte",
    "Veröffentlichungen": "Veröffentlichung",
    "Verübelnden": "Verübelnde",
    "Verübelnderen": "Verübelndere",
    "Verübelndsten": "Verübelndste",
    "Verübelns": "Verübeln",
    "Verübelte": "verübelt",
    "Verübelten": "Verübelte",
    "Verübelteren": "Verübeltere",
    "Verübeltesten": "Verübelteste",
    "Verübenden": "Verübende",
    "Verübens": "Verüben",
    "Verübte": "verübt",
    "Verübten": "Verübte",
    "Vespas": "Vespa",
    "Vespern": "Vesper",
    "Veterinäre": "Veterinär",
    "Veterinären": "Veterinär",
    "Veterinärs": "Veterinär",
    "Vetos": "Veto",
    "Vetterinnen": "Vetterin",
    "Vettern": "Vetter",
    "Vetters": "Vetter",
    "Vetzersbergs": "Vetzersberg",
    "Vickis": "Vicki",
    "Videos": "Video",
    "Vieche": "Viech",
    "Viecher": "Viech",
    "Viechereien": "Viecherei",
    "Viechern": "Viech",
    "Vieches": "Viech",
    "Viechs": "Viech",
    "Viehs": "Vieh",
    "Vielbefahrenen": "Vielbefahrene",
    "Vielbefahreneren": "Vielbefahrenere",
    "Vielbefahrensten": "Vielbefahrenste",
    "Vielbesungenen": "Vielbesungene",
    "Vielbändige": "vielbändig",
    "Vielbändigen": "Vielbändige",
    "Vieldeutigen": "Vieldeutige",
    "Vielfachen": "Vielfache",
    "Vielfältigen": "Vielfältige",
    "Vielfältigeren": "Vielfältigere",
    "Vielfältigsten": "Vielfältigste",
    "Vielsagenden": "Vielsagende",
    "Vielschichtigen": "Vielschichtige",
    "Vielseitigen": "Vielseitige",
    "Vielseitigeren": "Vielseitigere",
    "Vielseitigsten": "Vielseitigste",
    "Vielversprechenden": "Vielversprechende",
    "Vielversprechenderen": "Vielversprechendere",
    "Vielzahlen": "Vielzahl",
    "Vielzellern": "Vielzeller",
    "Vielzellers": "Vielzeller",
    "Vierbeinern": "Vierbeiner",
    "Vierbeiners": "Vierbeiner",
    "Vierbeinige": "vierbeinig",
    "Vierbeinigen": "Vierbeinige",
    "Vierecke": "Viereck",
    "Vierecken": "Viereck",
    "Viereckes": "Viereck",
    "Vierecks": "Viereck",
    "Vierern": "Vierer",
    "Vierers": "Vierer",
    "Vierfarbendrucke": "Vierfarbendruck",
    "Vierfarbendrucken": "Vierfarbendruck",
    "Vierfarbendrucks": "Vierfarbendruck",
    "Vierhändige": "vierhändig",
    "Vierhändigen": "Vierhändige",
    "Vierradbremsen": "Vierradbremse",
    "Viersitzern": "Viersitzer",
    "Viersitzers": "Viersitzer",
    "Viertaktern": "Viertakter",
    "Viertakters": "Viertakter",
    "Vierte": "viert",
    "Vierteilenden": "Vierteilende",
    "Vierteilens": "Vierteilen",
    "Viertel": "vierteln",
    "Viertelbogens": "Viertelbogen",
    "Vierteldrehungen": "Vierteldrehung",
    "Viertelfinalen": "Viertelfinale",
    "Viertelfinales": "Viertelfinale",
    "Vierteljahre": "Vierteljahr",
    "Vierteljahren": "Vierteljahr",
    "Vierteljahrs": "Vierteljahr",
    "Vierteljahrsschriften": "Vierteljahrsschrift",
    "Vierteljährliche": "vierteljährlich",
    "Vierteljährlichen": "Vierteljährliche",
    "Vierteln": "Viertel",
    "Viertelnden": "Viertelnde",
    "Viertelnoten": "Viertelnote",
    "Viertelns": "Vierteln",
    "Viertelpausen": "Viertelpause",
    "Viertels": "Viertel",
    "Viertelstündigen": "Viertelstündige",
    "Vierten": "Vierte",
    "Viertürigen": "Viertürige",
    "Vierundsechzigsteln": "Vierundsechzigstel",
    "Vierundsechzigstels": "Vierundsechzigstel",
    "Vierventilern": "Vierventiler",
    "Vierventilers": "Vierventiler",
    "Viervierteltakte": "Viervierteltakt",
    "Viervierteltakten": "Viervierteltakt",
    "Viervierteltakts": "Viervierteltakt",
    "Vierzigstundenwochen": "Vierzigstundenwoche",
    "Vierzylindern": "Vierzylinder",
    "Vierzylinders": "Vierzylinder",
    "Vietnamesen": "Vietnamese",
    "Vietnams": "Vietnam",
    "Viktorias": "Viktoria",
    "Villen": "Villa",
    "Violas": "Viola",
    "Violette": "violett",
    "Violetten": "Violette",
    "Violinen": "Violine",
    "Virchows": "Virchow",
    "Viren": "Virus",
    "Visagen": "Visage",
    "Visier": "visieren",
    "Visiere": "visieren",
    "Visieren": "Visier",
    "Visierenden": "Visierende",
    "Visierens": "Visieren",
    "Visieres": "Visier",
    "Visiers": "Visier",
    "Visierte": "visiert",
    "Visierten": "Visierte",
    "Visionen": "Vision",
    "Visionären": "Visionäre",
    "Visionäreren": "Visionärere",
    "Visionärsten": "Visionärste",
    "Visuelle": "visuell",
    "Visuellen": "Visuelle",
    "Vitalen": "Vitale",
    "Vitaleren": "Vitalere",
    "Vitalsten": "Vitalste",
    "Vitamine": "Vitamin",
    "Vitaminen": "Vitamin",
    "Vitamins": "Vitamin",
    "Vitrinen": "Vitrine",
    "Vizepräsidenten": "Vizepräsident",
    "Vladimirs": "Vladimir",
    "Vogelfreien": "Vogelfreie",
    "Vogelkundlern": "Vogelkundler",
    "Vogelkundlers": "Vogelkundler",
    "Vogels": "Vogel",
    "Vogteien": "Vogtei",
    "Vogts": "Vogt",
    "Voigts": "Voigt",
    "Volke": "Volk",
    "Volkers": "Volker",
    "Volkes": "Volk",
    "Volks": "Volk",
    "Volksbüchereien": "Volksbücherei",
    "Volksdeutsche": "volksdeutsch",
    "Volksdeutschen": "Volksdeutsche",
    "Volksdeutscheren": "Volksdeutschere",
    "Volksdeutschesten": "Volksdeutscheste",
    "Volkseigenen": "Volkseigene",
    "Volksentscheide": "Volksentscheid",
    "Volksentscheiden": "Volksentscheid",
    "Volksentscheides": "Volksentscheid",
    "Volksentscheids": "Volksentscheid",
    "Volksfremde": "volksfremd",
    "Volksfremden": "Volksfremde",
    "Volkshochschulen": "Volkshochschule",
    "Volkskundliche": "volkskundlich",
    "Volkskundlichen": "Volkskundliche",
    "Volkstümlichen": "Volkstümliche",
    "Volkswirtschaftlichen": "Volkswirtschaftliche",
    "Vollautomatischen": "Vollautomatische",
    "Vollberechtigten": "Vollberechtigte",
    "Vollblute": "Vollblut",
    "Vollblutes": "Vollblut",
    "Vollbluts": "Vollblut",
    "Vollblütige": "vollblütig",
    "Vollblütigen": "Vollblütige",
    "Vollbrachte": "vollbringen",
    "Vollbrachten": "vollbringen",
    "Vollbringenden": "Vollbringende",
    "Vollbringens": "Vollbringen",
    "Vollbusigen": "Vollbusige",
    "Vollbusigeren": "Vollbusigere",
    "Vollbusigsten": "Vollbusigste",
    "Vollen": "Volle",
    "Vollendenden": "Vollendende",
    "Vollendens": "Vollenden",
    "Vollendete": "vollendet",
    "Vollendeten": "Vollendete",
    "Vollendungen": "Vollendung",
    "Volleren": "Vollere",
    "Vollessenden": "Vollessende",
    "Vollessenderen": "Vollessendere",
    "Vollessendsten": "Vollessendste",
    "Vollessens": "Vollessen",
    "Volleyballe": "Volleyball",
    "Volleyballes": "Volleyball",
    "Volleyballs": "Volleyball",
    "Volleybälle": "Volleyball",
    "Volleybällen": "Volleyball",
    "Vollführenden": "Vollführende",
    "Vollführens": "Vollführen",
    "Vollführte": "vollführt",
    "Vollführten": "Vollführte",
    "Vollfüllenden": "Vollfüllende",
    "Vollfüllenderen": "Vollfüllendere",
    "Vollfüllendsten": "Vollfüllendste",
    "Vollfüllens": "Vollfüllen",
    "Vollgefühle": "Vollgefühl",
    "Vollgefühlen": "Vollgefühl",
    "Vollgefühls": "Vollgefühl",
    "Vollgefüllten": "Vollgefüllte",
    "Vollgefüllteren": "Vollgefülltere",
    "Vollgefülltesten": "Vollgefüllteste",
    "Vollgegessenen": "Vollgegessene",
    "Vollgegesseneren": "Vollgegessenere",
    "Vollgegessensten": "Vollgegessenste",
    "Vollgegossenen": "Vollgegossene",
    "Vollgekritzelten": "Vollgekritzelte",
    "Vollgekritzelteren": "Vollgekritzeltere",
    "Vollgelaberten": "Vollgelaberte",
    "Vollgelaberteren": "Vollgelabertere",
    "Vollgelabertesten": "Vollgelaberteste",
    "Vollgemachten": "Vollgemachte",
    "Vollgemalten": "Vollgemalte",
    "Vollgemalteren": "Vollgemaltere",
    "Vollgemaltesten": "Vollgemalteste",
    "Vollgepfropften": "Vollgepfropfte",
    "Vollgepfropfteren": "Vollgepfropftere",
    "Vollgequatschten": "Vollgequatschte",
    "Vollgequatschteren": "Vollgequatschtere",
    "Vollgeschlagenen": "Vollgeschlagene",
    "Vollgeschmierten": "Vollgeschmierte",
    "Vollgeschmierteren": "Vollgeschmiertere",
    "Vollgeschriebenen": "Vollgeschriebene",
    "Vollgeschriebeneren": "Vollgeschriebenere",
    "Vollgespritzten": "Vollgespritzte",
    "Vollgestopften": "Vollgestopfte",
    "Vollgestopfteren": "Vollgestopftere",
    "Vollgestopftesten": "Vollgestopfteste",
    "Vollgetankten": "Vollgetankte",
    "Vollgetankteren": "Vollgetanktere",
    "Vollgetanktesten": "Vollgetankteste",
    "Vollgießenden": "Vollgießende",
    "Vollgießens": "Vollgießen",
    "Volljährigen": "Volljährige",
    "Vollkommenen": "Vollkommene",
    "Vollkommeneren": "Vollkommenere",
    "Vollkommensten": "Vollkommenste",
    "Vollkritzelnden": "Vollkritzelnde",
    "Vollkritzelnderen": "Vollkritzelndere",
    "Vollkritzelndsten": "Vollkritzelndste",
    "Vollkritzelns": "Vollkritzeln",
    "Volllabernden": "Volllabernde",
    "Volllabernderen": "Volllaberndere",
    "Volllaberndsten": "Volllaberndste",
    "Volllaberns": "Volllabern",
    "Vollmachenden": "Vollmachende",
    "Vollmachens": "Vollmachen",
    "Vollmachten": "Vollmacht",
    "Vollmalenden": "Vollmalende",
    "Vollmalens": "Vollmalen",
    "Vollmers": "Vollmer",
    "Vollmonde": "Vollmond",
    "Vollmonden": "Vollmond",
    "Vollmonds": "Vollmond",
    "Vollmundige": "vollmundig",
    "Vollmundigen": "Vollmundige",
    "Vollmundigeren": "Vollmundigere",
    "Vollmundigsten": "Vollmundigste",
    "Vollnamen": "Vollname",
    "Vollpfropfenden": "Vollpfropfende",
    "Vollpfropfenderen": "Vollpfropfendere",
    "Vollpfropfendsten": "Vollpfropfendste",
    "Vollpfropfens": "Vollpfropfen",
    "Vollquatschenden": "Vollquatschende",
    "Vollquatschenderen": "Vollquatschendere",
    "Vollquatschens": "Vollquatschen",
    "Vollschlagenden": "Vollschlagende",
    "Vollschlagens": "Vollschlagen",
    "Vollschlanken": "Vollschlanke",
    "Vollschlankeren": "Vollschlankere",
    "Vollschlankesten": "Vollschlankeste",
    "Vollschmierenden": "Vollschmierende",
    "Vollschmierenderen": "Vollschmierendere",
    "Vollschmierens": "Vollschmieren",
    "Vollschreibenden": "Vollschreibende",
    "Vollschreibens": "Vollschreiben",
    "Vollsitzungen": "Vollsitzung",
    "Vollspritzenden": "Vollspritzende",
    "Vollspritzens": "Vollspritzen",
    "Vollsten": "Vollste",
    "Vollstopfenden": "Vollstopfende",
    "Vollstopfens": "Vollstopfen",
    "Vollständigen": "Vollständige",
    "Vollständigeren": "Vollständigere",
    "Vollständigsten": "Vollständigste",
    "Volltankenden": "Volltankende",
    "Volltankenderen": "Volltankendere",
    "Volltankendsten": "Volltankendste",
    "Volltankens": "Volltanken",
    "Volltreffern": "Volltreffer",
    "Volltreffers": "Volltreffer",
    "Volltrunkene": "volltrunken",
    "Volltrunkenen": "Volltrunkene",
    "Vollversammlungen": "Vollversammlung",
    "Vollwaisen": "Vollwaise",
    "Vollwaschmitteln": "Vollwaschmittel",
    "Vollwaschmittels": "Vollwaschmittel",
    "Vollwertige": "vollwertig",
    "Vollwertigen": "Vollwertige",
    "Vollwertigeren": "Vollwertigere",
    "Vollwertigsten": "Vollwertigste",
    "Vollzeitschulen": "Vollzeitschule",
    "Vollziehenden": "Vollziehende",
    "Vollziehens": "Vollziehen",
    "Vollzogenen": "Vollzogene",
    "Vollzugs": "Vollzug",
    "Vollzähligen": "Vollzählige",
    "Volumens": "Volumen",
    "Voluminöse": "voluminös",
    "Voluminösen": "Voluminöse",
    "Voluminöseren": "Voluminösere",
    "Voluminösesten": "Voluminöseste",
    "Vorabdrucke": "Vorabdruck",
    "Vorabdrucken": "Vorabdruck",
    "Vorabdrucks": "Vorabdruck",
    "Vorabende": "Vorabend",
    "Vorabenden": "Vorabend",
    "Vorabendes": "Vorabend",
    "Vorabends": "Vorabend",
    "Vorahnungen": "Vorahnung",
    "Voranbringenden": "Voranbringende",
    "Voranbringenderen": "Voranbringendere",
    "Voranbringendsten": "Voranbringendste",
    "Voranbringens": "Voranbringen",
    "Vorangebrachten": "Vorangebrachte",
    "Vorangegangenen": "Vorangegangene",
    "Vorangehenden": "Vorangehende",
    "Vorangehens": "Vorangehen",
    "Voranschlage": "Voranschlag",
    "Voranschlages": "Voranschlag",
    "Voranschlags": "Voranschlag",
    "Voranschläge": "Voranschlag",
    "Voranschlägen": "Voranschlag",
    "Voranzeigen": "Voranzeige",
    "Vorarbeiten": "Vorarbeit",
    "Vorarbeitenden": "Vorarbeitende",
    "Vorarbeitens": "Vorarbeiten",
    "Vorarbeitern": "Vorarbeiter",
    "Vorarbeiters": "Vorarbeiter",
    "Vorausblickenden": "Vorausblickende",
    "Vorausblickenderen": "Vorausblickendere",
    "Vorausblickens": "Vorausblicken",
    "Vorausgeblickten": "Vorausgeblickte",
    "Vorausgegangenen": "Vorausgegangene",
    "Vorausgehenden": "Vorausgehende",
    "Vorausgehens": "Vorausgehen",
    "Vorausgesagten": "Vorausgesagte",
    "Vorausgeschauten": "Vorausgeschaute",
    "Vorausgesehenen": "Vorausgesehene",
    "Vorausgesetzten": "Vorausgesetzte",
    "Voraussagenden": "Voraussagende",
    "Voraussagens": "Voraussagen",
    "Vorausschauenden": "Vorausschauende",
    "Vorausschauenderen": "Vorausschauendere",
    "Vorausschauens": "Vorausschauen",
    "Voraussehenden": "Voraussehende",
    "Voraussehens": "Voraussehen",
    "Voraussetzenden": "Voraussetzende",
    "Voraussetzens": "Voraussetzen",
    "Voraussetzungen": "Voraussetzung",
    "Voraussichtliche": "voraussichtlich",
    "Voraussichtlichen": "Voraussichtliche",
    "Vorbauenden": "Vorbauende",
    "Vorbauens": "Vorbauen",
    "Vorbedeutungen": "Vorbedeutung",
    "Vorbedingungen": "Vorbedingung",
    "Vorbehalte": "vorbehalten",
    "Vorbehalten": "Vorbehalt",
    "Vorbehaltenden": "Vorbehaltende",
    "Vorbehaltenen": "Vorbehaltene",
    "Vorbehaltens": "Vorbehalten",
    "Vorbehaltlosen": "Vorbehaltlose",
    "Vorbehalts": "Vorbehalt",
    "Vorbehandelnden": "Vorbehandelnde",
    "Vorbehandelns": "Vorbehandeln",
    "Vorbehandelte": "vorbehandelt",
    "Vorbehandelten": "Vorbehandelte",
    "Vorbehandlungen": "Vorbehandlung",
    "Vorbeibenehmenden": "Vorbeibenehmende",
    "Vorbeibenehmens": "Vorbeibenehmen",
    "Vorbeibenommenen": "Vorbeibenommene",
    "Vorbeifahrenden": "Vorbeifahrende",
    "Vorbeifahrens": "Vorbeifahren",
    "Vorbeifliegenden": "Vorbeifliegende",
    "Vorbeifliegens": "Vorbeifliegen",
    "Vorbeifließenden": "Vorbeifließende",
    "Vorbeifließens": "Vorbeifließen",
    "Vorbeiführenden": "Vorbeiführende",
    "Vorbeiführens": "Vorbeiführen",
    "Vorbeigefahrenen": "Vorbeigefahrene",
    "Vorbeigeflogenen": "Vorbeigeflogene",
    "Vorbeigeflossenen": "Vorbeigeflossene",
    "Vorbeigeführten": "Vorbeigeführte",
    "Vorbeigegangenen": "Vorbeigegangene",
    "Vorbeigehenden": "Vorbeigehende",
    "Vorbeigehens": "Vorbeigehen",
    "Vorbeigekommenen": "Vorbeigekommene",
    "Vorbeigelassenen": "Vorbeigelassene",
    "Vorbeigelaufenen": "Vorbeigelaufene",
    "Vorbeigerannten": "Vorbeigerannte",
    "Vorbeigeredeten": "Vorbeigeredete",
    "Vorbeigeschossenen": "Vorbeigeschossene",
    "Vorbeigetroffenen": "Vorbeigetroffene",
    "Vorbeikommenden": "Vorbeikommende",
    "Vorbeikommens": "Vorbeikommen",
    "Vorbeilassenden": "Vorbeilassende",
    "Vorbeilassens": "Vorbeilassen",
    "Vorbeilaufenden": "Vorbeilaufende",
    "Vorbeilaufens": "Vorbeilaufen",
    "Vorbeimarsche": "Vorbeimarsch",
    "Vorbeimarschierenden": "Vorbeimarschierende",
    "Vorbeimarschierens": "Vorbeimarschieren",
    "Vorbeimarschierte": "vorbeimarschiert",
    "Vorbeimarschierten": "Vorbeimarschierte",
    "Vorbeimarschs": "Vorbeimarsch",
    "Vorbeimärsche": "Vorbeimarsch",
    "Vorbeimärschen": "Vorbeimarsch",
    "Vorbeiredenden": "Vorbeiredende",
    "Vorbeiredens": "Vorbeireden",
    "Vorbeirennenden": "Vorbeirennende",
    "Vorbeirennens": "Vorbeirennen",
    "Vorbeischießenden": "Vorbeischießende",
    "Vorbeischießens": "Vorbeischießen",
    "Vorbeitreffenden": "Vorbeitreffende",
    "Vorbeitreffens": "Vorbeitreffen",
    "Vorbelasteten": "Vorbelastete",
    "Vorbemerkungen": "Vorbemerkung",
    "Vorbereitenden": "Vorbereitende",
    "Vorbereitens": "Vorbereiten",
    "Vorbereitete": "vorbereitet",
    "Vorbereiteten": "Vorbereitete",
    "Vorbereiteteren": "Vorbereitetere",
    "Vorbereitetesten": "Vorbereiteteste",
    "Vorbereitungen": "Vorbereitung",
    "Vorberichte": "Vorbericht",
    "Vorberichten": "Vorbericht",
    "Vorberichts": "Vorbericht",
    "Vorbescheide": "Vorbescheid",
    "Vorbescheiden": "Vorbescheid",
    "Vorbescheids": "Vorbescheid",
    "Vorbesprechungen": "Vorbesprechung",
    "Vorbestellenden": "Vorbestellende",
    "Vorbestellens": "Vorbestellen",
    "Vorbestellte": "vorbestellt",
    "Vorbestellten": "Vorbestellte",
    "Vorbestellungen": "Vorbestellung",
    "Vorbestimmte": "vorbestimmt",
    "Vorbestimmten": "Vorbestimmte",
    "Vorbestraften": "Vorbestrafte",
    "Vorbetenden": "Vorbetende",
    "Vorbetens": "Vorbeten",
    "Vorbeugenden": "Vorbeugende",
    "Vorbeugenderen": "Vorbeugendere",
    "Vorbeugendsten": "Vorbeugendste",
    "Vorbeugens": "Vorbeugen",
    "Vorbeugungen": "Vorbeugung",
    "Vorbilde": "vorbilden",
    "Vorbildenden": "Vorbildende",
    "Vorbildens": "Vorbilden",
    "Vorbilder": "Vorbild",
    "Vorbildern": "Vorbild",
    "Vorbildes": "Vorbild",
    "Vorbildhaftigkeiten": "Vorbildhaftigkeit",
    "Vorbildliche": "vorbildlich",
    "Vorbildlichen": "Vorbildliche",
    "Vorbildlicheren": "Vorbildlichere",
    "Vorbildlichsten": "Vorbildlichste",
    "Vorbilds": "Vorbild",
    "Vorbildungen": "Vorbildung",
    "Vorbindenden": "Vorbindende",
    "Vorbindens": "Vorbinden",
    "Vorbleichenden": "Vorbleichende",
    "Vorbleichens": "Vorbleichen",
    "Vorbohrenden": "Vorbohrende",
    "Vorbohrens": "Vorbohren",
    "Vorboten": "Vorbote",
    "Vorbringenden": "Vorbringende",
    "Vorbringens": "Vorbringen",
    "Vorbühnen": "Vorbühne",
    "Vordache": "Vordach",
    "Vordaches": "Vordach",
    "Vordachs": "Vordach",
    "Vordatierenden": "Vordatierende",
    "Vordatierens": "Vordatieren",
    "Vordatierte": "vordatiert",
    "Vordatierten": "Vordatierte",
    "Vordecks": "Vordeck",
    "Vordenkenden": "Vordenkende",
    "Vordenkens": "Vordenken",
    "Vorderdecks": "Vorderdeck",
    "Vordere": "vorder",
    "Vorderen": "Vordere",
    "Vordereren": "Vorderere",
    "Vordergebäuden": "Vordergebäude",
    "Vordergebäudes": "Vordergebäude",
    "Vordergliede": "Vorderglied",
    "Vorderglieder": "Vorderglied",
    "Vordergliedern": "Vorderglied",
    "Vordergliedes": "Vorderglied",
    "Vorderglieds": "Vorderglied",
    "Vordergrunds": "Vordergrund",
    "Vordergründige": "vordergründig",
    "Vordergründigen": "Vordergründige",
    "Vordergründigeren": "Vordergründigere",
    "Vordergründigsten": "Vordergründigste",
    "Vorderkopfe": "Vorderkopf",
    "Vorderkopfs": "Vorderkopf",
    "Vorderköpfe": "Vorderkopf",
    "Vorderköpfen": "Vorderkopf",
    "Vorderladern": "Vorderlader",
    "Vorderladers": "Vorderlader",
    "Vorderpfoten": "Vorderpfote",
    "Vorderpranken": "Vorderpranke",
    "Vorderrade": "Vorderrad",
    "Vorderrades": "Vorderrad",
    "Vorderrads": "Vorderrad",
    "Vorderräder": "Vorderrad",
    "Vorderrädern": "Vorderrad",
    "Vorderschiffe": "Vorderschiff",
    "Vorderschiffen": "Vorderschiff",
    "Vorderschiffs": "Vorderschiff",
    "Vorderschinkens": "Vorderschinken",
    "Vorderseiten": "Vorderseite",
    "Vorderste": "vorder",
    "Vordersten": "Vorderste",
    "Vordertüren": "Vordertür",
    "Vorderzimmern": "Vorderzimmer",
    "Vorderzimmers": "Vorderzimmer",
    "Vordringenden": "Vordringende",
    "Vordringens": "Vordringen",
    "Vordringlichen": "Vordringliche",
    "Vordrucke": "Vordruck",
    "Vordrucken": "Vordruck",
    "Vordruckes": "Vordruck",
    "Vordrucks": "Vordruck",
    "Vordruckwalzen": "Vordruckwalze",
    "Vordrängenden": "Vordrängende",
    "Vordrängens": "Vordrängen",
    "Vordächer": "Vordach",
    "Vordächern": "Vordach",
    "Voreheliche": "vorehelich",
    "Vorehelichen": "Voreheliche",
    "Voreiligen": "Voreilige",
    "Voreiligeren": "Voreiligere",
    "Voreiligsten": "Voreiligste",
    "Voreingenommenen": "Voreingenommene",
    "Voreingenommeneren": "Voreingenommenere",
    "Vorenden": "Vorende",
    "Vorendes": "Vorende",
    "Vorenthaltenden": "Vorenthaltende",
    "Vorenthaltenderen": "Vorenthaltendere",
    "Vorenthaltendsten": "Vorenthaltendste",
    "Vorenthaltenen": "Vorenthaltene",
    "Vorenthalteneren": "Vorenthaltenere",
    "Vorenthaltens": "Vorenthalten",
    "Vorenthaltenste": "vorenthalten",
    "Vorenthaltensten": "Vorenthaltenste",
    "Vorentladungen": "Vorentladung",
    "Vorentscheidungen": "Vorentscheidung",
    "Vorerben": "Vorerbe",
    "Vorerbschaften": "Vorerbschaft",
    "Vorerzählenden": "Vorerzählende",
    "Vorerzählens": "Vorerzählen",
    "Vorerzählte": "vorerzählt",
    "Vorerzählten": "Vorerzählte",
    "Vorfahren": "Vorfahr",
    "Vorfahrenden": "Vorfahrende",
    "Vorfahrens": "Vorfahren",
    "Vorfahrten": "Vorfahrt",
    "Vorfalle": "vorfallen",
    "Vorfallenden": "Vorfallende",
    "Vorfallens": "Vorfallen",
    "Vorfalles": "Vorfall",
    "Vorfalls": "Vorfall",
    "Vorfeiern": "Vorfeier",
    "Vorfelde": "Vorfeld",
    "Vorfelder": "Vorfeld",
    "Vorfeldern": "Vorfeld",
    "Vorfeldes": "Vorfeld",
    "Vorfelds": "Vorfeld",
    "Vorfertigenden": "Vorfertigende",
    "Vorfertigens": "Vorfertigen",
    "Vorfertigungen": "Vorfertigung",
    "Vorfilme": "Vorfilm",
    "Vorfilmen": "Vorfilm",
    "Vorfilms": "Vorfilm",
    "Vorfinanzierenden": "Vorfinanzierende",
    "Vorfinanzierens": "Vorfinanzieren",
    "Vorfinanzierte": "vorfinanziert",
    "Vorfinanzierten": "Vorfinanzierte",
    "Vorfinanzierungen": "Vorfinanzierung",
    "Vorfindenden": "Vorfindende",
    "Vorfindens": "Vorfinden",
    "Vorflunkernden": "Vorflunkernde",
    "Vorflunkernderen": "Vorflunkerndere",
    "Vorflunkerndsten": "Vorflunkerndste",
    "Vorflunkerns": "Vorflunkern",
    "Vorfluten": "Vorflut",
    "Vorflutern": "Vorfluter",
    "Vorfluters": "Vorfluter",
    "Vorformenden": "Vorformende",
    "Vorformens": "Vorformen",
    "Vorformulierenden": "Vorformulierende",
    "Vorformulierens": "Vorformulieren",
    "Vorformulierte": "vorformuliert",
    "Vorformulierten": "Vorformulierte",
    "Vorfrieden": "Vorfriede",
    "Vorfrüchte": "Vorfrucht",
    "Vorfrüchten": "Vorfrucht",
    "Vorfrühlinge": "Vorfrühling",
    "Vorfrühlingen": "Vorfrühling",
    "Vorfrühlings": "Vorfrühling",
    "Vorfälle": "Vorfall",
    "Vorfällen": "Vorfall",
    "Vorfühlenden": "Vorfühlende",
    "Vorfühlens": "Vorfühlen",
    "Vorführdamen": "Vorführdame",
    "Vorführenden": "Vorführende",
    "Vorführens": "Vorführen",
    "Vorführern": "Vorführer",
    "Vorführers": "Vorführer",
    "Vorführraume": "Vorführraum",
    "Vorführraums": "Vorführraum",
    "Vorführräume": "Vorführraum",
    "Vorführräumen": "Vorführraum",
    "Vorführungen": "Vorführung",
    "Vorgaben": "vorgeben",
    "Vorgange": "Vorgang",
    "Vorganges": "Vorgang",
    "Vorgangs": "Vorgang",
    "Vorgartens": "Vorgarten",
    "Vorgaukelnden": "Vorgaukelnde",
    "Vorgaukelns": "Vorgaukeln",
    "Vorgearbeiteten": "Vorgearbeitete",
    "Vorgebauten": "Vorgebaute",
    "Vorgebenden": "Vorgebende",
    "Vorgebens": "Vorgeben",
    "Vorgebeteten": "Vorgebetete",
    "Vorgebeugten": "Vorgebeugte",
    "Vorgebildeten": "Vorgebildete",
    "Vorgebirgen": "Vorgebirge",
    "Vorgebirges": "Vorgebirge",
    "Vorgeblichenen": "Vorgeblichene",
    "Vorgeblicheneren": "Vorgeblichenere",
    "Vorgeblichensten": "Vorgeblichenste",
    "Vorgebohrten": "Vorgebohrte",
    "Vorgebrachten": "Vorgebrachte",
    "Vorgebundenen": "Vorgebundene",
    "Vorgedachten": "Vorgedachte",
    "Vorgedrungenen": "Vorgedrungene",
    "Vorgedrängten": "Vorgedrängte",
    "Vorgefahrenen": "Vorgefahrene",
    "Vorgefallenen": "Vorgefallene",
    "Vorgefertigten": "Vorgefertigte",
    "Vorgeflunkerten": "Vorgeflunkerte",
    "Vorgeflunkerteren": "Vorgeflunkertere",
    "Vorgeformten": "Vorgeformte",
    "Vorgefundenen": "Vorgefundene",
    "Vorgefühle": "Vorgefühl",
    "Vorgefühlen": "Vorgefühl",
    "Vorgefühls": "Vorgefühl",
    "Vorgefühlten": "Vorgefühlte",
    "Vorgeführten": "Vorgeführte",
    "Vorgegangenen": "Vorgegangene",
    "Vorgegaukelten": "Vorgegaukelte",
    "Vorgegebenen": "Vorgegebene",
    "Vorgegriffenen": "Vorgegriffene",
    "Vorgegriffeneren": "Vorgegriffenere",
    "Vorgegriffensten": "Vorgegriffenste",
    "Vorgehaltenen": "Vorgehaltene",
    "Vorgehangenen": "Vorgehangene",
    "Vorgehenden": "Vorgehende",
    "Vorgehens": "Vorgehen",
    "Vorgeherrschten": "Vorgeherrschte",
    "Vorgeheuchelten": "Vorgeheuchelte",
    "Vorgeheuchelteren": "Vorgeheucheltere",
    "Vorgeheulten": "Vorgeheulte",
    "Vorgeheulteren": "Vorgeheultere",
    "Vorgeheultesten": "Vorgeheulteste",
    "Vorgehängten": "Vorgehängte",
    "Vorgejammerten": "Vorgejammerte",
    "Vorgekauten": "Vorgekaute",
    "Vorgekauteren": "Vorgekautere",
    "Vorgekautesten": "Vorgekauteste",
    "Vorgekehrten": "Vorgekehrte",
    "Vorgekeimten": "Vorgekeimte",
    "Vorgekeimteren": "Vorgekeimtere",
    "Vorgekeimtesten": "Vorgekeimteste",
    "Vorgeknöpften": "Vorgeknöpfte",
    "Vorgekommenen": "Vorgekommene",
    "Vorgeladenen": "Vorgeladene",
    "Vorgelaufenen": "Vorgelaufene",
    "Vorgelebten": "Vorgelebte",
    "Vorgelegenen": "Vorgelegene",
    "Vorgelegten": "Vorgelegte",
    "Vorgelesenen": "Vorgelesene",
    "Vorgelogenen": "Vorgelogene",
    "Vorgelogeneren": "Vorgelogenere",
    "Vorgelogensten": "Vorgelogenste",
    "Vorgemachten": "Vorgemachte",
    "Vorgemerkten": "Vorgemerkte",
    "Vorgeneigten": "Vorgeneigte",
    "Vorgenommenen": "Vorgenommene",
    "Vorgeordneten": "Vorgeordnete",
    "Vorgepreschten": "Vorgepreschte",
    "Vorgepreschteren": "Vorgepreschtere",
    "Vorgepreschtesten": "Vorgepreschteste",
    "Vorgequellten": "Vorgequellte",
    "Vorgequollenen": "Vorgequollene",
    "Vorgerechneten": "Vorgerechnete",
    "Vorgeredeten": "Vorgeredete",
    "Vorgerichteten": "Vorgerichtete",
    "Vorgerittenen": "Vorgerittene",
    "Vorgerückten": "Vorgerückte",
    "Vorgesagten": "Vorgesagte",
    "Vorgeschichten": "Vorgeschichte",
    "Vorgeschichtliche": "vorgeschichtlich",
    "Vorgeschichtlichen": "Vorgeschichtliche",
    "Vorgeschlagenen": "Vorgeschlagene",
    "Vorgeschmacke": "Vorgeschmack",
    "Vorgeschmackes": "Vorgeschmack",
    "Vorgeschmacks": "Vorgeschmack",
    "Vorgeschnittenen": "Vorgeschnittene",
    "Vorgeschobenen": "Vorgeschobene",
    "Vorgeschossenen": "Vorgeschossene",
    "Vorgeschriebenen": "Vorgeschriebene",
    "Vorgeschrittenen": "Vorgeschrittene",
    "Vorgeschwebten": "Vorgeschwebte",
    "Vorgeschwindelten": "Vorgeschwindelte",
    "Vorgeschwärmten": "Vorgeschwärmte",
    "Vorgeschützten": "Vorgeschützte",
    "Vorgesehenen": "Vorgesehene",
    "Vorgesessenen": "Vorgesessene",
    "Vorgesetzten": "Vorgesetzte",
    "Vorgesorgten": "Vorgesorgte",
    "Vorgesorgteren": "Vorgesorgtere",
    "Vorgesorgtesten": "Vorgesorgteste",
    "Vorgespannten": "Vorgespannte",
    "Vorgespiegelten": "Vorgespiegelte",
    "Vorgespielten": "Vorgespielte",
    "Vorgesprochenen": "Vorgesprochene",
    "Vorgesprungenen": "Vorgesprungene",
    "Vorgespulten": "Vorgespulte",
    "Vorgestandenen": "Vorgestandene",
    "Vorgestellten": "Vorgestellte",
    "Vorgestoßenen": "Vorgestoßene",
    "Vorgestülpten": "Vorgestülpte",
    "Vorgestürmten": "Vorgestürmte",
    "Vorgesungenen": "Vorgesungene",
    "Vorgetanzten": "Vorgetanzte",
    "Vorgetragenen": "Vorgetragene",
    "Vorgetretenen": "Vorgetretene",
    "Vorgetriebenen": "Vorgetriebene",
    "Vorgeturnten": "Vorgeturnte",
    "Vorgetäuschten": "Vorgetäuschte",
    "Vorgewagten": "Vorgewagte",
    "Vorgewarnten": "Vorgewarnte",
    "Vorgewiesenen": "Vorgewiesene",
    "Vorgewogenen": "Vorgewogene",
    "Vorgeworfenen": "Vorgeworfene",
    "Vorgewählten": "Vorgewählte",
    "Vorgewärmten": "Vorgewärmte",
    "Vorgewärmteren": "Vorgewärmtere",
    "Vorgewärmtesten": "Vorgewärmteste",
    "Vorgewölbten": "Vorgewölbte",
    "Vorgewölbteren": "Vorgewölbtere",
    "Vorgewölbtesten": "Vorgewölbteste",
    "Vorgezauberten": "Vorgezauberte",
    "Vorgezeichneten": "Vorgezeichnete",
    "Vorgezeigten": "Vorgezeigte",
    "Vorgezogenen": "Vorgezogene",
    "Vorgezählten": "Vorgezählte",
    "Vorgreifenden": "Vorgreifende",
    "Vorgreifenderen": "Vorgreifendere",
    "Vorgreifendsten": "Vorgreifendste",
    "Vorgreifens": "Vorgreifen",
    "Vorgriffe": "Vorgriff",
    "Vorgriffen": "Vorgriff",
    "Vorgriffs": "Vorgriff",
    "Vorgänge": "Vorgang",
    "Vorgängen": "Vorgang",
    "Vorgängern": "Vorgänger",
    "Vorgängers": "Vorgänger",
    "Vorgärten": "Vorgarten",
    "Vorhabens": "Vorhaben",
    "Vorhaltenden": "Vorhaltende",
    "Vorhaltens": "Vorhalten",
    "Vorhandenen": "Vorhandene",
    "Vorhange": "Vorhang",
    "Vorhangs": "Vorhang",
    "Vorhemde": "Vorhemd",
    "Vorhemden": "Vorhemd",
    "Vorhemds": "Vorhemd",
    "Vorherfahrenden": "Vorherfahrende",
    "Vorherfahrens": "Vorherfahren",
    "Vorhergefahrenen": "Vorhergefahrene",
    "Vorhergesagten": "Vorhergesagte",
    "Vorhergesprungenen": "Vorhergesprungene",
    "Vorherigen": "Vorherige",
    "Vorherrschenden": "Vorherrschende",
    "Vorherrschenderen": "Vorherrschendere",
    "Vorherrschendsten": "Vorherrschendste",
    "Vorherrschens": "Vorherrschen",
    "Vorhersagen": "Vorhersage",
    "Vorhersagenden": "Vorhersagende",
    "Vorhersagens": "Vorhersagen",
    "Vorhersehbaren": "Vorhersehbare",
    "Vorhersehbareren": "Vorhersehbarere",
    "Vorhersehbarsten": "Vorhersehbarste",
    "Vorherspringenden": "Vorherspringende",
    "Vorherspringens": "Vorherspringen",
    "Vorheuchelnden": "Vorheuchelnde",
    "Vorheuchelnderen": "Vorheuchelndere",
    "Vorheuchelndsten": "Vorheuchelndste",
    "Vorheuchelns": "Vorheucheln",
    "Vorheulenden": "Vorheulende",
    "Vorheulenderen": "Vorheulendere",
    "Vorheulendsten": "Vorheulendste",
    "Vorheulens": "Vorheulen",
    "Vorhofe": "Vorhof",
    "Vorhofs": "Vorhof",
    "Vorhänge": "vorhängen",
    "Vorhängen": "Vorhang",
    "Vorhängenden": "Vorhängende",
    "Vorhängens": "Vorhängen",
    "Vorhäute": "Vorhaut",
    "Vorhäuten": "Vorhaut",
    "Vorhöfe": "Vorhof",
    "Vorhöfen": "Vorhof",
    "Vorige": "vorig",
    "Vorigen": "Vorige",
    "Vorjahre": "Vorjahr",
    "Vorjahren": "Vorjahr",
    "Vorjahres": "Vorjahr",
    "Vorjahrs": "Vorjahr",
    "Vorjammernden": "Vorjammernde",
    "Vorjammernderen": "Vorjammerndere",
    "Vorjammerndsten": "Vorjammerndste",
    "Vorjammerns": "Vorjammern",
    "Vorkauenden": "Vorkauende",
    "Vorkauenderen": "Vorkauendere",
    "Vorkauendsten": "Vorkauendste",
    "Vorkauens": "Vorkauen",
    "Vorkehrenden": "Vorkehrende",
    "Vorkehrens": "Vorkehren",
    "Vorkehrungen": "Vorkehrung",
    "Vorkeimenden": "Vorkeimende",
    "Vorkeimenderen": "Vorkeimendere",
    "Vorkeimendsten": "Vorkeimendste",
    "Vorkeimens": "Vorkeimen",
    "Vorkenntnissese": "Vorkenntnisse",
    "Vorkenntnissesen": "Vorkenntnisse",
    "Vorklassikern": "Vorklassiker",
    "Vorklassikers": "Vorklassiker",
    "Vorknöpfenden": "Vorknöpfende",
    "Vorknöpfens": "Vorknöpfen",
    "Vorkommenden": "Vorkommende",
    "Vorkommens": "Vorkommen",
    "Vorkommnisse": "Vorkommnis",
    "Vorkommnissen": "Vorkommnis",
    "Vorkommnisses": "Vorkommnis",
    "Vorkriegszeiten": "Vorkriegszeit",
    "Vorkämpferinnen": "Vorkämpferin",
    "Vorladenden": "Vorladende",
    "Vorladens": "Vorladen",
    "Vorladungen": "Vorladung",
    "Vorlagen": "vorliegen",
    "Vorlands": "Vorland",
    "Vorlaufe": "vorlaufen",
    "Vorlaufenden": "Vorlaufende",
    "Vorlaufens": "Vorlaufen",
    "Vorlaufs": "Vorlauf",
    "Vorlauten": "Vorlaute",
    "Vorlauteren": "Vorlautere",
    "Vorlautesten": "Vorlauteste",
    "Vorlebenden": "Vorlebende",
    "Vorlebens": "Vorleben",
    "Vorlegenden": "Vorlegende",
    "Vorlegens": "Vorlegen",
    "Vorleistungen": "Vorleistung",
    "Vorlese": "vorlesen",
    "Vorlesen": "Vorlese",
    "Vorlesenden": "Vorlesende",
    "Vorlesens": "Vorlesen",
    "Vorlieben": "Vorliebe",
    "Vorliegenden": "Vorliegende",
    "Vorliegens": "Vorliegen",
    "Vorläufe": "Vorlauf",
    "Vorläufen": "Vorlauf",
    "Vorläufern": "Vorläufer",
    "Vorläufers": "Vorläufer",
    "Vorläufigen": "Vorläufige",
    "Vorlügenden": "Vorlügende",
    "Vorlügenderen": "Vorlügendere",
    "Vorlügendsten": "Vorlügendste",
    "Vorlügens": "Vorlügen",
    "Vormachenden": "Vormachende",
    "Vormachens": "Vormachen",
    "Vormaligen": "Vormalige",
    "Vormanne": "Vormann",
    "Vormannes": "Vormann",
    "Vormanns": "Vormann",
    "Vormarsche": "Vormarsch",
    "Vormarschs": "Vormarsch",
    "Vormaste": "Vormast",
    "Vormasten": "Vormast",
    "Vormasts": "Vormast",
    "Vormauern": "Vormauer",
    "Vormenschen": "Vormensch",
    "Vormerkenden": "Vormerkende",
    "Vormerkens": "Vormerken",
    "Vormerkungen": "Vormerkung",
    "Vormittage": "Vormittag",
    "Vormittagen": "Vormittag",
    "Vormittags": "Vormittag",
    "Vormundschaften": "Vormundschaft",
    "Vormänner": "Vormann",
    "Vormännern": "Vormann",
    "Vormärsche": "Vormarsch",
    "Vormärschen": "Vormarsch",
    "Vornamen": "Vorname",
    "Vornehme": "vornehm",
    "Vornehmen": "Vornehme",
    "Vornehmenden": "Vornehmende",
    "Vornehmens": "Vornehmen",
    "Vornehmeren": "Vornehmere",
    "Vornehmsten": "Vornehmste",
    "Vorneigenden": "Vorneigende",
    "Vorneigens": "Vorneigen",
    "Vorordnenden": "Vorordnende",
    "Vorordnens": "Vorordnen",
    "Vorordnern": "Vorordner",
    "Vorordners": "Vorordner",
    "Vororte": "Vorort",
    "Vororten": "Vorort",
    "Vorortes": "Vorort",
    "Vororts": "Vorort",
    "Vorpommerns": "Vorpommern",
    "Vorpostens": "Vorposten",
    "Vorpreschenden": "Vorpreschende",
    "Vorpreschenderen": "Vorpreschendere",
    "Vorpreschendsten": "Vorpreschendste",
    "Vorpreschens": "Vorpreschen",
    "Vorprogramme": "Vorprogramm",
    "Vorprogrammen": "Vorprogramm",
    "Vorprogrammierenden": "Vorprogrammierende",
    "Vorprogrammierens": "Vorprogrammieren",
    "Vorprogrammierte": "vorprogrammiert",
    "Vorprogrammierten": "Vorprogrammierte",
    "Vorprogramms": "Vorprogramm",
    "Vorprüfungen": "Vorprüfung",
    "Vorquellenden": "Vorquellende",
    "Vorquellens": "Vorquellen",
    "Vorrange": "Vorrang",
    "Vorranges": "Vorrang",
    "Vorrangige": "vorrangig",
    "Vorrangigen": "Vorrangige",
    "Vorrangigeren": "Vorrangigere",
    "Vorrangigsten": "Vorrangigste",
    "Vorrangs": "Vorrang",
    "Vorrate": "Vorrat",
    "Vorrats": "Vorrat",
    "Vorraume": "Vorraum",
    "Vorraums": "Vorraum",
    "Vorrechnenden": "Vorrechnende",
    "Vorrechnens": "Vorrechnen",
    "Vorrechte": "Vorrecht",
    "Vorrechten": "Vorrecht",
    "Vorrechts": "Vorrecht",
    "Vorrede": "vorreden",
    "Vorreden": "Vorrede",
    "Vorredenden": "Vorredende",
    "Vorredens": "Vorreden",
    "Vorrednern": "Vorredner",
    "Vorredners": "Vorredner",
    "Vorreitenden": "Vorreitende",
    "Vorreitens": "Vorreiten",
    "Vorreitern": "Vorreiter",
    "Vorreiters": "Vorreiter",
    "Vorrennens": "Vorrennen",
    "Vorrichtenden": "Vorrichtende",
    "Vorrichtens": "Vorrichten",
    "Vorrichtungen": "Vorrichtung",
    "Vorrunden": "Vorrunde",
    "Vorränge": "Vorrang",
    "Vorrängen": "Vorrang",
    "Vorräte": "Vorrat",
    "Vorräten": "Vorrat",
    "Vorrätige": "vorrätig",
    "Vorrätigen": "Vorrätige",
    "Vorräume": "Vorraum",
    "Vorräumen": "Vorraum",
    "Vorrückenden": "Vorrückende",
    "Vorrückens": "Vorrücken",
    "Vorsagenden": "Vorsagende",
    "Vorsagens": "Vorsagen",
    "Vorsatze": "Vorsatz",
    "Vorsatzes": "Vorsatz",
    "Vorschauen": "Vorschau",
    "Vorschiebenden": "Vorschiebende",
    "Vorschiebens": "Vorschieben",
    "Vorschießenden": "Vorschießende",
    "Vorschießens": "Vorschießen",
    "Vorschlage": "vorschlagen",
    "Vorschlagenden": "Vorschlagende",
    "Vorschlagens": "Vorschlagen",
    "Vorschlages": "Vorschlag",
    "Vorschlags": "Vorschlag",
    "Vorschlußrunden": "Vorschlußrunde",
    "Vorschläge": "Vorschlag",
    "Vorschlägen": "Vorschlag",
    "Vorschneidenden": "Vorschneidende",
    "Vorschneidens": "Vorschneiden",
    "Vorschnellen": "Vorschnelle",
    "Vorschreibenden": "Vorschreibende",
    "Vorschreibens": "Vorschreiben",
    "Vorschreitenden": "Vorschreitende",
    "Vorschreitens": "Vorschreiten",
    "Vorschriften": "Vorschrift",
    "Vorschriftsgemäße": "vorschriftsgemäß",
    "Vorschriftsgemäßen": "Vorschriftsgemäße",
    "Vorschube": "Vorschub",
    "Vorschubes": "Vorschub",
    "Vorschubs": "Vorschub",
    "Vorschulen": "Vorschule",
    "Vorschwebenden": "Vorschwebende",
    "Vorschwebens": "Vorschweben",
    "Vorschwindelnden": "Vorschwindelnde",
    "Vorschwindelns": "Vorschwindeln",
    "Vorschwärmenden": "Vorschwärmende",
    "Vorschwärmens": "Vorschwärmen",
    "Vorschälern": "Vorschäler",
    "Vorschälers": "Vorschäler",
    "Vorschübe": "Vorschub",
    "Vorschüben": "Vorschub",
    "Vorschützenden": "Vorschützende",
    "Vorschützens": "Vorschützen",
    "Vorsehenden": "Vorsehende",
    "Vorsehens": "Vorsehen",
    "Vorsetzenden": "Vorsetzende",
    "Vorsetzens": "Vorsetzen",
    "Vorsichtigen": "Vorsichtige",
    "Vorsichtigeren": "Vorsichtigere",
    "Vorsichtigsten": "Vorsichtigste",
    "Vorsilben": "Vorsilbe",
    "Vorsingenden": "Vorsingende",
    "Vorsingens": "Vorsingen",
    "Vorsintflutlichen": "Vorsintflutliche",
    "Vorsitze": "vorsitzen",
    "Vorsitzen": "Vorsitz",
    "Vorsitzenden": "Vorsitzende",
    "Vorsitzens": "Vorsitzen",
    "Vorsitzes": "Vorsitz",
    "Vorsommern": "Vorsommer",
    "Vorsommers": "Vorsommer",
    "Vorsorge": "vorsorgen",
    "Vorsorgenden": "Vorsorgende",
    "Vorsorgenderen": "Vorsorgendere",
    "Vorsorgendsten": "Vorsorgendste",
    "Vorsorgens": "Vorsorgen",
    "Vorsorglichen": "Vorsorgliche",
    "Vorspanne": "vorspannen",
    "Vorspannen": "Vorspann",
    "Vorspannenden": "Vorspannende",
    "Vorspannens": "Vorspannen",
    "Vorspanns": "Vorspann",
    "Vorspeisen": "Vorspeise",
    "Vorspiegelnden": "Vorspiegelnde",
    "Vorspiegelns": "Vorspiegeln",
    "Vorspielenden": "Vorspielende",
    "Vorspielens": "Vorspielen",
    "Vorsprechenden": "Vorsprechende",
    "Vorsprechens": "Vorsprechen",
    "Vorspringenden": "Vorspringende",
    "Vorspringens": "Vorspringen",
    "Vorspruche": "Vorspruch",
    "Vorspruchs": "Vorspruch",
    "Vorsprunge": "Vorsprung",
    "Vorsprunges": "Vorsprung",
    "Vorsprungs": "Vorsprung",
    "Vorsprüche": "Vorspruch",
    "Vorsprüchen": "Vorspruch",
    "Vorsprünge": "Vorsprung",
    "Vorsprüngen": "Vorsprung",
    "Vorspulenden": "Vorspulende",
    "Vorspulens": "Vorspulen",
    "Vorstand": "vorstehen",
    "Vorstande": "Vorstand",
    "Vorstandes": "Vorstand",
    "Vorstands": "Vorstand",
    "Vorstehenden": "Vorstehende",
    "Vorstehenderen": "Vorstehendere",
    "Vorstehendsten": "Vorstehendste",
    "Vorstehens": "Vorstehen",
    "Vorstehern": "Vorsteher",
    "Vorstehers": "Vorsteher",
    "Vorstellbaren": "Vorstellbare",
    "Vorstellbareren": "Vorstellbarere",
    "Vorstellbarsten": "Vorstellbarste",
    "Vorstellenden": "Vorstellende",
    "Vorstellens": "Vorstellen",
    "Vorstellungen": "Vorstellung",
    "Vorstoße": "vorstoßen",
    "Vorstoßenden": "Vorstoßende",
    "Vorstoßens": "Vorstoßen",
    "Vorstoßes": "Vorstoß",
    "Vorstufen": "Vorstufe",
    "Vorstädte": "Vorstadt",
    "Vorstädten": "Vorstadt",
    "Vorstände": "Vorstand",
    "Vorständen": "Vorstand",
    "Vorstöße": "Vorstoß",
    "Vorstößen": "Vorstoß",
    "Vorstülpenden": "Vorstülpende",
    "Vorstülpens": "Vorstülpen",
    "Vorstürmenden": "Vorstürmende",
    "Vorstürmens": "Vorstürmen",
    "Vorsängern": "Vorsänger",
    "Vorsängers": "Vorsänger",
    "Vorsätze": "Vorsatz",
    "Vorsätzen": "Vorsatz",
    "Vorsätzliche": "vorsätzlich",
    "Vorsätzlichen": "Vorsätzliche",
    "Vortage": "Vortag",
    "Vortagen": "Vortag",
    "Vortags": "Vortag",
    "Vortanzenden": "Vortanzende",
    "Vortanzens": "Vortanzen",
    "Vorteile": "Vorteil",
    "Vorteilen": "Vorteil",
    "Vorteilhafte": "vorteilhaft",
    "Vorteilhaften": "Vorteilhafte",
    "Vorteilhafteren": "Vorteilhaftere",
    "Vorteilhaftesten": "Vorteilhafteste",
    "Vorteils": "Vorteil",
    "Vortrage": "vortragen",
    "Vortragenden": "Vortragende",
    "Vortragens": "Vortragen",
    "Vortrages": "Vortrag",
    "Vortrags": "Vortrag",
    "Vortrefflichen": "Vortreffliche",
    "Vortrefflicheren": "Vortrefflichere",
    "Vortrefflichsten": "Vortrefflichste",
    "Vortreibenden": "Vortreibende",
    "Vortreibens": "Vortreiben",
    "Vortretenden": "Vortretende",
    "Vortretens": "Vortreten",
    "Vortritts": "Vortritt",
    "Vorträge": "Vortrag",
    "Vorträgen": "Vortrag",
    "Vorturnenden": "Vorturnende",
    "Vorturnens": "Vorturnen",
    "Vortänzern": "Vortänzer",
    "Vortänzers": "Vortänzer",
    "Vortäuschenden": "Vortäuschende",
    "Vortäuschens": "Vortäuschen",
    "Vortäuschungen": "Vortäuschung",
    "Voruntersuchungen": "Voruntersuchung",
    "Vorurteile": "Vorurteil",
    "Vorurteilen": "Vorurteil",
    "Vorurteils": "Vorurteil",
    "Vorurteilsfreie": "vorurteilsfrei",
    "Vorurteilsfreien": "Vorurteilsfreie",
    "Vorverfahrens": "Vorverfahren",
    "Vorverhandlungen": "Vorverhandlung",
    "Vorverkaufs": "Vorverkauf",
    "Vorverlegenden": "Vorverlegende",
    "Vorverlegens": "Vorverlegen",
    "Vorverlegte": "vorverlegt",
    "Vorverlegten": "Vorverlegte",
    "Vorverstärkern": "Vorverstärker",
    "Vorverstärkers": "Vorverstärker",
    "Vorverurteilenden": "Vorverurteilende",
    "Vorverurteilens": "Vorverurteilen",
    "Vorverurteilte": "vorverurteilt",
    "Vorverurteilten": "Vorverurteilte",
    "Vorwagenden": "Vorwagende",
    "Vorwagens": "Vorwagen",
    "Vorwande": "Vorwand",
    "Vorwandes": "Vorwand",
    "Vorwands": "Vorwand",
    "Vorwarnenden": "Vorwarnende",
    "Vorwarnens": "Vorwarnen",
    "Vorweggenommenen": "Vorweggenommene",
    "Vorwegleistungen": "Vorwegleistung",
    "Vorwegnahmen": "vorwegnehmen",
    "Vorwegnehmenden": "Vorwegnehmende",
    "Vorwegnehmens": "Vorwegnehmen",
    "Vorweisenden": "Vorweisende",
    "Vorweisens": "Vorweisen",
    "Vorwerfenden": "Vorwerfende",
    "Vorwerfens": "Vorwerfen",
    "Vorwiegenden": "Vorwiegende",
    "Vorwiegenderen": "Vorwiegendere",
    "Vorwiegendsten": "Vorwiegendste",
    "Vorwiegens": "Vorwiegen",
    "Vorwintern": "Vorwinter",
    "Vorwinters": "Vorwinter",
    "Vorwissens": "Vorwissen",
    "Vorworte": "Vorwort",
    "Vorworten": "Vorwort",
    "Vorwortes": "Vorwort",
    "Vorworts": "Vorwort",
    "Vorwurfe": "Vorwurf",
    "Vorwurfes": "Vorwurf",
    "Vorwurfs": "Vorwurf",
    "Vorwurfsvolle": "vorwurfsvoll",
    "Vorwurfsvollen": "Vorwurfsvolle",
    "Vorwurfsvolleren": "Vorwurfsvollere",
    "Vorwurfsvollsten": "Vorwurfsvollste",
    "Vorwählenden": "Vorwählende",
    "Vorwählens": "Vorwählen",
    "Vorwände": "Vorwand",
    "Vorwänden": "Vorwand",
    "Vorwärmenden": "Vorwärmende",
    "Vorwärmenderen": "Vorwärmendere",
    "Vorwärmendsten": "Vorwärmendste",
    "Vorwärmens": "Vorwärmen",
    "Vorwärmern": "Vorwärmer",
    "Vorwärmers": "Vorwärmer",
    "Vorwärtsgegangenen": "Vorwärtsgegangene",
    "Vorwärtsgehenden": "Vorwärtsgehende",
    "Vorwärtsgehens": "Vorwärtsgehen",
    "Vorwärtsgekommenen": "Vorwärtsgekommene",
    "Vorwärtsgekommeneren": "Vorwärtsgekommenere",
    "Vorwärtsgeschrittenen": "Vorwärtsgeschrittene",
    "Vorwärtskommenden": "Vorwärtskommende",
    "Vorwärtskommenderen": "Vorwärtskommendere",
    "Vorwärtskommens": "Vorwärtskommen",
    "Vorwärtsschreitenden": "Vorwärtsschreitende",
    "Vorwärtsschreitens": "Vorwärtsschreiten",
    "Vorwölbenden": "Vorwölbende",
    "Vorwölbenderen": "Vorwölbendere",
    "Vorwölbendsten": "Vorwölbendste",
    "Vorwölbens": "Vorwölben",
    "Vorwürfe": "Vorwurf",
    "Vorwürfen": "Vorwurf",
    "Vorzaubernden": "Vorzaubernde",
    "Vorzauberns": "Vorzaubern",
    "Vorzeichnenden": "Vorzeichnende",
    "Vorzeichnens": "Vorzeichnen",
    "Vorzeigenden": "Vorzeigende",
    "Vorzeigens": "Vorzeigen",
    "Vorzeiten": "Vorzeit",
    "Vorzensuren": "Vorzensur",
    "Vorziehenden": "Vorziehende",
    "Vorziehens": "Vorziehen",
    "Vorzimmern": "Vorzimmer",
    "Vorzimmers": "Vorzimmer",
    "Vorzuge": "Vorzug",
    "Vorzugs": "Vorzug",
    "Vorzählenden": "Vorzählende",
    "Vorzählens": "Vorzählen",
    "Vorzüge": "Vorzug",
    "Vorzügen": "Vorzug",
    "Vorzügliche": "vorzüglich",
    "Vorzüglichen": "Vorzügliche",
    "Vorzüglicheren": "Vorzüglichere",
    "Vorzüglichsten": "Vorzüglichste",
    "Vorübergegangenen": "Vorübergegangene",
    "Vorübergehenden": "Vorübergehende",
    "Vorübergehens": "Vorübergehen",
    "Voscheraus": "Voscherau",
    "Votums": "Votum",
    "Vulkane": "Vulkan",
    "Vulkanen": "Vulkan",
    "Vulkans": "Vulkan",
    "Väter": "Vater",
    "Väterchens": "Väterchen",
    "Väterleins": "Väterlein",
    "Väterliche": "väterlich",
    "Väterlichen": "Väterliche",
    "Väterlicheren": "Väterlichere",
    "Väterlichsten": "Väterlichste",
    "Vätern": "Vater",
    "Vögel": "vögeln",
    "Vögeln": "Vogel",
    "Vögelnden": "Vögelnde",
    "Vögelns": "Vögeln",
    "Vögleins": "Vöglein",
    "Völkchens": "Völkchen",
    "Völker": "Volk",
    "Völkerbunds": "Völkerbund",
    "Völkerkundliche": "völkerkundlich",
    "Völkerkundlichen": "Völkerkundliche",
    "Völkern": "Volk",
    "Völkerrechtliche": "völkerrechtlich",
    "Völkerrechtlichen": "Völkerrechtliche",
    "Völkerschaften": "Völkerschaft",
    "Völlegefühle": "Völlegefühl",
    "Völlegefühlen": "Völlegefühl",
    "Völlegefühles": "Völlegefühl",
    "Völlegefühls": "Völlegefühl",
    "Völligen": "Völlige",
    "WCs": "WC",
    "WMs": "WM",
    "Waagen": "Waage",
    "Waagerechte": "waagerecht",
    "Waagerechten": "Waagerechte",
    "Wabbeligen": "Wabbelige",
    "Wabbeligeren": "Wabbeligere",
    "Wabbeligsten": "Wabbeligste",
    "Wabbelnden": "Wabbelnde",
    "Wabbelnderen": "Wabbelndere",
    "Wabbelndsten": "Wabbelndste",
    "Wabbelns": "Wabbeln",
    "Waben": "Wabe",
    "Wachboote": "Wachboot",
    "Wachbooten": "Wachboot",
    "Wachboots": "Wachboot",
    "Wachdienste": "Wachdienst",
    "Wachdiensten": "Wachdienst",
    "Wachdiensts": "Wachdienst",
    "Wache": "wachen",
    "Wachen": "Wache",
    "Wachenden": "Wachende",
    "Wachens": "Wachen",
    "Wachgehaltenen": "Wachgehaltene",
    "Wachgehalteneren": "Wachgehaltenere",
    "Wachgehaltensten": "Wachgehaltenste",
    "Wachgerufenen": "Wachgerufene",
    "Wachgerüttelten": "Wachgerüttelte",
    "Wachgerüttelteren": "Wachgerütteltere",
    "Wachhaltenden": "Wachhaltende",
    "Wachhaltenderen": "Wachhaltendere",
    "Wachhaltendsten": "Wachhaltendste",
    "Wachhaltens": "Wachhalten",
    "Wachhunde": "Wachhund",
    "Wachhunden": "Wachhund",
    "Wachhunds": "Wachhund",
    "Wachmanne": "Wachmann",
    "Wachmannes": "Wachmann",
    "Wachmanns": "Wachmann",
    "Wachmannschaften": "Wachmannschaft",
    "Wachmänner": "Wachmann",
    "Wachmännern": "Wachmann",
    "Wacholderbeeren": "Wacholderbeere",
    "Wacholdern": "Wacholder",
    "Wacholders": "Wacholder",
    "Wachpostens": "Wachposten",
    "Wachrufenden": "Wachrufende",
    "Wachrufens": "Wachrufen",
    "Wachrüttelnden": "Wachrüttelnde",
    "Wachrüttelnderen": "Wachrüttelndere",
    "Wachrüttelndsten": "Wachrüttelndste",
    "Wachrüttelns": "Wachrütteln",
    "Wachsamen": "Wachsame",
    "Wachsameren": "Wachsamere",
    "Wachsamsten": "Wachsamste",
    "Wachsenden": "Wachsende",
    "Wachsens": "Wachsen",
    "Wachstums": "Wachstum",
    "Wachters": "Wachter",
    "Wachturme": "Wachturm",
    "Wachturmes": "Wachturm",
    "Wachturms": "Wachturm",
    "Wachtürme": "Wachturm",
    "Wachtürmen": "Wachturm",
    "Wackeren": "Wackere",
    "Wackereren": "Wackerere",
    "Wackersdorfs": "Wackersdorf",
    "Wackerste": "wacker",
    "Wackersten": "Wackerste",
    "Wackligen": "Wacklige",
    "Wackligeren": "Wackligere",
    "Wackligsten": "Wackligste",
    "Waden": "Wade",
    "Wadenbeine": "Wadenbein",
    "Wadenbeinen": "Wadenbein",
    "Wadenbeins": "Wadenbein",
    "Waffeln": "Waffel",
    "Waffen": "Waffe",
    "Waffnenden": "Waffnende",
    "Waffnens": "Waffnen",
    "Wagemute": "Wagemut",
    "Wagemutes": "Wagemut",
    "Wagemutige": "wagemutig",
    "Wagemutigen": "Wagemutige",
    "Wagemutigeren": "Wagemutigere",
    "Wagemutigsten": "Wagemutigste",
    "Wagemuts": "Wagemut",
    "Wagenden": "Wagende",
    "Wagenhebern": "Wagenheber",
    "Wagenhebers": "Wagenheber",
    "Wagens": "Wagen",
    "Waggons": "Waggon",
    "Waghalsige": "waghalsig",
    "Waghalsigen": "Waghalsige",
    "Waghalsigeren": "Waghalsigere",
    "Waghalsigsten": "Waghalsigste",
    "Wagners": "Wagner",
    "Wahlberechtigten": "Wahlberechtigte",
    "Wahlen": "Wahl",
    "Wahlfreien": "Wahlfreie",
    "Wahllosen": "Wahllose",
    "Wahlloseren": "Wahllosere",
    "Wahllosesten": "Wahlloseste",
    "Wahnsinnigen": "Wahnsinnige",
    "Wahnsinnigeren": "Wahnsinnigere",
    "Wahnsinnigsten": "Wahnsinnigste",
    "Wahnsinns": "Wahnsinn",
    "Wahnwitzigen": "Wahnwitzige",
    "Wahnwitzigeren": "Wahnwitzigere",
    "Wahnwitzigsten": "Wahnwitzigste",
    "Wahre": "wahren",
    "Wahren": "Wahre",
    "Wahrenden": "Wahrende",
    "Wahrens": "Wahren",
    "Wahrgenommenen": "Wahrgenommene",
    "Wahrgesagten": "Wahrgesagte",
    "Wahrhaften": "Wahrhafte",
    "Wahrhafteren": "Wahrhaftere",
    "Wahrhaftesten": "Wahrhafteste",
    "Wahrhaftigen": "Wahrhaftige",
    "Wahrhaftigeren": "Wahrhaftigere",
    "Wahrhaftigsten": "Wahrhaftigste",
    "Wahrheiten": "Wahrheit",
    "Wahrheitsgemäße": "wahrheitsgemäß",
    "Wahrheitsgemäßen": "Wahrheitsgemäße",
    "Wahrheitsliebenden": "Wahrheitsliebende",
    "Wahrnehmbaren": "Wahrnehmbare",
    "Wahrnehmenden": "Wahrnehmende",
    "Wahrnehmens": "Wahrnehmen",
    "Wahrnehmungen": "Wahrnehmung",
    "Wahrsagenden": "Wahrsagende",
    "Wahrsagens": "Wahrsagen",
    "Wahrsagern": "Wahrsager",
    "Wahrsagers": "Wahrsager",
    "Wahrscheinlichkeiten": "Wahrscheinlichkeit",
    "Waigels": "Waigel",
    "Waisen": "Waise",
    "Waisenknaben": "Waisenknabe",
    "Walde": "Wald",
    "Waldes": "Wald",
    "Waldhütern": "Waldhüter",
    "Waldhüters": "Waldhüter",
    "Waldnymphen": "Waldnymphe",
    "Waldorfschulen": "Waldorfschule",
    "Walds": "Wald",
    "Waldschrate": "Waldschrat",
    "Waldschraten": "Waldschrat",
    "Waldschrats": "Waldschrat",
    "Wale": "Wal",
    "Walen": "Wal",
    "Wales": "Wal",
    "Walesas": "Walesa",
    "Walisern": "Waliser",
    "Walisers": "Waliser",
    "Walisische": "walisisch",
    "Walisischen": "Walisische",
    "Wallache": "Wallach",
    "Wallachen": "Wallach",
    "Wallaches": "Wallach",
    "Wallachs": "Wallach",
    "Wallauern": "Wallauer",
    "Wallauers": "Wallauer",
    "Wallaus": "Wallau",
    "Walldorfern": "Walldorfer",
    "Walldorfers": "Walldorfer",
    "Walldorfs": "Walldorf",
    "Wallenden": "Wallende",
    "Wallens": "Wallen",
    "Wallmanns": "Wallmann",
    "Walpurgisnächte": "Walpurgisnacht",
    "Walpurgisnächten": "Walpurgisnacht",
    "Wals": "Wal",
    "Waltenden": "Waltende",
    "Waltens": "Walten",
    "Walters": "Walter",
    "Waltrauds": "Waltraud",
    "Walze": "walzen",
    "Walzen": "Walze",
    "Walzenden": "Walzende",
    "Walzenderen": "Walzendere",
    "Walzendsten": "Walzendste",
    "Walzens": "Walzen",
    "Walzern": "Walzer",
    "Walzers": "Walzer",
    "Wandel": "wandeln",
    "Wandeln": "Wandel",
    "Wandelnden": "Wandelnde",
    "Wandelnderen": "Wandelndere",
    "Wandelndsten": "Wandelndste",
    "Wandelns": "Wandeln",
    "Wandels": "Wandel",
    "Wanderdünen": "Wanderdüne",
    "Wanderern": "Wanderer",
    "Wanderers": "Wanderer",
    "Wanderführern": "Wanderführer",
    "Wanderführers": "Wanderführer",
    "Wanderhirten": "Wanderhirt",
    "Wanderinnen": "Wanderin",
    "Wanderkarten": "Wanderkarte",
    "Wanderlebern": "Wanderleber",
    "Wanderliede": "Wanderlied",
    "Wanderlieder": "Wanderlied",
    "Wanderliedern": "Wanderlied",
    "Wanderliedes": "Wanderlied",
    "Wanderlieds": "Wanderlied",
    "Wandermuscheln": "Wandermuschel",
    "Wandernden": "Wandernde",
    "Wandernieren": "Wanderniere",
    "Wanderns": "Wandern",
    "Wanderratten": "Wanderratte",
    "Wanderungen": "Wanderung",
    "Wanderwege": "Wanderweg",
    "Wanderwegen": "Wanderweg",
    "Wanderweges": "Wanderweg",
    "Wanderwegs": "Wanderweg",
    "Wandlern": "Wandler",
    "Wandlers": "Wandler",
    "Wandlungen": "Wandlung",
    "Wandlungsfähige": "wandlungsfähig",
    "Wandlungsfähigen": "Wandlungsfähige",
    "Wandlungsfähigeren": "Wandlungsfähigere",
    "Wandrerinnen": "Wandrerin",
    "Wangen": "Wange",
    "Wankelmotore": "Wankelmotor",
    "Wankelmotoren": "Wankelmotor",
    "Wankelmotors": "Wankelmotor",
    "Wankelmute": "Wankelmut",
    "Wankelmutes": "Wankelmut",
    "Wankelmuts": "Wankelmut",
    "Wankelmütige": "wankelmütig",
    "Wankelmütigen": "Wankelmütige",
    "Wankelmütigeren": "Wankelmütigere",
    "Wankelmütigsten": "Wankelmütigste",
    "Wankenden": "Wankende",
    "Wankenderen": "Wankendere",
    "Wankendsten": "Wankendste",
    "Wankens": "Wanken",
    "Wannen": "Wanne",
    "Wanzen": "Wanze",
    "Wappens": "Wappen",
    "Wappnenden": "Wappnende",
    "Wappnens": "Wappnen",
    "Waren": "Ware",
    "Warenkundlichen": "Warenkundliche",
    "Warmbiere": "Warmbier",
    "Warmbieren": "Warmbier",
    "Warmbiers": "Warmbier",
    "Warmblute": "Warmblut",
    "Warmblutes": "Warmblut",
    "Warmbluts": "Warmblut",
    "Warmblütern": "Warmblüter",
    "Warmblüters": "Warmblüter",
    "Warmblütige": "warmblütig",
    "Warmblütigen": "Warmblütige",
    "Warme": "warm",
    "Warmen": "Warme",
    "Warmgehaltenen": "Warmgehaltene",
    "Warmgehalteneren": "Warmgehaltenere",
    "Warmgehaltensten": "Warmgehaltenste",
    "Warmhaltenden": "Warmhaltende",
    "Warmhaltenderen": "Warmhaltendere",
    "Warmhaltendsten": "Warmhaltendste",
    "Warmhaltens": "Warmhalten",
    "Warmherzigen": "Warmherzige",
    "Warmherzigeren": "Warmherzigere",
    "Warmherzigsten": "Warmherzigste",
    "Warnanlagen": "Warnanlage",
    "Warnenden": "Warnende",
    "Warnens": "Warnen",
    "Warnstreiks": "Warnstreik",
    "Warnungen": "Warnung",
    "Warschauern": "Warschauer",
    "Warschauers": "Warschauer",
    "Warschaus": "Warschau",
    "Wartegelde": "Wartegeld",
    "Wartegelder": "Wartegeld",
    "Wartegeldern": "Wartegeld",
    "Wartegeldes": "Wartegeld",
    "Wartegelds": "Wartegeld",
    "Warten": "Warte",
    "Wartenden": "Wartende",
    "Wartens": "Warten",
    "Warteraume": "Warteraum",
    "Warteraumes": "Warteraum",
    "Warteraums": "Warteraum",
    "Warteräume": "Warteraum",
    "Warteräumen": "Warteraum",
    "Warteschlangen": "Warteschlange",
    "Wartezeiten": "Wartezeit",
    "Wartezimmern": "Wartezimmer",
    "Wartezimmers": "Wartezimmer",
    "Warts": "Wart",
    "Wartungsfreie": "wartungsfrei",
    "Wartungsfreien": "Wartungsfreie",
    "Warzen": "Warze",
    "Warägern": "Waräger",
    "Warägers": "Waräger",
    "Waschanlagen": "Waschanlage",
    "Waschbare": "waschbar",
    "Waschbaren": "Waschbare",
    "Waschbeckens": "Waschbecken",
    "Waschbetons": "Waschbeton",
    "Waschbrette": "Waschbrett",
    "Waschbretter": "Waschbrett",
    "Waschbrettern": "Waschbrett",
    "Waschbrettes": "Waschbrett",
    "Waschbretts": "Waschbrett",
    "Waschbären": "Waschbär",
    "Waschechten": "Waschechte",
    "Waschenden": "Waschende",
    "Waschens": "Waschen",
    "Waschfrauen": "Waschfrau",
    "Waschkauen": "Waschkaue",
    "Waschkesseln": "Waschkessel",
    "Waschkessels": "Waschkessel",
    "Waschküchen": "Waschküche",
    "Waschmaschinen": "Waschmaschine",
    "Waschmitteln": "Waschmittel",
    "Waschmittels": "Waschmittel",
    "Waschpulvern": "Waschpulver",
    "Waschpulvers": "Waschpulver",
    "Waschsalons": "Waschsalon",
    "Waschseifen": "Waschseife",
    "Waschstraßen": "Waschstraße",
    "Waschtage": "Waschtag",
    "Waschtagen": "Waschtag",
    "Waschtags": "Waschtag",
    "Waschtische": "Waschtisch",
    "Waschtischen": "Waschtisch",
    "Waschtischs": "Waschtisch",
    "Washingtons": "Washington",
    "Wasserdichte": "wasserdicht",
    "Wasserdichten": "Wasserdichte",
    "Wasserdichteren": "Wasserdichtere",
    "Wasserdichtesten": "Wasserdichteste",
    "Wasserfesten": "Wasserfeste",
    "Wasserfesteren": "Wasserfestere",
    "Wasserfestesten": "Wasserfesteste",
    "Wasserlöslichen": "Wasserlösliche",
    "Wasserlöslicheren": "Wasserlöslichere",
    "Wasserlöslichsten": "Wasserlöslichste",
    "Wassern": "Wasser",
    "Wassernymphen": "Wassernymphe",
    "Wassers": "Wasser",
    "Wasserscheue": "wasserscheu",
    "Wasserscheuen": "Wasserscheue",
    "Wasserscheueren": "Wasserscheuere",
    "Wasserscheusten": "Wasserscheuste",
    "Wassersparenden": "Wassersparende",
    "Watenden": "Watende",
    "Watenderen": "Watendere",
    "Watendsten": "Watendste",
    "Watens": "Waten",
    "Watschelnden": "Watschelnde",
    "Watschelnderen": "Watschelndere",
    "Watschelndsten": "Watschelndste",
    "Watschelns": "Watscheln",
    "Watte": "Watt",
    "Watten": "Watte",
    "Wattenscheids": "Wattenscheid",
    "Watts": "Watt",
    "Waynes": "Wayne",
    "Webenden": "Webende",
    "Webens": "Weben",
    "Webereien": "Weberei",
    "Webers": "Weber",
    "Wechsel": "wechseln",
    "Wechseln": "Wechsel",
    "Wechselnden": "Wechselnde",
    "Wechselns": "Wechseln",
    "Wechsels": "Wechsel",
    "Weckenden": "Weckende",
    "Weckens": "Wecken",
    "Weckern": "Wecker",
    "Weckers": "Wecker",
    "Weckrufe": "Weckruf",
    "Weckrufen": "Weckruf",
    "Weckrufs": "Weckruf",
    "Weddings": "Wedding",
    "Wedelnden": "Wedelnde",
    "Wedelnderen": "Wedelndere",
    "Wedelndsten": "Wedelndste",
    "Wedelns": "Wedeln",
    "Wedemeiers": "Wedemeier",
    "Wegbekommenden": "Wegbekommende",
    "Wegbekommenen": "Wegbekommene",
    "Wegbekommens": "Wegbekommen",
    "Wegblasenden": "Wegblasende",
    "Wegblasens": "Wegblasen",
    "Wegbleibenden": "Wegbleibende",
    "Wegbleibens": "Wegbleiben",
    "Wegblickenden": "Wegblickende",
    "Wegblickenderen": "Wegblickendere",
    "Wegblickendsten": "Wegblickendste",
    "Wegblickens": "Wegblicken",
    "Wegbrennenden": "Wegbrennende",
    "Wegbrennens": "Wegbrennen",
    "Wegbringenden": "Wegbringende",
    "Wegbringens": "Wegbringen",
    "Wegdenkenden": "Wegdenkende",
    "Wegdenkens": "Wegdenken",
    "Wegdrückenden": "Wegdrückende",
    "Wegdrückens": "Wegdrücken",
    "Wege": "Weg",
    "Wegen": "Weg",
    "Weges": "Weg",
    "Wegessenden": "Wegessende",
    "Wegessens": "Wegessen",
    "Wegfahrenden": "Wegfahrende",
    "Wegfahrens": "Wegfahren",
    "Wegfallenden": "Wegfallende",
    "Wegfallens": "Wegfallen",
    "Wegfalls": "Wegfall",
    "Wegfangenden": "Wegfangende",
    "Wegfangens": "Wegfangen",
    "Wegfegenden": "Wegfegende",
    "Wegfegens": "Wegfegen",
    "Wegfliegenden": "Wegfliegende",
    "Wegfliegens": "Wegfliegen",
    "Wegfließenden": "Wegfließende",
    "Wegfließens": "Wegfließen",
    "Wegfressenden": "Wegfressende",
    "Wegfressens": "Wegfressen",
    "Wegführenden": "Wegführende",
    "Wegführenderen": "Wegführendere",
    "Wegführendsten": "Wegführendste",
    "Wegführens": "Wegführen",
    "Weggebenden": "Weggebende",
    "Weggebens": "Weggeben",
    "Weggeblasenen": "Weggeblasene",
    "Weggeblickten": "Weggeblickte",
    "Weggebliebenen": "Weggebliebene",
    "Weggebrachten": "Weggebrachte",
    "Weggebrannten": "Weggebrannte",
    "Weggedachten": "Weggedachte",
    "Weggedrückten": "Weggedrückte",
    "Weggefahrenen": "Weggefahrene",
    "Weggefallenen": "Weggefallene",
    "Weggefangenen": "Weggefangene",
    "Weggefegten": "Weggefegte",
    "Weggeflogenen": "Weggeflogene",
    "Weggeflossenen": "Weggeflossene",
    "Weggefressenen": "Weggefressene",
    "Weggefährten": "Weggefährte",
    "Weggeführten": "Weggeführte",
    "Weggegangenen": "Weggegangene",
    "Weggegebenen": "Weggegebene",
    "Weggegessenen": "Weggegessene",
    "Weggehaltenen": "Weggehaltene",
    "Weggehenden": "Weggehende",
    "Weggehens": "Weggehen",
    "Weggehobenen": "Weggehobene",
    "Weggeholten": "Weggeholte",
    "Weggehängten": "Weggehängte",
    "Weggejagten": "Weggejagte",
    "Weggekehrten": "Weggekehrte",
    "Weggekommenen": "Weggekommene",
    "Weggekratzten": "Weggekratzte",
    "Weggelassenen": "Weggelassene",
    "Weggelaufenen": "Weggelaufene",
    "Weggelegten": "Weggelegte",
    "Weggemachten": "Weggemachte",
    "Weggenommenen": "Weggenommene",
    "Weggerafften": "Weggeraffte",
    "Weggerannten": "Weggerannte",
    "Weggerissenen": "Weggerissene",
    "Weggerollten": "Weggerollte",
    "Weggerufenen": "Weggerufene",
    "Weggeräumten": "Weggeräumte",
    "Weggeschafften": "Weggeschaffte",
    "Weggeschaufelten": "Weggeschaufelte",
    "Weggeschauten": "Weggeschaute",
    "Weggeschenkten": "Weggeschenkte",
    "Weggescherten": "Weggescherte",
    "Weggeschickten": "Weggeschickte",
    "Weggeschlichenen": "Weggeschlichene",
    "Weggeschlossenen": "Weggeschlossene",
    "Weggeschmissenen": "Weggeschmissene",
    "Weggeschmisseneren": "Weggeschmissenere",
    "Weggeschmolzenen": "Weggeschmolzene",
    "Weggeschmolzeneren": "Weggeschmolzenere",
    "Weggeschnappten": "Weggeschnappte",
    "Weggeschnittenen": "Weggeschnittene",
    "Weggeschobenen": "Weggeschobene",
    "Weggeschorenen": "Weggeschorene",
    "Weggeschütteten": "Weggeschüttete",
    "Weggesehenen": "Weggesehene",
    "Weggesetzten": "Weggesetzte",
    "Weggesoffenen": "Weggesoffene",
    "Weggespielten": "Weggespielte",
    "Weggesprengten": "Weggesprengte",
    "Weggespülten": "Weggespülte",
    "Weggesteckten": "Weggesteckte",
    "Weggestohlenen": "Weggestohlene",
    "Weggestohleneren": "Weggestohlenere",
    "Weggestohlensten": "Weggestohlenste",
    "Weggestorbenen": "Weggestorbene",
    "Weggestoßenen": "Weggestoßene",
    "Weggestrichenen": "Weggestrichene",
    "Weggetauchten": "Weggetauchte",
    "Weggetragenen": "Weggetragene",
    "Weggetretenen": "Weggetretene",
    "Weggetriebenen": "Weggetriebene",
    "Weggewandten": "Weggewandte",
    "Weggewendeten": "Weggewendete",
    "Weggewischten": "Weggewischte",
    "Weggeworfenen": "Weggeworfene",
    "Weggezauberten": "Weggezauberte",
    "Weggezogenen": "Weggezogene",
    "Weghaltenden": "Weghaltende",
    "Weghaltens": "Weghalten",
    "Weghebenden": "Weghebende",
    "Weghebens": "Wegheben",
    "Wegholenden": "Wegholende",
    "Wegholens": "Wegholen",
    "Weghängenden": "Weghängende",
    "Weghängens": "Weghängen",
    "Wegjagenden": "Wegjagende",
    "Wegjagens": "Wegjagen",
    "Wegkehrenden": "Wegkehrende",
    "Wegkehrens": "Wegkehren",
    "Wegkommenden": "Wegkommende",
    "Wegkommens": "Wegkommen",
    "Wegkratzenden": "Wegkratzende",
    "Wegkratzens": "Wegkratzen",
    "Weglassenden": "Weglassende",
    "Weglassens": "Weglassen",
    "Weglaufenden": "Weglaufende",
    "Weglaufens": "Weglaufen",
    "Weglegenden": "Weglegende",
    "Weglegens": "Weglegen",
    "Wegmachenden": "Wegmachende",
    "Wegmachens": "Wegmachen",
    "Wegnehmenden": "Wegnehmende",
    "Wegnehmens": "Wegnehmen",
    "Wegradierenden": "Wegradierende",
    "Wegradierens": "Wegradieren",
    "Wegradierte": "wegradiert",
    "Wegradierten": "Wegradierte",
    "Wegraffenden": "Wegraffende",
    "Wegraffens": "Wegraffen",
    "Wegreißenden": "Wegreißende",
    "Wegreißens": "Wegreißen",
    "Wegrennenden": "Wegrennende",
    "Wegrennens": "Wegrennen",
    "Wegrollenden": "Wegrollende",
    "Wegrollens": "Wegrollen",
    "Wegrufenden": "Wegrufende",
    "Wegrufens": "Wegrufen",
    "Wegräumenden": "Wegräumende",
    "Wegräumens": "Wegräumen",
    "Wegs": "Weg",
    "Wegsaufenden": "Wegsaufende",
    "Wegsaufens": "Wegsaufen",
    "Wegschaffenden": "Wegschaffende",
    "Wegschaffens": "Wegschaffen",
    "Wegschauenden": "Wegschauende",
    "Wegschauens": "Wegschauen",
    "Wegschaufelnden": "Wegschaufelnde",
    "Wegschaufelns": "Wegschaufeln",
    "Wegschenkenden": "Wegschenkende",
    "Wegschenkens": "Wegschenken",
    "Wegscherenden": "Wegscherende",
    "Wegscherens": "Wegscheren",
    "Wegschickenden": "Wegschickende",
    "Wegschickens": "Wegschicken",
    "Wegschiebenden": "Wegschiebende",
    "Wegschiebens": "Wegschieben",
    "Wegschleichenden": "Wegschleichende",
    "Wegschleichens": "Wegschleichen",
    "Wegschließenden": "Wegschließende",
    "Wegschließens": "Wegschließen",
    "Wegschmeißenden": "Wegschmeißende",
    "Wegschmeißens": "Wegschmeißen",
    "Wegschmelzenden": "Wegschmelzende",
    "Wegschmelzenderen": "Wegschmelzendere",
    "Wegschmelzendsten": "Wegschmelzendste",
    "Wegschmelzens": "Wegschmelzen",
    "Wegschnappenden": "Wegschnappende",
    "Wegschnappens": "Wegschnappen",
    "Wegschneidenden": "Wegschneidende",
    "Wegschneidens": "Wegschneiden",
    "Wegschüttenden": "Wegschüttende",
    "Wegschüttens": "Wegschütten",
    "Wegsehenden": "Wegsehende",
    "Wegsehens": "Wegsehen",
    "Wegsetzenden": "Wegsetzende",
    "Wegsetzens": "Wegsetzen",
    "Wegspielenden": "Wegspielende",
    "Wegspielens": "Wegspielen",
    "Wegsprengenden": "Wegsprengende",
    "Wegsprengens": "Wegsprengen",
    "Wegspülenden": "Wegspülende",
    "Wegspülens": "Wegspülen",
    "Wegsteckenden": "Wegsteckende",
    "Wegsteckens": "Wegstecken",
    "Wegstehlenden": "Wegstehlende",
    "Wegstehlenderen": "Wegstehlendere",
    "Wegstehlendsten": "Wegstehlendste",
    "Wegstehlens": "Wegstehlen",
    "Wegsterbenden": "Wegsterbende",
    "Wegsterbens": "Wegsterben",
    "Wegstoßenden": "Wegstoßende",
    "Wegstoßens": "Wegstoßen",
    "Wegstreichenden": "Wegstreichende",
    "Wegstreichens": "Wegstreichen",
    "Wegtauchenden": "Wegtauchende",
    "Wegtauchens": "Wegtauchen",
    "Wegtragenden": "Wegtragende",
    "Wegtragens": "Wegtragen",
    "Wegtreibenden": "Wegtreibende",
    "Wegtreibens": "Wegtreiben",
    "Wegtretenden": "Wegtretende",
    "Wegtretens": "Wegtreten",
    "Wegweisenden": "Wegweisende",
    "Wegweisern": "Wegweiser",
    "Wegweisers": "Wegweiser",
    "Wegwendenden": "Wegwendende",
    "Wegwendens": "Wegwenden",
    "Wegwerfenden": "Wegwerfende",
    "Wegwerfens": "Wegwerfen",
    "Wegwerfgesellschaften": "Wegwerfgesellschaft",
    "Wegwischenden": "Wegwischende",
    "Wegwischens": "Wegwischen",
    "Wegzaubernden": "Wegzaubernde",
    "Wegzauberns": "Wegzaubern",
    "Wegziehenden": "Wegziehende",
    "Wegziehens": "Wegziehen",
    "Weh": "wehen",
    "Wehe": "wehen",
    "Wehen": "Wehe",
    "Wehenden": "Wehende",
    "Wehens": "Wehen",
    "Wehes": "Weh",
    "Wehgeschreis": "Wehgeschrei",
    "Wehklagen": "Wehklage",
    "Wehleidige": "wehleidig",
    "Wehleidigen": "Wehleidige",
    "Wehleidigeren": "Wehleidigere",
    "Wehleidigsten": "Wehleidigste",
    "Wehmutsvollen": "Wehmutsvolle",
    "Wehmutsvolleren": "Wehmutsvollere",
    "Wehmutsvollsten": "Wehmutsvollste",
    "Wehmütigen": "Wehmütige",
    "Wehmütigeren": "Wehmütigere",
    "Wehmütigsten": "Wehmütigste",
    "Wehr": "wehren",
    "Wehrdienstpflichtige": "wehrdienstpflichtig",
    "Wehrdienstpflichtigen": "Wehrdienstpflichtige",
    "Wehren": "Wehr",
    "Wehrenden": "Wehrende",
    "Wehrenderen": "Wehrendere",
    "Wehrendsten": "Wehrendste",
    "Wehrens": "Wehren",
    "Wehrheimern": "Wehrheimer",
    "Wehrheimers": "Wehrheimer",
    "Wehrlose": "wehrlos",
    "Wehrlosen": "Wehrlose",
    "Wehrloseren": "Wehrlosere",
    "Wehrlosesten": "Wehrloseste",
    "Wehrpflichtigen": "Wehrpflichtige",
    "Wehs": "Weh",
    "Weibchens": "Weibchen",
    "Weibe": "Weib",
    "Weiber": "Weib",
    "Weibern": "Weib",
    "Weibes": "Weib",
    "Weibische": "weibisch",
    "Weibischen": "Weibische",
    "Weibischeren": "Weibischere",
    "Weibischsten": "Weibischste",
    "Weibleins": "Weiblein",
    "Weibliche": "weiblich",
    "Weiblichen": "Weibliche",
    "Weiblicheren": "Weiblichere",
    "Weiblichsten": "Weiblichste",
    "Weiche": "weichen",
    "Weichen": "Weiche",
    "Weichenden": "Weichende",
    "Weichens": "Weichen",
    "Weichenstellern": "Weichensteller",
    "Weichenstellers": "Weichensteller",
    "Weicheren": "Weichere",
    "Weicherts": "Weichert",
    "Weichgekochten": "Weichgekochte",
    "Weichnachten": "Weihnacht",
    "Weichspülern": "Weichspüler",
    "Weichspülers": "Weichspüler",
    "Weichsten": "Weichste",
    "Weiden": "Weide",
    "Weidenden": "Weidende",
    "Weidenderen": "Weidendere",
    "Weidendsten": "Weidendste",
    "Weidens": "Weiden",
    "Weidmännischen": "Weidmännische",
    "Weigernden": "Weigernde",
    "Weigernderen": "Weigerndere",
    "Weigerndsten": "Weigerndste",
    "Weigerns": "Weigern",
    "Weigerungen": "Weigerung",
    "Weihe": "weihen",
    "Weihen": "Weihe",
    "Weihenden": "Weihende",
    "Weihenderen": "Weihendere",
    "Weihendsten": "Weihendste",
    "Weihens": "Weihen",
    "Weihern": "Weiher",
    "Weihers": "Weiher",
    "Weihnachtenden": "Weihnachtende",
    "Weihnachtens": "Weihnachten",
    "Weihnachtlichen": "Weihnachtliche",
    "Weihnachtsgänse": "Weihnachtsgans",
    "Weihnachtsgänsen": "Weihnachtsgans",
    "Weihrauchs": "Weihrauch",
    "Weihwassers": "Weihwasser",
    "Weilbachs": "Weilbach",
    "Weilburgs": "Weilburg",
    "Weile": "weilen",
    "Weilenden": "Weilende",
    "Weilens": "Weilen",
    "Weimarern": "Weimarer",
    "Weimarers": "Weimarer",
    "Weimars": "Weimar",
    "Wein": "weinen",
    "Weinbaus": "Weinbau",
    "Weinbauten": "Weinbau",
    "Weine": "weinen",
    "Weinen": "Wein",
    "Weinenden": "Weinende",
    "Weinenderen": "Weinendere",
    "Weinendsten": "Weinendste",
    "Weinens": "Weinen",
    "Weinerliche": "weinerlich",
    "Weinerlichen": "Weinerliche",
    "Weinerlicheren": "Weinerlichere",
    "Weinerlichsten": "Weinerlichste",
    "Weines": "Wein",
    "Weins": "Wein",
    "Weisenden": "Weisende",
    "Weisens": "Weisen",
    "Weiser": "weise",
    "Weiseren": "Weisere",
    "Weisers": "Weiser",
    "Weisesten": "Weiseste",
    "Weisgesagten": "Weisgesagte",
    "Weisheiten": "Weisheit",
    "Weiskirchens": "Weiskirchen",
    "Weissagenden": "Weissagende",
    "Weissagens": "Weissagen",
    "Weissagungen": "Weissagung",
    "Weisungen": "Weisung",
    "Weisungsgebundene": "weisungsgebunden",
    "Weisungsgebundenen": "Weisungsgebundene",
    "Weisungsgemäßen": "Weisungsgemäße",
    "Weite": "weiten",
    "Weiten": "Weite",
    "Weitenden": "Weitende",
    "Weitenderen": "Weitendere",
    "Weitendsten": "Weitendste",
    "Weitens": "Weiten",
    "Weiterarbeitenden": "Weiterarbeitende",
    "Weiterarbeitens": "Weiterarbeiten",
    "Weiterbestandenen": "Weiterbestandene",
    "Weiterbestehenden": "Weiterbestehende",
    "Weiterbestehens": "Weiterbestehen",
    "Weiterbildenden": "Weiterbildende",
    "Weiterbildens": "Weiterbilden",
    "Weiterbildungen": "Weiterbildung",
    "Weiterbringenden": "Weiterbringende",
    "Weiterbringens": "Weiterbringen",
    "Weiterdenkenden": "Weiterdenkende",
    "Weiterdenkens": "Weiterdenken",
    "Weiterempfehlenden": "Weiterempfehlende",
    "Weiterempfehlens": "Weiterempfehlen",
    "Weiterempfohlenen": "Weiterempfohlene",
    "Weiteren": "Weitere",
    "Weiterentwickelnden": "Weiterentwickelnde",
    "Weiterentwickelns": "Weiterentwickeln",
    "Weiterentwickelte": "weiterentwickelt",
    "Weiterentwickelten": "Weiterentwickelte",
    "Weiterentwickelteren": "Weiterentwickeltere",
    "Weitererzählenden": "Weitererzählende",
    "Weitererzählens": "Weitererzählen",
    "Weitererzählte": "weitererzählt",
    "Weitererzählten": "Weitererzählte",
    "Weiterfahrenden": "Weiterfahrende",
    "Weiterfahrens": "Weiterfahren",
    "Weiterfliegenden": "Weiterfliegende",
    "Weiterfliegens": "Weiterfliegen",
    "Weiterführenden": "Weiterführende",
    "Weiterführens": "Weiterführen",
    "Weitergearbeiteten": "Weitergearbeitete",
    "Weitergebenden": "Weitergebende",
    "Weitergebens": "Weitergeben",
    "Weitergebildeten": "Weitergebildete",
    "Weitergebildeteren": "Weitergebildetere",
    "Weitergebrachten": "Weitergebrachte",
    "Weitergedachten": "Weitergedachte",
    "Weitergefahrenen": "Weitergefahrene",
    "Weitergeflogenen": "Weitergeflogene",
    "Weitergeführten": "Weitergeführte",
    "Weitergegangenen": "Weitergegangene",
    "Weitergegebenen": "Weitergegebene",
    "Weitergehenden": "Weitergehende",
    "Weitergehens": "Weitergehen",
    "Weitergeholfenen": "Weitergeholfene",
    "Weitergekommenen": "Weitergekommene",
    "Weitergekommeneren": "Weitergekommenere",
    "Weitergelaufenen": "Weitergelaufene",
    "Weitergeleiteten": "Weitergeleitete",
    "Weitergemachten": "Weitergemachte",
    "Weitergereisten": "Weitergereiste",
    "Weitergesagten": "Weitergesagte",
    "Weitergesponnenen": "Weitergesponnene",
    "Weitergetragenen": "Weitergetragene",
    "Weitergetrageneren": "Weitergetragenere",
    "Weiterhelfenden": "Weiterhelfende",
    "Weiterhelfens": "Weiterhelfen",
    "Weiterkommenden": "Weiterkommende",
    "Weiterkommenderen": "Weiterkommendere",
    "Weiterkommendsten": "Weiterkommendste",
    "Weiterkommens": "Weiterkommen",
    "Weiterlaufenden": "Weiterlaufende",
    "Weiterlaufens": "Weiterlaufen",
    "Weiterleitenden": "Weiterleitende",
    "Weiterleitens": "Weiterleiten",
    "Weitermachenden": "Weitermachende",
    "Weitermachens": "Weitermachen",
    "Weitermarschierenden": "Weitermarschierende",
    "Weitermarschierens": "Weitermarschieren",
    "Weitermarschierte": "weitermarschiert",
    "Weitermarschierten": "Weitermarschierte",
    "Weiterreisenden": "Weiterreisende",
    "Weiterreisens": "Weiterreisen",
    "Weitersagenden": "Weitersagende",
    "Weitersagens": "Weitersagen",
    "Weiterspinnenden": "Weiterspinnende",
    "Weiterspinnens": "Weiterspinnen",
    "Weitertragenden": "Weitertragende",
    "Weitertragenderen": "Weitertragendere",
    "Weitertragendsten": "Weitertragendste",
    "Weitertragens": "Weitertragen",
    "Weiterverbreitenden": "Weiterverbreitende",
    "Weiterverbreitens": "Weiterverbreiten",
    "Weiterverbreitete": "weiterverbreitet",
    "Weiterverbreiteten": "Weiterverbreitete",
    "Weiterverfolgenden": "Weiterverfolgende",
    "Weiterverfolgens": "Weiterverfolgen",
    "Weiterverfolgte": "weiterverfolgt",
    "Weiterverfolgten": "Weiterverfolgte",
    "Weiterverkaufenden": "Weiterverkaufende",
    "Weiterverkaufens": "Weiterverkaufen",
    "Weiterverkaufte": "weiterverkauft",
    "Weiterverkauften": "Weiterverkaufte",
    "Weitervermietenden": "Weitervermietende",
    "Weitervermietens": "Weitervermieten",
    "Weitervermietete": "weitervermietet",
    "Weitervermieteten": "Weitervermietete",
    "Weiterverwendungen": "Weiterverwendung",
    "Weitesten": "Weiteste",
    "Weithergeholten": "Weithergeholte",
    "Weitläufigen": "Weitläufige",
    "Weitläufigeren": "Weitläufigere",
    "Weitläufigsten": "Weitläufigste",
    "Weitreichenden": "Weitreichende",
    "Weitreichenderen": "Weitreichendere",
    "Weitreichendsten": "Weitreichendste",
    "Weitschweifigen": "Weitschweifige",
    "Weitschweifigeren": "Weitschweifigere",
    "Weitschweifigsten": "Weitschweifigste",
    "Weitsichtigen": "Weitsichtige",
    "Weitsichtigeren": "Weitsichtigere",
    "Weitsichtigsten": "Weitsichtigste",
    "Weitsprunge": "Weitsprung",
    "Weitsprunges": "Weitsprung",
    "Weitsprungs": "Weitsprung",
    "Weitsprünge": "Weitsprung",
    "Weitsprüngen": "Weitsprung",
    "Weitverbreitete": "weitverbreitet",
    "Weitverbreiteten": "Weitverbreitete",
    "Weitverbreiteteren": "Weitverbreitetere",
    "Weitverzweigten": "Weitverzweigte",
    "Weitverzweigteren": "Weitverzweigtere",
    "Weitwinkeln": "Weitwinkel",
    "Weitwinkels": "Weitwinkel",
    "Weizens": "Weizen",
    "Weizsäckers": "Weizsäcker",
    "Weiß": "wissen",
    "Weiße": "Weiß",
    "Weißen": "Weiße",
    "Weißeren": "Weißere",
    "Weißeste": "weiß",
    "Weißesten": "Weißeste",
    "Weißwaren": "Weißware",
    "Welkenden": "Welkende",
    "Welkenderen": "Welkendere",
    "Welkendsten": "Welkendste",
    "Welkens": "Welken",
    "Wellen": "Welle",
    "Wellenbrechern": "Wellenbrecher",
    "Wellenbrechers": "Wellenbrecher",
    "Wellenden": "Wellende",
    "Wellenderen": "Wellendere",
    "Wellendsten": "Wellendste",
    "Wellenlängen": "Wellenlänge",
    "Wellens": "Wellen",
    "Welligen": "Wellige",
    "Welligeren": "Welligere",
    "Welligsten": "Welligste",
    "Weltbekannten": "Weltbekannte",
    "Weltberühmten": "Weltberühmte",
    "Weltbewegenden": "Weltbewegende",
    "Weltbürgerlichen": "Weltbürgerliche",
    "Welten": "Welt",
    "Weltenbummlern": "Weltenbummler",
    "Weltenbummlers": "Weltenbummler",
    "Weltfremde": "weltfremd",
    "Weltfremden": "Weltfremde",
    "Weltfremderen": "Weltfremdere",
    "Weltfremdesten": "Weltfremdeste",
    "Weltgeschichtlichen": "Weltgeschichtliche",
    "Weltgewandten": "Weltgewandte",
    "Weltklassen": "Weltklasse",
    "Weltkluge": "weltklug",
    "Weltklugen": "Weltkluge",
    "Weltlichen": "Weltliche",
    "Weltlicheren": "Weltlichere",
    "Weltlichsten": "Weltlichste",
    "Weltmeisterinnen": "Weltmeisterin",
    "Weltmännischen": "Weltmännische",
    "Weltmännischeren": "Weltmännischere",
    "Weltmännischsten": "Weltmännischste",
    "Weltraums": "Weltraum",
    "Weltreisen": "Weltreise",
    "Weltweite": "weltweit",
    "Weltweiten": "Weltweite",
    "Wendelsplatzes": "Wendelsplatz",
    "Wenden": "Wende",
    "Wendenden": "Wendende",
    "Wendens": "Wenden",
    "Wendigen": "Wendige",
    "Wendigeren": "Wendigere",
    "Wendigkeiten": "Wendigkeit",
    "Wendigste": "wendig",
    "Wendigsten": "Wendigste",
    "Wenigen": "Wenige",
    "Wenigeren": "Wenigere",
    "Wenigsten": "Wenigste",
    "Wenzels": "Wenzel",
    "Werbenden": "Werbende",
    "Werbens": "Werben",
    "Werbeplakate": "Werbeplakat",
    "Werbeplakaten": "Werbeplakat",
    "Werbeplakates": "Werbeplakat",
    "Werbeplakats": "Werbeplakat",
    "Werbeslogans": "Werbeslogan",
    "Werbetexte": "Werbetext",
    "Werbetexten": "Werbetext",
    "Werbetexts": "Werbetext",
    "Werbeträgern": "Werbeträger",
    "Werbeträgers": "Werbeträger",
    "Werbewirksame": "werbewirksam",
    "Werbewirksamen": "Werbewirksame",
    "Werbewirksameren": "Werbewirksamere",
    "Werbewirksamsten": "Werbewirksamste",
    "Werbezeitungen": "Werbezeitung",
    "Werbungen": "Werbung",
    "Werdegange": "Werdegang",
    "Werdeganges": "Werdegang",
    "Werdegangs": "Werdegang",
    "Werdegänge": "Werdegang",
    "Werdegängen": "Werdegang",
    "Werfenden": "Werfende",
    "Werfens": "Werfen",
    "Werfern": "Werfer",
    "Werfers": "Werfer",
    "Werften": "Werft",
    "Werk": "werken",
    "Werkbüchereien": "Werkbücherei",
    "Werke": "werken",
    "Werkeleien": "Werkelei",
    "Werkelnden": "Werkelnde",
    "Werkelnderen": "Werkelndere",
    "Werkelndsten": "Werkelndste",
    "Werkelns": "Werkeln",
    "Werken": "Werk",
    "Werkenden": "Werkende",
    "Werkens": "Werken",
    "Werkes": "Werk",
    "Werks": "Werk",
    "Werkseigene": "werkseigen",
    "Werkseigenen": "Werkseigene",
    "Werkstätten": "Werkstätte",
    "Werktäglichen": "Werktägliche",
    "Werkzeuge": "Werkzeug",
    "Werkzeugen": "Werkzeug",
    "Werkzeuges": "Werkzeug",
    "Werkzeugs": "Werkzeug",
    "Werners": "Werner",
    "Wertbeständige": "wertbeständig",
    "Wertbeständigen": "Wertbeständige",
    "Wertbeständigeren": "Wertbeständigere",
    "Wertbeständigsten": "Wertbeständigste",
    "Werte": "werten",
    "Werten": "Wert",
    "Wertenden": "Wertende",
    "Wertens": "Werten",
    "Wertes": "Wert",
    "Wertfreien": "Wertfreie",
    "Wertfreieren": "Wertfreiere",
    "Wertfreiesten": "Wertfreieste",
    "Wertlosen": "Wertlose",
    "Wertloseren": "Wertlosere",
    "Wertlosesten": "Wertloseste",
    "Werts": "Wert",
    "Wertungen": "Wertung",
    "Wertvolle": "wertvoll",
    "Wertvollen": "Wertvolle",
    "Wertvolleren": "Wertvollere",
    "Wertvollsten": "Wertvollste",
    "Wesens": "Wesen",
    "Wesensfremde": "wesensfremd",
    "Wesensfremden": "Wesensfremde",
    "Wesentlichen": "Wesentliche",
    "Wesentlicheren": "Wesentlichere",
    "Wesentlichsten": "Wesentlichste",
    "Wespen": "Wespe",
    "Westdeutschen": "Westdeutsche",
    "Westdeutschlands": "Westdeutschland",
    "Weste": "West",
    "Westends": "Westend",
    "Westens": "Westen",
    "Westes": "West",
    "Westeuropäische": "westeuropäisch",
    "Westeuropäischen": "Westeuropäische",
    "Westfalen": "Westfale",
    "Westfalens": "Westfalen",
    "Westfälische": "westfälisch",
    "Westfälischen": "Westfälische",
    "Westfälischeren": "Westfälischere",
    "Westfälischsten": "Westfälischste",
    "Westgelde": "Westgeld",
    "Westgeldes": "Westgeld",
    "Westgelds": "Westgeld",
    "Westliche": "westlich",
    "Westlichen": "Westliche",
    "Westlicheren": "Westlichere",
    "Westlichsten": "Westlichste",
    "Wests": "West",
    "Wettbewerbe": "Wettbewerb",
    "Wettbewerben": "Wettbewerb",
    "Wettbewerbes": "Wettbewerb",
    "Wettbewerbs": "Wettbewerb",
    "Wette": "wetten",
    "Wetteifers": "Wetteifer",
    "Wetten": "Wette",
    "Wettenden": "Wettende",
    "Wettenderen": "Wettendere",
    "Wettendsten": "Wettendste",
    "Wettens": "Wetten",
    "Wetter": "wettern",
    "Wetterauern": "Wetterauer",
    "Wetterauers": "Wetterauer",
    "Wetteraus": "Wetterau",
    "Wetterbeständige": "wetterbeständig",
    "Wetterbeständigen": "Wetterbeständige",
    "Wetterbeständigeren": "Wetterbeständigere",
    "Wetterfesten": "Wetterfeste",
    "Wetterfesteren": "Wetterfestere",
    "Wetterfestesten": "Wetterfesteste",
    "Wetterfühligen": "Wetterfühlige",
    "Wetterfühligeren": "Wetterfühligere",
    "Wetterfühligsten": "Wetterfühligste",
    "Wetterlings": "Wetterling",
    "Wetternden": "Wetternde",
    "Wetternderen": "Wetterndere",
    "Wetterndsten": "Wetterndste",
    "Wetterns": "Wettern",
    "Wetters": "Wetter",
    "Wettfahrern": "Wettfahrer",
    "Wettfahrers": "Wettfahrer",
    "Wettgemachten": "Wettgemachte",
    "Wettkampfe": "Wettkampf",
    "Wettkampfes": "Wettkampf",
    "Wettkampfs": "Wettkampf",
    "Wettkämpfe": "Wettkampf",
    "Wettkämpfen": "Wettkampf",
    "Wettkämpfern": "Wettkämpfer",
    "Wettkämpfers": "Wettkämpfer",
    "Wettlaufe": "Wettlauf",
    "Wettlaufs": "Wettlauf",
    "Wettläufe": "Wettlauf",
    "Wettläufen": "Wettlauf",
    "Wettmachenden": "Wettmachende",
    "Wettmachens": "Wettmachen",
    "Wettrennens": "Wettrennen",
    "Wetturnens": "Wetturnen",
    "Wetzenden": "Wetzende",
    "Wetzens": "Wetzen",
    "Wetzlars": "Wetzlar",
    "Whiskys": "Whisky",
    "Whitneys": "Whitney",
    "Wichtelnden": "Wichtelnde",
    "Wichtelnderen": "Wichtelndere",
    "Wichtelndsten": "Wichtelndste",
    "Wichtelns": "Wichteln",
    "Wichtigen": "Wichtige",
    "Wichtigeren": "Wichtigere",
    "Wichtigkeiten": "Wichtigkeit",
    "Wichtigste": "wichtig",
    "Wichtigsten": "Wichtigste",
    "Wickel": "wickeln",
    "Wickeln": "Wickel",
    "Wickelnden": "Wickelnde",
    "Wickelns": "Wickeln",
    "Wickels": "Wickel",
    "Widdern": "Widder",
    "Widders": "Widder",
    "Widerfahrenden": "Widerfahrende",
    "Widerfahrenen": "Widerfahrene",
    "Widerfahrens": "Widerfahren",
    "Widergehallten": "Widergehallte",
    "Widergeklungenen": "Widergeklungene",
    "Widergeschienenen": "Widergeschienene",
    "Widergespiegelten": "Widergespiegelte",
    "Widerhallenden": "Widerhallende",
    "Widerhallenderen": "Widerhallendere",
    "Widerhallendsten": "Widerhallendste",
    "Widerhallens": "Widerhallen",
    "Widerhalls": "Widerhall",
    "Widerklingenden": "Widerklingende",
    "Widerklingens": "Widerklingen",
    "Widerklägern": "Widerkläger",
    "Widerklägers": "Widerkläger",
    "Widerlegbaren": "Widerlegbare",
    "Widerlegenden": "Widerlegende",
    "Widerlegens": "Widerlegen",
    "Widerlegte": "widerlegt",
    "Widerlegten": "Widerlegte",
    "Widerlegteren": "Widerlegtere",
    "Widerlegtesten": "Widerlegteste",
    "Widerlegungen": "Widerlegung",
    "Widerliche": "widerlich",
    "Widerlichen": "Widerliche",
    "Widerlicheren": "Widerlichere",
    "Widerlichsten": "Widerlichste",
    "Widerlinge": "Widerling",
    "Widerlingen": "Widerling",
    "Widerlings": "Widerling",
    "Widernden": "Widernde",
    "Widerns": "Widern",
    "Widerrechtliche": "widerrechtlich",
    "Widerrechtlichen": "Widerrechtliche",
    "Widerreden": "Widerrede",
    "Widerruf": "widerrufen",
    "Widerrufe": "widerrufen",
    "Widerrufen": "Widerruf",
    "Widerrufenden": "Widerrufende",
    "Widerrufenen": "Widerrufene",
    "Widerrufens": "Widerrufen",
    "Widerruflichen": "Widerrufliche",
    "Widerrufs": "Widerruf",
    "Widersachern": "Widersacher",
    "Widersachers": "Widersacher",
    "Widerscheine": "widerscheinen",
    "Widerscheinen": "Widerschein",
    "Widerscheinenden": "Widerscheinende",
    "Widerscheinens": "Widerscheinen",
    "Widerscheins": "Widerschein",
    "Widersetzenden": "Widersetzende",
    "Widersetzens": "Widersetzen",
    "Widersetzte": "widersetzt",
    "Widersetzten": "Widersetzte",
    "Widersinnigen": "Widersinnige",
    "Widersinnigeren": "Widersinnigere",
    "Widersinnigsten": "Widersinnigste",
    "Widersinns": "Widersinn",
    "Widerspenstige": "widerspenstig",
    "Widerspenstigen": "Widerspenstige",
    "Widerspenstigeren": "Widerspenstigere",
    "Widerspenstigsten": "Widerspenstigste",
    "Widerspiegelnden": "Widerspiegelnde",
    "Widerspiegelns": "Widerspiegeln",
    "Widersprechenden": "Widersprechende",
    "Widersprechenderen": "Widersprechendere",
    "Widersprechens": "Widersprechen",
    "Widersprochenen": "Widersprochene",
    "Widerspruche": "Widerspruch",
    "Widerspruchs": "Widerspruch",
    "Widerspruchslose": "widerspruchslos",
    "Widerspruchslosen": "Widerspruchslose",
    "Widersprüche": "Widerspruch",
    "Widersprüchen": "Widerspruch",
    "Widersprüchliche": "widersprüchlich",
    "Widersprüchlichen": "Widersprüchliche",
    "Widersprüchlicheren": "Widersprüchlichere",
    "Widerstande": "Widerstand",
    "Widerstandene": "widerstanden",
    "Widerstandenen": "Widerstandene",
    "Widerstandeneren": "Widerstandenere",
    "Widerstandensten": "Widerstandenste",
    "Widerstandes": "Widerstand",
    "Widerstands": "Widerstand",
    "Widerstandsfähige": "widerstandsfähig",
    "Widerstandsfähigen": "Widerstandsfähige",
    "Widerstandsfähigeren": "Widerstandsfähigere",
    "Widerstandslosen": "Widerstandslose",
    "Widerstandsloseren": "Widerstandslosere",
    "Widerstehenden": "Widerstehende",
    "Widerstehenderen": "Widerstehendere",
    "Widerstehendsten": "Widerstehendste",
    "Widerstehens": "Widerstehen",
    "Widerstrebenden": "Widerstrebende",
    "Widerstrebenderen": "Widerstrebendere",
    "Widerstrebendsten": "Widerstrebendste",
    "Widerstrebens": "Widerstreben",
    "Widerstrebte": "widerstrebt",
    "Widerstrebten": "Widerstrebte",
    "Widerstände": "Widerstand",
    "Widerständen": "Widerstand",
    "Widerwilligen": "Widerwillige",
    "Widerwilligeren": "Widerwilligere",
    "Widerwilligsten": "Widerwilligste",
    "Widerworte": "Widerwort",
    "Widerworten": "Widerwort",
    "Widerworts": "Widerwort",
    "Widerwärtigen": "Widerwärtige",
    "Widerwärtigeren": "Widerwärtigere",
    "Widerwärtigkeiten": "Widerwärtigkeit",
    "Widerwärtigste": "widerwärtig",
    "Widerwärtigsten": "Widerwärtigste",
    "Widmenden": "Widmende",
    "Widmens": "Widmen",
    "Widmungen": "Widmung",
    "Widrige": "widrig",
    "Widrigen": "Widrige",
    "Widrigkeiten": "Widrigkeit",
    "Wiederansiedlungen": "Wiederansiedlung",
    "Wiederaufbaue": "Wiederaufbau",
    "Wiederaufbaues": "Wiederaufbau",
    "Wiederaufbaus": "Wiederaufbau",
    "Wiederaufführungen": "Wiederaufführung",
    "Wiederaufgetauchten": "Wiederaufgetauchte",
    "Wiederauftauchenden": "Wiederauftauchende",
    "Wiederauftauchens": "Wiederauftauchen",
    "Wiederbeginns": "Wiederbeginn",
    "Wiederbekommenden": "Wiederbekommende",
    "Wiederbekommenen": "Wiederbekommene",
    "Wiederbekommens": "Wiederbekommen",
    "Wiederbelebenden": "Wiederbelebende",
    "Wiederbelebens": "Wiederbeleben",
    "Wiederbelebte": "wiederbelebt",
    "Wiederbelebten": "Wiederbelebte",
    "Wiederbringenden": "Wiederbringende",
    "Wiederbringens": "Wiederbringen",
    "Wiederergreifenden": "Wiederergreifende",
    "Wiederergreifens": "Wiederergreifen",
    "Wiederergriffenen": "Wiederergriffene",
    "Wiedererhaltenden": "Wiedererhaltende",
    "Wiedererhaltenen": "Wiedererhaltene",
    "Wiedererhaltens": "Wiedererhalten",
    "Wiedererkannte": "wiedererkennen",
    "Wiedererkannten": "wiedererkennen",
    "Wiedererkennenden": "Wiedererkennende",
    "Wiedererkennens": "Wiedererkennen",
    "Wiedererlangenden": "Wiedererlangende",
    "Wiedererlangens": "Wiedererlangen",
    "Wiedererlangte": "wiedererlangt",
    "Wiedererlangten": "Wiedererlangte",
    "Wiedererstattenden": "Wiedererstattende",
    "Wiedererstattens": "Wiedererstatten",
    "Wiedererstattete": "wiedererstattet",
    "Wiedererstatteten": "Wiedererstattete",
    "Wiedererzählenden": "Wiedererzählende",
    "Wiedererzählens": "Wiedererzählen",
    "Wiedererzählte": "wiedererzählt",
    "Wiedererzählten": "Wiedererzählte",
    "Wiedereröffnungen": "Wiedereröffnung",
    "Wiederfindenden": "Wiederfindende",
    "Wiederfindens": "Wiederfinden",
    "Wiedergaben": "wiedergeben",
    "Wiedergebenden": "Wiedergebende",
    "Wiedergebens": "Wiedergeben",
    "Wiedergeborenen": "Wiedergeborene",
    "Wiedergebrachten": "Wiedergebrachte",
    "Wiedergefundenen": "Wiedergefundene",
    "Wiedergegebenen": "Wiedergegebene",
    "Wiedergeimpften": "Wiedergeimpfte",
    "Wiedergekehrten": "Wiedergekehrte",
    "Wiedergekommenen": "Wiedergekommene",
    "Wiedergekriegten": "Wiedergekriegte",
    "Wiedergekäuten": "Wiedergekäute",
    "Wiedergeliebten": "Wiedergeliebte",
    "Wiedergeliebteren": "Wiedergeliebtere",
    "Wiedergesagten": "Wiedergesagte",
    "Wiedergesehenen": "Wiedergesehene",
    "Wiedergewinnenden": "Wiedergewinnende",
    "Wiedergewinnens": "Wiedergewinnen",
    "Wiedergewonnenen": "Wiedergewonnene",
    "Wiederhergestellten": "Wiederhergestellte",
    "Wiederherstellenden": "Wiederherstellende",
    "Wiederherstellens": "Wiederherstellen",
    "Wiederherstellungen": "Wiederherstellung",
    "Wiederholenden": "Wiederholende",
    "Wiederholens": "Wiederholen",
    "Wiederholte": "wiederholt",
    "Wiederholten": "Wiederholte",
    "Wiederholungen": "Wiederholung",
    "Wiederimpfenden": "Wiederimpfende",
    "Wiederimpfens": "Wiederimpfen",
    "Wiederimpfungen": "Wiederimpfung",
    "Wiederinstandsetzungen": "Wiederinstandsetzung",
    "Wiederkehrenden": "Wiederkehrende",
    "Wiederkehrens": "Wiederkehren",
    "Wiederkommenden": "Wiederkommende",
    "Wiederkommens": "Wiederkommen",
    "Wiederkriegenden": "Wiederkriegende",
    "Wiederkriegens": "Wiederkriegen",
    "Wiederkäuenden": "Wiederkäuende",
    "Wiederkäuens": "Wiederkäuen",
    "Wiederkäuern": "Wiederkäuer",
    "Wiederkäuers": "Wiederkäuer",
    "Wiederliebenden": "Wiederliebende",
    "Wiederliebenderen": "Wiederliebendere",
    "Wiederliebendsten": "Wiederliebendste",
    "Wiederliebens": "Wiederlieben",
    "Wiedersagenden": "Wiedersagende",
    "Wiedersagens": "Wiedersagen",
    "Wiedersehenden": "Wiedersehende",
    "Wiedersehens": "Wiedersehen",
    "Wiedersehns": "Wiedersehn",
    "Wiedertäufern": "Wiedertäufer",
    "Wiedertäufers": "Wiedertäufer",
    "Wiedervereinigen": "wiedervereinige",
    "Wiedervereinigenden": "Wiedervereinigende",
    "Wiedervereinigens": "Wiedervereinigen",
    "Wiedervereinigte": "wiedervereinigt",
    "Wiedervereinigten": "Wiedervereinigte",
    "Wiedervereinigungen": "Wiedervereinigung",
    "Wiederverkaufenden": "Wiederverkaufende",
    "Wiederverkaufens": "Wiederverkaufen",
    "Wiederverkaufs": "Wiederverkauf",
    "Wiederverkaufte": "wiederverkauft",
    "Wiederverkauften": "Wiederverkaufte",
    "Wiederverkäufern": "Wiederverkäufer",
    "Wiederverkäufers": "Wiederverkäufer",
    "Wiedmanns": "Wiedmann",
    "Wiege": "wiegen",
    "Wiegelnden": "Wiegelnde",
    "Wiegelns": "Wiegeln",
    "Wiegen": "Wiege",
    "Wiegenden": "Wiegende",
    "Wiegens": "Wiegen",
    "Wiehernden": "Wiehernde",
    "Wiehernderen": "Wieherndere",
    "Wieherndsten": "Wieherndste",
    "Wieherns": "Wiehern",
    "Wiener": "wienern",
    "Wienern": "Wiener",
    "Wienernden": "Wienernde",
    "Wienerns": "Wienern",
    "Wieners": "Wiener",
    "Wiens": "Wien",
    "Wiesbadenern": "Wiesbadener",
    "Wiesbadeners": "Wiesbadener",
    "Wiesbadens": "Wiesbaden",
    "Wiese": "weisen",
    "Wiesen": "Wiese",
    "Wikinge": "Wiking",
    "Wikinger": "Wiking",
    "Wikingern": "Wiking",
    "Wikinges": "Wiking",
    "Wikings": "Wiking",
    "Wilanows": "Wilanow",
    "Wilde": "wild",
    "Wilden": "Wilde",
    "Wildere": "wildern",
    "Wilderen": "Wildere",
    "Wilderer": "wild",
    "Wilderern": "Wilderer",
    "Wilderers": "Wilderer",
    "Wildernden": "Wildernde",
    "Wilderns": "Wildern",
    "Wildesten": "Wildeste",
    "Wildfremden": "Wildfremde",
    "Wildgartens": "Wildgarten",
    "Wildgänse": "Wildgans",
    "Wildgänsen": "Wildgans",
    "Wildgärten": "Wildgarten",
    "Wildhuhne": "Wildhuhn",
    "Wildhuhnes": "Wildhuhn",
    "Wildhuhns": "Wildhuhn",
    "Wildhühner": "Wildhuhn",
    "Wildhühnern": "Wildhuhn",
    "Wildhütern": "Wildhüter",
    "Wildhüters": "Wildhüter",
    "Wildlebende": "wildlebend",
    "Wildlebenden": "Wildlebende",
    "Wildnisse": "Wildnis",
    "Wildnissen": "Wildnis",
    "Wildpferde": "Wildpferd",
    "Wildpferden": "Wildpferd",
    "Wildpferds": "Wildpferd",
    "Wildsauen": "Wildsau",
    "Wildschafe": "Wildschaf",
    "Wildschafen": "Wildschaf",
    "Wildschafs": "Wildschaf",
    "Wildschweine": "Wildschwein",
    "Wildschweinen": "Wildschwein",
    "Wildschweins": "Wildschwein",
    "Wildwassern": "Wildwasser",
    "Wildwassers": "Wildwasser",
    "Wildwestfilme": "Wildwestfilm",
    "Wildwestfilmen": "Wildwestfilm",
    "Wildwestfilmes": "Wildwestfilm",
    "Wildwestfilms": "Wildwestfilm",
    "Wilfrieds": "Wilfried",
    "Wilhelminische": "wilhelminisch",
    "Wilhelminischen": "Wilhelminische",
    "Wilhelms": "Wilhelm",
    "Willen": "Wille",
    "Willenlose": "willenlos",
    "Willenlosen": "Willenlose",
    "Willenloseren": "Willenlosere",
    "Willenlosesten": "Willenloseste",
    "Willens": "Willen",
    "Willensschwache": "willensschwach",
    "Willensschwachen": "Willensschwache",
    "Willensstarken": "Willensstarke",
    "Willentlichen": "Willentliche",
    "Williams": "William",
    "Willies": "Willie",
    "Willigenden": "Willigende",
    "Willigens": "Willigen",
    "Willis": "Willi",
    "Willkürliche": "willkürlich",
    "Willkürlichen": "Willkürliche",
    "Willkürlicheren": "Willkürlichere",
    "Willkürlichsten": "Willkürlichste",
    "Willkürmaßnahmen": "Willkürmaßnahme",
    "Willys": "Willy",
    "Wilsons": "Wilson",
    "Wimbledons": "Wimbledon",
    "Wimmelnden": "Wimmelnde",
    "Wimmelns": "Wimmeln",
    "Wimmernden": "Wimmernde",
    "Wimmernderen": "Wimmerndere",
    "Wimmerndsten": "Wimmerndste",
    "Wimmerns": "Wimmern",
    "Wimpeln": "Wimpel",
    "Wimpels": "Wimpel",
    "Wind": "winden",
    "Windbeuteleien": "Windbeutelei",
    "Winde": "winden",
    "Windeckens": "Windecken",
    "Windeln": "Windel",
    "Windelweiche": "windelweich",
    "Windelweichen": "Windelweiche",
    "Winden": "Winde",
    "Windenden": "Windende",
    "Windens": "Winden",
    "Windern": "Winder",
    "Winders": "Winder",
    "Windes": "Wind",
    "Windfalle": "Windfall",
    "Windfalls": "Windfall",
    "Windfange": "Windfang",
    "Windfangs": "Windfang",
    "Windfälle": "Windfall",
    "Windfällen": "Windfall",
    "Windfänge": "Windfang",
    "Windfängen": "Windfang",
    "Windige": "windig",
    "Windigen": "Windige",
    "Windigeren": "Windigere",
    "Windigsten": "Windigste",
    "Windjammern": "Windjammer",
    "Windjammers": "Windjammer",
    "Windmaschinen": "Windmaschine",
    "Windrosen": "Windrose",
    "Winds": "Wind",
    "Windschiefe": "windschief",
    "Windschiefen": "Windschiefe",
    "Winfrieds": "Winfried",
    "Winiewiczs": "Winiewicz",
    "Winkel": "winkeln",
    "Winkelförmigen": "Winkelförmige",
    "Winkelförmigeren": "Winkelförmigere",
    "Winkelförmigsten": "Winkelförmigste",
    "Winkeln": "Winkel",
    "Winkelnden": "Winkelnde",
    "Winkelns": "Winkeln",
    "Winkels": "Winkel",
    "Winkenden": "Winkende",
    "Winkens": "Winken",
    "Winkern": "Winker",
    "Winkers": "Winker",
    "Winklers": "Winkler",
    "Winselnden": "Winselnde",
    "Winselnderen": "Winselndere",
    "Winselndsten": "Winselndste",
    "Winselns": "Winseln",
    "Winterfesten": "Winterfeste",
    "Winterfesteren": "Winterfestere",
    "Winterfestesten": "Winterfesteste",
    "Winterlichen": "Winterliche",
    "Winterlicheren": "Winterlichere",
    "Winterlichsten": "Winterlichste",
    "Wintern": "Winter",
    "Winters": "Winter",
    "Winzern": "Winzer",
    "Winzers": "Winzer",
    "Winzige": "winzig",
    "Winzigen": "Winzige",
    "Winzigeren": "Winzigere",
    "Winzigsten": "Winzigste",
    "Wipfeln": "Wipfel",
    "Wipfels": "Wipfel",
    "Wippenden": "Wippende",
    "Wippenderen": "Wippendere",
    "Wippendsten": "Wippendste",
    "Wippens": "Wippen",
    "Wirbel": "wirbeln",
    "Wirbeln": "Wirbel",
    "Wirbelnden": "Wirbelnde",
    "Wirbelnderen": "Wirbelndere",
    "Wirbelndsten": "Wirbelndste",
    "Wirbelns": "Wirbeln",
    "Wirbels": "Wirbel",
    "Wirkenden": "Wirkende",
    "Wirkenderen": "Wirkendere",
    "Wirkendsten": "Wirkendste",
    "Wirkens": "Wirken",
    "Wirklichen": "Wirkliche",
    "Wirklicheren": "Wirklichere",
    "Wirklichkeiten": "Wirklichkeit",
    "Wirklichkeitsfremde": "wirklichkeitsfremd",
    "Wirklichkeitsfremden": "Wirklichkeitsfremde",
    "Wirklichkeitsgetreuen": "Wirklichkeitsgetreue",
    "Wirklichsten": "Wirklichste",
    "Wirksamen": "Wirksame",
    "Wirksameren": "Wirksamere",
    "Wirksamkeiten": "Wirksamkeit",
    "Wirksamste": "wirksam",
    "Wirksamsten": "Wirksamste",
    "Wirkstoffe": "Wirkstoff",
    "Wirkstoffen": "Wirkstoff",
    "Wirkstoffes": "Wirkstoff",
    "Wirkstoffs": "Wirkstoff",
    "Wirkungen": "Wirkung",
    "Wirkungslose": "wirkungslos",
    "Wirkungslosen": "Wirkungslose",
    "Wirkungsloseren": "Wirkungslosere",
    "Wirkungslosesten": "Wirkungsloseste",
    "Wirkungsvollen": "Wirkungsvolle",
    "Wirkungsvolleren": "Wirkungsvollere",
    "Wirkungsvollsten": "Wirkungsvollste",
    "Wirren": "Wirre",
    "Wirreren": "Wirrere",
    "Wirrkopfe": "Wirrkopf",
    "Wirrkopfs": "Wirrkopf",
    "Wirrköpfe": "Wirrkopf",
    "Wirrköpfen": "Wirrkopf",
    "Wirrnisse": "Wirrnis",
    "Wirrnissen": "Wirrnis",
    "Wirrste": "wirr",
    "Wirrsten": "Wirrste",
    "Wirschen": "Wirsche",
    "Wirscheren": "Wirschere",
    "Wirschsten": "Wirschste",
    "Wirsinge": "Wirsing",
    "Wirsingen": "Wirsing",
    "Wirsings": "Wirsing",
    "Wirte": "wirten",
    "Wirten": "Wirt",
    "Wirtenden": "Wirtende",
    "Wirtens": "Wirten",
    "Wirtes": "Wirt",
    "Wirts": "Wirt",
    "Wirtschaften": "Wirtschaft",
    "Wirtschaftenden": "Wirtschaftende",
    "Wirtschaftens": "Wirtschaften",
    "Wirtschaftlichen": "Wirtschaftliche",
    "Wirtschaftlicheren": "Wirtschaftlichere",
    "Wirtschaftspolitischen": "Wirtschaftspolitische",
    "Wischenden": "Wischende",
    "Wischens": "Wischen",
    "Wischiwaschis": "Wischiwaschi",
    "Wischlappens": "Wischlappen",
    "Wismute": "Wismut",
    "Wismutes": "Wismut",
    "Wismuts": "Wismut",
    "Wispernden": "Wispernde",
    "Wispernderen": "Wisperndere",
    "Wisperndsten": "Wisperndste",
    "Wisperns": "Wispern",
    "Wissenden": "Wissende",
    "Wissenderen": "Wissendere",
    "Wissendsten": "Wissendste",
    "Wissens": "Wissen",
    "Wissenschaften": "Wissenschaft",
    "Wissenschaftlern": "Wissenschaftler",
    "Wissenschaftlers": "Wissenschaftler",
    "Wissenschaftliche": "wissenschaftlich",
    "Wissenschaftlichen": "Wissenschaftliche",
    "Wissenschaftlicheren": "Wissenschaftlichere",
    "Wissenswerten": "Wissenswerte",
    "Wissenswerteren": "Wissenswertere",
    "Wissenswertesten": "Wissenswerteste",
    "Wissentlichen": "Wissentliche",
    "Witternden": "Witternde",
    "Witternderen": "Witterndere",
    "Witterndsten": "Witterndste",
    "Witterns": "Wittern",
    "Witwen": "Witwe",
    "Witze": "Witz",
    "Witzelnden": "Witzelnde",
    "Witzelnderen": "Witzelndere",
    "Witzelndsten": "Witzelndste",
    "Witzelns": "Witzeln",
    "Witzen": "Witz",
    "Witzes": "Witz",
    "Witzige": "witzig",
    "Witzigen": "Witzige",
    "Witzigeren": "Witzigere",
    "Witzigsten": "Witzigste",
    "Witzlosen": "Witzlose",
    "Witzloseren": "Witzlosere",
    "Witzlosesten": "Witzloseste",
    "Wißbegierigen": "Wißbegierige",
    "Wißbegierigeren": "Wißbegierigere",
    "Wißbegierigsten": "Wißbegierigste",
    "Wladimirs": "Wladimir",
    "Wladyslaws": "Wladyslaw",
    "Wochen": "Woche",
    "Wochenende": "Wochenend",
    "Wochenenden": "Wochenend",
    "Wochenendes": "Wochenend",
    "Wochenlange": "wochenlang",
    "Wochenlangen": "Wochenlange",
    "Wochenschauen": "Wochenschau",
    "Wodkas": "Wodka",
    "Wohlanständigen": "Wohlanständige",
    "Wohlanständigeren": "Wohlanständigere",
    "Wohlanständigsten": "Wohlanständigste",
    "Wohlbedachten": "Wohlbedachte",
    "Wohlbefindens": "Wohlbefinden",
    "Wohlbehagens": "Wohlbehagen",
    "Wohlbehütete": "wohlbehütet",
    "Wohlbehüteten": "Wohlbehütete",
    "Wohlen": "Wohle",
    "Wohleren": "Wohlere",
    "Wohlergehens": "Wohlergehen",
    "Wohles": "Wohl",
    "Wohlgefallens": "Wohlgefallen",
    "Wohlgefühle": "Wohlgefühl",
    "Wohlgefühlen": "Wohlgefühl",
    "Wohlgefühls": "Wohlgefühl",
    "Wohlgenährte": "wohlgenährt",
    "Wohlgenährten": "Wohlgenährte",
    "Wohlgenährteren": "Wohlgenährtere",
    "Wohlgenährtesten": "Wohlgenährteste",
    "Wohlgeschmacke": "Wohlgeschmack",
    "Wohlgeschmackes": "Wohlgeschmack",
    "Wohlgeschmacks": "Wohlgeschmack",
    "Wohlhabende": "wohlhabend",
    "Wohlhabenden": "Wohlhabende",
    "Wohlhabenderen": "Wohlhabendere",
    "Wohlhabendsten": "Wohlhabendste",
    "Wohligen": "Wohlige",
    "Wohlklingenden": "Wohlklingende",
    "Wohllautenden": "Wohllautende",
    "Wohlriechenden": "Wohlriechende",
    "Wohlriechenderen": "Wohlriechendere",
    "Wohlriechendsten": "Wohlriechendste",
    "Wohls": "Wohl",
    "Wohlstande": "Wohlstand",
    "Wohlstandes": "Wohlstand",
    "Wohlstands": "Wohlstand",
    "Wohlste": "wohl",
    "Wohlsten": "Wohlste",
    "Wohltemperierten": "Wohltemperierte",
    "Wohltuenden": "Wohltuende",
    "Wohltuenderen": "Wohltuendere",
    "Wohltuendsten": "Wohltuendste",
    "Wohltätigen": "Wohltätige",
    "Wohlverdienten": "Wohlverdiente",
    "Wohnanlagen": "Wohnanlage",
    "Wohnberechtigte": "wohnberechtigt",
    "Wohnberechtigten": "Wohnberechtigte",
    "Wohnenden": "Wohnende",
    "Wohnens": "Wohnen",
    "Wohngartens": "Wohngarten",
    "Wohngebiete": "Wohngebiet",
    "Wohngebieten": "Wohngebiet",
    "Wohngebietes": "Wohngebiet",
    "Wohngebiets": "Wohngebiet",
    "Wohngebäuden": "Wohngebäude",
    "Wohngebäudes": "Wohngebäude",
    "Wohngemeinschaften": "Wohngemeinschaft",
    "Wohngärten": "Wohngarten",
    "Wohnhause": "Wohnhaus",
    "Wohnhauses": "Wohnhaus",
    "Wohnheime": "Wohnheim",
    "Wohnheimen": "Wohnheim",
    "Wohnheims": "Wohnheim",
    "Wohnhäuser": "Wohnhaus",
    "Wohnhäusern": "Wohnhaus",
    "Wohnkulturen": "Wohnkultur",
    "Wohnküchen": "Wohnküche",
    "Wohnliche": "wohnlich",
    "Wohnlichen": "Wohnliche",
    "Wohnlicheren": "Wohnlichere",
    "Wohnlichsten": "Wohnlichste",
    "Wohnmobile": "Wohnmobil",
    "Wohnmobilen": "Wohnmobil",
    "Wohnmobils": "Wohnmobil",
    "Wohnraume": "Wohnraum",
    "Wohnraumes": "Wohnraum",
    "Wohnraums": "Wohnraum",
    "Wohnräume": "Wohnraum",
    "Wohnräumen": "Wohnraum",
    "Wohnsitze": "Wohnsitz",
    "Wohnsitzen": "Wohnsitz",
    "Wohnsitzes": "Wohnsitz",
    "Wohnsitzlose": "wohnsitzlos",
    "Wohnsitzlosen": "Wohnsitzlose",
    "Wohnungen": "Wohnung",
    "Wohnvierteln": "Wohnviertel",
    "Wohnviertels": "Wohnviertel",
    "Wohnwagens": "Wohnwagen",
    "Wohnzimmern": "Wohnzimmer",
    "Wohnzimmers": "Wohnzimmer",
    "Wohnzimmmern": "Wohnzimmmer",
    "Wohnzimmmers": "Wohnzimmmer",
    "Woks": "Wok",
    "Wolfe": "Wolf",
    "Wolffs": "Wolff",
    "Wolfgangs": "Wolfgang",
    "Wolframs": "Wolfram",
    "Wolfs": "Wolf",
    "Wolfsburgs": "Wolfsburg",
    "Wolken": "Wolke",
    "Wolkenlose": "wolkenlos",
    "Wolkenlosen": "Wolkenlose",
    "Wolkenverhangenen": "Wolkenverhangene",
    "Wolkigen": "Wolkige",
    "Wolldecken": "Wolldecke",
    "Wolle": "wollen",
    "Wollkämmereien": "Wollkämmerei",
    "Wollspinnereien": "Wollspinnerei",
    "Wollüste": "Wollust",
    "Wollüsten": "Wollust",
    "Wollüstige": "wollüstig",
    "Wollüstigen": "Wollüstige",
    "Wollüstigeren": "Wollüstigere",
    "Wollüstigsten": "Wollüstigste",
    "Wolters": "Wolter",
    "Wonnen": "Wonne",
    "Wonneproppens": "Wonneproppen",
    "Wonnevolle": "wonnevoll",
    "Wonnevollen": "Wonnevolle",
    "Wonnevolleren": "Wonnevollere",
    "Wonnevollsten": "Wonnevollste",
    "Workshops": "Workshop",
    "Wortbrüchige": "wortbrüchig",
    "Wortbrüchigen": "Wortbrüchige",
    "Wortbrüchigeren": "Wortbrüchigere",
    "Wortbrüchigsten": "Wortbrüchigste",
    "Worte": "Wort",
    "Wortemachern": "Wortemacher",
    "Wortemachers": "Wortemacher",
    "Wortes": "Wort",
    "Wortgefechte": "Wortgefecht",
    "Wortgefechten": "Wortgefecht",
    "Wortgefechts": "Wortgefecht",
    "Wortgetreue": "wortgetreu",
    "Wortgetreuen": "Wortgetreue",
    "Wortkargen": "Wortkarge",
    "Wortklaubereien": "Wortklauberei",
    "Wortklaubern": "Wortklauber",
    "Wortklaubers": "Wortklauber",
    "Wortkärgeren": "Wortkärgere",
    "Wortlosen": "Wortlose",
    "Worts": "Wort",
    "Wortverdrehern": "Wortverdreher",
    "Wortverdrehers": "Wortverdreher",
    "Wortwörtliche": "wortwörtlich",
    "Wortwörtlichen": "Wortwörtliche",
    "Wringenden": "Wringende",
    "Wringens": "Wringen",
    "Wuchernden": "Wuchernde",
    "Wuchernderen": "Wucherndere",
    "Wucherndsten": "Wucherndste",
    "Wucherns": "Wuchern",
    "Wuchse": "Wuchs",
    "Wuchses": "Wuchs",
    "Wuchten": "Wucht",
    "Wuchtenden": "Wuchtende",
    "Wuchtenderen": "Wuchtendere",
    "Wuchtendsten": "Wuchtendste",
    "Wuchtens": "Wuchten",
    "Wuchtigen": "Wuchtige",
    "Wuchtigeren": "Wuchtigere",
    "Wuchtigsten": "Wuchtigste",
    "Wulste": "Wulst",
    "Wulsten": "Wulst",
    "Wulstes": "Wulst",
    "Wulstige": "wulstig",
    "Wulstigen": "Wulstige",
    "Wulstigeren": "Wulstigere",
    "Wulstigsten": "Wulstigste",
    "Wulsts": "Wulst",
    "Wunde": "wund",
    "Wunden": "Wunde",
    "Wunder": "wund",
    "Wunderbare": "wunderbar",
    "Wunderbaren": "Wunderbare",
    "Wunderbareren": "Wunderbarere",
    "Wunderbarsten": "Wunderbarste",
    "Wundere": "wundern",
    "Wunderen": "Wundere",
    "Wunderhübschen": "Wunderhübsche",
    "Wundern": "Wunder",
    "Wundernden": "Wundernde",
    "Wundernderen": "Wunderndere",
    "Wunderndsten": "Wunderndste",
    "Wunderns": "Wundern",
    "Wunderquellen": "Wunderquelle",
    "Wunders": "Wunder",
    "Wundersame": "wundersam",
    "Wundersamen": "Wundersame",
    "Wundersameren": "Wundersamere",
    "Wundersamsten": "Wundersamste",
    "Wunderschönen": "Wunderschöne",
    "Wunderschöneren": "Wunderschönere",
    "Wunderschönsten": "Wunderschönste",
    "Wundervollen": "Wundervolle",
    "Wundervolleren": "Wundervollere",
    "Wundervollsten": "Wundervollste",
    "Wundesten": "Wundeste",
    "Wundfiebers": "Wundfieber",
    "Wundflächen": "Wundfläche",
    "Wundklammern": "Wundklammer",
    "Wundrosen": "Wundrose",
    "Wundsalben": "Wundsalbe",
    "Wunsche": "Wunsch",
    "Wunsches": "Wunsch",
    "Wunschgemäßen": "Wunschgemäße",
    "Wunschlosen": "Wunschlose",
    "Wunschs": "Wunsch",
    "Wuppertalern": "Wuppertaler",
    "Wuppertalers": "Wuppertaler",
    "Wuppertals": "Wuppertal",
    "Wurfe": "Wurf",
    "Wurfes": "Wurf",
    "Wurfs": "Wurf",
    "Wurfsendungen": "Wurfsendung",
    "Wurlitzerorgeln": "Wurlitzerorgel",
    "Wurm": "wurmen",
    "Wurme": "wurmen",
    "Wurmenden": "Wurmende",
    "Wurmenderen": "Wurmendere",
    "Wurmendsten": "Wurmendste",
    "Wurmens": "Wurmen",
    "Wurmes": "Wurm",
    "Wurms": "Wurm",
    "Wurmstichigen": "Wurmstichige",
    "Wurstelnden": "Wurstelnde",
    "Wurstelnderen": "Wurstelndere",
    "Wurstelndsten": "Wurstelndste",
    "Wurstelns": "Wursteln",
    "Wurstenden": "Wurstende",
    "Wurstenderen": "Wurstendere",
    "Wurstendsten": "Wurstendste",
    "Wurstens": "Wursten",
    "Wurzel": "wurzeln",
    "Wurzeln": "Wurzel",
    "Wurzelnden": "Wurzelnde",
    "Wurzelns": "Wurzeln",
    "Wuscheligen": "Wuschelige",
    "Wuscheligeren": "Wuscheligere",
    "Wuscheligsten": "Wuscheligste",
    "Wuschelkopfe": "Wuschelkopf",
    "Wuschelkopfs": "Wuschelkopf",
    "Wuschelköpfe": "Wuschelkopf",
    "Wuschelköpfen": "Wuschelkopf",
    "Wuseligen": "Wuselige",
    "Wuseligeren": "Wuseligere",
    "Wuseligsten": "Wuseligste",
    "Wuselnden": "Wuselnde",
    "Wuselnderen": "Wuselndere",
    "Wuselndsten": "Wuselndste",
    "Wuselns": "Wuseln",
    "Wutentbrannte": "wutentbrannt",
    "Wutentbrannten": "Wutentbrannte",
    "Wutschäumenden": "Wutschäumende",
    "Wutschäumenderen": "Wutschäumendere",
    "Wutschäumendsten": "Wutschäumendste",
    "Wuttkes": "Wuttke",
    "Wynaldas": "Wynalda",
    "Wynhoffs": "Wynhoff",
    "Wächtern": "Wächter",
    "Wächters": "Wächter",
    "Wächtersbachs": "Wächtersbach",
    "Wägelchens": "Wägelchen",
    "Wägende": "wägend",
    "Wägenden": "Wägende",
    "Wägens": "Wägen",
    "Wählbaren": "Wählbare",
    "Wählenden": "Wählende",
    "Wählens": "Wählen",
    "Wählerinnen": "Wählerin",
    "Wählerische": "wählerisch",
    "Wählerischen": "Wählerische",
    "Wählerischeren": "Wählerischere",
    "Wählerischsten": "Wählerischste",
    "Wählern": "Wähler",
    "Wählers": "Wähler",
    "Wähnenden": "Wähnende",
    "Wähnens": "Wähnen",
    "Währende": "während",
    "Währenden": "Währende",
    "Währens": "Währen",
    "Währungen": "Währung",
    "Wäldchens": "Wäldchen",
    "Wälder": "Wald",
    "Wäldern": "Wald",
    "Wälzende": "wälzend",
    "Wälzenden": "Wälzende",
    "Wälzendere": "wälzend",
    "Wälzenderen": "Wälzendere",
    "Wälzendste": "wälzend",
    "Wälzendsten": "Wälzendste",
    "Wälzens": "Wälzen",
    "Wände": "winden",
    "Wänden": "winden",
    "Wännchens": "Wännchen",
    "Wännleins": "Wännlein",
    "Wärmeaustauschern": "Wärmeaustauscher",
    "Wärmeaustauschers": "Wärmeaustauscher",
    "Wärmenden": "Wärmende",
    "Wärmenderen": "Wärmendere",
    "Wärmendsten": "Wärmendste",
    "Wärmens": "Wärmen",
    "Wärmeren": "Wärmere",
    "Wärmetechnischen": "Wärmetechnische",
    "Wärmsten": "Wärmste",
    "Wärterinnen": "Wärterin",
    "Wäscherinnen": "Wäscherin",
    "Wässerchens": "Wässerchen",
    "Wässerigen": "Wässerige",
    "Wässerigeren": "Wässerigere",
    "Wässerigsten": "Wässerigste",
    "Wässernden": "Wässernde",
    "Wässernderen": "Wässerndere",
    "Wässerndsten": "Wässerndste",
    "Wässerns": "Wässern",
    "Wässrigen": "Wässrige",
    "Wässrigsten": "Wässrigste",
    "Wäßrigeren": "Wäßrigere",
    "Wöchentliche": "wöchentlich",
    "Wöchentlichen": "Wöchentliche",
    "Wölbenden": "Wölbende",
    "Wölbens": "Wölben",
    "Wölbungen": "Wölbung",
    "Wölfe": "Wolf",
    "Wölfen": "Wolf",
    "Wölfersheims": "Wölfersheim",
    "Wölfinnen": "Wölfin",
    "Wölfische": "wölfisch",
    "Wölfischen": "Wölfische",
    "Wölfleins": "Wölflein",
    "Wölkchens": "Wölkchen",
    "Wöllstadts": "Wöllstadt",
    "Wörners": "Wörner",
    "Wörtchens": "Wörtchen",
    "Wörter": "Wort",
    "Wörtern": "Wort",
    "Wörtleins": "Wörtlein",
    "Wörtliche": "wörtlich",
    "Wörtlichen": "Wörtliche",
    "Wüchse": "Wuchs",
    "Wüchsen": "Wuchs",
    "Wücks": "Wück",
    "Wühlenden": "Wühlende",
    "Wühlenderen": "Wühlendere",
    "Wühlendsten": "Wühlendste",
    "Wühlens": "Wühlen",
    "Wünsche": "wünschen",
    "Wünschen": "Wunsch",
    "Wünschenden": "Wünschende",
    "Wünschens": "Wünschen",
    "Wünschenswerte": "wünschenswert",
    "Wünschenswerten": "Wünschenswerte",
    "Wünschenswerteren": "Wünschenswertere",
    "Würdelose": "würdelos",
    "Würdelosen": "Würdelose",
    "Würdeloseren": "Würdelosere",
    "Würdelosesten": "Würdeloseste",
    "Würden": "Würde",
    "Würdevollen": "Würdevolle",
    "Würdevolleren": "Würdevollere",
    "Würdevollsten": "Würdevollste",
    "Würdigenden": "Würdigende",
    "Würdigens": "Würdigen",
    "Würdigungen": "Würdigung",
    "Würfe": "Wurf",
    "Würfel": "würfeln",
    "Würfeln": "Würfel",
    "Würfelnden": "Würfelnde",
    "Würfelnderen": "Würfelndere",
    "Würfelndsten": "Würfelndste",
    "Würfelns": "Würfeln",
    "Würfels": "Würfel",
    "Würfen": "Wurf",
    "Würgenden": "Würgende",
    "Würgenderen": "Würgendere",
    "Würgendsten": "Würgendste",
    "Würgens": "Würgen",
    "Würgern": "Würger",
    "Würgers": "Würger",
    "Würmer": "Wurm",
    "Würmern": "Wurm",
    "Würstchens": "Würstchen",
    "Würste": "Wurst",
    "Würsten": "Wurst",
    "Württembergischen": "Württembergische",
    "Württembergs": "Württemberg",
    "Würzburgs": "Würzburg",
    "Würzelchens": "Würzelchen",
    "Würzenden": "Würzende",
    "Würzenderen": "Würzendere",
    "Würzendsten": "Würzendste",
    "Würzens": "Würzen",
    "Würzigen": "Würzige",
    "Würzigeren": "Würzigere",
    "Würzigsten": "Würzigste",
    "Wüsten": "Wüste",
    "Wüsteneien": "Wüstenei",
    "Wüsteren": "Wüstere",
    "Wüstesten": "Wüsteste",
    "Wütenden": "Wütende",
    "Wütenderen": "Wütendere",
    "Wütendsten": "Wütendste",
    "Wütens": "Wüten",
    "Xanthippen": "Xanthippe",
    "Xis": "Xi",
    "Yachten": "Yacht",
    "Yeboahs": "Yeboah",
    "Yetis": "Yeti",
    "Yogas": "Yoga",
    "Yorkern": "Yorker",
    "Yorkers": "Yorker",
    "Yorks": "York",
    "Yuccas": "Yucca",
    "Yuppies": "Yuppie",
    "Yvonnes": "Yvonne",
    "Zackens": "Zacken",
    "Zagenden": "Zagende",
    "Zagenderen": "Zagendere",
    "Zagendsten": "Zagendste",
    "Zagens": "Zagen",
    "Zaghaften": "Zaghafte",
    "Zaghafteren": "Zaghaftere",
    "Zaghaftesten": "Zaghafteste",
    "Zagrebs": "Zagreb",
    "Zahl": "zahlen",
    "Zahlen": "Zahl",
    "Zahlenden": "Zahlende",
    "Zahlens": "Zahlen",
    "Zahlern": "Zahler",
    "Zahlers": "Zahler",
    "Zahllosen": "Zahllose",
    "Zahlreiche": "zahlreich",
    "Zahlreichen": "Zahlreiche",
    "Zahlreicheren": "Zahlreichere",
    "Zahlreichsten": "Zahlreichste",
    "Zahltage": "Zahltag",
    "Zahltagen": "Zahltag",
    "Zahltags": "Zahltag",
    "Zahlungen": "Zahlung",
    "Zahlungsfähige": "zahlungsfähig",
    "Zahlungsfähigen": "Zahlungsfähige",
    "Zahlungsfähigeren": "Zahlungsfähigere",
    "Zahlungsfähigsten": "Zahlungsfähigste",
    "Zahlungsunfähigen": "Zahlungsunfähige",
    "Zahlungsunfähigeren": "Zahlungsunfähigere",
    "Zahmen": "Zahme",
    "Zahmeren": "Zahmere",
    "Zahmsten": "Zahmste",
    "Zahn": "zahnen",
    "Zahne": "zahnen",
    "Zahnenden": "Zahnende",
    "Zahnenderen": "Zahnendere",
    "Zahnendsten": "Zahnendste",
    "Zahnens": "Zahnen",
    "Zahnes": "Zahn",
    "Zahnlosen": "Zahnlose",
    "Zahns": "Zahn",
    "Zahnungen": "Zahnung",
    "Zahnärztliche": "zahnärztlich",
    "Zahnärztlichen": "Zahnärztliche",
    "Zanders": "Zander",
    "Zangen": "Zange",
    "Zankenden": "Zankende",
    "Zankenderen": "Zankendere",
    "Zankendsten": "Zankendste",
    "Zankens": "Zanken",
    "Zanksüchtigen": "Zanksüchtige",
    "Zanksüchtigeren": "Zanksüchtigere",
    "Zanksüchtigsten": "Zanksüchtigste",
    "Zankteufeln": "Zankteufel",
    "Zankteufels": "Zankteufel",
    "Zapfenden": "Zapfende",
    "Zapfens": "Zapfen",
    "Zapfsäulen": "Zapfsäule",
    "Zappeligen": "Zappelige",
    "Zappeligeren": "Zappeligere",
    "Zappeligsten": "Zappeligste",
    "Zappelnden": "Zappelnde",
    "Zappelnderen": "Zappelndere",
    "Zappelndsten": "Zappelndste",
    "Zappelns": "Zappeln",
    "Zaren": "Zar",
    "Zarinnen": "Zarin",
    "Zarte": "zart",
    "Zarten": "Zarte",
    "Zarteren": "Zartere",
    "Zartesten": "Zarteste",
    "Zasters": "Zaster",
    "Zauber": "zaubern",
    "Zauberhaften": "Zauberhafte",
    "Zauberhafteren": "Zauberhaftere",
    "Zauberhaftesten": "Zauberhafteste",
    "Zauberinnen": "Zauberin",
    "Zaubern": "Zauber",
    "Zaubernden": "Zaubernde",
    "Zauberns": "Zaubern",
    "Zaubers": "Zauber",
    "Zauderern": "Zauderer",
    "Zauderers": "Zauderer",
    "Zaudernden": "Zaudernde",
    "Zaudernderen": "Zauderndere",
    "Zauderndsten": "Zauderndste",
    "Zauderns": "Zaudern",
    "Zaune": "Zaun",
    "Zauns": "Zaun",
    "Zausenden": "Zausende",
    "Zausens": "Zausen",
    "Zebras": "Zebra",
    "Zechenden": "Zechende",
    "Zechenderen": "Zechendere",
    "Zechendsten": "Zechendste",
    "Zechens": "Zechen",
    "Zecken": "Zecke",
    "Zehen": "Zehe",
    "Zehnfingersysteme": "Zehnfingersystem",
    "Zehnfingersystemen": "Zehnfingersystem",
    "Zehnfingersystems": "Zehnfingersystem",
    "Zehnkampfe": "Zehnkampf",
    "Zehnkampfs": "Zehnkampf",
    "Zehnkämpfe": "Zehnkampf",
    "Zehnkämpfen": "Zehnkampf",
    "Zehnmonatskinde": "Zehnmonatskind",
    "Zehnmonatskinder": "Zehnmonatskind",
    "Zehnmonatskindern": "Zehnmonatskind",
    "Zehnmonatskindes": "Zehnmonatskind",
    "Zehnmonatskinds": "Zehnmonatskind",
    "Zehnpfennigstücke": "Zehnpfennigstück",
    "Zehnpfennigstücken": "Zehnpfennigstück",
    "Zehnpfennigstückes": "Zehnpfennigstück",
    "Zehnpfennigstücks": "Zehnpfennigstück",
    "Zehntausenden": "Zehntausende",
    "Zehntausendsteln": "Zehntausendstel",
    "Zehntausendstels": "Zehntausendstel",
    "Zehnteln": "Zehntel",
    "Zehntels": "Zehntel",
    "Zehnten": "Zehnte",
    "Zehrenden": "Zehrende",
    "Zehrenderen": "Zehrendere",
    "Zehrendsten": "Zehrendste",
    "Zehrens": "Zehren",
    "Zeichenblocke": "Zeichenblock",
    "Zeichenblocks": "Zeichenblock",
    "Zeichenblöcke": "Zeichenblock",
    "Zeichenblöcken": "Zeichenblock",
    "Zeichenbrette": "Zeichenbrett",
    "Zeichenbretter": "Zeichenbrett",
    "Zeichenbrettern": "Zeichenbrett",
    "Zeichenbrettes": "Zeichenbrett",
    "Zeichenbretts": "Zeichenbrett",
    "Zeichenlehrern": "Zeichenlehrer",
    "Zeichenlehrers": "Zeichenlehrer",
    "Zeichens": "Zeichen",
    "Zeichnenden": "Zeichnende",
    "Zeichnens": "Zeichnen",
    "Zeichnerische": "zeichnerisch",
    "Zeichnerischen": "Zeichnerische",
    "Zeichnungen": "Zeichnung",
    "Zeigefingern": "Zeigefinger",
    "Zeigefingers": "Zeigefinger",
    "Zeigenden": "Zeigende",
    "Zeigens": "Zeigen",
    "Zeigern": "Zeiger",
    "Zeigers": "Zeiger",
    "Zeihens": "Zeihen",
    "Zeilen": "Zeile",
    "Zeilsheims": "Zeilsheim",
    "Zeiten": "Zeit",
    "Zeitfahrens": "Zeitfahren",
    "Zeitgebundene": "zeitgebunden",
    "Zeitgebundenen": "Zeitgebundene",
    "Zeitgemäßen": "Zeitgemäße",
    "Zeitgemäßeren": "Zeitgemäßere",
    "Zeitgemäßesten": "Zeitgemäßeste",
    "Zeitgenössischen": "Zeitgenössische",
    "Zeitgenössischeren": "Zeitgenössischere",
    "Zeitgeschichtlichen": "Zeitgeschichtliche",
    "Zeitgleichen": "Zeitgleiche",
    "Zeitigen": "Zeitige",
    "Zeitlichen": "Zeitliche",
    "Zeitlosen": "Zeitlose",
    "Zeitloseren": "Zeitlosere",
    "Zeitlosesten": "Zeitloseste",
    "Zeitraubenden": "Zeitraubende",
    "Zeitraume": "Zeitraum",
    "Zeitraumes": "Zeitraum",
    "Zeitraums": "Zeitraum",
    "Zeiträume": "Zeitraum",
    "Zeiträumen": "Zeitraum",
    "Zeitschriften": "Zeitschrift",
    "Zeitungen": "Zeitung",
    "Zeitweilige": "zeitweilig",
    "Zeitweiligen": "Zeitweilige",
    "Zellen": "Zelle",
    "Zellingens": "Zellingen",
    "Zellstoffe": "Zellstoff",
    "Zellstoffen": "Zellstoff",
    "Zellstoffes": "Zellstoff",
    "Zellstoffs": "Zellstoff",
    "Zellulare": "zellular",
    "Zellularen": "Zellulare",
    "Zelluloide": "Zelluloid",
    "Zelluloiden": "Zelluloid",
    "Zelluloids": "Zelluloid",
    "Zelte": "zelten",
    "Zelten": "Zelt",
    "Zeltenden": "Zeltende",
    "Zeltenderen": "Zeltendere",
    "Zeltendsten": "Zeltendste",
    "Zeltens": "Zelten",
    "Zeltes": "Zelt",
    "Zelts": "Zelt",
    "Zemente": "Zement",
    "Zementen": "Zement",
    "Zementes": "Zement",
    "Zementierenden": "Zementierende",
    "Zementierenderen": "Zementierendere",
    "Zementierendsten": "Zementierendste",
    "Zementierens": "Zementieren",
    "Zementierte": "zementiert",
    "Zementierten": "Zementierte",
    "Zementierteren": "Zementiertere",
    "Zementiertesten": "Zementierteste",
    "Zements": "Zement",
    "Zenite": "Zenit",
    "Zeniten": "Zenit",
    "Zenits": "Zenit",
    "Zensierenden": "Zensierende",
    "Zensierens": "Zensieren",
    "Zensierte": "zensiert",
    "Zensierten": "Zensierte",
    "Zensore": "Zensor",
    "Zensoren": "Zensor",
    "Zensors": "Zensor",
    "Zensuren": "Zensur",
    "Zentimern": "Zentimer",
    "Zentimers": "Zentimer",
    "Zentimetern": "Zentimeter",
    "Zentimeters": "Zentimeter",
    "Zentnerlasten": "Zentnerlast",
    "Zentnern": "Zentner",
    "Zentners": "Zentner",
    "Zentnerschwere": "zentnerschwer",
    "Zentnerschweren": "Zentnerschwere",
    "Zentralabiture": "Zentralabitur",
    "Zentralabituren": "Zentralabitur",
    "Zentralabiturs": "Zentralabitur",
    "Zentralbanken": "Zentralbank",
    "Zentralbewegungen": "Zentralbewegung",
    "Zentrale": "zentral",
    "Zentraleinheiten": "Zentraleinheit",
    "Zentralen": "Zentrale",
    "Zentraleren": "Zentralere",
    "Zentralheizungen": "Zentralheizung",
    "Zentralisierenden": "Zentralisierende",
    "Zentralisierenderen": "Zentralisierendere",
    "Zentralisierens": "Zentralisieren",
    "Zentralisierte": "zentralisiert",
    "Zentralisierten": "Zentralisierte",
    "Zentralisierteren": "Zentralisiertere",
    "Zentralisierteste": "zentralisiert",
    "Zentralisierungen": "Zentralisierung",
    "Zentralistische": "zentralistisch",
    "Zentralistischen": "Zentralistische",
    "Zentralkataloge": "Zentralkatalog",
    "Zentralkatalogen": "Zentralkatalog",
    "Zentralkatalogs": "Zentralkatalog",
    "Zentralmuseen": "Zentralmuseum",
    "Zentralmuseums": "Zentralmuseum",
    "Zentralspeichern": "Zentralspeicher",
    "Zentralspeichers": "Zentralspeicher",
    "Zentralstationen": "Zentralstation",
    "Zentralste": "zentral",
    "Zentralsten": "Zentralste",
    "Zentralverriegelungen": "Zentralverriegelung",
    "Zentren": "Zentrum",
    "Zentrierenden": "Zentrierende",
    "Zentrierenderen": "Zentrierendere",
    "Zentrierendsten": "Zentrierendste",
    "Zentrierens": "Zentrieren",
    "Zentrierte": "zentriert",
    "Zentrierten": "Zentrierte",
    "Zentrierteren": "Zentriertere",
    "Zentriertesten": "Zentrierteste",
    "Zentrifugalen": "Zentrifugale",
    "Zentrifugalpumpen": "Zentrifugalpumpe",
    "Zentrifugen": "Zentrifuge",
    "Zentrifugierenden": "Zentrifugierende",
    "Zentrifugierens": "Zentrifugieren",
    "Zentrifugierte": "zentrifugiert",
    "Zentrifugierten": "Zentrifugierte",
    "Zentrischen": "Zentrische",
    "Zentrums": "Zentrum",
    "Zeppeline": "Zeppelin",
    "Zeppelinen": "Zeppelin",
    "Zeppelinheims": "Zeppelinheim",
    "Zeppelins": "Zeppelin",
    "Zeptern": "Zepter",
    "Zepters": "Zepter",
    "Zerbeißenden": "Zerbeißende",
    "Zerbeißenderen": "Zerbeißendere",
    "Zerbeißendsten": "Zerbeißendste",
    "Zerbeißens": "Zerbeißen",
    "Zerbeulenden": "Zerbeulende",
    "Zerbeulens": "Zerbeulen",
    "Zerbeulte": "zerbeult",
    "Zerbeulten": "Zerbeulte",
    "Zerbeulteren": "Zerbeultere",
    "Zerbeultesten": "Zerbeulteste",
    "Zerbiegenden": "Zerbiegende",
    "Zerbiegens": "Zerbiegen",
    "Zerbissenen": "Zerbissene",
    "Zerbisseneren": "Zerbissenere",
    "Zerbissensten": "Zerbissenste",
    "Zerblasenden": "Zerblasende",
    "Zerblasenen": "Zerblasene",
    "Zerblasens": "Zerblasen",
    "Zerbogenen": "Zerbogene",
    "Zerbogeneren": "Zerbogenere",
    "Zerbogensten": "Zerbogenste",
    "Zerbombenden": "Zerbombende",
    "Zerbombenderen": "Zerbombendere",
    "Zerbombendsten": "Zerbombendste",
    "Zerbombens": "Zerbomben",
    "Zerbombte": "zerbombt",
    "Zerbombten": "Zerbombte",
    "Zerbombteren": "Zerbombtere",
    "Zerbombtesten": "Zerbombteste",
    "Zerbrechenden": "Zerbrechende",
    "Zerbrechens": "Zerbrechen",
    "Zerbrechlichen": "Zerbrechliche",
    "Zerbrechlicheren": "Zerbrechlichere",
    "Zerbrechlichsten": "Zerbrechlichste",
    "Zerbrochenen": "Zerbrochene",
    "Zerbrocheneren": "Zerbrochenere",
    "Zerbrochensten": "Zerbrochenste",
    "Zerbröckelnden": "Zerbröckelnde",
    "Zerbröckelnderen": "Zerbröckelndere",
    "Zerbröckelndsten": "Zerbröckelndste",
    "Zerbröckelns": "Zerbröckeln",
    "Zerbröckelte": "zerbröckelt",
    "Zerbröckelten": "Zerbröckelte",
    "Zerbröckelteren": "Zerbröckeltere",
    "Zerbröckeltesten": "Zerbröckelteste",
    "Zerdampfenden": "Zerdampfende",
    "Zerdampfenderen": "Zerdampfendere",
    "Zerdampfendsten": "Zerdampfendste",
    "Zerdampfens": "Zerdampfen",
    "Zerdampfte": "zerdampft",
    "Zerdampften": "Zerdampfte",
    "Zerdampfteren": "Zerdampftere",
    "Zerdampftesten": "Zerdampfteste",
    "Zerdellenden": "Zerdellende",
    "Zerdellenderen": "Zerdellendere",
    "Zerdellendsten": "Zerdellendste",
    "Zerdellens": "Zerdellen",
    "Zerdellte": "zerdellt",
    "Zerdellten": "Zerdellte",
    "Zerdellteren": "Zerdelltere",
    "Zerdelltesten": "Zerdellteste",
    "Zerdonnernden": "Zerdonnernde",
    "Zerdonnernderen": "Zerdonnerndere",
    "Zerdonnerndsten": "Zerdonnerndste",
    "Zerdonnerns": "Zerdonnern",
    "Zerdonnerte": "zerdonnert",
    "Zerdonnerten": "Zerdonnerte",
    "Zerdonnerteren": "Zerdonnertere",
    "Zerdonnertesten": "Zerdonnerteste",
    "Zerdröselnden": "Zerdröselnde",
    "Zerdröselnderen": "Zerdröselndere",
    "Zerdröselndsten": "Zerdröselndste",
    "Zerdröselns": "Zerdröseln",
    "Zerdröselte": "zerdröselt",
    "Zerdröselten": "Zerdröselte",
    "Zerdröselteren": "Zerdröseltere",
    "Zerdröseltesten": "Zerdröselteste",
    "Zerdrückenden": "Zerdrückende",
    "Zerdrückens": "Zerdrücken",
    "Zerdrückte": "zerdrückt",
    "Zerdrückten": "Zerdrückte",
    "Zerdrückteren": "Zerdrücktere",
    "Zerdrücktesten": "Zerdrückteste",
    "Zeremonien": "Zeremonie",
    "Zerfahrene": "zerfahren",
    "Zerfahrenen": "Zerfahrene",
    "Zerfahreneren": "Zerfahrenere",
    "Zerfahrensten": "Zerfahrenste",
    "Zerfallenden": "Zerfallende",
    "Zerfallenen": "Zerfallene",
    "Zerfalleneren": "Zerfallenere",
    "Zerfallens": "Zerfallen",
    "Zerfallenste": "zerfallen",
    "Zerfallensten": "Zerfallenste",
    "Zerfalls": "Zerfall",
    "Zerfasernden": "Zerfasernde",
    "Zerfasernderen": "Zerfaserndere",
    "Zerfaserndsten": "Zerfaserndste",
    "Zerfaserns": "Zerfasern",
    "Zerfaserte": "zerfasert",
    "Zerfaserten": "Zerfaserte",
    "Zerfaserteren": "Zerfasertere",
    "Zerfasertesten": "Zerfaserteste",
    "Zerfetzenden": "Zerfetzende",
    "Zerfetzenderen": "Zerfetzendere",
    "Zerfetzendsten": "Zerfetzendste",
    "Zerfetzens": "Zerfetzen",
    "Zerfetzte": "zerfetzt",
    "Zerfetzten": "Zerfetzte",
    "Zerfetzteren": "Zerfetztere",
    "Zerfetztesten": "Zerfetzteste",
    "Zerflatternden": "Zerflatternde",
    "Zerflatterns": "Zerflattern",
    "Zerflatterte": "zerflattert",
    "Zerflatterten": "Zerflatterte",
    "Zerfleddernden": "Zerfleddernde",
    "Zerfleddernderen": "Zerfledderndere",
    "Zerfledderndsten": "Zerfledderndste",
    "Zerfledderns": "Zerfleddern",
    "Zerfledderte": "zerfleddert",
    "Zerfledderten": "Zerfledderte",
    "Zerfledderteren": "Zerfleddertere",
    "Zerfleddertesten": "Zerfledderteste",
    "Zerfleischenden": "Zerfleischende",
    "Zerfleischens": "Zerfleischen",
    "Zerfleischte": "zerfleischt",
    "Zerfleischten": "Zerfleischte",
    "Zerfließenden": "Zerfließende",
    "Zerfließens": "Zerfließen",
    "Zerflossenen": "Zerflossene",
    "Zerflosseneren": "Zerflossenere",
    "Zerflossensten": "Zerflossenste",
    "Zerfransenden": "Zerfransende",
    "Zerfransenderen": "Zerfransendere",
    "Zerfransendsten": "Zerfransendste",
    "Zerfransens": "Zerfransen",
    "Zerfranste": "zerfranst",
    "Zerfransten": "Zerfranste",
    "Zerfransteren": "Zerfranstere",
    "Zerfranstesten": "Zerfransteste",
    "Zerfressenden": "Zerfressende",
    "Zerfressenderen": "Zerfressendere",
    "Zerfressendsten": "Zerfressendste",
    "Zerfressenen": "Zerfressene",
    "Zerfresseneren": "Zerfressenere",
    "Zerfressens": "Zerfressen",
    "Zerfressenste": "zerfressen",
    "Zerfressensten": "Zerfressenste",
    "Zergangenen": "Zergangene",
    "Zergehenden": "Zergehende",
    "Zergehens": "Zergehen",
    "Zergliedernden": "Zergliedernde",
    "Zergliedernderen": "Zergliederndere",
    "Zergliederndsten": "Zergliederndste",
    "Zergliederns": "Zergliedern",
    "Zergliederte": "zergliedert",
    "Zergliederten": "Zergliederte",
    "Zergliederteren": "Zergliedertere",
    "Zergliedertesten": "Zergliederteste",
    "Zerhackenden": "Zerhackende",
    "Zerhackenderen": "Zerhackendere",
    "Zerhackendsten": "Zerhackendste",
    "Zerhackens": "Zerhacken",
    "Zerhackte": "zerhackt",
    "Zerhackten": "Zerhackte",
    "Zerhackteren": "Zerhacktere",
    "Zerhacktesten": "Zerhackteste",
    "Zerhagelnden": "Zerhagelnde",
    "Zerhagelnderen": "Zerhagelndere",
    "Zerhagelndsten": "Zerhagelndste",
    "Zerhagelns": "Zerhageln",
    "Zerhagelte": "zerhagelt",
    "Zerhagelten": "Zerhagelte",
    "Zerhagelteren": "Zerhageltere",
    "Zerhageltesten": "Zerhagelteste",
    "Zerhauenden": "Zerhauende",
    "Zerhauenen": "Zerhauene",
    "Zerhaueneren": "Zerhauenere",
    "Zerhauens": "Zerhauen",
    "Zerhauenste": "zerhauen",
    "Zerhauensten": "Zerhauenste",
    "Zerhäckselnden": "Zerhäckselnde",
    "Zerhäckselns": "Zerhäckseln",
    "Zerhäckselte": "zerhäckselt",
    "Zerhäckselten": "Zerhäckselte",
    "Zerkauenden": "Zerkauende",
    "Zerkauens": "Zerkauen",
    "Zerkaute": "zerkaut",
    "Zerkauten": "Zerkaute",
    "Zerklebenden": "Zerklebende",
    "Zerklebenderen": "Zerklebendere",
    "Zerklebendsten": "Zerklebendste",
    "Zerklebens": "Zerkleben",
    "Zerklebte": "zerklebt",
    "Zerklebten": "Zerklebte",
    "Zerklebteren": "Zerklebtere",
    "Zerklebtesten": "Zerklebteste",
    "Zerkleinernden": "Zerkleinernde",
    "Zerkleinernderen": "Zerkleinerndere",
    "Zerkleinerndsten": "Zerkleinerndste",
    "Zerkleinerns": "Zerkleinern",
    "Zerkleinerte": "zerkleinert",
    "Zerkleinerten": "Zerkleinerte",
    "Zerkleinerteren": "Zerkleinertere",
    "Zerkleinertesten": "Zerkleinerteste",
    "Zerklumpenden": "Zerklumpende",
    "Zerklumpenderen": "Zerklumpendere",
    "Zerklumpendsten": "Zerklumpendste",
    "Zerklumpens": "Zerklumpen",
    "Zerklumpte": "zerklumpt",
    "Zerklumpten": "Zerklumpte",
    "Zerklumpteren": "Zerklumptere",
    "Zerklumptesten": "Zerklumpteste",
    "Zerknackenden": "Zerknackende",
    "Zerknackenderen": "Zerknackendere",
    "Zerknackendsten": "Zerknackendste",
    "Zerknackens": "Zerknacken",
    "Zerknackte": "zerknackt",
    "Zerknackten": "Zerknackte",
    "Zerknackteren": "Zerknacktere",
    "Zerknacktesten": "Zerknackteste",
    "Zerknallenden": "Zerknallende",
    "Zerknallenderen": "Zerknallendere",
    "Zerknallendsten": "Zerknallendste",
    "Zerknallens": "Zerknallen",
    "Zerknallte": "zerknallt",
    "Zerknallten": "Zerknallte",
    "Zerknallteren": "Zerknalltere",
    "Zerknalltesten": "Zerknallteste",
    "Zerknautschenden": "Zerknautschende",
    "Zerknautschenderen": "Zerknautschendere",
    "Zerknautschens": "Zerknautschen",
    "Zerknautschte": "zerknautscht",
    "Zerknautschten": "Zerknautschte",
    "Zerknautschteren": "Zerknautschtere",
    "Zerknautschtesten": "Zerknautschteste",
    "Zerkneifenden": "Zerkneifende",
    "Zerkneifens": "Zerkneifen",
    "Zerkniffenen": "Zerkniffene",
    "Zerknirschenden": "Zerknirschende",
    "Zerknirschenderen": "Zerknirschendere",
    "Zerknirschendsten": "Zerknirschendste",
    "Zerknirschens": "Zerknirschen",
    "Zerknirschte": "zerknirscht",
    "Zerknirschten": "Zerknirschte",
    "Zerknirschteren": "Zerknirschtere",
    "Zerknirschtesten": "Zerknirschteste",
    "Zerknitternden": "Zerknitternde",
    "Zerknitternderen": "Zerknitterndere",
    "Zerknitterndsten": "Zerknitterndste",
    "Zerknitterns": "Zerknittern",
    "Zerknitterte": "zerknittert",
    "Zerknitterten": "Zerknitterte",
    "Zerknitterteren": "Zerknittertere",
    "Zerknittertesten": "Zerknitterteste",
    "Zerknüllenden": "Zerknüllende",
    "Zerknüllenderen": "Zerknüllendere",
    "Zerknüllendsten": "Zerknüllendste",
    "Zerknüllens": "Zerknüllen",
    "Zerknüllte": "zerknüllt",
    "Zerknüllten": "Zerknüllte",
    "Zerknüllteren": "Zerknülltere",
    "Zerknülltesten": "Zerknüllteste",
    "Zerkochenden": "Zerkochende",
    "Zerkochens": "Zerkochen",
    "Zerkochte": "zerkocht",
    "Zerkochten": "Zerkochte",
    "Zerkochteren": "Zerkochtere",
    "Zerkochtesten": "Zerkochteste",
    "Zerkrachenden": "Zerkrachende",
    "Zerkrachenderen": "Zerkrachendere",
    "Zerkrachendsten": "Zerkrachendste",
    "Zerkrachens": "Zerkrachen",
    "Zerkrachte": "zerkracht",
    "Zerkrachten": "Zerkrachte",
    "Zerkrachteren": "Zerkrachtere",
    "Zerkrachtesten": "Zerkrachteste",
    "Zerkratzenden": "Zerkratzende",
    "Zerkratzenderen": "Zerkratzendere",
    "Zerkratzendsten": "Zerkratzendste",
    "Zerkratzens": "Zerkratzen",
    "Zerkratzte": "zerkratzt",
    "Zerkratzten": "Zerkratzte",
    "Zerkratzteren": "Zerkratztere",
    "Zerkratztesten": "Zerkratzteste",
    "Zerkräuselnden": "Zerkräuselnde",
    "Zerkräuselnderen": "Zerkräuselndere",
    "Zerkräuselndsten": "Zerkräuselndste",
    "Zerkräuselns": "Zerkräuseln",
    "Zerkräuselte": "zerkräuselt",
    "Zerkräuselten": "Zerkräuselte",
    "Zerkräuselteren": "Zerkräuseltere",
    "Zerkräuseltesten": "Zerkräuselteste",
    "Zerkrümelnden": "Zerkrümelnde",
    "Zerkrümelns": "Zerkrümeln",
    "Zerkrümelte": "zerkrümelt",
    "Zerkrümelten": "Zerkrümelte",
    "Zerlatschenden": "Zerlatschende",
    "Zerlatschenderen": "Zerlatschendere",
    "Zerlatschendsten": "Zerlatschendste",
    "Zerlatschens": "Zerlatschen",
    "Zerlatschte": "zerlatscht",
    "Zerlatschten": "Zerlatschte",
    "Zerlatschteren": "Zerlatschtere",
    "Zerlatschtesten": "Zerlatschteste",
    "Zerlaufenden": "Zerlaufende",
    "Zerlaufenen": "Zerlaufene",
    "Zerlaufeneren": "Zerlaufenere",
    "Zerlaufens": "Zerlaufen",
    "Zerlaufenste": "zerlaufen",
    "Zerlaufensten": "Zerlaufenste",
    "Zerlegenden": "Zerlegende",
    "Zerlegens": "Zerlegen",
    "Zerlegte": "zerlegt",
    "Zerlegten": "Zerlegte",
    "Zerlegteren": "Zerlegtere",
    "Zerlegtesten": "Zerlegteste",
    "Zerlegungen": "Zerlegung",
    "Zermahlenden": "Zermahlende",
    "Zermahlenen": "Zermahlene",
    "Zermahleneren": "Zermahlenere",
    "Zermahlens": "Zermahlen",
    "Zermahlenste": "zermahlen",
    "Zermahlensten": "Zermahlenste",
    "Zermalmenden": "Zermalmende",
    "Zermalmenderen": "Zermalmendere",
    "Zermalmendsten": "Zermalmendste",
    "Zermalmens": "Zermalmen",
    "Zermalmte": "zermalmt",
    "Zermalmten": "Zermalmte",
    "Zermalmteren": "Zermalmtere",
    "Zermalmtesten": "Zermalmteste",
    "Zermarternden": "Zermarternde",
    "Zermarternderen": "Zermarterndere",
    "Zermarterndsten": "Zermarterndste",
    "Zermarterns": "Zermartern",
    "Zermarterte": "zermartert",
    "Zermarterten": "Zermarterte",
    "Zermarterteren": "Zermartertere",
    "Zermartertesten": "Zermarterteste",
    "Zermetzelnden": "Zermetzelnde",
    "Zermetzelnderen": "Zermetzelndere",
    "Zermetzelndsten": "Zermetzelndste",
    "Zermetzelns": "Zermetzeln",
    "Zermetzelte": "zermetzelt",
    "Zermetzelten": "Zermetzelte",
    "Zermetzelteren": "Zermetzeltere",
    "Zermetzeltesten": "Zermetzelteste",
    "Zermürbenden": "Zermürbende",
    "Zermürbenderen": "Zermürbendere",
    "Zermürbendsten": "Zermürbendste",
    "Zermürbens": "Zermürben",
    "Zermürbte": "zermürbt",
    "Zermürbten": "Zermürbte",
    "Zermürbteren": "Zermürbtere",
    "Zermürbtesten": "Zermürbteste",
    "Zernagenden": "Zernagende",
    "Zernagenderen": "Zernagendere",
    "Zernagendsten": "Zernagendste",
    "Zernagens": "Zernagen",
    "Zernagte": "zernagt",
    "Zernagten": "Zernagte",
    "Zernagteren": "Zernagtere",
    "Zernagtesten": "Zernagteste",
    "Zernarbenden": "Zernarbende",
    "Zernarbenderen": "Zernarbendere",
    "Zernarbendsten": "Zernarbendste",
    "Zernarbens": "Zernarben",
    "Zernarbte": "zernarbt",
    "Zernarbten": "Zernarbte",
    "Zernarbteren": "Zernarbtere",
    "Zernarbtesten": "Zernarbteste",
    "Zerpfeifenden": "Zerpfeifende",
    "Zerpfeifenderen": "Zerpfeifendere",
    "Zerpfeifendsten": "Zerpfeifendste",
    "Zerpfeifens": "Zerpfeifen",
    "Zerpfiffenen": "Zerpfiffene",
    "Zerpfiffeneren": "Zerpfiffenere",
    "Zerpfiffensten": "Zerpfiffenste",
    "Zerpflückenden": "Zerpflückende",
    "Zerpflückenderen": "Zerpflückendere",
    "Zerpflückendsten": "Zerpflückendste",
    "Zerpflückens": "Zerpflücken",
    "Zerpflückte": "zerpflückt",
    "Zerpflückten": "Zerpflückte",
    "Zerpflückteren": "Zerpflücktere",
    "Zerpflücktesten": "Zerpflückteste",
    "Zerpflügenden": "Zerpflügende",
    "Zerpflügens": "Zerpflügen",
    "Zerpflügte": "zerpflügt",
    "Zerpflügten": "Zerpflügte",
    "Zerpickenden": "Zerpickende",
    "Zerpickens": "Zerpicken",
    "Zerpickte": "zerpickt",
    "Zerpickten": "Zerpickte",
    "Zerplatzenden": "Zerplatzende",
    "Zerplatzens": "Zerplatzen",
    "Zerplatzte": "zerplatzt",
    "Zerplatzten": "Zerplatzte",
    "Zerpressenden": "Zerpressende",
    "Zerpressens": "Zerpressen",
    "Zerpreßte": "zerpreßt",
    "Zerpreßten": "Zerpreßte",
    "Zerquetschenden": "Zerquetschende",
    "Zerquetschenderen": "Zerquetschendere",
    "Zerquetschendsten": "Zerquetschendste",
    "Zerquetschens": "Zerquetschen",
    "Zerquetschte": "zerquetscht",
    "Zerquetschten": "Zerquetschte",
    "Zerquetschteren": "Zerquetschtere",
    "Zerquetschtesten": "Zerquetschteste",
    "Zerrbilde": "Zerrbild",
    "Zerrbilder": "Zerrbild",
    "Zerrbildern": "Zerrbild",
    "Zerrbildes": "Zerrbild",
    "Zerrbilds": "Zerrbild",
    "Zerredenden": "Zerredende",
    "Zerredens": "Zerreden",
    "Zerredete": "zerredet",
    "Zerredeten": "Zerredete",
    "Zerreibenden": "Zerreibende",
    "Zerreibenderen": "Zerreibendere",
    "Zerreibendsten": "Zerreibendste",
    "Zerreibens": "Zerreiben",
    "Zerreißbaren": "Zerreißbare",
    "Zerreißbareren": "Zerreißbarere",
    "Zerreißbarsten": "Zerreißbarste",
    "Zerreißenden": "Zerreißende",
    "Zerreißenderen": "Zerreißendere",
    "Zerreißendsten": "Zerreißendste",
    "Zerreißens": "Zerreißen",
    "Zerreißproben": "Zerreißprobe",
    "Zerreißungen": "Zerreißung",
    "Zerrenden": "Zerrende",
    "Zerrens": "Zerren",
    "Zerriebenen": "Zerriebene",
    "Zerriebeneren": "Zerriebenere",
    "Zerriebensten": "Zerriebenste",
    "Zerrinnenden": "Zerrinnende",
    "Zerrinnens": "Zerrinnen",
    "Zerrissenen": "Zerrissene",
    "Zerrisseneren": "Zerrissenere",
    "Zerrissensten": "Zerrissenste",
    "Zerronnenen": "Zerronnene",
    "Zerronneneren": "Zerronnenere",
    "Zerronnensten": "Zerronnenste",
    "Zerrspiegeln": "Zerrspiegel",
    "Zerrspiegels": "Zerrspiegel",
    "Zerrungen": "Zerrung",
    "Zerrupfenden": "Zerrupfende",
    "Zerrupfenderen": "Zerrupfendere",
    "Zerrupfendsten": "Zerrupfendste",
    "Zerrupfens": "Zerrupfen",
    "Zerrupfte": "zerrupft",
    "Zerrupften": "Zerrupfte",
    "Zerrupfteren": "Zerrupftere",
    "Zerrupftesten": "Zerrupfteste",
    "Zerrüttelnden": "Zerrüttelnde",
    "Zerrüttelns": "Zerrütteln",
    "Zerrüttelte": "zerrüttelt",
    "Zerrüttelten": "Zerrüttelte",
    "Zerrüttelteren": "Zerrütteltere",
    "Zerrütteltesten": "Zerrüttelteste",
    "Zerrüttenden": "Zerrüttende",
    "Zerrüttenderen": "Zerrüttendere",
    "Zerrüttendsten": "Zerrüttendste",
    "Zerrüttens": "Zerrütten",
    "Zerrüttete": "zerrüttet",
    "Zerrütteten": "Zerrüttete",
    "Zerrütteteren": "Zerrüttetere",
    "Zerrüttetesten": "Zerrütteteste",
    "Zersalzenden": "Zersalzende",
    "Zersalzenen": "Zersalzene",
    "Zersalzeneren": "Zersalzenere",
    "Zersalzens": "Zersalzen",
    "Zersalzenste": "zersalzen",
    "Zersalzensten": "Zersalzenste",
    "Zerschellenden": "Zerschellende",
    "Zerschellenderen": "Zerschellendere",
    "Zerschellendsten": "Zerschellendste",
    "Zerschellens": "Zerschellen",
    "Zerschellte": "zerschellt",
    "Zerschellten": "Zerschellte",
    "Zerschellteren": "Zerschelltere",
    "Zerschelltesten": "Zerschellteste",
    "Zerscherenden": "Zerscherende",
    "Zerscherenderen": "Zerscherendere",
    "Zerscherendsten": "Zerscherendste",
    "Zerscherens": "Zerscheren",
    "Zerscheuernden": "Zerscheuernde",
    "Zerscheuernderen": "Zerscheuerndere",
    "Zerscheuerndsten": "Zerscheuerndste",
    "Zerscheuerns": "Zerscheuern",
    "Zerscheuerte": "zerscheuert",
    "Zerscheuerten": "Zerscheuerte",
    "Zerscheuerteren": "Zerscheuertere",
    "Zerscheuertesten": "Zerscheuerteste",
    "Zerschießenden": "Zerschießende",
    "Zerschießens": "Zerschießen",
    "Zerschindenden": "Zerschindende",
    "Zerschindenderen": "Zerschindendere",
    "Zerschindendsten": "Zerschindendste",
    "Zerschindens": "Zerschinden",
    "Zerschlagenden": "Zerschlagende",
    "Zerschlagenen": "Zerschlagene",
    "Zerschlageneren": "Zerschlagenere",
    "Zerschlagens": "Zerschlagen",
    "Zerschlagenste": "zerschlagen",
    "Zerschlagensten": "Zerschlagenste",
    "Zerschlissenen": "Zerschlissene",
    "Zerschlisseneren": "Zerschlissenere",
    "Zerschlissensten": "Zerschlissenste",
    "Zerschmeißenden": "Zerschmeißende",
    "Zerschmeißens": "Zerschmeißen",
    "Zerschmelzenden": "Zerschmelzende",
    "Zerschmelzenderen": "Zerschmelzendere",
    "Zerschmelzendsten": "Zerschmelzendste",
    "Zerschmelzens": "Zerschmelzen",
    "Zerschmetter": "zerschmettern",
    "Zerschmetternden": "Zerschmetternde",
    "Zerschmetternderen": "Zerschmetterndere",
    "Zerschmetterns": "Zerschmettern",
    "Zerschmetterte": "zerschmettert",
    "Zerschmetterten": "Zerschmetterte",
    "Zerschmetterteren": "Zerschmettertere",
    "Zerschmetterteste": "zerschmettert",
    "Zerschmissenen": "Zerschmissene",
    "Zerschmisseneren": "Zerschmissenere",
    "Zerschmissensten": "Zerschmissenste",
    "Zerschmolzenen": "Zerschmolzene",
    "Zerschmolzeneren": "Zerschmolzenere",
    "Zerschmolzensten": "Zerschmolzenste",
    "Zerschneidenden": "Zerschneidende",
    "Zerschneidenderen": "Zerschneidendere",
    "Zerschneidendsten": "Zerschneidendste",
    "Zerschneidens": "Zerschneiden",
    "Zerschnittenen": "Zerschnittene",
    "Zerschnitteneren": "Zerschnittenere",
    "Zerschnittensten": "Zerschnittenste",
    "Zerschorenen": "Zerschorene",
    "Zerschoreneren": "Zerschorenere",
    "Zerschorensten": "Zerschorenste",
    "Zerschossenen": "Zerschossene",
    "Zerschosseneren": "Zerschossenere",
    "Zerschossensten": "Zerschossenste",
    "Zerschundenen": "Zerschundene",
    "Zerschundeneren": "Zerschundenere",
    "Zerschundensten": "Zerschundenste",
    "Zersetzenden": "Zersetzende",
    "Zersetzenderen": "Zersetzendere",
    "Zersetzendsten": "Zersetzendste",
    "Zersetzens": "Zersetzen",
    "Zersetzte": "zersetzt",
    "Zersetzten": "Zersetzte",
    "Zersetzteren": "Zersetztere",
    "Zersetztesten": "Zersetzteste",
    "Zersiedelnden": "Zersiedelnde",
    "Zersiedelnderen": "Zersiedelndere",
    "Zersiedelndsten": "Zersiedelndste",
    "Zersiedelns": "Zersiedeln",
    "Zersiedelte": "zersiedelt",
    "Zersiedelten": "Zersiedelte",
    "Zersiedelteren": "Zersiedeltere",
    "Zersiedeltesten": "Zersiedelteste",
    "Zersiedenden": "Zersiedende",
    "Zersiedens": "Zersieden",
    "Zersiedete": "zersiedet",
    "Zersiedeten": "Zersiedete",
    "Zersottenen": "Zersottene",
    "Zerspaltenden": "Zerspaltende",
    "Zerspaltenderen": "Zerspaltendere",
    "Zerspaltendsten": "Zerspaltendste",
    "Zerspaltenen": "Zerspaltene",
    "Zerspalteneren": "Zerspaltenere",
    "Zerspaltens": "Zerspalten",
    "Zerspaltenste": "zerspalten",
    "Zerspaltensten": "Zerspaltenste",
    "Zersplitternden": "Zersplitternde",
    "Zersplitternderen": "Zersplitterndere",
    "Zersplitterndsten": "Zersplitterndste",
    "Zersplitterns": "Zersplittern",
    "Zersplitterte": "zersplittert",
    "Zersplitterten": "Zersplitterte",
    "Zersplitterteren": "Zersplittertere",
    "Zersplittertesten": "Zersplitterteste",
    "Zersplitterungen": "Zersplitterung",
    "Zersprengenden": "Zersprengende",
    "Zersprengens": "Zersprengen",
    "Zersprengte": "zersprengt",
    "Zersprengten": "Zersprengte",
    "Zerspringenden": "Zerspringende",
    "Zerspringens": "Zerspringen",
    "Zersprungenen": "Zersprungene",
    "Zersprungeneren": "Zersprungenere",
    "Zersprungensten": "Zersprungenste",
    "Zerstampfenden": "Zerstampfende",
    "Zerstampfenderen": "Zerstampfendere",
    "Zerstampfendsten": "Zerstampfendste",
    "Zerstampfens": "Zerstampfen",
    "Zerstampfte": "zerstampft",
    "Zerstampften": "Zerstampfte",
    "Zerstampfteren": "Zerstampftere",
    "Zerstampftesten": "Zerstampfteste",
    "Zerstechenden": "Zerstechende",
    "Zerstechens": "Zerstechen",
    "Zerstochenen": "Zerstochene",
    "Zerstocheneren": "Zerstochenere",
    "Zerstochensten": "Zerstochenste",
    "Zerstrahlungen": "Zerstrahlung",
    "Zerstreitenden": "Zerstreitende",
    "Zerstreitens": "Zerstreiten",
    "Zerstreuenden": "Zerstreuende",
    "Zerstreuens": "Zerstreuen",
    "Zerstreute": "zerstreut",
    "Zerstreuten": "Zerstreute",
    "Zerstreuungen": "Zerstreuung",
    "Zerstrittenen": "Zerstrittene",
    "Zerstritteneren": "Zerstrittenere",
    "Zerstrittensten": "Zerstrittenste",
    "Zerstäubenden": "Zerstäubende",
    "Zerstäubens": "Zerstäuben",
    "Zerstäubern": "Zerstäuber",
    "Zerstäubers": "Zerstäuber",
    "Zerstäubte": "zerstäubt",
    "Zerstäubten": "Zerstäubte",
    "Zerstörenden": "Zerstörende",
    "Zerstörens": "Zerstören",
    "Zerstörern": "Zerstörer",
    "Zerstörers": "Zerstörer",
    "Zerstörte": "zerstört",
    "Zerstörten": "Zerstörte",
    "Zerstörteren": "Zerstörtere",
    "Zerstörtesten": "Zerstörteste",
    "Zerstörungen": "Zerstörung",
    "Zerstückelnden": "Zerstückelnde",
    "Zerstückelnderen": "Zerstückelndere",
    "Zerstückelndsten": "Zerstückelndste",
    "Zerstückelns": "Zerstückeln",
    "Zerstückelte": "zerstückelt",
    "Zerstückelten": "Zerstückelte",
    "Zerstückelteren": "Zerstückeltere",
    "Zerstückeltesten": "Zerstückelteste",
    "Zerstümmelnden": "Zerstümmelnde",
    "Zerstümmelnderen": "Zerstümmelndere",
    "Zerstümmelndsten": "Zerstümmelndste",
    "Zerstümmelns": "Zerstümmeln",
    "Zerstümmelte": "zerstümmelt",
    "Zerstümmelten": "Zerstümmelte",
    "Zerstümmelteren": "Zerstümmeltere",
    "Zerstümmeltesten": "Zerstümmelteste",
    "Zersägenden": "Zersägende",
    "Zersägens": "Zersägen",
    "Zersägte": "zersägt",
    "Zersägten": "Zersägte",
    "Zerteilenden": "Zerteilende",
    "Zerteilens": "Zerteilen",
    "Zerteilte": "zerteilt",
    "Zerteilten": "Zerteilte",
    "Zerteilteren": "Zerteiltere",
    "Zerteiltesten": "Zerteilteste",
    "Zertifikate": "Zertifikat",
    "Zertifikaten": "Zertifikat",
    "Zertifikats": "Zertifikat",
    "Zertrampelnden": "Zertrampelnde",
    "Zertrampelnderen": "Zertrampelndere",
    "Zertrampelndsten": "Zertrampelndste",
    "Zertrampelns": "Zertrampeln",
    "Zertrampelte": "zertrampelt",
    "Zertrampelten": "Zertrampelte",
    "Zertrampelteren": "Zertrampeltere",
    "Zertrampeltesten": "Zertrampelteste",
    "Zertrennenden": "Zertrennende",
    "Zertrennens": "Zertrennen",
    "Zertrennte": "zertrennt",
    "Zertrennten": "Zertrennte",
    "Zertretenden": "Zertretende",
    "Zertretenen": "Zertretene",
    "Zertreteneren": "Zertretenere",
    "Zertretens": "Zertreten",
    "Zertretenste": "zertreten",
    "Zertretensten": "Zertretenste",
    "Zertrümmernden": "Zertrümmernde",
    "Zertrümmernderen": "Zertrümmerndere",
    "Zertrümmerndsten": "Zertrümmerndste",
    "Zertrümmerns": "Zertrümmern",
    "Zertrümmerte": "zertrümmert",
    "Zertrümmerten": "Zertrümmerte",
    "Zertrümmerteren": "Zertrümmertere",
    "Zertrümmertesten": "Zertrümmerteste",
    "Zertrümmerungen": "Zertrümmerung",
    "Zerwühlenden": "Zerwühlende",
    "Zerwühlenderen": "Zerwühlendere",
    "Zerwühlendsten": "Zerwühlendste",
    "Zerwühlens": "Zerwühlen",
    "Zerwühlte": "zerwühlt",
    "Zerwühlten": "Zerwühlte",
    "Zerwühlteren": "Zerwühltere",
    "Zerwühltesten": "Zerwühlteste",
    "Zerzausenden": "Zerzausende",
    "Zerzausenderen": "Zerzausendere",
    "Zerzausendsten": "Zerzausendste",
    "Zerzausens": "Zerzausen",
    "Zerzauste": "zerzaust",
    "Zerzausten": "Zerzauste",
    "Zerzausteren": "Zerzaustere",
    "Zerzaustesten": "Zerzausteste",
    "Zerzupfenden": "Zerzupfende",
    "Zerzupfens": "Zerzupfen",
    "Zerzupfte": "zerzupft",
    "Zerzupften": "Zerzupfte",
    "Zerzupfteren": "Zerzupftere",
    "Zerzupftesten": "Zerzupfteste",
    "Zetergeschreis": "Zetergeschrei",
    "Zettel": "zetteln",
    "Zettelkarteien": "Zettelkartei",
    "Zetteln": "Zettel",
    "Zettelnden": "Zettelnde",
    "Zettelns": "Zetteln",
    "Zettels": "Zettel",
    "Zeug": "zeugen",
    "Zeuge": "zeugen",
    "Zeugen": "Zeuge",
    "Zeugenden": "Zeugende",
    "Zeugens": "Zeugen",
    "Zeuges": "Zeug",
    "Zeuginnen": "Zeugin",
    "Zeugnisse": "Zeugnis",
    "Zeugnissen": "Zeugnis",
    "Zeugnisses": "Zeugnis",
    "Zeugs": "Zeug",
    "Zeugungen": "Zeugung",
    "Zeugungsfähige": "zeugungsfähig",
    "Zeugungsfähigen": "Zeugungsfähige",
    "Zeugungsfähigeren": "Zeugungsfähigere",
    "Zeugungsfähigsten": "Zeugungsfähigste",
    "Zeugungsunfähigen": "Zeugungsunfähige",
    "Zeugungsunfähigeren": "Zeugungsunfähigere",
    "Zickzacknähte": "Zickzacknaht",
    "Zickzacknähten": "Zickzacknaht",
    "Ziegeln": "Ziegel",
    "Ziegels": "Ziegel",
    "Ziegen": "Ziege",
    "Zieglers": "Ziegler",
    "Ziehenden": "Ziehende",
    "Ziehens": "Ziehen",
    "Ziehharmonikas": "Ziehharmonika",
    "Ziel": "zielen",
    "Ziele": "zielen",
    "Zielen": "Ziel",
    "Zielenden": "Zielende",
    "Zielens": "Zielen",
    "Zieles": "Ziel",
    "Ziellosen": "Ziellose",
    "Ziels": "Ziel",
    "Zielsetzungen": "Zielsetzung",
    "Zielsichere": "zielsicher",
    "Zielsicheren": "Zielsichere",
    "Zielsichereren": "Zielsicherere",
    "Zielsichersten": "Zielsicherste",
    "Zielstrebigen": "Zielstrebige",
    "Zielstrebigeren": "Zielstrebigere",
    "Zielstrebigsten": "Zielstrebigste",
    "Ziemenden": "Ziemende",
    "Ziemens": "Ziemen",
    "Ziemlichen": "Ziemliche",
    "Zierenden": "Zierende",
    "Zierenderen": "Zierendere",
    "Zierendsten": "Zierendste",
    "Zierens": "Zieren",
    "Zierleisten": "Zierleiste",
    "Zierliche": "zierlich",
    "Zierlichen": "Zierliche",
    "Zierlicheren": "Zierlichere",
    "Zierlichsten": "Zierlichste",
    "Zierpflanzen": "Zierpflanze",
    "Ziffern": "Ziffer",
    "Zigaretten": "Zigarette",
    "Zigarren": "Zigarre",
    "Zigeuner": "zigeunern",
    "Zigeunerischen": "Zigeunerische",
    "Zigeunern": "Zigeuner",
    "Zigeunernden": "Zigeunernde",
    "Zigeunerns": "Zigeunern",
    "Zigeuners": "Zigeuner",
    "Zigeunerte": "zigeunert",
    "Zigeunerten": "Zigeunerte",
    "Zigfachen": "Zigfache",
    "Zimbeln": "Zimbel",
    "Zimmer": "zimmern",
    "Zimmerern": "Zimmerer",
    "Zimmerers": "Zimmerer",
    "Zimmermanne": "Zimmermann",
    "Zimmermannes": "Zimmermann",
    "Zimmermanns": "Zimmermann",
    "Zimmermänner": "Zimmermann",
    "Zimmermännern": "Zimmermann",
    "Zimmern": "Zimmer",
    "Zimmernden": "Zimmernde",
    "Zimmerns": "Zimmern",
    "Zimmers": "Zimmer",
    "Zimperlichen": "Zimperliche",
    "Zimperlicheren": "Zimperlichere",
    "Zimperlichsten": "Zimperlichste",
    "Zimte": "Zimt",
    "Zimten": "Zimt",
    "Zimtes": "Zimt",
    "Zimts": "Zimt",
    "Zink": "zinken",
    "Zinke": "zinken",
    "Zinkenden": "Zinkende",
    "Zinkenderen": "Zinkendere",
    "Zinkendsten": "Zinkendste",
    "Zinkens": "Zinken",
    "Zinkes": "Zink",
    "Zinks": "Zink",
    "Zinne": "Zinn",
    "Zinnes": "Zinn",
    "Zinns": "Zinn",
    "Zinse": "Zins",
    "Zinsen": "Zins",
    "Zinses": "Zins",
    "Zinslose": "zinslos",
    "Zinslosen": "Zinslose",
    "Zinspflichtigen": "Zinspflichtige",
    "Zionisten": "Zionist",
    "Zionistische": "zionistisch",
    "Zionistischen": "Zionistische",
    "Zipfeln": "Zipfel",
    "Zipfels": "Zipfel",
    "Zirkel": "zirkeln",
    "Zirkeln": "Zirkel",
    "Zirkelnden": "Zirkelnde",
    "Zirkelnderen": "Zirkelndere",
    "Zirkelndsten": "Zirkelndste",
    "Zirkelns": "Zirkeln",
    "Zirkels": "Zirkel",
    "Zirkularen": "Zirkulare",
    "Zirkulierenden": "Zirkulierende",
    "Zirkulierens": "Zirkulieren",
    "Zirkulierte": "zirkuliert",
    "Zirkulierten": "Zirkulierte",
    "Zirndorfs": "Zirndorf",
    "Zirruswolken": "Zirruswolke",
    "Zischenden": "Zischende",
    "Zischenderen": "Zischendere",
    "Zischendsten": "Zischendste",
    "Zischens": "Zischen",
    "Zischlaute": "Zischlaut",
    "Zischlauten": "Zischlaut",
    "Zischlauts": "Zischlaut",
    "Zistrosen": "Zistrose",
    "Zitadellen": "Zitadelle",
    "Zitate": "Zitat",
    "Zitaten": "Zitat",
    "Zitats": "Zitat",
    "Zithern": "Zither",
    "Zitierenden": "Zitierende",
    "Zitierens": "Zitieren",
    "Zitierte": "zitiert",
    "Zitierten": "Zitierte",
    "Zitierteren": "Zitiertere",
    "Zitiertesten": "Zitierteste",
    "Zitronen": "Zitrone",
    "Zitrusfrüchte": "Zitrusfrucht",
    "Zitrusfrüchten": "Zitrusfrucht",
    "Zitteraale": "Zitteraal",
    "Zitteraalen": "Zitteraal",
    "Zitteraals": "Zitteraal",
    "Zitterigen": "Zitterige",
    "Zitterigeren": "Zitterigere",
    "Zitterigsten": "Zitterigste",
    "Zitterlaute": "Zitterlaut",
    "Zitterlauten": "Zitterlaut",
    "Zitterlauts": "Zitterlaut",
    "Zitternden": "Zitternde",
    "Zitternderen": "Zitterndere",
    "Zitterndsten": "Zitterndste",
    "Zitterns": "Zittern",
    "Zittrigen": "Zittrige",
    "Zittrigeren": "Zittrigere",
    "Zittrigsten": "Zittrigste",
    "Zivilbevölkerungen": "Zivilbevölkerung",
    "Zivildienste": "Zivildienst",
    "Zivildiensten": "Zivildienst",
    "Zivildienstes": "Zivildienst",
    "Zivildiensts": "Zivildienst",
    "Zivile": "zivil",
    "Zivilen": "Zivile",
    "Zivileren": "Zivilere",
    "Zivilisationen": "Zivilisation",
    "Zivilisten": "Zivilist",
    "Zivilregierungen": "Zivilregierung",
    "Zivilste": "zivil",
    "Zivilsten": "Zivilste",
    "Zivis": "Zivi",
    "Zobeln": "Zobel",
    "Zobels": "Zobel",
    "Zofen": "Zofe",
    "Zoffs": "Zoff",
    "Zoll": "zollen",
    "Zollamtliche": "zollamtlich",
    "Zollamtlichen": "Zollamtliche",
    "Zolle": "zollen",
    "Zollenden": "Zollende",
    "Zollens": "Zollen",
    "Zolles": "Zoll",
    "Zollfreien": "Zollfreie",
    "Zollpflichtige": "zollpflichtig",
    "Zollpflichtigen": "Zollpflichtige",
    "Zolls": "Zoll",
    "Zombies": "Zombie",
    "Zonen": "Zone",
    "Zoos": "Zoo",
    "Zopfe": "Zopf",
    "Zopfes": "Zopf",
    "Zopfs": "Zopf",
    "Zorcs": "Zorc",
    "Zornige": "zornig",
    "Zornigen": "Zornige",
    "Zornigeren": "Zornigere",
    "Zornigsten": "Zornigste",
    "Zorns": "Zorn",
    "Zottelige": "zottelig",
    "Zotteligen": "Zottelige",
    "Zotteligeren": "Zotteligere",
    "Zotteligsten": "Zotteligste",
    "Zuarbeitenden": "Zuarbeitende",
    "Zuarbeitens": "Zuarbeiten",
    "Zuballernden": "Zuballernde",
    "Zuballerns": "Zuballern",
    "Zubauenden": "Zubauende",
    "Zubauens": "Zubauen",
    "Zubehörs": "Zubehör",
    "Zubeißenden": "Zubeißende",
    "Zubeißens": "Zubeißen",
    "Zubekommenden": "Zubekommende",
    "Zubekommenen": "Zubekommene",
    "Zubekommens": "Zubekommen",
    "Zubereitenden": "Zubereitende",
    "Zubereitens": "Zubereiten",
    "Zubereitete": "zubereitet",
    "Zubereiteten": "Zubereitete",
    "Zubereitungen": "Zubereitung",
    "Zuberittenen": "Zuberittene",
    "Zubetonierenden": "Zubetonierende",
    "Zubetonierenderen": "Zubetonierendere",
    "Zubetonierendsten": "Zubetonierendste",
    "Zubetonierens": "Zubetonieren",
    "Zubetonierte": "zubetoniert",
    "Zubetonierten": "Zubetonierte",
    "Zubetonierteren": "Zubetoniertere",
    "Zubetoniertesten": "Zubetonierteste",
    "Zubilligenden": "Zubilligende",
    "Zubilligens": "Zubilligen",
    "Zubindenden": "Zubindende",
    "Zubindens": "Zubinden",
    "Zublinzelnden": "Zublinzelnde",
    "Zublinzelns": "Zublinzeln",
    "Zubringenden": "Zubringende",
    "Zubringens": "Zubringen",
    "Zubrote": "Zubrot",
    "Zubroten": "Zubrot",
    "Zubrots": "Zubrot",
    "Zubutternden": "Zubutternde",
    "Zubutterns": "Zubuttern",
    "Zubußen": "Zubuße",
    "Zuchthäuslern": "Zuchthäusler",
    "Zuchthäuslers": "Zuchthäusler",
    "Zuchtlosen": "Zuchtlose",
    "Zuchtloseren": "Zuchtlosere",
    "Zuchtlosesten": "Zuchtloseste",
    "Zuckenden": "Zuckende",
    "Zuckenderen": "Zuckendere",
    "Zuckendsten": "Zuckendste",
    "Zuckens": "Zucken",
    "Zuckers": "Zucker",
    "Zudenkenden": "Zudenkende",
    "Zudenkens": "Zudenken",
    "Zudienenden": "Zudienende",
    "Zudienens": "Zudienen",
    "Zudiktierenden": "Zudiktierende",
    "Zudiktierens": "Zudiktieren",
    "Zudiktierte": "zudiktiert",
    "Zudiktierten": "Zudiktierte",
    "Zudrehenden": "Zudrehende",
    "Zudrehens": "Zudrehen",
    "Zudringlichen": "Zudringliche",
    "Zudringlichkeiten": "Zudringlichkeit",
    "Zudrückenden": "Zudrückende",
    "Zudrückenderen": "Zudrückendere",
    "Zudrückendsten": "Zudrückendste",
    "Zudrückens": "Zudrücken",
    "Zueignenden": "Zueignende",
    "Zueignens": "Zueignen",
    "Zuerkannte": "zuerkennen",
    "Zuerkannten": "zuerkennen",
    "Zuerkennenden": "Zuerkennende",
    "Zuerkennens": "Zuerkennen",
    "Zufahrten": "Zufahrt",
    "Zufalle": "zufallen",
    "Zufallenden": "Zufallende",
    "Zufallens": "Zufallen",
    "Zufalles": "Zufall",
    "Zufalls": "Zufall",
    "Zufassenden": "Zufassende",
    "Zufassens": "Zufassen",
    "Zufaxenden": "Zufaxende",
    "Zufaxens": "Zufaxen",
    "Zufliegenden": "Zufliegende",
    "Zufliegens": "Zufliegen",
    "Zufließenden": "Zufließende",
    "Zufließens": "Zufließen",
    "Zufluchten": "Zuflucht",
    "Zuflüsternden": "Zuflüsternde",
    "Zuflüsterns": "Zuflüstern",
    "Zufriedenen": "Zufriedene",
    "Zufriedeneren": "Zufriedenere",
    "Zufriedengebenden": "Zufriedengebende",
    "Zufriedengebenderen": "Zufriedengebendere",
    "Zufriedengebens": "Zufriedengeben",
    "Zufriedengegebenen": "Zufriedengegebene",
    "Zufriedengegebeneren": "Zufriedengegebenere",
    "Zufriedengelassenen": "Zufriedengelassene",
    "Zufriedengestellten": "Zufriedengestellte",
    "Zufriedengestellteren": "Zufriedengestelltere",
    "Zufriedenheiten": "Zufriedenheit",
    "Zufriedenlassenden": "Zufriedenlassende",
    "Zufriedenlassens": "Zufriedenlassen",
    "Zufriedenstellenden": "Zufriedenstellende",
    "Zufriedenstellenderen": "Zufriedenstellendere",
    "Zufriedenstellens": "Zufriedenstellen",
    "Zufriedensten": "Zufriedenste",
    "Zufrierenden": "Zufrierende",
    "Zufrierenderen": "Zufrierendere",
    "Zufrierendsten": "Zufrierendste",
    "Zufrierens": "Zufrieren",
    "Zufächelnden": "Zufächelnde",
    "Zufächelns": "Zufächeln",
    "Zufälle": "Zufall",
    "Zufällen": "Zufall",
    "Zufälligen": "Zufällige",
    "Zufälligeren": "Zufälligere",
    "Zufälligsten": "Zufälligste",
    "Zufügenden": "Zufügende",
    "Zufügens": "Zufügen",
    "Zuführenden": "Zuführende",
    "Zuführenderen": "Zuführendere",
    "Zuführendsten": "Zuführendste",
    "Zuführens": "Zuführen",
    "Zuführungen": "Zuführung",
    "Zugange": "Zugang",
    "Zuganges": "Zugang",
    "Zugangs": "Zugang",
    "Zuge": "Zug",
    "Zugearbeiteten": "Zugearbeitete",
    "Zugeballerten": "Zugeballerte",
    "Zugebauten": "Zugebaute",
    "Zugebauteren": "Zugebautere",
    "Zugebautesten": "Zugebauteste",
    "Zugebenden": "Zugebende",
    "Zugebens": "Zugeben",
    "Zugebilligten": "Zugebilligte",
    "Zugebissenen": "Zugebissene",
    "Zugeblinzelten": "Zugeblinzelte",
    "Zugebrachten": "Zugebrachte",
    "Zugebundenen": "Zugebundene",
    "Zugebundeneren": "Zugebundenere",
    "Zugebundensten": "Zugebundenste",
    "Zugebutterten": "Zugebutterte",
    "Zugedachten": "Zugedachte",
    "Zugedienten": "Zugediente",
    "Zugedrehten": "Zugedrehte",
    "Zugedrückten": "Zugedrückte",
    "Zugeeigneten": "Zugeeignete",
    "Zugefallenen": "Zugefallene",
    "Zugefaxten": "Zugefaxte",
    "Zugefaßten": "Zugefaßte",
    "Zugeflogenen": "Zugeflogene",
    "Zugeflossenen": "Zugeflossene",
    "Zugeflüsterten": "Zugeflüsterte",
    "Zugefrorenen": "Zugefrorene",
    "Zugefroreneren": "Zugefrorenere",
    "Zugefrorensten": "Zugefrorenste",
    "Zugefächelten": "Zugefächelte",
    "Zugefügten": "Zugefügte",
    "Zugeführten": "Zugeführte",
    "Zugegangenen": "Zugegangene",
    "Zugegebenen": "Zugegebene",
    "Zugegossenen": "Zugegossene",
    "Zugegriffenen": "Zugegriffene",
    "Zugegriffeneren": "Zugegriffenere",
    "Zugegriffensten": "Zugegriffenste",
    "Zugehakten": "Zugehakte",
    "Zugehaltenen": "Zugehaltene",
    "Zugehauenen": "Zugehauene",
    "Zugeheilten": "Zugeheilte",
    "Zugeheilteren": "Zugeheiltere",
    "Zugeheiltesten": "Zugeheilteste",
    "Zugehenden": "Zugehende",
    "Zugehens": "Zugehen",
    "Zugehfrauen": "Zugehfrau",
    "Zugehängten": "Zugehängte",
    "Zugehörenden": "Zugehörende",
    "Zugehörens": "Zugehören",
    "Zugehörigen": "Zugehörige",
    "Zugehörte": "zugehört",
    "Zugehörten": "Zugehörte",
    "Zugejauchzten": "Zugejauchzte",
    "Zugejauchzteren": "Zugejauchztere",
    "Zugejauchztesten": "Zugejauchzteste",
    "Zugejubelten": "Zugejubelte",
    "Zugejubelteren": "Zugejubeltere",
    "Zugejubeltesten": "Zugejubelteste",
    "Zugekehrten": "Zugekehrte",
    "Zugeklappten": "Zugeklappte",
    "Zugeklebten": "Zugeklebte",
    "Zugeklinkten": "Zugeklinkte",
    "Zugeknallten": "Zugeknallte",
    "Zugeknöpften": "Zugeknöpfte",
    "Zugekommenen": "Zugekommene",
    "Zugekorkten": "Zugekorkte",
    "Zugekriegten": "Zugekriegte",
    "Zugelachten": "Zugelachte",
    "Zugeladenen": "Zugeladene",
    "Zugelangten": "Zugelangte",
    "Zugelassenen": "Zugelassene",
    "Zugelaufenen": "Zugelaufene",
    "Zugelegten": "Zugelegte",
    "Zugeleiteten": "Zugeleitete",
    "Zugelächelten": "Zugelächelte",
    "Zugelächelteren": "Zugelächeltere",
    "Zugelächeltesten": "Zugelächelteste",
    "Zugelöteten": "Zugelötete",
    "Zugemachten": "Zugemachte",
    "Zugemauerten": "Zugemauerte",
    "Zugemauerteren": "Zugemauertere",
    "Zugemauertesten": "Zugemauerteste",
    "Zugemessenen": "Zugemessene",
    "Zugemuteten": "Zugemutete",
    "Zugenagelten": "Zugenagelte",
    "Zugeneigten": "Zugeneigte",
    "Zugeneigteren": "Zugeneigtere",
    "Zugeneigtesten": "Zugeneigteste",
    "Zugenommenen": "Zugenommene",
    "Zugenommeneren": "Zugenommenere",
    "Zugenommensten": "Zugenommenste",
    "Zugenähten": "Zugenähte",
    "Zugeordneten": "Zugeordnete",
    "Zugepackten": "Zugepackte",
    "Zugepfropften": "Zugepfropfte",
    "Zugepfropfteren": "Zugepfropftere",
    "Zugepfropftesten": "Zugepfropfteste",
    "Zugeprosteten": "Zugeprostete",
    "Zugeratenen": "Zugeratene",
    "Zugeraunten": "Zugeraunte",
    "Zugerechneten": "Zugerechnete",
    "Zugeredeten": "Zugeredete",
    "Zugereichten": "Zugereichte",
    "Zugereisten": "Zugereiste",
    "Zugerichteten": "Zugerichtete",
    "Zugeriegelten": "Zugeriegelte",
    "Zugerittenen": "Zugerittene",
    "Zugerollten": "Zugerollte",
    "Zugerufenen": "Zugerufene",
    "Zugerüsteten": "Zugerüstete",
    "Zuges": "Zug",
    "Zugesagten": "Zugesagte",
    "Zugesandten": "Zugesandte",
    "Zugeschanzten": "Zugeschanzte",
    "Zugeschaufelten": "Zugeschaufelte",
    "Zugeschauten": "Zugeschaute",
    "Zugeschlagenen": "Zugeschlagene",
    "Zugeschlossenen": "Zugeschlossene",
    "Zugeschmissenen": "Zugeschmissene",
    "Zugeschnallten": "Zugeschnallte",
    "Zugeschnappten": "Zugeschnappte",
    "Zugeschneiten": "Zugeschneite",
    "Zugeschneiteren": "Zugeschneitere",
    "Zugeschneitesten": "Zugeschneiteste",
    "Zugeschnittenen": "Zugeschnittene",
    "Zugeschnürten": "Zugeschnürte",
    "Zugeschobenen": "Zugeschobene",
    "Zugeschossenen": "Zugeschossene",
    "Zugeschraubten": "Zugeschraubte",
    "Zugeschriebenen": "Zugeschriebene",
    "Zugeschusterten": "Zugeschusterte",
    "Zugeschütteten": "Zugeschüttete",
    "Zugeschütteteren": "Zugeschüttetere",
    "Zugeschüttetesten": "Zugeschütteteste",
    "Zugesehenen": "Zugesehene",
    "Zugesellenden": "Zugesellende",
    "Zugesellens": "Zugesellen",
    "Zugesellte": "zugesellt",
    "Zugesellten": "Zugesellte",
    "Zugesendeten": "Zugesendete",
    "Zugesessenen": "Zugesessene",
    "Zugesetzten": "Zugesetzte",
    "Zugesicherten": "Zugesicherte",
    "Zugesperrten": "Zugesperrte",
    "Zugespielten": "Zugespielte",
    "Zugespitzten": "Zugespitzte",
    "Zugesprochenen": "Zugesprochene",
    "Zugesprungenen": "Zugesprungene",
    "Zugestandenen": "Zugestandene",
    "Zugestandeneren": "Zugestandenere",
    "Zugestandensten": "Zugestandenste",
    "Zugesteckten": "Zugesteckte",
    "Zugestehenden": "Zugestehende",
    "Zugestehenderen": "Zugestehendere",
    "Zugestehendsten": "Zugestehendste",
    "Zugestehens": "Zugestehen",
    "Zugestellten": "Zugestellte",
    "Zugesteuerten": "Zugesteuerte",
    "Zugestiegenen": "Zugestiegene",
    "Zugestimmten": "Zugestimmte",
    "Zugestochenen": "Zugestochene",
    "Zugestopften": "Zugestopfte",
    "Zugestopfteren": "Zugestopftere",
    "Zugestopftesten": "Zugestopfteste",
    "Zugestoßenen": "Zugestoßene",
    "Zugestrebten": "Zugestrebte",
    "Zugeströmten": "Zugeströmte",
    "Zugestutzten": "Zugestutzte",
    "Zugeständnisse": "Zugeständnis",
    "Zugeständnissen": "Zugeständnis",
    "Zugeständnisses": "Zugeständnis",
    "Zugestöpselten": "Zugestöpselte",
    "Zugestürzten": "Zugestürzte",
    "Zugeteilten": "Zugeteilte",
    "Zugetragenen": "Zugetragene",
    "Zugetrauten": "Zugetraute",
    "Zugetriebenen": "Zugetriebene",
    "Zugetroffenen": "Zugetroffene",
    "Zugetrunkenen": "Zugetrunkene",
    "Zugewanderten": "Zugewanderte",
    "Zugewehten": "Zugewehte",
    "Zugewehteren": "Zugewehtere",
    "Zugewehtesten": "Zugewehteste",
    "Zugewendeten": "Zugewendete",
    "Zugewiesenen": "Zugewiesene",
    "Zugewinkten": "Zugewinkte",
    "Zugeworfenen": "Zugeworfene",
    "Zugezahlten": "Zugezahlte",
    "Zugezogenen": "Zugezogene",
    "Zugezwinkerten": "Zugezwinkerte",
    "Zugezählte": "zugezählt",
    "Zugezählten": "Zugezählte",
    "Zugießenden": "Zugießende",
    "Zugießens": "Zugießen",
    "Zugkräftigen": "Zugkräftige",
    "Zugkräftigeren": "Zugkräftigere",
    "Zugkräftigsten": "Zugkräftigste",
    "Zugreifenden": "Zugreifende",
    "Zugreifenderen": "Zugreifendere",
    "Zugreifendsten": "Zugreifendste",
    "Zugreifens": "Zugreifen",
    "Zugriffsbereiten": "Zugriffsbereite",
    "Zugriffsbereiteren": "Zugriffsbereitere",
    "Zugs": "Zug",
    "Zugänge": "Zugang",
    "Zugängen": "Zugang",
    "Zugängliche": "zugänglich",
    "Zugänglichen": "Zugängliche",
    "Zugänglicheren": "Zugänglichere",
    "Zugänglichsten": "Zugänglichste",
    "Zuhakenden": "Zuhakende",
    "Zuhakens": "Zuhaken",
    "Zuhaltenden": "Zuhaltende",
    "Zuhaltens": "Zuhalten",
    "Zuhauenden": "Zuhauende",
    "Zuhauens": "Zuhauen",
    "Zuheilenden": "Zuheilende",
    "Zuheilenderen": "Zuheilendere",
    "Zuheilendsten": "Zuheilendste",
    "Zuheilens": "Zuheilen",
    "Zuhältern": "Zuhälter",
    "Zuhälters": "Zuhälter",
    "Zuhängenden": "Zuhängende",
    "Zuhängens": "Zuhängen",
    "Zuhörenden": "Zuhörende",
    "Zuhörenderen": "Zuhörendere",
    "Zuhörendsten": "Zuhörendste",
    "Zuhörens": "Zuhören",
    "Zuhörern": "Zuhörer",
    "Zuhörers": "Zuhörer",
    "Zujauchzenden": "Zujauchzende",
    "Zujauchzenderen": "Zujauchzendere",
    "Zujauchzendsten": "Zujauchzendste",
    "Zujauchzens": "Zujauchzen",
    "Zujubelnden": "Zujubelnde",
    "Zujubelnderen": "Zujubelndere",
    "Zujubelndsten": "Zujubelndste",
    "Zujubelns": "Zujubeln",
    "Zukehrenden": "Zukehrende",
    "Zukehrens": "Zukehren",
    "Zuklappenden": "Zuklappende",
    "Zuklappens": "Zuklappen",
    "Zuklebenden": "Zuklebende",
    "Zuklebens": "Zukleben",
    "Zuklinkenden": "Zuklinkende",
    "Zuklinkens": "Zuklinken",
    "Zuknallenden": "Zuknallende",
    "Zuknallens": "Zuknallen",
    "Zuknöpfenden": "Zuknöpfende",
    "Zuknöpfens": "Zuknöpfen",
    "Zukommenden": "Zukommende",
    "Zukommens": "Zukommen",
    "Zukorkenden": "Zukorkende",
    "Zukorkens": "Zukorken",
    "Zukriegenden": "Zukriegende",
    "Zukriegens": "Zukriegen",
    "Zukunftsträchtigen": "Zukunftsträchtige",
    "Zukunftsträchtigeren": "Zukunftsträchtigere",
    "Zukünftigen": "Zukünftige",
    "Zulachenden": "Zulachende",
    "Zulachens": "Zulachen",
    "Zuladenden": "Zuladende",
    "Zuladens": "Zuladen",
    "Zulangenden": "Zulangende",
    "Zulangens": "Zulangen",
    "Zulassenden": "Zulassende",
    "Zulassens": "Zulassen",
    "Zulassungen": "Zulassung",
    "Zulassungsbehörden": "Zulassungsbehörde",
    "Zulassungsbestimmungen": "Zulassungsbestimmung",
    "Zulaufe": "zulaufen",
    "Zulaufenden": "Zulaufende",
    "Zulaufens": "Zulaufen",
    "Zulaufs": "Zulauf",
    "Zulegenden": "Zulegende",
    "Zulegens": "Zulegen",
    "Zuleitenden": "Zuleitende",
    "Zuleitens": "Zuleiten",
    "Zulieferern": "Zulieferer",
    "Zulieferers": "Zulieferer",
    "Zulächelnden": "Zulächelnde",
    "Zulächelnderen": "Zulächelndere",
    "Zulächelndsten": "Zulächelndste",
    "Zulächelns": "Zulächeln",
    "Zulässigen": "Zulässige",
    "Zulässigeren": "Zulässigere",
    "Zulässigsten": "Zulässigste",
    "Zuläufe": "Zulauf",
    "Zuläufen": "Zulauf",
    "Zulötenden": "Zulötende",
    "Zulötens": "Zulöten",
    "Zumachenden": "Zumachende",
    "Zumachens": "Zumachen",
    "Zumauernden": "Zumauernde",
    "Zumauernderen": "Zumauerndere",
    "Zumauerndsten": "Zumauerndste",
    "Zumauerns": "Zumauern",
    "Zumessenden": "Zumessende",
    "Zumessens": "Zumessen",
    "Zumutenden": "Zumutende",
    "Zumutens": "Zumuten",
    "Zumutungen": "Zumutung",
    "Zunagelnden": "Zunagelnde",
    "Zunagelns": "Zunageln",
    "Zunahmen": "zunehmen",
    "Zunehmenden": "Zunehmende",
    "Zunehmenderen": "Zunehmendere",
    "Zunehmendsten": "Zunehmendste",
    "Zunehmens": "Zunehmen",
    "Zuneigenden": "Zuneigende",
    "Zuneigenderen": "Zuneigendere",
    "Zuneigendsten": "Zuneigendste",
    "Zuneigens": "Zuneigen",
    "Zuneigungen": "Zuneigung",
    "Zungen": "Zunge",
    "Zungenbrechern": "Zungenbrecher",
    "Zungenbrechers": "Zungenbrecher",
    "Zunähenden": "Zunähende",
    "Zunähens": "Zunähen",
    "Zuordnenden": "Zuordnende",
    "Zuordnens": "Zuordnen",
    "Zuordnungen": "Zuordnung",
    "Zupackenden": "Zupackende",
    "Zupackenderen": "Zupackendere",
    "Zupackendsten": "Zupackendste",
    "Zupackens": "Zupacken",
    "Zupfenden": "Zupfende",
    "Zupfens": "Zupfen",
    "Zupfgeigen": "Zupfgeige",
    "Zupfropfenden": "Zupfropfende",
    "Zupfropfenderen": "Zupfropfendere",
    "Zupfropfendsten": "Zupfropfendste",
    "Zupfropfens": "Zupfropfen",
    "Zuprostenden": "Zuprostende",
    "Zuprostens": "Zuprosten",
    "Zuratenden": "Zuratende",
    "Zuratens": "Zuraten",
    "Zuraunenden": "Zuraunende",
    "Zuraunens": "Zuraunen",
    "Zurechnenden": "Zurechnende",
    "Zurechnens": "Zurechnen",
    "Zurechnungsfähigen": "Zurechnungsfähige",
    "Zurechnungsfähigeren": "Zurechnungsfähigere",
    "Zurechtbiegenden": "Zurechtbiegende",
    "Zurechtbiegenderen": "Zurechtbiegendere",
    "Zurechtbiegens": "Zurechtbiegen",
    "Zurechtfindenden": "Zurechtfindende",
    "Zurechtfindenderen": "Zurechtfindendere",
    "Zurechtfindens": "Zurechtfinden",
    "Zurechtgebogenen": "Zurechtgebogene",
    "Zurechtgebogeneren": "Zurechtgebogenere",
    "Zurechtgefundenen": "Zurechtgefundene",
    "Zurechtgefundeneren": "Zurechtgefundenere",
    "Zurechtgekommenen": "Zurechtgekommene",
    "Zurechtgekommeneren": "Zurechtgekommenere",
    "Zurechtgekriegten": "Zurechtgekriegte",
    "Zurechtgelegten": "Zurechtgelegte",
    "Zurechtgemachten": "Zurechtgemachte",
    "Zurechtgemachteren": "Zurechtgemachtere",
    "Zurechtgeschusterten": "Zurechtgeschusterte",
    "Zurechtgesetzten": "Zurechtgesetzte",
    "Zurechtgestutzten": "Zurechtgestutzte",
    "Zurechtgewiesenen": "Zurechtgewiesene",
    "Zurechtgewieseneren": "Zurechtgewiesenere",
    "Zurechtgezimmerten": "Zurechtgezimmerte",
    "Zurechtkommenden": "Zurechtkommende",
    "Zurechtkommenderen": "Zurechtkommendere",
    "Zurechtkommens": "Zurechtkommen",
    "Zurechtkriegenden": "Zurechtkriegende",
    "Zurechtkriegens": "Zurechtkriegen",
    "Zurechtlegenden": "Zurechtlegende",
    "Zurechtlegens": "Zurechtlegen",
    "Zurechtmachenden": "Zurechtmachende",
    "Zurechtmachenderen": "Zurechtmachendere",
    "Zurechtmachens": "Zurechtmachen",
    "Zurechtschusternden": "Zurechtschusternde",
    "Zurechtschusterns": "Zurechtschustern",
    "Zurechtsetzenden": "Zurechtsetzende",
    "Zurechtsetzens": "Zurechtsetzen",
    "Zurechtstutzenden": "Zurechtstutzende",
    "Zurechtstutzens": "Zurechtstutzen",
    "Zurechtweisenden": "Zurechtweisende",
    "Zurechtweisenderen": "Zurechtweisendere",
    "Zurechtweisens": "Zurechtweisen",
    "Zurechtweisungen": "Zurechtweisung",
    "Zurechtzimmernden": "Zurechtzimmernde",
    "Zurechtzimmerns": "Zurechtzimmern",
    "Zuredenden": "Zuredende",
    "Zuredens": "Zureden",
    "Zureichenden": "Zureichende",
    "Zureichens": "Zureichen",
    "Zureitenden": "Zureitende",
    "Zureitens": "Zureiten",
    "Zurichtenden": "Zurichtende",
    "Zurichtens": "Zurichten",
    "Zurichtern": "Zurichter",
    "Zurichters": "Zurichter",
    "Zuriegelnden": "Zuriegelnde",
    "Zuriegelns": "Zuriegeln",
    "Zurollenden": "Zurollende",
    "Zurollens": "Zurollen",
    "Zurrenden": "Zurrende",
    "Zurrens": "Zurren",
    "Zurufenden": "Zurufende",
    "Zurufens": "Zurufen",
    "Zurückbegebenden": "Zurückbegebende",
    "Zurückbegebenen": "Zurückbegebene",
    "Zurückbegebens": "Zurückbegeben",
    "Zurückbegleitenden": "Zurückbegleitende",
    "Zurückbegleitens": "Zurückbegleiten",
    "Zurückbegleitete": "zurückbegleitet",
    "Zurückbegleiteten": "Zurückbegleitete",
    "Zurückbehaltenden": "Zurückbehaltende",
    "Zurückbehaltenen": "Zurückbehaltene",
    "Zurückbehaltens": "Zurückbehalten",
    "Zurückbekommenden": "Zurückbekommende",
    "Zurückbekommenen": "Zurückbekommene",
    "Zurückbekommens": "Zurückbekommen",
    "Zurückbeugenden": "Zurückbeugende",
    "Zurückbeugenderen": "Zurückbeugendere",
    "Zurückbeugendsten": "Zurückbeugendste",
    "Zurückbeugens": "Zurückbeugen",
    "Zurückbewegenden": "Zurückbewegende",
    "Zurückbewegens": "Zurückbewegen",
    "Zurückbewegte": "zurückbewegt",
    "Zurückbewegten": "Zurückbewegte",
    "Zurückbewogenen": "Zurückbewogene",
    "Zurückbiegenden": "Zurückbiegende",
    "Zurückbiegens": "Zurückbiegen",
    "Zurückbildenden": "Zurückbildende",
    "Zurückbildenderen": "Zurückbildendere",
    "Zurückbildendsten": "Zurückbildendste",
    "Zurückbildens": "Zurückbilden",
    "Zurückbleibenden": "Zurückbleibende",
    "Zurückbleibens": "Zurückbleiben",
    "Zurückblickenden": "Zurückblickende",
    "Zurückblickenderen": "Zurückblickendere",
    "Zurückblickens": "Zurückblicken",
    "Zurückbringenden": "Zurückbringende",
    "Zurückbringens": "Zurückbringen",
    "Zurückdatierenden": "Zurückdatierende",
    "Zurückdatierens": "Zurückdatieren",
    "Zurückdatierte": "zurückdatiert",
    "Zurückdatierten": "Zurückdatierte",
    "Zurückdenkenden": "Zurückdenkende",
    "Zurückdenkens": "Zurückdenken",
    "Zurückdrehenden": "Zurückdrehende",
    "Zurückdrehens": "Zurückdrehen",
    "Zurückdrängenden": "Zurückdrängende",
    "Zurückdrängenderen": "Zurückdrängendere",
    "Zurückdrängens": "Zurückdrängen",
    "Zurückeilenden": "Zurückeilende",
    "Zurückeilens": "Zurückeilen",
    "Zurückerbetenen": "Zurückerbetene",
    "Zurückerbittenden": "Zurückerbittende",
    "Zurückerbittens": "Zurückerbitten",
    "Zurückerhaltenden": "Zurückerhaltende",
    "Zurückerhaltenen": "Zurückerhaltene",
    "Zurückerhaltens": "Zurückerhalten",
    "Zurückerinnernden": "Zurückerinnernde",
    "Zurückerinnerns": "Zurückerinnern",
    "Zurückerinnerte": "zurückerinnert",
    "Zurückerinnerten": "Zurückerinnerte",
    "Zurückerlangenden": "Zurückerlangende",
    "Zurückerlangens": "Zurückerlangen",
    "Zurückerlangte": "zurückerlangt",
    "Zurückerlangten": "Zurückerlangte",
    "Zurückerobernden": "Zurückerobernde",
    "Zurückeroberns": "Zurückerobern",
    "Zurückeroberte": "zurückerobert",
    "Zurückeroberten": "Zurückeroberte",
    "Zurückerstattenden": "Zurückerstattende",
    "Zurückerstattens": "Zurückerstatten",
    "Zurückerstattete": "zurückerstattet",
    "Zurückerstatteten": "Zurückerstattete",
    "Zurückerwartenden": "Zurückerwartende",
    "Zurückerwartens": "Zurückerwarten",
    "Zurückerwartete": "zurückerwartet",
    "Zurückerwarteten": "Zurückerwartete",
    "Zurückerwerbenden": "Zurückerwerbende",
    "Zurückerwerbens": "Zurückerwerben",
    "Zurückerworbenen": "Zurückerworbene",
    "Zurückfahrenden": "Zurückfahrende",
    "Zurückfahrens": "Zurückfahren",
    "Zurückfallenden": "Zurückfallende",
    "Zurückfallens": "Zurückfallen",
    "Zurückfindenden": "Zurückfindende",
    "Zurückfindens": "Zurückfinden",
    "Zurückfliegenden": "Zurückfliegende",
    "Zurückfliegens": "Zurückfliegen",
    "Zurückfließenden": "Zurückfließende",
    "Zurückfließens": "Zurückfließen",
    "Zurückfordernden": "Zurückfordernde",
    "Zurückforderns": "Zurückfordern",
    "Zurückfragenden": "Zurückfragende",
    "Zurückfragens": "Zurückfragen",
    "Zurückführenden": "Zurückführende",
    "Zurückführens": "Zurückführen",
    "Zurückgebenden": "Zurückgebende",
    "Zurückgebens": "Zurückgeben",
    "Zurückgebeugten": "Zurückgebeugte",
    "Zurückgebeugteren": "Zurückgebeugtere",
    "Zurückgebildeten": "Zurückgebildete",
    "Zurückgebildeteren": "Zurückgebildetere",
    "Zurückgeblickten": "Zurückgeblickte",
    "Zurückgebliebenen": "Zurückgebliebene",
    "Zurückgebogenen": "Zurückgebogene",
    "Zurückgebrachten": "Zurückgebrachte",
    "Zurückgedachten": "Zurückgedachte",
    "Zurückgedrehten": "Zurückgedrehte",
    "Zurückgedrängten": "Zurückgedrängte",
    "Zurückgedrängteren": "Zurückgedrängtere",
    "Zurückgeeilten": "Zurückgeeilte",
    "Zurückgefahrenen": "Zurückgefahrene",
    "Zurückgefallenen": "Zurückgefallene",
    "Zurückgeflogenen": "Zurückgeflogene",
    "Zurückgeflossenen": "Zurückgeflossene",
    "Zurückgeforderten": "Zurückgeforderte",
    "Zurückgefragten": "Zurückgefragte",
    "Zurückgefundenen": "Zurückgefundene",
    "Zurückgeführten": "Zurückgeführte",
    "Zurückgegangenen": "Zurückgegangene",
    "Zurückgegebenen": "Zurückgegebene",
    "Zurückgegriffenen": "Zurückgegriffene",
    "Zurückgehaltenen": "Zurückgehaltene",
    "Zurückgehenden": "Zurückgehende",
    "Zurückgehens": "Zurückgehen",
    "Zurückgeholten": "Zurückgeholte",
    "Zurückgejagten": "Zurückgejagte",
    "Zurückgekauften": "Zurückgekaufte",
    "Zurückgekehrten": "Zurückgekehrte",
    "Zurückgeklappten": "Zurückgeklappte",
    "Zurückgekommenen": "Zurückgekommene",
    "Zurückgekämmten": "Zurückgekämmte",
    "Zurückgelassenen": "Zurückgelassene",
    "Zurückgelaufenen": "Zurückgelaufene",
    "Zurückgelegenen": "Zurückgelegene",
    "Zurückgelehnten": "Zurückgelehnte",
    "Zurückgelehnteren": "Zurückgelehntere",
    "Zurückgemeldeten": "Zurückgemeldete",
    "Zurückgenommenen": "Zurückgenommene",
    "Zurückgeprallten": "Zurückgeprallte",
    "Zurückgereisten": "Zurückgereiste",
    "Zurückgerissenen": "Zurückgerissene",
    "Zurückgerittenen": "Zurückgerittene",
    "Zurückgerollten": "Zurückgerollte",
    "Zurückgerufenen": "Zurückgerufene",
    "Zurückgesandten": "Zurückgesandte",
    "Zurückgeschaffenen": "Zurückgeschaffene",
    "Zurückgeschafften": "Zurückgeschaffte",
    "Zurückgeschallten": "Zurückgeschallte",
    "Zurückgeschalteten": "Zurückgeschaltete",
    "Zurückgeschauderten": "Zurückgeschauderte",
    "Zurückgeschauderteren": "Zurückgeschaudertere",
    "Zurückgeschauten": "Zurückgeschaute",
    "Zurückgescheuchten": "Zurückgescheuchte",
    "Zurückgescheuten": "Zurückgescheute",
    "Zurückgeschlagenen": "Zurückgeschlagene",
    "Zurückgeschnellten": "Zurückgeschnellte",
    "Zurückgeschobenen": "Zurückgeschobene",
    "Zurückgeschraubten": "Zurückgeschraubte",
    "Zurückgeschreckten": "Zurückgeschreckte",
    "Zurückgeschreckteren": "Zurückgeschrecktere",
    "Zurückgeschriebenen": "Zurückgeschriebene",
    "Zurückgeschrockenen": "Zurückgeschrockene",
    "Zurückgeschwommenen": "Zurückgeschwommene",
    "Zurückgesehnten": "Zurückgesehnte",
    "Zurückgesehnteren": "Zurückgesehntere",
    "Zurückgesendeten": "Zurückgesendete",
    "Zurückgesetzten": "Zurückgesetzte",
    "Zurückgesprungenen": "Zurückgesprungene",
    "Zurückgespulten": "Zurückgespulte",
    "Zurückgestandenen": "Zurückgestandene",
    "Zurückgestellten": "Zurückgestellte",
    "Zurückgestoßenen": "Zurückgestoßene",
    "Zurückgestrahlten": "Zurückgestrahlte",
    "Zurückgestrahlteren": "Zurückgestrahltere",
    "Zurückgestreiften": "Zurückgestreifte",
    "Zurückgestrichenen": "Zurückgestrichene",
    "Zurückgeströmten": "Zurückgeströmte",
    "Zurückgestutzten": "Zurückgestutzte",
    "Zurückgesunkenen": "Zurückgesunkene",
    "Zurückgetaumelten": "Zurückgetaumelte",
    "Zurückgetragenen": "Zurückgetragene",
    "Zurückgetretenen": "Zurückgetretene",
    "Zurückgetriebenen": "Zurückgetriebene",
    "Zurückgewanderten": "Zurückgewanderte",
    "Zurückgeweichten": "Zurückgeweichte",
    "Zurückgewichenen": "Zurückgewichene",
    "Zurückgewiesenen": "Zurückgewiesene",
    "Zurückgewieseneren": "Zurückgewiesenere",
    "Zurückgewinnenden": "Zurückgewinnende",
    "Zurückgewinnens": "Zurückgewinnen",
    "Zurückgewirkten": "Zurückgewirkte",
    "Zurückgewonnenen": "Zurückgewonnene",
    "Zurückgeworfenen": "Zurückgeworfene",
    "Zurückgeworfeneren": "Zurückgeworfenere",
    "Zurückgewünschten": "Zurückgewünschte",
    "Zurückgezahlten": "Zurückgezahlte",
    "Zurückgezogenen": "Zurückgezogene",
    "Zurückgezogeneren": "Zurückgezogenere",
    "Zurückgezogensten": "Zurückgezogenste",
    "Zurückgreifenden": "Zurückgreifende",
    "Zurückgreifens": "Zurückgreifen",
    "Zurückhaltenden": "Zurückhaltende",
    "Zurückhaltenderen": "Zurückhaltendere",
    "Zurückhaltendsten": "Zurückhaltendste",
    "Zurückhaltens": "Zurückhalten",
    "Zurückhaltungen": "Zurückhaltung",
    "Zurückholenden": "Zurückholende",
    "Zurückholens": "Zurückholen",
    "Zurückjagenden": "Zurückjagende",
    "Zurückjagens": "Zurückjagen",
    "Zurückkaufenden": "Zurückkaufende",
    "Zurückkaufens": "Zurückkaufen",
    "Zurückkehrenden": "Zurückkehrende",
    "Zurückkehrens": "Zurückkehren",
    "Zurückklappenden": "Zurückklappende",
    "Zurückklappens": "Zurückklappen",
    "Zurückkommenden": "Zurückkommende",
    "Zurückkommens": "Zurückkommen",
    "Zurückkämmenden": "Zurückkämmende",
    "Zurückkämmens": "Zurückkämmen",
    "Zurücklassenden": "Zurücklassende",
    "Zurücklassens": "Zurücklassen",
    "Zurücklaufenden": "Zurücklaufende",
    "Zurücklaufens": "Zurücklaufen",
    "Zurücklehnenden": "Zurücklehnende",
    "Zurücklehnenderen": "Zurücklehnendere",
    "Zurücklehnendsten": "Zurücklehnendste",
    "Zurücklehnens": "Zurücklehnen",
    "Zurückliegenden": "Zurückliegende",
    "Zurückliegenderen": "Zurückliegendere",
    "Zurückliegendsten": "Zurückliegendste",
    "Zurückliegens": "Zurückliegen",
    "Zurückmarschierenden": "Zurückmarschierende",
    "Zurückmarschierens": "Zurückmarschieren",
    "Zurückmarschierte": "zurückmarschiert",
    "Zurückmarschierten": "Zurückmarschierte",
    "Zurückmeldenden": "Zurückmeldende",
    "Zurückmeldens": "Zurückmelden",
    "Zurücknehmenden": "Zurücknehmende",
    "Zurücknehmens": "Zurücknehmen",
    "Zurückprallenden": "Zurückprallende",
    "Zurückprallens": "Zurückprallen",
    "Zurückreisenden": "Zurückreisende",
    "Zurückreisens": "Zurückreisen",
    "Zurückreitenden": "Zurückreitende",
    "Zurückreitens": "Zurückreiten",
    "Zurückreißenden": "Zurückreißende",
    "Zurückreißens": "Zurückreißen",
    "Zurückrollenden": "Zurückrollende",
    "Zurückrollens": "Zurückrollen",
    "Zurückrufenden": "Zurückrufende",
    "Zurückrufens": "Zurückrufen",
    "Zurückschaffenden": "Zurückschaffende",
    "Zurückschaffens": "Zurückschaffen",
    "Zurückschallenden": "Zurückschallende",
    "Zurückschallens": "Zurückschallen",
    "Zurückschaltenden": "Zurückschaltende",
    "Zurückschaltens": "Zurückschalten",
    "Zurückschaudernden": "Zurückschaudernde",
    "Zurückschaudernderen": "Zurückschauderndere",
    "Zurückschauderns": "Zurückschaudern",
    "Zurückschauenden": "Zurückschauende",
    "Zurückschauens": "Zurückschauen",
    "Zurückscheuchenden": "Zurückscheuchende",
    "Zurückscheuchens": "Zurückscheuchen",
    "Zurückscheuenden": "Zurückscheuende",
    "Zurückscheuens": "Zurückscheuen",
    "Zurückschiebenden": "Zurückschiebende",
    "Zurückschiebens": "Zurückschieben",
    "Zurückschlagenden": "Zurückschlagende",
    "Zurückschlagens": "Zurückschlagen",
    "Zurückschnellenden": "Zurückschnellende",
    "Zurückschnellens": "Zurückschnellen",
    "Zurückschraubenden": "Zurückschraubende",
    "Zurückschraubens": "Zurückschrauben",
    "Zurückschreckenden": "Zurückschreckende",
    "Zurückschreckenderen": "Zurückschreckendere",
    "Zurückschreckens": "Zurückschrecken",
    "Zurückschreibenden": "Zurückschreibende",
    "Zurückschreibens": "Zurückschreiben",
    "Zurückschwimmenden": "Zurückschwimmende",
    "Zurückschwimmens": "Zurückschwimmen",
    "Zurücksehnenden": "Zurücksehnende",
    "Zurücksehnenderen": "Zurücksehnendere",
    "Zurücksehnendsten": "Zurücksehnendste",
    "Zurücksehnens": "Zurücksehnen",
    "Zurücksendenden": "Zurücksendende",
    "Zurücksendens": "Zurücksenden",
    "Zurücksetzenden": "Zurücksetzende",
    "Zurücksetzens": "Zurücksetzen",
    "Zurücksinkenden": "Zurücksinkende",
    "Zurücksinkens": "Zurücksinken",
    "Zurückspringenden": "Zurückspringende",
    "Zurückspringens": "Zurückspringen",
    "Zurückspulenden": "Zurückspulende",
    "Zurückspulens": "Zurückspulen",
    "Zurückstehenden": "Zurückstehende",
    "Zurückstehens": "Zurückstehen",
    "Zurückstellenden": "Zurückstellende",
    "Zurückstellens": "Zurückstellen",
    "Zurückstoßenden": "Zurückstoßende",
    "Zurückstoßens": "Zurückstoßen",
    "Zurückstrahlenden": "Zurückstrahlende",
    "Zurückstrahlenderen": "Zurückstrahlendere",
    "Zurückstrahlens": "Zurückstrahlen",
    "Zurückstreichenden": "Zurückstreichende",
    "Zurückstreichens": "Zurückstreichen",
    "Zurückstreifenden": "Zurückstreifende",
    "Zurückstreifens": "Zurückstreifen",
    "Zurückströmenden": "Zurückströmende",
    "Zurückströmens": "Zurückströmen",
    "Zurückstutzenden": "Zurückstutzende",
    "Zurückstutzens": "Zurückstutzen",
    "Zurücktaumelnden": "Zurücktaumelnde",
    "Zurücktaumelns": "Zurücktaumeln",
    "Zurücktragenden": "Zurücktragende",
    "Zurücktragens": "Zurücktragen",
    "Zurücktreibenden": "Zurücktreibende",
    "Zurücktreibens": "Zurücktreiben",
    "Zurücktretenden": "Zurücktretende",
    "Zurücktretens": "Zurücktreten",
    "Zurückverfolgenden": "Zurückverfolgende",
    "Zurückverfolgens": "Zurückverfolgen",
    "Zurückverfolgte": "zurückverfolgt",
    "Zurückverfolgten": "Zurückverfolgte",
    "Zurückverlangenden": "Zurückverlangende",
    "Zurückverlangens": "Zurückverlangen",
    "Zurückverlangte": "zurückverlangt",
    "Zurückverlangten": "Zurückverlangte",
    "Zurückverlegenden": "Zurückverlegende",
    "Zurückverlegens": "Zurückverlegen",
    "Zurückverlegte": "zurückverlegt",
    "Zurückverlegten": "Zurückverlegte",
    "Zurückversetzenden": "Zurückversetzende",
    "Zurückversetzens": "Zurückversetzen",
    "Zurückversetzte": "zurückversetzt",
    "Zurückversetzten": "Zurückversetzte",
    "Zurückverweisenden": "Zurückverweisende",
    "Zurückverweisens": "Zurückverweisen",
    "Zurückverwiesenen": "Zurückverwiesene",
    "Zurückwandernden": "Zurückwandernde",
    "Zurückwanderns": "Zurückwandern",
    "Zurückweichenden": "Zurückweichende",
    "Zurückweichens": "Zurückweichen",
    "Zurückweisenden": "Zurückweisende",
    "Zurückweisenderen": "Zurückweisendere",
    "Zurückweisendsten": "Zurückweisendste",
    "Zurückweisens": "Zurückweisen",
    "Zurückwerfenden": "Zurückwerfende",
    "Zurückwerfens": "Zurückwerfen",
    "Zurückwirkenden": "Zurückwirkende",
    "Zurückwirkens": "Zurückwirken",
    "Zurückwünschenden": "Zurückwünschende",
    "Zurückwünschens": "Zurückwünschen",
    "Zurückzahlenden": "Zurückzahlende",
    "Zurückzahlens": "Zurückzahlen",
    "Zurückziehenden": "Zurückziehende",
    "Zurückziehens": "Zurückziehen",
    "Zurückübersetzenden": "Zurückübersetzende",
    "Zurückübersetzens": "Zurückübersetzen",
    "Zurückübersetzte": "zurückübersetzt",
    "Zurückübersetzten": "Zurückübersetzte",
    "Zurüstenden": "Zurüstende",
    "Zurüstens": "Zurüsten",
    "Zusagenden": "Zusagende",
    "Zusagens": "Zusagen",
    "Zusammenarbeiten": "Zusammenarbeit",
    "Zusammenarbeitenden": "Zusammenarbeitende",
    "Zusammenarbeitens": "Zusammenarbeiten",
    "Zusammenballenden": "Zusammenballende",
    "Zusammenballens": "Zusammenballen",
    "Zusammenballungen": "Zusammenballung",
    "Zusammenbauenden": "Zusammenbauende",
    "Zusammenbauens": "Zusammenbauen",
    "Zusammenbeißenden": "Zusammenbeißende",
    "Zusammenbeißens": "Zusammenbeißen",
    "Zusammenbettelnden": "Zusammenbettelnde",
    "Zusammenbettelns": "Zusammenbetteln",
    "Zusammenbildungen": "Zusammenbildung",
    "Zusammenbindenden": "Zusammenbindende",
    "Zusammenbindens": "Zusammenbinden",
    "Zusammenbleibenden": "Zusammenbleibende",
    "Zusammenbleibens": "Zusammenbleiben",
    "Zusammenborgenden": "Zusammenborgende",
    "Zusammenborgens": "Zusammenborgen",
    "Zusammenbrauenden": "Zusammenbrauende",
    "Zusammenbrauens": "Zusammenbrauen",
    "Zusammenbrechenden": "Zusammenbrechende",
    "Zusammenbrechens": "Zusammenbrechen",
    "Zusammenbringenden": "Zusammenbringende",
    "Zusammenbringens": "Zusammenbringen",
    "Zusammenbruche": "Zusammenbruch",
    "Zusammenbruches": "Zusammenbruch",
    "Zusammenbruchs": "Zusammenbruch",
    "Zusammenbrüche": "Zusammenbruch",
    "Zusammenbrüchen": "Zusammenbruch",
    "Zusammendrängenden": "Zusammendrängende",
    "Zusammendrängens": "Zusammendrängen",
    "Zusammenfahrenden": "Zusammenfahrende",
    "Zusammenfahrenderen": "Zusammenfahrendere",
    "Zusammenfahrens": "Zusammenfahren",
    "Zusammenfallenden": "Zusammenfallende",
    "Zusammenfallens": "Zusammenfallen",
    "Zusammenfaltenden": "Zusammenfaltende",
    "Zusammenfaltenderen": "Zusammenfaltendere",
    "Zusammenfaltens": "Zusammenfalten",
    "Zusammenfassenden": "Zusammenfassende",
    "Zusammenfassens": "Zusammenfassen",
    "Zusammenfassungen": "Zusammenfassung",
    "Zusammenfege": "zusammenfegen",
    "Zusammenfegenden": "Zusammenfegende",
    "Zusammenfegenderen": "Zusammenfegendere",
    "Zusammenfegens": "Zusammenfegen",
    "Zusammenfindenden": "Zusammenfindende",
    "Zusammenfindenderen": "Zusammenfindendere",
    "Zusammenfindens": "Zusammenfinden",
    "Zusammenflechtenden": "Zusammenflechtende",
    "Zusammenflechtenderen": "Zusammenflechtendere",
    "Zusammenflechtens": "Zusammenflechten",
    "Zusammenfließenden": "Zusammenfließende",
    "Zusammenfließens": "Zusammenfließen",
    "Zusammenfügenden": "Zusammenfügende",
    "Zusammenfügens": "Zusammenfügen",
    "Zusammenführenden": "Zusammenführende",
    "Zusammenführens": "Zusammenführen",
    "Zusammengearbeiteten": "Zusammengearbeitete",
    "Zusammengeballten": "Zusammengeballte",
    "Zusammengeballteren": "Zusammengeballtere",
    "Zusammengebauten": "Zusammengebaute",
    "Zusammengebenden": "Zusammengebende",
    "Zusammengebens": "Zusammengeben",
    "Zusammengebettelten": "Zusammengebettelte",
    "Zusammengebissenen": "Zusammengebissene",
    "Zusammengebliebenen": "Zusammengebliebene",
    "Zusammengeborgten": "Zusammengeborgte",
    "Zusammengebrachten": "Zusammengebrachte",
    "Zusammengebrauten": "Zusammengebraute",
    "Zusammengebrochenen": "Zusammengebrochene",
    "Zusammengebundenen": "Zusammengebundene",
    "Zusammengedrängten": "Zusammengedrängte",
    "Zusammengefahrenen": "Zusammengefahrene",
    "Zusammengefahreneren": "Zusammengefahrenere",
    "Zusammengefallenen": "Zusammengefallene",
    "Zusammengefalteten": "Zusammengefaltete",
    "Zusammengefalteteren": "Zusammengefaltetere",
    "Zusammengefaßten": "Zusammengefaßte",
    "Zusammengefegten": "Zusammengefegte",
    "Zusammengefegteren": "Zusammengefegtere",
    "Zusammengeflochtenen": "Zusammengeflochtene",
    "Zusammengeflochteneren": "Zusammengeflochtenere",
    "Zusammengeflossenen": "Zusammengeflossene",
    "Zusammengefundenen": "Zusammengefundene",
    "Zusammengefundeneren": "Zusammengefundenere",
    "Zusammengefügten": "Zusammengefügte",
    "Zusammengeführten": "Zusammengeführte",
    "Zusammengegangenen": "Zusammengegangene",
    "Zusammengegebenen": "Zusammengegebene",
    "Zusammengegossenen": "Zusammengegossene",
    "Zusammengehaltenen": "Zusammengehaltene",
    "Zusammengehalteneren": "Zusammengehaltenere",
    "Zusammengehangenen": "Zusammengehangene",
    "Zusammengehauenen": "Zusammengehauene",
    "Zusammengehefteten": "Zusammengeheftete",
    "Zusammengeheilten": "Zusammengeheilte",
    "Zusammengeheilteren": "Zusammengeheiltere",
    "Zusammengehenden": "Zusammengehende",
    "Zusammengehens": "Zusammengehen",
    "Zusammengehängten": "Zusammengehängte",
    "Zusammengehörenden": "Zusammengehörende",
    "Zusammengehörens": "Zusammengehören",
    "Zusammengehörigen": "Zusammengehörige",
    "Zusammengehörte": "zusammengehört",
    "Zusammengehörten": "Zusammengehörte",
    "Zusammengekauften": "Zusammengekaufte",
    "Zusammengekaufteren": "Zusammengekauftere",
    "Zusammengekehrten": "Zusammengekehrte",
    "Zusammengeketteten": "Zusammengekettete",
    "Zusammengekitteten": "Zusammengekittete",
    "Zusammengeklammerten": "Zusammengeklammerte",
    "Zusammengeklammerteren": "Zusammengeklammertere",
    "Zusammengeklappten": "Zusammengeklappte",
    "Zusammengeklebten": "Zusammengeklebte",
    "Zusammengekleisterten": "Zusammengekleisterte",
    "Zusammengekleisterteren": "Zusammengekleistertere",
    "Zusammengeklungenen": "Zusammengeklungene",
    "Zusammengekniffenen": "Zusammengekniffene",
    "Zusammengekniffeneren": "Zusammengekniffenere",
    "Zusammengeknüllten": "Zusammengeknüllte",
    "Zusammengeknüllteren": "Zusammengeknülltere",
    "Zusammengeknüpften": "Zusammengeknüpfte",
    "Zusammengekommenen": "Zusammengekommene",
    "Zusammengekoppelten": "Zusammengekoppelte",
    "Zusammengekrampften": "Zusammengekrampfte",
    "Zusammengekrampfteren": "Zusammengekrampftere",
    "Zusammengekramten": "Zusammengekramte",
    "Zusammengekratzten": "Zusammengekratzte",
    "Zusammengekuppelten": "Zusammengekuppelte",
    "Zusammengelassenen": "Zusammengelassene",
    "Zusammengelaufenen": "Zusammengelaufene",
    "Zusammengelebten": "Zusammengelebte",
    "Zusammengelegenen": "Zusammengelegene",
    "Zusammengelegten": "Zusammengelegte",
    "Zusammengeleimten": "Zusammengeleimte",
    "Zusammengelesenen": "Zusammengelesene",
    "Zusammengelogenen": "Zusammengelogene",
    "Zusammengelogeneren": "Zusammengelogenere",
    "Zusammengeläpperten": "Zusammengeläpperte",
    "Zusammengenagelten": "Zusammengenagelte",
    "Zusammengenommenen": "Zusammengenommene",
    "Zusammengenähten": "Zusammengenähte",
    "Zusammengepaßten": "Zusammengepaßte",
    "Zusammengepaßteren": "Zusammengepaßtere",
    "Zusammengepferchten": "Zusammengepferchte",
    "Zusammengepferchteren": "Zusammengepferchtere",
    "Zusammengeprallten": "Zusammengeprallte",
    "Zusammengepreßten": "Zusammengepreßte",
    "Zusammengepreßteren": "Zusammengepreßtere",
    "Zusammengerafften": "Zusammengeraffte",
    "Zusammengeratenden": "Zusammengeratende",
    "Zusammengeratenen": "Zusammengeratene",
    "Zusammengeratens": "Zusammengeraten",
    "Zusammengerauften": "Zusammengeraufte",
    "Zusammengerechneten": "Zusammengerechnete",
    "Zusammengereihten": "Zusammengereihte",
    "Zusammengereimten": "Zusammengereimte",
    "Zusammengeringelten": "Zusammengeringelte",
    "Zusammengerissenen": "Zusammengerissene",
    "Zusammengerollten": "Zusammengerollte",
    "Zusammengerotteten": "Zusammengerottete",
    "Zusammengerufenen": "Zusammengerufene",
    "Zusammengeräumten": "Zusammengeräumte",
    "Zusammengerückten": "Zusammengerückte",
    "Zusammengescharrten": "Zusammengescharrte",
    "Zusammengescharten": "Zusammengescharte",
    "Zusammengeschlagenen": "Zusammengeschlagene",
    "Zusammengeschlossenen": "Zusammengeschlossene",
    "Zusammengeschmolzenen": "Zusammengeschmolzene",
    "Zusammengeschnürten": "Zusammengeschnürte",
    "Zusammengeschobenen": "Zusammengeschobene",
    "Zusammengeschossenen": "Zusammengeschossene",
    "Zusammengeschosseneren": "Zusammengeschossenere",
    "Zusammengeschraubten": "Zusammengeschraubte",
    "Zusammengeschreckten": "Zusammengeschreckte",
    "Zusammengeschreckteren": "Zusammengeschrecktere",
    "Zusammengeschriebenen": "Zusammengeschriebene",
    "Zusammengeschrockenen": "Zusammengeschrockene",
    "Zusammengeschrumpften": "Zusammengeschrumpfte",
    "Zusammengeschweißten": "Zusammengeschweißte",
    "Zusammengeschweißteren": "Zusammengeschweißtere",
    "Zusammengeschütteten": "Zusammengeschüttete",
    "Zusammengesessenen": "Zusammengesessene",
    "Zusammengesetzten": "Zusammengesetzte",
    "Zusammengespannten": "Zusammengespannte",
    "Zusammengesparten": "Zusammengesparte",
    "Zusammengesparteren": "Zusammengespartere",
    "Zusammengesperrten": "Zusammengesperrte",
    "Zusammengestandenen": "Zusammengestandene",
    "Zusammengestauchten": "Zusammengestauchte",
    "Zusammengestauchteren": "Zusammengestauchtere",
    "Zusammengesteckten": "Zusammengesteckte",
    "Zusammengestellten": "Zusammengestellte",
    "Zusammengestimmten": "Zusammengestimmte",
    "Zusammengestoßenen": "Zusammengestoßene",
    "Zusammengeströmten": "Zusammengeströmte",
    "Zusammengestürzten": "Zusammengestürzte",
    "Zusammengesuchten": "Zusammengesuchte",
    "Zusammengesunkenen": "Zusammengesunkene",
    "Zusammengetragenen": "Zusammengetragene",
    "Zusammengetretenen": "Zusammengetretene",
    "Zusammengetreteneren": "Zusammengetretenere",
    "Zusammengetriebenen": "Zusammengetriebene",
    "Zusammengetrockneten": "Zusammengetrocknete",
    "Zusammengetroffenen": "Zusammengetroffene",
    "Zusammengetrommelten": "Zusammengetrommelte",
    "Zusammengewachsenen": "Zusammengewachsene",
    "Zusammengewachsten": "Zusammengewachste",
    "Zusammengewirkten": "Zusammengewirkte",
    "Zusammengeworfenen": "Zusammengeworfene",
    "Zusammengewürfelten": "Zusammengewürfelte",
    "Zusammengezogenen": "Zusammengezogene",
    "Zusammengezählten": "Zusammengezählte",
    "Zusammengießenden": "Zusammengießende",
    "Zusammengießens": "Zusammengießen",
    "Zusammenhaltenden": "Zusammenhaltende",
    "Zusammenhaltenderen": "Zusammenhaltendere",
    "Zusammenhaltens": "Zusammenhalten",
    "Zusammenhange": "Zusammenhang",
    "Zusammenhanges": "Zusammenhang",
    "Zusammenhanglosen": "Zusammenhanglose",
    "Zusammenhangloseren": "Zusammenhanglosere",
    "Zusammenhangs": "Zusammenhang",
    "Zusammenhangslose": "zusammenhangslos",
    "Zusammenhangslosen": "Zusammenhangslose",
    "Zusammenhauenden": "Zusammenhauende",
    "Zusammenhauens": "Zusammenhauen",
    "Zusammenheftenden": "Zusammenheftende",
    "Zusammenheftens": "Zusammenheften",
    "Zusammenheilenden": "Zusammenheilende",
    "Zusammenheilenderen": "Zusammenheilendere",
    "Zusammenheilens": "Zusammenheilen",
    "Zusammenhänge": "zusammenhängen",
    "Zusammenhängen": "Zusammenhang",
    "Zusammenhängenden": "Zusammenhängende",
    "Zusammenhängenderen": "Zusammenhängendere",
    "Zusammenhängens": "Zusammenhängen",
    "Zusammenkaufenden": "Zusammenkaufende",
    "Zusammenkaufenderen": "Zusammenkaufendere",
    "Zusammenkaufens": "Zusammenkaufen",
    "Zusammenkehrenden": "Zusammenkehrende",
    "Zusammenkehrens": "Zusammenkehren",
    "Zusammenkettenden": "Zusammenkettende",
    "Zusammenkettens": "Zusammenketten",
    "Zusammenkittenden": "Zusammenkittende",
    "Zusammenkittens": "Zusammenkitten",
    "Zusammenklammernden": "Zusammenklammernde",
    "Zusammenklammernderen": "Zusammenklammerndere",
    "Zusammenklammerns": "Zusammenklammern",
    "Zusammenklange": "Zusammenklang",
    "Zusammenklangs": "Zusammenklang",
    "Zusammenklappbaren": "Zusammenklappbare",
    "Zusammenklappenden": "Zusammenklappende",
    "Zusammenklappens": "Zusammenklappen",
    "Zusammenklebenden": "Zusammenklebende",
    "Zusammenklebens": "Zusammenkleben",
    "Zusammenkleisternden": "Zusammenkleisternde",
    "Zusammenkleisternderen": "Zusammenkleisterndere",
    "Zusammenkleisterns": "Zusammenkleistern",
    "Zusammenklingenden": "Zusammenklingende",
    "Zusammenklingens": "Zusammenklingen",
    "Zusammenklänge": "zusammenklingen",
    "Zusammenklängen": "zusammenklingen",
    "Zusammenkneifenden": "Zusammenkneifende",
    "Zusammenkneifenderen": "Zusammenkneifendere",
    "Zusammenkneifens": "Zusammenkneifen",
    "Zusammenknüllenden": "Zusammenknüllende",
    "Zusammenknüllenderen": "Zusammenknüllendere",
    "Zusammenknüllens": "Zusammenknüllen",
    "Zusammenknüpfenden": "Zusammenknüpfende",
    "Zusammenknüpfens": "Zusammenknüpfen",
    "Zusammenkommenden": "Zusammenkommende",
    "Zusammenkommens": "Zusammenkommen",
    "Zusammenkoppelnden": "Zusammenkoppelnde",
    "Zusammenkoppelns": "Zusammenkoppeln",
    "Zusammenkramenden": "Zusammenkramende",
    "Zusammenkramens": "Zusammenkramen",
    "Zusammenkrampfenden": "Zusammenkrampfende",
    "Zusammenkrampfenderen": "Zusammenkrampfendere",
    "Zusammenkrampfens": "Zusammenkrampfen",
    "Zusammenkratzenden": "Zusammenkratzende",
    "Zusammenkratzens": "Zusammenkratzen",
    "Zusammenkuppelnden": "Zusammenkuppelnde",
    "Zusammenkuppelns": "Zusammenkuppeln",
    "Zusammenkünfte": "Zusammenkunft",
    "Zusammenkünften": "Zusammenkunft",
    "Zusammenlassenden": "Zusammenlassende",
    "Zusammenlassens": "Zusammenlassen",
    "Zusammenlaufe": "zusammenlaufen",
    "Zusammenlaufenden": "Zusammenlaufende",
    "Zusammenlaufens": "Zusammenlaufen",
    "Zusammenlaufs": "Zusammenlauf",
    "Zusammenlebenden": "Zusammenlebende",
    "Zusammenlebens": "Zusammenleben",
    "Zusammenlegenden": "Zusammenlegende",
    "Zusammenlegens": "Zusammenlegen",
    "Zusammenlegungen": "Zusammenlegung",
    "Zusammenleimenden": "Zusammenleimende",
    "Zusammenleimens": "Zusammenleimen",
    "Zusammenlesenden": "Zusammenlesende",
    "Zusammenlesens": "Zusammenlesen",
    "Zusammenliegenden": "Zusammenliegende",
    "Zusammenliegens": "Zusammenliegen",
    "Zusammenläppernden": "Zusammenläppernde",
    "Zusammenläpperns": "Zusammenläppern",
    "Zusammenläufe": "Zusammenlauf",
    "Zusammenläufen": "Zusammenlauf",
    "Zusammenlügenden": "Zusammenlügende",
    "Zusammenlügenderen": "Zusammenlügendere",
    "Zusammenlügens": "Zusammenlügen",
    "Zusammennagelnden": "Zusammennagelnde",
    "Zusammennagelns": "Zusammennageln",
    "Zusammennehmenden": "Zusammennehmende",
    "Zusammennehmens": "Zusammennehmen",
    "Zusammennähenden": "Zusammennähende",
    "Zusammennähens": "Zusammennähen",
    "Zusammenpassenden": "Zusammenpassende",
    "Zusammenpassenderen": "Zusammenpassendere",
    "Zusammenpassens": "Zusammenpassen",
    "Zusammenpferchenden": "Zusammenpferchende",
    "Zusammenpferchenderen": "Zusammenpferchendere",
    "Zusammenpferchens": "Zusammenpferchen",
    "Zusammenprallenden": "Zusammenprallende",
    "Zusammenprallens": "Zusammenprallen",
    "Zusammenpralls": "Zusammenprall",
    "Zusammenpressenden": "Zusammenpressende",
    "Zusammenpressenderen": "Zusammenpressendere",
    "Zusammenpressens": "Zusammenpressen",
    "Zusammenraffenden": "Zusammenraffende",
    "Zusammenraffens": "Zusammenraffen",
    "Zusammenraufenden": "Zusammenraufende",
    "Zusammenraufens": "Zusammenraufen",
    "Zusammenrechnenden": "Zusammenrechnende",
    "Zusammenrechnens": "Zusammenrechnen",
    "Zusammenreihenden": "Zusammenreihende",
    "Zusammenreihens": "Zusammenreihen",
    "Zusammenreimenden": "Zusammenreimende",
    "Zusammenreimens": "Zusammenreimen",
    "Zusammenreißenden": "Zusammenreißende",
    "Zusammenreißens": "Zusammenreißen",
    "Zusammenringelnden": "Zusammenringelnde",
    "Zusammenringelns": "Zusammenringeln",
    "Zusammenrollenden": "Zusammenrollende",
    "Zusammenrollens": "Zusammenrollen",
    "Zusammenrottenden": "Zusammenrottende",
    "Zusammenrottens": "Zusammenrotten",
    "Zusammenrottungen": "Zusammenrottung",
    "Zusammenrufenden": "Zusammenrufende",
    "Zusammenrufens": "Zusammenrufen",
    "Zusammenräumenden": "Zusammenräumende",
    "Zusammenräumens": "Zusammenräumen",
    "Zusammenrückenden": "Zusammenrückende",
    "Zusammenrückens": "Zusammenrücken",
    "Zusammenscharenden": "Zusammenscharende",
    "Zusammenscharens": "Zusammenscharen",
    "Zusammenscharrenden": "Zusammenscharrende",
    "Zusammenscharrens": "Zusammenscharren",
    "Zusammenschiebenden": "Zusammenschiebende",
    "Zusammenschiebens": "Zusammenschieben",
    "Zusammenschießenden": "Zusammenschießende",
    "Zusammenschießens": "Zusammenschießen",
    "Zusammenschlagenden": "Zusammenschlagende",
    "Zusammenschlagens": "Zusammenschlagen",
    "Zusammenschließenden": "Zusammenschließende",
    "Zusammenschließens": "Zusammenschließen",
    "Zusammenschlusse": "Zusammenschluß",
    "Zusammenschlusses": "Zusammenschluß",
    "Zusammenschlüsse": "Zusammenschluß",
    "Zusammenschlüssen": "Zusammenschluß",
    "Zusammenschmelzenden": "Zusammenschmelzende",
    "Zusammenschmelzens": "Zusammenschmelzen",
    "Zusammenschnürenden": "Zusammenschnürende",
    "Zusammenschnürens": "Zusammenschnüren",
    "Zusammenschraubenden": "Zusammenschraubende",
    "Zusammenschraubens": "Zusammenschrauben",
    "Zusammenschreckenden": "Zusammenschreckende",
    "Zusammenschreckenderen": "Zusammenschreckendere",
    "Zusammenschreckens": "Zusammenschrecken",
    "Zusammenschreibenden": "Zusammenschreibende",
    "Zusammenschreibens": "Zusammenschreiben",
    "Zusammenschrumpfenden": "Zusammenschrumpfende",
    "Zusammenschrumpfens": "Zusammenschrumpfen",
    "Zusammenschweißenden": "Zusammenschweißende",
    "Zusammenschweißenderen": "Zusammenschweißendere",
    "Zusammenschweißens": "Zusammenschweißen",
    "Zusammenschüttenden": "Zusammenschüttende",
    "Zusammenschüttens": "Zusammenschütten",
    "Zusammenseins": "Zusammensein",
    "Zusammensetzenden": "Zusammensetzende",
    "Zusammensetzens": "Zusammensetzen",
    "Zusammensetzungen": "Zusammensetzung",
    "Zusammensinkenden": "Zusammensinkende",
    "Zusammensinkens": "Zusammensinken",
    "Zusammensitzenden": "Zusammensitzende",
    "Zusammensitzens": "Zusammensitzen",
    "Zusammenspannenden": "Zusammenspannende",
    "Zusammenspannens": "Zusammenspannen",
    "Zusammensparenden": "Zusammensparende",
    "Zusammensparenderen": "Zusammensparendere",
    "Zusammensparens": "Zusammensparen",
    "Zusammensperrenden": "Zusammensperrende",
    "Zusammensperrens": "Zusammensperren",
    "Zusammenspiele": "Zusammenspiel",
    "Zusammenspielen": "Zusammenspiel",
    "Zusammenspiels": "Zusammenspiel",
    "Zusammenstauchenden": "Zusammenstauchende",
    "Zusammenstauchenderen": "Zusammenstauchendere",
    "Zusammenstauchens": "Zusammenstauchen",
    "Zusammensteckenden": "Zusammensteckende",
    "Zusammensteckens": "Zusammenstecken",
    "Zusammenstehenden": "Zusammenstehende",
    "Zusammenstehens": "Zusammenstehen",
    "Zusammenstellenden": "Zusammenstellende",
    "Zusammenstellens": "Zusammenstellen",
    "Zusammenstellungen": "Zusammenstellung",
    "Zusammenstimmenden": "Zusammenstimmende",
    "Zusammenstimmens": "Zusammenstimmen",
    "Zusammenstoße": "zusammenstoßen",
    "Zusammenstoßenden": "Zusammenstoßende",
    "Zusammenstoßens": "Zusammenstoßen",
    "Zusammenstoßes": "Zusammenstoß",
    "Zusammenströmenden": "Zusammenströmende",
    "Zusammenströmens": "Zusammenströmen",
    "Zusammenstöße": "Zusammenstoß",
    "Zusammenstößen": "Zusammenstoß",
    "Zusammenstürzenden": "Zusammenstürzende",
    "Zusammenstürzens": "Zusammenstürzen",
    "Zusammensuchenden": "Zusammensuchende",
    "Zusammensuchens": "Zusammensuchen",
    "Zusammentragenden": "Zusammentragende",
    "Zusammentragens": "Zusammentragen",
    "Zusammentreffenden": "Zusammentreffende",
    "Zusammentreffens": "Zusammentreffen",
    "Zusammentreibenden": "Zusammentreibende",
    "Zusammentreibens": "Zusammentreiben",
    "Zusammentretenden": "Zusammentretende",
    "Zusammentretenderen": "Zusammentretendere",
    "Zusammentretens": "Zusammentreten",
    "Zusammentrocknenden": "Zusammentrocknende",
    "Zusammentrocknens": "Zusammentrocknen",
    "Zusammentrommelnden": "Zusammentrommelnde",
    "Zusammentrommelns": "Zusammentrommeln",
    "Zusammenwachsenden": "Zusammenwachsende",
    "Zusammenwachsens": "Zusammenwachsen",
    "Zusammenwerfenden": "Zusammenwerfende",
    "Zusammenwerfens": "Zusammenwerfen",
    "Zusammenwirkenden": "Zusammenwirkende",
    "Zusammenwirkens": "Zusammenwirken",
    "Zusammenziehenden": "Zusammenziehende",
    "Zusammenziehens": "Zusammenziehen",
    "Zusammenzählenden": "Zusammenzählende",
    "Zusammenzählens": "Zusammenzählen",
    "Zusatzantrage": "Zusatzantrag",
    "Zusatzantrags": "Zusatzantrag",
    "Zusatzanträge": "Zusatzantrag",
    "Zusatzanträgen": "Zusatzantrag",
    "Zusatze": "Zusatz",
    "Zusatzes": "Zusatz",
    "Zusatzgeräte": "Zusatzgerät",
    "Zusatzgeräten": "Zusatzgerät",
    "Zusatzgeräts": "Zusatzgerät",
    "Zusatzversicherungen": "Zusatzversicherung",
    "Zuschanzenden": "Zuschanzende",
    "Zuschanzens": "Zuschanzen",
    "Zuschauenden": "Zuschauende",
    "Zuschauens": "Zuschauen",
    "Zuschauern": "Zuschauer",
    "Zuschauers": "Zuschauer",
    "Zuschaufelnden": "Zuschaufelnde",
    "Zuschaufelns": "Zuschaufeln",
    "Zuschiebenden": "Zuschiebende",
    "Zuschiebens": "Zuschieben",
    "Zuschießenden": "Zuschießende",
    "Zuschießens": "Zuschießen",
    "Zuschlage": "zuschlagen",
    "Zuschlagenden": "Zuschlagende",
    "Zuschlagens": "Zuschlagen",
    "Zuschlages": "Zuschlag",
    "Zuschlagpflichtigen": "Zuschlagpflichtige",
    "Zuschließenden": "Zuschließende",
    "Zuschließens": "Zuschließen",
    "Zuschläge": "Zuschlag",
    "Zuschlägen": "Zuschlag",
    "Zuschmeißenden": "Zuschmeißende",
    "Zuschmeißens": "Zuschmeißen",
    "Zuschnallenden": "Zuschnallende",
    "Zuschnallens": "Zuschnallen",
    "Zuschnappenden": "Zuschnappende",
    "Zuschnappens": "Zuschnappen",
    "Zuschneidenden": "Zuschneidende",
    "Zuschneidens": "Zuschneiden",
    "Zuschneienden": "Zuschneiende",
    "Zuschneienderen": "Zuschneiendere",
    "Zuschneiendsten": "Zuschneiendste",
    "Zuschneiens": "Zuschneien",
    "Zuschnürenden": "Zuschnürende",
    "Zuschnürens": "Zuschnüren",
    "Zuschraubenden": "Zuschraubende",
    "Zuschraubens": "Zuschrauben",
    "Zuschreibenden": "Zuschreibende",
    "Zuschreibens": "Zuschreiben",
    "Zuschriften": "Zuschrift",
    "Zuschusse": "Zuschuß",
    "Zuschusses": "Zuschuß",
    "Zuschusternden": "Zuschusternde",
    "Zuschusterns": "Zuschustern",
    "Zuschüsse": "Zuschuß",
    "Zuschüssen": "Zuschuß",
    "Zuschüttenden": "Zuschüttende",
    "Zuschüttens": "Zuschütten",
    "Zusehenden": "Zusehende",
    "Zusehens": "Zusehen",
    "Zusendenden": "Zusendende",
    "Zusendens": "Zusenden",
    "Zusetzenden": "Zusetzende",
    "Zusetzenderen": "Zusetzendere",
    "Zusetzendsten": "Zusetzendste",
    "Zusetzens": "Zusetzen",
    "Zusichernden": "Zusichernde",
    "Zusicherns": "Zusichern",
    "Zusitzenden": "Zusitzende",
    "Zusitzens": "Zusitzen",
    "Zusperrenden": "Zusperrende",
    "Zusperrens": "Zusperren",
    "Zuspiele": "zuspielen",
    "Zuspielen": "Zuspiel",
    "Zuspielenden": "Zuspielende",
    "Zuspielens": "Zuspielen",
    "Zuspiels": "Zuspiel",
    "Zuspitzenden": "Zuspitzende",
    "Zuspitzens": "Zuspitzen",
    "Zusprechenden": "Zusprechende",
    "Zusprechens": "Zusprechen",
    "Zuspringenden": "Zuspringende",
    "Zuspringens": "Zuspringen",
    "Zuspruchs": "Zuspruch",
    "Zustande": "Zustand",
    "Zustandegekommenen": "Zustandegekommene",
    "Zustandekommenden": "Zustandekommende",
    "Zustandekommens": "Zustandekommen",
    "Zustandes": "Zustand",
    "Zustands": "Zustand",
    "Zustechenden": "Zustechende",
    "Zustechens": "Zustechen",
    "Zusteckenden": "Zusteckende",
    "Zusteckens": "Zustecken",
    "Zustehenden": "Zustehende",
    "Zustehens": "Zustehen",
    "Zusteigenden": "Zusteigende",
    "Zusteigens": "Zusteigen",
    "Zustellbezirke": "Zustellbezirk",
    "Zustellbezirken": "Zustellbezirk",
    "Zustellbezirks": "Zustellbezirk",
    "Zustellenden": "Zustellende",
    "Zustellens": "Zustellen",
    "Zustellgebühren": "Zustellgebühr",
    "Zustellungen": "Zustellung",
    "Zustellvermerke": "Zustellvermerk",
    "Zustellvermerken": "Zustellvermerk",
    "Zustellvermerks": "Zustellvermerk",
    "Zusteuernden": "Zusteuernde",
    "Zusteuerns": "Zusteuern",
    "Zustimmenden": "Zustimmende",
    "Zustimmenderen": "Zustimmendere",
    "Zustimmendsten": "Zustimmendste",
    "Zustimmens": "Zustimmen",
    "Zustimmungen": "Zustimmung",
    "Zustopfenden": "Zustopfende",
    "Zustopfenderen": "Zustopfendere",
    "Zustopfendsten": "Zustopfendste",
    "Zustopfens": "Zustopfen",
    "Zustoßenden": "Zustoßende",
    "Zustoßens": "Zustoßen",
    "Zustrebenden": "Zustrebende",
    "Zustrebens": "Zustreben",
    "Zustrome": "Zustrom",
    "Zustromes": "Zustrom",
    "Zustroms": "Zustrom",
    "Zuströme": "zuströmen",
    "Zuströmen": "Zustrom",
    "Zuströmenden": "Zuströmende",
    "Zuströmens": "Zuströmen",
    "Zustutzenden": "Zustutzende",
    "Zustutzens": "Zustutzen",
    "Zustände": "Zustand",
    "Zuständen": "Zustand",
    "Zuständigen": "Zuständige",
    "Zuständigkeiten": "Zuständigkeit",
    "Zustöpselnden": "Zustöpselnde",
    "Zustöpselns": "Zustöpseln",
    "Zustürzenden": "Zustürzende",
    "Zustürzens": "Zustürzen",
    "Zusätze": "Zusatz",
    "Zusätzen": "Zusatz",
    "Zusätzliche": "zusätzlich",
    "Zusätzlichen": "Zusätzliche",
    "Zutaten": "Zutat",
    "Zuteilenden": "Zuteilende",
    "Zuteilens": "Zuteilen",
    "Zuteilungen": "Zuteilung",
    "Zutragenden": "Zutragende",
    "Zutragens": "Zutragen",
    "Zutrauenden": "Zutrauende",
    "Zutrauens": "Zutrauen",
    "Zutraulichen": "Zutrauliche",
    "Zutraulicheren": "Zutraulichere",
    "Zutraulichsten": "Zutraulichste",
    "Zutreffenden": "Zutreffende",
    "Zutreffenderen": "Zutreffendere",
    "Zutreffendsten": "Zutreffendste",
    "Zutreffens": "Zutreffen",
    "Zutreibenden": "Zutreibende",
    "Zutreibens": "Zutreiben",
    "Zutrinkenden": "Zutrinkende",
    "Zutrinkens": "Zutrinken",
    "Zuträgern": "Zuträger",
    "Zuträgers": "Zuträger",
    "Zuträglichen": "Zuträgliche",
    "Zuträglicheren": "Zuträglichere",
    "Zuträglichsten": "Zuträglichste",
    "Zuverlässigen": "Zuverlässige",
    "Zuverlässigeren": "Zuverlässigere",
    "Zuverlässigkeiten": "Zuverlässigkeit",
    "Zuverlässigste": "zuverlässig",
    "Zuverlässigsten": "Zuverlässigste",
    "Zuversichtlichen": "Zuversichtliche",
    "Zuversichtlicheren": "Zuversichtlichere",
    "Zuvorgekommenen": "Zuvorgekommene",
    "Zuvorgekommeneren": "Zuvorgekommenere",
    "Zuvorgekommensten": "Zuvorgekommenste",
    "Zuvorkommenden": "Zuvorkommende",
    "Zuvorkommenderen": "Zuvorkommendere",
    "Zuvorkommendsten": "Zuvorkommendste",
    "Zuvorkommens": "Zuvorkommen",
    "Zuwachse": "Zuwachs",
    "Zuwachses": "Zuwachs",
    "Zuwanderern": "Zuwanderer",
    "Zuwanderers": "Zuwanderer",
    "Zuwandernden": "Zuwandernde",
    "Zuwanderns": "Zuwandern",
    "Zuwanderungen": "Zuwanderung",
    "Zuwehenden": "Zuwehende",
    "Zuwehenderen": "Zuwehendere",
    "Zuwehendsten": "Zuwehendste",
    "Zuwehens": "Zuwehen",
    "Zuweisenden": "Zuweisende",
    "Zuweisens": "Zuweisen",
    "Zuweisungen": "Zuweisung",
    "Zuwendenden": "Zuwendende",
    "Zuwendenderen": "Zuwendendere",
    "Zuwendendsten": "Zuwendendste",
    "Zuwendens": "Zuwenden",
    "Zuwendungen": "Zuwendung",
    "Zuwerfenden": "Zuwerfende",
    "Zuwerfens": "Zuwerfen",
    "Zuwidergehandelten": "Zuwidergehandelte",
    "Zuwidergelaufenen": "Zuwidergelaufene",
    "Zuwiderhandelnden": "Zuwiderhandelnde",
    "Zuwiderhandelns": "Zuwiderhandeln",
    "Zuwiderlaufenden": "Zuwiderlaufende",
    "Zuwiderlaufens": "Zuwiderlaufen",
    "Zuwinkenden": "Zuwinkende",
    "Zuwinkens": "Zuwinken",
    "Zuwächse": "Zuwachs",
    "Zuwächsen": "Zuwachs",
    "Zuzahlenden": "Zuzahlende",
    "Zuzahlens": "Zuzahlen",
    "Zuziehenden": "Zuziehende",
    "Zuziehens": "Zuziehen",
    "Zuzwinkernden": "Zuzwinkernde",
    "Zuzwinkerns": "Zuzwinkern",
    "Zuzählende": "zuzählend",
    "Zuzählenden": "Zuzählende",
    "Zuzählens": "Zuzählen",
    "Zuzüglern": "Zuzügler",
    "Zuzüglers": "Zuzügler",
    "Zwange": "Zwang",
    "Zwanges": "Zwang",
    "Zwanghaften": "Zwanghafte",
    "Zwanghafteren": "Zwanghaftere",
    "Zwanghaftesten": "Zwanghafteste",
    "Zwanglosen": "Zwanglose",
    "Zwangloseren": "Zwanglosere",
    "Zwanglosesten": "Zwangloseste",
    "Zwangs": "Zwang",
    "Zwangsläufige": "zwangsläufig",
    "Zwangsläufigen": "Zwangsläufige",
    "Zwangsläufigeren": "Zwangsläufigere",
    "Zwangsläufigsten": "Zwangsläufigste",
    "Zwangsmitteln": "Zwangsmittel",
    "Zwangsmittels": "Zwangsmittel",
    "Zwangsmäßigen": "Zwangsmäßige",
    "Zwangsumgesiedelten": "Zwangsumgesiedelte",
    "Zwangsumsiedelnden": "Zwangsumsiedelnde",
    "Zwangsumsiedelns": "Zwangsumsiedeln",
    "Zwangsweiseren": "Zwangsweisere",
    "Zwangsweisesten": "Zwangsweiseste",
    "Zwanzigern": "Zwanziger",
    "Zwanzigers": "Zwanziger",
    "Zweckdenkens": "Zweckdenken",
    "Zweckdienliche": "zweckdienlich",
    "Zweckdienlichen": "Zweckdienliche",
    "Zwecke": "Zweck",
    "Zwecken": "Zweck",
    "Zweckentfremdete": "zweckentfremdet",
    "Zweckentfremdeten": "Zweckentfremdete",
    "Zweckgebundenen": "Zweckgebundene",
    "Zwecklosen": "Zwecklose",
    "Zweckloseren": "Zwecklosere",
    "Zwecklosesten": "Zweckloseste",
    "Zweckmäßigen": "Zweckmäßige",
    "Zweckmäßigeren": "Zweckmäßigere",
    "Zweckmäßigsten": "Zweckmäßigste",
    "Zwecks": "Zweck",
    "Zweckverbande": "Zweckverband",
    "Zweckverbands": "Zweckverband",
    "Zweckverbände": "Zweckverband",
    "Zweckverbänden": "Zweckverband",
    "Zweibeinern": "Zweibeiner",
    "Zweibeiners": "Zweibeiner",
    "Zweiblatts": "Zweiblatt",
    "Zweideutige": "zweideutig",
    "Zweideutigen": "Zweideutige",
    "Zweideutigeren": "Zweideutigere",
    "Zweideutigsten": "Zweideutigste",
    "Zweidimensionalen": "Zweidimensionale",
    "Zweieiigen": "Zweieiige",
    "Zweiern": "Zweier",
    "Zweiers": "Zweier",
    "Zweifache": "zweifach",
    "Zweifachen": "Zweifache",
    "Zweifel": "zweifeln",
    "Zweifelhaften": "Zweifelhafte",
    "Zweifelhafteren": "Zweifelhaftere",
    "Zweifelhaftesten": "Zweifelhafteste",
    "Zweifellosen": "Zweifellose",
    "Zweifelloseren": "Zweifellosere",
    "Zweifellosesten": "Zweifelloseste",
    "Zweifeln": "Zweifel",
    "Zweifelnden": "Zweifelnde",
    "Zweifelnderen": "Zweifelndere",
    "Zweifelndsten": "Zweifelndste",
    "Zweifelns": "Zweifeln",
    "Zweifels": "Zweifel",
    "Zweifelsfreie": "zweifelsfrei",
    "Zweifelsfreien": "Zweifelsfreie",
    "Zweifelsfreieren": "Zweifelsfreiere",
    "Zweifelsfreiesten": "Zweifelsfreieste",
    "Zweig": "zweigen",
    "Zweige": "zweigen",
    "Zweigen": "Zweig",
    "Zweigenden": "Zweigende",
    "Zweigens": "Zweigen",
    "Zweiges": "Zweig",
    "Zweigeschlechtige": "zweigeschlechtig",
    "Zweigeschlechtigen": "Zweigeschlechtige",
    "Zweigeteilten": "Zweigeteilte",
    "Zweigleisigen": "Zweigleisige",
    "Zweihändigen": "Zweihändige",
    "Zweihäusigen": "Zweihäusige",
    "Zweijährigen": "Zweijährige",
    "Zweiköpfigen": "Zweiköpfige",
    "Zweimaligen": "Zweimalige",
    "Zweimotorigen": "Zweimotorige",
    "Zweipoligen": "Zweipolige",
    "Zweirade": "Zweirad",
    "Zweirades": "Zweirad",
    "Zweirads": "Zweirad",
    "Zweireihern": "Zweireiher",
    "Zweireihers": "Zweireiher",
    "Zweireihige": "zweireihig",
    "Zweireihigen": "Zweireihige",
    "Zweiräder": "Zweirad",
    "Zweirädern": "Zweirad",
    "Zweischneidigen": "Zweischneidige",
    "Zweischneidigeren": "Zweischneidigere",
    "Zweischneidigsten": "Zweischneidigste",
    "Zweiseitigen": "Zweiseitige",
    "Zweisitzern": "Zweisitzer",
    "Zweisitzers": "Zweisitzer",
    "Zweispaltige": "zweispaltig",
    "Zweispaltigen": "Zweispaltige",
    "Zweisprachigen": "Zweisprachige",
    "Zweisprachigkeiten": "Zweisprachigkeit",
    "Zweispurige": "zweispurig",
    "Zweispurigen": "Zweispurige",
    "Zweispännern": "Zweispänner",
    "Zweispänners": "Zweispänner",
    "Zweispännige": "zweispännig",
    "Zweispännigen": "Zweispännige",
    "Zweistrahlern": "Zweistrahler",
    "Zweistrahlers": "Zweistrahler",
    "Zweistrahlige": "zweistrahlig",
    "Zweistrahligen": "Zweistrahlige",
    "Zweistündigen": "Zweistündige",
    "Zweitaktern": "Zweitakter",
    "Zweitakters": "Zweitakter",
    "Zweitausfertigungen": "Zweitausfertigung",
    "Zweite": "zweit",
    "Zweiteilern": "Zweiteiler",
    "Zweiteilers": "Zweiteiler",
    "Zweiteilige": "zweiteilig",
    "Zweiteiligen": "Zweiteilige",
    "Zweiten": "Zweite",
    "Zweitklassigen": "Zweitklassige",
    "Zweitligisten": "Zweitligist",
    "Zweitrangige": "zweitrangig",
    "Zweitrangigen": "Zweitrangige",
    "Zweitschriften": "Zweitschrift",
    "Zweitwagens": "Zweitwagen",
    "Zweitwohnungen": "Zweitwohnung",
    "Zweitägigen": "Zweitägige",
    "Zweiunddreißigsteln": "Zweiunddreißigstel",
    "Zweiunddreißigstels": "Zweiunddreißigstel",
    "Zweizylindern": "Zweizylinder",
    "Zweizylinders": "Zweizylinder",
    "Zwerchfelle": "Zwerchfell",
    "Zwerchfellen": "Zwerchfell",
    "Zwerchfells": "Zwerchfell",
    "Zwergapfels": "Zwergapfel",
    "Zwerge": "Zwerg",
    "Zwergen": "Zwerg",
    "Zwergenhafte": "zwergenhaft",
    "Zwergenhaften": "Zwergenhafte",
    "Zwergenhafteren": "Zwergenhaftere",
    "Zwergenhaftesten": "Zwergenhafteste",
    "Zwerginnen": "Zwergin",
    "Zwergs": "Zwerg",
    "Zwergschulen": "Zwergschule",
    "Zwergäpfel": "Zwergapfel",
    "Zwergäpfeln": "Zwergapfel",
    "Zwetschgen": "Zwetschge",
    "Zwiebel": "zwiebeln",
    "Zwiebeln": "Zwiebel",
    "Zwiebelnden": "Zwiebelnde",
    "Zwiebelns": "Zwiebeln",
    "Zwielichtigen": "Zwielichtige",
    "Zwielichtigeren": "Zwielichtigere",
    "Zwielichtigsten": "Zwielichtigste",
    "Zwieseln": "Zwiesel",
    "Zwiesels": "Zwiesel",
    "Zwiespältige": "zwiespältig",
    "Zwiespältigen": "Zwiespältige",
    "Zwiespältigeren": "Zwiespältigere",
    "Zwiespältigsten": "Zwiespältigste",
    "Zwillinge": "Zwilling",
    "Zwillingen": "Zwilling",
    "Zwillings": "Zwilling",
    "Zwingenden": "Zwingende",
    "Zwingens": "Zwingen",
    "Zwinkernden": "Zwinkernde",
    "Zwinkernderen": "Zwinkerndere",
    "Zwinkerndsten": "Zwinkerndste",
    "Zwinkerns": "Zwinkern",
    "Zwirbelnden": "Zwirbelnde",
    "Zwirbelnderen": "Zwirbelndere",
    "Zwirbelndsten": "Zwirbelndste",
    "Zwirbelns": "Zwirbeln",
    "Zwischenbemerkungen": "Zwischenbemerkung",
    "Zwischenberichte": "Zwischenbericht",
    "Zwischenberichten": "Zwischenbericht",
    "Zwischenberichtes": "Zwischenbericht",
    "Zwischenberichts": "Zwischenbericht",
    "Zwischenbescheide": "Zwischenbescheid",
    "Zwischenbescheiden": "Zwischenbescheid",
    "Zwischenbescheids": "Zwischenbescheid",
    "Zwischenbetriebliche": "zwischenbetrieblich",
    "Zwischenbetrieblichen": "Zwischenbetriebliche",
    "Zwischenblendenden": "Zwischenblendende",
    "Zwischenblendens": "Zwischenblenden",
    "Zwischenbodens": "Zwischenboden",
    "Zwischenböden": "Zwischenboden",
    "Zwischendecks": "Zwischendeck",
    "Zwischendinge": "Zwischending",
    "Zwischendingen": "Zwischending",
    "Zwischendings": "Zwischending",
    "Zwischenfalle": "Zwischenfall",
    "Zwischenfalles": "Zwischenfall",
    "Zwischenfalls": "Zwischenfall",
    "Zwischenfälle": "Zwischenfall",
    "Zwischenfällen": "Zwischenfall",
    "Zwischengeblendeten": "Zwischengeblendete",
    "Zwischengelandeten": "Zwischengelandete",
    "Zwischengliede": "Zwischenglied",
    "Zwischenglieder": "Zwischenglied",
    "Zwischengliedern": "Zwischenglied",
    "Zwischengliedes": "Zwischenglied",
    "Zwischenglieds": "Zwischenglied",
    "Zwischenhandels": "Zwischenhandel",
    "Zwischenhändlern": "Zwischenhändler",
    "Zwischenhändlers": "Zwischenhändler",
    "Zwischenlandenden": "Zwischenlandende",
    "Zwischenlandens": "Zwischenlanden",
    "Zwischenlandungen": "Zwischenlandung",
    "Zwischenlaufe": "Zwischenlauf",
    "Zwischenlaufs": "Zwischenlauf",
    "Zwischenläufe": "Zwischenlauf",
    "Zwischenläufen": "Zwischenlauf",
    "Zwischenmenschliche": "zwischenmenschlich",
    "Zwischenmenschlichen": "Zwischenmenschliche",
    "Zwischenprüfungen": "Zwischenprüfung",
    "Zwischenraume": "Zwischenraum",
    "Zwischenraumes": "Zwischenraum",
    "Zwischenraums": "Zwischenraum",
    "Zwischenrunden": "Zwischenrunde",
    "Zwischenräume": "Zwischenraum",
    "Zwischenräumen": "Zwischenraum",
    "Zwischenspiele": "Zwischenspiel",
    "Zwischenspielen": "Zwischenspiel",
    "Zwischenspiels": "Zwischenspiel",
    "Zwischenstaatliche": "zwischenstaatlich",
    "Zwischenstaatlichen": "Zwischenstaatliche",
    "Zwischenstationen": "Zwischenstation",
    "Zwischenstücke": "Zwischenstück",
    "Zwischenstücken": "Zwischenstück",
    "Zwischenstücks": "Zwischenstück",
    "Zwischentone": "Zwischenton",
    "Zwischentons": "Zwischenton",
    "Zwischenträgern": "Zwischenträger",
    "Zwischenträgers": "Zwischenträger",
    "Zwischentöne": "Zwischenton",
    "Zwischentönen": "Zwischenton",
    "Zwischenwände": "Zwischenwand",
    "Zwischenwänden": "Zwischenwand",
    "Zwischenzeiten": "Zwischenzeit",
    "Zwischenzeitliche": "zwischenzeitlich",
    "Zwischenzeitlichen": "Zwischenzeitliche",
    "Zwiste": "Zwist",
    "Zwisten": "Zwist",
    "Zwistigkeiten": "Zwistigkeit",
    "Zwists": "Zwist",
    "Zwitschernden": "Zwitschernde",
    "Zwitscherns": "Zwitschern",
    "Zwittern": "Zwitter",
    "Zwitters": "Zwitter",
    "Zwänge": "zwängen",
    "Zwängen": "zwingen",
    "Zwängenden": "Zwängende",
    "Zwängens": "Zwängen",
    "Zwölfecke": "Zwölfeck",
    "Zwölfecken": "Zwölfeck",
    "Zwölfecks": "Zwölfeck",
    "Zwölfen": "Zwölf",
    "Zwölffingerdarme": "Zwölffingerdarm",
    "Zwölffingerdarms": "Zwölffingerdarm",
    "Zwölffingerdärme": "Zwölffingerdarm",
    "Zwölffingerdärmen": "Zwölffingerdarm",
    "Zyanits": "Zyanit",
    "Zyklen": "Zyklus",
    "Zyklische": "zyklisch",
    "Zyklischen": "Zyklische",
    "Zyklometern": "Zyklometer",
    "Zyklometers": "Zyklometer",
    "Zyklone": "Zyklon",
    "Zyklonen": "Zyklone",
    "Zyklons": "Zyklon",
    "Zyklopen": "Zyklop",
    "Zylindern": "Zylinder",
    "Zylinders": "Zylinder",
    "Zynikern": "Zyniker",
    "Zynikers": "Zyniker",
    "Zynische": "zynisch",
    "Zynischen": "Zynische",
    "Zynischeren": "Zynischere",
    "Zynischsten": "Zynischste",
    "Zysten": "Zyste",
    "Zähen": "Zähe",
    "Zäheren": "Zähere",
    "Zähesten": "Zäheste",
    "Zähflüssigen": "Zähflüssige",
    "Zähflüssigeren": "Zähflüssigere",
    "Zähflüssigsten": "Zähflüssigste",
    "Zählbare": "zählbar",
    "Zählbaren": "Zählbare",
    "Zählende": "zählend",
    "Zählenden": "Zählende",
    "Zählens": "Zählen",
    "Zählern": "Zähler",
    "Zählers": "Zähler",
    "Zählmustern": "Zählmuster",
    "Zählmusters": "Zählmuster",
    "Zählungen": "Zählung",
    "Zähmbaren": "Zähmbare",
    "Zähmbareren": "Zähmbarere",
    "Zähmbarsten": "Zähmbarste",
    "Zähmenden": "Zähmende",
    "Zähmenderen": "Zähmendere",
    "Zähmendsten": "Zähmendste",
    "Zähmens": "Zähmen",
    "Zähne": "Zahn",
    "Zähneknirschende": "zähneknirschend",
    "Zähneknirschenden": "Zähneknirschende",
    "Zähnen": "Zahn",
    "Zänkern": "Zänker",
    "Zänkers": "Zänker",
    "Zänkischen": "Zänkische",
    "Zänkischeren": "Zänkischere",
    "Zänkischsten": "Zänkischste",
    "Zärtlichen": "Zärtliche",
    "Zärtlicheren": "Zärtlichere",
    "Zärtlichkeiten": "Zärtlichkeit",
    "Zärtlichste": "zärtlich",
    "Zärtlichsten": "Zärtlichste",
    "Zäumenden": "Zäumende",
    "Zäumens": "Zäumen",
    "Zäumungen": "Zäumung",
    "Zäunchens": "Zäunchen",
    "Zäune": "zäunen",
    "Zäunen": "Zaun",
    "Zäunenden": "Zäunende",
    "Zäunens": "Zäunen",
    "Zögerlichen": "Zögerliche",
    "Zögerlicheren": "Zögerlichere",
    "Zögerlichsten": "Zögerlichste",
    "Zögernden": "Zögernde",
    "Zögernderen": "Zögerndere",
    "Zögerndsten": "Zögerndste",
    "Zögerns": "Zögern",
    "Zöglinge": "Zögling",
    "Zöglingen": "Zögling",
    "Zöglings": "Zögling",
    "Zölle": "Zoll",
    "Zöllen": "Zoll",
    "Zöllnern": "Zöllner",
    "Zöllners": "Zöllner",
    "Zöpfe": "Zopf",
    "Zöpfen": "Zopf",
    "Züchtenden": "Züchtende",
    "Züchtens": "Züchten",
    "Züchterinnen": "Züchterin",
    "Züchtern": "Züchter",
    "Züchters": "Züchter",
    "Züchtigenden": "Züchtigende",
    "Züchtigens": "Züchtigen",
    "Züchtungen": "Züchtung",
    "Züge": "Zug",
    "Zügel": "zügeln",
    "Zügellosen": "Zügellose",
    "Zügelloseren": "Zügellosere",
    "Zügellosesten": "Zügelloseste",
    "Zügeln": "Zügel",
    "Zügelnden": "Zügelnde",
    "Zügelnderen": "Zügelndere",
    "Zügelndsten": "Zügelndste",
    "Zügelns": "Zügeln",
    "Zügels": "Zügel",
    "Zügen": "Zug",
    "Zügigen": "Zügige",
    "Zügigeren": "Zügigere",
    "Zügigsten": "Zügigste",
    "Zündelnden": "Zündelnde",
    "Zündelns": "Zündeln",
    "Zündenden": "Zündende",
    "Zündenderen": "Zündendere",
    "Zündendsten": "Zündendste",
    "Zündens": "Zünden",
    "Zündkapseln": "Zündkapsel",
    "Zündkerzen": "Zündkerze",
    "Zündpfannen": "Zündpfanne",
    "Zündschlüsseln": "Zündschlüssel",
    "Zündschlüssels": "Zündschlüssel",
    "Zündungen": "Zündung",
    "Zündverteilern": "Zündverteiler",
    "Zündverteilers": "Zündverteiler",
    "Zünfte": "Zunft",
    "Zünften": "Zunft",
    "Zünftige": "zünftig",
    "Zünftigen": "Zünftige",
    "Zünftigeren": "Zünftigere",
    "Zünftigsten": "Zünftigste",
    "Züngelchens": "Züngelchen",
    "Züngelnden": "Züngelnde",
    "Züngelnderen": "Züngelndere",
    "Züngelndsten": "Züngelndste",
    "Züngelns": "Züngeln",
    "Züngleins": "Zünglein",
    "Zürichern": "Züricher",
    "Zürichers": "Züricher",
    "Zürichs": "Zürich",
    "Zürnenden": "Zürnende",
    "Zürnenderen": "Zürnendere",
    "Zürnendsten": "Zürnendste",
    "Zürnens": "Zürnen",
    "aalend": "aalen",
    "aalende": "aalend",
    "aalendem": "aalend",
    "aalenden": "aalend",
    "aalender": "aalend",
    "aalendere": "aalend",
    "aalenderem": "aalend",
    "aalenderen": "aalend",
    "aalenderer": "aalend",
    "aalenderes": "aalend",
    "aalendes": "aalend",
    "aalendste": "aalend",
    "aalendstem": "aalend",
    "aalendsten": "aalend",
    "aalendster": "aalend",
    "aalendstes": "aalend",
    "aalest": "aalen",
    "aalet": "aalen",
    "aalglatte": "aalglatt",
    "aalglattem": "aalglatt",
    "aalglatten": "aalglatt",
    "aalglatter": "aalglatt",
    "aalglattere": "aalglatt",
    "aalglatterem": "aalglatt",
    "aalglatteren": "aalglatt",
    "aalglatterer": "aalglatt",
    "aalglatteres": "aalglatt",
    "aalglattes": "aalglatt",
    "aalglatteste": "aalglatt",
    "aalglattestem": "aalglatt",
    "aalglattesten": "aalglatt",
    "aalglattester": "aalglatt",
    "aalglattestes": "aalglatt",
    "aalst": "aalen",
    "aalt": "aalen",
    "aalte": "aalen",
    "aalten": "aalen",
    "aaltest": "aalen",
    "aaltet": "aalen",
    "abarbeite": "abarbeiten",
    "abarbeitend": "abarbeiten",
    "abarbeitende": "abarbeitend",
    "abarbeitendem": "abarbeitend",
    "abarbeitenden": "abarbeitend",
    "abarbeitender": "abarbeitend",
    "abarbeitendes": "abarbeitend",
    "abarbeitest": "abarbeiten",
    "abarbeitet": "abarbeiten",
    "abarbeitete": "abarbeiten",
    "abarbeiteten": "abarbeiten",
    "abarbeitetest": "abarbeiten",
    "abarbeitetet": "abarbeiten",
    "abartige": "abartig",
    "abartigem": "abartig",
    "abartigen": "abartig",
    "abartiger": "abartig",
    "abartigere": "abartig",
    "abartigerem": "abartig",
    "abartigeren": "abartig",
    "abartigerer": "abartig",
    "abartigeres": "abartig",
    "abartiges": "abartig",
    "abartigste": "abartig",
    "abartigstem": "abartig",
    "abartigsten": "abartig",
    "abartigster": "abartig",
    "abartigstes": "abartig",
    "abaß": "abessen",
    "abaßen": "abessen",
    "abaßt": "abessen",
    "abbalge": "abbalgen",
    "abbalgend": "abbalgen",
    "abbalgende": "abbalgend",
    "abbalgendem": "abbalgend",
    "abbalgenden": "abbalgend",
    "abbalgender": "abbalgend",
    "abbalgendes": "abbalgend",
    "abbalgest": "abbalgen",
    "abbalget": "abbalgen",
    "abbalgst": "abbalgen",
    "abbalgt": "abbalgen",
    "abbalgte": "abbalgen",
    "abbalgten": "abbalgen",
    "abbalgtest": "abbalgen",
    "abbalgtet": "abbalgen",
    "abband": "abbinden",
    "abbanden": "abbinden",
    "abbandest": "abbinden",
    "abbandet": "abbinden",
    "abbat": "abbitten",
    "abbaten": "abbitten",
    "abbatest": "abbitten",
    "abbatet": "abbitten",
    "abbaubare": "abbaubar",
    "abbaubarem": "abbaubar",
    "abbaubaren": "abbaubar",
    "abbaubarer": "abbaubar",
    "abbaubarere": "abbaubar",
    "abbaubarerem": "abbaubar",
    "abbaubareren": "abbaubar",
    "abbaubarerer": "abbaubar",
    "abbaubareres": "abbaubar",
    "abbaubares": "abbaubar",
    "abbaubarste": "abbaubar",
    "abbaubarstem": "abbaubar",
    "abbaubarsten": "abbaubar",
    "abbaubarster": "abbaubar",
    "abbaubarstes": "abbaubar",
    "abbaue": "abbauen",
    "abbauend": "abbauen",
    "abbauende": "abbauend",
    "abbauendem": "abbauend",
    "abbauenden": "abbauend",
    "abbauender": "abbauend",
    "abbauendes": "abbauend",
    "abbauest": "abbauen",
    "abbauet": "abbauen",
    "abbaust": "abbauen",
    "abbaut": "abbauen",
    "abbaute": "abbauen",
    "abbautest": "abbauen",
    "abbautet": "abbauen",
    "abbehalte": "abbehalten",
    "abbehaltend": "abbehalten",
    "abbehaltende": "abbehaltend",
    "abbehaltendem": "abbehaltend",
    "abbehaltenden": "abbehaltend",
    "abbehaltender": "abbehaltend",
    "abbehaltendes": "abbehaltend",
    "abbehaltene": "abbehalten",
    "abbehaltenem": "abbehalten",
    "abbehaltenen": "abbehalten",
    "abbehaltener": "abbehalten",
    "abbehaltenes": "abbehalten",
    "abbehaltest": "abbehalten",
    "abbehaltet": "abbehalten",
    "abbehielt": "abbehalten",
    "abbehielte": "abbehalten",
    "abbehielten": "abbehalten",
    "abbehieltest": "abbehalten",
    "abbehieltet": "abbehalten",
    "abbehält": "abbehalten",
    "abbehältst": "abbehalten",
    "abbeize": "abbeizen",
    "abbeizend": "abbeizen",
    "abbeizende": "abbeizend",
    "abbeizendem": "abbeizend",
    "abbeizenden": "abbeizend",
    "abbeizender": "abbeizend",
    "abbeizendes": "abbeizend",
    "abbeizest": "abbeizen",
    "abbeizet": "abbeizen",
    "abbeizt": "abbeizen",
    "abbeizte": "abbeizen",
    "abbeizten": "abbeizen",
    "abbeiztest": "abbeizen",
    "abbeiztet": "abbeizen",
    "abbeiße": "abbeißen",
    "abbeißend": "abbeißen",
    "abbeißende": "abbeißend",
    "abbeißendem": "abbeißend",
    "abbeißenden": "abbeißend",
    "abbeißender": "abbeißend",
    "abbeißendes": "abbeißend",
    "abbeißest": "abbeißen",
    "abbeißet": "abbeißen",
    "abbeißt": "abbeißen",
    "abbekam": "abbekommen",
    "abbekamen": "abbekommen",
    "abbekamst": "abbekommen",
    "abbekamt": "abbekommen",
    "abbekomme": "abbekommen",
    "abbekommend": "abbekommen",
    "abbekommende": "abbekommend",
    "abbekommendem": "abbekommend",
    "abbekommenden": "abbekommend",
    "abbekommender": "abbekommend",
    "abbekommendes": "abbekommend",
    "abbekommene": "abbekommen",
    "abbekommenem": "abbekommen",
    "abbekommenen": "abbekommen",
    "abbekommener": "abbekommen",
    "abbekommenes": "abbekommen",
    "abbekommest": "abbekommen",
    "abbekommet": "abbekommen",
    "abbekommst": "abbekommen",
    "abbekommt": "abbekommen",
    "abbekäme": "abbekommen",
    "abbekämen": "abbekommen",
    "abbekämest": "abbekommen",
    "abbekämet": "abbekommen",
    "abberief": "abberufen",
    "abberiefe": "abberufen",
    "abberiefen": "abberufen",
    "abberiefest": "abberufen",
    "abberiefet": "abberufen",
    "abberiefst": "abberufen",
    "abberieft": "abberufen",
    "abberufe": "abberufen",
    "abberufend": "abberufen",
    "abberufende": "abberufend",
    "abberufendem": "abberufend",
    "abberufenden": "abberufend",
    "abberufender": "abberufend",
    "abberufendes": "abberufend",
    "abberufene": "abberufen",
    "abberufenem": "abberufen",
    "abberufenen": "abberufen",
    "abberufener": "abberufen",
    "abberufenes": "abberufen",
    "abberufest": "abberufen",
    "abberufet": "abberufen",
    "abberufst": "abberufen",
    "abberuft": "abberufen",
    "abbestelle": "abbestellen",
    "abbestellend": "abbestellen",
    "abbestellende": "abbestellend",
    "abbestellendem": "abbestellend",
    "abbestellenden": "abbestellend",
    "abbestellender": "abbestellend",
    "abbestellendes": "abbestellend",
    "abbestellest": "abbestellen",
    "abbestellet": "abbestellen",
    "abbestellst": "abbestellen",
    "abbestellt": "abbestellen",
    "abbestellte": "abbestellen",
    "abbestelltem": "abbestellt",
    "abbestellten": "abbestellen",
    "abbestellter": "abbestellt",
    "abbestelltes": "abbestellt",
    "abbestelltest": "abbestellen",
    "abbestelltet": "abbestellen",
    "abbete": "abbeten",
    "abbetend": "abbeten",
    "abbetende": "abbetend",
    "abbetendem": "abbetend",
    "abbetenden": "abbetend",
    "abbetender": "abbetend",
    "abbetendes": "abbetend",
    "abbetest": "abbeten",
    "abbetet": "abbeten",
    "abbetete": "abbeten",
    "abbeteten": "abbeten",
    "abbetetest": "abbeten",
    "abbetetet": "abbeten",
    "abbettele": "abbetteln",
    "abbettelnd": "abbetteln",
    "abbettelnde": "abbettelnd",
    "abbettelndem": "abbettelnd",
    "abbettelnden": "abbettelnd",
    "abbettelnder": "abbettelnd",
    "abbettelndes": "abbettelnd",
    "abbettelst": "abbetteln",
    "abbettelt": "abbetteln",
    "abbettelte": "abbetteln",
    "abbettelten": "abbetteln",
    "abbetteltest": "abbetteln",
    "abbetteltet": "abbetteln",
    "abbettle": "abbetteln",
    "abbezahle": "abbezahlen",
    "abbezahlend": "abbezahlen",
    "abbezahlende": "abbezahlend",
    "abbezahlendem": "abbezahlend",
    "abbezahlenden": "abbezahlend",
    "abbezahlender": "abbezahlend",
    "abbezahlendes": "abbezahlend",
    "abbezahlest": "abbezahlen",
    "abbezahlet": "abbezahlen",
    "abbezahlst": "abbezahlen",
    "abbezahlt": "abbezahlen",
    "abbezahlte": "abbezahlen",
    "abbezahltem": "abbezahlt",
    "abbezahlten": "abbezahlen",
    "abbezahlter": "abbezahlt",
    "abbezahltes": "abbezahlt",
    "abbezahltest": "abbezahlen",
    "abbezahltet": "abbezahlen",
    "abbiege": "abbiegen",
    "abbiegend": "abbiegen",
    "abbiegende": "abbiegend",
    "abbiegendem": "abbiegend",
    "abbiegenden": "abbiegend",
    "abbiegender": "abbiegend",
    "abbiegendes": "abbiegend",
    "abbiegest": "abbiegen",
    "abbieget": "abbiegen",
    "abbiegst": "abbiegen",
    "abbiegt": "abbiegen",
    "abbildend": "abbilden",
    "abbildende": "abbildend",
    "abbildendem": "abbildend",
    "abbildenden": "abbildend",
    "abbildender": "abbildend",
    "abbildendes": "abbildend",
    "abbildest": "abbilden",
    "abbildet": "abbilden",
    "abbildete": "abbilden",
    "abbildeten": "abbilden",
    "abbildetest": "abbilden",
    "abbildetet": "abbilden",
    "abbinde": "abbinden",
    "abbindend": "abbinden",
    "abbindende": "abbindend",
    "abbindendem": "abbindend",
    "abbindenden": "abbindend",
    "abbindender": "abbindend",
    "abbindendere": "abbindend",
    "abbindenderem": "abbindend",
    "abbindenderen": "abbindend",
    "abbindenderer": "abbindend",
    "abbindenderes": "abbindend",
    "abbindendes": "abbindend",
    "abbindendste": "abbindend",
    "abbindendstem": "abbindend",
    "abbindendsten": "abbindend",
    "abbindendster": "abbindend",
    "abbindendstes": "abbindend",
    "abbindest": "abbinden",
    "abbindet": "abbinden",
    "abbisse": "abbeißen",
    "abbissen": "abbeißen",
    "abbissest": "abbeißen",
    "abbisset": "abbeißen",
    "abbitte": "abbitten",
    "abbittend": "abbitten",
    "abbittende": "abbittend",
    "abbittendem": "abbittend",
    "abbittenden": "abbittend",
    "abbittender": "abbittend",
    "abbittendes": "abbittend",
    "abbittest": "abbitten",
    "abbittet": "abbitten",
    "abbiß": "abbeißen",
    "abbißt": "abbeißen",
    "abblase": "abblasen",
    "abblasend": "abblasen",
    "abblasende": "abblasend",
    "abblasendem": "abblasend",
    "abblasenden": "abblasend",
    "abblasender": "abblasend",
    "abblasendes": "abblasend",
    "abblasest": "abblasen",
    "abblaset": "abblasen",
    "abblasse": "abblassen",
    "abblassend": "abblassen",
    "abblassende": "abblassend",
    "abblassendem": "abblassend",
    "abblassenden": "abblassend",
    "abblassender": "abblassend",
    "abblassendes": "abblassend",
    "abblassest": "abblassen",
    "abblasset": "abblassen",
    "abblast": "abblasen",
    "abblaßt": "abblassen",
    "abblaßte": "abblassen",
    "abblaßten": "abblassen",
    "abblaßtest": "abblassen",
    "abblaßtet": "abblassen",
    "abbleibe": "abbleiben",
    "abbleibend": "abbleiben",
    "abbleibende": "abbleibend",
    "abbleibendem": "abbleibend",
    "abbleibenden": "abbleibend",
    "abbleibender": "abbleibend",
    "abbleibendes": "abbleibend",
    "abbleibest": "abbleiben",
    "abbleibet": "abbleiben",
    "abbleibst": "abbleiben",
    "abbleibt": "abbleiben",
    "abblende": "abblenden",
    "abblendend": "abblenden",
    "abblendende": "abblendend",
    "abblendendem": "abblendend",
    "abblendenden": "abblendend",
    "abblendender": "abblendend",
    "abblendendes": "abblendend",
    "abblendest": "abblenden",
    "abblendet": "abblenden",
    "abblendete": "abblenden",
    "abblendeten": "abblenden",
    "abblendetest": "abblenden",
    "abblendetet": "abblenden",
    "abblieb": "abbleiben",
    "abbliebe": "abbleiben",
    "abblieben": "abbleiben",
    "abbliebest": "abbleiben",
    "abbliebet": "abbleiben",
    "abbliebst": "abbleiben",
    "abbliebt": "abbleiben",
    "abblies": "abblasen",
    "abbliese": "abblasen",
    "abbliesen": "abblasen",
    "abbliesest": "abblasen",
    "abblieset": "abblasen",
    "abbliest": "abblasen",
    "abblitze": "abblitzen",
    "abblitzend": "abblitzen",
    "abblitzende": "abblitzend",
    "abblitzendem": "abblitzend",
    "abblitzenden": "abblitzend",
    "abblitzender": "abblitzend",
    "abblitzendere": "abblitzend",
    "abblitzenderem": "abblitzend",
    "abblitzenderen": "abblitzend",
    "abblitzenderer": "abblitzend",
    "abblitzenderes": "abblitzend",
    "abblitzendes": "abblitzend",
    "abblitzendste": "abblitzend",
    "abblitzendstem": "abblitzend",
    "abblitzendsten": "abblitzend",
    "abblitzendster": "abblitzend",
    "abblitzendstes": "abblitzend",
    "abblitzest": "abblitzen",
    "abblitzet": "abblitzen",
    "abblitzt": "abblitzen",
    "abblitzte": "abblitzen",
    "abblitzten": "abblitzen",
    "abblitztest": "abblitzen",
    "abblitztet": "abblitzen",
    "abbläst": "abblasen",
    "abblättere": "abblättern",
    "abblätternd": "abblättern",
    "abblätternde": "abblätternd",
    "abblätterndem": "abblätternd",
    "abblätternden": "abblätternd",
    "abblätternder": "abblätternd",
    "abblätterndere": "abblätternd",
    "abblätternderem": "abblätternd",
    "abblätternderen": "abblätternd",
    "abblätternderer": "abblätternd",
    "abblätternderes": "abblätternd",
    "abblätterndes": "abblätternd",
    "abblätterndste": "abblätternd",
    "abblätterndstem": "abblätternd",
    "abblätterndsten": "abblätternd",
    "abblätterndster": "abblätternd",
    "abblätterndstes": "abblätternd",
    "abblätterst": "abblättern",
    "abblättert": "abblättern",
    "abblätterte": "abblättern",
    "abblätterten": "abblättern",
    "abblättertest": "abblättern",
    "abblättertet": "abblättern",
    "abblühe": "abblühen",
    "abblühend": "abblühen",
    "abblühende": "abblühend",
    "abblühendem": "abblühend",
    "abblühenden": "abblühend",
    "abblühender": "abblühend",
    "abblühendere": "abblühend",
    "abblühenderem": "abblühend",
    "abblühenderen": "abblühend",
    "abblühenderer": "abblühend",
    "abblühenderes": "abblühend",
    "abblühendes": "abblühend",
    "abblühendste": "abblühend",
    "abblühendstem": "abblühend",
    "abblühendsten": "abblühend",
    "abblühendster": "abblühend",
    "abblühendstes": "abblühend",
    "abblühest": "abblühen",
    "abblühet": "abblühen",
    "abblühst": "abblühen",
    "abblüht": "abblühen",
    "abblühte": "abblühen",
    "abblühten": "abblühen",
    "abblühtest": "abblühen",
    "abblühtet": "abblühen",
    "abbog": "abbiegen",
    "abbogen": "abbiegen",
    "abbogst": "abbiegen",
    "abbogt": "abbiegen",
    "abbrach": "abbrechen",
    "abbrachen": "abbrechen",
    "abbrachst": "abbrechen",
    "abbracht": "abbrechen",
    "abbrachte": "abbringen",
    "abbrachten": "abbringen",
    "abbrachtest": "abbringen",
    "abbrachtet": "abbringen",
    "abbrannte": "abbrennen",
    "abbrannten": "abbrennen",
    "abbranntest": "abbrennen",
    "abbranntet": "abbrennen",
    "abbrause": "abbrausen",
    "abbrausend": "abbrausen",
    "abbrausende": "abbrausend",
    "abbrausendem": "abbrausend",
    "abbrausenden": "abbrausend",
    "abbrausender": "abbrausend",
    "abbrausendes": "abbrausend",
    "abbrausest": "abbrausen",
    "abbrauset": "abbrausen",
    "abbraust": "abbrausen",
    "abbrauste": "abbrausen",
    "abbrausten": "abbrausen",
    "abbraustest": "abbrausen",
    "abbraustet": "abbrausen",
    "abbreche": "abbrechen",
    "abbrechend": "abbrechen",
    "abbrechende": "abbrechend",
    "abbrechendem": "abbrechend",
    "abbrechenden": "abbrechend",
    "abbrechender": "abbrechend",
    "abbrechendes": "abbrechend",
    "abbrechest": "abbrechen",
    "abbrechet": "abbrechen",
    "abbrecht": "abbrechen",
    "abbremse": "abbremsen",
    "abbremsend": "abbremsen",
    "abbremsende": "abbremsend",
    "abbremsendem": "abbremsend",
    "abbremsenden": "abbremsend",
    "abbremsender": "abbremsend",
    "abbremsendes": "abbremsend",
    "abbremsest": "abbremsen",
    "abbremset": "abbremsen",
    "abbremst": "abbremsen",
    "abbremste": "abbremsen",
    "abbremsten": "abbremsen",
    "abbremstest": "abbremsen",
    "abbremstet": "abbremsen",
    "abbrenne": "abbrennen",
    "abbrennend": "abbrennen",
    "abbrennende": "abbrennend",
    "abbrennendem": "abbrennend",
    "abbrennenden": "abbrennend",
    "abbrennender": "abbrennend",
    "abbrennendes": "abbrennend",
    "abbrennest": "abbrennen",
    "abbrennet": "abbrennen",
    "abbrennst": "abbrennen",
    "abbrennt": "abbrennen",
    "abbrichst": "abbrechen",
    "abbricht": "abbrechen",
    "abbringe": "abbringen",
    "abbringend": "abbringen",
    "abbringende": "abbringend",
    "abbringendem": "abbringend",
    "abbringenden": "abbringend",
    "abbringender": "abbringend",
    "abbringendes": "abbringend",
    "abbringest": "abbringen",
    "abbringet": "abbringen",
    "abbringst": "abbringen",
    "abbringt": "abbringen",
    "abbruchreifem": "abbruchreif",
    "abbruchreifen": "abbruchreif",
    "abbruchreifer": "abbruchreif",
    "abbruchreifere": "abbruchreif",
    "abbruchreiferem": "abbruchreif",
    "abbruchreiferen": "abbruchreif",
    "abbruchreiferer": "abbruchreif",
    "abbruchreiferes": "abbruchreif",
    "abbruchreifes": "abbruchreif",
    "abbruchreifste": "abbruchreif",
    "abbruchreifstem": "abbruchreif",
    "abbruchreifsten": "abbruchreif",
    "abbruchreifster": "abbruchreif",
    "abbruchreifstes": "abbruchreif",
    "abbräche": "abbrechen",
    "abbrächen": "abbrechen",
    "abbrächest": "abbrechen",
    "abbrächet": "abbrechen",
    "abbrächte": "abbringen",
    "abbrächten": "abbringen",
    "abbrächtest": "abbringen",
    "abbrächtet": "abbringen",
    "abbröckele": "abbröckeln",
    "abbröckelnd": "abbröckeln",
    "abbröckelnde": "abbröckelnd",
    "abbröckelndem": "abbröckelnd",
    "abbröckelnden": "abbröckelnd",
    "abbröckelnder": "abbröckelnd",
    "abbröckelndere": "abbröckelnd",
    "abbröckelnderem": "abbröckelnd",
    "abbröckelnderen": "abbröckelnd",
    "abbröckelnderer": "abbröckelnd",
    "abbröckelnderes": "abbröckelnd",
    "abbröckelndes": "abbröckelnd",
    "abbröckelndste": "abbröckelnd",
    "abbröckelndstem": "abbröckelnd",
    "abbröckelndsten": "abbröckelnd",
    "abbröckelndster": "abbröckelnd",
    "abbröckelndstes": "abbröckelnd",
    "abbröckelst": "abbröckeln",
    "abbröckelt": "abbröckeln",
    "abbröckelte": "abbröckeln",
    "abbröckelten": "abbröckeln",
    "abbröckeltest": "abbröckeln",
    "abbröckeltet": "abbröckeln",
    "abbröckle": "abbröckeln",
    "abbrühe": "abbrühen",
    "abbrühend": "abbrühen",
    "abbrühende": "abbrühend",
    "abbrühendem": "abbrühend",
    "abbrühenden": "abbrühend",
    "abbrühender": "abbrühend",
    "abbrühendere": "abbrühend",
    "abbrühenderem": "abbrühend",
    "abbrühenderen": "abbrühend",
    "abbrühenderer": "abbrühend",
    "abbrühenderes": "abbrühend",
    "abbrühendes": "abbrühend",
    "abbrühendste": "abbrühend",
    "abbrühendstem": "abbrühend",
    "abbrühendsten": "abbrühend",
    "abbrühendster": "abbrühend",
    "abbrühendstes": "abbrühend",
    "abbrühest": "abbrühen",
    "abbrühet": "abbrühen",
    "abbrühst": "abbrühen",
    "abbrüht": "abbrühen",
    "abbrühte": "abbrühen",
    "abbrühten": "abbrühen",
    "abbrühtest": "abbrühen",
    "abbrühtet": "abbrühen",
    "abbuche": "abbuchen",
    "abbuchend": "abbuchen",
    "abbuchende": "abbuchend",
    "abbuchendem": "abbuchend",
    "abbuchenden": "abbuchend",
    "abbuchender": "abbuchend",
    "abbuchendes": "abbuchend",
    "abbuchest": "abbuchen",
    "abbuchet": "abbuchen",
    "abbuchst": "abbuchen",
    "abbucht": "abbuchen",
    "abbuchte": "abbuchen",
    "abbuchten": "abbuchen",
    "abbuchtest": "abbuchen",
    "abbuchtet": "abbuchen",
    "abbände": "abbinden",
    "abbänden": "abbinden",
    "abbändest": "abbinden",
    "abbändet": "abbinden",
    "abbäte": "abbitten",
    "abbäten": "abbitten",
    "abbätest": "abbitten",
    "abbätet": "abbitten",
    "abböge": "abbiegen",
    "abbögen": "abbiegen",
    "abbögest": "abbiegen",
    "abböget": "abbiegen",
    "abbürste": "abbürsten",
    "abbürstend": "abbürsten",
    "abbürstende": "abbürstend",
    "abbürstendem": "abbürstend",
    "abbürstenden": "abbürstend",
    "abbürstender": "abbürstend",
    "abbürstendes": "abbürstend",
    "abbürstest": "abbürsten",
    "abbürstet": "abbürsten",
    "abbürstete": "abbürsten",
    "abbürsteten": "abbürsten",
    "abbürstetest": "abbürsten",
    "abbürstetet": "abbürsten",
    "abbüße": "abbüßen",
    "abbüßend": "abbüßen",
    "abbüßende": "abbüßend",
    "abbüßendem": "abbüßend",
    "abbüßenden": "abbüßend",
    "abbüßender": "abbüßend",
    "abbüßendes": "abbüßend",
    "abbüßest": "abbüßen",
    "abbüßet": "abbüßen",
    "abbüßt": "abbüßen",
    "abbüßte": "abbüßen",
    "abbüßten": "abbüßen",
    "abbüßtest": "abbüßen",
    "abbüßtet": "abbüßen",
    "abdache": "abdachen",
    "abdachend": "abdachen",
    "abdachende": "abdachend",
    "abdachendem": "abdachend",
    "abdachenden": "abdachend",
    "abdachender": "abdachend",
    "abdachendes": "abdachend",
    "abdachest": "abdachen",
    "abdachet": "abdachen",
    "abdachst": "abdachen",
    "abdacht": "abdachen",
    "abdachte": "abdachen",
    "abdachten": "abdachen",
    "abdachtest": "abdachen",
    "abdachtet": "abdachen",
    "abdampfend": "abdampfen",
    "abdampfende": "abdampfend",
    "abdampfendem": "abdampfend",
    "abdampfenden": "abdampfend",
    "abdampfender": "abdampfend",
    "abdampfendes": "abdampfend",
    "abdampfest": "abdampfen",
    "abdampfet": "abdampfen",
    "abdampfst": "abdampfen",
    "abdampft": "abdampfen",
    "abdampfte": "abdampfen",
    "abdampften": "abdampfen",
    "abdampftest": "abdampfen",
    "abdampftet": "abdampfen",
    "abdang": "abdingen",
    "abdangen": "abdingen",
    "abdangst": "abdingen",
    "abdangt": "abdingen",
    "abdanke": "abdanken",
    "abdankend": "abdanken",
    "abdankende": "abdankend",
    "abdankendem": "abdankend",
    "abdankenden": "abdankend",
    "abdankender": "abdankend",
    "abdankendes": "abdankend",
    "abdankest": "abdanken",
    "abdanket": "abdanken",
    "abdankst": "abdanken",
    "abdankt": "abdanken",
    "abdankte": "abdanken",
    "abdankten": "abdanken",
    "abdanktest": "abdanken",
    "abdanktet": "abdanken",
    "abdarbe": "abdarben",
    "abdarbend": "abdarben",
    "abdarbende": "abdarbend",
    "abdarbendem": "abdarbend",
    "abdarbenden": "abdarbend",
    "abdarbender": "abdarbend",
    "abdarbendes": "abdarbend",
    "abdarbest": "abdarben",
    "abdarbet": "abdarben",
    "abdarbst": "abdarben",
    "abdarbt": "abdarben",
    "abdarbte": "abdarben",
    "abdarbten": "abdarben",
    "abdarbtest": "abdarben",
    "abdarbtet": "abdarben",
    "abdecke": "abdecken",
    "abdeckend": "abdecken",
    "abdeckende": "abdeckend",
    "abdeckendem": "abdeckend",
    "abdeckenden": "abdeckend",
    "abdeckender": "abdeckend",
    "abdeckendes": "abdeckend",
    "abdeckest": "abdecken",
    "abdecket": "abdecken",
    "abdeckst": "abdecken",
    "abdeckt": "abdecken",
    "abdeckte": "abdecken",
    "abdeckten": "abdecken",
    "abdecktest": "abdecken",
    "abdecktet": "abdecken",
    "abdichte": "abdichten",
    "abdichtend": "abdichten",
    "abdichtende": "abdichtend",
    "abdichtendem": "abdichtend",
    "abdichtenden": "abdichtend",
    "abdichtender": "abdichtend",
    "abdichtendes": "abdichtend",
    "abdichtest": "abdichten",
    "abdichtet": "abdichten",
    "abdichtete": "abdichten",
    "abdichteten": "abdichten",
    "abdichtetest": "abdichten",
    "abdichtetet": "abdichten",
    "abdiene": "abdienen",
    "abdienend": "abdienen",
    "abdienende": "abdienend",
    "abdienendem": "abdienend",
    "abdienenden": "abdienend",
    "abdienender": "abdienend",
    "abdienendes": "abdienend",
    "abdienest": "abdienen",
    "abdienet": "abdienen",
    "abdienst": "abdienen",
    "abdient": "abdienen",
    "abdiente": "abdienen",
    "abdienten": "abdienen",
    "abdientest": "abdienen",
    "abdientet": "abdienen",
    "abdinge": "abdingen",
    "abdingend": "abdingen",
    "abdingende": "abdingend",
    "abdingendem": "abdingend",
    "abdingenden": "abdingend",
    "abdingender": "abdingend",
    "abdingendes": "abdingend",
    "abdingest": "abdingen",
    "abdinget": "abdingen",
    "abdingst": "abdingen",
    "abdingt": "abdingen",
    "abdiziere": "abdizieren",
    "abdizierend": "abdizieren",
    "abdizierende": "abdizierend",
    "abdizierendem": "abdizierend",
    "abdizierenden": "abdizierend",
    "abdizierender": "abdizierend",
    "abdizierendes": "abdizierend",
    "abdizierest": "abdizieren",
    "abdizieret": "abdizieren",
    "abdizierst": "abdizieren",
    "abdiziert": "abdizieren",
    "abdizierte": "abdizieren",
    "abdiziertem": "abdiziert",
    "abdizierten": "abdizieren",
    "abdizierter": "abdiziert",
    "abdiziertes": "abdiziert",
    "abdiziertest": "abdizieren",
    "abdiziertet": "abdizieren",
    "abdrehe": "abdrehen",
    "abdrehend": "abdrehen",
    "abdrehende": "abdrehend",
    "abdrehendem": "abdrehend",
    "abdrehenden": "abdrehend",
    "abdrehender": "abdrehend",
    "abdrehendere": "abdrehend",
    "abdrehenderem": "abdrehend",
    "abdrehenderen": "abdrehend",
    "abdrehenderer": "abdrehend",
    "abdrehenderes": "abdrehend",
    "abdrehendes": "abdrehend",
    "abdrehendste": "abdrehend",
    "abdrehendstem": "abdrehend",
    "abdrehendsten": "abdrehend",
    "abdrehendster": "abdrehend",
    "abdrehendstes": "abdrehend",
    "abdrehest": "abdrehen",
    "abdrehet": "abdrehen",
    "abdrehst": "abdrehen",
    "abdreht": "abdrehen",
    "abdrehte": "abdrehen",
    "abdrehten": "abdrehen",
    "abdrehtest": "abdrehen",
    "abdrehtet": "abdrehen",
    "abdrifte": "abdriften",
    "abdriftend": "abdriften",
    "abdriftende": "abdriftend",
    "abdriftendem": "abdriftend",
    "abdriftenden": "abdriftend",
    "abdriftender": "abdriftend",
    "abdriftendere": "abdriftend",
    "abdriftenderem": "abdriftend",
    "abdriftenderen": "abdriftend",
    "abdriftenderer": "abdriftend",
    "abdriftenderes": "abdriftend",
    "abdriftendes": "abdriftend",
    "abdriftendste": "abdriftend",
    "abdriftendstem": "abdriftend",
    "abdriftendsten": "abdriftend",
    "abdriftendster": "abdriftend",
    "abdriftendstes": "abdriftend",
    "abdriftest": "abdriften",
    "abdriftet": "abdriften",
    "abdriftete": "abdriften",
    "abdrifteten": "abdriften",
    "abdriftetest": "abdriften",
    "abdriftetet": "abdriften",
    "abdrossele": "abdrosseln",
    "abdrosselnd": "abdrosseln",
    "abdrosselnde": "abdrosselnd",
    "abdrosselndem": "abdrosselnd",
    "abdrosselnden": "abdrosselnd",
    "abdrosselnder": "abdrosselnd",
    "abdrosselndes": "abdrosselnd",
    "abdrosselst": "abdrosseln",
    "abdrosselt": "abdrosseln",
    "abdrosselte": "abdrosseln",
    "abdrosselten": "abdrosseln",
    "abdrosseltest": "abdrosseln",
    "abdrosseltet": "abdrosseln",
    "abdrossle": "abdrosseln",
    "abdruckend": "abdrucken",
    "abdruckende": "abdruckend",
    "abdruckendem": "abdruckend",
    "abdruckenden": "abdruckend",
    "abdruckender": "abdruckend",
    "abdruckendes": "abdruckend",
    "abdruckest": "abdrucken",
    "abdrucket": "abdrucken",
    "abdruckst": "abdrucken",
    "abdruckt": "abdrucken",
    "abdruckte": "abdrucken",
    "abdruckten": "abdrucken",
    "abdrucktest": "abdrucken",
    "abdrucktet": "abdrucken",
    "abdränge": "abdrängen",
    "abdrängend": "abdrängen",
    "abdrängende": "abdrängend",
    "abdrängendem": "abdrängend",
    "abdrängenden": "abdrängend",
    "abdrängender": "abdrängend",
    "abdrängendes": "abdrängend",
    "abdrängest": "abdrängen",
    "abdränget": "abdrängen",
    "abdrängst": "abdrängen",
    "abdrängt": "abdrängen",
    "abdrängte": "abdrängen",
    "abdrängten": "abdrängen",
    "abdrängtest": "abdrängen",
    "abdrängtet": "abdrängen",
    "abdrückend": "abdrücken",
    "abdrückendem": "abdrückend",
    "abdrückender": "abdrückend",
    "abdrückendes": "abdrückend",
    "abdrückest": "abdrücken",
    "abdrücket": "abdrücken",
    "abdrückst": "abdrücken",
    "abdrückt": "abdrücken",
    "abdrückte": "abdrücken",
    "abdrückten": "abdrücken",
    "abdrücktest": "abdrücken",
    "abdrücktet": "abdrücken",
    "abdunkele": "abdunkeln",
    "abdunkelnd": "abdunkeln",
    "abdunkelnde": "abdunkelnd",
    "abdunkelndem": "abdunkelnd",
    "abdunkelnden": "abdunkelnd",
    "abdunkelnder": "abdunkelnd",
    "abdunkelndere": "abdunkelnd",
    "abdunkelnderem": "abdunkelnd",
    "abdunkelnderen": "abdunkelnd",
    "abdunkelnderer": "abdunkelnd",
    "abdunkelnderes": "abdunkelnd",
    "abdunkelndes": "abdunkelnd",
    "abdunkelndste": "abdunkelnd",
    "abdunkelndstem": "abdunkelnd",
    "abdunkelndsten": "abdunkelnd",
    "abdunkelndster": "abdunkelnd",
    "abdunkelndstes": "abdunkelnd",
    "abdunkelst": "abdunkeln",
    "abdunkelt": "abdunkeln",
    "abdunkelte": "abdunkeln",
    "abdunkelten": "abdunkeln",
    "abdunkeltest": "abdunkeln",
    "abdunkeltet": "abdunkeln",
    "abdunkle": "abdunkeln",
    "abdusche": "abduschen",
    "abduschend": "abduschen",
    "abduschende": "abduschend",
    "abduschendem": "abduschend",
    "abduschenden": "abduschend",
    "abduschender": "abduschend",
    "abduschendes": "abduschend",
    "abduschest": "abduschen",
    "abduschet": "abduschen",
    "abduschst": "abduschen",
    "abduscht": "abduschen",
    "abduschte": "abduschen",
    "abduschten": "abduschen",
    "abduschtest": "abduschen",
    "abduschtet": "abduschen",
    "abduziere": "abduzieren",
    "abduzierend": "abduzieren",
    "abduzierende": "abduzierend",
    "abduzierendem": "abduzierend",
    "abduzierenden": "abduzierend",
    "abduzierender": "abduzierend",
    "abduzierendes": "abduzierend",
    "abduzierest": "abduzieren",
    "abduzieret": "abduzieren",
    "abduzierst": "abduzieren",
    "abduziert": "abduzieren",
    "abduzierte": "abduzieren",
    "abduziertem": "abduziert",
    "abduzierten": "abduzieren",
    "abduzierter": "abduziert",
    "abduziertes": "abduziert",
    "abduziertest": "abduzieren",
    "abduziertet": "abduzieren",
    "abdämme": "abdämmen",
    "abdämmend": "abdämmen",
    "abdämmende": "abdämmend",
    "abdämmendem": "abdämmend",
    "abdämmenden": "abdämmend",
    "abdämmender": "abdämmend",
    "abdämmendere": "abdämmend",
    "abdämmenderem": "abdämmend",
    "abdämmenderen": "abdämmend",
    "abdämmenderer": "abdämmend",
    "abdämmenderes": "abdämmend",
    "abdämmendes": "abdämmend",
    "abdämmendste": "abdämmend",
    "abdämmendstem": "abdämmend",
    "abdämmendsten": "abdämmend",
    "abdämmendster": "abdämmend",
    "abdämmendstes": "abdämmend",
    "abdämmest": "abdämmen",
    "abdämmet": "abdämmen",
    "abdämmst": "abdämmen",
    "abdämmt": "abdämmen",
    "abdämmte": "abdämmen",
    "abdämmten": "abdämmen",
    "abdämmtest": "abdämmen",
    "abdämmtet": "abdämmen",
    "abdänge": "abdingen",
    "abdängen": "abdingen",
    "abdängest": "abdingen",
    "abdänget": "abdingen",
    "abebbe": "abebben",
    "abebbend": "abebben",
    "abebbende": "abebbend",
    "abebbendem": "abebbend",
    "abebbenden": "abebbend",
    "abebbender": "abebbend",
    "abebbendere": "abebbend",
    "abebbenderem": "abebbend",
    "abebbenderen": "abebbend",
    "abebbenderer": "abebbend",
    "abebbenderes": "abebbend",
    "abebbendes": "abebbend",
    "abebbendste": "abebbend",
    "abebbendstem": "abebbend",
    "abebbendsten": "abebbend",
    "abebbendster": "abebbend",
    "abebbendstes": "abebbend",
    "abebbest": "abebben",
    "abebbet": "abebben",
    "abebbst": "abebben",
    "abebbt": "abebben",
    "abebbte": "abebben",
    "abebbten": "abebben",
    "abebbtest": "abebben",
    "abebbtet": "abebben",
    "abendfüllendem": "abendfüllend",
    "abendfüllenden": "abendfüllend",
    "abendfüllender": "abendfüllend",
    "abendfüllendes": "abendfüllend",
    "abendliche": "abendlich",
    "abendlichem": "abendlich",
    "abendlichen": "abendlich",
    "abendlicher": "abendlich",
    "abendliches": "abendlich",
    "abendländische": "abendländisch",
    "abendländischem": "abendländisch",
    "abendländischen": "abendländisch",
    "abendländischer": "abendländisch",
    "abendländisches": "abendländisch",
    "abenteuerliche": "abenteuerlich",
    "abenteuerlichem": "abenteuerlich",
    "abenteuerlichen": "abenteuerlich",
    "abenteuerlicher": "abenteuerlich",
    "abenteuerlichere": "abenteuerlich",
    "abenteuerlicherem": "abenteuerlich",
    "abenteuerlicheren": "abenteuerlich",
    "abenteuerlicherer": "abenteuerlich",
    "abenteuerlicheres": "abenteuerlich",
    "abenteuerliches": "abenteuerlich",
    "abenteuerlichste": "abenteuerlich",
    "abenteuerlichstem": "abenteuerlich",
    "abenteuerlichsten": "abenteuerlich",
    "abenteuerlichster": "abenteuerlich",
    "abenteuerlichstes": "abenteuerlich",
    "abenteuerlustige": "abenteuerlustig",
    "abenteuerlustigem": "abenteuerlustig",
    "abenteuerlustigen": "abenteuerlustig",
    "abenteuerlustiger": "abenteuerlustig",
    "abenteuerlustigere": "abenteuerlustig",
    "abenteuerlustigerem": "abenteuerlustig",
    "abenteuerlustigeren": "abenteuerlustig",
    "abenteuerlustigerer": "abenteuerlustig",
    "abenteuerlustigeres": "abenteuerlustig",
    "abenteuerlustiges": "abenteuerlustig",
    "abenteuerlustigste": "abenteuerlustig",
    "abenteuerlustigstem": "abenteuerlustig",
    "abenteuerlustigsten": "abenteuerlustig",
    "abenteuerlustigster": "abenteuerlustig",
    "abenteuerlustigstes": "abenteuerlustig",
    "abergläubischem": "abergläubisch",
    "abergläubischen": "abergläubisch",
    "abergläubischer": "abergläubisch",
    "abergläubischere": "abergläubisch",
    "abergläubischerem": "abergläubisch",
    "abergläubischeren": "abergläubisch",
    "abergläubischerer": "abergläubisch",
    "abergläubischeres": "abergläubisch",
    "abergläubisches": "abergläubisch",
    "abergläubischste": "abergläubisch",
    "abergläubischstem": "abergläubisch",
    "abergläubischsten": "abergläubisch",
    "abergläubischster": "abergläubisch",
    "abergläubischstes": "abergläubisch",
    "aberkannt": "aberkennen",
    "aberkannte": "aberkannt",
    "aberkanntem": "aberkannt",
    "aberkannten": "aberkannt",
    "aberkannter": "aberkannt",
    "aberkanntes": "aberkannt",
    "aberkanntest": "aberkennen",
    "aberkanntet": "aberkennen",
    "aberkenne": "aberkennen",
    "aberkennend": "aberkennen",
    "aberkennende": "aberkennend",
    "aberkennendem": "aberkennend",
    "aberkennenden": "aberkennend",
    "aberkennender": "aberkennend",
    "aberkennendes": "aberkennend",
    "aberkennest": "aberkennen",
    "aberkennet": "aberkennen",
    "aberkennst": "aberkennen",
    "aberkennt": "aberkennen",
    "abermalige": "abermalig",
    "abermaligem": "abermalig",
    "abermaligen": "abermalig",
    "abermaliger": "abermalig",
    "abermaliges": "abermalig",
    "aberwitzigem": "aberwitzig",
    "aberwitzigen": "aberwitzig",
    "aberwitziger": "aberwitzig",
    "aberwitzigere": "aberwitzig",
    "aberwitzigerem": "aberwitzig",
    "aberwitzigeren": "aberwitzig",
    "aberwitzigerer": "aberwitzig",
    "aberwitzigeres": "aberwitzig",
    "aberwitziges": "aberwitzig",
    "aberwitzigste": "aberwitzig",
    "aberwitzigstem": "aberwitzig",
    "aberwitzigsten": "aberwitzig",
    "aberwitzigster": "aberwitzig",
    "aberwitzigstes": "aberwitzig",
    "abesse": "abessen",
    "abessend": "abessen",
    "abessende": "abessend",
    "abessendem": "abessend",
    "abessenden": "abessend",
    "abessender": "abessend",
    "abessendes": "abessend",
    "abessest": "abessen",
    "abesset": "abessen",
    "abeßt": "abessen",
    "abfahre": "abfahren",
    "abfahrend": "abfahren",
    "abfahrende": "abfahrend",
    "abfahrendem": "abfahrend",
    "abfahrenden": "abfahrend",
    "abfahrender": "abfahrend",
    "abfahrendes": "abfahrend",
    "abfahrest": "abfahren",
    "abfahret": "abfahren",
    "abfahrt": "abfahren",
    "abfallend": "abfallen",
    "abfallende": "abfallend",
    "abfallendem": "abfallend",
    "abfallenden": "abfallend",
    "abfallender": "abfallend",
    "abfallendere": "abfallend",
    "abfallenderem": "abfallend",
    "abfallenderen": "abfallend",
    "abfallenderer": "abfallend",
    "abfallenderes": "abfallend",
    "abfallendes": "abfallend",
    "abfallendste": "abfallend",
    "abfallendstem": "abfallend",
    "abfallendsten": "abfallend",
    "abfallendster": "abfallend",
    "abfallendstes": "abfallend",
    "abfallest": "abfallen",
    "abfallet": "abfallen",
    "abfallt": "abfallen",
    "abfand": "abfinden",
    "abfanden": "abfinden",
    "abfandest": "abfinden",
    "abfandet": "abfinden",
    "abfange": "abfangen",
    "abfangend": "abfangen",
    "abfangende": "abfangend",
    "abfangendem": "abfangend",
    "abfangenden": "abfangend",
    "abfangender": "abfangend",
    "abfangendes": "abfangend",
    "abfangest": "abfangen",
    "abfanget": "abfangen",
    "abfangt": "abfangen",
    "abfasse": "abfassen",
    "abfassend": "abfassen",
    "abfassende": "abfassend",
    "abfassendem": "abfassend",
    "abfassenden": "abfassend",
    "abfassender": "abfassend",
    "abfassendes": "abfassend",
    "abfassest": "abfassen",
    "abfasset": "abfassen",
    "abfaßt": "abfassen",
    "abfaßte": "abfassen",
    "abfaßten": "abfassen",
    "abfaßtest": "abfassen",
    "abfaßtet": "abfassen",
    "abfedere": "abfedern",
    "abfedernd": "abfedern",
    "abfedernde": "abfedernd",
    "abfederndem": "abfedernd",
    "abfedernden": "abfedernd",
    "abfedernder": "abfedernd",
    "abfederndere": "abfedernd",
    "abfedernderem": "abfedernd",
    "abfedernderen": "abfedernd",
    "abfedernderer": "abfedernd",
    "abfedernderes": "abfedernd",
    "abfederndes": "abfedernd",
    "abfederndste": "abfedernd",
    "abfederndstem": "abfedernd",
    "abfederndsten": "abfedernd",
    "abfederndster": "abfedernd",
    "abfederndstes": "abfedernd",
    "abfederst": "abfedern",
    "abfedert": "abfedern",
    "abfederte": "abfedern",
    "abfederten": "abfedern",
    "abfedertest": "abfedern",
    "abfedertet": "abfedern",
    "abfeiere": "abfeiern",
    "abfeiernd": "abfeiern",
    "abfeiernde": "abfeiernd",
    "abfeierndem": "abfeiernd",
    "abfeiernden": "abfeiernd",
    "abfeiernder": "abfeiernd",
    "abfeierndere": "abfeiernd",
    "abfeiernderem": "abfeiernd",
    "abfeiernderen": "abfeiernd",
    "abfeiernderer": "abfeiernd",
    "abfeiernderes": "abfeiernd",
    "abfeierndes": "abfeiernd",
    "abfeierndste": "abfeiernd",
    "abfeierndstem": "abfeiernd",
    "abfeierndsten": "abfeiernd",
    "abfeierndster": "abfeiernd",
    "abfeierndstes": "abfeiernd",
    "abfeierst": "abfeiern",
    "abfeiert": "abfeiern",
    "abfeierte": "abfeiern",
    "abfeierten": "abfeiern",
    "abfeiertest": "abfeiern",
    "abfeiertet": "abfeiern",
    "abfeile": "abfeilen",
    "abfeilend": "abfeilen",
    "abfeilende": "abfeilend",
    "abfeilendem": "abfeilend",
    "abfeilenden": "abfeilend",
    "abfeilender": "abfeilend",
    "abfeilendere": "abfeilend",
    "abfeilenderem": "abfeilend",
    "abfeilenderen": "abfeilend",
    "abfeilenderer": "abfeilend",
    "abfeilenderes": "abfeilend",
    "abfeilendes": "abfeilend",
    "abfeilendste": "abfeilend",
    "abfeilendstem": "abfeilend",
    "abfeilendsten": "abfeilend",
    "abfeilendster": "abfeilend",
    "abfeilendstes": "abfeilend",
    "abfeilest": "abfeilen",
    "abfeilet": "abfeilen",
    "abfeilst": "abfeilen",
    "abfeilt": "abfeilen",
    "abfeilte": "abfeilen",
    "abfeilten": "abfeilen",
    "abfeiltest": "abfeilen",
    "abfeiltet": "abfeilen",
    "abfertige": "abfertigen",
    "abfertigend": "abfertigen",
    "abfertigende": "abfertigend",
    "abfertigendem": "abfertigend",
    "abfertigenden": "abfertigend",
    "abfertigender": "abfertigend",
    "abfertigendes": "abfertigend",
    "abfertigest": "abfertigen",
    "abfertiget": "abfertigen",
    "abfertigst": "abfertigen",
    "abfertigt": "abfertigen",
    "abfertigte": "abfertigen",
    "abfertigten": "abfertigen",
    "abfertigtest": "abfertigen",
    "abfertigtet": "abfertigen",
    "abfeuere": "abfeuern",
    "abfeuernd": "abfeuern",
    "abfeuernde": "abfeuernd",
    "abfeuerndem": "abfeuernd",
    "abfeuernden": "abfeuernd",
    "abfeuernder": "abfeuernd",
    "abfeuerndes": "abfeuernd",
    "abfeuerst": "abfeuern",
    "abfeuert": "abfeuern",
    "abfeuerte": "abfeuern",
    "abfeuerten": "abfeuern",
    "abfeuertest": "abfeuern",
    "abfeuertet": "abfeuern",
    "abfiebere": "abfiebern",
    "abfiebernd": "abfiebern",
    "abfiebernde": "abfiebernd",
    "abfieberndem": "abfiebernd",
    "abfiebernden": "abfiebernd",
    "abfiebernder": "abfiebernd",
    "abfieberndes": "abfiebernd",
    "abfieberst": "abfiebern",
    "abfiebert": "abfiebern",
    "abfieberte": "abfiebern",
    "abfieberten": "abfiebern",
    "abfiebertest": "abfiebern",
    "abfiebertet": "abfiebern",
    "abfiel": "abfallen",
    "abfiele": "abfallen",
    "abfielen": "abfallen",
    "abfielest": "abfallen",
    "abfielet": "abfallen",
    "abfielst": "abfallen",
    "abfielt": "abfallen",
    "abfilme": "abfilmen",
    "abfilmend": "abfilmen",
    "abfilmende": "abfilmend",
    "abfilmendem": "abfilmend",
    "abfilmenden": "abfilmend",
    "abfilmender": "abfilmend",
    "abfilmendes": "abfilmend",
    "abfilmest": "abfilmen",
    "abfilmet": "abfilmen",
    "abfilmst": "abfilmen",
    "abfilmt": "abfilmen",
    "abfilmte": "abfilmen",
    "abfilmten": "abfilmen",
    "abfilmtest": "abfilmen",
    "abfilmtet": "abfilmen",
    "abfinde": "abfinden",
    "abfindend": "abfinden",
    "abfindende": "abfindend",
    "abfindendem": "abfindend",
    "abfindenden": "abfindend",
    "abfindender": "abfindend",
    "abfindendes": "abfindend",
    "abfindest": "abfinden",
    "abfindet": "abfinden",
    "abfing": "abfangen",
    "abfinge": "abfangen",
    "abfingen": "abfangen",
    "abfingest": "abfangen",
    "abfinget": "abfangen",
    "abfingst": "abfangen",
    "abfingt": "abfangen",
    "abfische": "abfischen",
    "abfischend": "abfischen",
    "abfischende": "abfischend",
    "abfischendem": "abfischend",
    "abfischenden": "abfischend",
    "abfischender": "abfischend",
    "abfischendere": "abfischend",
    "abfischenderem": "abfischend",
    "abfischenderen": "abfischend",
    "abfischenderer": "abfischend",
    "abfischenderes": "abfischend",
    "abfischendes": "abfischend",
    "abfischendste": "abfischend",
    "abfischendstem": "abfischend",
    "abfischendsten": "abfischend",
    "abfischendster": "abfischend",
    "abfischendstes": "abfischend",
    "abfischest": "abfischen",
    "abfischet": "abfischen",
    "abfischst": "abfischen",
    "abfischt": "abfischen",
    "abfischte": "abfischen",
    "abfischten": "abfischen",
    "abfischtest": "abfischen",
    "abfischtet": "abfischen",
    "abflache": "abflachen",
    "abflachend": "abflachen",
    "abflachende": "abflachend",
    "abflachendem": "abflachend",
    "abflachenden": "abflachend",
    "abflachender": "abflachend",
    "abflachendere": "abflachend",
    "abflachenderem": "abflachend",
    "abflachenderen": "abflachend",
    "abflachenderer": "abflachend",
    "abflachenderes": "abflachend",
    "abflachendes": "abflachend",
    "abflachendste": "abflachend",
    "abflachendstem": "abflachend",
    "abflachendsten": "abflachend",
    "abflachendster": "abflachend",
    "abflachendstes": "abflachend",
    "abflachest": "abflachen",
    "abflachet": "abflachen",
    "abflachst": "abflachen",
    "abflacht": "abflachen",
    "abflachte": "abflachen",
    "abflachten": "abflachen",
    "abflachtest": "abflachen",
    "abflachtet": "abflachen",
    "abflaue": "abflauen",
    "abflauend": "abflauen",
    "abflauende": "abflauend",
    "abflauendem": "abflauend",
    "abflauenden": "abflauend",
    "abflauender": "abflauend",
    "abflauendes": "abflauend",
    "abflauest": "abflauen",
    "abflauet": "abflauen",
    "abflaust": "abflauen",
    "abflaut": "abflauen",
    "abflaute": "abflauen",
    "abflauten": "abflauen",
    "abflautest": "abflauen",
    "abflautet": "abflauen",
    "abfliege": "abfliegen",
    "abfliegend": "abfliegen",
    "abfliegende": "abfliegend",
    "abfliegendem": "abfliegend",
    "abfliegenden": "abfliegend",
    "abfliegender": "abfliegend",
    "abfliegendes": "abfliegend",
    "abfliegest": "abfliegen",
    "abflieget": "abfliegen",
    "abfliegst": "abfliegen",
    "abfliegt": "abfliegen",
    "abfließe": "abfließen",
    "abfließend": "abfließen",
    "abfließende": "abfließend",
    "abfließendem": "abfließend",
    "abfließenden": "abfließend",
    "abfließender": "abfließend",
    "abfließendes": "abfließend",
    "abfließest": "abfließen",
    "abfließet": "abfließen",
    "abfließt": "abfließen",
    "abflog": "abfliegen",
    "abflogen": "abfliegen",
    "abflogst": "abfliegen",
    "abflogt": "abfliegen",
    "abflossen": "abfließen",
    "abfloß": "abfließen",
    "abfloßt": "abfließen",
    "abfluchte": "abfluchten",
    "abfluchtend": "abfluchten",
    "abfluchtende": "abfluchtend",
    "abfluchtendem": "abfluchtend",
    "abfluchtenden": "abfluchtend",
    "abfluchtender": "abfluchtend",
    "abfluchtendes": "abfluchtend",
    "abfluchtest": "abfluchten",
    "abfluchtet": "abfluchten",
    "abfluchtete": "abfluchten",
    "abfluchteten": "abfluchten",
    "abfluchtetest": "abfluchten",
    "abfluchtetet": "abfluchten",
    "abflöge": "abfliegen",
    "abflögen": "abfliegen",
    "abflögest": "abfliegen",
    "abflöget": "abfliegen",
    "abflösse": "abfließen",
    "abflössen": "abfließen",
    "abflössest": "abfließen",
    "abflösset": "abfließen",
    "abfordere": "abfordern",
    "abfordernd": "abfordern",
    "abfordernde": "abfordernd",
    "abforderndem": "abfordernd",
    "abfordernden": "abfordernd",
    "abfordernder": "abfordernd",
    "abforderndere": "abfordernd",
    "abfordernderem": "abfordernd",
    "abfordernderen": "abfordernd",
    "abfordernderer": "abfordernd",
    "abfordernderes": "abfordernd",
    "abforderndes": "abfordernd",
    "abforderndste": "abfordernd",
    "abforderndstem": "abfordernd",
    "abforderndsten": "abfordernd",
    "abforderndster": "abfordernd",
    "abforderndstes": "abfordernd",
    "abforderst": "abfordern",
    "abfordert": "abfordern",
    "abforderte": "abfordern",
    "abforderten": "abfordern",
    "abfordertest": "abfordern",
    "abfordertet": "abfordern",
    "abforme": "abformen",
    "abformend": "abformen",
    "abformende": "abformend",
    "abformendem": "abformend",
    "abformenden": "abformend",
    "abformender": "abformend",
    "abformendes": "abformend",
    "abformest": "abformen",
    "abformet": "abformen",
    "abformst": "abformen",
    "abformt": "abformen",
    "abformte": "abformen",
    "abformten": "abformen",
    "abformtest": "abformen",
    "abformtet": "abformen",
    "abfrage": "abfragen",
    "abfragend": "abfragen",
    "abfragende": "abfragend",
    "abfragendem": "abfragend",
    "abfragenden": "abfragend",
    "abfragender": "abfragend",
    "abfragendes": "abfragend",
    "abfragest": "abfragen",
    "abfraget": "abfragen",
    "abfragst": "abfragen",
    "abfragt": "abfragen",
    "abfragte": "abfragen",
    "abfragten": "abfragen",
    "abfragtest": "abfragen",
    "abfragtet": "abfragen",
    "abfraß": "abfressen",
    "abfraßen": "abfressen",
    "abfraßt": "abfressen",
    "abfresse": "abfressen",
    "abfressend": "abfressen",
    "abfressende": "abfressend",
    "abfressendem": "abfressend",
    "abfressenden": "abfressend",
    "abfressender": "abfressend",
    "abfressendere": "abfressend",
    "abfressenderem": "abfressend",
    "abfressenderen": "abfressend",
    "abfressenderer": "abfressend",
    "abfressenderes": "abfressend",
    "abfressendes": "abfressend",
    "abfressendste": "abfressend",
    "abfressendstem": "abfressend",
    "abfressendsten": "abfressend",
    "abfressendster": "abfressend",
    "abfressendstes": "abfressend",
    "abfressest": "abfressen",
    "abfresset": "abfressen",
    "abfreßt": "abfressen",
    "abfriere": "abfrieren",
    "abfrierend": "abfrieren",
    "abfrierende": "abfrierend",
    "abfrierendem": "abfrierend",
    "abfrierenden": "abfrierend",
    "abfrierender": "abfrierend",
    "abfrierendere": "abfrierend",
    "abfrierenderem": "abfrierend",
    "abfrierenderen": "abfrierend",
    "abfrierenderer": "abfrierend",
    "abfrierenderes": "abfrierend",
    "abfrierendes": "abfrierend",
    "abfrierendste": "abfrierend",
    "abfrierendstem": "abfrierend",
    "abfrierendsten": "abfrierend",
    "abfrierendster": "abfrierend",
    "abfrierendstes": "abfrierend",
    "abfrierest": "abfrieren",
    "abfrieret": "abfrieren",
    "abfrierst": "abfrieren",
    "abfriert": "abfrieren",
    "abfrißt": "abfressen",
    "abfror": "abfrieren",
    "abfroren": "abfrieren",
    "abfrorst": "abfrieren",
    "abfrort": "abfrieren",
    "abfräße": "abfressen",
    "abfräßen": "abfressen",
    "abfräßest": "abfressen",
    "abfräßet": "abfressen",
    "abfröre": "abfrieren",
    "abfrören": "abfrieren",
    "abfrörest": "abfrieren",
    "abfröret": "abfrieren",
    "abfuhr": "abfahren",
    "abfuhren": "abfahren",
    "abfuhrst": "abfahren",
    "abfuhrt": "abfahren",
    "abfährst": "abfahren",
    "abfährt": "abfahren",
    "abfällige": "abfällig",
    "abfälligem": "abfällig",
    "abfälligen": "abfällig",
    "abfälliger": "abfällig",
    "abfälliges": "abfällig",
    "abfällst": "abfallen",
    "abfällt": "abfallen",
    "abfälsche": "abfälschen",
    "abfälschend": "abfälschen",
    "abfälschende": "abfälschend",
    "abfälschendem": "abfälschend",
    "abfälschenden": "abfälschend",
    "abfälschender": "abfälschend",
    "abfälschendes": "abfälschend",
    "abfälschest": "abfälschen",
    "abfälschet": "abfälschen",
    "abfälschst": "abfälschen",
    "abfälscht": "abfälschen",
    "abfälschte": "abfälschen",
    "abfälschten": "abfälschen",
    "abfälschtest": "abfälschen",
    "abfälschtet": "abfälschen",
    "abfände": "abfinden",
    "abfänden": "abfinden",
    "abfändest": "abfinden",
    "abfändet": "abfinden",
    "abfängst": "abfangen",
    "abfängt": "abfangen",
    "abfärbe": "abfärben",
    "abfärbend": "abfärben",
    "abfärbende": "abfärbend",
    "abfärbendem": "abfärbend",
    "abfärbenden": "abfärbend",
    "abfärbender": "abfärbend",
    "abfärbendere": "abfärbend",
    "abfärbenderem": "abfärbend",
    "abfärbenderen": "abfärbend",
    "abfärbenderer": "abfärbend",
    "abfärbenderes": "abfärbend",
    "abfärbendes": "abfärbend",
    "abfärbendste": "abfärbend",
    "abfärbendstem": "abfärbend",
    "abfärbendsten": "abfärbend",
    "abfärbendster": "abfärbend",
    "abfärbendstes": "abfärbend",
    "abfärbest": "abfärben",
    "abfärbet": "abfärben",
    "abfärbst": "abfärben",
    "abfärbt": "abfärben",
    "abfärbte": "abfärben",
    "abfärbten": "abfärben",
    "abfärbtest": "abfärben",
    "abfärbtet": "abfärben",
    "abführe": "abführen",
    "abführend": "abführen",
    "abführende": "abführend",
    "abführendem": "abführend",
    "abführenden": "abführend",
    "abführender": "abführend",
    "abführendes": "abführend",
    "abführest": "abführen",
    "abführet": "abführen",
    "abführst": "abführen",
    "abführt": "abführen",
    "abführte": "abführen",
    "abführten": "abführen",
    "abführtest": "abführen",
    "abführtet": "abführen",
    "abfülle": "abfüllen",
    "abfüllend": "abfüllen",
    "abfüllende": "abfüllend",
    "abfüllendem": "abfüllend",
    "abfüllenden": "abfüllend",
    "abfüllender": "abfüllend",
    "abfüllendes": "abfüllend",
    "abfüllest": "abfüllen",
    "abfüllet": "abfüllen",
    "abfüllst": "abfüllen",
    "abfüllt": "abfüllen",
    "abfüllte": "abfüllen",
    "abfüllten": "abfüllen",
    "abfülltest": "abfüllen",
    "abfülltet": "abfüllen",
    "abfüttere": "abfüttern",
    "abfütternd": "abfüttern",
    "abfütternde": "abfütternd",
    "abfütterndem": "abfütternd",
    "abfütternden": "abfütternd",
    "abfütternder": "abfütternd",
    "abfütterndes": "abfütternd",
    "abfütterst": "abfüttern",
    "abfüttert": "abfüttern",
    "abfütterte": "abfüttern",
    "abfütterten": "abfüttern",
    "abfüttertest": "abfüttern",
    "abfüttertet": "abfüttern",
    "abgab": "abgeben",
    "abgabenfreie": "abgabenfrei",
    "abgabenfreiem": "abgabenfrei",
    "abgabenfreien": "abgabenfrei",
    "abgabenfreier": "abgabenfrei",
    "abgabenfreies": "abgabenfrei",
    "abgabst": "abgeben",
    "abgabt": "abgeben",
    "abgalt": "abgelten",
    "abgalten": "abgelten",
    "abgaltest": "abgelten",
    "abgaltet": "abgelten",
    "abgasarmem": "abgasarm",
    "abgasarmen": "abgasarm",
    "abgasarmer": "abgasarm",
    "abgasarmes": "abgasarm",
    "abgasärmer": "abgasarm",
    "abgasärmere": "abgasarm",
    "abgasärmerem": "abgasarm",
    "abgasärmeren": "abgasarm",
    "abgasärmerer": "abgasarm",
    "abgasärmeres": "abgasarm",
    "abgasärmsten": "abgasarm",
    "abgaunere": "abgaunern",
    "abgaunernd": "abgaunern",
    "abgaunernde": "abgaunernd",
    "abgaunerndem": "abgaunernd",
    "abgaunernden": "abgaunernd",
    "abgaunernder": "abgaunernd",
    "abgaunerndes": "abgaunernd",
    "abgaunerst": "abgaunern",
    "abgaunert": "abgaunern",
    "abgaunerte": "abgaunern",
    "abgaunerten": "abgaunern",
    "abgaunertest": "abgaunern",
    "abgaunertet": "abgaunern",
    "abgearbeitet": "abarbeiten",
    "abgearbeitete": "abgearbeitet",
    "abgearbeitetem": "abgearbeitet",
    "abgearbeiteten": "abgearbeitet",
    "abgearbeiteter": "abgearbeitet",
    "abgearbeitetes": "abgearbeitet",
    "abgebalgt": "abbalgen",
    "abgebalgte": "abgebalgt",
    "abgebalgtem": "abgebalgt",
    "abgebalgten": "abgebalgt",
    "abgebalgter": "abgebalgt",
    "abgebalgtes": "abgebalgt",
    "abgebaut": "abbauen",
    "abgebaute": "abgebaut",
    "abgebautem": "abgebaut",
    "abgebauten": "abgebaut",
    "abgebauter": "abgebaut",
    "abgebautere": "abgebaut",
    "abgebauterem": "abgebaut",
    "abgebauteren": "abgebaut",
    "abgebauterer": "abgebaut",
    "abgebauteres": "abgebaut",
    "abgebautes": "abgebaut",
    "abgebauteste": "abgebaut",
    "abgebautestem": "abgebaut",
    "abgebautesten": "abgebaut",
    "abgebautester": "abgebaut",
    "abgebautestes": "abgebaut",
    "abgebe": "abgeben",
    "abgebeizt": "abbeizen",
    "abgebeizte": "abgebeizt",
    "abgebeiztem": "abgebeizt",
    "abgebeizten": "abgebeizt",
    "abgebeizter": "abgebeizt",
    "abgebeiztes": "abgebeizt",
    "abgebend": "abgeben",
    "abgebende": "abgebend",
    "abgebendem": "abgebend",
    "abgebenden": "abgebend",
    "abgebender": "abgebend",
    "abgebendes": "abgebend",
    "abgebest": "abgeben",
    "abgebet": "abgeben",
    "abgebeten": "abbitten",
    "abgebetene": "abgebeten",
    "abgebetenem": "abgebeten",
    "abgebetenen": "abgebeten",
    "abgebetener": "abgebeten",
    "abgebetenes": "abgebeten",
    "abgebetet": "abbeten",
    "abgebetete": "abgebetet",
    "abgebetetem": "abgebetet",
    "abgebeteten": "abgebetet",
    "abgebeteter": "abgebetet",
    "abgebetetes": "abgebetet",
    "abgebettelt": "abbetteln",
    "abgebettelte": "abgebettelt",
    "abgebetteltem": "abgebettelt",
    "abgebettelten": "abgebettelt",
    "abgebettelter": "abgebettelt",
    "abgebetteltes": "abgebettelt",
    "abgebildet": "abbilden",
    "abgebildete": "abgebildet",
    "abgebildetem": "abgebildet",
    "abgebildeten": "abgebildet",
    "abgebildeter": "abgebildet",
    "abgebildetes": "abgebildet",
    "abgebissen": "abbeißen",
    "abgebissene": "abgebissen",
    "abgebissenem": "abgebissen",
    "abgebissenen": "abgebissen",
    "abgebissener": "abgebissen",
    "abgebissenere": "abgebissen",
    "abgebissenerem": "abgebissen",
    "abgebisseneren": "abgebissen",
    "abgebissenerer": "abgebissen",
    "abgebisseneres": "abgebissen",
    "abgebissenes": "abgebissen",
    "abgebissenste": "abgebissen",
    "abgebissenstem": "abgebissen",
    "abgebissensten": "abgebissen",
    "abgebissenster": "abgebissen",
    "abgebissenstes": "abgebissen",
    "abgeblasen": "abblasen",
    "abgeblasene": "abgeblasen",
    "abgeblasenem": "abgeblasen",
    "abgeblasenen": "abgeblasen",
    "abgeblasener": "abgeblasen",
    "abgeblasenes": "abgeblasen",
    "abgeblaßt": "abblassen",
    "abgeblaßte": "abgeblaßt",
    "abgeblaßtem": "abgeblaßt",
    "abgeblaßten": "abgeblaßt",
    "abgeblaßter": "abgeblaßt",
    "abgeblaßtes": "abgeblaßt",
    "abgeblendet": "abblenden",
    "abgeblendete": "abgeblendet",
    "abgeblendetem": "abgeblendet",
    "abgeblendeten": "abgeblendet",
    "abgeblendeter": "abgeblendet",
    "abgeblendetes": "abgeblendet",
    "abgeblieben": "abbleiben",
    "abgebliebene": "abgeblieben",
    "abgebliebenem": "abgeblieben",
    "abgebliebenen": "abgeblieben",
    "abgebliebener": "abgeblieben",
    "abgebliebenes": "abgeblieben",
    "abgeblitzt": "abblitzen",
    "abgeblitzte": "abgeblitzt",
    "abgeblitztem": "abgeblitzt",
    "abgeblitzten": "abgeblitzt",
    "abgeblitzter": "abgeblitzt",
    "abgeblitztere": "abgeblitzt",
    "abgeblitzterem": "abgeblitzt",
    "abgeblitzteren": "abgeblitzt",
    "abgeblitzterer": "abgeblitzt",
    "abgeblitzteres": "abgeblitzt",
    "abgeblitztes": "abgeblitzt",
    "abgeblitzteste": "abgeblitzt",
    "abgeblitztestem": "abgeblitzt",
    "abgeblitztesten": "abgeblitzt",
    "abgeblitztester": "abgeblitzt",
    "abgeblitztestes": "abgeblitzt",
    "abgeblättert": "abblättern",
    "abgeblätterte": "abgeblättert",
    "abgeblättertem": "abgeblättert",
    "abgeblätterten": "abgeblättert",
    "abgeblätterter": "abgeblättert",
    "abgeblättertere": "abgeblättert",
    "abgeblätterterem": "abgeblättert",
    "abgeblätterteren": "abgeblättert",
    "abgeblätterterer": "abgeblättert",
    "abgeblätterteres": "abgeblättert",
    "abgeblättertes": "abgeblättert",
    "abgeblätterteste": "abgeblättert",
    "abgeblättertestem": "abgeblättert",
    "abgeblättertesten": "abgeblättert",
    "abgeblättertester": "abgeblättert",
    "abgeblättertestes": "abgeblättert",
    "abgeblüht": "abblühen",
    "abgeblühte": "abgeblüht",
    "abgeblühtem": "abgeblüht",
    "abgeblühten": "abgeblüht",
    "abgeblühter": "abgeblüht",
    "abgeblühtere": "abgeblüht",
    "abgeblühterem": "abgeblüht",
    "abgeblühteren": "abgeblüht",
    "abgeblühterer": "abgeblüht",
    "abgeblühteres": "abgeblüht",
    "abgeblühtes": "abgeblüht",
    "abgeblühteste": "abgeblüht",
    "abgeblühtestem": "abgeblüht",
    "abgeblühtesten": "abgeblüht",
    "abgeblühtester": "abgeblüht",
    "abgeblühtestes": "abgeblüht",
    "abgebogen": "abbiegen",
    "abgebogene": "abgebogen",
    "abgebogenem": "abgebogen",
    "abgebogenen": "abgebogen",
    "abgebogener": "abgebogen",
    "abgebogenes": "abgebogen",
    "abgebracht": "abbringen",
    "abgebrachte": "abgebracht",
    "abgebrachtem": "abgebracht",
    "abgebrachten": "abgebracht",
    "abgebrachter": "abgebracht",
    "abgebrachtes": "abgebracht",
    "abgebrannt": "abbrennen",
    "abgebrannte": "abgebrannt",
    "abgebranntem": "abgebrannt",
    "abgebrannten": "abgebrannt",
    "abgebrannter": "abgebrannt",
    "abgebranntere": "abgebrannt",
    "abgebrannterem": "abgebrannt",
    "abgebrannteren": "abgebrannt",
    "abgebrannterer": "abgebrannt",
    "abgebrannteres": "abgebrannt",
    "abgebranntes": "abgebrannt",
    "abgebrannteste": "abgebrannt",
    "abgebranntestem": "abgebrannt",
    "abgebranntesten": "abgebrannt",
    "abgebranntester": "abgebrannt",
    "abgebranntestes": "abgebrannt",
    "abgebraust": "abbrausen",
    "abgebrauste": "abgebraust",
    "abgebraustem": "abgebraust",
    "abgebrausten": "abgebraust",
    "abgebrauster": "abgebraust",
    "abgebraustes": "abgebraust",
    "abgebremst": "abbremsen",
    "abgebremste": "abgebremst",
    "abgebremstem": "abgebremst",
    "abgebremsten": "abgebremst",
    "abgebremster": "abgebremst",
    "abgebremstes": "abgebremst",
    "abgebrochen": "abbrechen",
    "abgebrochene": "abgebrochen",
    "abgebrochenem": "abgebrochen",
    "abgebrochenen": "abgebrochen",
    "abgebrochener": "abgebrochen",
    "abgebrochenere": "abgebrochen",
    "abgebrochenerem": "abgebrochen",
    "abgebrocheneren": "abgebrochen",
    "abgebrochenerer": "abgebrochen",
    "abgebrocheneres": "abgebrochen",
    "abgebrochenes": "abgebrochen",
    "abgebrochenste": "abgebrochen",
    "abgebrochenstem": "abgebrochen",
    "abgebrochensten": "abgebrochen",
    "abgebrochenster": "abgebrochen",
    "abgebrochenstes": "abgebrochen",
    "abgebröckelt": "abbröckeln",
    "abgebröckelte": "abgebröckelt",
    "abgebröckeltem": "abgebröckelt",
    "abgebröckelten": "abgebröckelt",
    "abgebröckelter": "abgebröckelt",
    "abgebröckeltere": "abgebröckelt",
    "abgebröckelterem": "abgebröckelt",
    "abgebröckelteren": "abgebröckelt",
    "abgebröckelterer": "abgebröckelt",
    "abgebröckelteres": "abgebröckelt",
    "abgebröckeltes": "abgebröckelt",
    "abgebröckelteste": "abgebröckelt",
    "abgebröckeltestem": "abgebröckelt",
    "abgebröckeltesten": "abgebröckelt",
    "abgebröckeltester": "abgebröckelt",
    "abgebröckeltestes": "abgebröckelt",
    "abgebrüht": "abbrühen",
    "abgebrühte": "abgebrüht",
    "abgebrühtem": "abgebrüht",
    "abgebrühten": "abgebrüht",
    "abgebrühter": "abgebrüht",
    "abgebrühtere": "abgebrüht",
    "abgebrühterem": "abgebrüht",
    "abgebrühteren": "abgebrüht",
    "abgebrühterer": "abgebrüht",
    "abgebrühteres": "abgebrüht",
    "abgebrühtes": "abgebrüht",
    "abgebrühteste": "abgebrüht",
    "abgebrühtestem": "abgebrüht",
    "abgebrühtesten": "abgebrüht",
    "abgebrühtester": "abgebrüht",
    "abgebrühtestes": "abgebrüht",
    "abgebt": "abgeben",
    "abgebucht": "abbuchen",
    "abgebuchte": "abgebucht",
    "abgebuchtem": "abgebucht",
    "abgebuchten": "abgebucht",
    "abgebuchter": "abgebucht",
    "abgebuchtes": "abgebucht",
    "abgebunden": "abbinden",
    "abgebundene": "abgebunden",
    "abgebundenem": "abgebunden",
    "abgebundenen": "abgebunden",
    "abgebundener": "abgebunden",
    "abgebundenere": "abgebunden",
    "abgebundenerem": "abgebunden",
    "abgebundeneren": "abgebunden",
    "abgebundenerer": "abgebunden",
    "abgebundeneres": "abgebunden",
    "abgebundenes": "abgebunden",
    "abgebundenste": "abgebunden",
    "abgebundenstem": "abgebunden",
    "abgebundensten": "abgebunden",
    "abgebundenster": "abgebunden",
    "abgebundenstes": "abgebunden",
    "abgebürstet": "abbürsten",
    "abgebürstete": "abgebürstet",
    "abgebürstetem": "abgebürstet",
    "abgebürsteten": "abgebürstet",
    "abgebürsteter": "abgebürstet",
    "abgebürstetes": "abgebürstet",
    "abgebüßt": "abbüßen",
    "abgebüßte": "abgebüßt",
    "abgebüßtem": "abgebüßt",
    "abgebüßten": "abgebüßt",
    "abgebüßter": "abgebüßt",
    "abgebüßtes": "abgebüßt",
    "abgedacht": "abdachen",
    "abgedachte": "abgedacht",
    "abgedachtem": "abgedacht",
    "abgedachten": "abgedacht",
    "abgedachter": "abgedacht",
    "abgedachtes": "abgedacht",
    "abgedampft": "abdampfen",
    "abgedampfte": "abgedampft",
    "abgedampftem": "abgedampft",
    "abgedampften": "abgedampft",
    "abgedampfter": "abgedampft",
    "abgedampftes": "abgedampft",
    "abgedankt": "abdanken",
    "abgedankte": "abgedankt",
    "abgedanktem": "abgedankt",
    "abgedankten": "abgedankt",
    "abgedankter": "abgedankt",
    "abgedanktes": "abgedankt",
    "abgedarbt": "abdarben",
    "abgedarbte": "abgedarbt",
    "abgedarbtem": "abgedarbt",
    "abgedarbten": "abgedarbt",
    "abgedarbter": "abgedarbt",
    "abgedarbtes": "abgedarbt",
    "abgedeckt": "abdecken",
    "abgedeckte": "abgedeckt",
    "abgedecktem": "abgedeckt",
    "abgedeckten": "abgedeckt",
    "abgedeckter": "abgedeckt",
    "abgedecktes": "abgedeckt",
    "abgedichtet": "abdichten",
    "abgedichtete": "abgedichtet",
    "abgedichtetem": "abgedichtet",
    "abgedichteten": "abgedichtet",
    "abgedichteter": "abgedichtet",
    "abgedichtetere": "abgedichtet",
    "abgedichteterem": "abgedichtet",
    "abgedichteteren": "abgedichtet",
    "abgedichteterer": "abgedichtet",
    "abgedichteteres": "abgedichtet",
    "abgedichtetes": "abgedichtet",
    "abgedichteteste": "abgedichtet",
    "abgedichtetestem": "abgedichtet",
    "abgedichtetesten": "abgedichtet",
    "abgedichtetester": "abgedichtet",
    "abgedichtetestes": "abgedichtet",
    "abgedient": "abdienen",
    "abgediente": "abgedient",
    "abgedientem": "abgedient",
    "abgedienten": "abgedient",
    "abgedienter": "abgedient",
    "abgedientes": "abgedient",
    "abgedreht": "abdrehen",
    "abgedrehte": "abgedreht",
    "abgedrehtem": "abgedreht",
    "abgedrehten": "abgedreht",
    "abgedrehter": "abgedreht",
    "abgedrehtere": "abgedreht",
    "abgedrehterem": "abgedreht",
    "abgedrehteren": "abgedreht",
    "abgedrehterer": "abgedreht",
    "abgedrehteres": "abgedreht",
    "abgedrehtes": "abgedreht",
    "abgedrehteste": "abgedreht",
    "abgedrehtestem": "abgedreht",
    "abgedrehtesten": "abgedreht",
    "abgedrehtester": "abgedreht",
    "abgedrehtestes": "abgedreht",
    "abgedriftet": "abdriften",
    "abgedriftete": "abgedriftet",
    "abgedriftetem": "abgedriftet",
    "abgedrifteten": "abgedriftet",
    "abgedrifteter": "abgedriftet",
    "abgedriftetere": "abgedriftet",
    "abgedrifteterem": "abgedriftet",
    "abgedrifteteren": "abgedriftet",
    "abgedrifteterer": "abgedriftet",
    "abgedrifteteres": "abgedriftet",
    "abgedriftetes": "abgedriftet",
    "abgedrifteteste": "abgedriftet",
    "abgedriftetestem": "abgedriftet",
    "abgedriftetesten": "abgedriftet",
    "abgedriftetester": "abgedriftet",
    "abgedriftetestes": "abgedriftet",
    "abgedroschene": "abgedroschen",
    "abgedroschenem": "abgedroschen",
    "abgedroschenen": "abgedroschen",
    "abgedroschener": "abgedroschen",
    "abgedroschenere": "abgedroschen",
    "abgedroschenerem": "abgedroschen",
    "abgedroscheneren": "abgedroschen",
    "abgedroschenerer": "abgedroschen",
    "abgedroscheneres": "abgedroschen",
    "abgedroschenes": "abgedroschen",
    "abgedroschenste": "abgedroschen",
    "abgedroschenstem": "abgedroschen",
    "abgedroschensten": "abgedroschen",
    "abgedroschenster": "abgedroschen",
    "abgedroschenstes": "abgedroschen",
    "abgedrosselt": "abdrosseln",
    "abgedrosselte": "abgedrosselt",
    "abgedrosseltem": "abgedrosselt",
    "abgedrosselten": "abgedrosselt",
    "abgedrosselter": "abgedrosselt",
    "abgedrosseltes": "abgedrosselt",
    "abgedruckt": "abdrucken",
    "abgedruckte": "abgedruckt",
    "abgedrucktem": "abgedruckt",
    "abgedruckten": "abgedruckt",
    "abgedruckter": "abgedruckt",
    "abgedrucktes": "abgedruckt",
    "abgedrängt": "abdrängen",
    "abgedrängte": "abgedrängt",
    "abgedrängtem": "abgedrängt",
    "abgedrängten": "abgedrängt",
    "abgedrängter": "abgedrängt",
    "abgedrängtes": "abgedrängt",
    "abgedrückt": "abdrücken",
    "abgedrücktem": "abgedrückt",
    "abgedrückter": "abgedrückt",
    "abgedrücktes": "abgedrückt",
    "abgedungen": "abdingen",
    "abgedungene": "abgedungen",
    "abgedungenem": "abgedungen",
    "abgedungenen": "abgedungen",
    "abgedungener": "abgedungen",
    "abgedungenes": "abgedungen",
    "abgedunkelt": "abdunkeln",
    "abgedunkelte": "abgedunkelt",
    "abgedunkeltem": "abgedunkelt",
    "abgedunkelten": "abgedunkelt",
    "abgedunkelter": "abgedunkelt",
    "abgedunkeltere": "abgedunkelt",
    "abgedunkelterem": "abgedunkelt",
    "abgedunkelteren": "abgedunkelt",
    "abgedunkelterer": "abgedunkelt",
    "abgedunkelteres": "abgedunkelt",
    "abgedunkeltes": "abgedunkelt",
    "abgedunkelteste": "abgedunkelt",
    "abgedunkeltestem": "abgedunkelt",
    "abgedunkeltesten": "abgedunkelt",
    "abgedunkeltester": "abgedunkelt",
    "abgedunkeltestes": "abgedunkelt",
    "abgeduscht": "abduschen",
    "abgeduschte": "abgeduscht",
    "abgeduschtem": "abgeduscht",
    "abgeduschten": "abgeduscht",
    "abgeduschter": "abgeduscht",
    "abgeduschtes": "abgeduscht",
    "abgedämmt": "abdämmen",
    "abgedämmte": "abgedämmt",
    "abgedämmtem": "abgedämmt",
    "abgedämmten": "abgedämmt",
    "abgedämmter": "abgedämmt",
    "abgedämmtere": "abgedämmt",
    "abgedämmterem": "abgedämmt",
    "abgedämmteren": "abgedämmt",
    "abgedämmterer": "abgedämmt",
    "abgedämmteres": "abgedämmt",
    "abgedämmtes": "abgedämmt",
    "abgedämmteste": "abgedämmt",
    "abgedämmtestem": "abgedämmt",
    "abgedämmtesten": "abgedämmt",
    "abgedämmtester": "abgedämmt",
    "abgedämmtestes": "abgedämmt",
    "abgeebbt": "abebben",
    "abgeebbte": "abgeebbt",
    "abgeebbtem": "abgeebbt",
    "abgeebbten": "abgeebbt",
    "abgeebbter": "abgeebbt",
    "abgeebbtere": "abgeebbt",
    "abgeebbterem": "abgeebbt",
    "abgeebbteren": "abgeebbt",
    "abgeebbterer": "abgeebbt",
    "abgeebbteres": "abgeebbt",
    "abgeebbtes": "abgeebbt",
    "abgeebbteste": "abgeebbt",
    "abgeebbtestem": "abgeebbt",
    "abgeebbtesten": "abgeebbt",
    "abgeebbtester": "abgeebbt",
    "abgeebbtestes": "abgeebbt",
    "abgefahren": "abfahren",
    "abgefahrene": "abgefahren",
    "abgefahrenem": "abgefahren",
    "abgefahrenen": "abgefahren",
    "abgefahrener": "abgefahren",
    "abgefahrenere": "abgefahren",
    "abgefahrenerem": "abgefahren",
    "abgefahreneren": "abgefahren",
    "abgefahrenerer": "abgefahren",
    "abgefahreneres": "abgefahren",
    "abgefahrenes": "abgefahren",
    "abgefahrenste": "abgefahren",
    "abgefahrenstem": "abgefahren",
    "abgefahrensten": "abgefahren",
    "abgefahrenster": "abgefahren",
    "abgefahrenstes": "abgefahren",
    "abgefallen": "abfallen",
    "abgefallene": "abgefallen",
    "abgefallenem": "abgefallen",
    "abgefallenen": "abgefallen",
    "abgefallener": "abgefallen",
    "abgefallenere": "abgefallen",
    "abgefallenerem": "abgefallen",
    "abgefalleneren": "abgefallen",
    "abgefallenerer": "abgefallen",
    "abgefalleneres": "abgefallen",
    "abgefallenes": "abgefallen",
    "abgefallenste": "abgefallen",
    "abgefallenstem": "abgefallen",
    "abgefallensten": "abgefallen",
    "abgefallenster": "abgefallen",
    "abgefallenstes": "abgefallen",
    "abgefangen": "abfangen",
    "abgefangene": "abgefangen",
    "abgefangenem": "abgefangen",
    "abgefangenen": "abgefangen",
    "abgefangener": "abgefangen",
    "abgefangenes": "abgefangen",
    "abgefaßt": "abfassen",
    "abgefaßte": "abgefaßt",
    "abgefaßtem": "abgefaßt",
    "abgefaßten": "abgefaßt",
    "abgefaßter": "abgefaßt",
    "abgefaßtes": "abgefaßt",
    "abgefedert": "abfedern",
    "abgefederte": "abgefedert",
    "abgefedertem": "abgefedert",
    "abgefederten": "abgefedert",
    "abgefederter": "abgefedert",
    "abgefedertere": "abgefedert",
    "abgefederterem": "abgefedert",
    "abgefederteren": "abgefedert",
    "abgefederterer": "abgefedert",
    "abgefederteres": "abgefedert",
    "abgefedertes": "abgefedert",
    "abgefederteste": "abgefedert",
    "abgefedertestem": "abgefedert",
    "abgefedertesten": "abgefedert",
    "abgefedertester": "abgefedert",
    "abgefedertestes": "abgefedert",
    "abgefeiert": "abfeiern",
    "abgefeierte": "abgefeiert",
    "abgefeiertem": "abgefeiert",
    "abgefeierten": "abgefeiert",
    "abgefeierter": "abgefeiert",
    "abgefeiertere": "abgefeiert",
    "abgefeierterem": "abgefeiert",
    "abgefeierteren": "abgefeiert",
    "abgefeierterer": "abgefeiert",
    "abgefeierteres": "abgefeiert",
    "abgefeiertes": "abgefeiert",
    "abgefeierteste": "abgefeiert",
    "abgefeiertestem": "abgefeiert",
    "abgefeiertesten": "abgefeiert",
    "abgefeiertester": "abgefeiert",
    "abgefeiertestes": "abgefeiert",
    "abgefeilt": "abfeilen",
    "abgefeilte": "abgefeilt",
    "abgefeiltem": "abgefeilt",
    "abgefeilten": "abgefeilt",
    "abgefeilter": "abgefeilt",
    "abgefeiltere": "abgefeilt",
    "abgefeilterem": "abgefeilt",
    "abgefeilteren": "abgefeilt",
    "abgefeilterer": "abgefeilt",
    "abgefeilteres": "abgefeilt",
    "abgefeiltes": "abgefeilt",
    "abgefeilteste": "abgefeilt",
    "abgefeiltestem": "abgefeilt",
    "abgefeiltesten": "abgefeilt",
    "abgefeiltester": "abgefeilt",
    "abgefeiltestes": "abgefeilt",
    "abgefertigt": "abfertigen",
    "abgefertigte": "abgefertigt",
    "abgefertigtem": "abgefertigt",
    "abgefertigten": "abgefertigt",
    "abgefertigter": "abgefertigt",
    "abgefertigtes": "abgefertigt",
    "abgefeuert": "abfeuern",
    "abgefeuerte": "abgefeuert",
    "abgefeuertem": "abgefeuert",
    "abgefeuerten": "abgefeuert",
    "abgefeuerter": "abgefeuert",
    "abgefeuertes": "abgefeuert",
    "abgefiebert": "abfiebern",
    "abgefieberte": "abgefiebert",
    "abgefiebertem": "abgefiebert",
    "abgefieberten": "abgefiebert",
    "abgefieberter": "abgefiebert",
    "abgefiebertes": "abgefiebert",
    "abgefilmt": "abfilmen",
    "abgefilmte": "abgefilmt",
    "abgefilmtem": "abgefilmt",
    "abgefilmten": "abgefilmt",
    "abgefilmter": "abgefilmt",
    "abgefilmtes": "abgefilmt",
    "abgefischt": "abfischen",
    "abgefischte": "abgefischt",
    "abgefischtem": "abgefischt",
    "abgefischten": "abgefischt",
    "abgefischter": "abgefischt",
    "abgefischtere": "abgefischt",
    "abgefischterem": "abgefischt",
    "abgefischteren": "abgefischt",
    "abgefischterer": "abgefischt",
    "abgefischteres": "abgefischt",
    "abgefischtes": "abgefischt",
    "abgefischteste": "abgefischt",
    "abgefischtestem": "abgefischt",
    "abgefischtesten": "abgefischt",
    "abgefischtester": "abgefischt",
    "abgefischtestes": "abgefischt",
    "abgeflacht": "abflachen",
    "abgeflachte": "abgeflacht",
    "abgeflachtem": "abgeflacht",
    "abgeflachten": "abgeflacht",
    "abgeflachter": "abgeflacht",
    "abgeflachtere": "abgeflacht",
    "abgeflachterem": "abgeflacht",
    "abgeflachteren": "abgeflacht",
    "abgeflachterer": "abgeflacht",
    "abgeflachteres": "abgeflacht",
    "abgeflachtes": "abgeflacht",
    "abgeflachteste": "abgeflacht",
    "abgeflachtestem": "abgeflacht",
    "abgeflachtesten": "abgeflacht",
    "abgeflachtester": "abgeflacht",
    "abgeflachtestes": "abgeflacht",
    "abgeflaut": "abflauen",
    "abgeflaute": "abgeflaut",
    "abgeflautem": "abgeflaut",
    "abgeflauten": "abgeflaut",
    "abgeflauter": "abgeflaut",
    "abgeflautes": "abgeflaut",
    "abgeflogen": "abfliegen",
    "abgeflogene": "abgeflogen",
    "abgeflogenem": "abgeflogen",
    "abgeflogenen": "abgeflogen",
    "abgeflogener": "abgeflogen",
    "abgeflogenes": "abgeflogen",
    "abgeflossen": "abfließen",
    "abgeflossene": "abgeflossen",
    "abgeflossenem": "abgeflossen",
    "abgeflossenen": "abgeflossen",
    "abgeflossener": "abgeflossen",
    "abgeflossenere": "abgeflossen",
    "abgeflossenerem": "abgeflossen",
    "abgeflosseneren": "abgeflossen",
    "abgeflossenerer": "abgeflossen",
    "abgeflosseneres": "abgeflossen",
    "abgeflossenes": "abgeflossen",
    "abgeflossenste": "abgeflossen",
    "abgeflossenstem": "abgeflossen",
    "abgeflossensten": "abgeflossen",
    "abgeflossenster": "abgeflossen",
    "abgeflossenstes": "abgeflossen",
    "abgefluchtet": "abfluchten",
    "abgefluchtete": "abgefluchtet",
    "abgefluchtetem": "abgefluchtet",
    "abgefluchteten": "abgefluchtet",
    "abgefluchteter": "abgefluchtet",
    "abgefluchtetes": "abgefluchtet",
    "abgefordert": "abfordern",
    "abgeforderte": "abgefordert",
    "abgefordertem": "abgefordert",
    "abgeforderten": "abgefordert",
    "abgeforderter": "abgefordert",
    "abgefordertere": "abgefordert",
    "abgeforderterem": "abgefordert",
    "abgeforderteren": "abgefordert",
    "abgeforderterer": "abgefordert",
    "abgeforderteres": "abgefordert",
    "abgefordertes": "abgefordert",
    "abgeforderteste": "abgefordert",
    "abgefordertestem": "abgefordert",
    "abgefordertesten": "abgefordert",
    "abgefordertester": "abgefordert",
    "abgefordertestes": "abgefordert",
    "abgeformt": "abformen",
    "abgeformte": "abgeformt",
    "abgeformtem": "abgeformt",
    "abgeformten": "abgeformt",
    "abgeformter": "abgeformt",
    "abgeformtes": "abgeformt",
    "abgefragt": "abfragen",
    "abgefragte": "abgefragt",
    "abgefragtem": "abgefragt",
    "abgefragten": "abgefragt",
    "abgefragter": "abgefragt",
    "abgefragtes": "abgefragt",
    "abgefressen": "abfressen",
    "abgefressene": "abgefressen",
    "abgefressenem": "abgefressen",
    "abgefressenen": "abgefressen",
    "abgefressener": "abgefressen",
    "abgefressenere": "abgefressen",
    "abgefressenerem": "abgefressen",
    "abgefresseneren": "abgefressen",
    "abgefressenerer": "abgefressen",
    "abgefresseneres": "abgefressen",
    "abgefressenes": "abgefressen",
    "abgefressenste": "abgefressen",
    "abgefressenstem": "abgefressen",
    "abgefressensten": "abgefressen",
    "abgefressenster": "abgefressen",
    "abgefressenstes": "abgefressen",
    "abgefroren": "abfrieren",
    "abgefrorene": "abgefroren",
    "abgefrorenem": "abgefroren",
    "abgefrorenen": "abgefroren",
    "abgefrorener": "abgefroren",
    "abgefrorenere": "abgefroren",
    "abgefrorenerem": "abgefroren",
    "abgefroreneren": "abgefroren",
    "abgefrorenerer": "abgefroren",
    "abgefroreneres": "abgefroren",
    "abgefrorenes": "abgefroren",
    "abgefrorenste": "abgefroren",
    "abgefrorenstem": "abgefroren",
    "abgefrorensten": "abgefroren",
    "abgefrorenster": "abgefroren",
    "abgefrorenstes": "abgefroren",
    "abgefunden": "abfinden",
    "abgefundene": "abgefunden",
    "abgefundenem": "abgefunden",
    "abgefundenen": "abgefunden",
    "abgefundener": "abgefunden",
    "abgefundenes": "abgefunden",
    "abgefälscht": "abfälschen",
    "abgefälschte": "abgefälscht",
    "abgefälschtem": "abgefälscht",
    "abgefälschten": "abgefälscht",
    "abgefälschter": "abgefälscht",
    "abgefälschtes": "abgefälscht",
    "abgefärbt": "abfärben",
    "abgefärbte": "abgefärbt",
    "abgefärbtem": "abgefärbt",
    "abgefärbten": "abgefärbt",
    "abgefärbter": "abgefärbt",
    "abgefärbtere": "abgefärbt",
    "abgefärbterem": "abgefärbt",
    "abgefärbteren": "abgefärbt",
    "abgefärbterer": "abgefärbt",
    "abgefärbteres": "abgefärbt",
    "abgefärbtes": "abgefärbt",
    "abgefärbteste": "abgefärbt",
    "abgefärbtestem": "abgefärbt",
    "abgefärbtesten": "abgefärbt",
    "abgefärbtester": "abgefärbt",
    "abgefärbtestes": "abgefärbt",
    "abgeführt": "abführen",
    "abgeführte": "abgeführt",
    "abgeführtem": "abgeführt",
    "abgeführten": "abgeführt",
    "abgeführter": "abgeführt",
    "abgeführtes": "abgeführt",
    "abgefüllt": "abfüllen",
    "abgefüllte": "abgefüllt",
    "abgefülltem": "abgefüllt",
    "abgefüllten": "abgefüllt",
    "abgefüllter": "abgefüllt",
    "abgefülltere": "abgefüllt",
    "abgefüllterem": "abgefüllt",
    "abgefüllteren": "abgefüllt",
    "abgefüllterer": "abgefüllt",
    "abgefüllteres": "abgefüllt",
    "abgefülltes": "abgefüllt",
    "abgefüllteste": "abgefüllt",
    "abgefülltestem": "abgefüllt",
    "abgefülltesten": "abgefüllt",
    "abgefülltester": "abgefüllt",
    "abgefülltestes": "abgefüllt",
    "abgefüttert": "abfüttern",
    "abgefütterte": "abgefüttert",
    "abgefüttertem": "abgefüttert",
    "abgefütterten": "abgefüttert",
    "abgefütterter": "abgefüttert",
    "abgefüttertes": "abgefüttert",
    "abgegangen": "abgehen",
    "abgegangene": "abgegangen",
    "abgegangenem": "abgegangen",
    "abgegangenen": "abgegangen",
    "abgegangener": "abgegangen",
    "abgegangenes": "abgegangen",
    "abgegaunert": "abgaunern",
    "abgegaunerte": "abgegaunert",
    "abgegaunertem": "abgegaunert",
    "abgegaunerten": "abgegaunert",
    "abgegaunerter": "abgegaunert",
    "abgegaunertes": "abgegaunert",
    "abgegeben": "abgeben",
    "abgegebene": "abgegeben",
    "abgegebenem": "abgegeben",
    "abgegebenen": "abgegeben",
    "abgegebener": "abgegeben",
    "abgegebenes": "abgegeben",
    "abgegessen": "abessen",
    "abgegessene": "abgegessen",
    "abgegessenem": "abgegessen",
    "abgegessenen": "abgegessen",
    "abgegessener": "abgegessen",
    "abgegessenes": "abgegessen",
    "abgeglichen": "abgleichen",
    "abgeglichene": "abgeglichen",
    "abgeglichenem": "abgeglichen",
    "abgeglichenen": "abgeglichen",
    "abgeglichener": "abgeglichen",
    "abgeglichenere": "abgeglichen",
    "abgeglichenerem": "abgeglichen",
    "abgeglicheneren": "abgeglichen",
    "abgeglichenerer": "abgeglichen",
    "abgeglicheneres": "abgeglichen",
    "abgeglichenes": "abgeglichen",
    "abgeglichenste": "abgeglichen",
    "abgeglichenstem": "abgeglichen",
    "abgeglichensten": "abgeglichen",
    "abgeglichenster": "abgeglichen",
    "abgeglichenstes": "abgeglichen",
    "abgeglitten": "abgleiten",
    "abgeglittene": "abgeglitten",
    "abgeglittenem": "abgeglitten",
    "abgeglittenen": "abgeglitten",
    "abgeglittener": "abgeglitten",
    "abgeglittenere": "abgeglitten",
    "abgeglittenerem": "abgeglitten",
    "abgeglitteneren": "abgeglitten",
    "abgeglittenerer": "abgeglitten",
    "abgeglitteneres": "abgeglitten",
    "abgeglittenes": "abgeglitten",
    "abgeglittenste": "abgeglitten",
    "abgeglittenstem": "abgeglitten",
    "abgeglittensten": "abgeglitten",
    "abgeglittenster": "abgeglitten",
    "abgeglittenstes": "abgeglitten",
    "abgegolten": "abgelten",
    "abgegoltene": "abgegolten",
    "abgegoltenem": "abgegolten",
    "abgegoltenen": "abgegolten",
    "abgegoltener": "abgegolten",
    "abgegoltenes": "abgegolten",
    "abgegossen": "abgießen",
    "abgegossene": "abgegossen",
    "abgegossenem": "abgegossen",
    "abgegossenen": "abgegossen",
    "abgegossener": "abgegossen",
    "abgegossenes": "abgegossen",
    "abgegraben": "abgraben",
    "abgegrabene": "abgegraben",
    "abgegrabenem": "abgegraben",
    "abgegrabenen": "abgegraben",
    "abgegrabener": "abgegraben",
    "abgegrabenes": "abgegraben",
    "abgegrast": "abgrasen",
    "abgegraste": "abgegrast",
    "abgegrastem": "abgegrast",
    "abgegrasten": "abgegrast",
    "abgegraster": "abgegrast",
    "abgegrastere": "abgegrast",
    "abgegrasterem": "abgegrast",
    "abgegrasteren": "abgegrast",
    "abgegrasterer": "abgegrast",
    "abgegrasteres": "abgegrast",
    "abgegrastes": "abgegrast",
    "abgegrasteste": "abgegrast",
    "abgegrastestem": "abgegrast",
    "abgegrastesten": "abgegrast",
    "abgegrastester": "abgegrast",
    "abgegrastestes": "abgegrast",
    "abgegrenzt": "abgrenzen",
    "abgegrenzte": "abgegrenzt",
    "abgegrenztem": "abgegrenzt",
    "abgegrenzten": "abgegrenzt",
    "abgegrenzter": "abgegrenzt",
    "abgegrenztere": "abgegrenzt",
    "abgegrenzterem": "abgegrenzt",
    "abgegrenzteren": "abgegrenzt",
    "abgegrenzterer": "abgegrenzt",
    "abgegrenzteres": "abgegrenzt",
    "abgegrenztes": "abgegrenzt",
    "abgegrenzteste": "abgegrenzt",
    "abgegrenztestem": "abgegrenzt",
    "abgegrenztesten": "abgegrenzt",
    "abgegrenztester": "abgegrenzt",
    "abgegrenztestes": "abgegrenzt",
    "abgegriffen": "abgreifen",
    "abgegriffene": "abgegriffen",
    "abgegriffenem": "abgegriffen",
    "abgegriffenen": "abgegriffen",
    "abgegriffener": "abgegriffen",
    "abgegriffenere": "abgegriffen",
    "abgegriffenerem": "abgegriffen",
    "abgegriffeneren": "abgegriffen",
    "abgegriffenerer": "abgegriffen",
    "abgegriffeneres": "abgegriffen",
    "abgegriffenes": "abgegriffen",
    "abgegriffenste": "abgegriffen",
    "abgegriffenstem": "abgegriffen",
    "abgegriffensten": "abgegriffen",
    "abgegriffenster": "abgegriffen",
    "abgegriffenstes": "abgegriffen",
    "abgegrätscht": "abgrätschen",
    "abgegrätschte": "abgegrätscht",
    "abgegrätschtem": "abgegrätscht",
    "abgegrätschten": "abgegrätscht",
    "abgegrätschter": "abgegrätscht",
    "abgegrätschtere": "abgegrätscht",
    "abgegrätschterem": "abgegrätscht",
    "abgegrätschteren": "abgegrätscht",
    "abgegrätschterer": "abgegrätscht",
    "abgegrätschteres": "abgegrätscht",
    "abgegrätschtes": "abgegrätscht",
    "abgegrätschteste": "abgegrätscht",
    "abgegrätschtestem": "abgegrätscht",
    "abgegrätschtesten": "abgegrätscht",
    "abgegrätschtester": "abgegrätscht",
    "abgegrätschtestes": "abgegrätscht",
    "abgehackt": "abhacken",
    "abgehackte": "abgehackt",
    "abgehacktem": "abgehackt",
    "abgehackten": "abgehackt",
    "abgehackter": "abgehackt",
    "abgehacktere": "abgehackt",
    "abgehackterem": "abgehackt",
    "abgehackteren": "abgehackt",
    "abgehackterer": "abgehackt",
    "abgehackteres": "abgehackt",
    "abgehacktes": "abgehackt",
    "abgehackteste": "abgehackt",
    "abgehacktestem": "abgehackt",
    "abgehacktesten": "abgehackt",
    "abgehacktester": "abgehackt",
    "abgehacktestes": "abgehackt",
    "abgehakt": "abhaken",
    "abgehakte": "abgehakt",
    "abgehaktem": "abgehakt",
    "abgehakten": "abgehakt",
    "abgehakter": "abgehakt",
    "abgehaktes": "abgehakt",
    "abgehalftert": "abhalftern",
    "abgehalfterte": "abgehalftert",
    "abgehalftertem": "abgehalftert",
    "abgehalfterten": "abgehalftert",
    "abgehalfterter": "abgehalftert",
    "abgehalftertes": "abgehalftert",
    "abgehalten": "abhalten",
    "abgehaltene": "abgehalten",
    "abgehaltenem": "abgehalten",
    "abgehaltenen": "abgehalten",
    "abgehaltener": "abgehalten",
    "abgehaltenes": "abgehalten",
    "abgehandelt": "abhandeln",
    "abgehandelte": "abgehandelt",
    "abgehandeltem": "abgehandelt",
    "abgehandelten": "abgehandelt",
    "abgehandelter": "abgehandelt",
    "abgehandeltes": "abgehandelt",
    "abgehangen": "abhängen",
    "abgehaspelt": "abhaspeln",
    "abgehaspelte": "abgehaspelt",
    "abgehaspeltem": "abgehaspelt",
    "abgehaspelten": "abgehaspelt",
    "abgehaspelter": "abgehaspelt",
    "abgehaspeltere": "abgehaspelt",
    "abgehaspelterem": "abgehaspelt",
    "abgehaspelteren": "abgehaspelt",
    "abgehaspelterer": "abgehaspelt",
    "abgehaspelteres": "abgehaspelt",
    "abgehaspeltes": "abgehaspelt",
    "abgehaspelteste": "abgehaspelt",
    "abgehaspeltestem": "abgehaspelt",
    "abgehaspeltesten": "abgehaspelt",
    "abgehaspeltester": "abgehaspelt",
    "abgehaspeltestes": "abgehaspelt",
    "abgehauen": "abhauen",
    "abgehauene": "abgehauen",
    "abgehauenem": "abgehauen",
    "abgehauenen": "abgehauen",
    "abgehauener": "abgehauen",
    "abgehauenes": "abgehauen",
    "abgehe": "abgehen",
    "abgeheftet": "abheften",
    "abgeheftete": "abgeheftet",
    "abgeheftetem": "abgeheftet",
    "abgehefteten": "abgeheftet",
    "abgehefteter": "abgeheftet",
    "abgeheftetes": "abgeheftet",
    "abgeheilt": "abheilen",
    "abgeheilte": "abgeheilt",
    "abgeheiltem": "abgeheilt",
    "abgeheilten": "abgeheilt",
    "abgeheilter": "abgeheilt",
    "abgeheiltere": "abgeheilt",
    "abgeheilterem": "abgeheilt",
    "abgeheilteren": "abgeheilt",
    "abgeheilterer": "abgeheilt",
    "abgeheilteres": "abgeheilt",
    "abgeheiltes": "abgeheilt",
    "abgeheilteste": "abgeheilt",
    "abgeheiltestem": "abgeheilt",
    "abgeheiltesten": "abgeheilt",
    "abgeheiltester": "abgeheilt",
    "abgeheiltestes": "abgeheilt",
    "abgehend": "abgehen",
    "abgehende": "abgehend",
    "abgehendem": "abgehend",
    "abgehenden": "abgehend",
    "abgehender": "abgehend",
    "abgehendes": "abgehend",
    "abgehest": "abgehen",
    "abgehet": "abgehen",
    "abgehetzt": "abhetzen",
    "abgehetzte": "abgehetzt",
    "abgehetztem": "abgehetzt",
    "abgehetzten": "abgehetzt",
    "abgehetzter": "abgehetzt",
    "abgehetztere": "abgehetzt",
    "abgehetzterem": "abgehetzt",
    "abgehetzteren": "abgehetzt",
    "abgehetzterer": "abgehetzt",
    "abgehetzteres": "abgehetzt",
    "abgehetztes": "abgehetzt",
    "abgehetzteste": "abgehetzt",
    "abgehetztestem": "abgehetzt",
    "abgehetztesten": "abgehetzt",
    "abgehetztester": "abgehetzt",
    "abgehetztestes": "abgehetzt",
    "abgehobelt": "abhobeln",
    "abgehobelte": "abgehobelt",
    "abgehobeltem": "abgehobelt",
    "abgehobelten": "abgehobelt",
    "abgehobelter": "abgehobelt",
    "abgehobeltere": "abgehobelt",
    "abgehobelterem": "abgehobelt",
    "abgehobelteren": "abgehobelt",
    "abgehobelterer": "abgehobelt",
    "abgehobelteres": "abgehobelt",
    "abgehobeltes": "abgehobelt",
    "abgehobelteste": "abgehobelt",
    "abgehobeltestem": "abgehobelt",
    "abgehobeltesten": "abgehobelt",
    "abgehobeltester": "abgehobelt",
    "abgehobeltestes": "abgehobelt",
    "abgehoben": "abheben",
    "abgehobene": "abgehoben",
    "abgehobenem": "abgehoben",
    "abgehobenen": "abgehoben",
    "abgehobener": "abgehoben",
    "abgehobenes": "abgehoben",
    "abgeholfen": "abhelfen",
    "abgeholfene": "abgeholfen",
    "abgeholfenem": "abgeholfen",
    "abgeholfenen": "abgeholfen",
    "abgeholfener": "abgeholfen",
    "abgeholfenes": "abgeholfen",
    "abgeholt": "abholen",
    "abgeholte": "abgeholt",
    "abgeholtem": "abgeholt",
    "abgeholten": "abgeholt",
    "abgeholter": "abgeholt",
    "abgeholtes": "abgeholt",
    "abgeholzt": "abholzen",
    "abgeholzte": "abgeholzt",
    "abgeholztem": "abgeholzt",
    "abgeholzten": "abgeholzt",
    "abgeholzter": "abgeholzt",
    "abgeholztere": "abgeholzt",
    "abgeholzterem": "abgeholzt",
    "abgeholzteren": "abgeholzt",
    "abgeholzterer": "abgeholzt",
    "abgeholzteres": "abgeholzt",
    "abgeholztes": "abgeholzt",
    "abgeholzteste": "abgeholzt",
    "abgeholztestem": "abgeholzt",
    "abgeholztesten": "abgeholzt",
    "abgeholztester": "abgeholzt",
    "abgeholztestes": "abgeholzt",
    "abgehorcht": "abhorchen",
    "abgehorchte": "abgehorcht",
    "abgehorchtem": "abgehorcht",
    "abgehorchten": "abgehorcht",
    "abgehorchter": "abgehorcht",
    "abgehorchtere": "abgehorcht",
    "abgehorchterem": "abgehorcht",
    "abgehorchteren": "abgehorcht",
    "abgehorchterer": "abgehorcht",
    "abgehorchteres": "abgehorcht",
    "abgehorchtes": "abgehorcht",
    "abgehorchteste": "abgehorcht",
    "abgehorchtestem": "abgehorcht",
    "abgehorchtesten": "abgehorcht",
    "abgehorchtester": "abgehorcht",
    "abgehorchtestes": "abgehorcht",
    "abgehst": "abgehen",
    "abgeht": "abgehen",
    "abgehängt": "abhängen",
    "abgehängte": "abgehängt",
    "abgehängtem": "abgehängt",
    "abgehängten": "abgehängt",
    "abgehängter": "abgehängt",
    "abgehängtes": "abgehängt",
    "abgehärtet": "abhärten",
    "abgehärtete": "abgehärtet",
    "abgehärtetem": "abgehärtet",
    "abgehärteten": "abgehärtet",
    "abgehärteter": "abgehärtet",
    "abgehärtetere": "abgehärtet",
    "abgehärteterem": "abgehärtet",
    "abgehärteteren": "abgehärtet",
    "abgehärteterer": "abgehärtet",
    "abgehärteteres": "abgehärtet",
    "abgehärtetes": "abgehärtet",
    "abgehärteteste": "abgehärtet",
    "abgehärtetestem": "abgehärtet",
    "abgehärtetesten": "abgehärtet",
    "abgehärtetester": "abgehärtet",
    "abgehärtetestes": "abgehärtet",
    "abgehäutet": "abhäuten",
    "abgehäutete": "abgehäutet",
    "abgehäutetem": "abgehäutet",
    "abgehäuteten": "abgehäutet",
    "abgehäuteter": "abgehäutet",
    "abgehäutetes": "abgehäutet",
    "abgehört": "abhören",
    "abgehörte": "abgehört",
    "abgehörtem": "abgehört",
    "abgehörten": "abgehört",
    "abgehörter": "abgehört",
    "abgehörtes": "abgehört",
    "abgejagt": "abjagen",
    "abgejagte": "abgejagt",
    "abgejagtem": "abgejagt",
    "abgejagten": "abgejagt",
    "abgejagter": "abgejagt",
    "abgejagtes": "abgejagt",
    "abgekantet": "abkanten",
    "abgekantete": "abgekantet",
    "abgekantetem": "abgekantet",
    "abgekanteten": "abgekantet",
    "abgekanteter": "abgekantet",
    "abgekantetere": "abgekantet",
    "abgekanteterem": "abgekantet",
    "abgekanteteren": "abgekantet",
    "abgekanteterer": "abgekantet",
    "abgekanteteres": "abgekantet",
    "abgekantetes": "abgekantet",
    "abgekanteteste": "abgekantet",
    "abgekantetestem": "abgekantet",
    "abgekantetesten": "abgekantet",
    "abgekantetester": "abgekantet",
    "abgekantetestes": "abgekantet",
    "abgekanzelt": "abkanzeln",
    "abgekanzelte": "abgekanzelt",
    "abgekanzeltem": "abgekanzelt",
    "abgekanzelten": "abgekanzelt",
    "abgekanzelter": "abgekanzelt",
    "abgekanzeltere": "abgekanzelt",
    "abgekanzelterem": "abgekanzelt",
    "abgekanzelteren": "abgekanzelt",
    "abgekanzelterer": "abgekanzelt",
    "abgekanzelteres": "abgekanzelt",
    "abgekanzeltes": "abgekanzelt",
    "abgekanzelteste": "abgekanzelt",
    "abgekanzeltestem": "abgekanzelt",
    "abgekanzeltesten": "abgekanzelt",
    "abgekanzeltester": "abgekanzelt",
    "abgekanzeltestes": "abgekanzelt",
    "abgekappt": "abkappen",
    "abgekappte": "abgekappt",
    "abgekapptem": "abgekappt",
    "abgekappten": "abgekappt",
    "abgekappter": "abgekappt",
    "abgekapptes": "abgekappt",
    "abgekapselt": "abkapseln",
    "abgekapselte": "abgekapselt",
    "abgekapseltem": "abgekapselt",
    "abgekapselten": "abgekapselt",
    "abgekapselter": "abgekapselt",
    "abgekapseltere": "abgekapselt",
    "abgekapselterem": "abgekapselt",
    "abgekapselteren": "abgekapselt",
    "abgekapselterer": "abgekapselt",
    "abgekapselteres": "abgekapselt",
    "abgekapseltes": "abgekapselt",
    "abgekapselteste": "abgekapselt",
    "abgekapseltestem": "abgekapselt",
    "abgekapseltesten": "abgekapselt",
    "abgekapseltester": "abgekapselt",
    "abgekapseltestes": "abgekapselt",
    "abgekartet": "abkarten",
    "abgekartete": "abgekartet",
    "abgekartetem": "abgekartet",
    "abgekarteten": "abgekartet",
    "abgekarteter": "abgekartet",
    "abgekartetere": "abgekartet",
    "abgekarteterem": "abgekartet",
    "abgekarteteren": "abgekartet",
    "abgekarteterer": "abgekartet",
    "abgekarteteres": "abgekartet",
    "abgekartetes": "abgekartet",
    "abgekarteteste": "abgekartet",
    "abgekartetestem": "abgekartet",
    "abgekartetesten": "abgekartet",
    "abgekartetester": "abgekartet",
    "abgekartetestes": "abgekartet",
    "abgekauft": "abkaufen",
    "abgekaufte": "abgekauft",
    "abgekauftem": "abgekauft",
    "abgekauften": "abgekauft",
    "abgekaufter": "abgekauft",
    "abgekauftes": "abgekauft",
    "abgekehrt": "abkehren",
    "abgekehrte": "abgekehrt",
    "abgekehrtem": "abgekehrt",
    "abgekehrten": "abgekehrt",
    "abgekehrter": "abgekehrt",
    "abgekehrtes": "abgekehrt",
    "abgeklappert": "abklappern",
    "abgeklapperte": "abgeklappert",
    "abgeklappertem": "abgeklappert",
    "abgeklapperten": "abgeklappert",
    "abgeklapperter": "abgeklappert",
    "abgeklappertes": "abgeklappert",
    "abgeklatscht": "abklatschen",
    "abgeklatschte": "abgeklatscht",
    "abgeklatschtem": "abgeklatscht",
    "abgeklatschten": "abgeklatscht",
    "abgeklatschter": "abgeklatscht",
    "abgeklatschtes": "abgeklatscht",
    "abgeklaubt": "abklauben",
    "abgeklaubte": "abgeklaubt",
    "abgeklaubtem": "abgeklaubt",
    "abgeklaubten": "abgeklaubt",
    "abgeklaubter": "abgeklaubt",
    "abgeklaubtere": "abgeklaubt",
    "abgeklaubterem": "abgeklaubt",
    "abgeklaubteren": "abgeklaubt",
    "abgeklaubterer": "abgeklaubt",
    "abgeklaubteres": "abgeklaubt",
    "abgeklaubtes": "abgeklaubt",
    "abgeklaubteste": "abgeklaubt",
    "abgeklaubtestem": "abgeklaubt",
    "abgeklaubtesten": "abgeklaubt",
    "abgeklaubtester": "abgeklaubt",
    "abgeklaubtestes": "abgeklaubt",
    "abgeklebt": "abkleben",
    "abgeklebte": "abgeklebt",
    "abgeklebtem": "abgeklebt",
    "abgeklebten": "abgeklebt",
    "abgeklebter": "abgeklebt",
    "abgeklebtes": "abgeklebt",
    "abgeklemmt": "abklemmen",
    "abgeklemmte": "abgeklemmt",
    "abgeklemmtem": "abgeklemmt",
    "abgeklemmten": "abgeklemmt",
    "abgeklemmter": "abgeklemmt",
    "abgeklemmtes": "abgeklemmt",
    "abgeklopft": "abklopfen",
    "abgeklopfte": "abgeklopft",
    "abgeklopftem": "abgeklopft",
    "abgeklopften": "abgeklopft",
    "abgeklopfter": "abgeklopft",
    "abgeklopftes": "abgeklopft",
    "abgeklungen": "abklingen",
    "abgeklungene": "abgeklungen",
    "abgeklungenem": "abgeklungen",
    "abgeklungenen": "abgeklungen",
    "abgeklungener": "abgeklungen",
    "abgeklungenes": "abgeklungen",
    "abgeklärt": "abklären",
    "abgeklärte": "abgeklärt",
    "abgeklärtem": "abgeklärt",
    "abgeklärten": "abgeklärt",
    "abgeklärter": "abgeklärt",
    "abgeklärtere": "abgeklärt",
    "abgeklärterem": "abgeklärt",
    "abgeklärteren": "abgeklärt",
    "abgeklärterer": "abgeklärt",
    "abgeklärteres": "abgeklärt",
    "abgeklärtes": "abgeklärt",
    "abgeklärteste": "abgeklärt",
    "abgeklärtestem": "abgeklärt",
    "abgeklärtesten": "abgeklärt",
    "abgeklärtester": "abgeklärt",
    "abgeklärtestes": "abgeklärt",
    "abgeknabbert": "abknabbern",
    "abgeknabberte": "abgeknabbert",
    "abgeknabbertem": "abgeknabbert",
    "abgeknabberten": "abgeknabbert",
    "abgeknabberter": "abgeknabbert",
    "abgeknabbertere": "abgeknabbert",
    "abgeknabberterem": "abgeknabbert",
    "abgeknabberteren": "abgeknabbert",
    "abgeknabberterer": "abgeknabbert",
    "abgeknabberteres": "abgeknabbert",
    "abgeknabbertes": "abgeknabbert",
    "abgeknabberteste": "abgeknabbert",
    "abgeknabbertestem": "abgeknabbert",
    "abgeknabbertesten": "abgeknabbert",
    "abgeknabbertester": "abgeknabbert",
    "abgeknabbertestes": "abgeknabbert",
    "abgeknallt": "abknallen",
    "abgeknallte": "abgeknallt",
    "abgeknalltem": "abgeknallt",
    "abgeknallten": "abgeknallt",
    "abgeknallter": "abgeknallt",
    "abgeknalltes": "abgeknallt",
    "abgeknapst": "abknapsen",
    "abgeknapste": "abgeknapst",
    "abgeknapstem": "abgeknapst",
    "abgeknapsten": "abgeknapst",
    "abgeknapster": "abgeknapst",
    "abgeknapstere": "abgeknapst",
    "abgeknapsterem": "abgeknapst",
    "abgeknapsteren": "abgeknapst",
    "abgeknapsterer": "abgeknapst",
    "abgeknapsteres": "abgeknapst",
    "abgeknapstes": "abgeknapst",
    "abgeknapsteste": "abgeknapst",
    "abgeknapstestem": "abgeknapst",
    "abgeknapstesten": "abgeknapst",
    "abgeknapstester": "abgeknapst",
    "abgeknapstestes": "abgeknapst",
    "abgeknickt": "abknicken",
    "abgeknickte": "abgeknickt",
    "abgeknicktem": "abgeknickt",
    "abgeknickten": "abgeknickt",
    "abgeknickter": "abgeknickt",
    "abgeknicktes": "abgeknickt",
    "abgekniffen": "abkneifen",
    "abgekniffene": "abgekniffen",
    "abgekniffenem": "abgekniffen",
    "abgekniffenen": "abgekniffen",
    "abgekniffener": "abgekniffen",
    "abgekniffenere": "abgekniffen",
    "abgekniffenerem": "abgekniffen",
    "abgekniffeneren": "abgekniffen",
    "abgekniffenerer": "abgekniffen",
    "abgekniffeneres": "abgekniffen",
    "abgekniffenes": "abgekniffen",
    "abgekniffenste": "abgekniffen",
    "abgekniffenstem": "abgekniffen",
    "abgekniffensten": "abgekniffen",
    "abgekniffenster": "abgekniffen",
    "abgekniffenstes": "abgekniffen",
    "abgeknipst": "abknipsen",
    "abgeknipste": "abgeknipst",
    "abgeknipstem": "abgeknipst",
    "abgeknipsten": "abgeknipst",
    "abgeknipster": "abgeknipst",
    "abgeknipstes": "abgeknipst",
    "abgeknutscht": "abknutschen",
    "abgeknutschte": "abgeknutscht",
    "abgeknutschtem": "abgeknutscht",
    "abgeknutschten": "abgeknutscht",
    "abgeknutschter": "abgeknutscht",
    "abgeknutschtere": "abgeknutscht",
    "abgeknutschterem": "abgeknutscht",
    "abgeknutschteren": "abgeknutscht",
    "abgeknutschterer": "abgeknutscht",
    "abgeknutschteres": "abgeknutscht",
    "abgeknutschtes": "abgeknutscht",
    "abgeknutschteste": "abgeknutscht",
    "abgeknutschtestem": "abgeknutscht",
    "abgeknutschtesten": "abgeknutscht",
    "abgeknutschtester": "abgeknutscht",
    "abgeknutschtestes": "abgeknutscht",
    "abgeknöpft": "abknöpfen",
    "abgeknöpfte": "abgeknöpft",
    "abgeknöpftem": "abgeknöpft",
    "abgeknöpften": "abgeknöpft",
    "abgeknöpfter": "abgeknöpft",
    "abgeknöpftes": "abgeknöpft",
    "abgekocht": "abkochen",
    "abgekochte": "abgekocht",
    "abgekochtem": "abgekocht",
    "abgekochten": "abgekocht",
    "abgekochter": "abgekocht",
    "abgekochtere": "abgekocht",
    "abgekochterem": "abgekocht",
    "abgekochteren": "abgekocht",
    "abgekochterer": "abgekocht",
    "abgekochteres": "abgekocht",
    "abgekochtes": "abgekocht",
    "abgekochteste": "abgekocht",
    "abgekochtestem": "abgekocht",
    "abgekochtesten": "abgekocht",
    "abgekochtester": "abgekocht",
    "abgekochtestes": "abgekocht",
    "abgekommen": "abkommen",
    "abgekommene": "abgekommen",
    "abgekommenem": "abgekommen",
    "abgekommenen": "abgekommen",
    "abgekommener": "abgekommen",
    "abgekommenes": "abgekommen",
    "abgekoppelt": "abkoppeln",
    "abgekoppelte": "abgekoppelt",
    "abgekoppeltem": "abgekoppelt",
    "abgekoppelten": "abgekoppelt",
    "abgekoppelter": "abgekoppelt",
    "abgekoppeltes": "abgekoppelt",
    "abgekotzt": "abkotzen",
    "abgekotzte": "abgekotzt",
    "abgekotztem": "abgekotzt",
    "abgekotzten": "abgekotzt",
    "abgekotzter": "abgekotzt",
    "abgekotztes": "abgekotzt",
    "abgekratzt": "abkratzen",
    "abgekratzte": "abgekratzt",
    "abgekratztem": "abgekratzt",
    "abgekratzten": "abgekratzt",
    "abgekratzter": "abgekratzt",
    "abgekratztes": "abgekratzt",
    "abgekriegt": "abkriegen",
    "abgekriegte": "abgekriegt",
    "abgekriegtem": "abgekriegt",
    "abgekriegten": "abgekriegt",
    "abgekriegter": "abgekriegt",
    "abgekriegtes": "abgekriegt",
    "abgekuppelt": "abkuppeln",
    "abgekuppelte": "abgekuppelt",
    "abgekuppeltem": "abgekuppelt",
    "abgekuppelten": "abgekuppelt",
    "abgekuppelter": "abgekuppelt",
    "abgekuppeltes": "abgekuppelt",
    "abgekämmt": "abkämmen",
    "abgekämmte": "abgekämmt",
    "abgekämmtem": "abgekämmt",
    "abgekämmten": "abgekämmt",
    "abgekämmter": "abgekämmt",
    "abgekämmtes": "abgekämmt",
    "abgekämpft": "abkämpfen",
    "abgekämpfte": "abgekämpft",
    "abgekämpftem": "abgekämpft",
    "abgekämpften": "abgekämpft",
    "abgekämpfter": "abgekämpft",
    "abgekämpftere": "abgekämpft",
    "abgekämpfterem": "abgekämpft",
    "abgekämpfteren": "abgekämpft",
    "abgekämpfterer": "abgekämpft",
    "abgekämpfteres": "abgekämpft",
    "abgekämpftes": "abgekämpft",
    "abgekämpfteste": "abgekämpft",
    "abgekämpftestem": "abgekämpft",
    "abgekämpftesten": "abgekämpft",
    "abgekämpftester": "abgekämpft",
    "abgekämpftestes": "abgekämpft",
    "abgekühlt": "abkühlen",
    "abgekühlte": "abgekühlt",
    "abgekühltem": "abgekühlt",
    "abgekühlten": "abgekühlt",
    "abgekühlter": "abgekühlt",
    "abgekühltere": "abgekühlt",
    "abgekühlterem": "abgekühlt",
    "abgekühlteren": "abgekühlt",
    "abgekühlterer": "abgekühlt",
    "abgekühlteres": "abgekühlt",
    "abgekühltes": "abgekühlt",
    "abgekühlteste": "abgekühlt",
    "abgekühltestem": "abgekühlt",
    "abgekühltesten": "abgekühlt",
    "abgekühltester": "abgekühlt",
    "abgekühltestes": "abgekühlt",
    "abgekürzt": "abkürzen",
    "abgekürzte": "abgekürzt",
    "abgekürztem": "abgekürzt",
    "abgekürzten": "abgekürzt",
    "abgekürzter": "abgekürzt",
    "abgekürztes": "abgekürzt",
    "abgeküßt": "abküssen",
    "abgeküßte": "abgeküßt",
    "abgeküßtem": "abgeküßt",
    "abgeküßten": "abgeküßt",
    "abgeküßter": "abgeküßt",
    "abgeküßtes": "abgeküßt",
    "abgelacht": "ablachen",
    "abgelachte": "abgelacht",
    "abgelachtem": "abgelacht",
    "abgelachten": "abgelacht",
    "abgelachter": "abgelacht",
    "abgelachtes": "abgelacht",
    "abgeladen": "abladen",
    "abgeladene": "abgeladen",
    "abgeladenem": "abgeladen",
    "abgeladenen": "abgeladen",
    "abgeladener": "abgeladen",
    "abgeladenes": "abgeladen",
    "abgelagert": "ablagern",
    "abgelagerte": "abgelagert",
    "abgelagertem": "abgelagert",
    "abgelagerten": "abgelagert",
    "abgelagerter": "abgelagert",
    "abgelagertes": "abgelagert",
    "abgelassen": "ablassen",
    "abgelassene": "abgelassen",
    "abgelassenem": "abgelassen",
    "abgelassenen": "abgelassen",
    "abgelassener": "abgelassen",
    "abgelassenes": "abgelassen",
    "abgelatscht": "ablatschen",
    "abgelatschte": "abgelatscht",
    "abgelatschtem": "abgelatscht",
    "abgelatschten": "abgelatscht",
    "abgelatschter": "abgelatscht",
    "abgelatschtere": "abgelatscht",
    "abgelatschterem": "abgelatscht",
    "abgelatschteren": "abgelatscht",
    "abgelatschterer": "abgelatscht",
    "abgelatschteres": "abgelatscht",
    "abgelatschtes": "abgelatscht",
    "abgelatschteste": "abgelatscht",
    "abgelatschtestem": "abgelatscht",
    "abgelatschtesten": "abgelatscht",
    "abgelatschtester": "abgelatscht",
    "abgelatschtestes": "abgelatscht",
    "abgelaufen": "ablaufen",
    "abgelaufene": "abgelaufen",
    "abgelaufenem": "abgelaufen",
    "abgelaufenen": "abgelaufen",
    "abgelaufener": "abgelaufen",
    "abgelaufenes": "abgelaufen",
    "abgelautet": "ablauten",
    "abgelautete": "abgelautet",
    "abgelautetem": "abgelautet",
    "abgelauteten": "abgelautet",
    "abgelauteter": "abgelautet",
    "abgelautetes": "abgelautet",
    "abgelebt": "ableben",
    "abgelebte": "abgelebt",
    "abgelebtem": "abgelebt",
    "abgelebten": "abgelebt",
    "abgelebter": "abgelebt",
    "abgelebtes": "abgelebt",
    "abgeledert": "abledern",
    "abgelederte": "abgeledert",
    "abgeledertem": "abgeledert",
    "abgelederten": "abgeledert",
    "abgelederter": "abgeledert",
    "abgeledertere": "abgeledert",
    "abgelederterem": "abgeledert",
    "abgelederteren": "abgeledert",
    "abgelederterer": "abgeledert",
    "abgelederteres": "abgeledert",
    "abgeledertes": "abgeledert",
    "abgelederteste": "abgeledert",
    "abgeledertestem": "abgeledert",
    "abgeledertesten": "abgeledert",
    "abgeledertester": "abgeledert",
    "abgeledertestes": "abgeledert",
    "abgelegene": "abgelegen",
    "abgelegenem": "abgelegen",
    "abgelegenen": "abgelegen",
    "abgelegener": "abgelegen",
    "abgelegenere": "abgelegen",
    "abgelegenerem": "abgelegen",
    "abgelegeneren": "abgelegen",
    "abgelegenerer": "abgelegen",
    "abgelegeneres": "abgelegen",
    "abgelegenes": "abgelegen",
    "abgelegenste": "abgelegen",
    "abgelegenstem": "abgelegen",
    "abgelegensten": "abgelegen",
    "abgelegenster": "abgelegen",
    "abgelegenstes": "abgelegen",
    "abgelegt": "ablegen",
    "abgelegte": "abgelegt",
    "abgelegtem": "abgelegt",
    "abgelegten": "abgelegt",
    "abgelegter": "abgelegt",
    "abgelegtes": "abgelegt",
    "abgelehnt": "ablehnen",
    "abgelehnte": "abgelehnt",
    "abgelehntem": "abgelehnt",
    "abgelehnten": "abgelehnt",
    "abgelehnter": "abgelehnt",
    "abgelehntes": "abgelehnt",
    "abgeleistet": "ableisten",
    "abgeleistete": "abgeleistet",
    "abgeleistetem": "abgeleistet",
    "abgeleisteten": "abgeleistet",
    "abgeleisteter": "abgeleistet",
    "abgeleistetes": "abgeleistet",
    "abgeleitet": "ableiten",
    "abgeleitete": "abgeleitet",
    "abgeleitetem": "abgeleitet",
    "abgeleiteten": "abgeleitet",
    "abgeleiteter": "abgeleitet",
    "abgeleitetes": "abgeleitet",
    "abgelenkt": "ablenken",
    "abgelenkte": "abgelenkt",
    "abgelenktem": "abgelenkt",
    "abgelenkten": "abgelenkt",
    "abgelenkter": "abgelenkt",
    "abgelenktere": "abgelenkt",
    "abgelenkterem": "abgelenkt",
    "abgelenkteren": "abgelenkt",
    "abgelenkterer": "abgelenkt",
    "abgelenkteres": "abgelenkt",
    "abgelenktes": "abgelenkt",
    "abgelenkteste": "abgelenkt",
    "abgelenktestem": "abgelenkt",
    "abgelenktesten": "abgelenkt",
    "abgelenktester": "abgelenkt",
    "abgelenktestes": "abgelenkt",
    "abgelesen": "ablesen",
    "abgelesene": "abgelesen",
    "abgelesenem": "abgelesen",
    "abgelesenen": "abgelesen",
    "abgelesener": "abgelesen",
    "abgelesenes": "abgelesen",
    "abgeleuchtet": "ableuchten",
    "abgeleuchtete": "abgeleuchtet",
    "abgeleuchtetem": "abgeleuchtet",
    "abgeleuchteten": "abgeleuchtet",
    "abgeleuchteter": "abgeleuchtet",
    "abgeleuchtetes": "abgeleuchtet",
    "abgelichtet": "ablichten",
    "abgelichtete": "abgelichtet",
    "abgelichtetem": "abgelichtet",
    "abgelichteten": "abgelichtet",
    "abgelichteter": "abgelichtet",
    "abgelichtetes": "abgelichtet",
    "abgeliefert": "abliefern",
    "abgelieferte": "abgeliefert",
    "abgeliefertem": "abgeliefert",
    "abgelieferten": "abgeliefert",
    "abgelieferter": "abgeliefert",
    "abgeliefertes": "abgeliefert",
    "abgeloschen": "ablöschen",
    "abgeloschene": "abgeloschen",
    "abgeloschenem": "abgeloschen",
    "abgeloschenen": "abgeloschen",
    "abgeloschener": "abgeloschen",
    "abgeloschenes": "abgeloschen",
    "abgelte": "abgelten",
    "abgeltend": "abgelten",
    "abgeltende": "abgeltend",
    "abgeltendem": "abgeltend",
    "abgeltenden": "abgeltend",
    "abgeltender": "abgeltend",
    "abgeltendes": "abgeltend",
    "abgeltest": "abgelten",
    "abgeltet": "abgelten",
    "abgelöscht": "ablöschen",
    "abgelöschte": "abgelöscht",
    "abgelöschtem": "abgelöscht",
    "abgelöschten": "abgelöscht",
    "abgelöschter": "abgelöscht",
    "abgelöschtes": "abgelöscht",
    "abgelöst": "ablösen",
    "abgelöste": "abgelöst",
    "abgelöstem": "abgelöst",
    "abgelösten": "abgelöst",
    "abgelöster": "abgelöst",
    "abgelöstes": "abgelöst",
    "abgemacht": "abmachen",
    "abgemachte": "abgemacht",
    "abgemachtem": "abgemacht",
    "abgemachten": "abgemacht",
    "abgemachter": "abgemacht",
    "abgemachtes": "abgemacht",
    "abgemagert": "abmagern",
    "abgemagerte": "abgemagert",
    "abgemagertem": "abgemagert",
    "abgemagerten": "abgemagert",
    "abgemagerter": "abgemagert",
    "abgemagertere": "abgemagert",
    "abgemagerterem": "abgemagert",
    "abgemagerteren": "abgemagert",
    "abgemagerterer": "abgemagert",
    "abgemagerteres": "abgemagert",
    "abgemagertes": "abgemagert",
    "abgemagerteste": "abgemagert",
    "abgemagertestem": "abgemagert",
    "abgemagertesten": "abgemagert",
    "abgemagertester": "abgemagert",
    "abgemagertestes": "abgemagert",
    "abgemalt": "abmalen",
    "abgemalte": "abgemalt",
    "abgemaltem": "abgemalt",
    "abgemalten": "abgemalt",
    "abgemalter": "abgemalt",
    "abgemaltes": "abgemalt",
    "abgemeldet": "abmelden",
    "abgemeldete": "abgemeldet",
    "abgemeldetem": "abgemeldet",
    "abgemeldeten": "abgemeldet",
    "abgemeldeter": "abgemeldet",
    "abgemeldetes": "abgemeldet",
    "abgemessen": "abmessen",
    "abgemessene": "abgemessen",
    "abgemessenem": "abgemessen",
    "abgemessenen": "abgemessen",
    "abgemessener": "abgemessen",
    "abgemessenes": "abgemessen",
    "abgemildert": "abmildern",
    "abgemilderte": "abgemildert",
    "abgemildertem": "abgemildert",
    "abgemilderten": "abgemildert",
    "abgemilderter": "abgemildert",
    "abgemildertes": "abgemildert",
    "abgemurkst": "abmurksen",
    "abgemurkste": "abgemurkst",
    "abgemurkstem": "abgemurkst",
    "abgemurksten": "abgemurkst",
    "abgemurkster": "abgemurkst",
    "abgemurkstes": "abgemurkst",
    "abgemustert": "abmustern",
    "abgemusterte": "abgemustert",
    "abgemustertem": "abgemustert",
    "abgemusterten": "abgemustert",
    "abgemusterter": "abgemustert",
    "abgemustertes": "abgemustert",
    "abgemäht": "abmähen",
    "abgemähte": "abgemäht",
    "abgemähtem": "abgemäht",
    "abgemähten": "abgemäht",
    "abgemähter": "abgemäht",
    "abgemähtere": "abgemäht",
    "abgemähterem": "abgemäht",
    "abgemähteren": "abgemäht",
    "abgemähterer": "abgemäht",
    "abgemähteres": "abgemäht",
    "abgemähtes": "abgemäht",
    "abgemähteste": "abgemäht",
    "abgemähtestem": "abgemäht",
    "abgemähtesten": "abgemäht",
    "abgemähtester": "abgemäht",
    "abgemähtestes": "abgemäht",
    "abgemüht": "abmühen",
    "abgemühte": "abgemüht",
    "abgemühtem": "abgemüht",
    "abgemühten": "abgemüht",
    "abgemühter": "abgemüht",
    "abgemühtes": "abgemüht",
    "abgenabelt": "abnabeln",
    "abgenabelte": "abgenabelt",
    "abgenabeltem": "abgenabelt",
    "abgenabelten": "abgenabelt",
    "abgenabelter": "abgenabelt",
    "abgenabeltes": "abgenabelt",
    "abgenagt": "abnagen",
    "abgenagte": "abgenagt",
    "abgenagtem": "abgenagt",
    "abgenagten": "abgenagt",
    "abgenagter": "abgenagt",
    "abgenagtere": "abgenagt",
    "abgenagterem": "abgenagt",
    "abgenagteren": "abgenagt",
    "abgenagterer": "abgenagt",
    "abgenagteres": "abgenagt",
    "abgenagtes": "abgenagt",
    "abgenagteste": "abgenagt",
    "abgenagtestem": "abgenagt",
    "abgenagtesten": "abgenagt",
    "abgenagtester": "abgenagt",
    "abgenagtestes": "abgenagt",
    "abgeneigt": "abneigen",
    "abgeneigte": "abgeneigt",
    "abgeneigtem": "abgeneigt",
    "abgeneigten": "abgeneigt",
    "abgeneigter": "abgeneigt",
    "abgeneigtes": "abgeneigt",
    "abgenommen": "abnehmen",
    "abgenommene": "abgenommen",
    "abgenommenem": "abgenommen",
    "abgenommenen": "abgenommen",
    "abgenommener": "abgenommen",
    "abgenommenere": "abgenommen",
    "abgenommenerem": "abgenommen",
    "abgenommeneren": "abgenommen",
    "abgenommenerer": "abgenommen",
    "abgenommeneres": "abgenommen",
    "abgenommenes": "abgenommen",
    "abgenommenste": "abgenommen",
    "abgenommenstem": "abgenommen",
    "abgenommensten": "abgenommen",
    "abgenommenster": "abgenommen",
    "abgenommenstes": "abgenommen",
    "abgenutzt": "abnutzen",
    "abgenutzte": "abgenutzt",
    "abgenutztem": "abgenutzt",
    "abgenutzten": "abgenutzt",
    "abgenutzter": "abgenutzt",
    "abgenutztere": "abgenutzt",
    "abgenutzterem": "abgenutzt",
    "abgenutzteren": "abgenutzt",
    "abgenutzterer": "abgenutzt",
    "abgenutzteres": "abgenutzt",
    "abgenutztes": "abgenutzt",
    "abgenutzteste": "abgenutzt",
    "abgenutztestem": "abgenutzt",
    "abgenutztesten": "abgenutzt",
    "abgenutztester": "abgenutzt",
    "abgenutztestes": "abgenutzt",
    "abgenäht": "abnähen",
    "abgenähte": "abgenäht",
    "abgenähtem": "abgenäht",
    "abgenähten": "abgenäht",
    "abgenähter": "abgenäht",
    "abgenähtes": "abgenäht",
    "abgeordnet": "abordnen",
    "abgeordnete": "abgeordnet",
    "abgeordnetem": "abgeordnet",
    "abgeordneten": "abgeordnet",
    "abgeordneter": "abgeordnet",
    "abgeordnetes": "abgeordnet",
    "abgepaßt": "abpassen",
    "abgepaßte": "abgepaßt",
    "abgepaßtem": "abgepaßt",
    "abgepaßten": "abgepaßt",
    "abgepaßter": "abgepaßt",
    "abgepaßtes": "abgepaßt",
    "abgepellt": "abpellen",
    "abgepellte": "abgepellt",
    "abgepelltem": "abgepellt",
    "abgepellten": "abgepellt",
    "abgepellter": "abgepellt",
    "abgepelltere": "abgepellt",
    "abgepellterem": "abgepellt",
    "abgepellteren": "abgepellt",
    "abgepellterer": "abgepellt",
    "abgepellteres": "abgepellt",
    "abgepelltes": "abgepellt",
    "abgepellteste": "abgepellt",
    "abgepelltestem": "abgepellt",
    "abgepelltesten": "abgepellt",
    "abgepelltester": "abgepellt",
    "abgepelltestes": "abgepellt",
    "abgepfiffen": "abpfeifen",
    "abgepfiffene": "abgepfiffen",
    "abgepfiffenem": "abgepfiffen",
    "abgepfiffenen": "abgepfiffen",
    "abgepfiffener": "abgepfiffen",
    "abgepfiffenes": "abgepfiffen",
    "abgeplatzt": "abplatzen",
    "abgeplatzte": "abgeplatzt",
    "abgeplatztem": "abgeplatzt",
    "abgeplatzten": "abgeplatzt",
    "abgeplatzter": "abgeplatzt",
    "abgeplatztere": "abgeplatzt",
    "abgeplatzterem": "abgeplatzt",
    "abgeplatzteren": "abgeplatzt",
    "abgeplatzterer": "abgeplatzt",
    "abgeplatzteres": "abgeplatzt",
    "abgeplatztes": "abgeplatzt",
    "abgeplatzteste": "abgeplatzt",
    "abgeplatztestem": "abgeplatzt",
    "abgeplatztesten": "abgeplatzt",
    "abgeplatztester": "abgeplatzt",
    "abgeplatztestes": "abgeplatzt",
    "abgeprallt": "abprallen",
    "abgeprallte": "abgeprallt",
    "abgepralltem": "abgeprallt",
    "abgeprallten": "abgeprallt",
    "abgeprallter": "abgeprallt",
    "abgepralltes": "abgeprallt",
    "abgepreßt": "abpressen",
    "abgepreßte": "abgepreßt",
    "abgepreßtem": "abgepreßt",
    "abgepreßten": "abgepreßt",
    "abgepreßter": "abgepreßt",
    "abgepreßtes": "abgepreßt",
    "abgepumpt": "abpumpen",
    "abgepumpte": "abgepumpt",
    "abgepumptem": "abgepumpt",
    "abgepumpten": "abgepumpt",
    "abgepumpter": "abgepumpt",
    "abgepumptere": "abgepumpt",
    "abgepumpterem": "abgepumpt",
    "abgepumpteren": "abgepumpt",
    "abgepumpterer": "abgepumpt",
    "abgepumpteres": "abgepumpt",
    "abgepumptes": "abgepumpt",
    "abgepumpteste": "abgepumpt",
    "abgepumptestem": "abgepumpt",
    "abgepumptesten": "abgepumpt",
    "abgepumptester": "abgepumpt",
    "abgepumptestes": "abgepumpt",
    "abgeputzt": "abputzen",
    "abgeputzte": "abgeputzt",
    "abgeputztem": "abgeputzt",
    "abgeputzten": "abgeputzt",
    "abgeputzter": "abgeputzt",
    "abgeputztes": "abgeputzt",
    "abgequetscht": "abquetschen",
    "abgequetschte": "abgequetscht",
    "abgequetschtem": "abgequetscht",
    "abgequetschten": "abgequetscht",
    "abgequetschter": "abgequetscht",
    "abgequetschtere": "abgequetscht",
    "abgequetschterem": "abgequetscht",
    "abgequetschteren": "abgequetscht",
    "abgequetschterer": "abgequetscht",
    "abgequetschteres": "abgequetscht",
    "abgequetschtes": "abgequetscht",
    "abgequetschteste": "abgequetscht",
    "abgequetschtestem": "abgequetscht",
    "abgequetschtesten": "abgequetscht",
    "abgequetschtester": "abgequetscht",
    "abgequetschtestes": "abgequetscht",
    "abgequält": "abquälen",
    "abgequälte": "abgequält",
    "abgequältem": "abgequält",
    "abgequälten": "abgequält",
    "abgequälter": "abgequält",
    "abgequältere": "abgequält",
    "abgequälterem": "abgequält",
    "abgequälteren": "abgequält",
    "abgequälterer": "abgequält",
    "abgequälteres": "abgequält",
    "abgequältes": "abgequält",
    "abgequälteste": "abgequält",
    "abgequältestem": "abgequält",
    "abgequältesten": "abgequält",
    "abgequältester": "abgequält",
    "abgequältestes": "abgequält",
    "abgeraten": "abraten",
    "abgeratene": "abgeraten",
    "abgeratenem": "abgeraten",
    "abgeratenen": "abgeraten",
    "abgeratener": "abgeraten",
    "abgeratenes": "abgeraten",
    "abgerauscht": "abrauschen",
    "abgerauschte": "abgerauscht",
    "abgerauschtem": "abgerauscht",
    "abgerauschten": "abgerauscht",
    "abgerauschter": "abgerauscht",
    "abgerauschtere": "abgerauscht",
    "abgerauschterem": "abgerauscht",
    "abgerauschteren": "abgerauscht",
    "abgerauschterer": "abgerauscht",
    "abgerauschteres": "abgerauscht",
    "abgerauschtes": "abgerauscht",
    "abgerauschteste": "abgerauscht",
    "abgerauschtestem": "abgerauscht",
    "abgerauschtesten": "abgerauscht",
    "abgerauschtester": "abgerauscht",
    "abgerauschtestes": "abgerauscht",
    "abgerechnet": "abrechnen",
    "abgerechnete": "abgerechnet",
    "abgerechnetem": "abgerechnet",
    "abgerechneten": "abgerechnet",
    "abgerechneter": "abgerechnet",
    "abgerechnetes": "abgerechnet",
    "abgeregt": "abregen",
    "abgeregte": "abgeregt",
    "abgeregtem": "abgeregt",
    "abgeregten": "abgeregt",
    "abgeregter": "abgeregt",
    "abgeregtes": "abgeregt",
    "abgereicht": "abreichen",
    "abgereichte": "abgereicht",
    "abgereichtem": "abgereicht",
    "abgereichten": "abgereicht",
    "abgereichter": "abgereicht",
    "abgereichtes": "abgereicht",
    "abgereist": "abreisen",
    "abgereiste": "abgereist",
    "abgereistem": "abgereist",
    "abgereisten": "abgereist",
    "abgereister": "abgereist",
    "abgereistes": "abgereist",
    "abgerichtet": "abrichten",
    "abgerichtete": "abgerichtet",
    "abgerichtetem": "abgerichtet",
    "abgerichteten": "abgerichtet",
    "abgerichteter": "abgerichtet",
    "abgerichtetere": "abgerichtet",
    "abgerichteterem": "abgerichtet",
    "abgerichteteren": "abgerichtet",
    "abgerichteterer": "abgerichtet",
    "abgerichteteres": "abgerichtet",
    "abgerichtetes": "abgerichtet",
    "abgerichteteste": "abgerichtet",
    "abgerichtetestem": "abgerichtet",
    "abgerichtetesten": "abgerichtet",
    "abgerichtetester": "abgerichtet",
    "abgerichtetestes": "abgerichtet",
    "abgerieben": "abreiben",
    "abgeriebene": "abgerieben",
    "abgeriebenem": "abgerieben",
    "abgeriebenen": "abgerieben",
    "abgeriebener": "abgerieben",
    "abgeriebenere": "abgerieben",
    "abgeriebenerem": "abgerieben",
    "abgeriebeneren": "abgerieben",
    "abgeriebenerer": "abgerieben",
    "abgeriebeneres": "abgerieben",
    "abgeriebenes": "abgerieben",
    "abgeriebenste": "abgerieben",
    "abgeriebenstem": "abgerieben",
    "abgeriebensten": "abgerieben",
    "abgeriebenster": "abgerieben",
    "abgeriebenstes": "abgerieben",
    "abgeriegelt": "abriegeln",
    "abgeriegelte": "abgeriegelt",
    "abgeriegeltem": "abgeriegelt",
    "abgeriegelten": "abgeriegelt",
    "abgeriegelter": "abgeriegelt",
    "abgeriegeltes": "abgeriegelt",
    "abgeriffelt": "abriffeln",
    "abgeriffelte": "abgeriffelt",
    "abgeriffeltem": "abgeriffelt",
    "abgeriffelten": "abgeriffelt",
    "abgeriffelter": "abgeriffelt",
    "abgeriffeltes": "abgeriffelt",
    "abgerindet": "abrinden",
    "abgerindete": "abgerindet",
    "abgerindetem": "abgerindet",
    "abgerindeten": "abgerindet",
    "abgerindeter": "abgerindet",
    "abgerindetes": "abgerindet",
    "abgerissen": "abreißen",
    "abgerissene": "abgerissen",
    "abgerissenem": "abgerissen",
    "abgerissenen": "abgerissen",
    "abgerissener": "abgerissen",
    "abgerissenere": "abgerissen",
    "abgerissenerem": "abgerissen",
    "abgerisseneren": "abgerissen",
    "abgerissenerer": "abgerissen",
    "abgerisseneres": "abgerissen",
    "abgerissenes": "abgerissen",
    "abgerissenste": "abgerissen",
    "abgerissenstem": "abgerissen",
    "abgerissensten": "abgerissen",
    "abgerissenster": "abgerissen",
    "abgerissenstes": "abgerissen",
    "abgeritten": "abreiten",
    "abgerittene": "abgeritten",
    "abgerittenem": "abgeritten",
    "abgerittenen": "abgeritten",
    "abgerittener": "abgeritten",
    "abgerittenes": "abgeritten",
    "abgerodet": "abroden",
    "abgerodete": "abgerodet",
    "abgerodetem": "abgerodet",
    "abgerodeten": "abgerodet",
    "abgerodeter": "abgerodet",
    "abgerodetere": "abgerodet",
    "abgerodeterem": "abgerodet",
    "abgerodeteren": "abgerodet",
    "abgerodeterer": "abgerodet",
    "abgerodeteres": "abgerodet",
    "abgerodetes": "abgerodet",
    "abgerodeteste": "abgerodet",
    "abgerodetestem": "abgerodet",
    "abgerodetesten": "abgerodet",
    "abgerodetester": "abgerodet",
    "abgerodetestes": "abgerodet",
    "abgerollt": "abrollen",
    "abgerollte": "abgerollt",
    "abgerolltem": "abgerollt",
    "abgerollten": "abgerollt",
    "abgerollter": "abgerollt",
    "abgerolltere": "abgerollt",
    "abgerollterem": "abgerollt",
    "abgerollteren": "abgerollt",
    "abgerollterer": "abgerollt",
    "abgerollteres": "abgerollt",
    "abgerolltes": "abgerollt",
    "abgerollteste": "abgerollt",
    "abgerolltestem": "abgerollt",
    "abgerolltesten": "abgerollt",
    "abgerolltester": "abgerollt",
    "abgerolltestes": "abgerollt",
    "abgerudert": "abrudern",
    "abgeruderte": "abgerudert",
    "abgerudertem": "abgerudert",
    "abgeruderten": "abgerudert",
    "abgeruderter": "abgerudert",
    "abgerudertes": "abgerudert",
    "abgerufen": "abrufen",
    "abgerufene": "abgerufen",
    "abgerufenem": "abgerufen",
    "abgerufenen": "abgerufen",
    "abgerufener": "abgerufen",
    "abgerufenes": "abgerufen",
    "abgerundet": "abrunden",
    "abgerundete": "abgerundet",
    "abgerundetem": "abgerundet",
    "abgerundeten": "abgerundet",
    "abgerundeter": "abgerundet",
    "abgerundetes": "abgerundet",
    "abgerungen": "abringen",
    "abgerungene": "abgerungen",
    "abgerungenem": "abgerungen",
    "abgerungenen": "abgerungen",
    "abgerungener": "abgerungen",
    "abgerungenes": "abgerungen",
    "abgerupft": "abrupfen",
    "abgerupfte": "abgerupft",
    "abgerupftem": "abgerupft",
    "abgerupften": "abgerupft",
    "abgerupfter": "abgerupft",
    "abgerupftere": "abgerupft",
    "abgerupfterem": "abgerupft",
    "abgerupfteren": "abgerupft",
    "abgerupfterer": "abgerupft",
    "abgerupfteres": "abgerupft",
    "abgerupftes": "abgerupft",
    "abgerupfteste": "abgerupft",
    "abgerupftestem": "abgerupft",
    "abgerupftesten": "abgerupft",
    "abgerupftester": "abgerupft",
    "abgerupftestes": "abgerupft",
    "abgerutscht": "abrutschen",
    "abgerutschte": "abgerutscht",
    "abgerutschtem": "abgerutscht",
    "abgerutschten": "abgerutscht",
    "abgerutschter": "abgerutscht",
    "abgerutschtes": "abgerutscht",
    "abgeräumt": "abräumen",
    "abgeräumte": "abgeräumt",
    "abgeräumtem": "abgeräumt",
    "abgeräumten": "abgeräumt",
    "abgeräumter": "abgeräumt",
    "abgeräumtere": "abgeräumt",
    "abgeräumterem": "abgeräumt",
    "abgeräumteren": "abgeräumt",
    "abgeräumterer": "abgeräumt",
    "abgeräumteres": "abgeräumt",
    "abgeräumtes": "abgeräumt",
    "abgeräumteste": "abgeräumt",
    "abgeräumtestem": "abgeräumt",
    "abgeräumtesten": "abgeräumt",
    "abgeräumtester": "abgeräumt",
    "abgeräumtestes": "abgeräumt",
    "abgerückt": "abrücken",
    "abgerückte": "abgerückt",
    "abgerücktem": "abgerückt",
    "abgerückten": "abgerückt",
    "abgerückter": "abgerückt",
    "abgerücktes": "abgerückt",
    "abgerührt": "abrühren",
    "abgerührte": "abgerührt",
    "abgerührtem": "abgerührt",
    "abgerührten": "abgerührt",
    "abgerührter": "abgerührt",
    "abgerührtes": "abgerührt",
    "abgerüstet": "abrüsten",
    "abgerüstete": "abgerüstet",
    "abgerüstetem": "abgerüstet",
    "abgerüsteten": "abgerüstet",
    "abgerüsteter": "abgerüstet",
    "abgerüstetes": "abgerüstet",
    "abgesagt": "absagen",
    "abgesagte": "abgesagt",
    "abgesagtem": "abgesagt",
    "abgesagten": "abgesagt",
    "abgesagter": "abgesagt",
    "abgesagtes": "abgesagt",
    "abgesahnt": "absahnen",
    "abgesahnte": "abgesahnt",
    "abgesahntem": "abgesahnt",
    "abgesahnten": "abgesahnt",
    "abgesahnter": "abgesahnt",
    "abgesahntes": "abgesahnt",
    "abgesandt": "absenden",
    "abgesandte": "abgesandt",
    "abgesandtem": "abgesandt",
    "abgesandten": "abgesandt",
    "abgesandter": "abgesandt",
    "abgesandtes": "abgesandt",
    "abgesattelt": "absatteln",
    "abgesattelte": "abgesattelt",
    "abgesatteltem": "abgesattelt",
    "abgesattelten": "abgesattelt",
    "abgesattelter": "abgesattelt",
    "abgesatteltes": "abgesattelt",
    "abgesaugt": "absaugen",
    "abgesaugte": "abgesaugt",
    "abgesaugtem": "abgesaugt",
    "abgesaugten": "abgesaugt",
    "abgesaugter": "abgesaugt",
    "abgesaugtere": "abgesaugt",
    "abgesaugterem": "abgesaugt",
    "abgesaugteren": "abgesaugt",
    "abgesaugterer": "abgesaugt",
    "abgesaugteres": "abgesaugt",
    "abgesaugtes": "abgesaugt",
    "abgesaugteste": "abgesaugt",
    "abgesaugtestem": "abgesaugt",
    "abgesaugtesten": "abgesaugt",
    "abgesaugtester": "abgesaugt",
    "abgesaugtestes": "abgesaugt",
    "abgesaust": "absausen",
    "abgesauste": "abgesaust",
    "abgesaustem": "abgesaust",
    "abgesausten": "abgesaust",
    "abgesauster": "abgesaust",
    "abgesaustes": "abgesaust",
    "abgeschabt": "abschaben",
    "abgeschabte": "abgeschabt",
    "abgeschabtem": "abgeschabt",
    "abgeschabten": "abgeschabt",
    "abgeschabter": "abgeschabt",
    "abgeschabtere": "abgeschabt",
    "abgeschabterem": "abgeschabt",
    "abgeschabteren": "abgeschabt",
    "abgeschabterer": "abgeschabt",
    "abgeschabteres": "abgeschabt",
    "abgeschabtes": "abgeschabt",
    "abgeschabteste": "abgeschabt",
    "abgeschabtestem": "abgeschabt",
    "abgeschabtesten": "abgeschabt",
    "abgeschabtester": "abgeschabt",
    "abgeschabtestes": "abgeschabt",
    "abgeschafft": "abschaffen",
    "abgeschaffte": "abgeschafft",
    "abgeschafftem": "abgeschafft",
    "abgeschafften": "abgeschafft",
    "abgeschaffter": "abgeschafft",
    "abgeschafftes": "abgeschafft",
    "abgeschaltet": "abschalten",
    "abgeschaltete": "abgeschaltet",
    "abgeschaltetem": "abgeschaltet",
    "abgeschalteten": "abgeschaltet",
    "abgeschalteter": "abgeschaltet",
    "abgeschaltetes": "abgeschaltet",
    "abgeschaut": "abschauen",
    "abgeschaute": "abgeschaut",
    "abgeschautem": "abgeschaut",
    "abgeschauten": "abgeschaut",
    "abgeschauter": "abgeschaut",
    "abgeschautes": "abgeschaut",
    "abgeschert": "abscheren",
    "abgescherte": "abgeschert",
    "abgeschertem": "abgeschert",
    "abgescherten": "abgeschert",
    "abgescherter": "abgeschert",
    "abgeschertes": "abgeschert",
    "abgescheuert": "abscheuern",
    "abgescheuerte": "abgescheuert",
    "abgescheuertem": "abgescheuert",
    "abgescheuerten": "abgescheuert",
    "abgescheuerter": "abgescheuert",
    "abgescheuertere": "abgescheuert",
    "abgescheuerterem": "abgescheuert",
    "abgescheuerteren": "abgescheuert",
    "abgescheuerterer": "abgescheuert",
    "abgescheuerteres": "abgescheuert",
    "abgescheuertes": "abgescheuert",
    "abgescheuerteste": "abgescheuert",
    "abgescheuertestem": "abgescheuert",
    "abgescheuertesten": "abgescheuert",
    "abgescheuertester": "abgescheuert",
    "abgescheuertestes": "abgescheuert",
    "abgeschieden": "abscheiden",
    "abgeschiedene": "abgeschieden",
    "abgeschiedenem": "abgeschieden",
    "abgeschiedenen": "abgeschieden",
    "abgeschiedener": "abgeschieden",
    "abgeschiedenes": "abgeschieden",
    "abgeschiefert": "abschiefern",
    "abgeschieferte": "abgeschiefert",
    "abgeschiefertem": "abgeschiefert",
    "abgeschieferten": "abgeschiefert",
    "abgeschieferter": "abgeschiefert",
    "abgeschiefertes": "abgeschiefert",
    "abgeschirmt": "abschirmen",
    "abgeschirmte": "abgeschirmt",
    "abgeschirmtem": "abgeschirmt",
    "abgeschirmten": "abgeschirmt",
    "abgeschirmter": "abgeschirmt",
    "abgeschirmtere": "abgeschirmt",
    "abgeschirmterem": "abgeschirmt",
    "abgeschirmteren": "abgeschirmt",
    "abgeschirmterer": "abgeschirmt",
    "abgeschirmteres": "abgeschirmt",
    "abgeschirmtes": "abgeschirmt",
    "abgeschirmteste": "abgeschirmt",
    "abgeschirmtestem": "abgeschirmt",
    "abgeschirmtesten": "abgeschirmt",
    "abgeschirmtester": "abgeschirmt",
    "abgeschirmtestes": "abgeschirmt",
    "abgeschirrt": "abschirren",
    "abgeschirrte": "abgeschirrt",
    "abgeschirrtem": "abgeschirrt",
    "abgeschirrten": "abgeschirrt",
    "abgeschirrter": "abgeschirrt",
    "abgeschirrtes": "abgeschirrt",
    "abgeschlachtet": "abschlachten",
    "abgeschlachtete": "abgeschlachtet",
    "abgeschlachtetem": "abgeschlachtet",
    "abgeschlachteten": "abgeschlachtet",
    "abgeschlachteter": "abgeschlachtet",
    "abgeschlachtetes": "abgeschlachtet",
    "abgeschlafft": "abschlaffen",
    "abgeschlaffte": "abgeschlafft",
    "abgeschlafftem": "abgeschlafft",
    "abgeschlafften": "abgeschlafft",
    "abgeschlaffter": "abgeschlafft",
    "abgeschlafftere": "abgeschlafft",
    "abgeschlaffterem": "abgeschlafft",
    "abgeschlaffteren": "abgeschlafft",
    "abgeschlaffterer": "abgeschlafft",
    "abgeschlaffteres": "abgeschlafft",
    "abgeschlafftes": "abgeschlafft",
    "abgeschlaffteste": "abgeschlafft",
    "abgeschlafftestem": "abgeschlafft",
    "abgeschlafftesten": "abgeschlafft",
    "abgeschlafftester": "abgeschlafft",
    "abgeschlafftestes": "abgeschlafft",
    "abgeschlagen": "abschlagen",
    "abgeschlagene": "abgeschlagen",
    "abgeschlagenem": "abgeschlagen",
    "abgeschlagenen": "abgeschlagen",
    "abgeschlagener": "abgeschlagen",
    "abgeschlagenes": "abgeschlagen",
    "abgeschleift": "abschleifen",
    "abgeschleifte": "abgeschleift",
    "abgeschleiftem": "abgeschleift",
    "abgeschleiften": "abgeschleift",
    "abgeschleifter": "abgeschleift",
    "abgeschleiftere": "abgeschleift",
    "abgeschleifterem": "abgeschleift",
    "abgeschleifteren": "abgeschleift",
    "abgeschleifterer": "abgeschleift",
    "abgeschleifteres": "abgeschleift",
    "abgeschleiftes": "abgeschleift",
    "abgeschleifteste": "abgeschleift",
    "abgeschleiftestem": "abgeschleift",
    "abgeschleiftesten": "abgeschleift",
    "abgeschleiftester": "abgeschleift",
    "abgeschleiftestes": "abgeschleift",
    "abgeschleppt": "abschleppen",
    "abgeschleppte": "abgeschleppt",
    "abgeschlepptem": "abgeschleppt",
    "abgeschleppten": "abgeschleppt",
    "abgeschleppter": "abgeschleppt",
    "abgeschlepptes": "abgeschleppt",
    "abgeschliffen": "abschleifen",
    "abgeschliffene": "abgeschliffen",
    "abgeschliffenem": "abgeschliffen",
    "abgeschliffenen": "abgeschliffen",
    "abgeschliffener": "abgeschliffen",
    "abgeschliffenes": "abgeschliffen",
    "abgeschlossen": "abschließen",
    "abgeschlossene": "abgeschlossen",
    "abgeschlossenem": "abgeschlossen",
    "abgeschlossenen": "abgeschlossen",
    "abgeschlossener": "abgeschlossen",
    "abgeschlossenes": "abgeschlossen",
    "abgeschlämmt": "abschlämmen",
    "abgeschlämmte": "abgeschlämmt",
    "abgeschlämmtem": "abgeschlämmt",
    "abgeschlämmten": "abgeschlämmt",
    "abgeschlämmter": "abgeschlämmt",
    "abgeschlämmtes": "abgeschlämmt",
    "abgeschmatzt": "abschmatzen",
    "abgeschmatzte": "abgeschmatzt",
    "abgeschmatztem": "abgeschmatzt",
    "abgeschmatzten": "abgeschmatzt",
    "abgeschmatzter": "abgeschmatzt",
    "abgeschmatztere": "abgeschmatzt",
    "abgeschmatzterem": "abgeschmatzt",
    "abgeschmatzteren": "abgeschmatzt",
    "abgeschmatzterer": "abgeschmatzt",
    "abgeschmatzteres": "abgeschmatzt",
    "abgeschmatztes": "abgeschmatzt",
    "abgeschmatzteste": "abgeschmatzt",
    "abgeschmatztestem": "abgeschmatzt",
    "abgeschmatztesten": "abgeschmatzt",
    "abgeschmatztester": "abgeschmatzt",
    "abgeschmatztestes": "abgeschmatzt",
    "abgeschmeichelt": "abschmeicheln",
    "abgeschmeichelte": "abgeschmeichelt",
    "abgeschmeicheltem": "abgeschmeichelt",
    "abgeschmeichelten": "abgeschmeichelt",
    "abgeschmeichelter": "abgeschmeichelt",
    "abgeschmeicheltere": "abgeschmeichelt",
    "abgeschmeichelterem": "abgeschmeichelt",
    "abgeschmeichelteren": "abgeschmeichelt",
    "abgeschmeichelterer": "abgeschmeichelt",
    "abgeschmeichelteres": "abgeschmeichelt",
    "abgeschmeicheltes": "abgeschmeichelt",
    "abgeschmeichelteste": "abgeschmeichelt",
    "abgeschmeicheltestem": "abgeschmeichelt",
    "abgeschmeicheltesten": "abgeschmeichelt",
    "abgeschmeicheltester": "abgeschmeichelt",
    "abgeschmeicheltestes": "abgeschmeichelt",
    "abgeschmettert": "abschmettern",
    "abgeschmetterte": "abgeschmettert",
    "abgeschmettertem": "abgeschmettert",
    "abgeschmetterten": "abgeschmettert",
    "abgeschmetterter": "abgeschmettert",
    "abgeschmettertes": "abgeschmettert",
    "abgeschmiert": "abschmieren",
    "abgeschmierte": "abgeschmiert",
    "abgeschmiertem": "abgeschmiert",
    "abgeschmierten": "abgeschmiert",
    "abgeschmierter": "abgeschmiert",
    "abgeschmiertes": "abgeschmiert",
    "abgeschminkt": "abschminken",
    "abgeschminkte": "abgeschminkt",
    "abgeschminktem": "abgeschminkt",
    "abgeschminkten": "abgeschminkt",
    "abgeschminkter": "abgeschminkt",
    "abgeschminktes": "abgeschminkt",
    "abgeschmolzen": "abschmelzen",
    "abgeschmolzene": "abgeschmolzen",
    "abgeschmolzenem": "abgeschmolzen",
    "abgeschmolzenen": "abgeschmolzen",
    "abgeschmolzener": "abgeschmolzen",
    "abgeschmolzenes": "abgeschmolzen",
    "abgeschnallt": "abschnallen",
    "abgeschnallte": "abgeschnallt",
    "abgeschnalltem": "abgeschnallt",
    "abgeschnallten": "abgeschnallt",
    "abgeschnallter": "abgeschnallt",
    "abgeschnalltes": "abgeschnallt",
    "abgeschnappt": "abschnappen",
    "abgeschnappte": "abgeschnappt",
    "abgeschnapptem": "abgeschnappt",
    "abgeschnappten": "abgeschnappt",
    "abgeschnappter": "abgeschnappt",
    "abgeschnapptes": "abgeschnappt",
    "abgeschnitten": "abschneiden",
    "abgeschnittene": "abgeschnitten",
    "abgeschnittenem": "abgeschnitten",
    "abgeschnittenen": "abgeschnitten",
    "abgeschnittener": "abgeschnitten",
    "abgeschnittenere": "abgeschnitten",
    "abgeschnittenerem": "abgeschnitten",
    "abgeschnitteneren": "abgeschnitten",
    "abgeschnittenerer": "abgeschnitten",
    "abgeschnitteneres": "abgeschnitten",
    "abgeschnittenes": "abgeschnitten",
    "abgeschnittenste": "abgeschnitten",
    "abgeschnittenstem": "abgeschnitten",
    "abgeschnittensten": "abgeschnitten",
    "abgeschnittenster": "abgeschnitten",
    "abgeschnittenstes": "abgeschnitten",
    "abgeschnürt": "abschnüren",
    "abgeschnürte": "abgeschnürt",
    "abgeschnürtem": "abgeschnürt",
    "abgeschnürten": "abgeschnürt",
    "abgeschnürter": "abgeschnürt",
    "abgeschnürtere": "abgeschnürt",
    "abgeschnürterem": "abgeschnürt",
    "abgeschnürteren": "abgeschnürt",
    "abgeschnürterer": "abgeschnürt",
    "abgeschnürteres": "abgeschnürt",
    "abgeschnürtes": "abgeschnürt",
    "abgeschnürteste": "abgeschnürt",
    "abgeschnürtestem": "abgeschnürt",
    "abgeschnürtesten": "abgeschnürt",
    "abgeschnürtester": "abgeschnürt",
    "abgeschnürtestes": "abgeschnürt",
    "abgeschoben": "abschieben",
    "abgeschobene": "abgeschoben",
    "abgeschobenem": "abgeschoben",
    "abgeschobenen": "abgeschoben",
    "abgeschobener": "abgeschoben",
    "abgeschobenes": "abgeschoben",
    "abgeschoren": "abscheren",
    "abgeschorene": "abgeschoren",
    "abgeschorenem": "abgeschoren",
    "abgeschorenen": "abgeschoren",
    "abgeschorener": "abgeschoren",
    "abgeschorenes": "abgeschoren",
    "abgeschossen": "abschießen",
    "abgeschossene": "abgeschossen",
    "abgeschossenem": "abgeschossen",
    "abgeschossenen": "abgeschossen",
    "abgeschossener": "abgeschossen",
    "abgeschossenes": "abgeschossen",
    "abgeschraubt": "abschrauben",
    "abgeschraubte": "abgeschraubt",
    "abgeschraubtem": "abgeschraubt",
    "abgeschraubten": "abgeschraubt",
    "abgeschraubter": "abgeschraubt",
    "abgeschraubtes": "abgeschraubt",
    "abgeschreckt": "abschrecken",
    "abgeschreckte": "abgeschreckt",
    "abgeschrecktem": "abgeschreckt",
    "abgeschreckten": "abgeschreckt",
    "abgeschreckter": "abgeschreckt",
    "abgeschrecktere": "abgeschreckt",
    "abgeschreckterem": "abgeschreckt",
    "abgeschreckteren": "abgeschreckt",
    "abgeschreckterer": "abgeschreckt",
    "abgeschreckteres": "abgeschreckt",
    "abgeschrecktes": "abgeschreckt",
    "abgeschreckteste": "abgeschreckt",
    "abgeschrecktestem": "abgeschreckt",
    "abgeschrecktesten": "abgeschreckt",
    "abgeschrecktester": "abgeschreckt",
    "abgeschrecktestes": "abgeschreckt",
    "abgeschrieben": "abschreiben",
    "abgeschriebene": "abgeschrieben",
    "abgeschriebenem": "abgeschrieben",
    "abgeschriebenen": "abgeschrieben",
    "abgeschriebener": "abgeschrieben",
    "abgeschriebenere": "abgeschrieben",
    "abgeschriebenerem": "abgeschrieben",
    "abgeschriebeneren": "abgeschrieben",
    "abgeschriebenerer": "abgeschrieben",
    "abgeschriebeneres": "abgeschrieben",
    "abgeschriebenes": "abgeschrieben",
    "abgeschriebenste": "abgeschrieben",
    "abgeschriebenstem": "abgeschrieben",
    "abgeschriebensten": "abgeschrieben",
    "abgeschriebenster": "abgeschrieben",
    "abgeschriebenstes": "abgeschrieben",
    "abgeschritten": "abschreiten",
    "abgeschrittene": "abgeschritten",
    "abgeschrittenem": "abgeschritten",
    "abgeschrittenen": "abgeschritten",
    "abgeschrittener": "abgeschritten",
    "abgeschrittenes": "abgeschritten",
    "abgeschrocken": "abschrecken",
    "abgeschrockene": "abgeschrocken",
    "abgeschrockenem": "abgeschrocken",
    "abgeschrockenen": "abgeschrocken",
    "abgeschrockener": "abgeschrocken",
    "abgeschrockenes": "abgeschrocken",
    "abgeschrägt": "abschrägen",
    "abgeschrägte": "abgeschrägt",
    "abgeschrägtem": "abgeschrägt",
    "abgeschrägten": "abgeschrägt",
    "abgeschrägter": "abgeschrägt",
    "abgeschrägtes": "abgeschrägt",
    "abgeschröpft": "abschröpfen",
    "abgeschröpfte": "abgeschröpft",
    "abgeschröpftem": "abgeschröpft",
    "abgeschröpften": "abgeschröpft",
    "abgeschröpfter": "abgeschröpft",
    "abgeschröpftes": "abgeschröpft",
    "abgeschuftet": "abschuften",
    "abgeschuftete": "abgeschuftet",
    "abgeschuftetem": "abgeschuftet",
    "abgeschufteten": "abgeschuftet",
    "abgeschufteter": "abgeschuftet",
    "abgeschuftetes": "abgeschuftet",
    "abgeschunden": "abschinden",
    "abgeschundene": "abgeschunden",
    "abgeschundenem": "abgeschunden",
    "abgeschundenen": "abgeschunden",
    "abgeschundener": "abgeschunden",
    "abgeschundenere": "abgeschunden",
    "abgeschundenerem": "abgeschunden",
    "abgeschundeneren": "abgeschunden",
    "abgeschundenerer": "abgeschunden",
    "abgeschundeneres": "abgeschunden",
    "abgeschundenes": "abgeschunden",
    "abgeschundenste": "abgeschunden",
    "abgeschundenstem": "abgeschunden",
    "abgeschundensten": "abgeschunden",
    "abgeschundenster": "abgeschunden",
    "abgeschundenstes": "abgeschunden",
    "abgeschwatzt": "abschwatzen",
    "abgeschwatzte": "abgeschwatzt",
    "abgeschwatztem": "abgeschwatzt",
    "abgeschwatzten": "abgeschwatzt",
    "abgeschwatzter": "abgeschwatzt",
    "abgeschwatztes": "abgeschwatzt",
    "abgeschweift": "abschweifen",
    "abgeschweifte": "abgeschweift",
    "abgeschweiftem": "abgeschweift",
    "abgeschweiften": "abgeschweift",
    "abgeschweifter": "abgeschweift",
    "abgeschweiftere": "abgeschweift",
    "abgeschweifterem": "abgeschweift",
    "abgeschweifteren": "abgeschweift",
    "abgeschweifterer": "abgeschweift",
    "abgeschweifteres": "abgeschweift",
    "abgeschweiftes": "abgeschweift",
    "abgeschweifteste": "abgeschweift",
    "abgeschweiftestem": "abgeschweift",
    "abgeschweiftesten": "abgeschweift",
    "abgeschweiftester": "abgeschweift",
    "abgeschweiftestes": "abgeschweift",
    "abgeschwellt": "abschwellen",
    "abgeschwellte": "abgeschwellt",
    "abgeschwelltem": "abgeschwellt",
    "abgeschwellten": "abgeschwellt",
    "abgeschwellter": "abgeschwellt",
    "abgeschwelltes": "abgeschwellt",
    "abgeschwenkt": "abschwenken",
    "abgeschwenkte": "abgeschwenkt",
    "abgeschwenktem": "abgeschwenkt",
    "abgeschwenkten": "abgeschwenkt",
    "abgeschwenkter": "abgeschwenkt",
    "abgeschwenktes": "abgeschwenkt",
    "abgeschwindelt": "abschwindeln",
    "abgeschwindelte": "abgeschwindelt",
    "abgeschwindeltem": "abgeschwindelt",
    "abgeschwindelten": "abgeschwindelt",
    "abgeschwindelter": "abgeschwindelt",
    "abgeschwindeltes": "abgeschwindelt",
    "abgeschwirrt": "abschwirren",
    "abgeschwirrte": "abgeschwirrt",
    "abgeschwirrtem": "abgeschwirrt",
    "abgeschwirrten": "abgeschwirrt",
    "abgeschwirrter": "abgeschwirrt",
    "abgeschwirrtes": "abgeschwirrt",
    "abgeschwollen": "abschwellen",
    "abgeschwollene": "abgeschwollen",
    "abgeschwollenem": "abgeschwollen",
    "abgeschwollenen": "abgeschwollen",
    "abgeschwollener": "abgeschwollen",
    "abgeschwollenere": "abgeschwollen",
    "abgeschwollenerem": "abgeschwollen",
    "abgeschwolleneren": "abgeschwollen",
    "abgeschwollenerer": "abgeschwollen",
    "abgeschwolleneres": "abgeschwollen",
    "abgeschwollenes": "abgeschwollen",
    "abgeschwollenste": "abgeschwollen",
    "abgeschwollenstem": "abgeschwollen",
    "abgeschwollensten": "abgeschwollen",
    "abgeschwollenster": "abgeschwollen",
    "abgeschwollenstes": "abgeschwollen",
    "abgeschworen": "abschwören",
    "abgeschworene": "abgeschworen",
    "abgeschworenem": "abgeschworen",
    "abgeschworenen": "abgeschworen",
    "abgeschworener": "abgeschworen",
    "abgeschworenes": "abgeschworen",
    "abgeschwungen": "abschwingen",
    "abgeschwungene": "abgeschwungen",
    "abgeschwungenem": "abgeschwungen",
    "abgeschwungenen": "abgeschwungen",
    "abgeschwungener": "abgeschwungen",
    "abgeschwungenes": "abgeschwungen",
    "abgeschwächt": "abschwächen",
    "abgeschwächte": "abgeschwächt",
    "abgeschwächtem": "abgeschwächt",
    "abgeschwächten": "abgeschwächt",
    "abgeschwächter": "abgeschwächt",
    "abgeschwächtere": "abgeschwächt",
    "abgeschwächterem": "abgeschwächt",
    "abgeschwächteren": "abgeschwächt",
    "abgeschwächterer": "abgeschwächt",
    "abgeschwächteres": "abgeschwächt",
    "abgeschwächtes": "abgeschwächt",
    "abgeschwächteste": "abgeschwächt",
    "abgeschwächtestem": "abgeschwächt",
    "abgeschwächtesten": "abgeschwächt",
    "abgeschwächtester": "abgeschwächt",
    "abgeschwächtestes": "abgeschwächt",
    "abgeschält": "abschälen",
    "abgeschälte": "abgeschält",
    "abgeschältem": "abgeschält",
    "abgeschälten": "abgeschält",
    "abgeschälter": "abgeschält",
    "abgeschältes": "abgeschält",
    "abgeschätzt": "abschätzen",
    "abgeschätzte": "abgeschätzt",
    "abgeschätztem": "abgeschätzt",
    "abgeschätzten": "abgeschätzt",
    "abgeschätzter": "abgeschätzt",
    "abgeschätztes": "abgeschätzt",
    "abgeschäumt": "abschäumen",
    "abgeschäumte": "abgeschäumt",
    "abgeschäumtem": "abgeschäumt",
    "abgeschäumten": "abgeschäumt",
    "abgeschäumter": "abgeschäumt",
    "abgeschäumtes": "abgeschäumt",
    "abgeschöpft": "abschöpfen",
    "abgeschöpfte": "abgeschöpft",
    "abgeschöpftem": "abgeschöpft",
    "abgeschöpften": "abgeschöpft",
    "abgeschöpfter": "abgeschöpft",
    "abgeschöpftes": "abgeschöpft",
    "abgeschürft": "abschürfen",
    "abgeschürfte": "abgeschürft",
    "abgeschürftem": "abgeschürft",
    "abgeschürften": "abgeschürft",
    "abgeschürfter": "abgeschürft",
    "abgeschürftere": "abgeschürft",
    "abgeschürfterem": "abgeschürft",
    "abgeschürfteren": "abgeschürft",
    "abgeschürfterer": "abgeschürft",
    "abgeschürfteres": "abgeschürft",
    "abgeschürftes": "abgeschürft",
    "abgeschürfteste": "abgeschürft",
    "abgeschürftestem": "abgeschürft",
    "abgeschürftesten": "abgeschürft",
    "abgeschürftester": "abgeschürft",
    "abgeschürftestes": "abgeschürft",
    "abgeschüttelt": "abschütteln",
    "abgeschüttelte": "abgeschüttelt",
    "abgeschütteltem": "abgeschüttelt",
    "abgeschüttelten": "abgeschüttelt",
    "abgeschüttelter": "abgeschüttelt",
    "abgeschütteltes": "abgeschüttelt",
    "abgesegnet": "absegnen",
    "abgesegnete": "abgesegnet",
    "abgesegnetem": "abgesegnet",
    "abgesegneten": "abgesegnet",
    "abgesegneter": "abgesegnet",
    "abgesegnetes": "abgesegnet",
    "abgesehen": "absehen",
    "abgesehene": "abgesehen",
    "abgesehenem": "abgesehen",
    "abgesehenen": "abgesehen",
    "abgesehener": "abgesehen",
    "abgesehenes": "abgesehen",
    "abgeseift": "abseifen",
    "abgeseifte": "abgeseift",
    "abgeseiftem": "abgeseift",
    "abgeseiften": "abgeseift",
    "abgeseifter": "abgeseift",
    "abgeseiftere": "abgeseift",
    "abgeseifterem": "abgeseift",
    "abgeseifteren": "abgeseift",
    "abgeseifterer": "abgeseift",
    "abgeseifteres": "abgeseift",
    "abgeseiftes": "abgeseift",
    "abgeseifteste": "abgeseift",
    "abgeseiftestem": "abgeseift",
    "abgeseiftesten": "abgeseift",
    "abgeseiftester": "abgeseift",
    "abgeseiftestes": "abgeseift",
    "abgeseilt": "abseilen",
    "abgeseilte": "abgeseilt",
    "abgeseiltem": "abgeseilt",
    "abgeseilten": "abgeseilt",
    "abgeseilter": "abgeseilt",
    "abgeseiltere": "abgeseilt",
    "abgeseilterem": "abgeseilt",
    "abgeseilteren": "abgeseilt",
    "abgeseilterer": "abgeseilt",
    "abgeseilteres": "abgeseilt",
    "abgeseiltes": "abgeseilt",
    "abgeseilteste": "abgeseilt",
    "abgeseiltestem": "abgeseilt",
    "abgeseiltesten": "abgeseilt",
    "abgeseiltester": "abgeseilt",
    "abgeseiltestes": "abgeseilt",
    "abgesendet": "absenden",
    "abgesendete": "abgesendet",
    "abgesendetem": "abgesendet",
    "abgesendeten": "abgesendet",
    "abgesendeter": "abgesendet",
    "abgesendetes": "abgesendet",
    "abgesengt": "absengen",
    "abgesengte": "abgesengt",
    "abgesengtem": "abgesengt",
    "abgesengten": "abgesengt",
    "abgesengter": "abgesengt",
    "abgesengtere": "abgesengt",
    "abgesengterem": "abgesengt",
    "abgesengteren": "abgesengt",
    "abgesengterer": "abgesengt",
    "abgesengteres": "abgesengt",
    "abgesengtes": "abgesengt",
    "abgesengteste": "abgesengt",
    "abgesengtestem": "abgesengt",
    "abgesengtesten": "abgesengt",
    "abgesengtester": "abgesengt",
    "abgesengtestes": "abgesengt",
    "abgesenkt": "absenken",
    "abgesenkte": "abgesenkt",
    "abgesenktem": "abgesenkt",
    "abgesenkten": "abgesenkt",
    "abgesenkter": "abgesenkt",
    "abgesenktes": "abgesenkt",
    "abgesessen": "absitzen",
    "abgesessene": "abgesessen",
    "abgesessenem": "abgesessen",
    "abgesessenen": "abgesessen",
    "abgesessener": "abgesessen",
    "abgesessenes": "abgesessen",
    "abgesetzt": "absetzen",
    "abgesetzte": "abgesetzt",
    "abgesetztem": "abgesetzt",
    "abgesetzten": "abgesetzt",
    "abgesetzter": "abgesetzt",
    "abgesetztes": "abgesetzt",
    "abgesichert": "absichern",
    "abgesicherte": "abgesichert",
    "abgesichertem": "abgesichert",
    "abgesicherten": "abgesichert",
    "abgesicherter": "abgesichert",
    "abgesichertere": "abgesichert",
    "abgesicherterem": "abgesichert",
    "abgesicherteren": "abgesichert",
    "abgesicherterer": "abgesichert",
    "abgesicherteres": "abgesichert",
    "abgesichertes": "abgesichert",
    "abgesicherteste": "abgesichert",
    "abgesichertestem": "abgesichert",
    "abgesichertesten": "abgesichert",
    "abgesichertester": "abgesichert",
    "abgesichertestes": "abgesichert",
    "abgesoffen": "absaufen",
    "abgesoffene": "abgesoffen",
    "abgesoffenem": "abgesoffen",
    "abgesoffenen": "abgesoffen",
    "abgesoffener": "abgesoffen",
    "abgesoffenere": "abgesoffen",
    "abgesoffenerem": "abgesoffen",
    "abgesoffeneren": "abgesoffen",
    "abgesoffenerer": "abgesoffen",
    "abgesoffeneres": "abgesoffen",
    "abgesoffenes": "abgesoffen",
    "abgesoffenste": "abgesoffen",
    "abgesoffenstem": "abgesoffen",
    "abgesoffensten": "abgesoffen",
    "abgesoffenster": "abgesoffen",
    "abgesoffenstes": "abgesoffen",
    "abgesogen": "absaugen",
    "abgesogene": "abgesogen",
    "abgesogenem": "abgesogen",
    "abgesogenen": "abgesogen",
    "abgesogener": "abgesogen",
    "abgesogenes": "abgesogen",
    "abgesondert": "absondern",
    "abgesonderte": "abgesondert",
    "abgesondertem": "abgesondert",
    "abgesonderten": "abgesondert",
    "abgesonderter": "abgesondert",
    "abgesondertes": "abgesondert",
    "abgespalten": "abspalten",
    "abgespaltene": "abgespalten",
    "abgespaltenem": "abgespalten",
    "abgespaltenen": "abgespalten",
    "abgespaltener": "abgespalten",
    "abgespaltenere": "abgespalten",
    "abgespaltenerem": "abgespalten",
    "abgespalteneren": "abgespalten",
    "abgespaltenerer": "abgespalten",
    "abgespalteneres": "abgespalten",
    "abgespaltenes": "abgespalten",
    "abgespaltenste": "abgespalten",
    "abgespaltenstem": "abgespalten",
    "abgespaltensten": "abgespalten",
    "abgespaltenster": "abgespalten",
    "abgespaltenstes": "abgespalten",
    "abgespannt": "abspannen",
    "abgespannte": "abgespannt",
    "abgespanntem": "abgespannt",
    "abgespannten": "abgespannt",
    "abgespannter": "abgespannt",
    "abgespanntes": "abgespannt",
    "abgespart": "absparen",
    "abgesparte": "abgespart",
    "abgespartem": "abgespart",
    "abgesparten": "abgespart",
    "abgesparter": "abgespart",
    "abgespartere": "abgespart",
    "abgesparterem": "abgespart",
    "abgesparteren": "abgespart",
    "abgesparterer": "abgespart",
    "abgesparteres": "abgespart",
    "abgespartes": "abgespart",
    "abgesparteste": "abgespart",
    "abgespartestem": "abgespart",
    "abgespartesten": "abgespart",
    "abgespartester": "abgespart",
    "abgespartestes": "abgespart",
    "abgespeichert": "abspeichern",
    "abgespeicherte": "abgespeichert",
    "abgespeichertem": "abgespeichert",
    "abgespeicherten": "abgespeichert",
    "abgespeicherter": "abgespeichert",
    "abgespeichertes": "abgespeichert",
    "abgespeist": "abspeisen",
    "abgespeiste": "abgespeist",
    "abgespeistem": "abgespeist",
    "abgespeisten": "abgespeist",
    "abgespeister": "abgespeist",
    "abgespeistes": "abgespeist",
    "abgesperrt": "absperren",
    "abgesperrte": "abgesperrt",
    "abgesperrtem": "abgesperrt",
    "abgesperrten": "abgesperrt",
    "abgesperrter": "abgesperrt",
    "abgesperrtes": "abgesperrt",
    "abgespiegelt": "abspiegeln",
    "abgespiegelte": "abgespiegelt",
    "abgespiegeltem": "abgespiegelt",
    "abgespiegelten": "abgespiegelt",
    "abgespiegelter": "abgespiegelt",
    "abgespiegeltes": "abgespiegelt",
    "abgespielt": "abspielen",
    "abgespielte": "abgespielt",
    "abgespieltem": "abgespielt",
    "abgespielten": "abgespielt",
    "abgespielter": "abgespielt",
    "abgespieltes": "abgespielt",
    "abgesplittert": "absplittern",
    "abgesplitterte": "abgesplittert",
    "abgesplittertem": "abgesplittert",
    "abgesplitterten": "abgesplittert",
    "abgesplitterter": "abgesplittert",
    "abgesplittertes": "abgesplittert",
    "abgespreizt": "abspreizen",
    "abgespreizte": "abgespreizt",
    "abgespreiztem": "abgespreizt",
    "abgespreizten": "abgespreizt",
    "abgespreizter": "abgespreizt",
    "abgespreiztes": "abgespreizt",
    "abgesprengt": "absprengen",
    "abgesprengte": "abgesprengt",
    "abgesprengtem": "abgesprengt",
    "abgesprengten": "abgesprengt",
    "abgesprengter": "abgesprengt",
    "abgesprengtes": "abgesprengt",
    "abgespritzt": "abspritzen",
    "abgespritzte": "abgespritzt",
    "abgespritztem": "abgespritzt",
    "abgespritzten": "abgespritzt",
    "abgespritzter": "abgespritzt",
    "abgespritztes": "abgespritzt",
    "abgesprochen": "absprechen",
    "abgesprochene": "abgesprochen",
    "abgesprochenem": "abgesprochen",
    "abgesprochenen": "abgesprochen",
    "abgesprochener": "abgesprochen",
    "abgesprochenes": "abgesprochen",
    "abgesprungen": "abspringen",
    "abgesprungene": "abgesprungen",
    "abgesprungenem": "abgesprungen",
    "abgesprungenen": "abgesprungen",
    "abgesprungener": "abgesprungen",
    "abgesprungenes": "abgesprungen",
    "abgesprüht": "absprühen",
    "abgesprühte": "abgesprüht",
    "abgesprühtem": "abgesprüht",
    "abgesprühten": "abgesprüht",
    "abgesprühter": "abgesprüht",
    "abgesprühtes": "abgesprüht",
    "abgespult": "abspulen",
    "abgespulte": "abgespult",
    "abgespultem": "abgespult",
    "abgespulten": "abgespult",
    "abgespulter": "abgespult",
    "abgespultes": "abgespult",
    "abgespült": "abspülen",
    "abgespültem": "abgespült",
    "abgespülter": "abgespült",
    "abgespültes": "abgespült",
    "abgestammt": "abstammen",
    "abgestammte": "abgestammt",
    "abgestammtem": "abgestammt",
    "abgestammten": "abgestammt",
    "abgestammter": "abgestammt",
    "abgestammtes": "abgestammt",
    "abgestanden": "abstehen",
    "abgestandene": "abgestanden",
    "abgestandenem": "abgestanden",
    "abgestandenen": "abgestanden",
    "abgestandener": "abgestanden",
    "abgestandenere": "abgestanden",
    "abgestandenerem": "abgestanden",
    "abgestandeneren": "abgestanden",
    "abgestandenerer": "abgestanden",
    "abgestandeneres": "abgestanden",
    "abgestandenes": "abgestanden",
    "abgestandenste": "abgestanden",
    "abgestandenstem": "abgestanden",
    "abgestandensten": "abgestanden",
    "abgestandenster": "abgestanden",
    "abgestandenstes": "abgestanden",
    "abgestattet": "abstatten",
    "abgestattete": "abgestattet",
    "abgestattetem": "abgestattet",
    "abgestatteten": "abgestattet",
    "abgestatteter": "abgestattet",
    "abgestattetes": "abgestattet",
    "abgestaubt": "abstauben",
    "abgestaubte": "abgestaubt",
    "abgestaubtem": "abgestaubt",
    "abgestaubten": "abgestaubt",
    "abgestaubter": "abgestaubt",
    "abgestaubtere": "abgestaubt",
    "abgestaubterem": "abgestaubt",
    "abgestaubteren": "abgestaubt",
    "abgestaubterer": "abgestaubt",
    "abgestaubteres": "abgestaubt",
    "abgestaubtes": "abgestaubt",
    "abgestaubteste": "abgestaubt",
    "abgestaubtestem": "abgestaubt",
    "abgestaubtesten": "abgestaubt",
    "abgestaubtester": "abgestaubt",
    "abgestaubtestes": "abgestaubt",
    "abgesteift": "absteifen",
    "abgesteifte": "abgesteift",
    "abgesteiftem": "abgesteift",
    "abgesteiften": "abgesteift",
    "abgesteifter": "abgesteift",
    "abgesteiftere": "abgesteift",
    "abgesteifterem": "abgesteift",
    "abgesteifteren": "abgesteift",
    "abgesteifterer": "abgesteift",
    "abgesteifteres": "abgesteift",
    "abgesteiftes": "abgesteift",
    "abgesteifteste": "abgesteift",
    "abgesteiftestem": "abgesteift",
    "abgesteiftesten": "abgesteift",
    "abgesteiftester": "abgesteift",
    "abgesteiftestes": "abgesteift",
    "abgestellt": "abstellen",
    "abgestellte": "abgestellt",
    "abgestelltem": "abgestellt",
    "abgestellten": "abgestellt",
    "abgestellter": "abgestellt",
    "abgestelltes": "abgestellt",
    "abgestempelt": "abstempeln",
    "abgestempelte": "abgestempelt",
    "abgestempeltem": "abgestempelt",
    "abgestempelten": "abgestempelt",
    "abgestempelter": "abgestempelt",
    "abgestempeltes": "abgestempelt",
    "abgesteppt": "absteppen",
    "abgesteppte": "abgesteppt",
    "abgestepptem": "abgesteppt",
    "abgesteppten": "abgesteppt",
    "abgesteppter": "abgesteppt",
    "abgestepptere": "abgesteppt",
    "abgesteppterem": "abgesteppt",
    "abgesteppteren": "abgesteppt",
    "abgesteppterer": "abgesteppt",
    "abgesteppteres": "abgesteppt",
    "abgestepptes": "abgesteppt",
    "abgesteppteste": "abgesteppt",
    "abgestepptestem": "abgesteppt",
    "abgestepptesten": "abgesteppt",
    "abgestepptester": "abgesteppt",
    "abgestepptestes": "abgesteppt",
    "abgestiegen": "absteigen",
    "abgestiegene": "abgestiegen",
    "abgestiegenem": "abgestiegen",
    "abgestiegenen": "abgestiegen",
    "abgestiegener": "abgestiegen",
    "abgestiegenes": "abgestiegen",
    "abgestielt": "abstielen",
    "abgestielte": "abgestielt",
    "abgestieltem": "abgestielt",
    "abgestielten": "abgestielt",
    "abgestielter": "abgestielt",
    "abgestieltes": "abgestielt",
    "abgestillt": "abstillen",
    "abgestillte": "abgestillt",
    "abgestilltem": "abgestillt",
    "abgestillten": "abgestillt",
    "abgestillter": "abgestillt",
    "abgestilltes": "abgestillt",
    "abgestimmt": "abstimmen",
    "abgestimmte": "abgestimmt",
    "abgestimmtem": "abgestimmt",
    "abgestimmten": "abgestimmt",
    "abgestimmter": "abgestimmt",
    "abgestimmtes": "abgestimmt",
    "abgestochen": "abstechen",
    "abgestochene": "abgestochen",
    "abgestochenem": "abgestochen",
    "abgestochenen": "abgestochen",
    "abgestochener": "abgestochen",
    "abgestochenes": "abgestochen",
    "abgestoppt": "abstoppen",
    "abgestoppte": "abgestoppt",
    "abgestopptem": "abgestoppt",
    "abgestoppten": "abgestoppt",
    "abgestoppter": "abgestoppt",
    "abgestopptes": "abgestoppt",
    "abgestorben": "absterben",
    "abgestorbene": "abgestorben",
    "abgestorbenem": "abgestorben",
    "abgestorbenen": "abgestorben",
    "abgestorbener": "abgestorben",
    "abgestorbenere": "abgestorben",
    "abgestorbenerem": "abgestorben",
    "abgestorbeneren": "abgestorben",
    "abgestorbenerer": "abgestorben",
    "abgestorbeneres": "abgestorben",
    "abgestorbenes": "abgestorben",
    "abgestorbenste": "abgestorben",
    "abgestorbenstem": "abgestorben",
    "abgestorbensten": "abgestorben",
    "abgestorbenster": "abgestorben",
    "abgestorbenstes": "abgestorben",
    "abgestottert": "abstottern",
    "abgestotterte": "abgestottert",
    "abgestottertem": "abgestottert",
    "abgestotterten": "abgestottert",
    "abgestotterter": "abgestottert",
    "abgestottertes": "abgestottert",
    "abgestoßen": "abstoßen",
    "abgestoßene": "abgestoßen",
    "abgestoßenem": "abgestoßen",
    "abgestoßenen": "abgestoßen",
    "abgestoßener": "abgestoßen",
    "abgestoßenes": "abgestoßen",
    "abgestraft": "abstrafen",
    "abgestrafte": "abgestraft",
    "abgestraftem": "abgestraft",
    "abgestraften": "abgestraft",
    "abgestrafter": "abgestraft",
    "abgestraftes": "abgestraft",
    "abgestrahlt": "abstrahlen",
    "abgestrahlte": "abgestrahlt",
    "abgestrahltem": "abgestrahlt",
    "abgestrahlten": "abgestrahlt",
    "abgestrahlter": "abgestrahlt",
    "abgestrahltes": "abgestrahlt",
    "abgestrampelt": "abstrampeln",
    "abgestrampelte": "abgestrampelt",
    "abgestrampeltem": "abgestrampelt",
    "abgestrampelten": "abgestrampelt",
    "abgestrampelter": "abgestrampelt",
    "abgestrampeltes": "abgestrampelt",
    "abgestrebt": "abstreben",
    "abgestrebte": "abgestrebt",
    "abgestrebtem": "abgestrebt",
    "abgestrebten": "abgestrebt",
    "abgestrebter": "abgestrebt",
    "abgestrebtes": "abgestrebt",
    "abgestreift": "abstreifen",
    "abgestreifte": "abgestreift",
    "abgestreiftem": "abgestreift",
    "abgestreiften": "abgestreift",
    "abgestreifter": "abgestreift",
    "abgestreiftes": "abgestreift",
    "abgestrichen": "abstreichen",
    "abgestrichene": "abgestrichen",
    "abgestrichenem": "abgestrichen",
    "abgestrichenen": "abgestrichen",
    "abgestrichener": "abgestrichen",
    "abgestrichenes": "abgestrichen",
    "abgestritten": "abstreiten",
    "abgestrittene": "abgestritten",
    "abgestrittenem": "abgestritten",
    "abgestrittenen": "abgestritten",
    "abgestrittener": "abgestritten",
    "abgestrittenes": "abgestritten",
    "abgeströmt": "abströmen",
    "abgeströmte": "abgeströmt",
    "abgeströmtem": "abgeströmt",
    "abgeströmten": "abgeströmt",
    "abgeströmter": "abgeströmt",
    "abgeströmtes": "abgeströmt",
    "abgestuft": "abstufen",
    "abgestufte": "abgestuft",
    "abgestuftem": "abgestuft",
    "abgestuften": "abgestuft",
    "abgestufter": "abgestuft",
    "abgestuftes": "abgestuft",
    "abgestumpft": "abstumpfen",
    "abgestumpfte": "abgestumpft",
    "abgestumpftem": "abgestumpft",
    "abgestumpften": "abgestumpft",
    "abgestumpfter": "abgestumpft",
    "abgestumpftere": "abgestumpft",
    "abgestumpfterem": "abgestumpft",
    "abgestumpfteren": "abgestumpft",
    "abgestumpfterer": "abgestumpft",
    "abgestumpfteres": "abgestumpft",
    "abgestumpftes": "abgestumpft",
    "abgestumpfteste": "abgestumpft",
    "abgestumpftestem": "abgestumpft",
    "abgestumpftesten": "abgestumpft",
    "abgestumpftester": "abgestumpft",
    "abgestumpftestes": "abgestumpft",
    "abgestürzt": "abstürzen",
    "abgestürzte": "abgestürzt",
    "abgestürztem": "abgestürzt",
    "abgestürzten": "abgestürzt",
    "abgestürzter": "abgestürzt",
    "abgestürztere": "abgestürzt",
    "abgestürzterem": "abgestürzt",
    "abgestürzteren": "abgestürzt",
    "abgestürzterer": "abgestürzt",
    "abgestürzteres": "abgestürzt",
    "abgestürztes": "abgestürzt",
    "abgestürzteste": "abgestürzt",
    "abgestürztestem": "abgestürzt",
    "abgestürztesten": "abgestürzt",
    "abgestürztester": "abgestürzt",
    "abgestürztestes": "abgestürzt",
    "abgestützt": "abstützen",
    "abgestützte": "abgestützt",
    "abgestütztem": "abgestützt",
    "abgestützten": "abgestützt",
    "abgestützter": "abgestützt",
    "abgestütztes": "abgestützt",
    "abgesucht": "absuchen",
    "abgesuchte": "abgesucht",
    "abgesuchtem": "abgesucht",
    "abgesuchten": "abgesucht",
    "abgesuchter": "abgesucht",
    "abgesuchtere": "abgesucht",
    "abgesuchterem": "abgesucht",
    "abgesuchteren": "abgesucht",
    "abgesuchterer": "abgesucht",
    "abgesuchteres": "abgesucht",
    "abgesuchtes": "abgesucht",
    "abgesuchteste": "abgesucht",
    "abgesuchtestem": "abgesucht",
    "abgesuchtesten": "abgesucht",
    "abgesuchtester": "abgesucht",
    "abgesuchtestes": "abgesucht",
    "abgesungen": "absingen",
    "abgesungene": "abgesungen",
    "abgesungenem": "abgesungen",
    "abgesungenen": "abgesungen",
    "abgesungener": "abgesungen",
    "abgesungenes": "abgesungen",
    "abgesäbelt": "absäbeln",
    "abgesäbelte": "abgesäbelt",
    "abgesäbeltem": "abgesäbelt",
    "abgesäbelten": "abgesäbelt",
    "abgesäbelter": "abgesäbelt",
    "abgesäbeltes": "abgesäbelt",
    "abgesägt": "absägen",
    "abgesägtem": "abgesägt",
    "abgesägter": "abgesägt",
    "abgesägtes": "abgesägt",
    "abgetakelt": "abtakeln",
    "abgetakelte": "abgetakelt",
    "abgetakeltem": "abgetakelt",
    "abgetakelten": "abgetakelt",
    "abgetakelter": "abgetakelt",
    "abgetakeltes": "abgetakelt",
    "abgetankt": "abtanken",
    "abgetankte": "abgetankt",
    "abgetanktem": "abgetankt",
    "abgetankten": "abgetankt",
    "abgetankter": "abgetankt",
    "abgetanktes": "abgetankt",
    "abgetanzt": "abtanzen",
    "abgetanzte": "abgetanzt",
    "abgetanztem": "abgetanzt",
    "abgetanzten": "abgetanzt",
    "abgetanzter": "abgetanzt",
    "abgetanztere": "abgetanzt",
    "abgetanzterem": "abgetanzt",
    "abgetanzteren": "abgetanzt",
    "abgetanzterer": "abgetanzt",
    "abgetanzteres": "abgetanzt",
    "abgetanztes": "abgetanzt",
    "abgetanzteste": "abgetanzt",
    "abgetanztestem": "abgetanzt",
    "abgetanztesten": "abgetanzt",
    "abgetanztester": "abgetanzt",
    "abgetanztestes": "abgetanzt",
    "abgetastet": "abtasten",
    "abgetastete": "abgetastet",
    "abgetastetem": "abgetastet",
    "abgetasteten": "abgetastet",
    "abgetasteter": "abgetastet",
    "abgetastetes": "abgetastet",
    "abgetaucht": "abtauchen",
    "abgetauchte": "abgetaucht",
    "abgetauchtem": "abgetaucht",
    "abgetauchten": "abgetaucht",
    "abgetauchter": "abgetaucht",
    "abgetauchtes": "abgetaucht",
    "abgetaut": "abtauen",
    "abgetaute": "abgetaut",
    "abgetautem": "abgetaut",
    "abgetauten": "abgetaut",
    "abgetauter": "abgetaut",
    "abgetautes": "abgetaut",
    "abgeteilt": "abteilen",
    "abgeteilte": "abgeteilt",
    "abgeteiltem": "abgeteilt",
    "abgeteilten": "abgeteilt",
    "abgeteilter": "abgeteilt",
    "abgeteiltes": "abgeteilt",
    "abgetippt": "abtippen",
    "abgetippte": "abgetippt",
    "abgetipptem": "abgetippt",
    "abgetippten": "abgetippt",
    "abgetippter": "abgetippt",
    "abgetipptes": "abgetippt",
    "abgetragen": "abtragen",
    "abgetragene": "abgetragen",
    "abgetragenem": "abgetragen",
    "abgetragenen": "abgetragen",
    "abgetragener": "abgetragen",
    "abgetragenere": "abgetragen",
    "abgetragenerem": "abgetragen",
    "abgetrageneren": "abgetragen",
    "abgetragenerer": "abgetragen",
    "abgetrageneres": "abgetragen",
    "abgetragenes": "abgetragen",
    "abgetragenste": "abgetragen",
    "abgetragenstem": "abgetragen",
    "abgetragensten": "abgetragen",
    "abgetragenster": "abgetragen",
    "abgetragenstes": "abgetragen",
    "abgetrennt": "abtrennen",
    "abgetrennte": "abgetrennt",
    "abgetrenntem": "abgetrennt",
    "abgetrennten": "abgetrennt",
    "abgetrennter": "abgetrennt",
    "abgetrenntes": "abgetrennt",
    "abgetreten": "abtreten",
    "abgetretene": "abgetreten",
    "abgetretenem": "abgetreten",
    "abgetretenen": "abgetreten",
    "abgetretener": "abgetreten",
    "abgetretenes": "abgetreten",
    "abgetrieben": "abtreiben",
    "abgetriebene": "abgetrieben",
    "abgetriebenem": "abgetrieben",
    "abgetriebenen": "abgetrieben",
    "abgetriebener": "abgetrieben",
    "abgetriebenes": "abgetrieben",
    "abgetrocknet": "abtrocknen",
    "abgetrocknete": "abgetrocknet",
    "abgetrocknetem": "abgetrocknet",
    "abgetrockneten": "abgetrocknet",
    "abgetrockneter": "abgetrocknet",
    "abgetrocknetere": "abgetrocknet",
    "abgetrockneterem": "abgetrocknet",
    "abgetrockneteren": "abgetrocknet",
    "abgetrockneterer": "abgetrocknet",
    "abgetrockneteres": "abgetrocknet",
    "abgetrocknetes": "abgetrocknet",
    "abgetrockneteste": "abgetrocknet",
    "abgetrocknetestem": "abgetrocknet",
    "abgetrocknetesten": "abgetrocknet",
    "abgetrocknetester": "abgetrocknet",
    "abgetrocknetestes": "abgetrocknet",
    "abgetropft": "abtropfen",
    "abgetropfte": "abgetropft",
    "abgetropftem": "abgetropft",
    "abgetropften": "abgetropft",
    "abgetropfter": "abgetropft",
    "abgetropftes": "abgetropft",
    "abgetrotzt": "abtrotzen",
    "abgetrotzte": "abgetrotzt",
    "abgetrotztem": "abgetrotzt",
    "abgetrotzten": "abgetrotzt",
    "abgetrotzter": "abgetrotzt",
    "abgetrotztes": "abgetrotzt",
    "abgetrudelt": "abtrudeln",
    "abgetrudelte": "abgetrudelt",
    "abgetrudeltem": "abgetrudelt",
    "abgetrudelten": "abgetrudelt",
    "abgetrudelter": "abgetrudelt",
    "abgetrudeltes": "abgetrudelt",
    "abgetrunken": "abtrinken",
    "abgetrunkene": "abgetrunken",
    "abgetrunkenem": "abgetrunken",
    "abgetrunkenen": "abgetrunken",
    "abgetrunkener": "abgetrunken",
    "abgetrunkenes": "abgetrunken",
    "abgeträufelt": "abträufeln",
    "abgeträufelte": "abgeträufelt",
    "abgeträufeltem": "abgeträufelt",
    "abgeträufelten": "abgeträufelt",
    "abgeträufelter": "abgeträufelt",
    "abgeträufeltes": "abgeträufelt",
    "abgetupft": "abtupfen",
    "abgetupfte": "abgetupft",
    "abgetupftem": "abgetupft",
    "abgetupften": "abgetupft",
    "abgetupfter": "abgetupft",
    "abgetupftes": "abgetupft",
    "abgetönt": "abtönen",
    "abgetönte": "abgetönt",
    "abgetöntem": "abgetönt",
    "abgetönten": "abgetönt",
    "abgetönter": "abgetönt",
    "abgetöntes": "abgetönt",
    "abgetötet": "abtöten",
    "abgetötete": "abgetötet",
    "abgetötetem": "abgetötet",
    "abgetöteten": "abgetötet",
    "abgetöteter": "abgetötet",
    "abgetötetes": "abgetötet",
    "abgeurteilt": "aburteilen",
    "abgeurteilte": "abgeurteilt",
    "abgeurteiltem": "abgeurteilt",
    "abgeurteilten": "abgeurteilt",
    "abgeurteilter": "abgeurteilt",
    "abgeurteiltes": "abgeurteilt",
    "abgewandelt": "abwandeln",
    "abgewandelte": "abgewandelt",
    "abgewandeltem": "abgewandelt",
    "abgewandelten": "abgewandelt",
    "abgewandelter": "abgewandelt",
    "abgewandeltere": "abgewandelt",
    "abgewandelterem": "abgewandelt",
    "abgewandelteren": "abgewandelt",
    "abgewandelterer": "abgewandelt",
    "abgewandelteres": "abgewandelt",
    "abgewandeltes": "abgewandelt",
    "abgewandelteste": "abgewandelt",
    "abgewandeltestem": "abgewandelt",
    "abgewandeltesten": "abgewandelt",
    "abgewandeltester": "abgewandelt",
    "abgewandeltestes": "abgewandelt",
    "abgewandert": "abwandern",
    "abgewanderte": "abgewandert",
    "abgewandertem": "abgewandert",
    "abgewanderten": "abgewandert",
    "abgewanderter": "abgewandert",
    "abgewandertes": "abgewandert",
    "abgewandt": "abwenden",
    "abgewann": "abgewinnen",
    "abgewannen": "abgewinnen",
    "abgewannst": "abgewinnen",
    "abgewannt": "abgewinnen",
    "abgewartet": "abwarten",
    "abgewartete": "abgewartet",
    "abgewartetem": "abgewartet",
    "abgewarteten": "abgewartet",
    "abgewarteter": "abgewartet",
    "abgewartetes": "abgewartet",
    "abgewaschen": "abwaschen",
    "abgewaschene": "abgewaschen",
    "abgewaschenem": "abgewaschen",
    "abgewaschenen": "abgewaschen",
    "abgewaschener": "abgewaschen",
    "abgewaschenere": "abgewaschen",
    "abgewaschenerem": "abgewaschen",
    "abgewascheneren": "abgewaschen",
    "abgewaschenerer": "abgewaschen",
    "abgewascheneres": "abgewaschen",
    "abgewaschenes": "abgewaschen",
    "abgewaschenste": "abgewaschen",
    "abgewaschenstem": "abgewaschen",
    "abgewaschensten": "abgewaschen",
    "abgewaschenster": "abgewaschen",
    "abgewaschenstes": "abgewaschen",
    "abgewechselt": "abwechseln",
    "abgewechselte": "abgewechselt",
    "abgewechseltem": "abgewechselt",
    "abgewechselten": "abgewechselt",
    "abgewechselter": "abgewechselt",
    "abgewechseltes": "abgewechselt",
    "abgewehrt": "abwehren",
    "abgewehrte": "abgewehrt",
    "abgewehrtem": "abgewehrt",
    "abgewehrten": "abgewehrt",
    "abgewehrter": "abgewehrt",
    "abgewehrtes": "abgewehrt",
    "abgeweicht": "abweichen",
    "abgeweichte": "abgeweicht",
    "abgeweichtem": "abgeweicht",
    "abgeweichten": "abgeweicht",
    "abgeweichter": "abgeweicht",
    "abgeweichtere": "abgeweicht",
    "abgeweichterem": "abgeweicht",
    "abgeweichteren": "abgeweicht",
    "abgeweichterer": "abgeweicht",
    "abgeweichteres": "abgeweicht",
    "abgeweichtes": "abgeweicht",
    "abgeweichteste": "abgeweicht",
    "abgeweichtestem": "abgeweicht",
    "abgeweichtesten": "abgeweicht",
    "abgeweichtester": "abgeweicht",
    "abgeweichtestes": "abgeweicht",
    "abgeweidet": "abweiden",
    "abgeweidete": "abgeweidet",
    "abgeweidetem": "abgeweidet",
    "abgeweideten": "abgeweidet",
    "abgeweideter": "abgeweidet",
    "abgeweidetere": "abgeweidet",
    "abgeweideterem": "abgeweidet",
    "abgeweideteren": "abgeweidet",
    "abgeweideterer": "abgeweidet",
    "abgeweideteres": "abgeweidet",
    "abgeweidetes": "abgeweidet",
    "abgeweideteste": "abgeweidet",
    "abgeweidetestem": "abgeweidet",
    "abgeweidetesten": "abgeweidet",
    "abgeweidetester": "abgeweidet",
    "abgeweidetestes": "abgeweidet",
    "abgewendet": "abwenden",
    "abgewendete": "abgewendet",
    "abgewendetem": "abgewendet",
    "abgewendeten": "abgewendet",
    "abgewendeter": "abgewendet",
    "abgewendetes": "abgewendet",
    "abgewertet": "abwerten",
    "abgewertete": "abgewertet",
    "abgewertetem": "abgewertet",
    "abgewerteten": "abgewertet",
    "abgewerteter": "abgewertet",
    "abgewertetes": "abgewertet",
    "abgewetzt": "abwetzen",
    "abgewetzte": "abgewetzt",
    "abgewetztem": "abgewetzt",
    "abgewetzten": "abgewetzt",
    "abgewetzter": "abgewetzt",
    "abgewetztere": "abgewetzt",
    "abgewetzterem": "abgewetzt",
    "abgewetzteren": "abgewetzt",
    "abgewetzterer": "abgewetzt",
    "abgewetzteres": "abgewetzt",
    "abgewetztes": "abgewetzt",
    "abgewetzteste": "abgewetzt",
    "abgewetztestem": "abgewetzt",
    "abgewetztesten": "abgewetzt",
    "abgewetztester": "abgewetzt",
    "abgewetztestes": "abgewetzt",
    "abgewichen": "abweichen",
    "abgewichene": "abgewichen",
    "abgewichenem": "abgewichen",
    "abgewichenen": "abgewichen",
    "abgewichener": "abgewichen",
    "abgewichenere": "abgewichen",
    "abgewichenerem": "abgewichen",
    "abgewicheneren": "abgewichen",
    "abgewichenerer": "abgewichen",
    "abgewicheneres": "abgewichen",
    "abgewichenes": "abgewichen",
    "abgewichenste": "abgewichen",
    "abgewichenstem": "abgewichen",
    "abgewichensten": "abgewichen",
    "abgewichenster": "abgewichen",
    "abgewichenstes": "abgewichen",
    "abgewickelt": "abwickeln",
    "abgewickelte": "abgewickelt",
    "abgewickeltem": "abgewickelt",
    "abgewickelten": "abgewickelt",
    "abgewickelter": "abgewickelt",
    "abgewickeltere": "abgewickelt",
    "abgewickelterem": "abgewickelt",
    "abgewickelteren": "abgewickelt",
    "abgewickelterer": "abgewickelt",
    "abgewickelteres": "abgewickelt",
    "abgewickeltes": "abgewickelt",
    "abgewickelteste": "abgewickelt",
    "abgewickeltestem": "abgewickelt",
    "abgewickeltesten": "abgewickelt",
    "abgewickeltester": "abgewickelt",
    "abgewickeltestes": "abgewickelt",
    "abgewiesen": "abweisen",
    "abgewiesene": "abgewiesen",
    "abgewiesenem": "abgewiesen",
    "abgewiesenen": "abgewiesen",
    "abgewiesener": "abgewiesen",
    "abgewiesenes": "abgewiesen",
    "abgewimmelt": "abwimmeln",
    "abgewimmelte": "abgewimmelt",
    "abgewimmeltem": "abgewimmelt",
    "abgewimmelten": "abgewimmelt",
    "abgewimmelter": "abgewimmelt",
    "abgewimmeltes": "abgewimmelt",
    "abgewinkt": "abwinken",
    "abgewinkte": "abgewinkt",
    "abgewinktem": "abgewinkt",
    "abgewinkten": "abgewinkt",
    "abgewinkter": "abgewinkt",
    "abgewinktes": "abgewinkt",
    "abgewinne": "abgewinnen",
    "abgewinnend": "abgewinnen",
    "abgewinnende": "abgewinnend",
    "abgewinnendem": "abgewinnend",
    "abgewinnenden": "abgewinnend",
    "abgewinnender": "abgewinnend",
    "abgewinnendere": "abgewinnend",
    "abgewinnenderem": "abgewinnend",
    "abgewinnenderen": "abgewinnend",
    "abgewinnenderer": "abgewinnend",
    "abgewinnenderes": "abgewinnend",
    "abgewinnendes": "abgewinnend",
    "abgewinnendste": "abgewinnend",
    "abgewinnendstem": "abgewinnend",
    "abgewinnendsten": "abgewinnend",
    "abgewinnendster": "abgewinnend",
    "abgewinnendstes": "abgewinnend",
    "abgewinnest": "abgewinnen",
    "abgewinnet": "abgewinnen",
    "abgewinnst": "abgewinnen",
    "abgewinnt": "abgewinnen",
    "abgewirtschaftet": "abwirtschaften",
    "abgewirtschaftete": "abgewirtschaftet",
    "abgewirtschaftetem": "abgewirtschaftet",
    "abgewirtschafteten": "abgewirtschaftet",
    "abgewirtschafteter": "abgewirtschaftet",
    "abgewirtschaftetere": "abgewirtschaftet",
    "abgewirtschafteterem": "abgewirtschaftet",
    "abgewirtschafteteren": "abgewirtschaftet",
    "abgewirtschafteterer": "abgewirtschaftet",
    "abgewirtschafteteres": "abgewirtschaftet",
    "abgewirtschaftetes": "abgewirtschaftet",
    "abgewirtschafteteste": "abgewirtschaftet",
    "abgewirtschaftetestem": "abgewirtschaftet",
    "abgewirtschaftetesten": "abgewirtschaftet",
    "abgewirtschaftetester": "abgewirtschaftet",
    "abgewirtschaftetestes": "abgewirtschaftet",
    "abgewischt": "abwischen",
    "abgewischte": "abgewischt",
    "abgewischtem": "abgewischt",
    "abgewischten": "abgewischt",
    "abgewischter": "abgewischt",
    "abgewischtes": "abgewischt",
    "abgewogen": "abwiegen",
    "abgewogene": "abgewogen",
    "abgewogenem": "abgewogen",
    "abgewogenen": "abgewogen",
    "abgewogener": "abgewogen",
    "abgewogenes": "abgewogen",
    "abgewohnt": "abwohnen",
    "abgewohnte": "abgewohnt",
    "abgewohntem": "abgewohnt",
    "abgewohnten": "abgewohnt",
    "abgewohnter": "abgewohnt",
    "abgewohntere": "abgewohnt",
    "abgewohnterem": "abgewohnt",
    "abgewohnteren": "abgewohnt",
    "abgewohnterer": "abgewohnt",
    "abgewohnteres": "abgewohnt",
    "abgewohntes": "abgewohnt",
    "abgewohnteste": "abgewohnt",
    "abgewohntestem": "abgewohnt",
    "abgewohntesten": "abgewohnt",
    "abgewohntester": "abgewohnt",
    "abgewohntestes": "abgewohnt",
    "abgewonnen": "abgewinnen",
    "abgewonnene": "abgewonnen",
    "abgewonnenem": "abgewonnen",
    "abgewonnenen": "abgewonnen",
    "abgewonnener": "abgewonnen",
    "abgewonnenere": "abgewonnen",
    "abgewonnenerem": "abgewonnen",
    "abgewonneneren": "abgewonnen",
    "abgewonnenerer": "abgewonnen",
    "abgewonneneres": "abgewonnen",
    "abgewonnenes": "abgewonnen",
    "abgewonnenste": "abgewonnen",
    "abgewonnenstem": "abgewonnen",
    "abgewonnensten": "abgewonnen",
    "abgewonnenster": "abgewonnen",
    "abgewonnenstes": "abgewonnen",
    "abgeworben": "abwerben",
    "abgeworbene": "abgeworben",
    "abgeworbenem": "abgeworben",
    "abgeworbenen": "abgeworben",
    "abgeworbener": "abgeworben",
    "abgeworbenes": "abgeworben",
    "abgeworfen": "abwerfen",
    "abgeworfene": "abgeworfen",
    "abgeworfenem": "abgeworfen",
    "abgeworfenen": "abgeworfen",
    "abgeworfener": "abgeworfen",
    "abgeworfenes": "abgeworfen",
    "abgewrackte": "abgewrackt",
    "abgewracktem": "abgewrackt",
    "abgewrackten": "abgewrackt",
    "abgewrackter": "abgewrackt",
    "abgewracktere": "abgewrackt",
    "abgewrackterem": "abgewrackt",
    "abgewrackteren": "abgewrackt",
    "abgewrackterer": "abgewrackt",
    "abgewrackteres": "abgewrackt",
    "abgewracktes": "abgewrackt",
    "abgewrackteste": "abgewrackt",
    "abgewracktestem": "abgewrackt",
    "abgewracktesten": "abgewrackt",
    "abgewracktester": "abgewrackt",
    "abgewracktestes": "abgewrackt",
    "abgewunden": "abwinden",
    "abgewundene": "abgewunden",
    "abgewundenem": "abgewunden",
    "abgewundenen": "abgewunden",
    "abgewundener": "abgewunden",
    "abgewundenes": "abgewunden",
    "abgewählt": "abwählen",
    "abgewählte": "abgewählt",
    "abgewähltem": "abgewählt",
    "abgewählten": "abgewählt",
    "abgewählter": "abgewählt",
    "abgewähltes": "abgewählt",
    "abgewälzt": "abwälzen",
    "abgewälzte": "abgewälzt",
    "abgewälztem": "abgewälzt",
    "abgewälzten": "abgewälzt",
    "abgewälzter": "abgewälzt",
    "abgewälztere": "abgewälzt",
    "abgewälzterem": "abgewälzt",
    "abgewälzteren": "abgewälzt",
    "abgewälzterer": "abgewälzt",
    "abgewälzteres": "abgewälzt",
    "abgewälztes": "abgewälzt",
    "abgewälzteste": "abgewälzt",
    "abgewälztestem": "abgewälzt",
    "abgewälztesten": "abgewälzt",
    "abgewälztester": "abgewälzt",
    "abgewälztestes": "abgewälzt",
    "abgewänne": "abgewinnen",
    "abgewännen": "abgewinnen",
    "abgewännest": "abgewinnen",
    "abgewännet": "abgewinnen",
    "abgewöhne": "abgewöhnen",
    "abgewöhnend": "abgewöhnen",
    "abgewöhnende": "abgewöhnend",
    "abgewöhnendem": "abgewöhnend",
    "abgewöhnenden": "abgewöhnend",
    "abgewöhnender": "abgewöhnend",
    "abgewöhnendes": "abgewöhnend",
    "abgewöhnest": "abgewöhnen",
    "abgewöhnet": "abgewöhnen",
    "abgewöhnst": "abgewöhnen",
    "abgewöhnt": "abgewöhnen",
    "abgewöhnte": "abgewöhnt",
    "abgewöhntem": "abgewöhnt",
    "abgewöhnten": "abgewöhnt",
    "abgewöhnter": "abgewöhnt",
    "abgewöhntes": "abgewöhnt",
    "abgewöhntest": "abgewöhnen",
    "abgewöhntet": "abgewöhnen",
    "abgewürgt": "abwürgen",
    "abgewürgte": "abgewürgt",
    "abgewürgtem": "abgewürgt",
    "abgewürgten": "abgewürgt",
    "abgewürgter": "abgewürgt",
    "abgewürgtere": "abgewürgt",
    "abgewürgterem": "abgewürgt",
    "abgewürgteren": "abgewürgt",
    "abgewürgterer": "abgewürgt",
    "abgewürgteres": "abgewürgt",
    "abgewürgtes": "abgewürgt",
    "abgewürgteste": "abgewürgt",
    "abgewürgtestem": "abgewürgt",
    "abgewürgtesten": "abgewürgt",
    "abgewürgtester": "abgewürgt",
    "abgewürgtestes": "abgewürgt",
    "abgezahlt": "abzahlen",
    "abgezahlte": "abgezahlt",
    "abgezahltem": "abgezahlt",
    "abgezahlten": "abgezahlt",
    "abgezahlter": "abgezahlt",
    "abgezahltes": "abgezahlt",
    "abgezapft": "abzapfen",
    "abgezapfte": "abgezapft",
    "abgezapftem": "abgezapft",
    "abgezapften": "abgezapft",
    "abgezapfter": "abgezapft",
    "abgezapftes": "abgezapft",
    "abgezappelt": "abzappeln",
    "abgezappelte": "abgezappelt",
    "abgezappeltem": "abgezappelt",
    "abgezappelten": "abgezappelt",
    "abgezappelter": "abgezappelt",
    "abgezappeltere": "abgezappelt",
    "abgezappelterem": "abgezappelt",
    "abgezappelteren": "abgezappelt",
    "abgezappelterer": "abgezappelt",
    "abgezappelteres": "abgezappelt",
    "abgezappeltes": "abgezappelt",
    "abgezappelteste": "abgezappelt",
    "abgezappeltestem": "abgezappelt",
    "abgezappeltesten": "abgezappelt",
    "abgezappeltester": "abgezappelt",
    "abgezappeltestes": "abgezappelt",
    "abgezeichnet": "abzeichnen",
    "abgezeichnete": "abgezeichnet",
    "abgezeichnetem": "abgezeichnet",
    "abgezeichneten": "abgezeichnet",
    "abgezeichneter": "abgezeichnet",
    "abgezeichnetes": "abgezeichnet",
    "abgezielt": "abzielen",
    "abgezielte": "abgezielt",
    "abgezieltem": "abgezielt",
    "abgezielten": "abgezielt",
    "abgezielter": "abgezielt",
    "abgezieltes": "abgezielt",
    "abgezirkelt": "abzirkeln",
    "abgezirkelte": "abgezirkelt",
    "abgezirkeltem": "abgezirkelt",
    "abgezirkelten": "abgezirkelt",
    "abgezirkelter": "abgezirkelt",
    "abgezirkeltes": "abgezirkelt",
    "abgezischt": "abzischen",
    "abgezischte": "abgezischt",
    "abgezischtem": "abgezischt",
    "abgezischten": "abgezischt",
    "abgezischter": "abgezischt",
    "abgezischtes": "abgezischt",
    "abgezittert": "abzittern",
    "abgezitterte": "abgezittert",
    "abgezittertem": "abgezittert",
    "abgezitterten": "abgezittert",
    "abgezitterter": "abgezittert",
    "abgezittertes": "abgezittert",
    "abgezogen": "abziehen",
    "abgezogene": "abgezogen",
    "abgezogenem": "abgezogen",
    "abgezogenen": "abgezogen",
    "abgezogener": "abgezogen",
    "abgezogenes": "abgezogen",
    "abgezupft": "abzupfen",
    "abgezupfte": "abgezupft",
    "abgezupftem": "abgezupft",
    "abgezupften": "abgezupft",
    "abgezupfter": "abgezupft",
    "abgezupftes": "abgezupft",
    "abgezweigt": "abzweigen",
    "abgezweigte": "abgezweigt",
    "abgezweigtem": "abgezweigt",
    "abgezweigten": "abgezweigt",
    "abgezweigter": "abgezweigt",
    "abgezweigtes": "abgezweigt",
    "abgezwitschert": "abzwitschern",
    "abgezwitscherte": "abgezwitschert",
    "abgezwitschertem": "abgezwitschert",
    "abgezwitscherten": "abgezwitschert",
    "abgezwitscherter": "abgezwitschert",
    "abgezwitschertes": "abgezwitschert",
    "abgezwungen": "abzwingen",
    "abgezwungene": "abgezwungen",
    "abgezwungenem": "abgezwungen",
    "abgezwungenen": "abgezwungen",
    "abgezwungener": "abgezwungen",
    "abgezwungenes": "abgezwungen",
    "abgezählt": "abzählen",
    "abgezähltem": "abgezählt",
    "abgezählter": "abgezählt",
    "abgezähltere": "abgezählt",
    "abgezählterem": "abgezählt",
    "abgezählteren": "abgezählt",
    "abgezählterer": "abgezählt",
    "abgezählteres": "abgezählt",
    "abgezähltes": "abgezählt",
    "abgezählteste": "abgezählt",
    "abgezähltestem": "abgezählt",
    "abgezähltesten": "abgezählt",
    "abgezähltester": "abgezählt",
    "abgezähltestes": "abgezählt",
    "abgezäumt": "abzäumen",
    "abgezäumte": "abgezäumt",
    "abgezäumtem": "abgezäumt",
    "abgezäumten": "abgezäumt",
    "abgezäumter": "abgezäumt",
    "abgezäumtere": "abgezäumt",
    "abgezäumterem": "abgezäumt",
    "abgezäumteren": "abgezäumt",
    "abgezäumterer": "abgezäumt",
    "abgezäumteres": "abgezäumt",
    "abgezäumtes": "abgezäumt",
    "abgezäumteste": "abgezäumt",
    "abgezäumtestem": "abgezäumt",
    "abgezäumtesten": "abgezäumt",
    "abgezäumtester": "abgezäumt",
    "abgezäumtestes": "abgezäumt",
    "abgezäunt": "abzäunen",
    "abgezäunte": "abgezäunt",
    "abgezäuntem": "abgezäunt",
    "abgezäunten": "abgezäunt",
    "abgezäunter": "abgezäunt",
    "abgezäuntes": "abgezäunt",
    "abgeändert": "abändern",
    "abgeänderte": "abgeändert",
    "abgeändertem": "abgeändert",
    "abgeänderten": "abgeändert",
    "abgeänderter": "abgeändert",
    "abgeändertere": "abgeändert",
    "abgeänderterem": "abgeändert",
    "abgeänderteren": "abgeändert",
    "abgeänderterer": "abgeändert",
    "abgeänderteres": "abgeändert",
    "abgeändertes": "abgeändert",
    "abgeänderteste": "abgeändert",
    "abgeändertestem": "abgeändert",
    "abgeändertesten": "abgeändert",
    "abgeändertester": "abgeändert",
    "abgeändertestes": "abgeändert",
    "abgeästet": "abästen",
    "abgeästete": "abgeästet",
    "abgeästetem": "abgeästet",
    "abgeästeten": "abgeästet",
    "abgeästeter": "abgeästet",
    "abgeästetes": "abgeästet",
    "abgibst": "abgeben",
    "abgibt": "abgeben",
    "abgieße": "abgießen",
    "abgießend": "abgießen",
    "abgießende": "abgießend",
    "abgießendem": "abgießend",
    "abgießenden": "abgießend",
    "abgießender": "abgießend",
    "abgießendes": "abgießend",
    "abgießest": "abgießen",
    "abgießet": "abgießen",
    "abgießt": "abgießen",
    "abgilt": "abgelten",
    "abgiltst": "abgelten",
    "abging": "abgehen",
    "abginge": "abgehen",
    "abgingen": "abgehen",
    "abgingest": "abgehen",
    "abginget": "abgehen",
    "abgingst": "abgehen",
    "abgingt": "abgehen",
    "abgleiche": "abgleichen",
    "abgleichend": "abgleichen",
    "abgleichende": "abgleichend",
    "abgleichendem": "abgleichend",
    "abgleichenden": "abgleichend",
    "abgleichender": "abgleichend",
    "abgleichendes": "abgleichend",
    "abgleichest": "abgleichen",
    "abgleichet": "abgleichen",
    "abgleichst": "abgleichen",
    "abgleicht": "abgleichen",
    "abgleite": "abgleiten",
    "abgleitend": "abgleiten",
    "abgleitende": "abgleitend",
    "abgleitendem": "abgleitend",
    "abgleitenden": "abgleitend",
    "abgleitender": "abgleitend",
    "abgleitendere": "abgleitend",
    "abgleitenderem": "abgleitend",
    "abgleitenderen": "abgleitend",
    "abgleitenderer": "abgleitend",
    "abgleitenderes": "abgleitend",
    "abgleitendes": "abgleitend",
    "abgleitendste": "abgleitend",
    "abgleitendstem": "abgleitend",
    "abgleitendsten": "abgleitend",
    "abgleitendster": "abgleitend",
    "abgleitendstes": "abgleitend",
    "abgleitest": "abgleiten",
    "abgleitet": "abgleiten",
    "abglich": "abgleichen",
    "abgliche": "abgleichen",
    "abglichen": "abgleichen",
    "abglichest": "abgleichen",
    "abglichet": "abgleichen",
    "abglichst": "abgleichen",
    "abglicht": "abgleichen",
    "abglitt": "abgleiten",
    "abglitte": "abgleiten",
    "abglitten": "abgleiten",
    "abglittest": "abgleiten",
    "abglittet": "abgleiten",
    "abgossen": "abgießen",
    "abgoß": "abgießen",
    "abgoßt": "abgießen",
    "abgrabe": "abgraben",
    "abgrabend": "abgraben",
    "abgrabende": "abgrabend",
    "abgrabendem": "abgrabend",
    "abgrabenden": "abgrabend",
    "abgrabender": "abgrabend",
    "abgrabendes": "abgrabend",
    "abgrabest": "abgraben",
    "abgrabet": "abgraben",
    "abgrabt": "abgraben",
    "abgrase": "abgrasen",
    "abgrasend": "abgrasen",
    "abgrasende": "abgrasend",
    "abgrasendem": "abgrasend",
    "abgrasenden": "abgrasend",
    "abgrasender": "abgrasend",
    "abgrasendere": "abgrasend",
    "abgrasenderem": "abgrasend",
    "abgrasenderen": "abgrasend",
    "abgrasenderer": "abgrasend",
    "abgrasenderes": "abgrasend",
    "abgrasendes": "abgrasend",
    "abgrasendste": "abgrasend",
    "abgrasendstem": "abgrasend",
    "abgrasendsten": "abgrasend",
    "abgrasendster": "abgrasend",
    "abgrasendstes": "abgrasend",
    "abgrasest": "abgrasen",
    "abgraset": "abgrasen",
    "abgrast": "abgrasen",
    "abgraste": "abgrasen",
    "abgrasten": "abgrasen",
    "abgrastest": "abgrasen",
    "abgrastet": "abgrasen",
    "abgreife": "abgreifen",
    "abgreifend": "abgreifen",
    "abgreifende": "abgreifend",
    "abgreifendem": "abgreifend",
    "abgreifenden": "abgreifend",
    "abgreifender": "abgreifend",
    "abgreifendes": "abgreifend",
    "abgreifest": "abgreifen",
    "abgreifet": "abgreifen",
    "abgreifst": "abgreifen",
    "abgreift": "abgreifen",
    "abgrenze": "abgrenzen",
    "abgrenzend": "abgrenzen",
    "abgrenzende": "abgrenzend",
    "abgrenzendem": "abgrenzend",
    "abgrenzenden": "abgrenzend",
    "abgrenzender": "abgrenzend",
    "abgrenzendere": "abgrenzend",
    "abgrenzenderem": "abgrenzend",
    "abgrenzenderen": "abgrenzend",
    "abgrenzenderer": "abgrenzend",
    "abgrenzenderes": "abgrenzend",
    "abgrenzendes": "abgrenzend",
    "abgrenzendste": "abgrenzend",
    "abgrenzendstem": "abgrenzend",
    "abgrenzendsten": "abgrenzend",
    "abgrenzendster": "abgrenzend",
    "abgrenzendstes": "abgrenzend",
    "abgrenzest": "abgrenzen",
    "abgrenzet": "abgrenzen",
    "abgrenzt": "abgrenzen",
    "abgrenzte": "abgrenzen",
    "abgrenzten": "abgrenzen",
    "abgrenztest": "abgrenzen",
    "abgrenztet": "abgrenzen",
    "abgriff": "abgreifen",
    "abgriffe": "abgreifen",
    "abgriffen": "abgreifen",
    "abgriffest": "abgreifen",
    "abgriffet": "abgreifen",
    "abgriffst": "abgreifen",
    "abgrifft": "abgreifen",
    "abgrub": "abgraben",
    "abgruben": "abgraben",
    "abgrubst": "abgraben",
    "abgrubt": "abgraben",
    "abgräbst": "abgraben",
    "abgräbt": "abgraben",
    "abgrätsche": "abgrätschen",
    "abgrätschend": "abgrätschen",
    "abgrätschende": "abgrätschend",
    "abgrätschendem": "abgrätschend",
    "abgrätschenden": "abgrätschend",
    "abgrätschender": "abgrätschend",
    "abgrätschendere": "abgrätschend",
    "abgrätschenderem": "abgrätschend",
    "abgrätschenderen": "abgrätschend",
    "abgrätschenderer": "abgrätschend",
    "abgrätschenderes": "abgrätschend",
    "abgrätschendes": "abgrätschend",
    "abgrätschendste": "abgrätschend",
    "abgrätschendstem": "abgrätschend",
    "abgrätschendsten": "abgrätschend",
    "abgrätschendster": "abgrätschend",
    "abgrätschendstes": "abgrätschend",
    "abgrätschest": "abgrätschen",
    "abgrätschet": "abgrätschen",
    "abgrätschst": "abgrätschen",
    "abgrätscht": "abgrätschen",
    "abgrätschte": "abgrätschen",
    "abgrätschten": "abgrätschen",
    "abgrätschtest": "abgrätschen",
    "abgrätschtet": "abgrätschen",
    "abgrübe": "abgraben",
    "abgrüben": "abgraben",
    "abgrübest": "abgraben",
    "abgrübet": "abgraben",
    "abgründigem": "abgründig",
    "abgründigen": "abgründig",
    "abgründiger": "abgründig",
    "abgründiges": "abgründig",
    "abgäbe": "abgeben",
    "abgäben": "abgeben",
    "abgäbest": "abgeben",
    "abgäbet": "abgeben",
    "abgälte": "abgelten",
    "abgälten": "abgelten",
    "abgältest": "abgelten",
    "abgältet": "abgelten",
    "abgösse": "abgießen",
    "abgössen": "abgießen",
    "abgössest": "abgießen",
    "abgösset": "abgießen",
    "abgöttischem": "abgöttisch",
    "abgöttischen": "abgöttisch",
    "abgöttischer": "abgöttisch",
    "abgöttisches": "abgöttisch",
    "abhacke": "abhacken",
    "abhackend": "abhacken",
    "abhackende": "abhackend",
    "abhackendem": "abhackend",
    "abhackenden": "abhackend",
    "abhackender": "abhackend",
    "abhackendere": "abhackend",
    "abhackenderem": "abhackend",
    "abhackenderen": "abhackend",
    "abhackenderer": "abhackend",
    "abhackenderes": "abhackend",
    "abhackendes": "abhackend",
    "abhackendste": "abhackend",
    "abhackendstem": "abhackend",
    "abhackendsten": "abhackend",
    "abhackendster": "abhackend",
    "abhackendstes": "abhackend",
    "abhackest": "abhacken",
    "abhacket": "abhacken",
    "abhackst": "abhacken",
    "abhackt": "abhacken",
    "abhackte": "abhacken",
    "abhackten": "abhacken",
    "abhacktest": "abhacken",
    "abhacktet": "abhacken",
    "abhake": "abhaken",
    "abhakend": "abhaken",
    "abhakende": "abhakend",
    "abhakendem": "abhakend",
    "abhakenden": "abhakend",
    "abhakender": "abhakend",
    "abhakendes": "abhakend",
    "abhakest": "abhaken",
    "abhaket": "abhaken",
    "abhakst": "abhaken",
    "abhakt": "abhaken",
    "abhakte": "abhaken",
    "abhakten": "abhaken",
    "abhaktest": "abhaken",
    "abhaktet": "abhaken",
    "abhalf": "abhelfen",
    "abhalfen": "abhelfen",
    "abhalfst": "abhelfen",
    "abhalft": "abhelfen",
    "abhalftere": "abhalftern",
    "abhalfternd": "abhalftern",
    "abhalfternde": "abhalfternd",
    "abhalfterndem": "abhalfternd",
    "abhalfternden": "abhalfternd",
    "abhalfternder": "abhalfternd",
    "abhalfterndes": "abhalfternd",
    "abhalfterst": "abhalftern",
    "abhalftert": "abhalftern",
    "abhalfterte": "abhalftern",
    "abhalfterten": "abhalftern",
    "abhalftertest": "abhalftern",
    "abhalftertet": "abhalftern",
    "abhalte": "abhalten",
    "abhaltend": "abhalten",
    "abhaltende": "abhaltend",
    "abhaltendem": "abhaltend",
    "abhaltenden": "abhaltend",
    "abhaltender": "abhaltend",
    "abhaltendes": "abhaltend",
    "abhaltest": "abhalten",
    "abhaltet": "abhalten",
    "abhandele": "abhandeln",
    "abhandelnd": "abhandeln",
    "abhandelnde": "abhandelnd",
    "abhandelndem": "abhandelnd",
    "abhandelnden": "abhandelnd",
    "abhandelnder": "abhandelnd",
    "abhandelndes": "abhandelnd",
    "abhandelst": "abhandeln",
    "abhandelt": "abhandeln",
    "abhandelte": "abhandeln",
    "abhandelten": "abhandeln",
    "abhandeltest": "abhandeln",
    "abhandeltet": "abhandeln",
    "abhandle": "abhandeln",
    "abhaspele": "abhaspeln",
    "abhaspelnd": "abhaspeln",
    "abhaspelnde": "abhaspelnd",
    "abhaspelndem": "abhaspelnd",
    "abhaspelnden": "abhaspelnd",
    "abhaspelnder": "abhaspelnd",
    "abhaspelndes": "abhaspelnd",
    "abhaspelst": "abhaspeln",
    "abhaspelt": "abhaspeln",
    "abhaspelte": "abhaspeln",
    "abhaspelten": "abhaspeln",
    "abhaspeltest": "abhaspeln",
    "abhaspeltet": "abhaspeln",
    "abhasple": "abhaspeln",
    "abhaue": "abhauen",
    "abhauend": "abhauen",
    "abhauende": "abhauend",
    "abhauendem": "abhauend",
    "abhauenden": "abhauend",
    "abhauender": "abhauend",
    "abhauendes": "abhauend",
    "abhauest": "abhauen",
    "abhauet": "abhauen",
    "abhaust": "abhauen",
    "abhaut": "abhauen",
    "abhaute": "abhauen",
    "abhauten": "abhauen",
    "abhautest": "abhauen",
    "abhautet": "abhauen",
    "abhebe": "abheben",
    "abhebend": "abheben",
    "abhebende": "abhebend",
    "abhebendem": "abhebend",
    "abhebenden": "abhebend",
    "abhebender": "abhebend",
    "abhebendes": "abhebend",
    "abhebest": "abheben",
    "abhebet": "abheben",
    "abhebst": "abheben",
    "abhebt": "abheben",
    "abhefte": "abheften",
    "abheftend": "abheften",
    "abheftende": "abheftend",
    "abheftendem": "abheftend",
    "abheftenden": "abheftend",
    "abheftender": "abheftend",
    "abheftendes": "abheftend",
    "abheftest": "abheften",
    "abheftet": "abheften",
    "abheftete": "abheften",
    "abhefteten": "abheften",
    "abheftetest": "abheften",
    "abheftetet": "abheften",
    "abheile": "abheilen",
    "abheilend": "abheilen",
    "abheilende": "abheilend",
    "abheilendem": "abheilend",
    "abheilenden": "abheilend",
    "abheilender": "abheilend",
    "abheilendere": "abheilend",
    "abheilenderem": "abheilend",
    "abheilenderen": "abheilend",
    "abheilenderer": "abheilend",
    "abheilenderes": "abheilend",
    "abheilendes": "abheilend",
    "abheilendste": "abheilend",
    "abheilendstem": "abheilend",
    "abheilendsten": "abheilend",
    "abheilendster": "abheilend",
    "abheilendstes": "abheilend",
    "abheilest": "abheilen",
    "abheilet": "abheilen",
    "abheilst": "abheilen",
    "abheilt": "abheilen",
    "abheilte": "abheilen",
    "abheilten": "abheilen",
    "abheiltest": "abheilen",
    "abheiltet": "abheilen",
    "abhelfe": "abhelfen",
    "abhelfend": "abhelfen",
    "abhelfende": "abhelfend",
    "abhelfendem": "abhelfend",
    "abhelfenden": "abhelfend",
    "abhelfender": "abhelfend",
    "abhelfendes": "abhelfend",
    "abhelfest": "abhelfen",
    "abhelfet": "abhelfen",
    "abhelft": "abhelfen",
    "abhetze": "abhetzen",
    "abhetzend": "abhetzen",
    "abhetzende": "abhetzend",
    "abhetzendem": "abhetzend",
    "abhetzenden": "abhetzend",
    "abhetzender": "abhetzend",
    "abhetzendere": "abhetzend",
    "abhetzenderem": "abhetzend",
    "abhetzenderen": "abhetzend",
    "abhetzenderer": "abhetzend",
    "abhetzenderes": "abhetzend",
    "abhetzendes": "abhetzend",
    "abhetzendste": "abhetzend",
    "abhetzendstem": "abhetzend",
    "abhetzendsten": "abhetzend",
    "abhetzendster": "abhetzend",
    "abhetzendstes": "abhetzend",
    "abhetzest": "abhetzen",
    "abhetzet": "abhetzen",
    "abhetzt": "abhetzen",
    "abhetzte": "abhetzen",
    "abhetzten": "abhetzen",
    "abhetztest": "abhetzen",
    "abhetztet": "abhetzen",
    "abhielt": "abhalten",
    "abhielte": "abhalten",
    "abhielten": "abhalten",
    "abhieltest": "abhalten",
    "abhieltet": "abhalten",
    "abhilfst": "abhelfen",
    "abhilft": "abhelfen",
    "abhing": "abhängen",
    "abhinge": "abhängen",
    "abhingen": "abhängen",
    "abhingest": "abhängen",
    "abhinget": "abhängen",
    "abhingst": "abhängen",
    "abhingt": "abhängen",
    "abhob": "abheben",
    "abhobele": "abhobeln",
    "abhobelnd": "abhobeln",
    "abhobelnde": "abhobelnd",
    "abhobelndem": "abhobelnd",
    "abhobelnden": "abhobelnd",
    "abhobelnder": "abhobelnd",
    "abhobelndere": "abhobelnd",
    "abhobelnderem": "abhobelnd",
    "abhobelnderen": "abhobelnd",
    "abhobelnderer": "abhobelnd",
    "abhobelnderes": "abhobelnd",
    "abhobelndes": "abhobelnd",
    "abhobelndste": "abhobelnd",
    "abhobelndstem": "abhobelnd",
    "abhobelndsten": "abhobelnd",
    "abhobelndster": "abhobelnd",
    "abhobelndstes": "abhobelnd",
    "abhobelst": "abhobeln",
    "abhobelt": "abhobeln",
    "abhobelte": "abhobeln",
    "abhobelten": "abhobeln",
    "abhobeltest": "abhobeln",
    "abhobeltet": "abhobeln",
    "abhoben": "abheben",
    "abhoble": "abhobeln",
    "abhobst": "abheben",
    "abhobt": "abheben",
    "abhole": "abholen",
    "abholend": "abholen",
    "abholende": "abholend",
    "abholendem": "abholend",
    "abholenden": "abholend",
    "abholender": "abholend",
    "abholendes": "abholend",
    "abholest": "abholen",
    "abholet": "abholen",
    "abholst": "abholen",
    "abholt": "abholen",
    "abholte": "abholen",
    "abholten": "abholen",
    "abholtest": "abholen",
    "abholtet": "abholen",
    "abholze": "abholzen",
    "abholzend": "abholzen",
    "abholzende": "abholzend",
    "abholzendem": "abholzend",
    "abholzenden": "abholzend",
    "abholzender": "abholzend",
    "abholzendes": "abholzend",
    "abholzest": "abholzen",
    "abholzet": "abholzen",
    "abholzt": "abholzen",
    "abholzte": "abholzen",
    "abholzten": "abholzen",
    "abholztest": "abholzen",
    "abholztet": "abholzen",
    "abhorche": "abhorchen",
    "abhorchend": "abhorchen",
    "abhorchende": "abhorchend",
    "abhorchendem": "abhorchend",
    "abhorchenden": "abhorchend",
    "abhorchender": "abhorchend",
    "abhorchendere": "abhorchend",
    "abhorchenderem": "abhorchend",
    "abhorchenderen": "abhorchend",
    "abhorchenderer": "abhorchend",
    "abhorchenderes": "abhorchend",
    "abhorchendes": "abhorchend",
    "abhorchendste": "abhorchend",
    "abhorchendstem": "abhorchend",
    "abhorchendsten": "abhorchend",
    "abhorchendster": "abhorchend",
    "abhorchendstes": "abhorchend",
    "abhorchest": "abhorchen",
    "abhorchet": "abhorchen",
    "abhorchst": "abhorchen",
    "abhorcht": "abhorchen",
    "abhorchte": "abhorchen",
    "abhorchten": "abhorchen",
    "abhorchtest": "abhorchen",
    "abhorchtet": "abhorchen",
    "abhälfe": "abhelfen",
    "abhälfen": "abhelfen",
    "abhälfest": "abhelfen",
    "abhälfet": "abhelfen",
    "abhält": "abhalten",
    "abhältst": "abhalten",
    "abhänge": "abhängen",
    "abhängend": "abhängen",
    "abhängende": "abhängend",
    "abhängendem": "abhängend",
    "abhängenden": "abhängend",
    "abhängender": "abhängend",
    "abhängendes": "abhängend",
    "abhängest": "abhängen",
    "abhänget": "abhängen",
    "abhängige": "abhängig",
    "abhängigem": "abhängig",
    "abhängigen": "abhängig",
    "abhängiger": "abhängig",
    "abhängigere": "abhängig",
    "abhängigerem": "abhängig",
    "abhängigeren": "abhängig",
    "abhängigerer": "abhängig",
    "abhängigeres": "abhängig",
    "abhängiges": "abhängig",
    "abhängigstem": "abhängig",
    "abhängigsten": "abhängig",
    "abhängigster": "abhängig",
    "abhängigstes": "abhängig",
    "abhängst": "abhängen",
    "abhängt": "abhängen",
    "abhängte": "abhängen",
    "abhängten": "abhängen",
    "abhängtest": "abhängen",
    "abhängtet": "abhängen",
    "abhärte": "abhärten",
    "abhärtend": "abhärten",
    "abhärtende": "abhärtend",
    "abhärtendem": "abhärtend",
    "abhärtenden": "abhärtend",
    "abhärtender": "abhärtend",
    "abhärtendere": "abhärtend",
    "abhärtenderem": "abhärtend",
    "abhärtenderen": "abhärtend",
    "abhärtenderer": "abhärtend",
    "abhärtenderes": "abhärtend",
    "abhärtendes": "abhärtend",
    "abhärtendste": "abhärtend",
    "abhärtendstem": "abhärtend",
    "abhärtendsten": "abhärtend",
    "abhärtendster": "abhärtend",
    "abhärtendstes": "abhärtend",
    "abhärtest": "abhärten",
    "abhärtet": "abhärten",
    "abhärtete": "abhärten",
    "abhärteten": "abhärten",
    "abhärtetest": "abhärten",
    "abhärtetet": "abhärten",
    "abhäute": "abhäuten",
    "abhäutend": "abhäuten",
    "abhäutende": "abhäutend",
    "abhäutendem": "abhäutend",
    "abhäutenden": "abhäutend",
    "abhäutender": "abhäutend",
    "abhäutendes": "abhäutend",
    "abhäutest": "abhäuten",
    "abhäutet": "abhäuten",
    "abhäutete": "abhäuten",
    "abhäuteten": "abhäuten",
    "abhäutetest": "abhäuten",
    "abhäutetet": "abhäuten",
    "abhöbe": "abheben",
    "abhöben": "abheben",
    "abhöbest": "abheben",
    "abhöbet": "abheben",
    "abhöre": "abhören",
    "abhörend": "abhören",
    "abhörende": "abhörend",
    "abhörendem": "abhörend",
    "abhörenden": "abhörend",
    "abhörender": "abhörend",
    "abhörendes": "abhörend",
    "abhörest": "abhören",
    "abhöret": "abhören",
    "abhörst": "abhören",
    "abhört": "abhören",
    "abhörte": "abhören",
    "abhörten": "abhören",
    "abhörtest": "abhören",
    "abhörtet": "abhören",
    "abißt": "abessen",
    "abjage": "abjagen",
    "abjagend": "abjagen",
    "abjagende": "abjagend",
    "abjagendem": "abjagend",
    "abjagenden": "abjagend",
    "abjagender": "abjagend",
    "abjagendes": "abjagend",
    "abjagest": "abjagen",
    "abjaget": "abjagen",
    "abjagst": "abjagen",
    "abjagt": "abjagen",
    "abjagte": "abjagen",
    "abjagten": "abjagen",
    "abjagtest": "abjagen",
    "abjagtet": "abjagen",
    "abkam": "abkommen",
    "abkamen": "abkommen",
    "abkamst": "abkommen",
    "abkamt": "abkommen",
    "abkante": "abkanten",
    "abkantend": "abkanten",
    "abkantende": "abkantend",
    "abkantendem": "abkantend",
    "abkantenden": "abkantend",
    "abkantender": "abkantend",
    "abkantendere": "abkantend",
    "abkantenderem": "abkantend",
    "abkantenderen": "abkantend",
    "abkantenderer": "abkantend",
    "abkantenderes": "abkantend",
    "abkantendes": "abkantend",
    "abkantendste": "abkantend",
    "abkantendstem": "abkantend",
    "abkantendsten": "abkantend",
    "abkantendster": "abkantend",
    "abkantendstes": "abkantend",
    "abkantest": "abkanten",
    "abkantet": "abkanten",
    "abkantete": "abkanten",
    "abkanteten": "abkanten",
    "abkantetest": "abkanten",
    "abkantetet": "abkanten",
    "abkanzele": "abkanzeln",
    "abkanzelnd": "abkanzeln",
    "abkanzelnde": "abkanzelnd",
    "abkanzelndem": "abkanzelnd",
    "abkanzelnden": "abkanzelnd",
    "abkanzelnder": "abkanzelnd",
    "abkanzelndere": "abkanzelnd",
    "abkanzelnderem": "abkanzelnd",
    "abkanzelnderen": "abkanzelnd",
    "abkanzelnderer": "abkanzelnd",
    "abkanzelnderes": "abkanzelnd",
    "abkanzelndes": "abkanzelnd",
    "abkanzelndste": "abkanzelnd",
    "abkanzelndstem": "abkanzelnd",
    "abkanzelndsten": "abkanzelnd",
    "abkanzelndster": "abkanzelnd",
    "abkanzelndstes": "abkanzelnd",
    "abkanzelst": "abkanzeln",
    "abkanzelt": "abkanzeln",
    "abkanzelte": "abkanzeln",
    "abkanzelten": "abkanzeln",
    "abkanzeltest": "abkanzeln",
    "abkanzeltet": "abkanzeln",
    "abkanzle": "abkanzeln",
    "abkappe": "abkappen",
    "abkappend": "abkappen",
    "abkappende": "abkappend",
    "abkappendem": "abkappend",
    "abkappenden": "abkappend",
    "abkappender": "abkappend",
    "abkappendes": "abkappend",
    "abkappest": "abkappen",
    "abkappet": "abkappen",
    "abkappst": "abkappen",
    "abkappt": "abkappen",
    "abkappte": "abkappen",
    "abkappten": "abkappen",
    "abkapptest": "abkappen",
    "abkapptet": "abkappen",
    "abkapsele": "abkapseln",
    "abkapselnd": "abkapseln",
    "abkapselnde": "abkapselnd",
    "abkapselndem": "abkapselnd",
    "abkapselnden": "abkapselnd",
    "abkapselnder": "abkapselnd",
    "abkapselndere": "abkapselnd",
    "abkapselnderem": "abkapselnd",
    "abkapselnderen": "abkapselnd",
    "abkapselnderer": "abkapselnd",
    "abkapselnderes": "abkapselnd",
    "abkapselndes": "abkapselnd",
    "abkapselndste": "abkapselnd",
    "abkapselndstem": "abkapselnd",
    "abkapselndsten": "abkapselnd",
    "abkapselndster": "abkapselnd",
    "abkapselndstes": "abkapselnd",
    "abkapselst": "abkapseln",
    "abkapselt": "abkapseln",
    "abkapselte": "abkapseln",
    "abkapselten": "abkapseln",
    "abkapseltest": "abkapseln",
    "abkapseltet": "abkapseln",
    "abkapsle": "abkapseln",
    "abkarte": "abkarten",
    "abkartend": "abkarten",
    "abkartende": "abkartend",
    "abkartendem": "abkartend",
    "abkartenden": "abkartend",
    "abkartender": "abkartend",
    "abkartendere": "abkartend",
    "abkartenderem": "abkartend",
    "abkartenderen": "abkartend",
    "abkartenderer": "abkartend",
    "abkartenderes": "abkartend",
    "abkartendes": "abkartend",
    "abkartendste": "abkartend",
    "abkartendstem": "abkartend",
    "abkartendsten": "abkartend",
    "abkartendster": "abkartend",
    "abkartendstes": "abkartend",
    "abkartest": "abkarten",
    "abkartet": "abkarten",
    "abkartete": "abkarten",
    "abkarteten": "abkarten",
    "abkartetest": "abkarten",
    "abkartetet": "abkarten",
    "abkassiere": "abkassieren",
    "abkassierend": "abkassieren",
    "abkassierende": "abkassierend",
    "abkassierendem": "abkassierend",
    "abkassierenden": "abkassierend",
    "abkassierender": "abkassierend",
    "abkassierendere": "abkassierend",
    "abkassierenderem": "abkassierend",
    "abkassierenderen": "abkassierend",
    "abkassierenderer": "abkassierend",
    "abkassierenderes": "abkassierend",
    "abkassierendes": "abkassierend",
    "abkassierendste": "abkassierend",
    "abkassierendstem": "abkassierend",
    "abkassierendsten": "abkassierend",
    "abkassierendster": "abkassierend",
    "abkassierendstes": "abkassierend",
    "abkassierest": "abkassieren",
    "abkassieret": "abkassieren",
    "abkassierst": "abkassieren",
    "abkassiert": "abkassieren",
    "abkassierte": "abkassieren",
    "abkassiertem": "abkassiert",
    "abkassierten": "abkassieren",
    "abkassierter": "abkassiert",
    "abkassiertere": "abkassiert",
    "abkassierterem": "abkassiert",
    "abkassierteren": "abkassiert",
    "abkassierterer": "abkassiert",
    "abkassierteres": "abkassiert",
    "abkassiertes": "abkassiert",
    "abkassiertest": "abkassieren",
    "abkassierteste": "abkassiert",
    "abkassiertestem": "abkassiert",
    "abkassiertesten": "abkassiert",
    "abkassiertester": "abkassiert",
    "abkassiertestes": "abkassiert",
    "abkassiertet": "abkassieren",
    "abkaufe": "abkaufen",
    "abkaufend": "abkaufen",
    "abkaufende": "abkaufend",
    "abkaufendem": "abkaufend",
    "abkaufenden": "abkaufend",
    "abkaufender": "abkaufend",
    "abkaufendes": "abkaufend",
    "abkaufest": "abkaufen",
    "abkaufet": "abkaufen",
    "abkaufst": "abkaufen",
    "abkauft": "abkaufen",
    "abkaufte": "abkaufen",
    "abkauften": "abkaufen",
    "abkauftest": "abkaufen",
    "abkauftet": "abkaufen",
    "abkehre": "abkehren",
    "abkehrend": "abkehren",
    "abkehrende": "abkehrend",
    "abkehrendem": "abkehrend",
    "abkehrenden": "abkehrend",
    "abkehrender": "abkehrend",
    "abkehrendes": "abkehrend",
    "abkehrest": "abkehren",
    "abkehret": "abkehren",
    "abkehrst": "abkehren",
    "abkehrt": "abkehren",
    "abkehrte": "abkehren",
    "abkehrten": "abkehren",
    "abkehrtest": "abkehren",
    "abkehrtet": "abkehren",
    "abklang": "abklingen",
    "abklangen": "abklingen",
    "abklangst": "abklingen",
    "abklangt": "abklingen",
    "abklappere": "abklappern",
    "abklappernd": "abklappern",
    "abklappernde": "abklappernd",
    "abklapperndem": "abklappernd",
    "abklappernden": "abklappernd",
    "abklappernder": "abklappernd",
    "abklapperndes": "abklappernd",
    "abklapperst": "abklappern",
    "abklappert": "abklappern",
    "abklapperte": "abklappern",
    "abklapperten": "abklappern",
    "abklappertest": "abklappern",
    "abklappertet": "abklappern",
    "abklatsche": "abklatschen",
    "abklatschend": "abklatschen",
    "abklatschende": "abklatschend",
    "abklatschendem": "abklatschend",
    "abklatschenden": "abklatschend",
    "abklatschender": "abklatschend",
    "abklatschendes": "abklatschend",
    "abklatschest": "abklatschen",
    "abklatschet": "abklatschen",
    "abklatschst": "abklatschen",
    "abklatscht": "abklatschen",
    "abklatschte": "abklatschen",
    "abklatschten": "abklatschen",
    "abklatschtest": "abklatschen",
    "abklatschtet": "abklatschen",
    "abklaube": "abklauben",
    "abklaubend": "abklauben",
    "abklaubende": "abklaubend",
    "abklaubendem": "abklaubend",
    "abklaubenden": "abklaubend",
    "abklaubender": "abklaubend",
    "abklaubendere": "abklaubend",
    "abklaubenderem": "abklaubend",
    "abklaubenderen": "abklaubend",
    "abklaubenderer": "abklaubend",
    "abklaubenderes": "abklaubend",
    "abklaubendes": "abklaubend",
    "abklaubendste": "abklaubend",
    "abklaubendstem": "abklaubend",
    "abklaubendsten": "abklaubend",
    "abklaubendster": "abklaubend",
    "abklaubendstes": "abklaubend",
    "abklaubest": "abklauben",
    "abklaubet": "abklauben",
    "abklaubst": "abklauben",
    "abklaubt": "abklauben",
    "abklaubte": "abklauben",
    "abklaubten": "abklauben",
    "abklaubtest": "abklauben",
    "abklaubtet": "abklauben",
    "abklebe": "abkleben",
    "abklebend": "abkleben",
    "abklebende": "abklebend",
    "abklebendem": "abklebend",
    "abklebenden": "abklebend",
    "abklebender": "abklebend",
    "abklebendes": "abklebend",
    "abklebest": "abkleben",
    "abklebet": "abkleben",
    "abklebst": "abkleben",
    "abklebt": "abkleben",
    "abklebte": "abkleben",
    "abklebten": "abkleben",
    "abklebtest": "abkleben",
    "abklebtet": "abkleben",
    "abklemme": "abklemmen",
    "abklemmend": "abklemmen",
    "abklemmende": "abklemmend",
    "abklemmendem": "abklemmend",
    "abklemmenden": "abklemmend",
    "abklemmender": "abklemmend",
    "abklemmendes": "abklemmend",
    "abklemmest": "abklemmen",
    "abklemmet": "abklemmen",
    "abklemmst": "abklemmen",
    "abklemmt": "abklemmen",
    "abklemmte": "abklemmen",
    "abklemmten": "abklemmen",
    "abklemmtest": "abklemmen",
    "abklemmtet": "abklemmen",
    "abklinge": "abklingen",
    "abklingend": "abklingen",
    "abklingende": "abklingend",
    "abklingendem": "abklingend",
    "abklingenden": "abklingend",
    "abklingender": "abklingend",
    "abklingendes": "abklingend",
    "abklingest": "abklingen",
    "abklinget": "abklingen",
    "abklingst": "abklingen",
    "abklingt": "abklingen",
    "abklopfe": "abklopfen",
    "abklopfend": "abklopfen",
    "abklopfende": "abklopfend",
    "abklopfendem": "abklopfend",
    "abklopfenden": "abklopfend",
    "abklopfender": "abklopfend",
    "abklopfendes": "abklopfend",
    "abklopfest": "abklopfen",
    "abklopfet": "abklopfen",
    "abklopfst": "abklopfen",
    "abklopft": "abklopfen",
    "abklopfte": "abklopfen",
    "abklopften": "abklopfen",
    "abklopftest": "abklopfen",
    "abklopftet": "abklopfen",
    "abklänge": "abklingen",
    "abklängen": "abklingen",
    "abklängest": "abklingen",
    "abklänget": "abklingen",
    "abkläre": "abklären",
    "abklärend": "abklären",
    "abklärende": "abklärend",
    "abklärendem": "abklärend",
    "abklärenden": "abklärend",
    "abklärender": "abklärend",
    "abklärendes": "abklärend",
    "abklärest": "abklären",
    "abkläret": "abklären",
    "abklärst": "abklären",
    "abklärt": "abklären",
    "abklärte": "abklären",
    "abklärten": "abklären",
    "abklärtest": "abklären",
    "abklärtet": "abklären",
    "abknabbere": "abknabbern",
    "abknabbernd": "abknabbern",
    "abknabbernde": "abknabbernd",
    "abknabberndem": "abknabbernd",
    "abknabbernden": "abknabbernd",
    "abknabbernder": "abknabbernd",
    "abknabberndere": "abknabbernd",
    "abknabbernderem": "abknabbernd",
    "abknabbernderen": "abknabbernd",
    "abknabbernderer": "abknabbernd",
    "abknabbernderes": "abknabbernd",
    "abknabberndes": "abknabbernd",
    "abknabberndste": "abknabbernd",
    "abknabberndstem": "abknabbernd",
    "abknabberndsten": "abknabbernd",
    "abknabberndster": "abknabbernd",
    "abknabberndstes": "abknabbernd",
    "abknabberst": "abknabbern",
    "abknabbert": "abknabbern",
    "abknabberte": "abknabbern",
    "abknabberten": "abknabbern",
    "abknabbertest": "abknabbern",
    "abknabbertet": "abknabbern",
    "abknalle": "abknallen",
    "abknallend": "abknallen",
    "abknallende": "abknallend",
    "abknallendem": "abknallend",
    "abknallenden": "abknallend",
    "abknallender": "abknallend",
    "abknallendes": "abknallend",
    "abknallest": "abknallen",
    "abknallet": "abknallen",
    "abknallst": "abknallen",
    "abknallt": "abknallen",
    "abknallte": "abknallen",
    "abknallten": "abknallen",
    "abknalltest": "abknallen",
    "abknalltet": "abknallen",
    "abknapse": "abknapsen",
    "abknapsend": "abknapsen",
    "abknapsende": "abknapsend",
    "abknapsendem": "abknapsend",
    "abknapsenden": "abknapsend",
    "abknapsender": "abknapsend",
    "abknapsendere": "abknapsend",
    "abknapsenderem": "abknapsend",
    "abknapsenderen": "abknapsend",
    "abknapsenderer": "abknapsend",
    "abknapsenderes": "abknapsend",
    "abknapsendes": "abknapsend",
    "abknapsendste": "abknapsend",
    "abknapsendstem": "abknapsend",
    "abknapsendsten": "abknapsend",
    "abknapsendster": "abknapsend",
    "abknapsendstes": "abknapsend",
    "abknapsest": "abknapsen",
    "abknapset": "abknapsen",
    "abknapst": "abknapsen",
    "abknapste": "abknapsen",
    "abknapsten": "abknapsen",
    "abknapstest": "abknapsen",
    "abknapstet": "abknapsen",
    "abkneife": "abkneifen",
    "abkneifend": "abkneifen",
    "abkneifende": "abkneifend",
    "abkneifendem": "abkneifend",
    "abkneifenden": "abkneifend",
    "abkneifender": "abkneifend",
    "abkneifendes": "abkneifend",
    "abkneifest": "abkneifen",
    "abkneifet": "abkneifen",
    "abkneifst": "abkneifen",
    "abkneift": "abkneifen",
    "abknicke": "abknicken",
    "abknickend": "abknicken",
    "abknickende": "abknickend",
    "abknickendem": "abknickend",
    "abknickenden": "abknickend",
    "abknickender": "abknickend",
    "abknickendes": "abknickend",
    "abknickest": "abknicken",
    "abknicket": "abknicken",
    "abknickst": "abknicken",
    "abknickt": "abknicken",
    "abknickte": "abknicken",
    "abknickten": "abknicken",
    "abknicktest": "abknicken",
    "abknicktet": "abknicken",
    "abkniff": "abkneifen",
    "abkniffe": "abkneifen",
    "abkniffen": "abkneifen",
    "abkniffest": "abkneifen",
    "abkniffet": "abkneifen",
    "abkniffst": "abkneifen",
    "abknifft": "abkneifen",
    "abknipse": "abknipsen",
    "abknipsend": "abknipsen",
    "abknipsende": "abknipsend",
    "abknipsendem": "abknipsend",
    "abknipsenden": "abknipsend",
    "abknipsender": "abknipsend",
    "abknipsendes": "abknipsend",
    "abknipsest": "abknipsen",
    "abknipset": "abknipsen",
    "abknipst": "abknipsen",
    "abknipste": "abknipsen",
    "abknipsten": "abknipsen",
    "abknipstest": "abknipsen",
    "abknipstet": "abknipsen",
    "abknutsche": "abknutschen",
    "abknutschend": "abknutschen",
    "abknutschende": "abknutschend",
    "abknutschendem": "abknutschend",
    "abknutschenden": "abknutschend",
    "abknutschender": "abknutschend",
    "abknutschendere": "abknutschend",
    "abknutschenderem": "abknutschend",
    "abknutschenderen": "abknutschend",
    "abknutschenderer": "abknutschend",
    "abknutschenderes": "abknutschend",
    "abknutschendes": "abknutschend",
    "abknutschendste": "abknutschend",
    "abknutschendstem": "abknutschend",
    "abknutschendsten": "abknutschend",
    "abknutschendster": "abknutschend",
    "abknutschendstes": "abknutschend",
    "abknutschest": "abknutschen",
    "abknutschet": "abknutschen",
    "abknutschst": "abknutschen",
    "abknutscht": "abknutschen",
    "abknutschte": "abknutschen",
    "abknutschten": "abknutschen",
    "abknutschtest": "abknutschen",
    "abknutschtet": "abknutschen",
    "abknöpfe": "abknöpfen",
    "abknöpfend": "abknöpfen",
    "abknöpfende": "abknöpfend",
    "abknöpfendem": "abknöpfend",
    "abknöpfenden": "abknöpfend",
    "abknöpfender": "abknöpfend",
    "abknöpfendes": "abknöpfend",
    "abknöpfest": "abknöpfen",
    "abknöpfet": "abknöpfen",
    "abknöpfst": "abknöpfen",
    "abknöpft": "abknöpfen",
    "abknöpfte": "abknöpfen",
    "abknöpften": "abknöpfen",
    "abknöpftest": "abknöpfen",
    "abknöpftet": "abknöpfen",
    "abkoche": "abkochen",
    "abkochend": "abkochen",
    "abkochende": "abkochend",
    "abkochendem": "abkochend",
    "abkochenden": "abkochend",
    "abkochender": "abkochend",
    "abkochendere": "abkochend",
    "abkochenderem": "abkochend",
    "abkochenderen": "abkochend",
    "abkochenderer": "abkochend",
    "abkochenderes": "abkochend",
    "abkochendes": "abkochend",
    "abkochendste": "abkochend",
    "abkochendstem": "abkochend",
    "abkochendsten": "abkochend",
    "abkochendster": "abkochend",
    "abkochendstes": "abkochend",
    "abkochest": "abkochen",
    "abkochet": "abkochen",
    "abkochst": "abkochen",
    "abkocht": "abkochen",
    "abkochte": "abkochen",
    "abkochten": "abkochen",
    "abkochtest": "abkochen",
    "abkochtet": "abkochen",
    "abkommandiere": "abkommandieren",
    "abkommandierend": "abkommandieren",
    "abkommandierende": "abkommandierend",
    "abkommandierendem": "abkommandierend",
    "abkommandierenden": "abkommandierend",
    "abkommandierender": "abkommandierend",
    "abkommandierendes": "abkommandierend",
    "abkommandierest": "abkommandieren",
    "abkommandieret": "abkommandieren",
    "abkommandierst": "abkommandieren",
    "abkommandiert": "abkommandieren",
    "abkommandierte": "abkommandieren",
    "abkommandiertem": "abkommandiert",
    "abkommandierten": "abkommandieren",
    "abkommandierter": "abkommandiert",
    "abkommandiertes": "abkommandiert",
    "abkommandiertest": "abkommandieren",
    "abkommandiertet": "abkommandieren",
    "abkommend": "abkommen",
    "abkommende": "abkommend",
    "abkommendem": "abkommend",
    "abkommenden": "abkommend",
    "abkommender": "abkommend",
    "abkommendes": "abkommend",
    "abkommest": "abkommen",
    "abkommet": "abkommen",
    "abkommst": "abkommen",
    "abkommt": "abkommen",
    "abkoppele": "abkoppeln",
    "abkoppelnd": "abkoppeln",
    "abkoppelnde": "abkoppelnd",
    "abkoppelndem": "abkoppelnd",
    "abkoppelnden": "abkoppelnd",
    "abkoppelnder": "abkoppelnd",
    "abkoppelndes": "abkoppelnd",
    "abkoppelst": "abkoppeln",
    "abkoppelt": "abkoppeln",
    "abkoppelte": "abkoppeln",
    "abkoppelten": "abkoppeln",
    "abkoppeltest": "abkoppeln",
    "abkoppeltet": "abkoppeln",
    "abkopple": "abkoppeln",
    "abkotze": "abkotzen",
    "abkotzend": "abkotzen",
    "abkotzende": "abkotzend",
    "abkotzendem": "abkotzend",
    "abkotzenden": "abkotzend",
    "abkotzender": "abkotzend",
    "abkotzendes": "abkotzend",
    "abkotzest": "abkotzen",
    "abkotzet": "abkotzen",
    "abkotzt": "abkotzen",
    "abkotzte": "abkotzen",
    "abkotzten": "abkotzen",
    "abkotztest": "abkotzen",
    "abkotztet": "abkotzen",
    "abkratze": "abkratzen",
    "abkratzend": "abkratzen",
    "abkratzende": "abkratzend",
    "abkratzendem": "abkratzend",
    "abkratzenden": "abkratzend",
    "abkratzender": "abkratzend",
    "abkratzendes": "abkratzend",
    "abkratzest": "abkratzen",
    "abkratzet": "abkratzen",
    "abkratzt": "abkratzen",
    "abkratzte": "abkratzen",
    "abkratzten": "abkratzen",
    "abkratztest": "abkratzen",
    "abkratztet": "abkratzen",
    "abkriege": "abkriegen",
    "abkriegend": "abkriegen",
    "abkriegende": "abkriegend",
    "abkriegendem": "abkriegend",
    "abkriegenden": "abkriegend",
    "abkriegender": "abkriegend",
    "abkriegendes": "abkriegend",
    "abkriegest": "abkriegen",
    "abkrieget": "abkriegen",
    "abkriegst": "abkriegen",
    "abkriegt": "abkriegen",
    "abkriegte": "abkriegen",
    "abkriegten": "abkriegen",
    "abkriegtest": "abkriegen",
    "abkriegtet": "abkriegen",
    "abkuppele": "abkuppeln",
    "abkuppelnd": "abkuppeln",
    "abkuppelnde": "abkuppelnd",
    "abkuppelndem": "abkuppelnd",
    "abkuppelnden": "abkuppelnd",
    "abkuppelnder": "abkuppelnd",
    "abkuppelndes": "abkuppelnd",
    "abkuppelst": "abkuppeln",
    "abkuppelt": "abkuppeln",
    "abkuppelte": "abkuppeln",
    "abkuppelten": "abkuppeln",
    "abkuppeltest": "abkuppeln",
    "abkuppeltet": "abkuppeln",
    "abkupple": "abkuppeln",
    "abkäme": "abkommen",
    "abkämen": "abkommen",
    "abkämest": "abkommen",
    "abkämet": "abkommen",
    "abkämme": "abkämmen",
    "abkämmend": "abkämmen",
    "abkämmende": "abkämmend",
    "abkämmendem": "abkämmend",
    "abkämmenden": "abkämmend",
    "abkämmender": "abkämmend",
    "abkämmendes": "abkämmend",
    "abkämmest": "abkämmen",
    "abkämmet": "abkämmen",
    "abkämmst": "abkämmen",
    "abkämmt": "abkämmen",
    "abkämmte": "abkämmen",
    "abkämmten": "abkämmen",
    "abkämmtest": "abkämmen",
    "abkämmtet": "abkämmen",
    "abkämpfe": "abkämpfen",
    "abkämpfend": "abkämpfen",
    "abkämpfende": "abkämpfend",
    "abkämpfendem": "abkämpfend",
    "abkämpfenden": "abkämpfend",
    "abkämpfender": "abkämpfend",
    "abkämpfendere": "abkämpfend",
    "abkämpfenderem": "abkämpfend",
    "abkämpfenderen": "abkämpfend",
    "abkämpfenderer": "abkämpfend",
    "abkämpfenderes": "abkämpfend",
    "abkämpfendes": "abkämpfend",
    "abkämpfendste": "abkämpfend",
    "abkämpfendstem": "abkämpfend",
    "abkämpfendsten": "abkämpfend",
    "abkämpfendster": "abkämpfend",
    "abkämpfendstes": "abkämpfend",
    "abkämpfest": "abkämpfen",
    "abkämpfet": "abkämpfen",
    "abkämpfst": "abkämpfen",
    "abkämpft": "abkämpfen",
    "abkämpfte": "abkämpfen",
    "abkämpften": "abkämpfen",
    "abkämpftest": "abkämpfen",
    "abkämpftet": "abkämpfen",
    "abkömmliche": "abkömmlich",
    "abkömmlichem": "abkömmlich",
    "abkömmlichen": "abkömmlich",
    "abkömmlicher": "abkömmlich",
    "abkömmlichere": "abkömmlich",
    "abkömmlicherem": "abkömmlich",
    "abkömmlicheren": "abkömmlich",
    "abkömmlicherer": "abkömmlich",
    "abkömmlicheres": "abkömmlich",
    "abkömmliches": "abkömmlich",
    "abkömmlichste": "abkömmlich",
    "abkömmlichstem": "abkömmlich",
    "abkömmlichsten": "abkömmlich",
    "abkömmlichster": "abkömmlich",
    "abkömmlichstes": "abkömmlich",
    "abkühle": "abkühlen",
    "abkühlend": "abkühlen",
    "abkühlende": "abkühlend",
    "abkühlendem": "abkühlend",
    "abkühlenden": "abkühlend",
    "abkühlender": "abkühlend",
    "abkühlendere": "abkühlend",
    "abkühlenderem": "abkühlend",
    "abkühlenderen": "abkühlend",
    "abkühlenderer": "abkühlend",
    "abkühlenderes": "abkühlend",
    "abkühlendes": "abkühlend",
    "abkühlendste": "abkühlend",
    "abkühlendstem": "abkühlend",
    "abkühlendsten": "abkühlend",
    "abkühlendster": "abkühlend",
    "abkühlendstes": "abkühlend",
    "abkühlest": "abkühlen",
    "abkühlet": "abkühlen",
    "abkühlst": "abkühlen",
    "abkühlt": "abkühlen",
    "abkühlte": "abkühlen",
    "abkühlten": "abkühlen",
    "abkühltest": "abkühlen",
    "abkühltet": "abkühlen",
    "abkürze": "abkürzen",
    "abkürzend": "abkürzen",
    "abkürzende": "abkürzend",
    "abkürzendem": "abkürzend",
    "abkürzenden": "abkürzend",
    "abkürzender": "abkürzend",
    "abkürzendes": "abkürzend",
    "abkürzest": "abkürzen",
    "abkürzet": "abkürzen",
    "abkürzt": "abkürzen",
    "abkürzte": "abkürzen",
    "abkürzten": "abkürzen",
    "abkürztest": "abkürzen",
    "abkürztet": "abkürzen",
    "abküsse": "abküssen",
    "abküssend": "abküssen",
    "abküssende": "abküssend",
    "abküssendem": "abküssend",
    "abküssenden": "abküssend",
    "abküssender": "abküssend",
    "abküssendes": "abküssend",
    "abküssest": "abküssen",
    "abküsset": "abküssen",
    "abküßt": "abküssen",
    "abküßte": "abküssen",
    "abküßten": "abküssen",
    "abküßtest": "abküssen",
    "abküßtet": "abküssen",
    "ablache": "ablachen",
    "ablachend": "ablachen",
    "ablachende": "ablachend",
    "ablachendem": "ablachend",
    "ablachenden": "ablachend",
    "ablachender": "ablachend",
    "ablachendes": "ablachend",
    "ablachest": "ablachen",
    "ablachet": "ablachen",
    "ablachst": "ablachen",
    "ablacht": "ablachen",
    "ablachte": "ablachen",
    "ablachten": "ablachen",
    "ablachtest": "ablachen",
    "ablachtet": "ablachen",
    "ablade": "abladen",
    "abladend": "abladen",
    "abladende": "abladend",
    "abladendem": "abladend",
    "abladenden": "abladend",
    "abladender": "abladend",
    "abladendes": "abladend",
    "abladest": "abladen",
    "abladet": "abladen",
    "ablagere": "ablagern",
    "ablagernd": "ablagern",
    "ablagernde": "ablagernd",
    "ablagerndem": "ablagernd",
    "ablagernden": "ablagernd",
    "ablagernder": "ablagernd",
    "ablagerndes": "ablagernd",
    "ablagerst": "ablagern",
    "ablagert": "ablagern",
    "ablagerte": "ablagern",
    "ablagerten": "ablagern",
    "ablagertest": "ablagern",
    "ablagertet": "ablagern",
    "ablaktiere": "ablaktieren",
    "ablaktierend": "ablaktieren",
    "ablaktierende": "ablaktierend",
    "ablaktierendem": "ablaktierend",
    "ablaktierenden": "ablaktierend",
    "ablaktierender": "ablaktierend",
    "ablaktierendes": "ablaktierend",
    "ablaktierest": "ablaktieren",
    "ablaktieret": "ablaktieren",
    "ablaktierst": "ablaktieren",
    "ablaktiert": "ablaktieren",
    "ablaktierte": "ablaktieren",
    "ablaktiertem": "ablaktiert",
    "ablaktierten": "ablaktieren",
    "ablaktierter": "ablaktiert",
    "ablaktiertes": "ablaktiert",
    "ablaktiertest": "ablaktieren",
    "ablaktiertet": "ablaktieren",
    "ablas": "ablesen",
    "ablasen": "ablesen",
    "ablasse": "ablassen",
    "ablassend": "ablassen",
    "ablassende": "ablassend",
    "ablassendem": "ablassend",
    "ablassenden": "ablassend",
    "ablassender": "ablassend",
    "ablassendes": "ablassend",
    "ablassest": "ablassen",
    "ablasset": "ablassen",
    "ablast": "ablesen",
    "ablatsche": "ablatschen",
    "ablatschend": "ablatschen",
    "ablatschende": "ablatschend",
    "ablatschendem": "ablatschend",
    "ablatschenden": "ablatschend",
    "ablatschender": "ablatschend",
    "ablatschendere": "ablatschend",
    "ablatschenderem": "ablatschend",
    "ablatschenderen": "ablatschend",
    "ablatschenderer": "ablatschend",
    "ablatschenderes": "ablatschend",
    "ablatschendes": "ablatschend",
    "ablatschendste": "ablatschend",
    "ablatschendstem": "ablatschend",
    "ablatschendsten": "ablatschend",
    "ablatschendster": "ablatschend",
    "ablatschendstes": "ablatschend",
    "ablatschest": "ablatschen",
    "ablatschet": "ablatschen",
    "ablatschst": "ablatschen",
    "ablatscht": "ablatschen",
    "ablatschte": "ablatschen",
    "ablatschten": "ablatschen",
    "ablatschtest": "ablatschen",
    "ablatschtet": "ablatschen",
    "ablaufend": "ablaufen",
    "ablaufende": "ablaufend",
    "ablaufendem": "ablaufend",
    "ablaufenden": "ablaufend",
    "ablaufender": "ablaufend",
    "ablaufendes": "ablaufend",
    "ablaufest": "ablaufen",
    "ablaufet": "ablaufen",
    "ablauft": "ablaufen",
    "ablaute": "ablauten",
    "ablautend": "ablauten",
    "ablautende": "ablautend",
    "ablautendem": "ablautend",
    "ablautenden": "ablautend",
    "ablautender": "ablautend",
    "ablautendes": "ablautend",
    "ablautest": "ablauten",
    "ablautet": "ablauten",
    "ablautete": "ablauten",
    "ablauteten": "ablauten",
    "ablautetest": "ablauten",
    "ablautetet": "ablauten",
    "ablaßt": "ablassen",
    "ablebe": "ableben",
    "ablebend": "ableben",
    "ablebende": "ablebend",
    "ablebendem": "ablebend",
    "ablebenden": "ablebend",
    "ablebender": "ablebend",
    "ablebendes": "ablebend",
    "ablebest": "ableben",
    "ablebet": "ableben",
    "ablebst": "ableben",
    "ablebt": "ableben",
    "ablebte": "ableben",
    "ablebten": "ableben",
    "ablebtest": "ableben",
    "ablebtet": "ableben",
    "abledere": "abledern",
    "abledernd": "abledern",
    "abledernde": "abledernd",
    "ablederndem": "abledernd",
    "abledernden": "abledernd",
    "abledernder": "abledernd",
    "ablederndere": "abledernd",
    "abledernderem": "abledernd",
    "abledernderen": "abledernd",
    "abledernderer": "abledernd",
    "abledernderes": "abledernd",
    "ablederndes": "abledernd",
    "ablederndste": "abledernd",
    "ablederndstem": "abledernd",
    "ablederndsten": "abledernd",
    "ablederndster": "abledernd",
    "ablederndstes": "abledernd",
    "ablederst": "abledern",
    "abledert": "abledern",
    "ablederte": "abledern",
    "ablederten": "abledern",
    "abledertest": "abledern",
    "abledertet": "abledern",
    "ablege": "ablegen",
    "ablegend": "ablegen",
    "ablegende": "ablegend",
    "ablegendem": "ablegend",
    "ablegenden": "ablegend",
    "ablegender": "ablegend",
    "ablegendes": "ablegend",
    "ablegest": "ablegen",
    "ableget": "ablegen",
    "ablegst": "ablegen",
    "ablegt": "ablegen",
    "ablegte": "ablegen",
    "ablegten": "ablegen",
    "ablegtest": "ablegen",
    "ablegtet": "ablegen",
    "ablehne": "ablehnen",
    "ablehnend": "ablehnen",
    "ablehnende": "ablehnend",
    "ablehnendem": "ablehnend",
    "ablehnenden": "ablehnend",
    "ablehnender": "ablehnend",
    "ablehnendere": "ablehnend",
    "ablehnenderem": "ablehnend",
    "ablehnenderen": "ablehnend",
    "ablehnenderer": "ablehnend",
    "ablehnenderes": "ablehnend",
    "ablehnendes": "ablehnend",
    "ablehnendste": "ablehnend",
    "ablehnendstem": "ablehnend",
    "ablehnendsten": "ablehnend",
    "ablehnendster": "ablehnend",
    "ablehnendstes": "ablehnend",
    "ablehnest": "ablehnen",
    "ablehnet": "ablehnen",
    "ablehnst": "ablehnen",
    "ablehnt": "ablehnen",
    "ablehnte": "ablehnen",
    "ablehnten": "ablehnen",
    "ablehntest": "ablehnen",
    "ablehntet": "ablehnen",
    "ableiste": "ableisten",
    "ableistend": "ableisten",
    "ableistende": "ableistend",
    "ableistendem": "ableistend",
    "ableistenden": "ableistend",
    "ableistender": "ableistend",
    "ableistendes": "ableistend",
    "ableistest": "ableisten",
    "ableistet": "ableisten",
    "ableistete": "ableisten",
    "ableisteten": "ableisten",
    "ableistetest": "ableisten",
    "ableistetet": "ableisten",
    "ableitbare": "ableitbar",
    "ableitbarem": "ableitbar",
    "ableitbaren": "ableitbar",
    "ableitbarer": "ableitbar",
    "ableitbares": "ableitbar",
    "ableite": "ableiten",
    "ableitend": "ableiten",
    "ableitende": "ableitend",
    "ableitendem": "ableitend",
    "ableitenden": "ableitend",
    "ableitender": "ableitend",
    "ableitendes": "ableitend",
    "ableitest": "ableiten",
    "ableitet": "ableiten",
    "ableitete": "ableiten",
    "ableiteten": "ableiten",
    "ableitetest": "ableiten",
    "ableitetet": "ableiten",
    "ablenke": "ablenken",
    "ablenkend": "ablenken",
    "ablenkende": "ablenkend",
    "ablenkendem": "ablenkend",
    "ablenkenden": "ablenkend",
    "ablenkender": "ablenkend",
    "ablenkendere": "ablenkend",
    "ablenkenderem": "ablenkend",
    "ablenkenderen": "ablenkend",
    "ablenkenderer": "ablenkend",
    "ablenkenderes": "ablenkend",
    "ablenkendes": "ablenkend",
    "ablenkendste": "ablenkend",
    "ablenkendstem": "ablenkend",
    "ablenkendsten": "ablenkend",
    "ablenkendster": "ablenkend",
    "ablenkendstes": "ablenkend",
    "ablenkest": "ablenken",
    "ablenket": "ablenken",
    "ablenkst": "ablenken",
    "ablenkt": "ablenken",
    "ablenkte": "ablenken",
    "ablenkten": "ablenken",
    "ablenktest": "ablenken",
    "ablenktet": "ablenken",
    "ablese": "ablesen",
    "ablesend": "ablesen",
    "ablesende": "ablesend",
    "ablesendem": "ablesend",
    "ablesenden": "ablesend",
    "ablesender": "ablesend",
    "ablesendes": "ablesend",
    "ablesest": "ablesen",
    "ableset": "ablesen",
    "ablest": "ablesen",
    "ableuchte": "ableuchten",
    "ableuchtend": "ableuchten",
    "ableuchtende": "ableuchtend",
    "ableuchtendem": "ableuchtend",
    "ableuchtenden": "ableuchtend",
    "ableuchtender": "ableuchtend",
    "ableuchtendes": "ableuchtend",
    "ableuchtest": "ableuchten",
    "ableuchtet": "ableuchten",
    "ableuchtete": "ableuchten",
    "ableuchteten": "ableuchten",
    "ableuchtetest": "ableuchten",
    "ableuchtetet": "ableuchten",
    "ablichte": "ablichten",
    "ablichtend": "ablichten",
    "ablichtende": "ablichtend",
    "ablichtendem": "ablichtend",
    "ablichtenden": "ablichtend",
    "ablichtender": "ablichtend",
    "ablichtendes": "ablichtend",
    "ablichtest": "ablichten",
    "ablichtet": "ablichten",
    "ablichtete": "ablichten",
    "ablichteten": "ablichten",
    "ablichtetest": "ablichten",
    "ablichtetet": "ablichten",
    "ablief": "ablaufen",
    "abliefe": "ablaufen",
    "abliefen": "ablaufen",
    "abliefere": "abliefern",
    "abliefernd": "abliefern",
    "abliefernde": "abliefernd",
    "ablieferndem": "abliefernd",
    "abliefernden": "abliefernd",
    "abliefernder": "abliefernd",
    "ablieferndes": "abliefernd",
    "ablieferst": "abliefern",
    "abliefert": "abliefern",
    "ablieferte": "abliefern",
    "ablieferten": "abliefern",
    "abliefertest": "abliefern",
    "abliefertet": "abliefern",
    "abliefest": "ablaufen",
    "abliefet": "ablaufen",
    "abliefst": "ablaufen",
    "ablieft": "ablaufen",
    "abliest": "ablesen",
    "abließ": "ablassen",
    "abließe": "ablassen",
    "abließen": "ablassen",
    "abließest": "ablassen",
    "abließet": "ablassen",
    "abließt": "ablassen",
    "ablischst": "ablöschen",
    "ablischt": "ablöschen",
    "ablosch": "ablöschen",
    "abloschen": "ablöschen",
    "abloschst": "ablöschen",
    "abloscht": "ablöschen",
    "ablud": "abladen",
    "abluden": "abladen",
    "abludest": "abladen",
    "abludet": "abladen",
    "ablädst": "abladen",
    "ablädt": "abladen",
    "abläse": "ablesen",
    "abläsen": "ablesen",
    "abläsest": "ablesen",
    "abläset": "ablesen",
    "abläufst": "ablaufen",
    "abläuft": "ablaufen",
    "abläßt": "ablassen",
    "ablösche": "ablöschen",
    "ablöschend": "ablöschen",
    "ablöschende": "ablöschend",
    "ablöschendem": "ablöschend",
    "ablöschenden": "ablöschend",
    "ablöschender": "ablöschend",
    "ablöschendes": "ablöschend",
    "ablöschest": "ablöschen",
    "ablöschet": "ablöschen",
    "ablöschst": "ablöschen",
    "ablöscht": "ablöschen",
    "ablöschte": "ablöschen",
    "ablöschten": "ablöschen",
    "ablöschtest": "ablöschen",
    "ablöschtet": "ablöschen",
    "ablöse": "ablösen",
    "ablösend": "ablösen",
    "ablösende": "ablösend",
    "ablösendem": "ablösend",
    "ablösenden": "ablösend",
    "ablösender": "ablösend",
    "ablösendes": "ablösend",
    "ablösest": "ablösen",
    "ablöset": "ablösen",
    "ablöst": "ablösen",
    "ablöste": "ablösen",
    "ablösten": "ablösen",
    "ablöstest": "ablösen",
    "ablöstet": "ablösen",
    "ablüde": "abladen",
    "ablüden": "abladen",
    "ablüdest": "abladen",
    "ablüdet": "abladen",
    "abmache": "abmachen",
    "abmachend": "abmachen",
    "abmachende": "abmachend",
    "abmachendem": "abmachend",
    "abmachenden": "abmachend",
    "abmachender": "abmachend",
    "abmachendes": "abmachend",
    "abmachest": "abmachen",
    "abmachet": "abmachen",
    "abmachst": "abmachen",
    "abmacht": "abmachen",
    "abmachte": "abmachen",
    "abmachten": "abmachen",
    "abmachtest": "abmachen",
    "abmachtet": "abmachen",
    "abmagere": "abmagern",
    "abmagernd": "abmagern",
    "abmagernde": "abmagernd",
    "abmagerndem": "abmagernd",
    "abmagernden": "abmagernd",
    "abmagernder": "abmagernd",
    "abmagerndere": "abmagernd",
    "abmagernderem": "abmagernd",
    "abmagernderen": "abmagernd",
    "abmagernderer": "abmagernd",
    "abmagernderes": "abmagernd",
    "abmagerndes": "abmagernd",
    "abmagerndste": "abmagernd",
    "abmagerndstem": "abmagernd",
    "abmagerndsten": "abmagernd",
    "abmagerndster": "abmagernd",
    "abmagerndstes": "abmagernd",
    "abmagerst": "abmagern",
    "abmagert": "abmagern",
    "abmagerte": "abmagern",
    "abmagerten": "abmagern",
    "abmagertest": "abmagern",
    "abmagertet": "abmagern",
    "abmale": "abmalen",
    "abmalend": "abmalen",
    "abmalende": "abmalend",
    "abmalendem": "abmalend",
    "abmalenden": "abmalend",
    "abmalender": "abmalend",
    "abmalendes": "abmalend",
    "abmalest": "abmalen",
    "abmalet": "abmalen",
    "abmalst": "abmalen",
    "abmalt": "abmalen",
    "abmalte": "abmalen",
    "abmalten": "abmalen",
    "abmaltest": "abmalen",
    "abmaltet": "abmalen",
    "abmarschiere": "abmarschieren",
    "abmarschierend": "abmarschieren",
    "abmarschierende": "abmarschierend",
    "abmarschierendem": "abmarschierend",
    "abmarschierenden": "abmarschierend",
    "abmarschierender": "abmarschierend",
    "abmarschierendes": "abmarschierend",
    "abmarschierest": "abmarschieren",
    "abmarschieret": "abmarschieren",
    "abmarschierst": "abmarschieren",
    "abmarschiert": "abmarschieren",
    "abmarschierte": "abmarschieren",
    "abmarschiertem": "abmarschiert",
    "abmarschierten": "abmarschieren",
    "abmarschierter": "abmarschiert",
    "abmarschiertes": "abmarschiert",
    "abmarschiertest": "abmarschieren",
    "abmarschiertet": "abmarschieren",
    "abmaß": "abmessen",
    "abmaßen": "abmessen",
    "abmaßt": "abmessen",
    "abmelde": "abmelden",
    "abmeldend": "abmelden",
    "abmeldende": "abmeldend",
    "abmeldendem": "abmeldend",
    "abmeldenden": "abmeldend",
    "abmeldender": "abmeldend",
    "abmeldendes": "abmeldend",
    "abmeldest": "abmelden",
    "abmeldet": "abmelden",
    "abmeldete": "abmelden",
    "abmeldeten": "abmelden",
    "abmeldetest": "abmelden",
    "abmeldetet": "abmelden",
    "abmesse": "abmessen",
    "abmessend": "abmessen",
    "abmessende": "abmessend",
    "abmessendem": "abmessend",
    "abmessenden": "abmessend",
    "abmessender": "abmessend",
    "abmessendes": "abmessend",
    "abmessest": "abmessen",
    "abmesset": "abmessen",
    "abmeßt": "abmessen",
    "abmildere": "abmildern",
    "abmildernd": "abmildern",
    "abmildernde": "abmildernd",
    "abmilderndem": "abmildernd",
    "abmildernden": "abmildernd",
    "abmildernder": "abmildernd",
    "abmilderndes": "abmildernd",
    "abmilderst": "abmildern",
    "abmildert": "abmildern",
    "abmilderte": "abmildern",
    "abmilderten": "abmildern",
    "abmildertest": "abmildern",
    "abmildertet": "abmildern",
    "abmißt": "abmessen",
    "abmontiere": "abmontieren",
    "abmontierend": "abmontieren",
    "abmontierende": "abmontierend",
    "abmontierendem": "abmontierend",
    "abmontierenden": "abmontierend",
    "abmontierender": "abmontierend",
    "abmontierendes": "abmontierend",
    "abmontierest": "abmontieren",
    "abmontieret": "abmontieren",
    "abmontierst": "abmontieren",
    "abmontiert": "abmontieren",
    "abmontierte": "abmontieren",
    "abmontiertem": "abmontiert",
    "abmontierten": "abmontieren",
    "abmontierter": "abmontiert",
    "abmontiertes": "abmontiert",
    "abmontiertest": "abmontieren",
    "abmontiertet": "abmontieren",
    "abmurkse": "abmurksen",
    "abmurksend": "abmurksen",
    "abmurksende": "abmurksend",
    "abmurksendem": "abmurksend",
    "abmurksenden": "abmurksend",
    "abmurksender": "abmurksend",
    "abmurksendes": "abmurksend",
    "abmurksest": "abmurksen",
    "abmurkset": "abmurksen",
    "abmurkst": "abmurksen",
    "abmurkste": "abmurksen",
    "abmurksten": "abmurksen",
    "abmurkstest": "abmurksen",
    "abmurkstet": "abmurksen",
    "abmustere": "abmustern",
    "abmusternd": "abmustern",
    "abmusternde": "abmusternd",
    "abmusterndem": "abmusternd",
    "abmusternden": "abmusternd",
    "abmusternder": "abmusternd",
    "abmusterndes": "abmusternd",
    "abmusterst": "abmustern",
    "abmustert": "abmustern",
    "abmusterte": "abmustern",
    "abmusterten": "abmustern",
    "abmustertest": "abmustern",
    "abmustertet": "abmustern",
    "abmähe": "abmähen",
    "abmähend": "abmähen",
    "abmähende": "abmähend",
    "abmähendem": "abmähend",
    "abmähenden": "abmähend",
    "abmähender": "abmähend",
    "abmähendere": "abmähend",
    "abmähenderem": "abmähend",
    "abmähenderen": "abmähend",
    "abmähenderer": "abmähend",
    "abmähenderes": "abmähend",
    "abmähendes": "abmähend",
    "abmähendste": "abmähend",
    "abmähendstem": "abmähend",
    "abmähendsten": "abmähend",
    "abmähendster": "abmähend",
    "abmähendstes": "abmähend",
    "abmähest": "abmähen",
    "abmähet": "abmähen",
    "abmähst": "abmähen",
    "abmäht": "abmähen",
    "abmähte": "abmähen",
    "abmähten": "abmähen",
    "abmähtest": "abmähen",
    "abmähtet": "abmähen",
    "abmäße": "abmessen",
    "abmäßen": "abmessen",
    "abmäßest": "abmessen",
    "abmäßet": "abmessen",
    "abmühe": "abmühen",
    "abmühend": "abmühen",
    "abmühende": "abmühend",
    "abmühendem": "abmühend",
    "abmühenden": "abmühend",
    "abmühender": "abmühend",
    "abmühendes": "abmühend",
    "abmühest": "abmühen",
    "abmühet": "abmühen",
    "abmühst": "abmühen",
    "abmüht": "abmühen",
    "abmühte": "abmühen",
    "abmühten": "abmühen",
    "abmühtest": "abmühen",
    "abmühtet": "abmühen",
    "abnabele": "abnabeln",
    "abnabelnd": "abnabeln",
    "abnabelnde": "abnabelnd",
    "abnabelndem": "abnabelnd",
    "abnabelnden": "abnabelnd",
    "abnabelnder": "abnabelnd",
    "abnabelndes": "abnabelnd",
    "abnabelst": "abnabeln",
    "abnabelt": "abnabeln",
    "abnabelte": "abnabeln",
    "abnabelten": "abnabeln",
    "abnabeltest": "abnabeln",
    "abnabeltet": "abnabeln",
    "abnable": "abnabeln",
    "abnage": "abnagen",
    "abnagend": "abnagen",
    "abnagende": "abnagend",
    "abnagendem": "abnagend",
    "abnagenden": "abnagend",
    "abnagender": "abnagend",
    "abnagendere": "abnagend",
    "abnagenderem": "abnagend",
    "abnagenderen": "abnagend",
    "abnagenderer": "abnagend",
    "abnagenderes": "abnagend",
    "abnagendes": "abnagend",
    "abnagendste": "abnagend",
    "abnagendstem": "abnagend",
    "abnagendsten": "abnagend",
    "abnagendster": "abnagend",
    "abnagendstes": "abnagend",
    "abnagest": "abnagen",
    "abnaget": "abnagen",
    "abnagst": "abnagen",
    "abnagt": "abnagen",
    "abnagte": "abnagen",
    "abnagten": "abnagen",
    "abnagtest": "abnagen",
    "abnagtet": "abnagen",
    "abnahm": "abnehmen",
    "abnahmen": "abnehmen",
    "abnahmst": "abnehmen",
    "abnahmt": "abnehmen",
    "abnehmbare": "abnehmbar",
    "abnehmbarem": "abnehmbar",
    "abnehmbaren": "abnehmbar",
    "abnehmbarer": "abnehmbar",
    "abnehmbares": "abnehmbar",
    "abnehme": "abnehmen",
    "abnehmend": "abnehmen",
    "abnehmende": "abnehmend",
    "abnehmendem": "abnehmend",
    "abnehmenden": "abnehmend",
    "abnehmender": "abnehmend",
    "abnehmendes": "abnehmend",
    "abnehmest": "abnehmen",
    "abnehmet": "abnehmen",
    "abnehmt": "abnehmen",
    "abneige": "abneigen",
    "abneigend": "abneigen",
    "abneigende": "abneigend",
    "abneigendem": "abneigend",
    "abneigenden": "abneigend",
    "abneigender": "abneigend",
    "abneigendes": "abneigend",
    "abneigest": "abneigen",
    "abneiget": "abneigen",
    "abneigst": "abneigen",
    "abneigt": "abneigen",
    "abneigte": "abneigen",
    "abneigten": "abneigen",
    "abneigtest": "abneigen",
    "abneigtet": "abneigen",
    "abnimmst": "abnehmen",
    "abnimmt": "abnehmen",
    "abnormale": "abnormal",
    "abnormalem": "abnormal",
    "abnormalen": "abnormal",
    "abnormaler": "abnormal",
    "abnormales": "abnormal",
    "abnorme": "abnorm",
    "abnormem": "abnorm",
    "abnormen": "abnorm",
    "abnormer": "abnorm",
    "abnormes": "abnorm",
    "abnutze": "abnutzen",
    "abnutzend": "abnutzen",
    "abnutzende": "abnutzend",
    "abnutzendem": "abnutzend",
    "abnutzenden": "abnutzend",
    "abnutzender": "abnutzend",
    "abnutzendes": "abnutzend",
    "abnutzest": "abnutzen",
    "abnutzet": "abnutzen",
    "abnutzt": "abnutzen",
    "abnutzte": "abnutzen",
    "abnutzten": "abnutzen",
    "abnutztest": "abnutzen",
    "abnutztet": "abnutzen",
    "abnähe": "abnähen",
    "abnähend": "abnähen",
    "abnähende": "abnähend",
    "abnähendem": "abnähend",
    "abnähenden": "abnähend",
    "abnähender": "abnähend",
    "abnähendes": "abnähend",
    "abnähest": "abnähen",
    "abnähet": "abnähen",
    "abnähme": "abnehmen",
    "abnähmen": "abnehmen",
    "abnähmest": "abnehmen",
    "abnähmet": "abnehmen",
    "abnähst": "abnähen",
    "abnäht": "abnähen",
    "abnähte": "abnähen",
    "abnähten": "abnähen",
    "abnähtest": "abnähen",
    "abnähtet": "abnähen",
    "abonniere": "abonnieren",
    "abonnierend": "abonnieren",
    "abonnierende": "abonnierend",
    "abonnierendem": "abonnierend",
    "abonnierenden": "abonnierend",
    "abonnierender": "abonnierend",
    "abonnierendere": "abonnierend",
    "abonnierenderem": "abonnierend",
    "abonnierenderen": "abonnierend",
    "abonnierenderer": "abonnierend",
    "abonnierenderes": "abonnierend",
    "abonnierendes": "abonnierend",
    "abonnierendste": "abonnierend",
    "abonnierendstem": "abonnierend",
    "abonnierendsten": "abonnierend",
    "abonnierendster": "abonnierend",
    "abonnierendstes": "abonnierend",
    "abonnierest": "abonnieren",
    "abonnieret": "abonnieren",
    "abonnierst": "abonnieren",
    "abonniert": "abonnieren",
    "abonnierte": "abonnieren",
    "abonniertem": "abonniert",
    "abonnierten": "abonnieren",
    "abonnierter": "abonniert",
    "abonniertes": "abonniert",
    "abonniertest": "abonnieren",
    "abonniertet": "abonnieren",
    "abordne": "abordnen",
    "abordnend": "abordnen",
    "abordnende": "abordnend",
    "abordnendem": "abordnend",
    "abordnenden": "abordnend",
    "abordnender": "abordnend",
    "abordnendes": "abordnend",
    "abordnest": "abordnen",
    "abordnet": "abordnen",
    "abordnete": "abordnen",
    "abordneten": "abordnen",
    "abordnetest": "abordnen",
    "abordnetet": "abordnen",
    "abpasse": "abpassen",
    "abpassend": "abpassen",
    "abpassende": "abpassend",
    "abpassendem": "abpassend",
    "abpassenden": "abpassend",
    "abpassender": "abpassend",
    "abpassendes": "abpassend",
    "abpassest": "abpassen",
    "abpasset": "abpassen",
    "abpaßt": "abpassen",
    "abpaßte": "abpassen",
    "abpaßten": "abpassen",
    "abpaßtest": "abpassen",
    "abpaßtet": "abpassen",
    "abpelle": "abpellen",
    "abpellend": "abpellen",
    "abpellende": "abpellend",
    "abpellendem": "abpellend",
    "abpellenden": "abpellend",
    "abpellender": "abpellend",
    "abpellendere": "abpellend",
    "abpellenderem": "abpellend",
    "abpellenderen": "abpellend",
    "abpellenderer": "abpellend",
    "abpellenderes": "abpellend",
    "abpellendes": "abpellend",
    "abpellendste": "abpellend",
    "abpellendstem": "abpellend",
    "abpellendsten": "abpellend",
    "abpellendster": "abpellend",
    "abpellendstes": "abpellend",
    "abpellest": "abpellen",
    "abpellet": "abpellen",
    "abpellst": "abpellen",
    "abpellt": "abpellen",
    "abpellte": "abpellen",
    "abpellten": "abpellen",
    "abpelltest": "abpellen",
    "abpelltet": "abpellen",
    "abpfeife": "abpfeifen",
    "abpfeifend": "abpfeifen",
    "abpfeifende": "abpfeifend",
    "abpfeifendem": "abpfeifend",
    "abpfeifenden": "abpfeifend",
    "abpfeifender": "abpfeifend",
    "abpfeifendes": "abpfeifend",
    "abpfeifest": "abpfeifen",
    "abpfeifet": "abpfeifen",
    "abpfeifst": "abpfeifen",
    "abpfeift": "abpfeifen",
    "abpfiff": "abpfeifen",
    "abpfiffe": "abpfeifen",
    "abpfiffen": "abpfeifen",
    "abpfiffest": "abpfeifen",
    "abpfiffet": "abpfeifen",
    "abpfiffst": "abpfeifen",
    "abpfifft": "abpfeifen",
    "abplatze": "abplatzen",
    "abplatzend": "abplatzen",
    "abplatzende": "abplatzend",
    "abplatzendem": "abplatzend",
    "abplatzenden": "abplatzend",
    "abplatzender": "abplatzend",
    "abplatzendere": "abplatzend",
    "abplatzenderem": "abplatzend",
    "abplatzenderen": "abplatzend",
    "abplatzenderer": "abplatzend",
    "abplatzenderes": "abplatzend",
    "abplatzendes": "abplatzend",
    "abplatzendste": "abplatzend",
    "abplatzendstem": "abplatzend",
    "abplatzendsten": "abplatzend",
    "abplatzendster": "abplatzend",
    "abplatzendstes": "abplatzend",
    "abplatzest": "abplatzen",
    "abplatzet": "abplatzen",
    "abplatzt": "abplatzen",
    "abplatzte": "abplatzen",
    "abplatzten": "abplatzen",
    "abplatztest": "abplatzen",
    "abplatztet": "abplatzen",
    "abpralle": "abprallen",
    "abprallend": "abprallen",
    "abprallende": "abprallend",
    "abprallendem": "abprallend",
    "abprallenden": "abprallend",
    "abprallender": "abprallend",
    "abprallendes": "abprallend",
    "abprallest": "abprallen",
    "abprallet": "abprallen",
    "abprallst": "abprallen",
    "abprallt": "abprallen",
    "abprallte": "abprallen",
    "abprallten": "abprallen",
    "abpralltest": "abprallen",
    "abpralltet": "abprallen",
    "abpresse": "abpressen",
    "abpressend": "abpressen",
    "abpressende": "abpressend",
    "abpressendem": "abpressend",
    "abpressenden": "abpressend",
    "abpressender": "abpressend",
    "abpressendes": "abpressend",
    "abpressest": "abpressen",
    "abpresset": "abpressen",
    "abpreßt": "abpressen",
    "abpreßte": "abpressen",
    "abpreßten": "abpressen",
    "abpreßtest": "abpressen",
    "abpreßtet": "abpressen",
    "abpumpe": "abpumpen",
    "abpumpend": "abpumpen",
    "abpumpende": "abpumpend",
    "abpumpendem": "abpumpend",
    "abpumpenden": "abpumpend",
    "abpumpender": "abpumpend",
    "abpumpendere": "abpumpend",
    "abpumpenderem": "abpumpend",
    "abpumpenderen": "abpumpend",
    "abpumpenderer": "abpumpend",
    "abpumpenderes": "abpumpend",
    "abpumpendes": "abpumpend",
    "abpumpendste": "abpumpend",
    "abpumpendstem": "abpumpend",
    "abpumpendsten": "abpumpend",
    "abpumpendster": "abpumpend",
    "abpumpendstes": "abpumpend",
    "abpumpest": "abpumpen",
    "abpumpet": "abpumpen",
    "abpumpst": "abpumpen",
    "abpumpt": "abpumpen",
    "abpumpte": "abpumpen",
    "abpumpten": "abpumpen",
    "abpumptest": "abpumpen",
    "abpumptet": "abpumpen",
    "abputze": "abputzen",
    "abputzend": "abputzen",
    "abputzende": "abputzend",
    "abputzendem": "abputzend",
    "abputzenden": "abputzend",
    "abputzender": "abputzend",
    "abputzendes": "abputzend",
    "abputzest": "abputzen",
    "abputzet": "abputzen",
    "abputzt": "abputzen",
    "abputzte": "abputzen",
    "abputzten": "abputzen",
    "abputztest": "abputzen",
    "abputztet": "abputzen",
    "abqualifiziere": "abqualifizieren",
    "abqualifizierend": "abqualifizieren",
    "abqualifizierende": "abqualifizierend",
    "abqualifizierendem": "abqualifizierend",
    "abqualifizierenden": "abqualifizierend",
    "abqualifizierender": "abqualifizierend",
    "abqualifizierendere": "abqualifizierend",
    "abqualifizierenderem": "abqualifizierend",
    "abqualifizierenderen": "abqualifizierend",
    "abqualifizierenderer": "abqualifizierend",
    "abqualifizierenderes": "abqualifizierend",
    "abqualifizierendes": "abqualifizierend",
    "abqualifizierendste": "abqualifizierend",
    "abqualifizierendstem": "abqualifizierend",
    "abqualifizierendsten": "abqualifizierend",
    "abqualifizierendster": "abqualifizierend",
    "abqualifizierendstes": "abqualifizierend",
    "abqualifizierest": "abqualifizieren",
    "abqualifizieret": "abqualifizieren",
    "abqualifizierst": "abqualifizieren",
    "abqualifiziert": "abqualifizieren",
    "abqualifizierte": "abqualifizieren",
    "abqualifiziertem": "abqualifiziert",
    "abqualifizierten": "abqualifizieren",
    "abqualifizierter": "abqualifiziert",
    "abqualifiziertere": "abqualifiziert",
    "abqualifizierterem": "abqualifiziert",
    "abqualifizierteren": "abqualifiziert",
    "abqualifizierterer": "abqualifiziert",
    "abqualifizierteres": "abqualifiziert",
    "abqualifiziertes": "abqualifiziert",
    "abqualifiziertest": "abqualifizieren",
    "abqualifizierteste": "abqualifiziert",
    "abqualifiziertestem": "abqualifiziert",
    "abqualifiziertesten": "abqualifiziert",
    "abqualifiziertester": "abqualifiziert",
    "abqualifiziertestes": "abqualifiziert",
    "abqualifiziertet": "abqualifizieren",
    "abquetsche": "abquetschen",
    "abquetschend": "abquetschen",
    "abquetschende": "abquetschend",
    "abquetschendem": "abquetschend",
    "abquetschenden": "abquetschend",
    "abquetschender": "abquetschend",
    "abquetschendere": "abquetschend",
    "abquetschenderem": "abquetschend",
    "abquetschenderen": "abquetschend",
    "abquetschenderer": "abquetschend",
    "abquetschenderes": "abquetschend",
    "abquetschendes": "abquetschend",
    "abquetschendste": "abquetschend",
    "abquetschendstem": "abquetschend",
    "abquetschendsten": "abquetschend",
    "abquetschendster": "abquetschend",
    "abquetschendstes": "abquetschend",
    "abquetschest": "abquetschen",
    "abquetschet": "abquetschen",
    "abquetschst": "abquetschen",
    "abquetscht": "abquetschen",
    "abquetschte": "abquetschen",
    "abquetschten": "abquetschen",
    "abquetschtest": "abquetschen",
    "abquetschtet": "abquetschen",
    "abquäle": "abquälen",
    "abquälend": "abquälen",
    "abquälende": "abquälend",
    "abquälendem": "abquälend",
    "abquälenden": "abquälend",
    "abquälender": "abquälend",
    "abquälendere": "abquälend",
    "abquälenderem": "abquälend",
    "abquälenderen": "abquälend",
    "abquälenderer": "abquälend",
    "abquälenderes": "abquälend",
    "abquälendes": "abquälend",
    "abquälendste": "abquälend",
    "abquälendstem": "abquälend",
    "abquälendsten": "abquälend",
    "abquälendster": "abquälend",
    "abquälendstes": "abquälend",
    "abquälest": "abquälen",
    "abquälet": "abquälen",
    "abquälst": "abquälen",
    "abquält": "abquälen",
    "abquälte": "abquälen",
    "abquälten": "abquälen",
    "abquältest": "abquälen",
    "abquältet": "abquälen",
    "abrang": "abringen",
    "abrangen": "abringen",
    "abrangst": "abringen",
    "abrangt": "abringen",
    "abrasiere": "abrasieren",
    "abrasierend": "abrasieren",
    "abrasierende": "abrasierend",
    "abrasierendem": "abrasierend",
    "abrasierenden": "abrasierend",
    "abrasierender": "abrasierend",
    "abrasierendes": "abrasierend",
    "abrasierest": "abrasieren",
    "abrasieret": "abrasieren",
    "abrasierst": "abrasieren",
    "abrasiert": "abrasieren",
    "abrasierte": "abrasieren",
    "abrasiertem": "abrasiert",
    "abrasierten": "abrasieren",
    "abrasierter": "abrasiert",
    "abrasiertes": "abrasiert",
    "abrasiertest": "abrasieren",
    "abrasiertet": "abrasieren",
    "abrate": "abraten",
    "abratend": "abraten",
    "abratende": "abratend",
    "abratendem": "abratend",
    "abratenden": "abratend",
    "abratender": "abratend",
    "abratendes": "abratend",
    "abratest": "abraten",
    "abratet": "abraten",
    "abrausche": "abrauschen",
    "abrauschend": "abrauschen",
    "abrauschende": "abrauschend",
    "abrauschendem": "abrauschend",
    "abrauschenden": "abrauschend",
    "abrauschender": "abrauschend",
    "abrauschendere": "abrauschend",
    "abrauschenderem": "abrauschend",
    "abrauschenderen": "abrauschend",
    "abrauschenderer": "abrauschend",
    "abrauschenderes": "abrauschend",
    "abrauschendes": "abrauschend",
    "abrauschendste": "abrauschend",
    "abrauschendstem": "abrauschend",
    "abrauschendsten": "abrauschend",
    "abrauschendster": "abrauschend",
    "abrauschendstes": "abrauschend",
    "abrauschest": "abrauschen",
    "abrauschet": "abrauschen",
    "abrauschst": "abrauschen",
    "abrauscht": "abrauschen",
    "abrauschte": "abrauschen",
    "abrauschten": "abrauschen",
    "abrauschtest": "abrauschen",
    "abrauschtet": "abrauschen",
    "abreagiere": "abreagieren",
    "abreagierend": "abreagieren",
    "abreagierende": "abreagierend",
    "abreagierendem": "abreagierend",
    "abreagierenden": "abreagierend",
    "abreagierender": "abreagierend",
    "abreagierendere": "abreagierend",
    "abreagierenderem": "abreagierend",
    "abreagierenderen": "abreagierend",
    "abreagierenderer": "abreagierend",
    "abreagierenderes": "abreagierend",
    "abreagierendes": "abreagierend",
    "abreagierendste": "abreagierend",
    "abreagierendstem": "abreagierend",
    "abreagierendsten": "abreagierend",
    "abreagierendster": "abreagierend",
    "abreagierendstes": "abreagierend",
    "abreagierest": "abreagieren",
    "abreagieret": "abreagieren",
    "abreagierst": "abreagieren",
    "abreagiert": "abreagieren",
    "abreagierte": "abreagieren",
    "abreagiertem": "abreagiert",
    "abreagierten": "abreagieren",
    "abreagierter": "abreagiert",
    "abreagiertere": "abreagiert",
    "abreagierterem": "abreagiert",
    "abreagierteren": "abreagiert",
    "abreagierterer": "abreagiert",
    "abreagierteres": "abreagiert",
    "abreagiertes": "abreagiert",
    "abreagiertest": "abreagieren",
    "abreagierteste": "abreagiert",
    "abreagiertestem": "abreagiert",
    "abreagiertesten": "abreagiert",
    "abreagiertester": "abreagiert",
    "abreagiertestes": "abreagiert",
    "abreagiertet": "abreagieren",
    "abrechne": "abrechnen",
    "abrechnend": "abrechnen",
    "abrechnende": "abrechnend",
    "abrechnendem": "abrechnend",
    "abrechnenden": "abrechnend",
    "abrechnender": "abrechnend",
    "abrechnendes": "abrechnend",
    "abrechnest": "abrechnen",
    "abrechnet": "abrechnen",
    "abrechnete": "abrechnen",
    "abrechneten": "abrechnen",
    "abrechnetest": "abrechnen",
    "abrechnetet": "abrechnen",
    "abrege": "abregen",
    "abregend": "abregen",
    "abregende": "abregend",
    "abregendem": "abregend",
    "abregenden": "abregend",
    "abregender": "abregend",
    "abregendes": "abregend",
    "abregest": "abregen",
    "abreget": "abregen",
    "abregst": "abregen",
    "abregt": "abregen",
    "abregte": "abregen",
    "abregten": "abregen",
    "abregtest": "abregen",
    "abregtet": "abregen",
    "abreibe": "abreiben",
    "abreibend": "abreiben",
    "abreibende": "abreibend",
    "abreibendem": "abreibend",
    "abreibenden": "abreibend",
    "abreibender": "abreibend",
    "abreibendere": "abreibend",
    "abreibenderem": "abreibend",
    "abreibenderen": "abreibend",
    "abreibenderer": "abreibend",
    "abreibenderes": "abreibend",
    "abreibendes": "abreibend",
    "abreibendste": "abreibend",
    "abreibendstem": "abreibend",
    "abreibendsten": "abreibend",
    "abreibendster": "abreibend",
    "abreibendstes": "abreibend",
    "abreibest": "abreiben",
    "abreibet": "abreiben",
    "abreibst": "abreiben",
    "abreibt": "abreiben",
    "abreiche": "abreichen",
    "abreichend": "abreichen",
    "abreichende": "abreichend",
    "abreichendem": "abreichend",
    "abreichenden": "abreichend",
    "abreichender": "abreichend",
    "abreichendes": "abreichend",
    "abreichest": "abreichen",
    "abreichet": "abreichen",
    "abreichst": "abreichen",
    "abreicht": "abreichen",
    "abreichte": "abreichen",
    "abreichten": "abreichen",
    "abreichtest": "abreichen",
    "abreichtet": "abreichen",
    "abreise": "abreisen",
    "abreisend": "abreisen",
    "abreisende": "abreisend",
    "abreisendem": "abreisend",
    "abreisenden": "abreisend",
    "abreisender": "abreisend",
    "abreisendes": "abreisend",
    "abreisest": "abreisen",
    "abreiset": "abreisen",
    "abreist": "abreisen",
    "abreiste": "abreisen",
    "abreisten": "abreisen",
    "abreistest": "abreisen",
    "abreistet": "abreisen",
    "abreite": "abreiten",
    "abreitend": "abreiten",
    "abreitende": "abreitend",
    "abreitendem": "abreitend",
    "abreitenden": "abreitend",
    "abreitender": "abreitend",
    "abreitendes": "abreitend",
    "abreitest": "abreiten",
    "abreitet": "abreiten",
    "abreiße": "abreißen",
    "abreißend": "abreißen",
    "abreißende": "abreißend",
    "abreißendem": "abreißend",
    "abreißenden": "abreißend",
    "abreißender": "abreißend",
    "abreißendes": "abreißend",
    "abreißest": "abreißen",
    "abreißet": "abreißen",
    "abreißt": "abreißen",
    "abrichte": "abrichten",
    "abrichtend": "abrichten",
    "abrichtende": "abrichtend",
    "abrichtendem": "abrichtend",
    "abrichtenden": "abrichtend",
    "abrichtender": "abrichtend",
    "abrichtendes": "abrichtend",
    "abrichtest": "abrichten",
    "abrichtet": "abrichten",
    "abrichtete": "abrichten",
    "abrichteten": "abrichten",
    "abrichtetest": "abrichten",
    "abrichtetet": "abrichten",
    "abrieb": "abreiben",
    "abriebe": "abreiben",
    "abrieben": "abreiben",
    "abriebest": "abreiben",
    "abriebet": "abreiben",
    "abriebfeste": "abriebfest",
    "abriebfestem": "abriebfest",
    "abriebfesten": "abriebfest",
    "abriebfester": "abriebfest",
    "abriebfestere": "abriebfest",
    "abriebfesterem": "abriebfest",
    "abriebfesteren": "abriebfest",
    "abriebfesterer": "abriebfest",
    "abriebfesteres": "abriebfest",
    "abriebfestes": "abriebfest",
    "abriebfesteste": "abriebfest",
    "abriebfestestem": "abriebfest",
    "abriebfestesten": "abriebfest",
    "abriebfestester": "abriebfest",
    "abriebfestestes": "abriebfest",
    "abriebst": "abreiben",
    "abriebt": "abreiben",
    "abrief": "abrufen",
    "abriefe": "abrufen",
    "abriefen": "abrufen",
    "abriefest": "abrufen",
    "abriefet": "abrufen",
    "abriefst": "abrufen",
    "abrieft": "abrufen",
    "abriegele": "abriegeln",
    "abriegelnd": "abriegeln",
    "abriegelnde": "abriegelnd",
    "abriegelndem": "abriegelnd",
    "abriegelnden": "abriegelnd",
    "abriegelnder": "abriegelnd",
    "abriegelndes": "abriegelnd",
    "abriegelst": "abriegeln",
    "abriegelt": "abriegeln",
    "abriegelte": "abriegeln",
    "abriegelten": "abriegeln",
    "abriegeltest": "abriegeln",
    "abriegeltet": "abriegeln",
    "abriegle": "abriegeln",
    "abriet": "abraten",
    "abriete": "abraten",
    "abrieten": "abraten",
    "abrietest": "abraten",
    "abrietet": "abraten",
    "abriffele": "abriffeln",
    "abriffelnd": "abriffeln",
    "abriffelnde": "abriffelnd",
    "abriffelndem": "abriffelnd",
    "abriffelnden": "abriffelnd",
    "abriffelnder": "abriffelnd",
    "abriffelndes": "abriffelnd",
    "abriffelst": "abriffeln",
    "abriffelt": "abriffeln",
    "abriffelte": "abriffeln",
    "abriffelten": "abriffeln",
    "abriffeltest": "abriffeln",
    "abriffeltet": "abriffeln",
    "abriffle": "abriffeln",
    "abrinde": "abrinden",
    "abrindend": "abrinden",
    "abrindende": "abrindend",
    "abrindendem": "abrindend",
    "abrindenden": "abrindend",
    "abrindender": "abrindend",
    "abrindendes": "abrindend",
    "abrindest": "abrinden",
    "abrindet": "abrinden",
    "abrindete": "abrinden",
    "abrindeten": "abrinden",
    "abrindetest": "abrinden",
    "abrindetet": "abrinden",
    "abringe": "abringen",
    "abringend": "abringen",
    "abringende": "abringend",
    "abringendem": "abringend",
    "abringenden": "abringend",
    "abringender": "abringend",
    "abringendes": "abringend",
    "abringest": "abringen",
    "abringet": "abringen",
    "abringst": "abringen",
    "abringt": "abringen",
    "abrisse": "abreißen",
    "abrissen": "abreißen",
    "abrissest": "abreißen",
    "abrisset": "abreißen",
    "abritt": "abreiten",
    "abritte": "abreiten",
    "abritten": "abreiten",
    "abrittest": "abreiten",
    "abrittet": "abreiten",
    "abriß": "abreißen",
    "abrißt": "abreißen",
    "abrode": "abroden",
    "abrodend": "abroden",
    "abrodende": "abrodend",
    "abrodendem": "abrodend",
    "abrodenden": "abrodend",
    "abrodender": "abrodend",
    "abrodendere": "abrodend",
    "abrodenderem": "abrodend",
    "abrodenderen": "abrodend",
    "abrodenderer": "abrodend",
    "abrodenderes": "abrodend",
    "abrodendes": "abrodend",
    "abrodendste": "abrodend",
    "abrodendstem": "abrodend",
    "abrodendsten": "abrodend",
    "abrodendster": "abrodend",
    "abrodendstes": "abrodend",
    "abrodest": "abroden",
    "abrodet": "abroden",
    "abrodete": "abroden",
    "abrodeten": "abroden",
    "abrodetest": "abroden",
    "abrodetet": "abroden",
    "abrolle": "abrollen",
    "abrollend": "abrollen",
    "abrollende": "abrollend",
    "abrollendem": "abrollend",
    "abrollenden": "abrollend",
    "abrollender": "abrollend",
    "abrollendere": "abrollend",
    "abrollenderem": "abrollend",
    "abrollenderen": "abrollend",
    "abrollenderer": "abrollend",
    "abrollenderes": "abrollend",
    "abrollendes": "abrollend",
    "abrollendste": "abrollend",
    "abrollendstem": "abrollend",
    "abrollendsten": "abrollend",
    "abrollendster": "abrollend",
    "abrollendstes": "abrollend",
    "abrollest": "abrollen",
    "abrollet": "abrollen",
    "abrollst": "abrollen",
    "abrollt": "abrollen",
    "abrollte": "abrollen",
    "abrollten": "abrollen",
    "abrolltest": "abrollen",
    "abrolltet": "abrollen",
    "abrudere": "abrudern",
    "abrudernd": "abrudern",
    "abrudernde": "abrudernd",
    "abruderndem": "abrudernd",
    "abrudernden": "abrudernd",
    "abrudernder": "abrudernd",
    "abruderndes": "abrudernd",
    "abruderst": "abrudern",
    "abrudert": "abrudern",
    "abruderte": "abrudern",
    "abruderten": "abrudern",
    "abrudertest": "abrudern",
    "abrudertet": "abrudern",
    "abrufe": "abrufen",
    "abrufend": "abrufen",
    "abrufende": "abrufend",
    "abrufendem": "abrufend",
    "abrufenden": "abrufend",
    "abrufender": "abrufend",
    "abrufendes": "abrufend",
    "abrufest": "abrufen",
    "abrufet": "abrufen",
    "abrufst": "abrufen",
    "abruft": "abrufen",
    "abrunde": "abrunden",
    "abrundend": "abrunden",
    "abrundende": "abrundend",
    "abrundendem": "abrundend",
    "abrundenden": "abrundend",
    "abrundender": "abrundend",
    "abrundendes": "abrundend",
    "abrundest": "abrunden",
    "abrundet": "abrunden",
    "abrundete": "abrunden",
    "abrundeten": "abrunden",
    "abrundetest": "abrunden",
    "abrundetet": "abrunden",
    "abrupfe": "abrupfen",
    "abrupfend": "abrupfen",
    "abrupfende": "abrupfend",
    "abrupfendem": "abrupfend",
    "abrupfenden": "abrupfend",
    "abrupfender": "abrupfend",
    "abrupfendere": "abrupfend",
    "abrupfenderem": "abrupfend",
    "abrupfenderen": "abrupfend",
    "abrupfenderer": "abrupfend",
    "abrupfenderes": "abrupfend",
    "abrupfendes": "abrupfend",
    "abrupfendste": "abrupfend",
    "abrupfendstem": "abrupfend",
    "abrupfendsten": "abrupfend",
    "abrupfendster": "abrupfend",
    "abrupfendstes": "abrupfend",
    "abrupfest": "abrupfen",
    "abrupfet": "abrupfen",
    "abrupfst": "abrupfen",
    "abrupft": "abrupfen",
    "abrupfte": "abrupfen",
    "abrupften": "abrupfen",
    "abrupftest": "abrupfen",
    "abrupftet": "abrupfen",
    "abrupte": "abrupt",
    "abruptem": "abrupt",
    "abrupten": "abrupt",
    "abrupter": "abrupt",
    "abruptere": "abrupt",
    "abrupterem": "abrupt",
    "abrupteren": "abrupt",
    "abrupterer": "abrupt",
    "abrupteres": "abrupt",
    "abruptes": "abrupt",
    "abrupteste": "abrupt",
    "abruptestem": "abrupt",
    "abruptesten": "abrupt",
    "abruptester": "abrupt",
    "abruptestes": "abrupt",
    "abrutsche": "abrutschen",
    "abrutschend": "abrutschen",
    "abrutschende": "abrutschend",
    "abrutschendem": "abrutschend",
    "abrutschenden": "abrutschend",
    "abrutschender": "abrutschend",
    "abrutschendes": "abrutschend",
    "abrutschest": "abrutschen",
    "abrutschet": "abrutschen",
    "abrutschst": "abrutschen",
    "abrutscht": "abrutschen",
    "abrutschte": "abrutschen",
    "abrutschten": "abrutschen",
    "abrutschtest": "abrutschen",
    "abrutschtet": "abrutschen",
    "abränge": "abringen",
    "abrängen": "abringen",
    "abrängest": "abringen",
    "abränget": "abringen",
    "abrät": "abraten",
    "abrätst": "abraten",
    "abräume": "abräumen",
    "abräumend": "abräumen",
    "abräumende": "abräumend",
    "abräumendem": "abräumend",
    "abräumenden": "abräumend",
    "abräumender": "abräumend",
    "abräumendere": "abräumend",
    "abräumenderem": "abräumend",
    "abräumenderen": "abräumend",
    "abräumenderer": "abräumend",
    "abräumenderes": "abräumend",
    "abräumendes": "abräumend",
    "abräumendste": "abräumend",
    "abräumendstem": "abräumend",
    "abräumendsten": "abräumend",
    "abräumendster": "abräumend",
    "abräumendstes": "abräumend",
    "abräumest": "abräumen",
    "abräumet": "abräumen",
    "abräumst": "abräumen",
    "abräumt": "abräumen",
    "abräumte": "abräumen",
    "abräumten": "abräumen",
    "abräumtest": "abräumen",
    "abräumtet": "abräumen",
    "abrücke": "abrücken",
    "abrückend": "abrücken",
    "abrückende": "abrückend",
    "abrückendem": "abrückend",
    "abrückenden": "abrückend",
    "abrückender": "abrückend",
    "abrückendes": "abrückend",
    "abrückest": "abrücken",
    "abrücket": "abrücken",
    "abrückst": "abrücken",
    "abrückt": "abrücken",
    "abrückte": "abrücken",
    "abrückten": "abrücken",
    "abrücktest": "abrücken",
    "abrücktet": "abrücken",
    "abrühre": "abrühren",
    "abrührend": "abrühren",
    "abrührende": "abrührend",
    "abrührendem": "abrührend",
    "abrührenden": "abrührend",
    "abrührender": "abrührend",
    "abrührendes": "abrührend",
    "abrührest": "abrühren",
    "abrühret": "abrühren",
    "abrührst": "abrühren",
    "abrührt": "abrühren",
    "abrührte": "abrühren",
    "abrührten": "abrühren",
    "abrührtest": "abrühren",
    "abrührtet": "abrühren",
    "abrüste": "abrüsten",
    "abrüstend": "abrüsten",
    "abrüstende": "abrüstend",
    "abrüstendem": "abrüstend",
    "abrüstenden": "abrüstend",
    "abrüstender": "abrüstend",
    "abrüstendes": "abrüstend",
    "abrüstest": "abrüsten",
    "abrüstet": "abrüsten",
    "abrüstete": "abrüsten",
    "abrüsteten": "abrüsten",
    "abrüstetest": "abrüsten",
    "abrüstetet": "abrüsten",
    "absage": "absagen",
    "absagend": "absagen",
    "absagende": "absagend",
    "absagendem": "absagend",
    "absagenden": "absagend",
    "absagender": "absagend",
    "absagendes": "absagend",
    "absagest": "absagen",
    "absaget": "absagen",
    "absagst": "absagen",
    "absagt": "absagen",
    "absagte": "absagen",
    "absagten": "absagen",
    "absagtest": "absagen",
    "absagtet": "absagen",
    "absah": "absehen",
    "absahen": "absehen",
    "absahne": "absahnen",
    "absahnend": "absahnen",
    "absahnende": "absahnend",
    "absahnendem": "absahnend",
    "absahnenden": "absahnend",
    "absahnender": "absahnend",
    "absahnendes": "absahnend",
    "absahnest": "absahnen",
    "absahnet": "absahnen",
    "absahnst": "absahnen",
    "absahnt": "absahnen",
    "absahnte": "absahnen",
    "absahnten": "absahnen",
    "absahntest": "absahnen",
    "absahntet": "absahnen",
    "absahst": "absehen",
    "absaht": "absehen",
    "absandte": "absenden",
    "absandten": "absenden",
    "absandtest": "absenden",
    "absandtet": "absenden",
    "absang": "absingen",
    "absangen": "absingen",
    "absangst": "absingen",
    "absangt": "absingen",
    "absattele": "absatteln",
    "absattelnd": "absatteln",
    "absattelnde": "absattelnd",
    "absattelndem": "absattelnd",
    "absattelnden": "absattelnd",
    "absattelnder": "absattelnd",
    "absattelndes": "absattelnd",
    "absattelst": "absatteln",
    "absattelt": "absatteln",
    "absattelte": "absatteln",
    "absattelten": "absatteln",
    "absatteltest": "absatteln",
    "absatteltet": "absatteln",
    "absattle": "absatteln",
    "absatzfähigem": "absatzfähig",
    "absatzfähigen": "absatzfähig",
    "absatzfähiger": "absatzfähig",
    "absatzfähigere": "absatzfähig",
    "absatzfähigerem": "absatzfähig",
    "absatzfähigeren": "absatzfähig",
    "absatzfähigerer": "absatzfähig",
    "absatzfähigeres": "absatzfähig",
    "absatzfähiges": "absatzfähig",
    "absatzfähigste": "absatzfähig",
    "absatzfähigstem": "absatzfähig",
    "absatzfähigsten": "absatzfähig",
    "absatzfähigster": "absatzfähig",
    "absatzfähigstes": "absatzfähig",
    "absatzweisem": "absatzweise",
    "absatzweisen": "absatzweise",
    "absatzweiser": "absatzweise",
    "absatzweises": "absatzweise",
    "absaufe": "absaufen",
    "absaufend": "absaufen",
    "absaufende": "absaufend",
    "absaufendem": "absaufend",
    "absaufenden": "absaufend",
    "absaufender": "absaufend",
    "absaufendes": "absaufend",
    "absaufest": "absaufen",
    "absaufet": "absaufen",
    "absauft": "absaufen",
    "absauge": "absaugen",
    "absaugend": "absaugen",
    "absaugende": "absaugend",
    "absaugendem": "absaugend",
    "absaugenden": "absaugend",
    "absaugender": "absaugend",
    "absaugendes": "absaugend",
    "absaugest": "absaugen",
    "absauget": "absaugen",
    "absaugst": "absaugen",
    "absaugt": "absaugen",
    "absaugte": "absaugen",
    "absaugten": "absaugen",
    "absaugtest": "absaugen",
    "absaugtet": "absaugen",
    "absause": "absausen",
    "absausend": "absausen",
    "absausende": "absausend",
    "absausendem": "absausend",
    "absausenden": "absausend",
    "absausender": "absausend",
    "absausendes": "absausend",
    "absausest": "absausen",
    "absauset": "absausen",
    "absaust": "absausen",
    "absauste": "absausen",
    "absausten": "absausen",
    "absaustest": "absausen",
    "absaustet": "absausen",
    "absaß": "absitzen",
    "absaßen": "absitzen",
    "absaßt": "absitzen",
    "abschabe": "abschaben",
    "abschabend": "abschaben",
    "abschabende": "abschabend",
    "abschabendem": "abschabend",
    "abschabenden": "abschabend",
    "abschabender": "abschabend",
    "abschabendere": "abschabend",
    "abschabenderem": "abschabend",
    "abschabenderen": "abschabend",
    "abschabenderer": "abschabend",
    "abschabenderes": "abschabend",
    "abschabendes": "abschabend",
    "abschabendste": "abschabend",
    "abschabendstem": "abschabend",
    "abschabendsten": "abschabend",
    "abschabendster": "abschabend",
    "abschabendstes": "abschabend",
    "abschabest": "abschaben",
    "abschabet": "abschaben",
    "abschabst": "abschaben",
    "abschabt": "abschaben",
    "abschabte": "abschaben",
    "abschabten": "abschaben",
    "abschabtest": "abschaben",
    "abschabtet": "abschaben",
    "abschaffe": "abschaffen",
    "abschaffend": "abschaffen",
    "abschaffende": "abschaffend",
    "abschaffendem": "abschaffend",
    "abschaffenden": "abschaffend",
    "abschaffender": "abschaffend",
    "abschaffendes": "abschaffend",
    "abschaffest": "abschaffen",
    "abschaffet": "abschaffen",
    "abschaffst": "abschaffen",
    "abschafft": "abschaffen",
    "abschaffte": "abschaffen",
    "abschafften": "abschaffen",
    "abschafftest": "abschaffen",
    "abschafftet": "abschaffen",
    "abschalte": "abschalten",
    "abschaltend": "abschalten",
    "abschaltende": "abschaltend",
    "abschaltendem": "abschaltend",
    "abschaltenden": "abschaltend",
    "abschaltender": "abschaltend",
    "abschaltendes": "abschaltend",
    "abschaltest": "abschalten",
    "abschaltet": "abschalten",
    "abschaltete": "abschalten",
    "abschalteten": "abschalten",
    "abschaltetest": "abschalten",
    "abschaltetet": "abschalten",
    "abschaue": "abschauen",
    "abschauend": "abschauen",
    "abschauende": "abschauend",
    "abschauendem": "abschauend",
    "abschauenden": "abschauend",
    "abschauender": "abschauend",
    "abschauendes": "abschauend",
    "abschauest": "abschauen",
    "abschauet": "abschauen",
    "abschaust": "abschauen",
    "abschaut": "abschauen",
    "abschaute": "abschauen",
    "abschauten": "abschauen",
    "abschautest": "abschauen",
    "abschautet": "abschauen",
    "abscheide": "abscheiden",
    "abscheidend": "abscheiden",
    "abscheidende": "abscheidend",
    "abscheidendem": "abscheidend",
    "abscheidenden": "abscheidend",
    "abscheidender": "abscheidend",
    "abscheidendes": "abscheidend",
    "abscheidest": "abscheiden",
    "abscheidet": "abscheiden",
    "abschere": "abscheren",
    "abscherend": "abscheren",
    "abscherende": "abscherend",
    "abscherendem": "abscherend",
    "abscherenden": "abscherend",
    "abscherender": "abscherend",
    "abscherendes": "abscherend",
    "abscherest": "abscheren",
    "abscheret": "abscheren",
    "abscherst": "abscheren",
    "abschert": "abscheren",
    "abscherte": "abscheren",
    "abscherten": "abscheren",
    "abschertest": "abscheren",
    "abschertet": "abscheren",
    "abscheuere": "abscheuern",
    "abscheuernd": "abscheuern",
    "abscheuernde": "abscheuernd",
    "abscheuerndem": "abscheuernd",
    "abscheuernden": "abscheuernd",
    "abscheuernder": "abscheuernd",
    "abscheuerndere": "abscheuernd",
    "abscheuernderem": "abscheuernd",
    "abscheuernderen": "abscheuernd",
    "abscheuernderer": "abscheuernd",
    "abscheuernderes": "abscheuernd",
    "abscheuerndes": "abscheuernd",
    "abscheuerndste": "abscheuernd",
    "abscheuerndstem": "abscheuernd",
    "abscheuerndsten": "abscheuernd",
    "abscheuerndster": "abscheuernd",
    "abscheuerndstes": "abscheuernd",
    "abscheuerst": "abscheuern",
    "abscheuert": "abscheuern",
    "abscheuerte": "abscheuern",
    "abscheuerten": "abscheuern",
    "abscheuertest": "abscheuern",
    "abscheuertet": "abscheuern",
    "abscheuliche": "abscheulich",
    "abscheulichem": "abscheulich",
    "abscheulichen": "abscheulich",
    "abscheulicher": "abscheulich",
    "abscheulichere": "abscheulich",
    "abscheulicherem": "abscheulich",
    "abscheulicheren": "abscheulich",
    "abscheulicherer": "abscheulich",
    "abscheulicheres": "abscheulich",
    "abscheuliches": "abscheulich",
    "abscheulichste": "abscheulich",
    "abscheulichstem": "abscheulich",
    "abscheulichsten": "abscheulich",
    "abscheulichster": "abscheulich",
    "abscheulichstes": "abscheulich",
    "abschiebe": "abschieben",
    "abschiebend": "abschieben",
    "abschiebende": "abschiebend",
    "abschiebendem": "abschiebend",
    "abschiebenden": "abschiebend",
    "abschiebender": "abschiebend",
    "abschiebendes": "abschiebend",
    "abschiebest": "abschieben",
    "abschiebet": "abschieben",
    "abschiebst": "abschieben",
    "abschiebt": "abschieben",
    "abschiede": "abscheiden",
    "abschiedest": "abscheiden",
    "abschiedet": "abscheiden",
    "abschiefere": "abschiefern",
    "abschiefernd": "abschiefern",
    "abschiefernde": "abschiefernd",
    "abschieferndem": "abschiefernd",
    "abschiefernden": "abschiefernd",
    "abschiefernder": "abschiefernd",
    "abschieferndes": "abschiefernd",
    "abschieferst": "abschiefern",
    "abschiefert": "abschiefern",
    "abschieferte": "abschiefern",
    "abschieferten": "abschiefern",
    "abschiefertest": "abschiefern",
    "abschiefertet": "abschiefern",
    "abschieße": "abschießen",
    "abschießend": "abschießen",
    "abschießende": "abschießend",
    "abschießendem": "abschießend",
    "abschießenden": "abschießend",
    "abschießender": "abschießend",
    "abschießendes": "abschießend",
    "abschießest": "abschießen",
    "abschießet": "abschießen",
    "abschießt": "abschießen",
    "abschinde": "abschinden",
    "abschindend": "abschinden",
    "abschindende": "abschindend",
    "abschindendem": "abschindend",
    "abschindenden": "abschindend",
    "abschindender": "abschindend",
    "abschindendere": "abschindend",
    "abschindenderem": "abschindend",
    "abschindenderen": "abschindend",
    "abschindenderer": "abschindend",
    "abschindenderes": "abschindend",
    "abschindendes": "abschindend",
    "abschindendste": "abschindend",
    "abschindendstem": "abschindend",
    "abschindendsten": "abschindend",
    "abschindendster": "abschindend",
    "abschindendstes": "abschindend",
    "abschindest": "abschinden",
    "abschindet": "abschinden",
    "abschindete": "abschinden",
    "abschindeten": "abschinden",
    "abschindetest": "abschinden",
    "abschindetet": "abschinden",
    "abschirme": "abschirmen",
    "abschirmend": "abschirmen",
    "abschirmende": "abschirmend",
    "abschirmendem": "abschirmend",
    "abschirmenden": "abschirmend",
    "abschirmender": "abschirmend",
    "abschirmendere": "abschirmend",
    "abschirmenderem": "abschirmend",
    "abschirmenderen": "abschirmend",
    "abschirmenderer": "abschirmend",
    "abschirmenderes": "abschirmend",
    "abschirmendes": "abschirmend",
    "abschirmendste": "abschirmend",
    "abschirmendstem": "abschirmend",
    "abschirmendsten": "abschirmend",
    "abschirmendster": "abschirmend",
    "abschirmendstes": "abschirmend",
    "abschirmest": "abschirmen",
    "abschirmet": "abschirmen",
    "abschirmst": "abschirmen",
    "abschirmt": "abschirmen",
    "abschirmte": "abschirmen",
    "abschirmten": "abschirmen",
    "abschirmtest": "abschirmen",
    "abschirmtet": "abschirmen",
    "abschirre": "abschirren",
    "abschirrend": "abschirren",
    "abschirrende": "abschirrend",
    "abschirrendem": "abschirrend",
    "abschirrenden": "abschirrend",
    "abschirrender": "abschirrend",
    "abschirrendes": "abschirrend",
    "abschirrest": "abschirren",
    "abschirret": "abschirren",
    "abschirrst": "abschirren",
    "abschirrt": "abschirren",
    "abschirrte": "abschirren",
    "abschirrten": "abschirren",
    "abschirrtest": "abschirren",
    "abschirrtet": "abschirren",
    "abschlachte": "abschlachten",
    "abschlachtend": "abschlachten",
    "abschlachtende": "abschlachtend",
    "abschlachtendem": "abschlachtend",
    "abschlachtenden": "abschlachtend",
    "abschlachtender": "abschlachtend",
    "abschlachtendes": "abschlachtend",
    "abschlachtest": "abschlachten",
    "abschlachtet": "abschlachten",
    "abschlachtete": "abschlachten",
    "abschlachteten": "abschlachten",
    "abschlachtetest": "abschlachten",
    "abschlachtetet": "abschlachten",
    "abschlaffe": "abschlaffen",
    "abschlaffend": "abschlaffen",
    "abschlaffende": "abschlaffend",
    "abschlaffendem": "abschlaffend",
    "abschlaffenden": "abschlaffend",
    "abschlaffender": "abschlaffend",
    "abschlaffendere": "abschlaffend",
    "abschlaffenderem": "abschlaffend",
    "abschlaffenderen": "abschlaffend",
    "abschlaffenderer": "abschlaffend",
    "abschlaffenderes": "abschlaffend",
    "abschlaffendes": "abschlaffend",
    "abschlaffendste": "abschlaffend",
    "abschlaffendstem": "abschlaffend",
    "abschlaffendsten": "abschlaffend",
    "abschlaffendster": "abschlaffend",
    "abschlaffendstes": "abschlaffend",
    "abschlaffest": "abschlaffen",
    "abschlaffet": "abschlaffen",
    "abschlaffst": "abschlaffen",
    "abschlafft": "abschlaffen",
    "abschlaffte": "abschlaffen",
    "abschlafften": "abschlaffen",
    "abschlafftest": "abschlaffen",
    "abschlafftet": "abschlaffen",
    "abschlagend": "abschlagen",
    "abschlagende": "abschlagend",
    "abschlagendem": "abschlagend",
    "abschlagenden": "abschlagend",
    "abschlagender": "abschlagend",
    "abschlagendes": "abschlagend",
    "abschlagest": "abschlagen",
    "abschlaget": "abschlagen",
    "abschlagt": "abschlagen",
    "abschleife": "abschleifen",
    "abschleifend": "abschleifen",
    "abschleifende": "abschleifend",
    "abschleifendem": "abschleifend",
    "abschleifenden": "abschleifend",
    "abschleifender": "abschleifend",
    "abschleifendere": "abschleifend",
    "abschleifenderem": "abschleifend",
    "abschleifenderen": "abschleifend",
    "abschleifenderer": "abschleifend",
    "abschleifenderes": "abschleifend",
    "abschleifendes": "abschleifend",
    "abschleifendste": "abschleifend",
    "abschleifendstem": "abschleifend",
    "abschleifendsten": "abschleifend",
    "abschleifendster": "abschleifend",
    "abschleifendstes": "abschleifend",
    "abschleifest": "abschleifen",
    "abschleifet": "abschleifen",
    "abschleifst": "abschleifen",
    "abschleift": "abschleifen",
    "abschleifte": "abschleifen",
    "abschleiften": "abschleifen",
    "abschleiftest": "abschleifen",
    "abschleiftet": "abschleifen",
    "abschleppe": "abschleppen",
    "abschleppend": "abschleppen",
    "abschleppende": "abschleppend",
    "abschleppendem": "abschleppend",
    "abschleppenden": "abschleppend",
    "abschleppender": "abschleppend",
    "abschleppendes": "abschleppend",
    "abschleppest": "abschleppen",
    "abschleppet": "abschleppen",
    "abschleppst": "abschleppen",
    "abschleppt": "abschleppen",
    "abschleppte": "abschleppen",
    "abschleppten": "abschleppen",
    "abschlepptest": "abschleppen",
    "abschlepptet": "abschleppen",
    "abschließe": "abschließen",
    "abschließend": "abschließen",
    "abschließende": "abschließend",
    "abschließendem": "abschließend",
    "abschließenden": "abschließend",
    "abschließender": "abschließend",
    "abschließendes": "abschließend",
    "abschließest": "abschließen",
    "abschließet": "abschließen",
    "abschließt": "abschließen",
    "abschliff": "abschleifen",
    "abschliffe": "abschleifen",
    "abschliffen": "abschleifen",
    "abschliffest": "abschleifen",
    "abschliffet": "abschleifen",
    "abschliffst": "abschleifen",
    "abschlifft": "abschleifen",
    "abschlossen": "abschließen",
    "abschloß": "abschließen",
    "abschloßt": "abschließen",
    "abschlug": "abschlagen",
    "abschlugen": "abschlagen",
    "abschlugst": "abschlagen",
    "abschlugt": "abschlagen",
    "abschlägst": "abschlagen",
    "abschlägt": "abschlagen",
    "abschlämme": "abschlämmen",
    "abschlämmend": "abschlämmen",
    "abschlämmende": "abschlämmend",
    "abschlämmendem": "abschlämmend",
    "abschlämmenden": "abschlämmend",
    "abschlämmender": "abschlämmend",
    "abschlämmendes": "abschlämmend",
    "abschlämmest": "abschlämmen",
    "abschlämmet": "abschlämmen",
    "abschlämmst": "abschlämmen",
    "abschlämmt": "abschlämmen",
    "abschlämmte": "abschlämmen",
    "abschlämmten": "abschlämmen",
    "abschlämmtest": "abschlämmen",
    "abschlämmtet": "abschlämmen",
    "abschlösse": "abschließen",
    "abschlössen": "abschließen",
    "abschlössest": "abschließen",
    "abschlösset": "abschließen",
    "abschlüge": "abschlagen",
    "abschlügen": "abschlagen",
    "abschlügest": "abschlagen",
    "abschlüget": "abschlagen",
    "abschmatze": "abschmatzen",
    "abschmatzend": "abschmatzen",
    "abschmatzende": "abschmatzend",
    "abschmatzendem": "abschmatzend",
    "abschmatzenden": "abschmatzend",
    "abschmatzender": "abschmatzend",
    "abschmatzendere": "abschmatzend",
    "abschmatzenderem": "abschmatzend",
    "abschmatzenderen": "abschmatzend",
    "abschmatzenderer": "abschmatzend",
    "abschmatzenderes": "abschmatzend",
    "abschmatzendes": "abschmatzend",
    "abschmatzendste": "abschmatzend",
    "abschmatzendstem": "abschmatzend",
    "abschmatzendsten": "abschmatzend",
    "abschmatzendster": "abschmatzend",
    "abschmatzendstes": "abschmatzend",
    "abschmatzest": "abschmatzen",
    "abschmatzet": "abschmatzen",
    "abschmatzt": "abschmatzen",
    "abschmatzte": "abschmatzen",
    "abschmatzten": "abschmatzen",
    "abschmatztest": "abschmatzen",
    "abschmatztet": "abschmatzen",
    "abschmeichele": "abschmeicheln",
    "abschmeichelnd": "abschmeicheln",
    "abschmeichelnde": "abschmeichelnd",
    "abschmeichelndem": "abschmeichelnd",
    "abschmeichelnden": "abschmeichelnd",
    "abschmeichelnder": "abschmeichelnd",
    "abschmeichelndere": "abschmeichelnd",
    "abschmeichelnderem": "abschmeichelnd",
    "abschmeichelnderen": "abschmeichelnd",
    "abschmeichelnderer": "abschmeichelnd",
    "abschmeichelnderes": "abschmeichelnd",
    "abschmeichelndes": "abschmeichelnd",
    "abschmeichelndste": "abschmeichelnd",
    "abschmeichelndstem": "abschmeichelnd",
    "abschmeichelndsten": "abschmeichelnd",
    "abschmeichelndster": "abschmeichelnd",
    "abschmeichelndstes": "abschmeichelnd",
    "abschmeichelst": "abschmeicheln",
    "abschmeichelt": "abschmeicheln",
    "abschmeichelte": "abschmeicheln",
    "abschmeichelten": "abschmeicheln",
    "abschmeicheltest": "abschmeicheln",
    "abschmeicheltet": "abschmeicheln",
    "abschmeichle": "abschmeicheln",
    "abschmelze": "abschmelzen",
    "abschmelzend": "abschmelzen",
    "abschmelzende": "abschmelzend",
    "abschmelzendem": "abschmelzend",
    "abschmelzenden": "abschmelzend",
    "abschmelzender": "abschmelzend",
    "abschmelzendes": "abschmelzend",
    "abschmelzest": "abschmelzen",
    "abschmelzet": "abschmelzen",
    "abschmelzt": "abschmelzen",
    "abschmettere": "abschmettern",
    "abschmetternd": "abschmettern",
    "abschmetternde": "abschmetternd",
    "abschmetterndem": "abschmetternd",
    "abschmetternden": "abschmetternd",
    "abschmetternder": "abschmetternd",
    "abschmetterndes": "abschmetternd",
    "abschmetterst": "abschmettern",
    "abschmettert": "abschmettern",
    "abschmetterte": "abschmettern",
    "abschmetterten": "abschmettern",
    "abschmettertest": "abschmettern",
    "abschmettertet": "abschmettern",
    "abschmiere": "abschmieren",
    "abschmierend": "abschmieren",
    "abschmierende": "abschmierend",
    "abschmierendem": "abschmierend",
    "abschmierenden": "abschmierend",
    "abschmierender": "abschmierend",
    "abschmierendes": "abschmierend",
    "abschmierest": "abschmieren",
    "abschmieret": "abschmieren",
    "abschmierst": "abschmieren",
    "abschmiert": "abschmieren",
    "abschmierte": "abschmieren",
    "abschmierten": "abschmieren",
    "abschmiertest": "abschmieren",
    "abschmiertet": "abschmieren",
    "abschmilzt": "abschmelzen",
    "abschminke": "abschminken",
    "abschminkend": "abschminken",
    "abschminkende": "abschminkend",
    "abschminkendem": "abschminkend",
    "abschminkenden": "abschminkend",
    "abschminkender": "abschminkend",
    "abschminkendes": "abschminkend",
    "abschminkest": "abschminken",
    "abschminket": "abschminken",
    "abschminkst": "abschminken",
    "abschminkt": "abschminken",
    "abschminkte": "abschminken",
    "abschminkten": "abschminken",
    "abschminktest": "abschminken",
    "abschminktet": "abschminken",
    "abschmolz": "abschmelzen",
    "abschmolzen": "abschmelzen",
    "abschmolzst": "abschmelzen",
    "abschmolzt": "abschmelzen",
    "abschmölze": "abschmelzen",
    "abschmölzen": "abschmelzen",
    "abschmölzest": "abschmelzen",
    "abschmölzet": "abschmelzen",
    "abschnalle": "abschnallen",
    "abschnallend": "abschnallen",
    "abschnallende": "abschnallend",
    "abschnallendem": "abschnallend",
    "abschnallenden": "abschnallend",
    "abschnallender": "abschnallend",
    "abschnallendes": "abschnallend",
    "abschnallest": "abschnallen",
    "abschnallet": "abschnallen",
    "abschnallst": "abschnallen",
    "abschnallt": "abschnallen",
    "abschnallte": "abschnallen",
    "abschnallten": "abschnallen",
    "abschnalltest": "abschnallen",
    "abschnalltet": "abschnallen",
    "abschnappe": "abschnappen",
    "abschnappend": "abschnappen",
    "abschnappende": "abschnappend",
    "abschnappendem": "abschnappend",
    "abschnappenden": "abschnappend",
    "abschnappender": "abschnappend",
    "abschnappendes": "abschnappend",
    "abschnappest": "abschnappen",
    "abschnappet": "abschnappen",
    "abschnappst": "abschnappen",
    "abschnappt": "abschnappen",
    "abschnappte": "abschnappen",
    "abschnappten": "abschnappen",
    "abschnapptest": "abschnappen",
    "abschnapptet": "abschnappen",
    "abschneide": "abschneiden",
    "abschneidend": "abschneiden",
    "abschneidende": "abschneidend",
    "abschneidendem": "abschneidend",
    "abschneidenden": "abschneidend",
    "abschneidender": "abschneidend",
    "abschneidendes": "abschneidend",
    "abschneidest": "abschneiden",
    "abschneidet": "abschneiden",
    "abschnitt": "abschneiden",
    "abschnittest": "abschneiden",
    "abschnittet": "abschneiden",
    "abschnüre": "abschnüren",
    "abschnürend": "abschnüren",
    "abschnürende": "abschnürend",
    "abschnürendem": "abschnürend",
    "abschnürenden": "abschnürend",
    "abschnürender": "abschnürend",
    "abschnürendere": "abschnürend",
    "abschnürenderem": "abschnürend",
    "abschnürenderen": "abschnürend",
    "abschnürenderer": "abschnürend",
    "abschnürenderes": "abschnürend",
    "abschnürendes": "abschnürend",
    "abschnürendste": "abschnürend",
    "abschnürendstem": "abschnürend",
    "abschnürendsten": "abschnürend",
    "abschnürendster": "abschnürend",
    "abschnürendstes": "abschnürend",
    "abschnürest": "abschnüren",
    "abschnüret": "abschnüren",
    "abschnürst": "abschnüren",
    "abschnürt": "abschnüren",
    "abschnürte": "abschnüren",
    "abschnürten": "abschnüren",
    "abschnürtest": "abschnüren",
    "abschnürtet": "abschnüren",
    "abschob": "abschieben",
    "abschoben": "abschieben",
    "abschobst": "abschieben",
    "abschobt": "abschieben",
    "abschor": "abscheren",
    "abschoren": "abscheren",
    "abschorst": "abscheren",
    "abschort": "abscheren",
    "abschossen": "abschießen",
    "abschoß": "abschießen",
    "abschoßt": "abschießen",
    "abschrak": "abschrecken",
    "abschraken": "abschrecken",
    "abschrakst": "abschrecken",
    "abschrakt": "abschrecken",
    "abschraube": "abschrauben",
    "abschraubend": "abschrauben",
    "abschraubende": "abschraubend",
    "abschraubendem": "abschraubend",
    "abschraubenden": "abschraubend",
    "abschraubender": "abschraubend",
    "abschraubendes": "abschraubend",
    "abschraubest": "abschrauben",
    "abschraubet": "abschrauben",
    "abschraubst": "abschrauben",
    "abschraubt": "abschrauben",
    "abschraubte": "abschrauben",
    "abschraubten": "abschrauben",
    "abschraubtest": "abschrauben",
    "abschraubtet": "abschrauben",
    "abschrecke": "abschrecken",
    "abschreckend": "abschrecken",
    "abschreckende": "abschreckend",
    "abschreckendem": "abschreckend",
    "abschreckenden": "abschreckend",
    "abschreckender": "abschreckend",
    "abschreckendere": "abschreckend",
    "abschreckenderem": "abschreckend",
    "abschreckenderen": "abschreckend",
    "abschreckenderer": "abschreckend",
    "abschreckenderes": "abschreckend",
    "abschreckendes": "abschreckend",
    "abschreckendste": "abschreckend",
    "abschreckendstem": "abschreckend",
    "abschreckendsten": "abschreckend",
    "abschreckendster": "abschreckend",
    "abschreckendstes": "abschreckend",
    "abschreckest": "abschrecken",
    "abschrecket": "abschrecken",
    "abschreckst": "abschrecken",
    "abschreckt": "abschrecken",
    "abschreckte": "abschrecken",
    "abschreckten": "abschrecken",
    "abschrecktest": "abschrecken",
    "abschrecktet": "abschrecken",
    "abschreibe": "abschreiben",
    "abschreibend": "abschreiben",
    "abschreibende": "abschreibend",
    "abschreibendem": "abschreibend",
    "abschreibenden": "abschreibend",
    "abschreibender": "abschreibend",
    "abschreibendes": "abschreibend",
    "abschreibest": "abschreiben",
    "abschreibet": "abschreiben",
    "abschreibst": "abschreiben",
    "abschreibt": "abschreiben",
    "abschreitend": "abschreiten",
    "abschreitende": "abschreitend",
    "abschreitendem": "abschreitend",
    "abschreitenden": "abschreitend",
    "abschreitender": "abschreitend",
    "abschreitendes": "abschreitend",
    "abschrickst": "abschrecken",
    "abschrickt": "abschrecken",
    "abschrieb": "abschreiben",
    "abschriebe": "abschreiben",
    "abschrieben": "abschreiben",
    "abschriebest": "abschreiben",
    "abschriebet": "abschreiben",
    "abschriebst": "abschreiben",
    "abschriebt": "abschreiben",
    "abschräge": "abschrägen",
    "abschrägend": "abschrägen",
    "abschrägende": "abschrägend",
    "abschrägendem": "abschrägend",
    "abschrägenden": "abschrägend",
    "abschrägender": "abschrägend",
    "abschrägendes": "abschrägend",
    "abschrägest": "abschrägen",
    "abschräget": "abschrägen",
    "abschrägst": "abschrägen",
    "abschrägt": "abschrägen",
    "abschrägte": "abschrägen",
    "abschrägten": "abschrägen",
    "abschrägtest": "abschrägen",
    "abschrägtet": "abschrägen",
    "abschräke": "abschrecken",
    "abschräken": "abschrecken",
    "abschräkest": "abschrecken",
    "abschräket": "abschrecken",
    "abschröpfe": "abschröpfen",
    "abschröpfend": "abschröpfen",
    "abschröpfende": "abschröpfend",
    "abschröpfendem": "abschröpfend",
    "abschröpfenden": "abschröpfend",
    "abschröpfender": "abschröpfend",
    "abschröpfendes": "abschröpfend",
    "abschröpfest": "abschröpfen",
    "abschröpfet": "abschröpfen",
    "abschröpfst": "abschröpfen",
    "abschröpft": "abschröpfen",
    "abschröpfte": "abschröpfen",
    "abschröpften": "abschröpfen",
    "abschröpftest": "abschröpfen",
    "abschröpftet": "abschröpfen",
    "abschufte": "abschuften",
    "abschuftend": "abschuften",
    "abschuftende": "abschuftend",
    "abschuftendem": "abschuftend",
    "abschuftenden": "abschuftend",
    "abschuftender": "abschuftend",
    "abschuftendere": "abschuftend",
    "abschuftenderem": "abschuftend",
    "abschuftenderen": "abschuftend",
    "abschuftenderer": "abschuftend",
    "abschuftenderes": "abschuftend",
    "abschuftendes": "abschuftend",
    "abschuftendste": "abschuftend",
    "abschuftendstem": "abschuftend",
    "abschuftendsten": "abschuftend",
    "abschuftendster": "abschuftend",
    "abschuftendstes": "abschuftend",
    "abschuftest": "abschuften",
    "abschuftet": "abschuften",
    "abschuftete": "abschuften",
    "abschufteten": "abschuften",
    "abschuftetest": "abschuften",
    "abschuftetet": "abschuften",
    "abschwang": "abschwingen",
    "abschwangen": "abschwingen",
    "abschwangst": "abschwingen",
    "abschwangt": "abschwingen",
    "abschwatze": "abschwatzen",
    "abschwatzend": "abschwatzen",
    "abschwatzende": "abschwatzend",
    "abschwatzendem": "abschwatzend",
    "abschwatzenden": "abschwatzend",
    "abschwatzender": "abschwatzend",
    "abschwatzendere": "abschwatzend",
    "abschwatzenderem": "abschwatzend",
    "abschwatzenderen": "abschwatzend",
    "abschwatzenderer": "abschwatzend",
    "abschwatzenderes": "abschwatzend",
    "abschwatzendes": "abschwatzend",
    "abschwatzendste": "abschwatzend",
    "abschwatzendstem": "abschwatzend",
    "abschwatzendsten": "abschwatzend",
    "abschwatzendster": "abschwatzend",
    "abschwatzendstes": "abschwatzend",
    "abschwatzest": "abschwatzen",
    "abschwatzet": "abschwatzen",
    "abschwatzt": "abschwatzen",
    "abschwatzte": "abschwatzen",
    "abschwatzten": "abschwatzen",
    "abschwatztest": "abschwatzen",
    "abschwatztet": "abschwatzen",
    "abschweife": "abschweifen",
    "abschweifend": "abschweifen",
    "abschweifende": "abschweifend",
    "abschweifendem": "abschweifend",
    "abschweifenden": "abschweifend",
    "abschweifender": "abschweifend",
    "abschweifendere": "abschweifend",
    "abschweifenderem": "abschweifend",
    "abschweifenderen": "abschweifend",
    "abschweifenderer": "abschweifend",
    "abschweifenderes": "abschweifend",
    "abschweifendes": "abschweifend",
    "abschweifendste": "abschweifend",
    "abschweifendstem": "abschweifend",
    "abschweifendsten": "abschweifend",
    "abschweifendster": "abschweifend",
    "abschweifendstes": "abschweifend",
    "abschweifest": "abschweifen",
    "abschweifet": "abschweifen",
    "abschweifst": "abschweifen",
    "abschweift": "abschweifen",
    "abschweifte": "abschweifen",
    "abschweiften": "abschweifen",
    "abschweiftest": "abschweifen",
    "abschweiftet": "abschweifen",
    "abschwelle": "abschwellen",
    "abschwellend": "abschwellen",
    "abschwellende": "abschwellend",
    "abschwellendem": "abschwellend",
    "abschwellenden": "abschwellend",
    "abschwellender": "abschwellend",
    "abschwellendere": "abschwellend",
    "abschwellenderem": "abschwellend",
    "abschwellenderen": "abschwellend",
    "abschwellenderer": "abschwellend",
    "abschwellenderes": "abschwellend",
    "abschwellendes": "abschwellend",
    "abschwellendste": "abschwellend",
    "abschwellendstem": "abschwellend",
    "abschwellendsten": "abschwellend",
    "abschwellendster": "abschwellend",
    "abschwellendstes": "abschwellend",
    "abschwellest": "abschwellen",
    "abschwellet": "abschwellen",
    "abschwellst": "abschwellen",
    "abschwellt": "abschwellen",
    "abschwellte": "abschwellen",
    "abschwellten": "abschwellen",
    "abschwelltest": "abschwellen",
    "abschwelltet": "abschwellen",
    "abschwenke": "abschwenken",
    "abschwenkend": "abschwenken",
    "abschwenkende": "abschwenkend",
    "abschwenkendem": "abschwenkend",
    "abschwenkenden": "abschwenkend",
    "abschwenkender": "abschwenkend",
    "abschwenkendes": "abschwenkend",
    "abschwenkest": "abschwenken",
    "abschwenket": "abschwenken",
    "abschwenkst": "abschwenken",
    "abschwenkt": "abschwenken",
    "abschwenkte": "abschwenken",
    "abschwenkten": "abschwenken",
    "abschwenktest": "abschwenken",
    "abschwenktet": "abschwenken",
    "abschwillst": "abschwellen",
    "abschwillt": "abschwellen",
    "abschwindele": "abschwindeln",
    "abschwindelnd": "abschwindeln",
    "abschwindelnde": "abschwindelnd",
    "abschwindelndem": "abschwindelnd",
    "abschwindelnden": "abschwindelnd",
    "abschwindelnder": "abschwindelnd",
    "abschwindelndes": "abschwindelnd",
    "abschwindelst": "abschwindeln",
    "abschwindelt": "abschwindeln",
    "abschwindelte": "abschwindeln",
    "abschwindelten": "abschwindeln",
    "abschwindeltest": "abschwindeln",
    "abschwindeltet": "abschwindeln",
    "abschwindle": "abschwindeln",
    "abschwinge": "abschwingen",
    "abschwingend": "abschwingen",
    "abschwingende": "abschwingend",
    "abschwingendem": "abschwingend",
    "abschwingenden": "abschwingend",
    "abschwingender": "abschwingend",
    "abschwingendes": "abschwingend",
    "abschwingest": "abschwingen",
    "abschwinget": "abschwingen",
    "abschwingst": "abschwingen",
    "abschwingt": "abschwingen",
    "abschwirre": "abschwirren",
    "abschwirrend": "abschwirren",
    "abschwirrende": "abschwirrend",
    "abschwirrendem": "abschwirrend",
    "abschwirrenden": "abschwirrend",
    "abschwirrender": "abschwirrend",
    "abschwirrendes": "abschwirrend",
    "abschwirrest": "abschwirren",
    "abschwirret": "abschwirren",
    "abschwirrst": "abschwirren",
    "abschwirrt": "abschwirren",
    "abschwirrte": "abschwirren",
    "abschwirrten": "abschwirren",
    "abschwirrtest": "abschwirren",
    "abschwirrtet": "abschwirren",
    "abschwoll": "abschwellen",
    "abschwollen": "abschwellen",
    "abschwollst": "abschwellen",
    "abschwollt": "abschwellen",
    "abschwor": "abschwören",
    "abschworen": "abschwören",
    "abschworst": "abschwören",
    "abschwort": "abschwören",
    "abschwäche": "abschwächen",
    "abschwächend": "abschwächen",
    "abschwächende": "abschwächend",
    "abschwächendem": "abschwächend",
    "abschwächenden": "abschwächend",
    "abschwächender": "abschwächend",
    "abschwächendere": "abschwächend",
    "abschwächenderem": "abschwächend",
    "abschwächenderen": "abschwächend",
    "abschwächenderer": "abschwächend",
    "abschwächenderes": "abschwächend",
    "abschwächendes": "abschwächend",
    "abschwächendste": "abschwächend",
    "abschwächendstem": "abschwächend",
    "abschwächendsten": "abschwächend",
    "abschwächendster": "abschwächend",
    "abschwächendstes": "abschwächend",
    "abschwächest": "abschwächen",
    "abschwächet": "abschwächen",
    "abschwächst": "abschwächen",
    "abschwächt": "abschwächen",
    "abschwächte": "abschwächen",
    "abschwächten": "abschwächen",
    "abschwächtest": "abschwächen",
    "abschwächtet": "abschwächen",
    "abschwänge": "abschwingen",
    "abschwängen": "abschwingen",
    "abschwängest": "abschwingen",
    "abschwänget": "abschwingen",
    "abschwölle": "abschwellen",
    "abschwöllen": "abschwellen",
    "abschwöllest": "abschwellen",
    "abschwöllet": "abschwellen",
    "abschwöre": "abschwören",
    "abschwörend": "abschwören",
    "abschwörende": "abschwörend",
    "abschwörendem": "abschwörend",
    "abschwörenden": "abschwörend",
    "abschwörender": "abschwörend",
    "abschwörendes": "abschwörend",
    "abschwörest": "abschwören",
    "abschwöret": "abschwören",
    "abschwörst": "abschwören",
    "abschwört": "abschwören",
    "abschäle": "abschälen",
    "abschälend": "abschälen",
    "abschälende": "abschälend",
    "abschälendem": "abschälend",
    "abschälenden": "abschälend",
    "abschälender": "abschälend",
    "abschälendes": "abschälend",
    "abschälest": "abschälen",
    "abschälet": "abschälen",
    "abschälst": "abschälen",
    "abschält": "abschälen",
    "abschälte": "abschälen",
    "abschälten": "abschälen",
    "abschältest": "abschälen",
    "abschältet": "abschälen",
    "abschätze": "abschätzen",
    "abschätzend": "abschätzen",
    "abschätzende": "abschätzend",
    "abschätzendem": "abschätzend",
    "abschätzenden": "abschätzend",
    "abschätzender": "abschätzend",
    "abschätzendes": "abschätzend",
    "abschätzest": "abschätzen",
    "abschätzet": "abschätzen",
    "abschätzt": "abschätzen",
    "abschätzte": "abschätzen",
    "abschätzten": "abschätzen",
    "abschätztest": "abschätzen",
    "abschätztet": "abschätzen",
    "abschäume": "abschäumen",
    "abschäumend": "abschäumen",
    "abschäumende": "abschäumend",
    "abschäumendem": "abschäumend",
    "abschäumenden": "abschäumend",
    "abschäumender": "abschäumend",
    "abschäumendes": "abschäumend",
    "abschäumest": "abschäumen",
    "abschäumet": "abschäumen",
    "abschäumst": "abschäumen",
    "abschäumt": "abschäumen",
    "abschäumte": "abschäumen",
    "abschäumten": "abschäumen",
    "abschäumtest": "abschäumen",
    "abschäumtet": "abschäumen",
    "abschöbe": "abschieben",
    "abschöben": "abschieben",
    "abschöbest": "abschieben",
    "abschöbet": "abschieben",
    "abschöpfe": "abschöpfen",
    "abschöpfend": "abschöpfen",
    "abschöpfende": "abschöpfend",
    "abschöpfendem": "abschöpfend",
    "abschöpfenden": "abschöpfend",
    "abschöpfender": "abschöpfend",
    "abschöpfendes": "abschöpfend",
    "abschöpfest": "abschöpfen",
    "abschöpfet": "abschöpfen",
    "abschöpfst": "abschöpfen",
    "abschöpft": "abschöpfen",
    "abschöpfte": "abschöpfen",
    "abschöpften": "abschöpfen",
    "abschöpftest": "abschöpfen",
    "abschöpftet": "abschöpfen",
    "abschöre": "abscheren",
    "abschören": "abscheren",
    "abschörest": "abscheren",
    "abschöret": "abscheren",
    "abschösse": "abschießen",
    "abschössen": "abschießen",
    "abschössest": "abschießen",
    "abschösset": "abschießen",
    "abschürfe": "abschürfen",
    "abschürfend": "abschürfen",
    "abschürfende": "abschürfend",
    "abschürfendem": "abschürfend",
    "abschürfenden": "abschürfend",
    "abschürfender": "abschürfend",
    "abschürfendere": "abschürfend",
    "abschürfenderem": "abschürfend",
    "abschürfenderen": "abschürfend",
    "abschürfenderer": "abschürfend",
    "abschürfenderes": "abschürfend",
    "abschürfendes": "abschürfend",
    "abschürfendste": "abschürfend",
    "abschürfendstem": "abschürfend",
    "abschürfendsten": "abschürfend",
    "abschürfendster": "abschürfend",
    "abschürfendstes": "abschürfend",
    "abschürfest": "abschürfen",
    "abschürfet": "abschürfen",
    "abschürfst": "abschürfen",
    "abschürft": "abschürfen",
    "abschürfte": "abschürfen",
    "abschürften": "abschürfen",
    "abschürftest": "abschürfen",
    "abschürftet": "abschürfen",
    "abschüssigem": "abschüssig",
    "abschüssigen": "abschüssig",
    "abschüssiger": "abschüssig",
    "abschüssigere": "abschüssig",
    "abschüssigerem": "abschüssig",
    "abschüssigeren": "abschüssig",
    "abschüssigerer": "abschüssig",
    "abschüssigeres": "abschüssig",
    "abschüssiges": "abschüssig",
    "abschüssigste": "abschüssig",
    "abschüssigstem": "abschüssig",
    "abschüssigsten": "abschüssig",
    "abschüssigster": "abschüssig",
    "abschüssigstes": "abschüssig",
    "abschüttele": "abschütteln",
    "abschüttelnd": "abschütteln",
    "abschüttelnde": "abschüttelnd",
    "abschüttelndem": "abschüttelnd",
    "abschüttelnden": "abschüttelnd",
    "abschüttelnder": "abschüttelnd",
    "abschüttelndes": "abschüttelnd",
    "abschüttelst": "abschütteln",
    "abschüttelt": "abschütteln",
    "abschüttelte": "abschütteln",
    "abschüttelten": "abschütteln",
    "abschütteltest": "abschütteln",
    "abschütteltet": "abschütteln",
    "abschüttle": "abschütteln",
    "absegne": "absegnen",
    "absegnend": "absegnen",
    "absegnende": "absegnend",
    "absegnendem": "absegnend",
    "absegnenden": "absegnend",
    "absegnender": "absegnend",
    "absegnendes": "absegnend",
    "absegnest": "absegnen",
    "absegnet": "absegnen",
    "absegnete": "absegnen",
    "absegneten": "absegnen",
    "absegnetest": "absegnen",
    "absegnetet": "absegnen",
    "absehbare": "absehbar",
    "absehbarem": "absehbar",
    "absehbaren": "absehbar",
    "absehbarer": "absehbar",
    "absehbares": "absehbar",
    "absehe": "absehen",
    "absehend": "absehen",
    "absehende": "absehend",
    "absehendem": "absehend",
    "absehenden": "absehend",
    "absehender": "absehend",
    "absehendes": "absehend",
    "absehest": "absehen",
    "absehet": "absehen",
    "abseht": "absehen",
    "abseife": "abseifen",
    "abseifend": "abseifen",
    "abseifende": "abseifend",
    "abseifendem": "abseifend",
    "abseifenden": "abseifend",
    "abseifender": "abseifend",
    "abseifendere": "abseifend",
    "abseifenderem": "abseifend",
    "abseifenderen": "abseifend",
    "abseifenderer": "abseifend",
    "abseifenderes": "abseifend",
    "abseifendes": "abseifend",
    "abseifendste": "abseifend",
    "abseifendstem": "abseifend",
    "abseifendsten": "abseifend",
    "abseifendster": "abseifend",
    "abseifendstes": "abseifend",
    "abseifest": "abseifen",
    "abseifet": "abseifen",
    "abseifst": "abseifen",
    "abseift": "abseifen",
    "abseifte": "abseifen",
    "abseiften": "abseifen",
    "abseiftest": "abseifen",
    "abseiftet": "abseifen",
    "abseile": "abseilen",
    "abseilend": "abseilen",
    "abseilende": "abseilend",
    "abseilendem": "abseilend",
    "abseilenden": "abseilend",
    "abseilender": "abseilend",
    "abseilendere": "abseilend",
    "abseilenderem": "abseilend",
    "abseilenderen": "abseilend",
    "abseilenderer": "abseilend",
    "abseilenderes": "abseilend",
    "abseilendes": "abseilend",
    "abseilendste": "abseilend",
    "abseilendstem": "abseilend",
    "abseilendsten": "abseilend",
    "abseilendster": "abseilend",
    "abseilendstes": "abseilend",
    "abseilest": "abseilen",
    "abseilet": "abseilen",
    "abseilst": "abseilen",
    "abseilt": "abseilen",
    "abseilte": "abseilen",
    "abseilten": "abseilen",
    "abseiltest": "abseilen",
    "abseiltet": "abseilen",
    "absende": "absenden",
    "absendend": "absenden",
    "absendende": "absendend",
    "absendendem": "absendend",
    "absendenden": "absendend",
    "absendender": "absendend",
    "absendendes": "absendend",
    "absendest": "absenden",
    "absendet": "absenden",
    "absendete": "absenden",
    "absendeten": "absenden",
    "absendetest": "absenden",
    "absendetet": "absenden",
    "absenge": "absengen",
    "absengend": "absengen",
    "absengende": "absengend",
    "absengendem": "absengend",
    "absengenden": "absengend",
    "absengender": "absengend",
    "absengendere": "absengend",
    "absengenderem": "absengend",
    "absengenderen": "absengend",
    "absengenderer": "absengend",
    "absengenderes": "absengend",
    "absengendes": "absengend",
    "absengendste": "absengend",
    "absengendstem": "absengend",
    "absengendsten": "absengend",
    "absengendster": "absengend",
    "absengendstes": "absengend",
    "absengest": "absengen",
    "absenget": "absengen",
    "absengst": "absengen",
    "absengt": "absengen",
    "absengte": "absengen",
    "absengten": "absengen",
    "absengtest": "absengen",
    "absengtet": "absengen",
    "absenke": "absenken",
    "absenkend": "absenken",
    "absenkende": "absenkend",
    "absenkendem": "absenkend",
    "absenkenden": "absenkend",
    "absenkender": "absenkend",
    "absenkendes": "absenkend",
    "absenkest": "absenken",
    "absenket": "absenken",
    "absenkst": "absenken",
    "absenkt": "absenken",
    "absenkte": "absenken",
    "absenkten": "absenken",
    "absenktest": "absenken",
    "absenktet": "absenken",
    "absetze": "absetzen",
    "absetzend": "absetzen",
    "absetzende": "absetzend",
    "absetzendem": "absetzend",
    "absetzenden": "absetzend",
    "absetzender": "absetzend",
    "absetzendes": "absetzend",
    "absetzest": "absetzen",
    "absetzet": "absetzen",
    "absetzt": "absetzen",
    "absetzte": "absetzen",
    "absetzten": "absetzen",
    "absetztest": "absetzen",
    "absetztet": "absetzen",
    "absichere": "absichern",
    "absichernd": "absichern",
    "absichernde": "absichernd",
    "absicherndem": "absichernd",
    "absichernden": "absichernd",
    "absichernder": "absichernd",
    "absicherndere": "absichernd",
    "absichernderem": "absichernd",
    "absichernderen": "absichernd",
    "absichernderer": "absichernd",
    "absichernderes": "absichernd",
    "absicherndes": "absichernd",
    "absicherndste": "absichernd",
    "absicherndstem": "absichernd",
    "absicherndsten": "absichernd",
    "absicherndster": "absichernd",
    "absicherndstes": "absichernd",
    "absicherst": "absichern",
    "absichert": "absichern",
    "absicherte": "absichern",
    "absicherten": "absichern",
    "absichertest": "absichern",
    "absichertet": "absichern",
    "absiehst": "absehen",
    "absieht": "absehen",
    "absinge": "absingen",
    "absingend": "absingen",
    "absingende": "absingend",
    "absingendem": "absingend",
    "absingenden": "absingend",
    "absingender": "absingend",
    "absingendes": "absingend",
    "absingest": "absingen",
    "absinget": "absingen",
    "absingst": "absingen",
    "absingt": "absingen",
    "absitze": "absitzen",
    "absitzend": "absitzen",
    "absitzende": "absitzend",
    "absitzendem": "absitzend",
    "absitzenden": "absitzend",
    "absitzender": "absitzend",
    "absitzendes": "absitzend",
    "absitzest": "absitzen",
    "absitzet": "absitzen",
    "absitzt": "absitzen",
    "absoff": "absaufen",
    "absoffen": "absaufen",
    "absoffst": "absaufen",
    "absofft": "absaufen",
    "absog": "absaugen",
    "absogen": "absaugen",
    "absogst": "absaugen",
    "absogt": "absaugen",
    "absolute": "absolut",
    "absolutem": "absolut",
    "absoluten": "absolut",
    "absoluter": "absolut",
    "absolutes": "absolut",
    "absolutistischem": "absolutistisch",
    "absolutistischen": "absolutistisch",
    "absolutistischer": "absolutistisch",
    "absolutistischere": "absolutistisch",
    "absolutistischerem": "absolutistisch",
    "absolutistischeren": "absolutistisch",
    "absolutistischerer": "absolutistisch",
    "absolutistischeres": "absolutistisch",
    "absolutistisches": "absolutistisch",
    "absolutistischste": "absolutistisch",
    "absolutistischstem": "absolutistisch",
    "absolutistischsten": "absolutistisch",
    "absolutistischster": "absolutistisch",
    "absolutistischstes": "absolutistisch",
    "absolviere": "absolvieren",
    "absolvierend": "absolvieren",
    "absolvierende": "absolvierend",
    "absolvierendem": "absolvierend",
    "absolvierenden": "absolvierend",
    "absolvierender": "absolvierend",
    "absolvierendes": "absolvierend",
    "absolvierest": "absolvieren",
    "absolvieret": "absolvieren",
    "absolvierst": "absolvieren",
    "absolviert": "absolvieren",
    "absolvierte": "absolvieren",
    "absolviertem": "absolviert",
    "absolvierten": "absolvieren",
    "absolvierter": "absolviert",
    "absolviertes": "absolviert",
    "absolviertest": "absolvieren",
    "absolviertet": "absolvieren",
    "absondere": "absondern",
    "absonderliche": "absonderlich",
    "absonderlichem": "absonderlich",
    "absonderlichen": "absonderlich",
    "absonderlicher": "absonderlich",
    "absonderlichere": "absonderlich",
    "absonderlicherem": "absonderlich",
    "absonderlicheren": "absonderlich",
    "absonderlicherer": "absonderlich",
    "absonderlicheres": "absonderlich",
    "absonderliches": "absonderlich",
    "absonderlichstem": "absonderlich",
    "absonderlichsten": "absonderlich",
    "absonderlichster": "absonderlich",
    "absonderlichstes": "absonderlich",
    "absondernd": "absondern",
    "absondernde": "absondernd",
    "absonderndem": "absondernd",
    "absondernden": "absondernd",
    "absondernder": "absondernd",
    "absonderndes": "absondernd",
    "absonderst": "absondern",
    "absondert": "absondern",
    "absonderte": "absondern",
    "absonderten": "absondern",
    "absondertest": "absondern",
    "absondertet": "absondern",
    "absorbiere": "absorbieren",
    "absorbierend": "absorbieren",
    "absorbierende": "absorbierend",
    "absorbierendem": "absorbierend",
    "absorbierenden": "absorbierend",
    "absorbierender": "absorbierend",
    "absorbierendere": "absorbierend",
    "absorbierenderem": "absorbierend",
    "absorbierenderen": "absorbierend",
    "absorbierenderer": "absorbierend",
    "absorbierenderes": "absorbierend",
    "absorbierendes": "absorbierend",
    "absorbierendste": "absorbierend",
    "absorbierendstem": "absorbierend",
    "absorbierendsten": "absorbierend",
    "absorbierendster": "absorbierend",
    "absorbierendstes": "absorbierend",
    "absorbierest": "absorbieren",
    "absorbieret": "absorbieren",
    "absorbierst": "absorbieren",
    "absorbiert": "absorbieren",
    "absorbierte": "absorbieren",
    "absorbiertem": "absorbiert",
    "absorbierten": "absorbieren",
    "absorbierter": "absorbiert",
    "absorbiertere": "absorbiert",
    "absorbierterem": "absorbiert",
    "absorbierteren": "absorbiert",
    "absorbierterer": "absorbiert",
    "absorbierteres": "absorbiert",
    "absorbiertes": "absorbiert",
    "absorbiertest": "absorbieren",
    "absorbierteste": "absorbiert",
    "absorbiertestem": "absorbiert",
    "absorbiertesten": "absorbiert",
    "absorbiertester": "absorbiert",
    "absorbiertestes": "absorbiert",
    "absorbiertet": "absorbieren",
    "abspalte": "abspalten",
    "abspaltend": "abspalten",
    "abspaltende": "abspaltend",
    "abspaltendem": "abspaltend",
    "abspaltenden": "abspaltend",
    "abspaltender": "abspaltend",
    "abspaltendere": "abspaltend",
    "abspaltenderem": "abspaltend",
    "abspaltenderen": "abspaltend",
    "abspaltenderer": "abspaltend",
    "abspaltenderes": "abspaltend",
    "abspaltendes": "abspaltend",
    "abspaltendste": "abspaltend",
    "abspaltendstem": "abspaltend",
    "abspaltendsten": "abspaltend",
    "abspaltendster": "abspaltend",
    "abspaltendstes": "abspaltend",
    "abspaltest": "abspalten",
    "abspaltet": "abspalten",
    "abspaltete": "abspalten",
    "abspalteten": "abspalten",
    "abspaltetest": "abspalten",
    "abspaltetet": "abspalten",
    "abspanne": "abspannen",
    "abspannend": "abspannen",
    "abspannende": "abspannend",
    "abspannendem": "abspannend",
    "abspannenden": "abspannend",
    "abspannender": "abspannend",
    "abspannendes": "abspannend",
    "abspannest": "abspannen",
    "abspannet": "abspannen",
    "abspannst": "abspannen",
    "abspannt": "abspannen",
    "abspannte": "abspannen",
    "abspannten": "abspannen",
    "abspanntest": "abspannen",
    "abspanntet": "abspannen",
    "abspare": "absparen",
    "absparend": "absparen",
    "absparende": "absparend",
    "absparendem": "absparend",
    "absparenden": "absparend",
    "absparender": "absparend",
    "absparendere": "absparend",
    "absparenderem": "absparend",
    "absparenderen": "absparend",
    "absparenderer": "absparend",
    "absparenderes": "absparend",
    "absparendes": "absparend",
    "absparendste": "absparend",
    "absparendstem": "absparend",
    "absparendsten": "absparend",
    "absparendster": "absparend",
    "absparendstes": "absparend",
    "absparest": "absparen",
    "absparet": "absparen",
    "absparst": "absparen",
    "abspart": "absparen",
    "absparte": "absparen",
    "absparten": "absparen",
    "abspartest": "absparen",
    "abspartet": "absparen",
    "abspeichere": "abspeichern",
    "abspeichernd": "abspeichern",
    "abspeichernde": "abspeichernd",
    "abspeicherndem": "abspeichernd",
    "abspeichernden": "abspeichernd",
    "abspeichernder": "abspeichernd",
    "abspeicherndes": "abspeichernd",
    "abspeicherst": "abspeichern",
    "abspeichert": "abspeichern",
    "abspeicherte": "abspeichern",
    "abspeicherten": "abspeichern",
    "abspeichertest": "abspeichern",
    "abspeichertet": "abspeichern",
    "abspeise": "abspeisen",
    "abspeisend": "abspeisen",
    "abspeisende": "abspeisend",
    "abspeisendem": "abspeisend",
    "abspeisenden": "abspeisend",
    "abspeisender": "abspeisend",
    "abspeisendes": "abspeisend",
    "abspeisest": "abspeisen",
    "abspeiset": "abspeisen",
    "abspeist": "abspeisen",
    "abspeiste": "abspeisen",
    "abspeisten": "abspeisen",
    "abspeistest": "abspeisen",
    "abspeistet": "abspeisen",
    "abspenstige": "abspenstig",
    "abspenstigem": "abspenstig",
    "abspenstigen": "abspenstig",
    "abspenstiger": "abspenstig",
    "abspenstiges": "abspenstig",
    "absperre": "absperren",
    "absperrend": "absperren",
    "absperrende": "absperrend",
    "absperrendem": "absperrend",
    "absperrenden": "absperrend",
    "absperrender": "absperrend",
    "absperrendes": "absperrend",
    "absperrest": "absperren",
    "absperret": "absperren",
    "absperrst": "absperren",
    "absperrt": "absperren",
    "absperrte": "absperren",
    "absperrten": "absperren",
    "absperrtest": "absperren",
    "absperrtet": "absperren",
    "abspiegele": "abspiegeln",
    "abspiegelnd": "abspiegeln",
    "abspiegelnde": "abspiegelnd",
    "abspiegelndem": "abspiegelnd",
    "abspiegelnden": "abspiegelnd",
    "abspiegelnder": "abspiegelnd",
    "abspiegelndes": "abspiegelnd",
    "abspiegelst": "abspiegeln",
    "abspiegelt": "abspiegeln",
    "abspiegelte": "abspiegeln",
    "abspiegelten": "abspiegeln",
    "abspiegeltest": "abspiegeln",
    "abspiegeltet": "abspiegeln",
    "abspiegle": "abspiegeln",
    "abspielend": "abspielen",
    "abspielende": "abspielend",
    "abspielendem": "abspielend",
    "abspielenden": "abspielend",
    "abspielender": "abspielend",
    "abspielendes": "abspielend",
    "abspielest": "abspielen",
    "abspielet": "abspielen",
    "abspielst": "abspielen",
    "abspielt": "abspielen",
    "abspielte": "abspielen",
    "abspielten": "abspielen",
    "abspieltest": "abspielen",
    "abspieltet": "abspielen",
    "absplittere": "absplittern",
    "absplitternd": "absplittern",
    "absplitternde": "absplitternd",
    "absplitterndem": "absplitternd",
    "absplitternden": "absplitternd",
    "absplitternder": "absplitternd",
    "absplitterndes": "absplitternd",
    "absplitterst": "absplittern",
    "absplittert": "absplittern",
    "absplitterte": "absplittern",
    "absplitterten": "absplittern",
    "absplittertest": "absplittern",
    "absplittertet": "absplittern",
    "absprach": "absprechen",
    "absprachst": "absprechen",
    "abspracht": "absprechen",
    "absprang": "abspringen",
    "absprangen": "abspringen",
    "absprangst": "abspringen",
    "absprangt": "abspringen",
    "abspreche": "absprechen",
    "absprechend": "absprechen",
    "absprechende": "absprechend",
    "absprechendem": "absprechend",
    "absprechenden": "absprechend",
    "absprechender": "absprechend",
    "absprechendes": "absprechend",
    "absprechest": "absprechen",
    "absprechet": "absprechen",
    "absprecht": "absprechen",
    "abspreize": "abspreizen",
    "abspreizend": "abspreizen",
    "abspreizende": "abspreizend",
    "abspreizendem": "abspreizend",
    "abspreizenden": "abspreizend",
    "abspreizender": "abspreizend",
    "abspreizendes": "abspreizend",
    "abspreizest": "abspreizen",
    "abspreizet": "abspreizen",
    "abspreizt": "abspreizen",
    "abspreizte": "abspreizen",
    "abspreizten": "abspreizen",
    "abspreiztest": "abspreizen",
    "abspreiztet": "abspreizen",
    "absprenge": "absprengen",
    "absprengend": "absprengen",
    "absprengende": "absprengend",
    "absprengendem": "absprengend",
    "absprengenden": "absprengend",
    "absprengender": "absprengend",
    "absprengendes": "absprengend",
    "absprengest": "absprengen",
    "absprenget": "absprengen",
    "absprengst": "absprengen",
    "absprengt": "absprengen",
    "absprengte": "absprengen",
    "absprengten": "absprengen",
    "absprengtest": "absprengen",
    "absprengtet": "absprengen",
    "absprichst": "absprechen",
    "abspricht": "absprechen",
    "abspringe": "abspringen",
    "abspringend": "abspringen",
    "abspringende": "abspringend",
    "abspringendem": "abspringend",
    "abspringenden": "abspringend",
    "abspringender": "abspringend",
    "abspringendes": "abspringend",
    "abspringest": "abspringen",
    "abspringet": "abspringen",
    "abspringst": "abspringen",
    "abspringt": "abspringen",
    "abspritze": "abspritzen",
    "abspritzend": "abspritzen",
    "abspritzende": "abspritzend",
    "abspritzendem": "abspritzend",
    "abspritzenden": "abspritzend",
    "abspritzender": "abspritzend",
    "abspritzendes": "abspritzend",
    "abspritzest": "abspritzen",
    "abspritzet": "abspritzen",
    "abspritzt": "abspritzen",
    "abspritzte": "abspritzen",
    "abspritzten": "abspritzen",
    "abspritztest": "abspritzen",
    "abspritztet": "abspritzen",
    "abspräche": "absprechen",
    "absprächen": "absprechen",
    "absprächest": "absprechen",
    "absprächet": "absprechen",
    "abspränge": "abspringen",
    "absprängen": "abspringen",
    "absprängest": "abspringen",
    "abspränget": "abspringen",
    "absprühe": "absprühen",
    "absprühend": "absprühen",
    "absprühende": "absprühend",
    "absprühendem": "absprühend",
    "absprühenden": "absprühend",
    "absprühender": "absprühend",
    "absprühendes": "absprühend",
    "absprühest": "absprühen",
    "absprühet": "absprühen",
    "absprühst": "absprühen",
    "absprüht": "absprühen",
    "absprühte": "absprühen",
    "absprühten": "absprühen",
    "absprühtest": "absprühen",
    "absprühtet": "absprühen",
    "abspule": "abspulen",
    "abspulend": "abspulen",
    "abspulende": "abspulend",
    "abspulendem": "abspulend",
    "abspulenden": "abspulend",
    "abspulender": "abspulend",
    "abspulendes": "abspulend",
    "abspulest": "abspulen",
    "abspulet": "abspulen",
    "abspulst": "abspulen",
    "abspult": "abspulen",
    "abspulte": "abspulen",
    "abspulten": "abspulen",
    "abspultest": "abspulen",
    "abspultet": "abspulen",
    "abspüle": "abspülen",
    "abspülend": "abspülen",
    "abspülendem": "abspülend",
    "abspülender": "abspülend",
    "abspülendes": "abspülend",
    "abspülest": "abspülen",
    "abspület": "abspülen",
    "abspülst": "abspülen",
    "abspült": "abspülen",
    "abspülte": "abspülen",
    "abspülten": "abspülen",
    "abspültest": "abspülen",
    "abspültet": "abspülen",
    "abstach": "abstechen",
    "abstachen": "abstechen",
    "abstachst": "abstechen",
    "abstacht": "abstechen",
    "abstamme": "abstammen",
    "abstammend": "abstammen",
    "abstammende": "abstammend",
    "abstammendem": "abstammend",
    "abstammenden": "abstammend",
    "abstammender": "abstammend",
    "abstammendes": "abstammend",
    "abstammest": "abstammen",
    "abstammet": "abstammen",
    "abstammst": "abstammen",
    "abstammt": "abstammen",
    "abstammte": "abstammen",
    "abstammten": "abstammen",
    "abstammtest": "abstammen",
    "abstammtet": "abstammen",
    "abstanden": "abstehen",
    "abstandest": "abstehen",
    "abstandet": "abstehen",
    "abstarb": "absterben",
    "abstarben": "absterben",
    "abstarbst": "absterben",
    "abstarbt": "absterben",
    "abstatte": "abstatten",
    "abstattend": "abstatten",
    "abstattende": "abstattend",
    "abstattendem": "abstattend",
    "abstattenden": "abstattend",
    "abstattender": "abstattend",
    "abstattendes": "abstattend",
    "abstattest": "abstatten",
    "abstattet": "abstatten",
    "abstattete": "abstatten",
    "abstatteten": "abstatten",
    "abstattetest": "abstatten",
    "abstattetet": "abstatten",
    "abstaube": "abstauben",
    "abstaubend": "abstauben",
    "abstaubende": "abstaubend",
    "abstaubendem": "abstaubend",
    "abstaubenden": "abstaubend",
    "abstaubender": "abstaubend",
    "abstaubendere": "abstaubend",
    "abstaubenderem": "abstaubend",
    "abstaubenderen": "abstaubend",
    "abstaubenderer": "abstaubend",
    "abstaubenderes": "abstaubend",
    "abstaubendes": "abstaubend",
    "abstaubendste": "abstaubend",
    "abstaubendstem": "abstaubend",
    "abstaubendsten": "abstaubend",
    "abstaubendster": "abstaubend",
    "abstaubendstes": "abstaubend",
    "abstaubest": "abstauben",
    "abstaubet": "abstauben",
    "abstaubst": "abstauben",
    "abstaubt": "abstauben",
    "abstaubte": "abstauben",
    "abstaubten": "abstauben",
    "abstaubtest": "abstauben",
    "abstaubtet": "abstauben",
    "absteche": "abstechen",
    "abstechend": "abstechen",
    "abstechende": "abstechend",
    "abstechendem": "abstechend",
    "abstechenden": "abstechend",
    "abstechender": "abstechend",
    "abstechendes": "abstechend",
    "abstechest": "abstechen",
    "abstechet": "abstechen",
    "abstecht": "abstechen",
    "abstehe": "abstehen",
    "abstehend": "abstehen",
    "abstehende": "abstehend",
    "abstehendem": "abstehend",
    "abstehenden": "abstehend",
    "abstehender": "abstehend",
    "abstehendere": "abstehend",
    "abstehenderem": "abstehend",
    "abstehenderen": "abstehend",
    "abstehenderer": "abstehend",
    "abstehenderes": "abstehend",
    "abstehendes": "abstehend",
    "abstehendste": "abstehend",
    "abstehendstem": "abstehend",
    "abstehendsten": "abstehend",
    "abstehendster": "abstehend",
    "abstehendstes": "abstehend",
    "abstehest": "abstehen",
    "abstehet": "abstehen",
    "abstehst": "abstehen",
    "absteht": "abstehen",
    "absteife": "absteifen",
    "absteifend": "absteifen",
    "absteifende": "absteifend",
    "absteifendem": "absteifend",
    "absteifenden": "absteifend",
    "absteifender": "absteifend",
    "absteifendere": "absteifend",
    "absteifenderem": "absteifend",
    "absteifenderen": "absteifend",
    "absteifenderer": "absteifend",
    "absteifenderes": "absteifend",
    "absteifendes": "absteifend",
    "absteifendste": "absteifend",
    "absteifendstem": "absteifend",
    "absteifendsten": "absteifend",
    "absteifendster": "absteifend",
    "absteifendstes": "absteifend",
    "absteifest": "absteifen",
    "absteifet": "absteifen",
    "absteifst": "absteifen",
    "absteift": "absteifen",
    "absteifte": "absteifen",
    "absteiften": "absteifen",
    "absteiftest": "absteifen",
    "absteiftet": "absteifen",
    "absteige": "absteigen",
    "absteigend": "absteigen",
    "absteigende": "absteigend",
    "absteigendem": "absteigend",
    "absteigenden": "absteigend",
    "absteigender": "absteigend",
    "absteigendes": "absteigend",
    "absteigest": "absteigen",
    "absteiget": "absteigen",
    "absteigst": "absteigen",
    "absteigt": "absteigen",
    "abstelle": "abstellen",
    "abstellend": "abstellen",
    "abstellende": "abstellend",
    "abstellendem": "abstellend",
    "abstellenden": "abstellend",
    "abstellender": "abstellend",
    "abstellendes": "abstellend",
    "abstellest": "abstellen",
    "abstellet": "abstellen",
    "abstellst": "abstellen",
    "abstellt": "abstellen",
    "abstellte": "abstellen",
    "abstellten": "abstellen",
    "abstelltest": "abstellen",
    "abstelltet": "abstellen",
    "abstempele": "abstempeln",
    "abstempelnd": "abstempeln",
    "abstempelnde": "abstempelnd",
    "abstempelndem": "abstempelnd",
    "abstempelnden": "abstempelnd",
    "abstempelnder": "abstempelnd",
    "abstempelndes": "abstempelnd",
    "abstempelst": "abstempeln",
    "abstempelt": "abstempeln",
    "abstempelte": "abstempeln",
    "abstempelten": "abstempeln",
    "abstempeltest": "abstempeln",
    "abstempeltet": "abstempeln",
    "abstemple": "abstempeln",
    "absteppe": "absteppen",
    "absteppend": "absteppen",
    "absteppende": "absteppend",
    "absteppendem": "absteppend",
    "absteppenden": "absteppend",
    "absteppender": "absteppend",
    "absteppendere": "absteppend",
    "absteppenderem": "absteppend",
    "absteppenderen": "absteppend",
    "absteppenderer": "absteppend",
    "absteppenderes": "absteppend",
    "absteppendes": "absteppend",
    "absteppendste": "absteppend",
    "absteppendstem": "absteppend",
    "absteppendsten": "absteppend",
    "absteppendster": "absteppend",
    "absteppendstes": "absteppend",
    "absteppest": "absteppen",
    "absteppet": "absteppen",
    "absteppst": "absteppen",
    "absteppt": "absteppen",
    "absteppte": "absteppen",
    "absteppten": "absteppen",
    "abstepptest": "absteppen",
    "abstepptet": "absteppen",
    "absterbe": "absterben",
    "absterbend": "absterben",
    "absterbende": "absterbend",
    "absterbendem": "absterbend",
    "absterbenden": "absterbend",
    "absterbender": "absterbend",
    "absterbendere": "absterbend",
    "absterbenderem": "absterbend",
    "absterbenderen": "absterbend",
    "absterbenderer": "absterbend",
    "absterbenderes": "absterbend",
    "absterbendes": "absterbend",
    "absterbendste": "absterbend",
    "absterbendstem": "absterbend",
    "absterbendsten": "absterbend",
    "absterbendster": "absterbend",
    "absterbendstes": "absterbend",
    "absterbest": "absterben",
    "absterbet": "absterben",
    "absterbt": "absterben",
    "abstichst": "abstechen",
    "absticht": "abstechen",
    "abstieg": "absteigen",
    "abstiegest": "absteigen",
    "abstieget": "absteigen",
    "abstiegsgefährdetem": "abstiegsgefährdet",
    "abstiegsgefährdeten": "abstiegsgefährdet",
    "abstiegsgefährdeter": "abstiegsgefährdet",
    "abstiegsgefährdetere": "abstiegsgefährdet",
    "abstiegsgefährdeterem": "abstiegsgefährdet",
    "abstiegsgefährdeteren": "abstiegsgefährdet",
    "abstiegsgefährdeterer": "abstiegsgefährdet",
    "abstiegsgefährdeteres": "abstiegsgefährdet",
    "abstiegsgefährdetes": "abstiegsgefährdet",
    "abstiegsgefährdeteste": "abstiegsgefährdet",
    "abstiegsgefährdetestem": "abstiegsgefährdet",
    "abstiegsgefährdetesten": "abstiegsgefährdet",
    "abstiegsgefährdetester": "abstiegsgefährdet",
    "abstiegsgefährdetestes": "abstiegsgefährdet",
    "abstiegst": "absteigen",
    "abstiegt": "absteigen",
    "abstiele": "abstielen",
    "abstielend": "abstielen",
    "abstielende": "abstielend",
    "abstielendem": "abstielend",
    "abstielenden": "abstielend",
    "abstielender": "abstielend",
    "abstielendes": "abstielend",
    "abstielest": "abstielen",
    "abstielet": "abstielen",
    "abstielst": "abstielen",
    "abstielt": "abstielen",
    "abstielte": "abstielen",
    "abstielten": "abstielen",
    "abstieltest": "abstielen",
    "abstieltet": "abstielen",
    "abstieß": "abstoßen",
    "abstieße": "abstoßen",
    "abstießen": "abstoßen",
    "abstießest": "abstoßen",
    "abstießet": "abstoßen",
    "abstießt": "abstoßen",
    "abstille": "abstillen",
    "abstillend": "abstillen",
    "abstillende": "abstillend",
    "abstillendem": "abstillend",
    "abstillenden": "abstillend",
    "abstillender": "abstillend",
    "abstillendes": "abstillend",
    "abstillest": "abstillen",
    "abstillet": "abstillen",
    "abstillst": "abstillen",
    "abstillt": "abstillen",
    "abstillte": "abstillen",
    "abstillten": "abstillen",
    "abstilltest": "abstillen",
    "abstilltet": "abstillen",
    "abstimme": "abstimmen",
    "abstimmend": "abstimmen",
    "abstimmende": "abstimmend",
    "abstimmendem": "abstimmend",
    "abstimmenden": "abstimmend",
    "abstimmender": "abstimmend",
    "abstimmendes": "abstimmend",
    "abstimmest": "abstimmen",
    "abstimmet": "abstimmen",
    "abstimmst": "abstimmen",
    "abstimmt": "abstimmen",
    "abstimmte": "abstimmen",
    "abstimmten": "abstimmen",
    "abstimmtest": "abstimmen",
    "abstimmtet": "abstimmen",
    "abstirbst": "absterben",
    "abstirbt": "absterben",
    "abstoppe": "abstoppen",
    "abstoppend": "abstoppen",
    "abstoppende": "abstoppend",
    "abstoppendem": "abstoppend",
    "abstoppenden": "abstoppend",
    "abstoppender": "abstoppend",
    "abstoppendes": "abstoppend",
    "abstoppest": "abstoppen",
    "abstoppet": "abstoppen",
    "abstoppst": "abstoppen",
    "abstoppt": "abstoppen",
    "abstoppte": "abstoppen",
    "abstoppten": "abstoppen",
    "abstopptest": "abstoppen",
    "abstopptet": "abstoppen",
    "abstottere": "abstottern",
    "abstotternd": "abstottern",
    "abstotternde": "abstotternd",
    "abstotterndem": "abstotternd",
    "abstotternden": "abstotternd",
    "abstotternder": "abstotternd",
    "abstotterndes": "abstotternd",
    "abstotterst": "abstottern",
    "abstottert": "abstottern",
    "abstotterte": "abstottern",
    "abstotterten": "abstottern",
    "abstottertest": "abstottern",
    "abstottertet": "abstottern",
    "abstoße": "abstoßen",
    "abstoßend": "abstoßen",
    "abstoßende": "abstoßend",
    "abstoßendem": "abstoßend",
    "abstoßenden": "abstoßend",
    "abstoßender": "abstoßend",
    "abstoßendere": "abstoßend",
    "abstoßenderem": "abstoßend",
    "abstoßenderen": "abstoßend",
    "abstoßenderer": "abstoßend",
    "abstoßenderes": "abstoßend",
    "abstoßendes": "abstoßend",
    "abstoßendste": "abstoßend",
    "abstoßendstem": "abstoßend",
    "abstoßendsten": "abstoßend",
    "abstoßendster": "abstoßend",
    "abstoßendstes": "abstoßend",
    "abstoßest": "abstoßen",
    "abstoßet": "abstoßen",
    "abstoßt": "abstoßen",
    "abstrafe": "abstrafen",
    "abstrafend": "abstrafen",
    "abstrafende": "abstrafend",
    "abstrafendem": "abstrafend",
    "abstrafenden": "abstrafend",
    "abstrafender": "abstrafend",
    "abstrafendes": "abstrafend",
    "abstrafest": "abstrafen",
    "abstrafet": "abstrafen",
    "abstrafst": "abstrafen",
    "abstraft": "abstrafen",
    "abstrafte": "abstrafen",
    "abstraften": "abstrafen",
    "abstraftest": "abstrafen",
    "abstraftet": "abstrafen",
    "abstrahle": "abstrahlen",
    "abstrahlend": "abstrahlen",
    "abstrahlende": "abstrahlend",
    "abstrahlendem": "abstrahlend",
    "abstrahlenden": "abstrahlend",
    "abstrahlender": "abstrahlend",
    "abstrahlendes": "abstrahlend",
    "abstrahlest": "abstrahlen",
    "abstrahlet": "abstrahlen",
    "abstrahlst": "abstrahlen",
    "abstrahlt": "abstrahlen",
    "abstrahlte": "abstrahlen",
    "abstrahlten": "abstrahlen",
    "abstrahltest": "abstrahlen",
    "abstrahltet": "abstrahlen",
    "abstraktem": "abstrakt",
    "abstrakten": "abstrakt",
    "abstrakter": "abstrakt",
    "abstraktere": "abstrakt",
    "abstrakterem": "abstrakt",
    "abstrakteren": "abstrakt",
    "abstrakterer": "abstrakt",
    "abstrakteres": "abstrakt",
    "abstraktes": "abstrakt",
    "abstrakteste": "abstrakt",
    "abstraktestem": "abstrakt",
    "abstraktesten": "abstrakt",
    "abstraktester": "abstrakt",
    "abstraktestes": "abstrakt",
    "abstrampele": "abstrampeln",
    "abstrampelnd": "abstrampeln",
    "abstrampelnde": "abstrampelnd",
    "abstrampelndem": "abstrampelnd",
    "abstrampelnden": "abstrampelnd",
    "abstrampelnder": "abstrampelnd",
    "abstrampelndes": "abstrampelnd",
    "abstrampelst": "abstrampeln",
    "abstrampelt": "abstrampeln",
    "abstrampelte": "abstrampeln",
    "abstrampelten": "abstrampeln",
    "abstrampeltest": "abstrampeln",
    "abstrampeltet": "abstrampeln",
    "abstrample": "abstrampeln",
    "abstrebe": "abstreben",
    "abstrebend": "abstreben",
    "abstrebende": "abstrebend",
    "abstrebendem": "abstrebend",
    "abstrebenden": "abstrebend",
    "abstrebender": "abstrebend",
    "abstrebendes": "abstrebend",
    "abstrebest": "abstreben",
    "abstrebet": "abstreben",
    "abstrebst": "abstreben",
    "abstrebt": "abstreben",
    "abstrebte": "abstreben",
    "abstrebten": "abstreben",
    "abstrebtest": "abstreben",
    "abstrebtet": "abstreben",
    "abstreiche": "abstreichen",
    "abstreichend": "abstreichen",
    "abstreichende": "abstreichend",
    "abstreichendem": "abstreichend",
    "abstreichenden": "abstreichend",
    "abstreichender": "abstreichend",
    "abstreichendes": "abstreichend",
    "abstreichest": "abstreichen",
    "abstreichet": "abstreichen",
    "abstreichst": "abstreichen",
    "abstreicht": "abstreichen",
    "abstreife": "abstreifen",
    "abstreifend": "abstreifen",
    "abstreifende": "abstreifend",
    "abstreifendem": "abstreifend",
    "abstreifenden": "abstreifend",
    "abstreifender": "abstreifend",
    "abstreifendes": "abstreifend",
    "abstreifest": "abstreifen",
    "abstreifet": "abstreifen",
    "abstreifst": "abstreifen",
    "abstreift": "abstreifen",
    "abstreifte": "abstreifen",
    "abstreiften": "abstreifen",
    "abstreiftest": "abstreifen",
    "abstreiftet": "abstreifen",
    "abstreite": "abstreiten",
    "abstreitend": "abstreiten",
    "abstreitende": "abstreitend",
    "abstreitendem": "abstreitend",
    "abstreitenden": "abstreitend",
    "abstreitender": "abstreitend",
    "abstreitendes": "abstreitend",
    "abstreitest": "abstreiten",
    "abstreitet": "abstreiten",
    "abstrich": "abstreichen",
    "abstrichest": "abstreichen",
    "abstrichet": "abstreichen",
    "abstrichst": "abstreichen",
    "abstricht": "abstreichen",
    "abstritt": "abstreiten",
    "abstritte": "abstreiten",
    "abstritten": "abstreiten",
    "abstrittest": "abstreiten",
    "abstrittet": "abstreiten",
    "abströme": "abströmen",
    "abströmend": "abströmen",
    "abströmende": "abströmend",
    "abströmendem": "abströmend",
    "abströmenden": "abströmend",
    "abströmender": "abströmend",
    "abströmendes": "abströmend",
    "abströmest": "abströmen",
    "abströmet": "abströmen",
    "abströmst": "abströmen",
    "abströmt": "abströmen",
    "abströmte": "abströmen",
    "abströmten": "abströmen",
    "abströmtest": "abströmen",
    "abströmtet": "abströmen",
    "abstufe": "abstufen",
    "abstufend": "abstufen",
    "abstufende": "abstufend",
    "abstufendem": "abstufend",
    "abstufenden": "abstufend",
    "abstufender": "abstufend",
    "abstufendes": "abstufend",
    "abstufest": "abstufen",
    "abstufet": "abstufen",
    "abstufst": "abstufen",
    "abstuft": "abstufen",
    "abstufte": "abstufen",
    "abstuften": "abstufen",
    "abstuftest": "abstufen",
    "abstuftet": "abstufen",
    "abstumpfe": "abstumpfen",
    "abstumpfend": "abstumpfen",
    "abstumpfende": "abstumpfend",
    "abstumpfendem": "abstumpfend",
    "abstumpfenden": "abstumpfend",
    "abstumpfender": "abstumpfend",
    "abstumpfendere": "abstumpfend",
    "abstumpfenderem": "abstumpfend",
    "abstumpfenderen": "abstumpfend",
    "abstumpfenderer": "abstumpfend",
    "abstumpfenderes": "abstumpfend",
    "abstumpfendes": "abstumpfend",
    "abstumpfendste": "abstumpfend",
    "abstumpfendstem": "abstumpfend",
    "abstumpfendsten": "abstumpfend",
    "abstumpfendster": "abstumpfend",
    "abstumpfendstes": "abstumpfend",
    "abstumpfest": "abstumpfen",
    "abstumpfet": "abstumpfen",
    "abstumpfst": "abstumpfen",
    "abstumpft": "abstumpfen",
    "abstumpfte": "abstumpfen",
    "abstumpften": "abstumpfen",
    "abstumpftest": "abstumpfen",
    "abstumpftet": "abstumpfen",
    "abstäche": "abstechen",
    "abstächen": "abstechen",
    "abstächest": "abstechen",
    "abstächet": "abstechen",
    "abstärbe": "absterben",
    "abstärben": "absterben",
    "abstärbest": "absterben",
    "abstärbet": "absterben",
    "abstößt": "abstoßen",
    "abstünde": "abstehen",
    "abstünden": "abstehen",
    "abstündest": "abstehen",
    "abstündet": "abstehen",
    "abstürzend": "abstürzen",
    "abstürzende": "abstürzend",
    "abstürzendem": "abstürzend",
    "abstürzenden": "abstürzend",
    "abstürzender": "abstürzend",
    "abstürzendere": "abstürzend",
    "abstürzenderem": "abstürzend",
    "abstürzenderen": "abstürzend",
    "abstürzenderer": "abstürzend",
    "abstürzenderes": "abstürzend",
    "abstürzendes": "abstürzend",
    "abstürzendste": "abstürzend",
    "abstürzendstem": "abstürzend",
    "abstürzendsten": "abstürzend",
    "abstürzendster": "abstürzend",
    "abstürzendstes": "abstürzend",
    "abstürzest": "abstürzen",
    "abstürzet": "abstürzen",
    "abstürzt": "abstürzen",
    "abstürzte": "abstürzen",
    "abstürzten": "abstürzen",
    "abstürztest": "abstürzen",
    "abstürztet": "abstürzen",
    "abstütze": "abstützen",
    "abstützend": "abstützen",
    "abstützende": "abstützend",
    "abstützendem": "abstützend",
    "abstützenden": "abstützend",
    "abstützender": "abstützend",
    "abstützendes": "abstützend",
    "abstützest": "abstützen",
    "abstützet": "abstützen",
    "abstützt": "abstützen",
    "abstützte": "abstützen",
    "abstützten": "abstützen",
    "abstütztest": "abstützen",
    "abstütztet": "abstützen",
    "absuche": "absuchen",
    "absuchend": "absuchen",
    "absuchende": "absuchend",
    "absuchendem": "absuchend",
    "absuchenden": "absuchend",
    "absuchender": "absuchend",
    "absuchendes": "absuchend",
    "absuchest": "absuchen",
    "absuchet": "absuchen",
    "absuchst": "absuchen",
    "absucht": "absuchen",
    "absuchte": "absuchen",
    "absuchten": "absuchen",
    "absuchtest": "absuchen",
    "absuchtet": "absuchen",
    "absurde": "absurd",
    "absurdem": "absurd",
    "absurden": "absurd",
    "absurder": "absurd",
    "absurdere": "absurd",
    "absurderem": "absurd",
    "absurderen": "absurd",
    "absurderer": "absurd",
    "absurderes": "absurd",
    "absurdes": "absurd",
    "absurdeste": "absurd",
    "absurdestem": "absurd",
    "absurdesten": "absurd",
    "absurdester": "absurd",
    "absurdestes": "absurd",
    "absäbele": "absäbeln",
    "absäbelnd": "absäbeln",
    "absäbelnde": "absäbelnd",
    "absäbelndem": "absäbelnd",
    "absäbelnden": "absäbelnd",
    "absäbelnder": "absäbelnd",
    "absäbelndes": "absäbelnd",
    "absäbelst": "absäbeln",
    "absäbelt": "absäbeln",
    "absäbelte": "absäbeln",
    "absäbelten": "absäbeln",
    "absäbeltest": "absäbeln",
    "absäbeltet": "absäbeln",
    "absäble": "absäbeln",
    "absäge": "absägen",
    "absägend": "absägen",
    "absägendem": "absägend",
    "absägender": "absägend",
    "absägendes": "absägend",
    "absägest": "absägen",
    "absäget": "absägen",
    "absägst": "absägen",
    "absägt": "absägen",
    "absägte": "absägen",
    "absägten": "absägen",
    "absägtest": "absägen",
    "absägtet": "absägen",
    "absähe": "absehen",
    "absähen": "absehen",
    "absähest": "absehen",
    "absähet": "absehen",
    "absänge": "absingen",
    "absängen": "absingen",
    "absängest": "absingen",
    "absänget": "absingen",
    "absäufst": "absaufen",
    "absäuft": "absaufen",
    "absäße": "absitzen",
    "absäßen": "absitzen",
    "absäßest": "absitzen",
    "absäßet": "absitzen",
    "absöffe": "absaufen",
    "absöffen": "absaufen",
    "absöffest": "absaufen",
    "absöffet": "absaufen",
    "absöge": "absaugen",
    "absögen": "absaugen",
    "absögest": "absaugen",
    "absöget": "absaugen",
    "abtakele": "abtakeln",
    "abtakelnd": "abtakeln",
    "abtakelnde": "abtakelnd",
    "abtakelndem": "abtakelnd",
    "abtakelnden": "abtakelnd",
    "abtakelnder": "abtakelnd",
    "abtakelndes": "abtakelnd",
    "abtakelst": "abtakeln",
    "abtakelt": "abtakeln",
    "abtakelte": "abtakeln",
    "abtakelten": "abtakeln",
    "abtakeltest": "abtakeln",
    "abtakeltet": "abtakeln",
    "abtakle": "abtakeln",
    "abtanke": "abtanken",
    "abtankend": "abtanken",
    "abtankende": "abtankend",
    "abtankendem": "abtankend",
    "abtankenden": "abtankend",
    "abtankender": "abtankend",
    "abtankendes": "abtankend",
    "abtankest": "abtanken",
    "abtanket": "abtanken",
    "abtankst": "abtanken",
    "abtankt": "abtanken",
    "abtankte": "abtanken",
    "abtankten": "abtanken",
    "abtanktest": "abtanken",
    "abtanktet": "abtanken",
    "abtanze": "abtanzen",
    "abtanzend": "abtanzen",
    "abtanzende": "abtanzend",
    "abtanzendem": "abtanzend",
    "abtanzenden": "abtanzend",
    "abtanzender": "abtanzend",
    "abtanzendere": "abtanzend",
    "abtanzenderem": "abtanzend",
    "abtanzenderen": "abtanzend",
    "abtanzenderer": "abtanzend",
    "abtanzenderes": "abtanzend",
    "abtanzendes": "abtanzend",
    "abtanzendste": "abtanzend",
    "abtanzendstem": "abtanzend",
    "abtanzendsten": "abtanzend",
    "abtanzendster": "abtanzend",
    "abtanzendstes": "abtanzend",
    "abtanzest": "abtanzen",
    "abtanzet": "abtanzen",
    "abtanzt": "abtanzen",
    "abtanzte": "abtanzen",
    "abtanzten": "abtanzen",
    "abtanztest": "abtanzen",
    "abtanztet": "abtanzen",
    "abtaste": "abtasten",
    "abtastend": "abtasten",
    "abtastende": "abtastend",
    "abtastendem": "abtastend",
    "abtastenden": "abtastend",
    "abtastender": "abtastend",
    "abtastendes": "abtastend",
    "abtastest": "abtasten",
    "abtastet": "abtasten",
    "abtastete": "abtasten",
    "abtasteten": "abtasten",
    "abtastetest": "abtasten",
    "abtastetet": "abtasten",
    "abtauche": "abtauchen",
    "abtauchend": "abtauchen",
    "abtauchende": "abtauchend",
    "abtauchendem": "abtauchend",
    "abtauchenden": "abtauchend",
    "abtauchender": "abtauchend",
    "abtauchendes": "abtauchend",
    "abtauchest": "abtauchen",
    "abtauchet": "abtauchen",
    "abtauchst": "abtauchen",
    "abtaucht": "abtauchen",
    "abtauchte": "abtauchen",
    "abtauchten": "abtauchen",
    "abtauchtest": "abtauchen",
    "abtauchtet": "abtauchen",
    "abtaue": "abtauen",
    "abtauend": "abtauen",
    "abtauende": "abtauend",
    "abtauendem": "abtauend",
    "abtauenden": "abtauend",
    "abtauender": "abtauend",
    "abtauendes": "abtauend",
    "abtauest": "abtauen",
    "abtauet": "abtauen",
    "abtaust": "abtauen",
    "abtaut": "abtauen",
    "abtaute": "abtauen",
    "abtauten": "abtauen",
    "abtautest": "abtauen",
    "abtautet": "abtauen",
    "abteilend": "abteilen",
    "abteilende": "abteilend",
    "abteilendem": "abteilend",
    "abteilenden": "abteilend",
    "abteilender": "abteilend",
    "abteilendes": "abteilend",
    "abteilest": "abteilen",
    "abteilet": "abteilen",
    "abteilst": "abteilen",
    "abteilt": "abteilen",
    "abteilte": "abteilen",
    "abteilten": "abteilen",
    "abteiltest": "abteilen",
    "abteiltet": "abteilen",
    "abtelefoniere": "abtelefonieren",
    "abtelefonierend": "abtelefonieren",
    "abtelefonierende": "abtelefonierend",
    "abtelefonierendem": "abtelefonierend",
    "abtelefonierenden": "abtelefonierend",
    "abtelefonierender": "abtelefonierend",
    "abtelefonierendes": "abtelefonierend",
    "abtelefonierest": "abtelefonieren",
    "abtelefonieret": "abtelefonieren",
    "abtelefonierst": "abtelefonieren",
    "abtelefoniert": "abtelefonieren",
    "abtelefonierte": "abtelefonieren",
    "abtelefoniertem": "abtelefoniert",
    "abtelefonierten": "abtelefonieren",
    "abtelefonierter": "abtelefoniert",
    "abtelefoniertes": "abtelefoniert",
    "abtelefoniertest": "abtelefonieren",
    "abtelefoniertet": "abtelefonieren",
    "abtippe": "abtippen",
    "abtippend": "abtippen",
    "abtippende": "abtippend",
    "abtippendem": "abtippend",
    "abtippenden": "abtippend",
    "abtippender": "abtippend",
    "abtippendes": "abtippend",
    "abtippest": "abtippen",
    "abtippet": "abtippen",
    "abtippst": "abtippen",
    "abtippt": "abtippen",
    "abtippte": "abtippen",
    "abtippten": "abtippen",
    "abtipptest": "abtippen",
    "abtipptet": "abtippen",
    "abtragend": "abtragen",
    "abtragende": "abtragend",
    "abtragendem": "abtragend",
    "abtragenden": "abtragend",
    "abtragender": "abtragend",
    "abtragendes": "abtragend",
    "abtragest": "abtragen",
    "abtraget": "abtragen",
    "abtragt": "abtragen",
    "abtrank": "abtrinken",
    "abtranken": "abtrinken",
    "abtrankst": "abtrinken",
    "abtrankt": "abtrinken",
    "abtransportiere": "abtransportieren",
    "abtransportierend": "abtransportieren",
    "abtransportierende": "abtransportierend",
    "abtransportierendem": "abtransportierend",
    "abtransportierenden": "abtransportierend",
    "abtransportierender": "abtransportierend",
    "abtransportierendes": "abtransportierend",
    "abtransportierest": "abtransportieren",
    "abtransportieret": "abtransportieren",
    "abtransportierst": "abtransportieren",
    "abtransportiert": "abtransportieren",
    "abtransportierte": "abtransportieren",
    "abtransportiertem": "abtransportiert",
    "abtransportierten": "abtransportieren",
    "abtransportierter": "abtransportiert",
    "abtransportiertes": "abtransportiert",
    "abtransportiertest": "abtransportieren",
    "abtransportiertet": "abtransportieren",
    "abtrat": "abtreten",
    "abtraten": "abtreten",
    "abtratest": "abtreten",
    "abtratet": "abtreten",
    "abtreibe": "abtreiben",
    "abtreibend": "abtreiben",
    "abtreibende": "abtreibend",
    "abtreibendem": "abtreibend",
    "abtreibenden": "abtreibend",
    "abtreibender": "abtreibend",
    "abtreibendes": "abtreibend",
    "abtreibest": "abtreiben",
    "abtreibet": "abtreiben",
    "abtreibst": "abtreiben",
    "abtreibt": "abtreiben",
    "abtrennbarem": "abtrennbar",
    "abtrennbaren": "abtrennbar",
    "abtrennbarer": "abtrennbar",
    "abtrennbares": "abtrennbar",
    "abtrenne": "abtrennen",
    "abtrennend": "abtrennen",
    "abtrennende": "abtrennend",
    "abtrennendem": "abtrennend",
    "abtrennenden": "abtrennend",
    "abtrennender": "abtrennend",
    "abtrennendes": "abtrennend",
    "abtrennest": "abtrennen",
    "abtrennet": "abtrennen",
    "abtrennst": "abtrennen",
    "abtrennt": "abtrennen",
    "abtrennte": "abtrennen",
    "abtrennten": "abtrennen",
    "abtrenntest": "abtrennen",
    "abtrenntet": "abtrennen",
    "abtrete": "abtreten",
    "abtretend": "abtreten",
    "abtretende": "abtretend",
    "abtretendem": "abtretend",
    "abtretenden": "abtretend",
    "abtretender": "abtretend",
    "abtretendes": "abtretend",
    "abtretest": "abtreten",
    "abtretet": "abtreten",
    "abtriebe": "abtreiben",
    "abtriebest": "abtreiben",
    "abtriebet": "abtreiben",
    "abtriebst": "abtreiben",
    "abtriebt": "abtreiben",
    "abtrinke": "abtrinken",
    "abtrinkend": "abtrinken",
    "abtrinkende": "abtrinkend",
    "abtrinkendem": "abtrinkend",
    "abtrinkenden": "abtrinkend",
    "abtrinkender": "abtrinkend",
    "abtrinkendes": "abtrinkend",
    "abtrinkest": "abtrinken",
    "abtrinket": "abtrinken",
    "abtrinkst": "abtrinken",
    "abtrinkt": "abtrinken",
    "abtritt": "abtreten",
    "abtrittst": "abtreten",
    "abtrockne": "abtrocknen",
    "abtrocknend": "abtrocknen",
    "abtrocknende": "abtrocknend",
    "abtrocknendem": "abtrocknend",
    "abtrocknenden": "abtrocknend",
    "abtrocknender": "abtrocknend",
    "abtrocknendere": "abtrocknend",
    "abtrocknenderem": "abtrocknend",
    "abtrocknenderen": "abtrocknend",
    "abtrocknenderer": "abtrocknend",
    "abtrocknenderes": "abtrocknend",
    "abtrocknendes": "abtrocknend",
    "abtrocknendste": "abtrocknend",
    "abtrocknendstem": "abtrocknend",
    "abtrocknendsten": "abtrocknend",
    "abtrocknendster": "abtrocknend",
    "abtrocknendstes": "abtrocknend",
    "abtrocknest": "abtrocknen",
    "abtrocknet": "abtrocknen",
    "abtrocknete": "abtrocknen",
    "abtrockneten": "abtrocknen",
    "abtrocknetest": "abtrocknen",
    "abtrocknetet": "abtrocknen",
    "abtropfe": "abtropfen",
    "abtropfend": "abtropfen",
    "abtropfende": "abtropfend",
    "abtropfendem": "abtropfend",
    "abtropfenden": "abtropfend",
    "abtropfender": "abtropfend",
    "abtropfendes": "abtropfend",
    "abtropfest": "abtropfen",
    "abtropfet": "abtropfen",
    "abtropfst": "abtropfen",
    "abtropft": "abtropfen",
    "abtropfte": "abtropfen",
    "abtropften": "abtropfen",
    "abtropftest": "abtropfen",
    "abtropftet": "abtropfen",
    "abtrotze": "abtrotzen",
    "abtrotzend": "abtrotzen",
    "abtrotzende": "abtrotzend",
    "abtrotzendem": "abtrotzend",
    "abtrotzenden": "abtrotzend",
    "abtrotzender": "abtrotzend",
    "abtrotzendes": "abtrotzend",
    "abtrotzest": "abtrotzen",
    "abtrotzet": "abtrotzen",
    "abtrotzt": "abtrotzen",
    "abtrotzte": "abtrotzen",
    "abtrotzten": "abtrotzen",
    "abtrotztest": "abtrotzen",
    "abtrotztet": "abtrotzen",
    "abtrudele": "abtrudeln",
    "abtrudelnd": "abtrudeln",
    "abtrudelnde": "abtrudelnd",
    "abtrudelndem": "abtrudelnd",
    "abtrudelnden": "abtrudelnd",
    "abtrudelnder": "abtrudelnd",
    "abtrudelndes": "abtrudelnd",
    "abtrudelst": "abtrudeln",
    "abtrudelt": "abtrudeln",
    "abtrudelte": "abtrudeln",
    "abtrudelten": "abtrudeln",
    "abtrudeltest": "abtrudeln",
    "abtrudeltet": "abtrudeln",
    "abtrudle": "abtrudeln",
    "abtrug": "abtragen",
    "abtrugen": "abtragen",
    "abtrugst": "abtragen",
    "abtrugt": "abtragen",
    "abträgliche": "abträglich",
    "abträglichem": "abträglich",
    "abträglichen": "abträglich",
    "abträglicher": "abträglich",
    "abträgliches": "abträglich",
    "abträgst": "abtragen",
    "abträgt": "abtragen",
    "abtränke": "abtrinken",
    "abtränken": "abtrinken",
    "abtränkest": "abtrinken",
    "abtränket": "abtrinken",
    "abträte": "abtreten",
    "abträten": "abtreten",
    "abträtest": "abtreten",
    "abträtet": "abtreten",
    "abträufele": "abträufeln",
    "abträufelnd": "abträufeln",
    "abträufelnde": "abträufelnd",
    "abträufelndem": "abträufelnd",
    "abträufelnden": "abträufelnd",
    "abträufelnder": "abträufelnd",
    "abträufelndes": "abträufelnd",
    "abträufelst": "abträufeln",
    "abträufelt": "abträufeln",
    "abträufelte": "abträufeln",
    "abträufelten": "abträufeln",
    "abträufeltest": "abträufeln",
    "abträufeltet": "abträufeln",
    "abträufle": "abträufeln",
    "abtrüge": "abtragen",
    "abtrügen": "abtragen",
    "abtrügest": "abtragen",
    "abtrüget": "abtragen",
    "abtrünnige": "abtrünnig",
    "abtrünnigem": "abtrünnig",
    "abtrünnigen": "abtrünnig",
    "abtrünniger": "abtrünnig",
    "abtrünnigere": "abtrünnig",
    "abtrünnigerem": "abtrünnig",
    "abtrünnigeren": "abtrünnig",
    "abtrünnigerer": "abtrünnig",
    "abtrünnigeres": "abtrünnig",
    "abtrünniges": "abtrünnig",
    "abtrünnigste": "abtrünnig",
    "abtrünnigstem": "abtrünnig",
    "abtrünnigsten": "abtrünnig",
    "abtrünnigster": "abtrünnig",
    "abtrünnigstes": "abtrünnig",
    "abtupfe": "abtupfen",
    "abtupfend": "abtupfen",
    "abtupfende": "abtupfend",
    "abtupfendem": "abtupfend",
    "abtupfenden": "abtupfend",
    "abtupfender": "abtupfend",
    "abtupfendes": "abtupfend",
    "abtupfest": "abtupfen",
    "abtupfet": "abtupfen",
    "abtupfst": "abtupfen",
    "abtupft": "abtupfen",
    "abtupfte": "abtupfen",
    "abtupften": "abtupfen",
    "abtupftest": "abtupfen",
    "abtupftet": "abtupfen",
    "abtöne": "abtönen",
    "abtönend": "abtönen",
    "abtönende": "abtönend",
    "abtönendem": "abtönend",
    "abtönenden": "abtönend",
    "abtönender": "abtönend",
    "abtönendes": "abtönend",
    "abtönest": "abtönen",
    "abtönet": "abtönen",
    "abtönst": "abtönen",
    "abtönt": "abtönen",
    "abtönte": "abtönen",
    "abtönten": "abtönen",
    "abtöntest": "abtönen",
    "abtöntet": "abtönen",
    "abtöte": "abtöten",
    "abtötend": "abtöten",
    "abtötende": "abtötend",
    "abtötendem": "abtötend",
    "abtötenden": "abtötend",
    "abtötender": "abtötend",
    "abtötendes": "abtötend",
    "abtötest": "abtöten",
    "abtötet": "abtöten",
    "abtötete": "abtöten",
    "abtöteten": "abtöten",
    "abtötetest": "abtöten",
    "abtötetet": "abtöten",
    "aburteile": "aburteilen",
    "aburteilend": "aburteilen",
    "aburteilende": "aburteilend",
    "aburteilendem": "aburteilend",
    "aburteilenden": "aburteilend",
    "aburteilender": "aburteilend",
    "aburteilendes": "aburteilend",
    "aburteilest": "aburteilen",
    "aburteilet": "aburteilen",
    "aburteilst": "aburteilen",
    "aburteilt": "aburteilen",
    "aburteilte": "aburteilen",
    "aburteilten": "aburteilen",
    "aburteiltest": "aburteilen",
    "aburteiltet": "aburteilen",
    "abverlange": "abverlangen",
    "abverlangend": "abverlangen",
    "abverlangende": "abverlangend",
    "abverlangendem": "abverlangend",
    "abverlangenden": "abverlangend",
    "abverlangender": "abverlangend",
    "abverlangendes": "abverlangend",
    "abverlangest": "abverlangen",
    "abverlanget": "abverlangen",
    "abverlangst": "abverlangen",
    "abverlangt": "abverlangen",
    "abverlangte": "abverlangen",
    "abverlangtem": "abverlangt",
    "abverlangten": "abverlangen",
    "abverlangter": "abverlangt",
    "abverlangtes": "abverlangt",
    "abverlangtest": "abverlangen",
    "abverlangtet": "abverlangen",
    "abwand": "abwinden",
    "abwandele": "abwandeln",
    "abwandelnd": "abwandeln",
    "abwandelnde": "abwandelnd",
    "abwandelndem": "abwandelnd",
    "abwandelnden": "abwandelnd",
    "abwandelnder": "abwandelnd",
    "abwandelndes": "abwandelnd",
    "abwandelst": "abwandeln",
    "abwandelt": "abwandeln",
    "abwandelte": "abwandeln",
    "abwandelten": "abwandeln",
    "abwandeltest": "abwandeln",
    "abwandeltet": "abwandeln",
    "abwanden": "abwinden",
    "abwandere": "abwandern",
    "abwandernd": "abwandern",
    "abwandernde": "abwandernd",
    "abwanderndem": "abwandernd",
    "abwandernden": "abwandernd",
    "abwandernder": "abwandernd",
    "abwanderndes": "abwandernd",
    "abwanderst": "abwandern",
    "abwandert": "abwandern",
    "abwanderte": "abwandern",
    "abwanderten": "abwandern",
    "abwandertest": "abwandern",
    "abwandertet": "abwandern",
    "abwandest": "abwinden",
    "abwandet": "abwinden",
    "abwandle": "abwandeln",
    "abwandte": "abwenden",
    "abwandten": "abwenden",
    "abwandtest": "abwenden",
    "abwandtet": "abwenden",
    "abwarb": "abwerben",
    "abwarben": "abwerben",
    "abwarbst": "abwerben",
    "abwarbt": "abwerben",
    "abwarf": "abwerfen",
    "abwarfen": "abwerfen",
    "abwarfst": "abwerfen",
    "abwarft": "abwerfen",
    "abwarte": "abwarten",
    "abwartend": "abwarten",
    "abwartende": "abwartend",
    "abwartendem": "abwartend",
    "abwartenden": "abwartend",
    "abwartender": "abwartend",
    "abwartendere": "abwartend",
    "abwartenderem": "abwartend",
    "abwartenderen": "abwartend",
    "abwartenderer": "abwartend",
    "abwartenderes": "abwartend",
    "abwartendes": "abwartend",
    "abwartendste": "abwartend",
    "abwartendstem": "abwartend",
    "abwartendsten": "abwartend",
    "abwartendster": "abwartend",
    "abwartendstes": "abwartend",
    "abwartest": "abwarten",
    "abwartet": "abwarten",
    "abwartete": "abwarten",
    "abwarteten": "abwarten",
    "abwartetest": "abwarten",
    "abwartetet": "abwarten",
    "abwasche": "abwaschen",
    "abwaschend": "abwaschen",
    "abwaschende": "abwaschend",
    "abwaschendem": "abwaschend",
    "abwaschenden": "abwaschend",
    "abwaschender": "abwaschend",
    "abwaschendes": "abwaschend",
    "abwaschest": "abwaschen",
    "abwaschet": "abwaschen",
    "abwascht": "abwaschen",
    "abwechsele": "abwechseln",
    "abwechselnd": "abwechseln",
    "abwechselnde": "abwechselnd",
    "abwechselndem": "abwechselnd",
    "abwechselnden": "abwechselnd",
    "abwechselnder": "abwechselnd",
    "abwechselndes": "abwechselnd",
    "abwechselst": "abwechseln",
    "abwechselt": "abwechseln",
    "abwechselte": "abwechseln",
    "abwechselten": "abwechseln",
    "abwechseltest": "abwechseln",
    "abwechseltet": "abwechseln",
    "abwechsle": "abwechseln",
    "abwechslungsreichem": "abwechslungsreich",
    "abwechslungsreichen": "abwechslungsreich",
    "abwechslungsreicher": "abwechslungsreich",
    "abwechslungsreichere": "abwechslungsreich",
    "abwechslungsreicherem": "abwechslungsreich",
    "abwechslungsreicheren": "abwechslungsreich",
    "abwechslungsreicherer": "abwechslungsreich",
    "abwechslungsreicheres": "abwechslungsreich",
    "abwechslungsreiches": "abwechslungsreich",
    "abwechslungsreichste": "abwechslungsreich",
    "abwechslungsreichstem": "abwechslungsreich",
    "abwechslungsreichsten": "abwechslungsreich",
    "abwechslungsreichster": "abwechslungsreich",
    "abwechslungsreichstes": "abwechslungsreich",
    "abwegige": "abwegig",
    "abwegigem": "abwegig",
    "abwegigen": "abwegig",
    "abwegiger": "abwegig",
    "abwegigere": "abwegig",
    "abwegigerem": "abwegig",
    "abwegigeren": "abwegig",
    "abwegigerer": "abwegig",
    "abwegigeres": "abwegig",
    "abwegiges": "abwegig",
    "abwegigste": "abwegig",
    "abwegigstem": "abwegig",
    "abwegigsten": "abwegig",
    "abwegigster": "abwegig",
    "abwegigstes": "abwegig",
    "abwehre": "abwehren",
    "abwehrend": "abwehren",
    "abwehrende": "abwehrend",
    "abwehrendem": "abwehrend",
    "abwehrenden": "abwehrend",
    "abwehrender": "abwehrend",
    "abwehrendes": "abwehrend",
    "abwehrest": "abwehren",
    "abwehret": "abwehren",
    "abwehrst": "abwehren",
    "abwehrt": "abwehren",
    "abwehrte": "abwehren",
    "abwehrten": "abwehren",
    "abwehrtest": "abwehren",
    "abwehrtet": "abwehren",
    "abweiche": "abweichen",
    "abweichend": "abweichen",
    "abweichende": "abweichend",
    "abweichendem": "abweichend",
    "abweichenden": "abweichend",
    "abweichender": "abweichend",
    "abweichendere": "abweichend",
    "abweichenderem": "abweichend",
    "abweichenderen": "abweichend",
    "abweichenderer": "abweichend",
    "abweichenderes": "abweichend",
    "abweichendes": "abweichend",
    "abweichendste": "abweichend",
    "abweichendstem": "abweichend",
    "abweichendsten": "abweichend",
    "abweichendster": "abweichend",
    "abweichendstes": "abweichend",
    "abweichest": "abweichen",
    "abweichet": "abweichen",
    "abweichst": "abweichen",
    "abweicht": "abweichen",
    "abweichte": "abweichen",
    "abweichten": "abweichen",
    "abweichtest": "abweichen",
    "abweichtet": "abweichen",
    "abweide": "abweiden",
    "abweidend": "abweiden",
    "abweidende": "abweidend",
    "abweidendem": "abweidend",
    "abweidenden": "abweidend",
    "abweidender": "abweidend",
    "abweidendere": "abweidend",
    "abweidenderem": "abweidend",
    "abweidenderen": "abweidend",
    "abweidenderer": "abweidend",
    "abweidenderes": "abweidend",
    "abweidendes": "abweidend",
    "abweidendste": "abweidend",
    "abweidendstem": "abweidend",
    "abweidendsten": "abweidend",
    "abweidendster": "abweidend",
    "abweidendstes": "abweidend",
    "abweidest": "abweiden",
    "abweidet": "abweiden",
    "abweidete": "abweiden",
    "abweideten": "abweiden",
    "abweidetest": "abweiden",
    "abweidetet": "abweiden",
    "abweise": "abweisen",
    "abweisend": "abweisen",
    "abweisende": "abweisend",
    "abweisendem": "abweisend",
    "abweisenden": "abweisend",
    "abweisender": "abweisend",
    "abweisendere": "abweisend",
    "abweisenderem": "abweisend",
    "abweisenderen": "abweisend",
    "abweisenderer": "abweisend",
    "abweisenderes": "abweisend",
    "abweisendes": "abweisend",
    "abweisendste": "abweisend",
    "abweisendstem": "abweisend",
    "abweisendsten": "abweisend",
    "abweisendster": "abweisend",
    "abweisendstes": "abweisend",
    "abweisest": "abweisen",
    "abweiset": "abweisen",
    "abweist": "abweisen",
    "abwendbarem": "abwendbar",
    "abwendbaren": "abwendbar",
    "abwendbarer": "abwendbar",
    "abwendbares": "abwendbar",
    "abwende": "abwenden",
    "abwendend": "abwenden",
    "abwendende": "abwendend",
    "abwendendem": "abwendend",
    "abwendenden": "abwendend",
    "abwendender": "abwendend",
    "abwendendes": "abwendend",
    "abwendest": "abwenden",
    "abwendet": "abwenden",
    "abwendete": "abwenden",
    "abwendeten": "abwenden",
    "abwendetest": "abwenden",
    "abwendetet": "abwenden",
    "abwerbe": "abwerben",
    "abwerbend": "abwerben",
    "abwerbende": "abwerbend",
    "abwerbendem": "abwerbend",
    "abwerbenden": "abwerbend",
    "abwerbender": "abwerbend",
    "abwerbendes": "abwerbend",
    "abwerbest": "abwerben",
    "abwerbet": "abwerben",
    "abwerbt": "abwerben",
    "abwerfe": "abwerfen",
    "abwerfend": "abwerfen",
    "abwerfende": "abwerfend",
    "abwerfendem": "abwerfend",
    "abwerfenden": "abwerfend",
    "abwerfender": "abwerfend",
    "abwerfendes": "abwerfend",
    "abwerfest": "abwerfen",
    "abwerfet": "abwerfen",
    "abwerft": "abwerfen",
    "abwerte": "abwerten",
    "abwertend": "abwerten",
    "abwertende": "abwertend",
    "abwertendem": "abwertend",
    "abwertenden": "abwertend",
    "abwertender": "abwertend",
    "abwertendere": "abwertend",
    "abwertenderem": "abwertend",
    "abwertenderen": "abwertend",
    "abwertenderer": "abwertend",
    "abwertenderes": "abwertend",
    "abwertendes": "abwertend",
    "abwertendste": "abwertend",
    "abwertendstem": "abwertend",
    "abwertendsten": "abwertend",
    "abwertendster": "abwertend",
    "abwertendstes": "abwertend",
    "abwertest": "abwerten",
    "abwertet": "abwerten",
    "abwertete": "abwerten",
    "abwerteten": "abwerten",
    "abwertetest": "abwerten",
    "abwertetet": "abwerten",
    "abwesendem": "abwesend",
    "abwesenden": "abwesend",
    "abwesender": "abwesend",
    "abwesendes": "abwesend",
    "abwetze": "abwetzen",
    "abwetzend": "abwetzen",
    "abwetzende": "abwetzend",
    "abwetzendem": "abwetzend",
    "abwetzenden": "abwetzend",
    "abwetzender": "abwetzend",
    "abwetzendere": "abwetzend",
    "abwetzenderem": "abwetzend",
    "abwetzenderen": "abwetzend",
    "abwetzenderer": "abwetzend",
    "abwetzenderes": "abwetzend",
    "abwetzendes": "abwetzend",
    "abwetzendste": "abwetzend",
    "abwetzendstem": "abwetzend",
    "abwetzendsten": "abwetzend",
    "abwetzendster": "abwetzend",
    "abwetzendstes": "abwetzend",
    "abwetzest": "abwetzen",
    "abwetzet": "abwetzen",
    "abwetzt": "abwetzen",
    "abwetzte": "abwetzen",
    "abwetzten": "abwetzen",
    "abwetztest": "abwetzen",
    "abwetztet": "abwetzen",
    "abwich": "abweichen",
    "abwiche": "abweichen",
    "abwichen": "abweichen",
    "abwichest": "abweichen",
    "abwichet": "abweichen",
    "abwichst": "abweichen",
    "abwicht": "abweichen",
    "abwickele": "abwickeln",
    "abwickelnd": "abwickeln",
    "abwickelnde": "abwickelnd",
    "abwickelndem": "abwickelnd",
    "abwickelnden": "abwickelnd",
    "abwickelnder": "abwickelnd",
    "abwickelndes": "abwickelnd",
    "abwickelst": "abwickeln",
    "abwickelt": "abwickeln",
    "abwickelte": "abwickeln",
    "abwickelten": "abwickeln",
    "abwickeltest": "abwickeln",
    "abwickeltet": "abwickeln",
    "abwickle": "abwickeln",
    "abwiege": "abwiegen",
    "abwiegend": "abwiegen",
    "abwiegende": "abwiegend",
    "abwiegendem": "abwiegend",
    "abwiegenden": "abwiegend",
    "abwiegender": "abwiegend",
    "abwiegendes": "abwiegend",
    "abwiegest": "abwiegen",
    "abwieget": "abwiegen",
    "abwiegst": "abwiegen",
    "abwiegt": "abwiegen",
    "abwies": "abweisen",
    "abwiese": "abweisen",
    "abwiesen": "abweisen",
    "abwiesest": "abweisen",
    "abwieset": "abweisen",
    "abwiest": "abweisen",
    "abwimmele": "abwimmeln",
    "abwimmelnd": "abwimmeln",
    "abwimmelnde": "abwimmelnd",
    "abwimmelndem": "abwimmelnd",
    "abwimmelnden": "abwimmelnd",
    "abwimmelnder": "abwimmelnd",
    "abwimmelndes": "abwimmelnd",
    "abwimmelst": "abwimmeln",
    "abwimmelt": "abwimmeln",
    "abwimmelte": "abwimmeln",
    "abwimmelten": "abwimmeln",
    "abwimmeltest": "abwimmeln",
    "abwimmeltet": "abwimmeln",
    "abwimmle": "abwimmeln",
    "abwinde": "abwinden",
    "abwindend": "abwinden",
    "abwindende": "abwindend",
    "abwindendem": "abwindend",
    "abwindenden": "abwindend",
    "abwindender": "abwindend",
    "abwindendes": "abwindend",
    "abwindest": "abwinden",
    "abwindet": "abwinden",
    "abwinke": "abwinken",
    "abwinkend": "abwinken",
    "abwinkende": "abwinkend",
    "abwinkendem": "abwinkend",
    "abwinkenden": "abwinkend",
    "abwinkender": "abwinkend",
    "abwinkendes": "abwinkend",
    "abwinkest": "abwinken",
    "abwinket": "abwinken",
    "abwinkst": "abwinken",
    "abwinkt": "abwinken",
    "abwinkte": "abwinken",
    "abwinkten": "abwinken",
    "abwinktest": "abwinken",
    "abwinktet": "abwinken",
    "abwirbst": "abwerben",
    "abwirbt": "abwerben",
    "abwirfst": "abwerfen",
    "abwirft": "abwerfen",
    "abwirtschafte": "abwirtschaften",
    "abwirtschaftend": "abwirtschaften",
    "abwirtschaftende": "abwirtschaftend",
    "abwirtschaftendem": "abwirtschaftend",
    "abwirtschaftenden": "abwirtschaftend",
    "abwirtschaftender": "abwirtschaftend",
    "abwirtschaftendere": "abwirtschaftend",
    "abwirtschaftenderem": "abwirtschaftend",
    "abwirtschaftenderen": "abwirtschaftend",
    "abwirtschaftenderer": "abwirtschaftend",
    "abwirtschaftenderes": "abwirtschaftend",
    "abwirtschaftendes": "abwirtschaftend",
    "abwirtschaftendste": "abwirtschaftend",
    "abwirtschaftendstem": "abwirtschaftend",
    "abwirtschaftendsten": "abwirtschaftend",
    "abwirtschaftendster": "abwirtschaftend",
    "abwirtschaftendstes": "abwirtschaftend",
    "abwirtschaftest": "abwirtschaften",
    "abwirtschaftet": "abwirtschaften",
    "abwirtschaftete": "abwirtschaften",
    "abwirtschafteten": "abwirtschaften",
    "abwirtschaftetest": "abwirtschaften",
    "abwirtschaftetet": "abwirtschaften",
    "abwische": "abwischen",
    "abwischend": "abwischen",
    "abwischende": "abwischend",
    "abwischendem": "abwischend",
    "abwischenden": "abwischend",
    "abwischender": "abwischend",
    "abwischendes": "abwischend",
    "abwischest": "abwischen",
    "abwischet": "abwischen",
    "abwischst": "abwischen",
    "abwischt": "abwischen",
    "abwischte": "abwischen",
    "abwischten": "abwischen",
    "abwischtest": "abwischen",
    "abwischtet": "abwischen",
    "abwog": "abwiegen",
    "abwogen": "abwiegen",
    "abwogst": "abwiegen",
    "abwogt": "abwiegen",
    "abwohne": "abwohnen",
    "abwohnend": "abwohnen",
    "abwohnende": "abwohnend",
    "abwohnendem": "abwohnend",
    "abwohnenden": "abwohnend",
    "abwohnender": "abwohnend",
    "abwohnendere": "abwohnend",
    "abwohnenderem": "abwohnend",
    "abwohnenderen": "abwohnend",
    "abwohnenderer": "abwohnend",
    "abwohnenderes": "abwohnend",
    "abwohnendes": "abwohnend",
    "abwohnendste": "abwohnend",
    "abwohnendstem": "abwohnend",
    "abwohnendsten": "abwohnend",
    "abwohnendster": "abwohnend",
    "abwohnendstes": "abwohnend",
    "abwohnest": "abwohnen",
    "abwohnet": "abwohnen",
    "abwohnst": "abwohnen",
    "abwohnt": "abwohnen",
    "abwohnte": "abwohnen",
    "abwohnten": "abwohnen",
    "abwohntest": "abwohnen",
    "abwohntet": "abwohnen",
    "abwusch": "abwaschen",
    "abwuschen": "abwaschen",
    "abwuschst": "abwaschen",
    "abwuscht": "abwaschen",
    "abwäge": "abwägen",
    "abwägend": "abwägen",
    "abwägende": "abwägend",
    "abwägendem": "abwägend",
    "abwägenden": "abwägend",
    "abwägender": "abwägend",
    "abwägendes": "abwägend",
    "abwägest": "abwägen",
    "abwäget": "abwägen",
    "abwägst": "abwägen",
    "abwägt": "abwägen",
    "abwähle": "abwählen",
    "abwählend": "abwählen",
    "abwählende": "abwählend",
    "abwählendem": "abwählend",
    "abwählenden": "abwählend",
    "abwählender": "abwählend",
    "abwählendes": "abwählend",
    "abwählest": "abwählen",
    "abwählet": "abwählen",
    "abwählst": "abwählen",
    "abwählt": "abwählen",
    "abwählte": "abwählen",
    "abwählten": "abwählen",
    "abwähltest": "abwählen",
    "abwähltet": "abwählen",
    "abwälze": "abwälzen",
    "abwälzend": "abwälzen",
    "abwälzende": "abwälzend",
    "abwälzendem": "abwälzend",
    "abwälzenden": "abwälzend",
    "abwälzender": "abwälzend",
    "abwälzendere": "abwälzend",
    "abwälzenderem": "abwälzend",
    "abwälzenderen": "abwälzend",
    "abwälzenderer": "abwälzend",
    "abwälzenderes": "abwälzend",
    "abwälzendes": "abwälzend",
    "abwälzendste": "abwälzend",
    "abwälzendstem": "abwälzend",
    "abwälzendsten": "abwälzend",
    "abwälzendster": "abwälzend",
    "abwälzendstes": "abwälzend",
    "abwälzest": "abwälzen",
    "abwälzet": "abwälzen",
    "abwälzt": "abwälzen",
    "abwälzte": "abwälzen",
    "abwälzten": "abwälzen",
    "abwälztest": "abwälzen",
    "abwälztet": "abwälzen",
    "abwände": "abwinden",
    "abwänden": "abwinden",
    "abwändest": "abwinden",
    "abwändet": "abwinden",
    "abwärbe": "abwerben",
    "abwärben": "abwerben",
    "abwärbest": "abwerben",
    "abwärbet": "abwerben",
    "abwärfe": "abwerfen",
    "abwärfen": "abwerfen",
    "abwärfest": "abwerfen",
    "abwärfet": "abwerfen",
    "abwärtsgegangen": "abwärtsgehen",
    "abwärtsgegangene": "abwärtsgegangen",
    "abwärtsgegangenem": "abwärtsgegangen",
    "abwärtsgegangenen": "abwärtsgegangen",
    "abwärtsgegangener": "abwärtsgegangen",
    "abwärtsgegangenes": "abwärtsgegangen",
    "abwärtsgehe": "abwärtsgehen",
    "abwärtsgehend": "abwärtsgehen",
    "abwärtsgehende": "abwärtsgehend",
    "abwärtsgehendem": "abwärtsgehend",
    "abwärtsgehenden": "abwärtsgehend",
    "abwärtsgehender": "abwärtsgehend",
    "abwärtsgehendes": "abwärtsgehend",
    "abwärtsgehest": "abwärtsgehen",
    "abwärtsgehet": "abwärtsgehen",
    "abwärtsgehst": "abwärtsgehen",
    "abwärtsgeht": "abwärtsgehen",
    "abwärtsging": "abwärtsgehen",
    "abwärtsginge": "abwärtsgehen",
    "abwärtsgingen": "abwärtsgehen",
    "abwärtsgingest": "abwärtsgehen",
    "abwärtsginget": "abwärtsgehen",
    "abwärtsgingst": "abwärtsgehen",
    "abwärtsgingt": "abwärtsgehen",
    "abwärtszugehen": "abwärtsgehen",
    "abwäschst": "abwaschen",
    "abwäscht": "abwaschen",
    "abwöge": "abwiegen",
    "abwögen": "abwiegen",
    "abwögest": "abwiegen",
    "abwöget": "abwiegen",
    "abwürge": "abwürgen",
    "abwürgend": "abwürgen",
    "abwürgende": "abwürgend",
    "abwürgendem": "abwürgend",
    "abwürgenden": "abwürgend",
    "abwürgender": "abwürgend",
    "abwürgendere": "abwürgend",
    "abwürgenderem": "abwürgend",
    "abwürgenderen": "abwürgend",
    "abwürgenderer": "abwürgend",
    "abwürgenderes": "abwürgend",
    "abwürgendes": "abwürgend",
    "abwürgendste": "abwürgend",
    "abwürgendstem": "abwürgend",
    "abwürgendsten": "abwürgend",
    "abwürgendster": "abwürgend",
    "abwürgendstes": "abwürgend",
    "abwürgest": "abwürgen",
    "abwürget": "abwürgen",
    "abwürgst": "abwürgen",
    "abwürgt": "abwürgen",
    "abwürgte": "abwürgen",
    "abwürgten": "abwürgen",
    "abwürgtest": "abwürgen",
    "abwürgtet": "abwürgen",
    "abwüsche": "abwaschen",
    "abwüschen": "abwaschen",
    "abwüschest": "abwaschen",
    "abwüschet": "abwaschen",
    "abzahle": "abzahlen",
    "abzahlend": "abzahlen",
    "abzahlende": "abzahlend",
    "abzahlendem": "abzahlend",
    "abzahlenden": "abzahlend",
    "abzahlender": "abzahlend",
    "abzahlendes": "abzahlend",
    "abzahlest": "abzahlen",
    "abzahlet": "abzahlen",
    "abzahlst": "abzahlen",
    "abzahlt": "abzahlen",
    "abzahlte": "abzahlen",
    "abzahlten": "abzahlen",
    "abzahltest": "abzahlen",
    "abzahltet": "abzahlen",
    "abzapfe": "abzapfen",
    "abzapfend": "abzapfen",
    "abzapfende": "abzapfend",
    "abzapfendem": "abzapfend",
    "abzapfenden": "abzapfend",
    "abzapfender": "abzapfend",
    "abzapfendes": "abzapfend",
    "abzapfest": "abzapfen",
    "abzapfet": "abzapfen",
    "abzapfst": "abzapfen",
    "abzapft": "abzapfen",
    "abzapfte": "abzapfen",
    "abzapften": "abzapfen",
    "abzapftest": "abzapfen",
    "abzapftet": "abzapfen",
    "abzappele": "abzappeln",
    "abzappelnd": "abzappeln",
    "abzappelnde": "abzappelnd",
    "abzappelndem": "abzappelnd",
    "abzappelnden": "abzappelnd",
    "abzappelnder": "abzappelnd",
    "abzappelndere": "abzappelnd",
    "abzappelnderem": "abzappelnd",
    "abzappelnderen": "abzappelnd",
    "abzappelnderer": "abzappelnd",
    "abzappelnderes": "abzappelnd",
    "abzappelndes": "abzappelnd",
    "abzappelndste": "abzappelnd",
    "abzappelndstem": "abzappelnd",
    "abzappelndsten": "abzappelnd",
    "abzappelndster": "abzappelnd",
    "abzappelndstes": "abzappelnd",
    "abzappelst": "abzappeln",
    "abzappelt": "abzappeln",
    "abzappelte": "abzappeln",
    "abzappelten": "abzappeln",
    "abzappeltest": "abzappeln",
    "abzappeltet": "abzappeln",
    "abzapple": "abzappeln",
    "abzeichne": "abzeichnen",
    "abzeichnend": "abzeichnen",
    "abzeichnende": "abzeichnend",
    "abzeichnendem": "abzeichnend",
    "abzeichnenden": "abzeichnend",
    "abzeichnender": "abzeichnend",
    "abzeichnendes": "abzeichnend",
    "abzeichnest": "abzeichnen",
    "abzeichnet": "abzeichnen",
    "abzeichnete": "abzeichnen",
    "abzeichneten": "abzeichnen",
    "abzeichnetest": "abzeichnen",
    "abzeichnetet": "abzeichnen",
    "abziehe": "abziehen",
    "abziehend": "abziehen",
    "abziehende": "abziehend",
    "abziehendem": "abziehend",
    "abziehenden": "abziehend",
    "abziehender": "abziehend",
    "abziehendes": "abziehend",
    "abziehest": "abziehen",
    "abziehet": "abziehen",
    "abziehst": "abziehen",
    "abzieht": "abziehen",
    "abziele": "abzielen",
    "abzielend": "abzielen",
    "abzielende": "abzielend",
    "abzielendem": "abzielend",
    "abzielenden": "abzielend",
    "abzielender": "abzielend",
    "abzielendes": "abzielend",
    "abzielest": "abzielen",
    "abzielet": "abzielen",
    "abzielst": "abzielen",
    "abzielt": "abzielen",
    "abzielte": "abzielen",
    "abzielten": "abzielen",
    "abzieltest": "abzielen",
    "abzieltet": "abzielen",
    "abzirkele": "abzirkeln",
    "abzirkelnd": "abzirkeln",
    "abzirkelnde": "abzirkelnd",
    "abzirkelndem": "abzirkelnd",
    "abzirkelnden": "abzirkelnd",
    "abzirkelnder": "abzirkelnd",
    "abzirkelndes": "abzirkelnd",
    "abzirkelst": "abzirkeln",
    "abzirkelt": "abzirkeln",
    "abzirkelte": "abzirkeln",
    "abzirkelten": "abzirkeln",
    "abzirkeltest": "abzirkeln",
    "abzirkeltet": "abzirkeln",
    "abzirkle": "abzirkeln",
    "abzische": "abzischen",
    "abzischend": "abzischen",
    "abzischende": "abzischend",
    "abzischendem": "abzischend",
    "abzischenden": "abzischend",
    "abzischender": "abzischend",
    "abzischendes": "abzischend",
    "abzischest": "abzischen",
    "abzischet": "abzischen",
    "abzischst": "abzischen",
    "abzischt": "abzischen",
    "abzischte": "abzischen",
    "abzischten": "abzischen",
    "abzischtest": "abzischen",
    "abzischtet": "abzischen",
    "abzittere": "abzittern",
    "abzitternd": "abzittern",
    "abzitternde": "abzitternd",
    "abzitterndem": "abzitternd",
    "abzitternden": "abzitternd",
    "abzitternder": "abzitternd",
    "abzitterndes": "abzitternd",
    "abzitterst": "abzittern",
    "abzittert": "abzittern",
    "abzitterte": "abzittern",
    "abzitterten": "abzittern",
    "abzittertest": "abzittern",
    "abzittertet": "abzittern",
    "abzog": "abziehen",
    "abzogen": "abziehen",
    "abzogst": "abziehen",
    "abzogt": "abziehen",
    "abzuarbeiten": "abarbeiten",
    "abzubalgen": "abbalgen",
    "abzubauen": "abbauen",
    "abzubehalten": "abbehalten",
    "abzubeizen": "abbeizen",
    "abzubeißen": "abbeißen",
    "abzubekommen": "abbekommen",
    "abzuberufen": "abberufen",
    "abzubestellen": "abbestellen",
    "abzubeten": "abbeten",
    "abzubetteln": "abbetteln",
    "abzubezahlen": "abbezahlen",
    "abzubiegen": "abbiegen",
    "abzubilden": "abbilden",
    "abzubinden": "abbinden",
    "abzubitten": "abbitten",
    "abzublasen": "abblasen",
    "abzublassen": "abblassen",
    "abzubleiben": "abbleiben",
    "abzublenden": "abblenden",
    "abzublitzen": "abblitzen",
    "abzublättern": "abblättern",
    "abzublühen": "abblühen",
    "abzubrausen": "abbrausen",
    "abzubrechen": "abbrechen",
    "abzubremsen": "abbremsen",
    "abzubrennen": "abbrennen",
    "abzubringen": "abbringen",
    "abzubröckeln": "abbröckeln",
    "abzubrühen": "abbrühen",
    "abzubuchen": "abbuchen",
    "abzubürsten": "abbürsten",
    "abzubüßen": "abbüßen",
    "abzudachen": "abdachen",
    "abzudampfen": "abdampfen",
    "abzudanken": "abdanken",
    "abzudarben": "abdarben",
    "abzudecken": "abdecken",
    "abzudichten": "abdichten",
    "abzudienen": "abdienen",
    "abzudingen": "abdingen",
    "abzudrehen": "abdrehen",
    "abzudriften": "abdriften",
    "abzudrosseln": "abdrosseln",
    "abzudrucken": "abdrucken",
    "abzudrängen": "abdrängen",
    "abzudrücken": "abdrücken",
    "abzudunkeln": "abdunkeln",
    "abzuduschen": "abduschen",
    "abzudämmen": "abdämmen",
    "abzuebben": "abebben",
    "abzuerkennen": "aberkennen",
    "abzuessen": "abessen",
    "abzufahren": "abfahren",
    "abzufallen": "abfallen",
    "abzufangen": "abfangen",
    "abzufassen": "abfassen",
    "abzufedern": "abfedern",
    "abzufeiern": "abfeiern",
    "abzufeilen": "abfeilen",
    "abzufertigen": "abfertigen",
    "abzufeuern": "abfeuern",
    "abzufiebern": "abfiebern",
    "abzufilmen": "abfilmen",
    "abzufinden": "abfinden",
    "abzufischen": "abfischen",
    "abzuflachen": "abflachen",
    "abzuflauen": "abflauen",
    "abzufliegen": "abfliegen",
    "abzufließen": "abfließen",
    "abzufluchten": "abfluchten",
    "abzufordern": "abfordern",
    "abzuformen": "abformen",
    "abzufragen": "abfragen",
    "abzufressen": "abfressen",
    "abzufrieren": "abfrieren",
    "abzufälschen": "abfälschen",
    "abzufärben": "abfärben",
    "abzuführen": "abführen",
    "abzufüllen": "abfüllen",
    "abzufüttern": "abfüttern",
    "abzugaunern": "abgaunern",
    "abzugeben": "abgeben",
    "abzugehen": "abgehen",
    "abzugelten": "abgelten",
    "abzugewinnen": "abgewinnen",
    "abzugewöhnen": "abgewöhnen",
    "abzugießen": "abgießen",
    "abzugleichen": "abgleichen",
    "abzugleiten": "abgleiten",
    "abzugraben": "abgraben",
    "abzugrasen": "abgrasen",
    "abzugreifen": "abgreifen",
    "abzugrenzen": "abgrenzen",
    "abzugrätschen": "abgrätschen",
    "abzugsfähigem": "abzugsfähig",
    "abzugsfähigen": "abzugsfähig",
    "abzugsfähiger": "abzugsfähig",
    "abzugsfähiges": "abzugsfähig",
    "abzuhacken": "abhacken",
    "abzuhaken": "abhaken",
    "abzuhalftern": "abhalftern",
    "abzuhalten": "abhalten",
    "abzuhandeln": "abhandeln",
    "abzuhaspeln": "abhaspeln",
    "abzuhauen": "abhauen",
    "abzuheben": "abheben",
    "abzuheften": "abheften",
    "abzuheilen": "abheilen",
    "abzuhelfen": "abhelfen",
    "abzuhetzen": "abhetzen",
    "abzuhobeln": "abhobeln",
    "abzuholen": "abholen",
    "abzuholzen": "abholzen",
    "abzuhorchen": "abhorchen",
    "abzuhängen": "abhängen",
    "abzuhärten": "abhärten",
    "abzuhäuten": "abhäuten",
    "abzuhören": "abhören",
    "abzujagen": "abjagen",
    "abzukanten": "abkanten",
    "abzukanzeln": "abkanzeln",
    "abzukappen": "abkappen",
    "abzukapseln": "abkapseln",
    "abzukarten": "abkarten",
    "abzukassieren": "abkassieren",
    "abzukaufen": "abkaufen",
    "abzukehren": "abkehren",
    "abzuklappern": "abklappern",
    "abzuklatschen": "abklatschen",
    "abzuklauben": "abklauben",
    "abzukleben": "abkleben",
    "abzuklemmen": "abklemmen",
    "abzuklingen": "abklingen",
    "abzuklopfen": "abklopfen",
    "abzuklären": "abklären",
    "abzuknabbern": "abknabbern",
    "abzuknallen": "abknallen",
    "abzuknapsen": "abknapsen",
    "abzukneifen": "abkneifen",
    "abzuknicken": "abknicken",
    "abzuknipsen": "abknipsen",
    "abzuknutschen": "abknutschen",
    "abzuknöpfen": "abknöpfen",
    "abzukochen": "abkochen",
    "abzukommandieren": "abkommandieren",
    "abzukommen": "abkommen",
    "abzukoppeln": "abkoppeln",
    "abzukotzen": "abkotzen",
    "abzukratzen": "abkratzen",
    "abzukriegen": "abkriegen",
    "abzukuppeln": "abkuppeln",
    "abzukämmen": "abkämmen",
    "abzukämpfen": "abkämpfen",
    "abzukühlen": "abkühlen",
    "abzukürzen": "abkürzen",
    "abzuküssen": "abküssen",
    "abzulachen": "ablachen",
    "abzuladen": "abladen",
    "abzulagern": "ablagern",
    "abzulassen": "ablassen",
    "abzulatschen": "ablatschen",
    "abzulaufen": "ablaufen",
    "abzulauten": "ablauten",
    "abzuleben": "ableben",
    "abzuledern": "abledern",
    "abzulegen": "ablegen",
    "abzulehnen": "ablehnen",
    "abzuleisten": "ableisten",
    "abzuleiten": "ableiten",
    "abzulenken": "ablenken",
    "abzulesen": "ablesen",
    "abzuleuchten": "ableuchten",
    "abzulichten": "ablichten",
    "abzuliefern": "abliefern",
    "abzulöschen": "ablöschen",
    "abzulösen": "ablösen",
    "abzumachen": "abmachen",
    "abzumagern": "abmagern",
    "abzumalen": "abmalen",
    "abzumarschieren": "abmarschieren",
    "abzumelden": "abmelden",
    "abzumessen": "abmessen",
    "abzumildern": "abmildern",
    "abzumontieren": "abmontieren",
    "abzumurksen": "abmurksen",
    "abzumustern": "abmustern",
    "abzumähen": "abmähen",
    "abzumühen": "abmühen",
    "abzunabeln": "abnabeln",
    "abzunagen": "abnagen",
    "abzunehmen": "abnehmen",
    "abzuneigen": "abneigen",
    "abzunutzen": "abnutzen",
    "abzunähen": "abnähen",
    "abzuordnen": "abordnen",
    "abzupassen": "abpassen",
    "abzupellen": "abpellen",
    "abzupfe": "abzupfen",
    "abzupfeifen": "abpfeifen",
    "abzupfend": "abzupfen",
    "abzupfende": "abzupfend",
    "abzupfendem": "abzupfend",
    "abzupfenden": "abzupfend",
    "abzupfender": "abzupfend",
    "abzupfendes": "abzupfend",
    "abzupfest": "abzupfen",
    "abzupfet": "abzupfen",
    "abzupfst": "abzupfen",
    "abzupft": "abzupfen",
    "abzupfte": "abzupfen",
    "abzupften": "abzupfen",
    "abzupftest": "abzupfen",
    "abzupftet": "abzupfen",
    "abzuplatzen": "abplatzen",
    "abzuprallen": "abprallen",
    "abzupressen": "abpressen",
    "abzupumpen": "abpumpen",
    "abzuputzen": "abputzen",
    "abzuqualifizieren": "abqualifizieren",
    "abzuquetschen": "abquetschen",
    "abzuquälen": "abquälen",
    "abzurasieren": "abrasieren",
    "abzuraten": "abraten",
    "abzurauschen": "abrauschen",
    "abzureagieren": "abreagieren",
    "abzurechnen": "abrechnen",
    "abzuregen": "abregen",
    "abzureiben": "abreiben",
    "abzureichen": "abreichen",
    "abzureisen": "abreisen",
    "abzureiten": "abreiten",
    "abzureißen": "abreißen",
    "abzurichten": "abrichten",
    "abzuriegeln": "abriegeln",
    "abzuriffeln": "abriffeln",
    "abzurinden": "abrinden",
    "abzuringen": "abringen",
    "abzuroden": "abroden",
    "abzurollen": "abrollen",
    "abzurudern": "abrudern",
    "abzurufen": "abrufen",
    "abzurunden": "abrunden",
    "abzurupfen": "abrupfen",
    "abzurutschen": "abrutschen",
    "abzuräumen": "abräumen",
    "abzurücken": "abrücken",
    "abzurühren": "abrühren",
    "abzurüsten": "abrüsten",
    "abzusagen": "absagen",
    "abzusahnen": "absahnen",
    "abzusatteln": "absatteln",
    "abzusaufen": "absaufen",
    "abzusaugen": "absaugen",
    "abzusausen": "absausen",
    "abzuschaben": "abschaben",
    "abzuschaffen": "abschaffen",
    "abzuschalten": "abschalten",
    "abzuschauen": "abschauen",
    "abzuscheiden": "abscheiden",
    "abzuscheren": "abscheren",
    "abzuscheuern": "abscheuern",
    "abzuschieben": "abschieben",
    "abzuschiefern": "abschiefern",
    "abzuschießen": "abschießen",
    "abzuschinden": "abschinden",
    "abzuschirmen": "abschirmen",
    "abzuschirren": "abschirren",
    "abzuschlachten": "abschlachten",
    "abzuschlaffen": "abschlaffen",
    "abzuschlagen": "abschlagen",
    "abzuschleifen": "abschleifen",
    "abzuschleppen": "abschleppen",
    "abzuschließen": "abschließen",
    "abzuschlämmen": "abschlämmen",
    "abzuschmatzen": "abschmatzen",
    "abzuschmeicheln": "abschmeicheln",
    "abzuschmelzen": "abschmelzen",
    "abzuschmettern": "abschmettern",
    "abzuschmieren": "abschmieren",
    "abzuschminken": "abschminken",
    "abzuschnallen": "abschnallen",
    "abzuschnappen": "abschnappen",
    "abzuschneiden": "abschneiden",
    "abzuschnüren": "abschnüren",
    "abzuschrauben": "abschrauben",
    "abzuschrecken": "abschrecken",
    "abzuschreiben": "abschreiben",
    "abzuschrägen": "abschrägen",
    "abzuschröpfen": "abschröpfen",
    "abzuschuften": "abschuften",
    "abzuschwatzen": "abschwatzen",
    "abzuschweifen": "abschweifen",
    "abzuschwellen": "abschwellen",
    "abzuschwenken": "abschwenken",
    "abzuschwindeln": "abschwindeln",
    "abzuschwingen": "abschwingen",
    "abzuschwirren": "abschwirren",
    "abzuschwächen": "abschwächen",
    "abzuschwören": "abschwören",
    "abzuschälen": "abschälen",
    "abzuschätzen": "abschätzen",
    "abzuschäumen": "abschäumen",
    "abzuschöpfen": "abschöpfen",
    "abzuschürfen": "abschürfen",
    "abzuschütteln": "abschütteln",
    "abzusegnen": "absegnen",
    "abzusehen": "absehen",
    "abzuseifen": "abseifen",
    "abzuseilen": "abseilen",
    "abzusenden": "absenden",
    "abzusengen": "absengen",
    "abzusenken": "absenken",
    "abzusetzen": "absetzen",
    "abzusichern": "absichern",
    "abzusingen": "absingen",
    "abzusitzen": "absitzen",
    "abzusondern": "absondern",
    "abzuspalten": "abspalten",
    "abzuspannen": "abspannen",
    "abzusparen": "absparen",
    "abzuspeichern": "abspeichern",
    "abzuspeisen": "abspeisen",
    "abzusperren": "absperren",
    "abzuspiegeln": "abspiegeln",
    "abzuspielen": "abspielen",
    "abzusplittern": "absplittern",
    "abzusprechen": "absprechen",
    "abzuspreizen": "abspreizen",
    "abzusprengen": "absprengen",
    "abzuspringen": "abspringen",
    "abzuspritzen": "abspritzen",
    "abzusprühen": "absprühen",
    "abzuspulen": "abspulen",
    "abzuspülen": "abspülen",
    "abzustammen": "abstammen",
    "abzustatten": "abstatten",
    "abzustauben": "abstauben",
    "abzustechen": "abstechen",
    "abzustehen": "abstehen",
    "abzusteifen": "absteifen",
    "abzusteigen": "absteigen",
    "abzustellen": "abstellen",
    "abzustempeln": "abstempeln",
    "abzusteppen": "absteppen",
    "abzusterben": "absterben",
    "abzustielen": "abstielen",
    "abzustillen": "abstillen",
    "abzustimmen": "abstimmen",
    "abzustoppen": "abstoppen",
    "abzustottern": "abstottern",
    "abzustoßen": "abstoßen",
    "abzustrafen": "abstrafen",
    "abzustrahlen": "abstrahlen",
    "abzustrampeln": "abstrampeln",
    "abzustreben": "abstreben",
    "abzustreichen": "abstreichen",
    "abzustreifen": "abstreifen",
    "abzustreiten": "abstreiten",
    "abzuströmen": "abströmen",
    "abzustufen": "abstufen",
    "abzustumpfen": "abstumpfen",
    "abzustürzen": "abstürzen",
    "abzustützen": "abstützen",
    "abzusuchen": "absuchen",
    "abzusäbeln": "absäbeln",
    "abzusägen": "absägen",
    "abzutakeln": "abtakeln",
    "abzutanken": "abtanken",
    "abzutanzen": "abtanzen",
    "abzutasten": "abtasten",
    "abzutauchen": "abtauchen",
    "abzutauen": "abtauen",
    "abzuteilen": "abteilen",
    "abzutelefonieren": "abtelefonieren",
    "abzutippen": "abtippen",
    "abzutragen": "abtragen",
    "abzutransportieren": "abtransportieren",
    "abzutreiben": "abtreiben",
    "abzutrennen": "abtrennen",
    "abzutreten": "abtreten",
    "abzutrinken": "abtrinken",
    "abzutrocknen": "abtrocknen",
    "abzutropfen": "abtropfen",
    "abzutrotzen": "abtrotzen",
    "abzutrudeln": "abtrudeln",
    "abzuträufeln": "abträufeln",
    "abzutupfen": "abtupfen",
    "abzutönen": "abtönen",
    "abzutöten": "abtöten",
    "abzuurteilen": "aburteilen",
    "abzuverlangen": "abverlangen",
    "abzuwandeln": "abwandeln",
    "abzuwandern": "abwandern",
    "abzuwarten": "abwarten",
    "abzuwaschen": "abwaschen",
    "abzuwechseln": "abwechseln",
    "abzuwehren": "abwehren",
    "abzuweichen": "abweichen",
    "abzuweiden": "abweiden",
    "abzuweisen": "abweisen",
    "abzuwenden": "abwenden",
    "abzuwerben": "abwerben",
    "abzuwerfen": "abwerfen",
    "abzuwerten": "abwerten",
    "abzuwetzen": "abwetzen",
    "abzuwickeln": "abwickeln",
    "abzuwiegen": "abwiegen",
    "abzuwimmeln": "abwimmeln",
    "abzuwinden": "abwinden",
    "abzuwinken": "abwinken",
    "abzuwirtschaften": "abwirtschaften",
    "abzuwischen": "abwischen",
    "abzuwohnen": "abwohnen",
    "abzuwägen": "abwägen",
    "abzuwählen": "abwählen",
    "abzuwälzen": "abwälzen",
    "abzuwürgen": "abwürgen",
    "abzuzahlen": "abzahlen",
    "abzuzapfen": "abzapfen",
    "abzuzappeln": "abzappeln",
    "abzuzeichnen": "abzeichnen",
    "abzuziehen": "abziehen",
    "abzuzielen": "abzielen",
    "abzuzirkeln": "abzirkeln",
    "abzuzischen": "abzischen",
    "abzuzittern": "abzittern",
    "abzuzupfen": "abzupfen",
    "abzuzweigen": "abzweigen",
    "abzuzwingen": "abzwingen",
    "abzuzwitschern": "abzwitschern",
    "abzuzählen": "abzählen",
    "abzuzäumen": "abzäumen",
    "abzuzäunen": "abzäunen",
    "abzuändern": "abändern",
    "abzuästen": "abästen",
    "abzwang": "abzwingen",
    "abzwangen": "abzwingen",
    "abzwangst": "abzwingen",
    "abzwangt": "abzwingen",
    "abzweige": "abzweigen",
    "abzweigend": "abzweigen",
    "abzweigende": "abzweigend",
    "abzweigendem": "abzweigend",
    "abzweigenden": "abzweigend",
    "abzweigender": "abzweigend",
    "abzweigendes": "abzweigend",
    "abzweigest": "abzweigen",
    "abzweiget": "abzweigen",
    "abzweigst": "abzweigen",
    "abzweigt": "abzweigen",
    "abzweigte": "abzweigen",
    "abzweigten": "abzweigen",
    "abzweigtest": "abzweigen",
    "abzweigtet": "abzweigen",
    "abzwinge": "abzwingen",
    "abzwingend": "abzwingen",
    "abzwingende": "abzwingend",
    "abzwingendem": "abzwingend",
    "abzwingenden": "abzwingend",
    "abzwingender": "abzwingend",
    "abzwingendes": "abzwingend",
    "abzwingest": "abzwingen",
    "abzwinget": "abzwingen",
    "abzwingst": "abzwingen",
    "abzwingt": "abzwingen",
    "abzwitschere": "abzwitschern",
    "abzwitschernd": "abzwitschern",
    "abzwitschernde": "abzwitschernd",
    "abzwitscherndem": "abzwitschernd",
    "abzwitschernden": "abzwitschernd",
    "abzwitschernder": "abzwitschernd",
    "abzwitscherndes": "abzwitschernd",
    "abzwitscherst": "abzwitschern",
    "abzwitschert": "abzwitschern",
    "abzwitscherte": "abzwitschern",
    "abzwitscherten": "abzwitschern",
    "abzwitschertest": "abzwitschern",
    "abzwitschertet": "abzwitschern",
    "abzwänge": "abzwingen",
    "abzwängen": "abzwingen",
    "abzwängest": "abzwingen",
    "abzwänget": "abzwingen",
    "abzähle": "abzählen",
    "abzählend": "abzählen",
    "abzählendem": "abzählend",
    "abzählender": "abzählend",
    "abzählendes": "abzählend",
    "abzählest": "abzählen",
    "abzählet": "abzählen",
    "abzählst": "abzählen",
    "abzählt": "abzählen",
    "abzählte": "abzählen",
    "abzählten": "abzählen",
    "abzähltest": "abzählen",
    "abzähltet": "abzählen",
    "abzäume": "abzäumen",
    "abzäumend": "abzäumen",
    "abzäumende": "abzäumend",
    "abzäumendem": "abzäumend",
    "abzäumenden": "abzäumend",
    "abzäumender": "abzäumend",
    "abzäumendere": "abzäumend",
    "abzäumenderem": "abzäumend",
    "abzäumenderen": "abzäumend",
    "abzäumenderer": "abzäumend",
    "abzäumenderes": "abzäumend",
    "abzäumendes": "abzäumend",
    "abzäumendste": "abzäumend",
    "abzäumendstem": "abzäumend",
    "abzäumendsten": "abzäumend",
    "abzäumendster": "abzäumend",
    "abzäumendstes": "abzäumend",
    "abzäumest": "abzäumen",
    "abzäumet": "abzäumen",
    "abzäumst": "abzäumen",
    "abzäumt": "abzäumen",
    "abzäumte": "abzäumen",
    "abzäumten": "abzäumen",
    "abzäumtest": "abzäumen",
    "abzäumtet": "abzäumen",
    "abzäune": "abzäunen",
    "abzäunend": "abzäunen",
    "abzäunende": "abzäunend",
    "abzäunendem": "abzäunend",
    "abzäunenden": "abzäunend",
    "abzäunender": "abzäunend",
    "abzäunendes": "abzäunend",
    "abzäunest": "abzäunen",
    "abzäunet": "abzäunen",
    "abzäunst": "abzäunen",
    "abzäunt": "abzäunen",
    "abzäunte": "abzäunen",
    "abzäunten": "abzäunen",
    "abzäuntest": "abzäunen",
    "abzäuntet": "abzäunen",
    "abzöge": "abziehen",
    "abzögen": "abziehen",
    "abzögest": "abziehen",
    "abzöget": "abziehen",
    "abändere": "abändern",
    "abändernd": "abändern",
    "abändernde": "abändernd",
    "abänderndem": "abändernd",
    "abändernden": "abändernd",
    "abändernder": "abändernd",
    "abänderndere": "abändernd",
    "abändernderem": "abändernd",
    "abändernderen": "abändernd",
    "abändernderer": "abändernd",
    "abändernderes": "abändernd",
    "abänderndes": "abändernd",
    "abänderndste": "abändernd",
    "abänderndstem": "abändernd",
    "abänderndsten": "abändernd",
    "abänderndster": "abändernd",
    "abänderndstes": "abändernd",
    "abänderst": "abändern",
    "abändert": "abändern",
    "abänderte": "abändern",
    "abänderten": "abändern",
    "abändertest": "abändern",
    "abändertet": "abändern",
    "abäste": "abästen",
    "abästend": "abästen",
    "abästende": "abästend",
    "abästendem": "abästend",
    "abästenden": "abästend",
    "abästender": "abästend",
    "abästendes": "abästend",
    "abästest": "abästen",
    "abästet": "abästen",
    "abästete": "abästen",
    "abästeten": "abästen",
    "abästetest": "abästen",
    "abästetet": "abästen",
    "abäße": "abessen",
    "abäßen": "abessen",
    "abäßest": "abessen",
    "abäßet": "abessen",
    "achtarmigem": "achtarmig",
    "achtarmigen": "achtarmig",
    "achtarmiger": "achtarmig",
    "achtarmiges": "achtarmig",
    "achtbare": "achtbar",
    "achtbarem": "achtbar",
    "achtbaren": "achtbar",
    "achtbarer": "achtbar",
    "achtbares": "achtbar",
    "achte": "achten",
    "achtend": "achten",
    "achtende": "achtend",
    "achtendem": "achtend",
    "achtenden": "achtend",
    "achtender": "achtend",
    "achtendere": "achtend",
    "achtenderem": "achtend",
    "achtenderen": "achtend",
    "achtenderer": "achtend",
    "achtenderes": "achtend",
    "achtendes": "achtend",
    "achtendste": "achtend",
    "achtendstem": "achtend",
    "achtendsten": "achtend",
    "achtendster": "achtend",
    "achtendstes": "achtend",
    "achtest": "achten",
    "achtet": "achten",
    "achtete": "achten",
    "achteten": "achten",
    "achtetest": "achten",
    "achtetet": "achten",
    "achtfache": "achtfach",
    "achtfachem": "achtfach",
    "achtfachen": "achtfach",
    "achtfacher": "achtfach",
    "achtfaches": "achtfach",
    "achtgab": "achtgeben",
    "achtgaben": "achtgeben",
    "achtgabst": "achtgeben",
    "achtgabt": "achtgeben",
    "achtgebe": "achtgeben",
    "achtgebend": "achtgeben",
    "achtgebende": "achtgebend",
    "achtgebendem": "achtgebend",
    "achtgebenden": "achtgebend",
    "achtgebender": "achtgebend",
    "achtgebendere": "achtgebend",
    "achtgebenderem": "achtgebend",
    "achtgebenderen": "achtgebend",
    "achtgebenderer": "achtgebend",
    "achtgebenderes": "achtgebend",
    "achtgebendes": "achtgebend",
    "achtgebendste": "achtgebend",
    "achtgebendstem": "achtgebend",
    "achtgebendsten": "achtgebend",
    "achtgebendster": "achtgebend",
    "achtgebendstes": "achtgebend",
    "achtgebest": "achtgeben",
    "achtgebet": "achtgeben",
    "achtgebt": "achtgeben",
    "achtgegeben": "achtgeben",
    "achtgegebene": "achtgegeben",
    "achtgegebenem": "achtgegeben",
    "achtgegebenen": "achtgegeben",
    "achtgegebener": "achtgegeben",
    "achtgegebenere": "achtgegeben",
    "achtgegebenerem": "achtgegeben",
    "achtgegebeneren": "achtgegeben",
    "achtgegebenerer": "achtgegeben",
    "achtgegebeneres": "achtgegeben",
    "achtgegebenes": "achtgegeben",
    "achtgegebenste": "achtgegeben",
    "achtgegebenstem": "achtgegeben",
    "achtgegebensten": "achtgegeben",
    "achtgegebenster": "achtgegeben",
    "achtgegebenstes": "achtgegeben",
    "achtgibst": "achtgeben",
    "achtgibt": "achtgeben",
    "achtgäbe": "achtgeben",
    "achtgäben": "achtgeben",
    "achtgäbest": "achtgeben",
    "achtgäbet": "achtgeben",
    "achtjährige": "achtjährig",
    "achtjährigem": "achtjährig",
    "achtjährigen": "achtjährig",
    "achtjähriger": "achtjährig",
    "achtjähriges": "achtjährig",
    "achtkantige": "achtkantig",
    "achtkantigem": "achtkantig",
    "achtkantigen": "achtkantig",
    "achtkantiger": "achtkantig",
    "achtkantiges": "achtkantig",
    "achtlose": "achtlos",
    "achtlosem": "achtlos",
    "achtlosen": "achtlos",
    "achtloser": "achtlos",
    "achtlosere": "achtlos",
    "achtloserem": "achtlos",
    "achtloseren": "achtlos",
    "achtloserer": "achtlos",
    "achtloseres": "achtlos",
    "achtloses": "achtlos",
    "achtloseste": "achtlos",
    "achtlosestem": "achtlos",
    "achtlosesten": "achtlos",
    "achtlosester": "achtlos",
    "achtlosestes": "achtlos",
    "achtmalige": "achtmalig",
    "achtmaligem": "achtmalig",
    "achtmaligen": "achtmalig",
    "achtmaliger": "achtmalig",
    "achtmaliges": "achtmalig",
    "achtprozentigem": "achtprozentig",
    "achtprozentigen": "achtprozentig",
    "achtprozentiger": "achtprozentig",
    "achtprozentiges": "achtprozentig",
    "achtsaitige": "achtsaitig",
    "achtsaitigem": "achtsaitig",
    "achtsaitigen": "achtsaitig",
    "achtsaitiger": "achtsaitig",
    "achtsaitiges": "achtsaitig",
    "achtsame": "achtsam",
    "achtsamem": "achtsam",
    "achtsamen": "achtsam",
    "achtsamer": "achtsam",
    "achtsamere": "achtsam",
    "achtsamerem": "achtsam",
    "achtsameren": "achtsam",
    "achtsamerer": "achtsam",
    "achtsameres": "achtsam",
    "achtsames": "achtsam",
    "achtsamste": "achtsam",
    "achtsamstem": "achtsam",
    "achtsamsten": "achtsam",
    "achtsamster": "achtsam",
    "achtsamstes": "achtsam",
    "achtseitige": "achtseitig",
    "achtseitigem": "achtseitig",
    "achtseitigen": "achtseitig",
    "achtseitiger": "achtseitig",
    "achtseitiges": "achtseitig",
    "achtsilbige": "achtsilbig",
    "achtsilbigem": "achtsilbig",
    "achtsilbigen": "achtsilbig",
    "achtsilbiger": "achtsilbig",
    "achtsilbiges": "achtsilbig",
    "achtstündigem": "achtstündig",
    "achtstündigen": "achtstündig",
    "achtstündiger": "achtstündig",
    "achtstündiges": "achtstündig",
    "achttägige": "achttägig",
    "achttägigem": "achttägig",
    "achttägigen": "achttägig",
    "achttägiger": "achttägig",
    "achttägiges": "achttägig",
    "achtzigfache": "achtzigfach",
    "achtzigfachem": "achtzigfach",
    "achtzigfachen": "achtzigfach",
    "achtzigfacher": "achtzigfach",
    "achtzigfaches": "achtzigfach",
    "achtzigjährige": "achtzigjährig",
    "achtzigjährigem": "achtzigjährig",
    "achtzigjährigen": "achtzigjährig",
    "achtzigjähriger": "achtzigjährig",
    "achtzigjähriges": "achtzigjährig",
    "achtzugeben": "achtgeben",
    "addiere": "addieren",
    "addierend": "addieren",
    "addierende": "addierend",
    "addierendem": "addierend",
    "addierenden": "addierend",
    "addierender": "addierend",
    "addierendes": "addierend",
    "addierest": "addieren",
    "addieret": "addieren",
    "addierst": "addieren",
    "addiert": "addieren",
    "addierte": "addieren",
    "addiertem": "addiert",
    "addierten": "addieren",
    "addierter": "addiert",
    "addiertes": "addiert",
    "addiertest": "addieren",
    "addiertet": "addieren",
    "additionale": "additional",
    "additionalem": "additional",
    "additionalen": "additional",
    "additionaler": "additional",
    "additionales": "additional",
    "additivem": "additiv",
    "additiven": "additiv",
    "additiver": "additiv",
    "additives": "additiv",
    "adele": "adeln",
    "adelige": "adelig",
    "adeligem": "adelig",
    "adeligen": "adelig",
    "adeliger": "adelig",
    "adeliges": "adelig",
    "adelnd": "adeln",
    "adelnde": "adelnd",
    "adelndem": "adelnd",
    "adelnden": "adelnd",
    "adelnder": "adelnd",
    "adelndes": "adelnd",
    "adelst": "adeln",
    "adelt": "adeln",
    "adelte": "adeln",
    "adelten": "adeln",
    "adeltest": "adeln",
    "adeltet": "adeln",
    "aderreichem": "aderreich",
    "aderreichen": "aderreich",
    "aderreicher": "aderreich",
    "aderreichere": "aderreich",
    "aderreicherem": "aderreich",
    "aderreicheren": "aderreich",
    "aderreicherer": "aderreich",
    "aderreicheres": "aderreich",
    "aderreiches": "aderreich",
    "aderreichste": "aderreich",
    "aderreichstem": "aderreich",
    "aderreichsten": "aderreich",
    "aderreichster": "aderreich",
    "aderreichstes": "aderreich",
    "adhärente": "adhärent",
    "adhärentem": "adhärent",
    "adhärenten": "adhärent",
    "adhärenter": "adhärent",
    "adhärentes": "adhärent",
    "adjektivischem": "adjektivisch",
    "adjektivischen": "adjektivisch",
    "adjektivischer": "adjektivisch",
    "adjektivisches": "adjektivisch",
    "adjustiere": "adjustieren",
    "adjustierend": "adjustieren",
    "adjustierende": "adjustierend",
    "adjustierendem": "adjustierend",
    "adjustierenden": "adjustierend",
    "adjustierender": "adjustierend",
    "adjustierendes": "adjustierend",
    "adjustierest": "adjustieren",
    "adjustieret": "adjustieren",
    "adjustierst": "adjustieren",
    "adjustiert": "adjustieren",
    "adjustierte": "adjustieren",
    "adjustiertem": "adjustiert",
    "adjustierten": "adjustieren",
    "adjustierter": "adjustiert",
    "adjustiertes": "adjustiert",
    "adjustiertest": "adjustieren",
    "adjustiertet": "adjustieren",
    "adle": "adeln",
    "adoleszentem": "adoleszent",
    "adoleszenten": "adoleszent",
    "adoleszenter": "adoleszent",
    "adoleszentes": "adoleszent",
    "adressiere": "adressieren",
    "adressierend": "adressieren",
    "adressierende": "adressierend",
    "adressierendem": "adressierend",
    "adressierenden": "adressierend",
    "adressierender": "adressierend",
    "adressierendes": "adressierend",
    "adressierest": "adressieren",
    "adressieret": "adressieren",
    "adressierst": "adressieren",
    "adressiert": "adressieren",
    "adressierte": "adressieren",
    "adressiertem": "adressiert",
    "adressierten": "adressieren",
    "adressierter": "adressiert",
    "adressiertes": "adressiert",
    "adressiertest": "adressieren",
    "adressiertet": "adressieren",
    "adsorbierbare": "adsorbierbar",
    "adsorbierbarem": "adsorbierbar",
    "adsorbierbaren": "adsorbierbar",
    "adsorbierbarer": "adsorbierbar",
    "adsorbierbarere": "adsorbierbar",
    "adsorbierbarerem": "adsorbierbar",
    "adsorbierbareren": "adsorbierbar",
    "adsorbierbarerer": "adsorbierbar",
    "adsorbierbareres": "adsorbierbar",
    "adsorbierbares": "adsorbierbar",
    "adsorbierbarste": "adsorbierbar",
    "adsorbierbarstem": "adsorbierbar",
    "adsorbierbarsten": "adsorbierbar",
    "adsorbierbarster": "adsorbierbar",
    "adsorbierbarstes": "adsorbierbar",
    "adsorbiere": "adsorbieren",
    "adsorbierend": "adsorbieren",
    "adsorbierende": "adsorbierend",
    "adsorbierendem": "adsorbierend",
    "adsorbierenden": "adsorbierend",
    "adsorbierender": "adsorbierend",
    "adsorbierendere": "adsorbierend",
    "adsorbierenderem": "adsorbierend",
    "adsorbierenderen": "adsorbierend",
    "adsorbierenderer": "adsorbierend",
    "adsorbierenderes": "adsorbierend",
    "adsorbierendes": "adsorbierend",
    "adsorbierendste": "adsorbierend",
    "adsorbierendstem": "adsorbierend",
    "adsorbierendsten": "adsorbierend",
    "adsorbierendster": "adsorbierend",
    "adsorbierendstes": "adsorbierend",
    "adsorbierest": "adsorbieren",
    "adsorbieret": "adsorbieren",
    "adsorbierst": "adsorbieren",
    "adsorbiert": "adsorbieren",
    "adsorbierte": "adsorbieren",
    "adsorbiertem": "adsorbiert",
    "adsorbierten": "adsorbieren",
    "adsorbierter": "adsorbiert",
    "adsorbiertere": "adsorbiert",
    "adsorbierterem": "adsorbiert",
    "adsorbierteren": "adsorbiert",
    "adsorbierterer": "adsorbiert",
    "adsorbierteres": "adsorbiert",
    "adsorbiertes": "adsorbiert",
    "adsorbiertest": "adsorbieren",
    "adsorbierteste": "adsorbiert",
    "adsorbiertestem": "adsorbiert",
    "adsorbiertesten": "adsorbiert",
    "adsorbiertester": "adsorbiert",
    "adsorbiertestes": "adsorbiert",
    "adsorbiertet": "adsorbieren",
    "affektiere": "affektieren",
    "affektierend": "affektieren",
    "affektierende": "affektierend",
    "affektierendem": "affektierend",
    "affektierenden": "affektierend",
    "affektierender": "affektierend",
    "affektierendere": "affektierend",
    "affektierenderem": "affektierend",
    "affektierenderen": "affektierend",
    "affektierenderer": "affektierend",
    "affektierenderes": "affektierend",
    "affektierendes": "affektierend",
    "affektierendste": "affektierend",
    "affektierendstem": "affektierend",
    "affektierendsten": "affektierend",
    "affektierendster": "affektierend",
    "affektierendstes": "affektierend",
    "affektierest": "affektieren",
    "affektieret": "affektieren",
    "affektierst": "affektieren",
    "affektiert": "affektieren",
    "affektierte": "affektieren",
    "affektiertem": "affektiert",
    "affektierten": "affektieren",
    "affektierter": "affektiert",
    "affektiertere": "affektiert",
    "affektierterem": "affektiert",
    "affektierteren": "affektiert",
    "affektierterer": "affektiert",
    "affektierteres": "affektiert",
    "affektiertes": "affektiert",
    "affektiertest": "affektieren",
    "affektierteste": "affektiert",
    "affektiertestem": "affektiert",
    "affektiertesten": "affektiert",
    "affektiertester": "affektiert",
    "affektiertestes": "affektiert",
    "affektiertet": "affektieren",
    "affektionierte": "affektioniert",
    "affektioniertem": "affektioniert",
    "affektionierten": "affektioniert",
    "affektionierter": "affektioniert",
    "affektioniertere": "affektioniert",
    "affektionierterem": "affektioniert",
    "affektionierteren": "affektioniert",
    "affektionierterer": "affektioniert",
    "affektionierteres": "affektioniert",
    "affektioniertes": "affektioniert",
    "affektionierteste": "affektioniert",
    "affektioniertestem": "affektioniert",
    "affektioniertesten": "affektioniert",
    "affektioniertester": "affektioniert",
    "affektioniertestes": "affektioniert",
    "affektive": "affektiv",
    "affektivem": "affektiv",
    "affektiven": "affektiv",
    "affektiver": "affektiv",
    "affektivere": "affektiv",
    "affektiverem": "affektiv",
    "affektiveren": "affektiv",
    "affektiverer": "affektiv",
    "affektiveres": "affektiv",
    "affektives": "affektiv",
    "affektivste": "affektiv",
    "affektivstem": "affektiv",
    "affektivsten": "affektiv",
    "affektivster": "affektiv",
    "affektivstes": "affektiv",
    "affenartigem": "affenartig",
    "affenartigen": "affenartig",
    "affenartiger": "affenartig",
    "affenartigere": "affenartig",
    "affenartigerem": "affenartig",
    "affenartigeren": "affenartig",
    "affenartigerer": "affenartig",
    "affenartigeres": "affenartig",
    "affenartiges": "affenartig",
    "affenartigste": "affenartig",
    "affenartigstem": "affenartig",
    "affenartigsten": "affenartig",
    "affenartigster": "affenartig",
    "affenartigstes": "affenartig",
    "affengeile": "affengeil",
    "affengeilem": "affengeil",
    "affengeilen": "affengeil",
    "affengeiler": "affengeil",
    "affengeilere": "affengeil",
    "affengeilerem": "affengeil",
    "affengeileren": "affengeil",
    "affengeilerer": "affengeil",
    "affengeileres": "affengeil",
    "affengeiles": "affengeil",
    "affengeilste": "affengeil",
    "affengeilstem": "affengeil",
    "affengeilsten": "affengeil",
    "affengeilster": "affengeil",
    "affengeilstes": "affengeil",
    "affige": "affig",
    "affigem": "affig",
    "affigen": "affig",
    "affiger": "affig",
    "affigere": "affig",
    "affigerem": "affig",
    "affigeren": "affig",
    "affigerer": "affig",
    "affigeres": "affig",
    "affiges": "affig",
    "affigste": "affig",
    "affigstem": "affig",
    "affigsten": "affig",
    "affigster": "affig",
    "affigstes": "affig",
    "affinem": "affin",
    "affinen": "affin",
    "affiner": "affin",
    "affines": "affin",
    "affirmativem": "affirmativ",
    "affirmativen": "affirmativ",
    "affirmativer": "affirmativ",
    "affirmativere": "affirmativ",
    "affirmativerem": "affirmativ",
    "affirmativeren": "affirmativ",
    "affirmativerer": "affirmativ",
    "affirmativeres": "affirmativ",
    "affirmatives": "affirmativ",
    "affirmativste": "affirmativ",
    "affirmativstem": "affirmativ",
    "affirmativsten": "affirmativ",
    "affirmativster": "affirmativ",
    "affirmativstes": "affirmativ",
    "affirmiere": "affirmieren",
    "affirmierend": "affirmieren",
    "affirmierende": "affirmierend",
    "affirmierendem": "affirmierend",
    "affirmierenden": "affirmierend",
    "affirmierender": "affirmierend",
    "affirmierendere": "affirmierend",
    "affirmierenderem": "affirmierend",
    "affirmierenderen": "affirmierend",
    "affirmierenderer": "affirmierend",
    "affirmierenderes": "affirmierend",
    "affirmierendes": "affirmierend",
    "affirmierendste": "affirmierend",
    "affirmierendstem": "affirmierend",
    "affirmierendsten": "affirmierend",
    "affirmierendster": "affirmierend",
    "affirmierendstes": "affirmierend",
    "affirmierest": "affirmieren",
    "affirmieret": "affirmieren",
    "affirmierst": "affirmieren",
    "affirmiert": "affirmieren",
    "affirmierte": "affirmieren",
    "affirmiertem": "affirmiert",
    "affirmierten": "affirmieren",
    "affirmierter": "affirmiert",
    "affirmiertere": "affirmiert",
    "affirmierterem": "affirmiert",
    "affirmierteren": "affirmiert",
    "affirmierterer": "affirmiert",
    "affirmierteres": "affirmiert",
    "affirmiertes": "affirmiert",
    "affirmiertest": "affirmieren",
    "affirmierteste": "affirmiert",
    "affirmiertestem": "affirmiert",
    "affirmiertesten": "affirmiert",
    "affirmiertester": "affirmiert",
    "affirmiertestes": "affirmiert",
    "affirmiertet": "affirmieren",
    "afghanischem": "afghanisch",
    "afghanischen": "afghanisch",
    "afghanischer": "afghanisch",
    "afghanisches": "afghanisch",
    "afrikanischem": "afrikanisch",
    "afrikanischen": "afrikanisch",
    "afrikanischer": "afrikanisch",
    "afrikanischere": "afrikanisch",
    "afrikanischerem": "afrikanisch",
    "afrikanischeren": "afrikanisch",
    "afrikanischerer": "afrikanisch",
    "afrikanischeres": "afrikanisch",
    "afrikanisches": "afrikanisch",
    "afrikanischste": "afrikanisch",
    "afrikanischstem": "afrikanisch",
    "afrikanischsten": "afrikanisch",
    "afrikanischster": "afrikanisch",
    "afrikanischstes": "afrikanisch",
    "agglomerierend": "agglomerieren",
    "agglomerierende": "agglomerierend",
    "agglomerierendem": "agglomerierend",
    "agglomerierenden": "agglomerierend",
    "agglomerierender": "agglomerierend",
    "agglomerierendere": "agglomerierend",
    "agglomerierenderem": "agglomerierend",
    "agglomerierenderen": "agglomerierend",
    "agglomerierenderer": "agglomerierend",
    "agglomerierenderes": "agglomerierend",
    "agglomerierendes": "agglomerierend",
    "agglomerierendste": "agglomerierend",
    "agglomerierendstem": "agglomerierend",
    "agglomerierendsten": "agglomerierend",
    "agglomerierendster": "agglomerierend",
    "agglomerierendstes": "agglomerierend",
    "agglomerierest": "agglomerieren",
    "agglomerieret": "agglomerieren",
    "agglomerierst": "agglomerieren",
    "agglomeriert": "agglomerieren",
    "agglomerierte": "agglomerieren",
    "agglomeriertem": "agglomeriert",
    "agglomerierten": "agglomerieren",
    "agglomerierter": "agglomeriert",
    "agglomeriertere": "agglomeriert",
    "agglomerierterem": "agglomeriert",
    "agglomerierteren": "agglomeriert",
    "agglomerierterer": "agglomeriert",
    "agglomerierteres": "agglomeriert",
    "agglomeriertes": "agglomeriert",
    "agglomeriertest": "agglomerieren",
    "agglomerierteste": "agglomeriert",
    "agglomeriertestem": "agglomeriert",
    "agglomeriertesten": "agglomeriert",
    "agglomeriertester": "agglomeriert",
    "agglomeriertestes": "agglomeriert",
    "agglomeriertet": "agglomerieren",
    "agglutiniere": "agglutinieren",
    "agglutinierend": "agglutinieren",
    "agglutinierende": "agglutinierend",
    "agglutinierendem": "agglutinierend",
    "agglutinierenden": "agglutinierend",
    "agglutinierender": "agglutinierend",
    "agglutinierendes": "agglutinierend",
    "agglutinierest": "agglutinieren",
    "agglutinieret": "agglutinieren",
    "agglutinierst": "agglutinieren",
    "agglutiniert": "agglutinieren",
    "agglutinierte": "agglutinieren",
    "agglutiniertem": "agglutiniert",
    "agglutinierten": "agglutinieren",
    "agglutinierter": "agglutiniert",
    "agglutiniertes": "agglutiniert",
    "agglutiniertest": "agglutinieren",
    "agglutiniertet": "agglutinieren",
    "aggressivem": "aggressiv",
    "aggressiven": "aggressiv",
    "aggressiver": "aggressiv",
    "aggressivere": "aggressiv",
    "aggressiverem": "aggressiv",
    "aggressiveren": "aggressiv",
    "aggressiverer": "aggressiv",
    "aggressiveres": "aggressiv",
    "aggressives": "aggressiv",
    "aggressivstem": "aggressiv",
    "aggressivsten": "aggressiv",
    "aggressivster": "aggressiv",
    "aggressivstes": "aggressiv",
    "agiere": "agieren",
    "agierend": "agieren",
    "agierende": "agierend",
    "agierendem": "agierend",
    "agierenden": "agierend",
    "agierender": "agierend",
    "agierendere": "agierend",
    "agierenderem": "agierend",
    "agierenderen": "agierend",
    "agierenderer": "agierend",
    "agierenderes": "agierend",
    "agierendes": "agierend",
    "agierendste": "agierend",
    "agierendstem": "agierend",
    "agierendsten": "agierend",
    "agierendster": "agierend",
    "agierendstes": "agierend",
    "agierest": "agieren",
    "agieret": "agieren",
    "agierst": "agieren",
    "agiert": "agieren",
    "agierte": "agieren",
    "agiertem": "agiert",
    "agierten": "agieren",
    "agierter": "agiert",
    "agiertes": "agiert",
    "agiertest": "agieren",
    "agiertet": "agieren",
    "agile": "agil",
    "agilem": "agil",
    "agilen": "agil",
    "agiler": "agil",
    "agilere": "agil",
    "agilerem": "agil",
    "agileren": "agil",
    "agilerer": "agil",
    "agileres": "agil",
    "agiles": "agil",
    "agilste": "agil",
    "agilstem": "agil",
    "agilsten": "agil",
    "agilster": "agil",
    "agilstes": "agil",
    "agitatorischem": "agitatorisch",
    "agitatorischen": "agitatorisch",
    "agitatorischer": "agitatorisch",
    "agitatorischere": "agitatorisch",
    "agitatorischerem": "agitatorisch",
    "agitatorischeren": "agitatorisch",
    "agitatorischerer": "agitatorisch",
    "agitatorischeres": "agitatorisch",
    "agitatorisches": "agitatorisch",
    "agitatorischste": "agitatorisch",
    "agitatorischstem": "agitatorisch",
    "agitatorischsten": "agitatorisch",
    "agitatorischster": "agitatorisch",
    "agitatorischstes": "agitatorisch",
    "agrotechnischem": "agrotechnisch",
    "agrotechnischen": "agrotechnisch",
    "agrotechnischer": "agrotechnisch",
    "agrotechnisches": "agrotechnisch",
    "ahme": "ahmen",
    "ahmend": "ahmen",
    "ahmende": "ahmend",
    "ahmendem": "ahmend",
    "ahmenden": "ahmend",
    "ahmender": "ahmend",
    "ahmendere": "ahmend",
    "ahmenderem": "ahmend",
    "ahmenderen": "ahmend",
    "ahmenderer": "ahmend",
    "ahmenderes": "ahmend",
    "ahmendes": "ahmend",
    "ahmendste": "ahmend",
    "ahmendstem": "ahmend",
    "ahmendsten": "ahmend",
    "ahmendster": "ahmend",
    "ahmendstes": "ahmend",
    "ahmest": "ahmen",
    "ahmet": "ahmen",
    "ahmst": "ahmen",
    "ahmt": "ahmen",
    "ahmte": "ahmen",
    "ahmten": "ahmen",
    "ahmtest": "ahmen",
    "ahmtet": "ahmen",
    "ahnde": "ahnden",
    "ahndend": "ahnden",
    "ahndende": "ahndend",
    "ahndendem": "ahndend",
    "ahndenden": "ahndend",
    "ahndender": "ahndend",
    "ahndendere": "ahndend",
    "ahndenderem": "ahndend",
    "ahndenderen": "ahndend",
    "ahndenderer": "ahndend",
    "ahndenderes": "ahndend",
    "ahndendes": "ahndend",
    "ahndendste": "ahndend",
    "ahndendstem": "ahndend",
    "ahndendsten": "ahndend",
    "ahndendster": "ahndend",
    "ahndendstes": "ahndend",
    "ahndest": "ahnden",
    "ahndet": "ahnden",
    "ahndete": "ahnden",
    "ahndeten": "ahnden",
    "ahndetest": "ahnden",
    "ahndetet": "ahnden",
    "ahne": "ahnen",
    "ahnend": "ahnen",
    "ahnende": "ahnend",
    "ahnendem": "ahnend",
    "ahnenden": "ahnend",
    "ahnender": "ahnend",
    "ahnendere": "ahnend",
    "ahnenderem": "ahnend",
    "ahnenderen": "ahnend",
    "ahnenderer": "ahnend",
    "ahnenderes": "ahnend",
    "ahnendes": "ahnend",
    "ahnendste": "ahnend",
    "ahnendstem": "ahnend",
    "ahnendsten": "ahnend",
    "ahnendster": "ahnend",
    "ahnendstes": "ahnend",
    "ahnest": "ahnen",
    "ahnet": "ahnen",
    "ahnst": "ahnen",
    "ahnt": "ahnen",
    "ahnte": "ahnen",
    "ahnten": "ahnen",
    "ahntest": "ahnen",
    "ahntet": "ahnen",
    "ahnungslosem": "ahnungslos",
    "ahnungslosen": "ahnungslos",
    "ahnungsloser": "ahnungslos",
    "ahnungslosere": "ahnungslos",
    "ahnungsloserem": "ahnungslos",
    "ahnungsloseren": "ahnungslos",
    "ahnungsloserer": "ahnungslos",
    "ahnungsloseres": "ahnungslos",
    "ahnungsloses": "ahnungslos",
    "ahnungsloseste": "ahnungslos",
    "ahnungslosestem": "ahnungslos",
    "ahnungslosesten": "ahnungslos",
    "ahnungslosester": "ahnungslos",
    "ahnungslosestes": "ahnungslos",
    "ahnungsvolle": "ahnungsvoll",
    "ahnungsvollem": "ahnungsvoll",
    "ahnungsvollen": "ahnungsvoll",
    "ahnungsvoller": "ahnungsvoll",
    "ahnungsvollere": "ahnungsvoll",
    "ahnungsvollerem": "ahnungsvoll",
    "ahnungsvolleren": "ahnungsvoll",
    "ahnungsvollerer": "ahnungsvoll",
    "ahnungsvolleres": "ahnungsvoll",
    "ahnungsvolles": "ahnungsvoll",
    "ahnungsvollste": "ahnungsvoll",
    "ahnungsvollstem": "ahnungsvoll",
    "ahnungsvollsten": "ahnungsvoll",
    "ahnungsvollster": "ahnungsvoll",
    "ahnungsvollstes": "ahnungsvoll",
    "akademischem": "akademisch",
    "akademischen": "akademisch",
    "akademischer": "akademisch",
    "akademisches": "akademisch",
    "akklamiere": "akklamieren",
    "akklamierend": "akklamieren",
    "akklamierende": "akklamierend",
    "akklamierendem": "akklamierend",
    "akklamierenden": "akklamierend",
    "akklamierender": "akklamierend",
    "akklamierendere": "akklamierend",
    "akklamierenderem": "akklamierend",
    "akklamierenderen": "akklamierend",
    "akklamierenderer": "akklamierend",
    "akklamierenderes": "akklamierend",
    "akklamierendes": "akklamierend",
    "akklamierendste": "akklamierend",
    "akklamierendstem": "akklamierend",
    "akklamierendsten": "akklamierend",
    "akklamierendster": "akklamierend",
    "akklamierendstes": "akklamierend",
    "akklamierest": "akklamieren",
    "akklamieret": "akklamieren",
    "akklamierst": "akklamieren",
    "akklamiert": "akklamieren",
    "akklamierte": "akklamieren",
    "akklamiertem": "akklamiert",
    "akklamierten": "akklamieren",
    "akklamierter": "akklamiert",
    "akklamiertere": "akklamiert",
    "akklamierterem": "akklamiert",
    "akklamierteren": "akklamiert",
    "akklamierterer": "akklamiert",
    "akklamierteres": "akklamiert",
    "akklamiertes": "akklamiert",
    "akklamiertest": "akklamieren",
    "akklamierteste": "akklamiert",
    "akklamiertestem": "akklamiert",
    "akklamiertesten": "akklamiert",
    "akklamiertester": "akklamiert",
    "akklamiertestes": "akklamiert",
    "akklamiertet": "akklamieren",
    "akklimatisiere": "akklimatisieren",
    "akklimatisierend": "akklimatisieren",
    "akklimatisierende": "akklimatisierend",
    "akklimatisierendem": "akklimatisierend",
    "akklimatisierenden": "akklimatisierend",
    "akklimatisierender": "akklimatisierend",
    "akklimatisierendes": "akklimatisierend",
    "akklimatisierest": "akklimatisieren",
    "akklimatisieret": "akklimatisieren",
    "akklimatisierst": "akklimatisieren",
    "akklimatisiert": "akklimatisieren",
    "akklimatisierte": "akklimatisieren",
    "akklimatisiertem": "akklimatisiert",
    "akklimatisierten": "akklimatisieren",
    "akklimatisierter": "akklimatisiert",
    "akklimatisiertes": "akklimatisiert",
    "akklimatisiertest": "akklimatisieren",
    "akklimatisiertet": "akklimatisieren",
    "akkommodiere": "akkommodieren",
    "akkommodierend": "akkommodieren",
    "akkommodierende": "akkommodierend",
    "akkommodierendem": "akkommodierend",
    "akkommodierenden": "akkommodierend",
    "akkommodierender": "akkommodierend",
    "akkommodierendes": "akkommodierend",
    "akkommodierest": "akkommodieren",
    "akkommodieret": "akkommodieren",
    "akkommodierst": "akkommodieren",
    "akkommodiert": "akkommodieren",
    "akkommodierte": "akkommodieren",
    "akkommodiertem": "akkommodiert",
    "akkommodierten": "akkommodieren",
    "akkommodierter": "akkommodiert",
    "akkommodiertes": "akkommodiert",
    "akkommodiertest": "akkommodieren",
    "akkommodiertet": "akkommodieren",
    "akkreditiere": "akkreditieren",
    "akkreditierend": "akkreditieren",
    "akkreditierende": "akkreditierend",
    "akkreditierendem": "akkreditierend",
    "akkreditierenden": "akkreditierend",
    "akkreditierender": "akkreditierend",
    "akkreditierendes": "akkreditierend",
    "akkreditierest": "akkreditieren",
    "akkreditieret": "akkreditieren",
    "akkreditierst": "akkreditieren",
    "akkreditiert": "akkreditieren",
    "akkreditierte": "akkreditieren",
    "akkreditiertem": "akkreditiert",
    "akkreditierten": "akkreditieren",
    "akkreditierter": "akkreditiert",
    "akkreditiertes": "akkreditiert",
    "akkreditiertest": "akkreditieren",
    "akkreditiertet": "akkreditieren",
    "akkumuliere": "akkumulieren",
    "akkumulierend": "akkumulieren",
    "akkumulierende": "akkumulierend",
    "akkumulierendem": "akkumulierend",
    "akkumulierenden": "akkumulierend",
    "akkumulierender": "akkumulierend",
    "akkumulierendes": "akkumulierend",
    "akkumulierest": "akkumulieren",
    "akkumulieret": "akkumulieren",
    "akkumulierst": "akkumulieren",
    "akkumuliert": "akkumulieren",
    "akkumulierte": "akkumulieren",
    "akkumuliertem": "akkumuliert",
    "akkumulierten": "akkumulieren",
    "akkumulierter": "akkumuliert",
    "akkumuliertes": "akkumuliert",
    "akkumuliertest": "akkumulieren",
    "akkumuliertet": "akkumulieren",
    "akkurate": "akkurat",
    "akkuratem": "akkurat",
    "akkuraten": "akkurat",
    "akkurater": "akkurat",
    "akkuratere": "akkurat",
    "akkuraterem": "akkurat",
    "akkurateren": "akkurat",
    "akkuraterer": "akkurat",
    "akkurateres": "akkurat",
    "akkurates": "akkurat",
    "akkurateste": "akkurat",
    "akkuratestem": "akkurat",
    "akkuratesten": "akkurat",
    "akkuratester": "akkurat",
    "akkuratestes": "akkurat",
    "akquiriere": "akquirieren",
    "akquirierend": "akquirieren",
    "akquirierende": "akquirierend",
    "akquirierendem": "akquirierend",
    "akquirierenden": "akquirierend",
    "akquirierender": "akquirierend",
    "akquirierendes": "akquirierend",
    "akquirierest": "akquirieren",
    "akquirieret": "akquirieren",
    "akquirierst": "akquirieren",
    "akquiriert": "akquirieren",
    "akquirierte": "akquirieren",
    "akquiriertem": "akquiriert",
    "akquirierten": "akquirieren",
    "akquirierter": "akquiriert",
    "akquiriertes": "akquiriert",
    "akquiriertest": "akquirieren",
    "akquiriertet": "akquirieren",
    "akrobatischem": "akrobatisch",
    "akrobatischen": "akrobatisch",
    "akrobatischer": "akrobatisch",
    "akrobatischere": "akrobatisch",
    "akrobatischerem": "akrobatisch",
    "akrobatischeren": "akrobatisch",
    "akrobatischerer": "akrobatisch",
    "akrobatischeres": "akrobatisch",
    "akrobatisches": "akrobatisch",
    "akrobatischste": "akrobatisch",
    "akrobatischstem": "akrobatisch",
    "akrobatischsten": "akrobatisch",
    "akrobatischster": "akrobatisch",
    "akrobatischstes": "akrobatisch",
    "aktenkundigem": "aktenkundig",
    "aktenkundigen": "aktenkundig",
    "aktenkundiger": "aktenkundig",
    "aktenkundigere": "aktenkundig",
    "aktenkundigerem": "aktenkundig",
    "aktenkundigeren": "aktenkundig",
    "aktenkundigerer": "aktenkundig",
    "aktenkundigeres": "aktenkundig",
    "aktenkundiges": "aktenkundig",
    "aktenkundigste": "aktenkundig",
    "aktenkundigstem": "aktenkundig",
    "aktenkundigsten": "aktenkundig",
    "aktenkundigster": "aktenkundig",
    "aktenkundigstes": "aktenkundig",
    "aktivem": "aktiv",
    "aktiven": "aktiv",
    "aktiver": "aktiv",
    "aktivere": "aktiv",
    "aktiverem": "aktiv",
    "aktiveren": "aktiv",
    "aktiverer": "aktiv",
    "aktiveres": "aktiv",
    "aktives": "aktiv",
    "aktiviere": "aktivieren",
    "aktivierend": "aktivieren",
    "aktivierende": "aktivierend",
    "aktivierendem": "aktivierend",
    "aktivierenden": "aktivierend",
    "aktivierender": "aktivierend",
    "aktivierendes": "aktivierend",
    "aktivierest": "aktivieren",
    "aktivieret": "aktivieren",
    "aktivierst": "aktivieren",
    "aktiviert": "aktivieren",
    "aktivierte": "aktivieren",
    "aktiviertem": "aktiviert",
    "aktivierten": "aktivieren",
    "aktivierter": "aktiviert",
    "aktiviertes": "aktiviert",
    "aktiviertest": "aktivieren",
    "aktiviertet": "aktivieren",
    "aktivstem": "aktiv",
    "aktivsten": "aktiv",
    "aktivster": "aktiv",
    "aktivstes": "aktiv",
    "aktualisierend": "aktualisieren",
    "aktualisierende": "aktualisierend",
    "aktualisierendem": "aktualisierend",
    "aktualisierenden": "aktualisierend",
    "aktualisierender": "aktualisierend",
    "aktualisierendere": "aktualisierend",
    "aktualisierenderem": "aktualisierend",
    "aktualisierenderen": "aktualisierend",
    "aktualisierenderer": "aktualisierend",
    "aktualisierenderes": "aktualisierend",
    "aktualisierendes": "aktualisierend",
    "aktualisierendste": "aktualisierend",
    "aktualisierendstem": "aktualisierend",
    "aktualisierendsten": "aktualisierend",
    "aktualisierendster": "aktualisierend",
    "aktualisierendstes": "aktualisierend",
    "aktualisierest": "aktualisieren",
    "aktualisieret": "aktualisieren",
    "aktualisierst": "aktualisieren",
    "aktualisiert": "aktualisieren",
    "aktualisierte": "aktualisieren",
    "aktualisiertem": "aktualisiert",
    "aktualisierten": "aktualisieren",
    "aktualisierter": "aktualisiert",
    "aktualisiertere": "aktualisiert",
    "aktualisierterem": "aktualisiert",
    "aktualisierteren": "aktualisiert",
    "aktualisierterer": "aktualisiert",
    "aktualisierteres": "aktualisiert",
    "aktualisiertes": "aktualisiert",
    "aktualisiertest": "aktualisieren",
    "aktualisierteste": "aktualisiert",
    "aktualisiertestem": "aktualisiert",
    "aktualisiertesten": "aktualisiert",
    "aktualisiertester": "aktualisiert",
    "aktualisiertestes": "aktualisiert",
    "aktualisiertet": "aktualisieren",
    "aktuelle": "aktuell",
    "aktuellem": "aktuell",
    "aktuellen": "aktuell",
    "aktueller": "aktuell",
    "aktuellere": "aktuell",
    "aktuellerem": "aktuell",
    "aktuelleren": "aktuell",
    "aktuellerer": "aktuell",
    "aktuelleres": "aktuell",
    "aktuelles": "aktuell",
    "aktuellste": "aktuell",
    "aktuellstem": "aktuell",
    "aktuellsten": "aktuell",
    "aktuellster": "aktuell",
    "aktuellstes": "aktuell",
    "akupunktiere": "akupunktieren",
    "akupunktierend": "akupunktieren",
    "akupunktierende": "akupunktierend",
    "akupunktierendem": "akupunktierend",
    "akupunktierenden": "akupunktierend",
    "akupunktierender": "akupunktierend",
    "akupunktierendes": "akupunktierend",
    "akupunktierest": "akupunktieren",
    "akupunktieret": "akupunktieren",
    "akupunktierst": "akupunktieren",
    "akupunktiert": "akupunktieren",
    "akupunktierte": "akupunktieren",
    "akupunktiertem": "akupunktiert",
    "akupunktierten": "akupunktieren",
    "akupunktierter": "akupunktiert",
    "akupunktiertes": "akupunktiert",
    "akupunktiertest": "akupunktieren",
    "akupunktiertet": "akupunktieren",
    "akustischem": "akustisch",
    "akustischen": "akustisch",
    "akustischer": "akustisch",
    "akustischere": "akustisch",
    "akustischerem": "akustisch",
    "akustischeren": "akustisch",
    "akustischerer": "akustisch",
    "akustischeres": "akustisch",
    "akustisches": "akustisch",
    "akustischste": "akustisch",
    "akustischstem": "akustisch",
    "akustischsten": "akustisch",
    "akustischster": "akustisch",
    "akustischstes": "akustisch",
    "akute": "akut",
    "akutem": "akut",
    "akuten": "akut",
    "akuter": "akut",
    "akutere": "akut",
    "akuterem": "akut",
    "akuteren": "akut",
    "akuterer": "akut",
    "akuteres": "akut",
    "akutes": "akut",
    "akuteste": "akut",
    "akutestem": "akut",
    "akutesten": "akut",
    "akutester": "akut",
    "akutestes": "akut",
    "akzentuiere": "akzentuieren",
    "akzentuierend": "akzentuieren",
    "akzentuierende": "akzentuierend",
    "akzentuierendem": "akzentuierend",
    "akzentuierenden": "akzentuierend",
    "akzentuierender": "akzentuierend",
    "akzentuierendere": "akzentuierend",
    "akzentuierenderem": "akzentuierend",
    "akzentuierenderen": "akzentuierend",
    "akzentuierenderer": "akzentuierend",
    "akzentuierenderes": "akzentuierend",
    "akzentuierendes": "akzentuierend",
    "akzentuierendste": "akzentuierend",
    "akzentuierendstem": "akzentuierend",
    "akzentuierendsten": "akzentuierend",
    "akzentuierendster": "akzentuierend",
    "akzentuierendstes": "akzentuierend",
    "akzentuierest": "akzentuieren",
    "akzentuieret": "akzentuieren",
    "akzentuierst": "akzentuieren",
    "akzentuiert": "akzentuieren",
    "akzentuierte": "akzentuieren",
    "akzentuiertem": "akzentuiert",
    "akzentuierten": "akzentuieren",
    "akzentuierter": "akzentuiert",
    "akzentuiertere": "akzentuiert",
    "akzentuierterem": "akzentuiert",
    "akzentuierteren": "akzentuiert",
    "akzentuierterer": "akzentuiert",
    "akzentuierteres": "akzentuiert",
    "akzentuiertes": "akzentuiert",
    "akzentuiertest": "akzentuieren",
    "akzentuierteste": "akzentuiert",
    "akzentuiertestem": "akzentuiert",
    "akzentuiertesten": "akzentuiert",
    "akzentuiertester": "akzentuiert",
    "akzentuiertestes": "akzentuiert",
    "akzentuiertet": "akzentuieren",
    "akzeptabelste": "akzeptabel",
    "akzeptabelstem": "akzeptabel",
    "akzeptabelsten": "akzeptabel",
    "akzeptabelster": "akzeptabel",
    "akzeptabelstes": "akzeptabel",
    "akzeptable": "akzeptabel",
    "akzeptablem": "akzeptabel",
    "akzeptablen": "akzeptabel",
    "akzeptabler": "akzeptabel",
    "akzeptablere": "akzeptabel",
    "akzeptablerem": "akzeptabel",
    "akzeptableren": "akzeptabel",
    "akzeptablerer": "akzeptabel",
    "akzeptableres": "akzeptabel",
    "akzeptables": "akzeptabel",
    "akzeptiere": "akzeptieren",
    "akzeptierend": "akzeptieren",
    "akzeptierende": "akzeptierend",
    "akzeptierendem": "akzeptierend",
    "akzeptierenden": "akzeptierend",
    "akzeptierender": "akzeptierend",
    "akzeptierendes": "akzeptierend",
    "akzeptierest": "akzeptieren",
    "akzeptieret": "akzeptieren",
    "akzeptierst": "akzeptieren",
    "akzeptiert": "akzeptieren",
    "akzeptierte": "akzeptieren",
    "akzeptiertem": "akzeptiert",
    "akzeptierten": "akzeptieren",
    "akzeptierter": "akzeptiert",
    "akzeptiertere": "akzeptiert",
    "akzeptierterem": "akzeptiert",
    "akzeptierteren": "akzeptiert",
    "akzeptierterer": "akzeptiert",
    "akzeptierteres": "akzeptiert",
    "akzeptiertes": "akzeptiert",
    "akzeptiertest": "akzeptieren",
    "akzeptierteste": "akzeptiert",
    "akzeptiertestem": "akzeptiert",
    "akzeptiertesten": "akzeptiert",
    "akzeptiertester": "akzeptiert",
    "akzeptiertestes": "akzeptiert",
    "akzeptiertet": "akzeptieren",
    "alarmiere": "alarmieren",
    "alarmierend": "alarmieren",
    "alarmierende": "alarmierend",
    "alarmierendem": "alarmierend",
    "alarmierenden": "alarmierend",
    "alarmierender": "alarmierend",
    "alarmierendere": "alarmierend",
    "alarmierenderem": "alarmierend",
    "alarmierenderen": "alarmierend",
    "alarmierenderer": "alarmierend",
    "alarmierenderes": "alarmierend",
    "alarmierendes": "alarmierend",
    "alarmierendste": "alarmierend",
    "alarmierendstem": "alarmierend",
    "alarmierendsten": "alarmierend",
    "alarmierendster": "alarmierend",
    "alarmierendstes": "alarmierend",
    "alarmierest": "alarmieren",
    "alarmieret": "alarmieren",
    "alarmierst": "alarmieren",
    "alarmiert": "alarmieren",
    "alarmierte": "alarmieren",
    "alarmiertem": "alarmiert",
    "alarmierten": "alarmieren",
    "alarmierter": "alarmiert",
    "alarmiertes": "alarmiert",
    "alarmiertest": "alarmieren",
    "alarmiertet": "alarmieren",
    "albanischem": "albanisch",
    "albanischen": "albanisch",
    "albanischer": "albanisch",
    "albanisches": "albanisch",
    "albere": "albern",
    "albernd": "albern",
    "albernde": "albernd",
    "alberndem": "albernd",
    "albernden": "albernd",
    "albernder": "albernd",
    "alberndere": "albernd",
    "albernderem": "albernd",
    "albernderen": "albernd",
    "albernderer": "albernd",
    "albernderes": "albernd",
    "alberndes": "albernd",
    "alberndste": "albernd",
    "alberndstem": "albernd",
    "alberndsten": "albernd",
    "alberndster": "albernd",
    "alberndstes": "albernd",
    "alberst": "albern",
    "albert": "albern",
    "alberte": "albern",
    "alberten": "albern",
    "albertest": "albern",
    "albertet": "albern",
    "alemannischem": "alemannisch",
    "alemannischen": "alemannisch",
    "alemannischer": "alemannisch",
    "alemannisches": "alemannisch",
    "alkalischem": "alkalisch",
    "alkalischen": "alkalisch",
    "alkalischer": "alkalisch",
    "alkalisches": "alkalisch",
    "alkalisiere": "alkalisieren",
    "alkalisierend": "alkalisieren",
    "alkalisierende": "alkalisierend",
    "alkalisierendem": "alkalisierend",
    "alkalisierenden": "alkalisierend",
    "alkalisierender": "alkalisierend",
    "alkalisierendere": "alkalisierend",
    "alkalisierenderem": "alkalisierend",
    "alkalisierenderen": "alkalisierend",
    "alkalisierenderer": "alkalisierend",
    "alkalisierenderes": "alkalisierend",
    "alkalisierendes": "alkalisierend",
    "alkalisierendste": "alkalisierend",
    "alkalisierendstem": "alkalisierend",
    "alkalisierendsten": "alkalisierend",
    "alkalisierendster": "alkalisierend",
    "alkalisierendstes": "alkalisierend",
    "alkalisierest": "alkalisieren",
    "alkalisieret": "alkalisieren",
    "alkalisierst": "alkalisieren",
    "alkalisiert": "alkalisieren",
    "alkalisierte": "alkalisieren",
    "alkalisiertem": "alkalisiert",
    "alkalisierten": "alkalisieren",
    "alkalisierter": "alkalisiert",
    "alkalisiertere": "alkalisiert",
    "alkalisierterem": "alkalisiert",
    "alkalisierteren": "alkalisiert",
    "alkalisierterer": "alkalisiert",
    "alkalisierteres": "alkalisiert",
    "alkalisiertes": "alkalisiert",
    "alkalisiertest": "alkalisieren",
    "alkalisierteste": "alkalisiert",
    "alkalisiertestem": "alkalisiert",
    "alkalisiertesten": "alkalisiert",
    "alkalisiertester": "alkalisiert",
    "alkalisiertestes": "alkalisiert",
    "alkalisiertet": "alkalisieren",
    "alkoholfreiem": "alkoholfrei",
    "alkoholfreien": "alkoholfrei",
    "alkoholfreier": "alkoholfrei",
    "alkoholfreiere": "alkoholfrei",
    "alkoholfreierem": "alkoholfrei",
    "alkoholfreieren": "alkoholfrei",
    "alkoholfreierer": "alkoholfrei",
    "alkoholfreieres": "alkoholfrei",
    "alkoholfreies": "alkoholfrei",
    "alkoholfreiste": "alkoholfrei",
    "alkoholfreistem": "alkoholfrei",
    "alkoholfreisten": "alkoholfrei",
    "alkoholfreister": "alkoholfrei",
    "alkoholfreistes": "alkoholfrei",
    "alkoholischem": "alkoholisch",
    "alkoholischen": "alkoholisch",
    "alkoholischer": "alkoholisch",
    "alkoholischere": "alkoholisch",
    "alkoholischerem": "alkoholisch",
    "alkoholischeren": "alkoholisch",
    "alkoholischerer": "alkoholisch",
    "alkoholischeres": "alkoholisch",
    "alkoholisches": "alkoholisch",
    "alkoholischste": "alkoholisch",
    "alkoholischstem": "alkoholisch",
    "alkoholischsten": "alkoholisch",
    "alkoholischster": "alkoholisch",
    "alkoholischstes": "alkoholisch",
    "alkoholisiere": "alkoholisieren",
    "alkoholisierend": "alkoholisieren",
    "alkoholisierende": "alkoholisierend",
    "alkoholisierendem": "alkoholisierend",
    "alkoholisierenden": "alkoholisierend",
    "alkoholisierender": "alkoholisierend",
    "alkoholisierendere": "alkoholisierend",
    "alkoholisierenderem": "alkoholisierend",
    "alkoholisierenderen": "alkoholisierend",
    "alkoholisierenderer": "alkoholisierend",
    "alkoholisierenderes": "alkoholisierend",
    "alkoholisierendes": "alkoholisierend",
    "alkoholisierendste": "alkoholisierend",
    "alkoholisierendstem": "alkoholisierend",
    "alkoholisierendsten": "alkoholisierend",
    "alkoholisierendster": "alkoholisierend",
    "alkoholisierendstes": "alkoholisierend",
    "alkoholisierest": "alkoholisieren",
    "alkoholisieret": "alkoholisieren",
    "alkoholisierst": "alkoholisieren",
    "alkoholisiert": "alkoholisieren",
    "alkoholisierte": "alkoholisieren",
    "alkoholisiertem": "alkoholisiert",
    "alkoholisierten": "alkoholisieren",
    "alkoholisierter": "alkoholisiert",
    "alkoholisiertere": "alkoholisiert",
    "alkoholisierterem": "alkoholisiert",
    "alkoholisierteren": "alkoholisiert",
    "alkoholisierterer": "alkoholisiert",
    "alkoholisierteres": "alkoholisiert",
    "alkoholisiertes": "alkoholisiert",
    "alkoholisiertest": "alkoholisieren",
    "alkoholisiertestem": "alkoholisiert",
    "alkoholisiertesten": "alkoholisiert",
    "alkoholisiertester": "alkoholisiert",
    "alkoholisiertestes": "alkoholisiert",
    "alkoholisiertet": "alkoholisieren",
    "allbekanntem": "allbekannt",
    "allbekannten": "allbekannt",
    "allbekannter": "allbekannt",
    "allbekanntes": "allbekannt",
    "allbeliebte": "allbeliebt",
    "allbeliebtem": "allbeliebt",
    "allbeliebten": "allbeliebt",
    "allbeliebter": "allbeliebt",
    "allbeliebtes": "allbeliebt",
    "alle": "all",
    "alleinerziehendem": "alleinerziehend",
    "alleinerziehenden": "alleinerziehend",
    "alleinerziehender": "alleinerziehend",
    "alleinerziehendes": "alleinerziehend",
    "alleinigem": "alleinig",
    "alleinigen": "alleinig",
    "alleiniger": "alleinig",
    "alleiniges": "alleinig",
    "alleinstehendem": "alleinstehend",
    "alleinstehenden": "alleinstehend",
    "alleinstehender": "alleinstehend",
    "alleinstehendes": "alleinstehend",
    "allem": "alle",
    "allen": "alle",
    "aller": "all",
    "allerbestem": "allerbeste",
    "allerbesten": "allerbeste",
    "allerbester": "allerbeste",
    "allerbestes": "allerbeste",
    "allererstem": "allererste",
    "allerersten": "allererste",
    "allererster": "allererste",
    "allererstes": "allererste",
    "alles": "alle",
    "allesfressende": "allesfressend",
    "allesfressendem": "allesfressend",
    "allesfressenden": "allesfressend",
    "allesfressender": "allesfressend",
    "allesfressendes": "allesfressend",
    "allgegenwärtigem": "allgegenwärtig",
    "allgegenwärtigen": "allgegenwärtig",
    "allgegenwärtiger": "allgegenwärtig",
    "allgegenwärtiges": "allgegenwärtig",
    "allgemeinbildendem": "allgemeinbildend",
    "allgemeinbildenden": "allgemeinbildend",
    "allgemeinbildender": "allgemeinbildend",
    "allgemeinbildendes": "allgemeinbildend",
    "allgemeine": "allgemein",
    "allgemeinem": "allgemein",
    "allgemeinen": "allgemein",
    "allgemeiner": "allgemein",
    "allgemeinere": "allgemein",
    "allgemeinerem": "allgemein",
    "allgemeineren": "allgemein",
    "allgemeinerer": "allgemein",
    "allgemeineres": "allgemein",
    "allgemeines": "allgemein",
    "allgemeingültige": "allgemeingültig",
    "allgemeingültigem": "allgemeingültig",
    "allgemeingültigen": "allgemeingültig",
    "allgemeingültiger": "allgemeingültig",
    "allgemeingültigere": "allgemeingültig",
    "allgemeingültigerem": "allgemeingültig",
    "allgemeingültigeren": "allgemeingültig",
    "allgemeingültigerer": "allgemeingültig",
    "allgemeingültigeres": "allgemeingültig",
    "allgemeingültiges": "allgemeingültig",
    "allgemeingültigste": "allgemeingültig",
    "allgemeingültigstem": "allgemeingültig",
    "allgemeingültigsten": "allgemeingültig",
    "allgemeingültigster": "allgemeingültig",
    "allgemeingültigstes": "allgemeingültig",
    "allgemeinstem": "allgemein",
    "allgemeinsten": "allgemein",
    "allgemeinster": "allgemein",
    "allgemeinstes": "allgemein",
    "allmonatliche": "allmonatlich",
    "allmonatlichem": "allmonatlich",
    "allmonatlichen": "allmonatlich",
    "allmonatlicher": "allmonatlich",
    "allmonatliches": "allmonatlich",
    "allmächtigem": "allmächtig",
    "allmächtigen": "allmächtig",
    "allmächtiger": "allmächtig",
    "allmächtiges": "allmächtig",
    "allmähliche": "allmählich",
    "allmählichem": "allmählich",
    "allmählichen": "allmählich",
    "allmählicher": "allmählich",
    "allmähliches": "allmählich",
    "allseitigem": "allseitig",
    "allseitigen": "allseitig",
    "allseitiger": "allseitig",
    "allseitiges": "allseitig",
    "allstündliche": "allstündlich",
    "allstündlichem": "allstündlich",
    "allstündlichen": "allstündlich",
    "allstündlicher": "allstündlich",
    "allstündliches": "allstündlich",
    "alltagstypischem": "alltagstypisch",
    "alltagstypischen": "alltagstypisch",
    "alltagstypischer": "alltagstypisch",
    "alltagstypischere": "alltagstypisch",
    "alltagstypischerem": "alltagstypisch",
    "alltagstypischeren": "alltagstypisch",
    "alltagstypischerer": "alltagstypisch",
    "alltagstypischeres": "alltagstypisch",
    "alltagstypisches": "alltagstypisch",
    "alltagstypischste": "alltagstypisch",
    "alltagstypischstem": "alltagstypisch",
    "alltagstypischsten": "alltagstypisch",
    "alltagstypischster": "alltagstypisch",
    "alltagstypischstes": "alltagstypisch",
    "alltäglichem": "alltäglich",
    "alltäglichen": "alltäglich",
    "alltäglicher": "alltäglich",
    "alltägliches": "alltäglich",
    "allumfassende": "allumfassend",
    "allumfassendem": "allumfassend",
    "allumfassenden": "allumfassend",
    "allumfassender": "allumfassend",
    "allumfassendere": "allumfassend",
    "allumfassenderem": "allumfassend",
    "allumfassenderen": "allumfassend",
    "allumfassenderer": "allumfassend",
    "allumfassenderes": "allumfassend",
    "allumfassendes": "allumfassend",
    "allumfassendste": "allumfassend",
    "allumfassendstem": "allumfassend",
    "allumfassendsten": "allumfassend",
    "allumfassendster": "allumfassend",
    "allumfassendstes": "allumfassend",
    "allwissendem": "allwissend",
    "allwissenden": "allwissend",
    "allwissender": "allwissend",
    "allwissendes": "allwissend",
    "allwöchentliche": "allwöchentlich",
    "allwöchentlichem": "allwöchentlich",
    "allwöchentlichen": "allwöchentlich",
    "allwöchentlicher": "allwöchentlich",
    "allwöchentliches": "allwöchentlich",
    "alphabetischem": "alphabetisch",
    "alphabetischen": "alphabetisch",
    "alphabetischer": "alphabetisch",
    "alphabetisches": "alphabetisch",
    "alphabetisiere": "alphabetisieren",
    "alphabetisierend": "alphabetisieren",
    "alphabetisierende": "alphabetisierend",
    "alphabetisierendem": "alphabetisierend",
    "alphabetisierenden": "alphabetisierend",
    "alphabetisierender": "alphabetisierend",
    "alphabetisierendere": "alphabetisierend",
    "alphabetisierenderem": "alphabetisierend",
    "alphabetisierenderen": "alphabetisierend",
    "alphabetisierenderer": "alphabetisierend",
    "alphabetisierenderes": "alphabetisierend",
    "alphabetisierendes": "alphabetisierend",
    "alphabetisierendste": "alphabetisierend",
    "alphabetisierendstem": "alphabetisierend",
    "alphabetisierendsten": "alphabetisierend",
    "alphabetisierendster": "alphabetisierend",
    "alphabetisierendstes": "alphabetisierend",
    "alphabetisierest": "alphabetisieren",
    "alphabetisieret": "alphabetisieren",
    "alphabetisierst": "alphabetisieren",
    "alphabetisiert": "alphabetisieren",
    "alphabetisierte": "alphabetisieren",
    "alphabetisiertem": "alphabetisiert",
    "alphabetisierten": "alphabetisieren",
    "alphabetisierter": "alphabetisiert",
    "alphabetisiertere": "alphabetisiert",
    "alphabetisierterem": "alphabetisiert",
    "alphabetisierteren": "alphabetisiert",
    "alphabetisierterer": "alphabetisiert",
    "alphabetisierteres": "alphabetisiert",
    "alphabetisiertes": "alphabetisiert",
    "alphabetisiertest": "alphabetisieren",
    "alphabetisierteste": "alphabetisiert",
    "alphabetisiertestem": "alphabetisiert",
    "alphabetisiertesten": "alphabetisiert",
    "alphabetisiertester": "alphabetisiert",
    "alphabetisiertestes": "alphabetisiert",
    "alphabetisiertet": "alphabetisieren",
    "alphanumerischem": "alphanumerisch",
    "alphanumerischen": "alphanumerisch",
    "alphanumerischer": "alphanumerisch",
    "alphanumerisches": "alphanumerisch",
    "alpinem": "alpin",
    "alpinen": "alpin",
    "alpiner": "alpin",
    "alpines": "alpin",
    "alsbaldigem": "alsbaldig",
    "alsbaldigen": "alsbaldig",
    "alsbaldiger": "alsbaldig",
    "alsbaldiges": "alsbaldig",
    "altbewährtem": "altbewährt",
    "altbewährten": "altbewährt",
    "altbewährter": "altbewährt",
    "altbewährtere": "altbewährt",
    "altbewährterem": "altbewährt",
    "altbewährteren": "altbewährt",
    "altbewährterer": "altbewährt",
    "altbewährteres": "altbewährt",
    "altbewährtes": "altbewährt",
    "altbewährteste": "altbewährt",
    "altbewährtestem": "altbewährt",
    "altbewährtesten": "altbewährt",
    "altbewährtester": "altbewährt",
    "altbewährtestes": "altbewährt",
    "altdeutsche": "altdeutsch",
    "altdeutschem": "altdeutsch",
    "altdeutschen": "altdeutsch",
    "altdeutscher": "altdeutsch",
    "altdeutsches": "altdeutsch",
    "alte": "alt",
    "alteingesessenem": "alteingesessen",
    "alteingesessenen": "alteingesessen",
    "alteingesessener": "alteingesessen",
    "alteingesessenere": "alteingesessen",
    "alteingesessenerem": "alteingesessen",
    "alteingesesseneren": "alteingesessen",
    "alteingesessenerer": "alteingesessen",
    "alteingesesseneres": "alteingesessen",
    "alteingesessenes": "alteingesessen",
    "alteingesessenste": "alteingesessen",
    "alteingesessenstem": "alteingesessen",
    "alteingesessensten": "alteingesessen",
    "alteingesessenster": "alteingesessen",
    "alteingesessenstes": "alteingesessen",
    "alteingewurzelte": "alteingewurzelt",
    "alteingewurzeltem": "alteingewurzelt",
    "alteingewurzelten": "alteingewurzelt",
    "alteingewurzelter": "alteingewurzelt",
    "alteingewurzeltes": "alteingewurzelt",
    "altem": "alt",
    "alten": "alt",
    "alter": "altern",
    "altere": "altern",
    "alteriere": "alterieren",
    "alterierend": "alterieren",
    "alterierende": "alterierend",
    "alterierendem": "alterierend",
    "alterierenden": "alterierend",
    "alterierender": "alterierend",
    "alterierendere": "alterierend",
    "alterierenderem": "alterierend",
    "alterierenderen": "alterierend",
    "alterierenderer": "alterierend",
    "alterierenderes": "alterierend",
    "alterierendes": "alterierend",
    "alterierendste": "alterierend",
    "alterierendstem": "alterierend",
    "alterierendsten": "alterierend",
    "alterierendster": "alterierend",
    "alterierendstes": "alterierend",
    "alterierest": "alterieren",
    "alterieret": "alterieren",
    "alterierst": "alterieren",
    "alteriert": "alterieren",
    "alterierte": "alterieren",
    "alteriertem": "alteriert",
    "alterierten": "alterieren",
    "alterierter": "alteriert",
    "alteriertere": "alteriert",
    "alterierterem": "alteriert",
    "alterierteren": "alteriert",
    "alterierterer": "alteriert",
    "alterierteres": "alteriert",
    "alteriertes": "alteriert",
    "alteriertest": "alterieren",
    "alterierteste": "alteriert",
    "alteriertestem": "alteriert",
    "alteriertesten": "alteriert",
    "alteriertester": "alteriert",
    "alteriertestes": "alteriert",
    "alteriertet": "alterieren",
    "alternativem": "alternativ",
    "alternativen": "alternativ",
    "alternativer": "alternativ",
    "alternativere": "alternativ",
    "alternativerem": "alternativ",
    "alternativeren": "alternativ",
    "alternativerer": "alternativ",
    "alternativeres": "alternativ",
    "alternatives": "alternativ",
    "alternativste": "alternativ",
    "alternativstem": "alternativ",
    "alternativsten": "alternativ",
    "alternativster": "alternativ",
    "alternativstes": "alternativ",
    "alternd": "altern",
    "alternde": "alternd",
    "alterndem": "alternd",
    "alternden": "alternd",
    "alternder": "alternd",
    "alterndere": "alternd",
    "alternderem": "alternd",
    "alternderen": "alternd",
    "alternderer": "alternd",
    "alternderes": "alternd",
    "alterndes": "alternd",
    "alterndste": "alternd",
    "alterndstem": "alternd",
    "alterndsten": "alternd",
    "alterndster": "alternd",
    "alterndstes": "alternd",
    "alterniere": "alternieren",
    "alternierend": "alternieren",
    "alternierende": "alternierend",
    "alternierendem": "alternierend",
    "alternierenden": "alternierend",
    "alternierender": "alternierend",
    "alternierendere": "alternierend",
    "alternierenderem": "alternierend",
    "alternierenderen": "alternierend",
    "alternierenderer": "alternierend",
    "alternierenderes": "alternierend",
    "alternierendes": "alternierend",
    "alternierendste": "alternierend",
    "alternierendstem": "alternierend",
    "alternierendsten": "alternierend",
    "alternierendster": "alternierend",
    "alternierendstes": "alternierend",
    "alternierest": "alternieren",
    "alternieret": "alternieren",
    "alternierst": "alternieren",
    "alterniert": "alternieren",
    "alternierte": "alternieren",
    "alterniertem": "alterniert",
    "alternierten": "alternieren",
    "alternierter": "alterniert",
    "alterniertes": "alterniert",
    "alterniertest": "alternieren",
    "alterniertet": "alternieren",
    "altersbedingtem": "altersbedingt",
    "altersbedingten": "altersbedingt",
    "altersbedingter": "altersbedingt",
    "altersbedingtes": "altersbedingt",
    "altersschwachem": "altersschwach",
    "altersschwachen": "altersschwach",
    "altersschwacher": "altersschwach",
    "altersschwaches": "altersschwach",
    "altersschwächer": "altersschwach",
    "altersschwächere": "altersschwach",
    "altersschwächerem": "altersschwach",
    "altersschwächeren": "altersschwach",
    "altersschwächerer": "altersschwach",
    "altersschwächeres": "altersschwach",
    "altersschwächsten": "altersschwach",
    "alterst": "altern",
    "altert": "altern",
    "alterte": "altern",
    "alterten": "altern",
    "altertest": "altern",
    "altertet": "altern",
    "altertümlichem": "altertümlich",
    "altertümlichen": "altertümlich",
    "altertümlicher": "altertümlich",
    "altertümlichere": "altertümlich",
    "altertümlicherem": "altertümlich",
    "altertümlicheren": "altertümlich",
    "altertümlicherer": "altertümlich",
    "altertümlicheres": "altertümlich",
    "altertümliches": "altertümlich",
    "altertümlichste": "altertümlich",
    "altertümlichstem": "altertümlich",
    "altertümlichsten": "altertümlich",
    "altertümlichster": "altertümlich",
    "altertümlichstes": "altertümlich",
    "altes": "alt",
    "altfranzösische": "altfranzösisch",
    "altfranzösischem": "altfranzösisch",
    "altfranzösischen": "altfranzösisch",
    "altfranzösischer": "altfranzösisch",
    "altfranzösischere": "altfranzösisch",
    "altfranzösischerem": "altfranzösisch",
    "altfranzösischeren": "altfranzösisch",
    "altfranzösischerer": "altfranzösisch",
    "altfranzösischeres": "altfranzösisch",
    "altfranzösisches": "altfranzösisch",
    "altfranzösischste": "altfranzösisch",
    "altfranzösischstem": "altfranzösisch",
    "altfranzösischsten": "altfranzösisch",
    "altfranzösischster": "altfranzösisch",
    "altfranzösischstes": "altfranzösisch",
    "altfränkische": "altfränkisch",
    "altfränkischem": "altfränkisch",
    "altfränkischen": "altfränkisch",
    "altfränkischer": "altfränkisch",
    "altfränkischere": "altfränkisch",
    "altfränkischerem": "altfränkisch",
    "altfränkischeren": "altfränkisch",
    "altfränkischerer": "altfränkisch",
    "altfränkischeres": "altfränkisch",
    "altfränkisches": "altfränkisch",
    "altfränkischste": "altfränkisch",
    "altfränkischstem": "altfränkisch",
    "altfränkischsten": "altfränkisch",
    "altfränkischster": "altfränkisch",
    "altfränkischstes": "altfränkisch",
    "altgriechischem": "altgriechisch",
    "altgriechischen": "altgriechisch",
    "altgriechischer": "altgriechisch",
    "altgriechisches": "altgriechisch",
    "althergebrachte": "althergebracht",
    "althergebrachtem": "althergebracht",
    "althergebrachten": "althergebracht",
    "althergebrachter": "althergebracht",
    "althergebrachtes": "althergebracht",
    "althochdeutschem": "althochdeutsch",
    "althochdeutschen": "althochdeutsch",
    "althochdeutscher": "althochdeutsch",
    "althochdeutsches": "althochdeutsch",
    "altindische": "altindisch",
    "altindischem": "altindisch",
    "altindischen": "altindisch",
    "altindischer": "altindisch",
    "altindisches": "altindisch",
    "altkatholischem": "altkatholisch",
    "altkatholischen": "altkatholisch",
    "altkatholischer": "altkatholisch",
    "altkatholischere": "altkatholisch",
    "altkatholischerem": "altkatholisch",
    "altkatholischeren": "altkatholisch",
    "altkatholischerer": "altkatholisch",
    "altkatholischeres": "altkatholisch",
    "altkatholisches": "altkatholisch",
    "altkatholischste": "altkatholisch",
    "altkatholischstem": "altkatholisch",
    "altkatholischsten": "altkatholisch",
    "altkatholischster": "altkatholisch",
    "altkatholischstes": "altkatholisch",
    "altklugem": "altklug",
    "altklugen": "altklug",
    "altkluger": "altklug",
    "altkluges": "altklug",
    "altklüger": "altklug",
    "altklügere": "altklug",
    "altklügerem": "altklug",
    "altklügeren": "altklug",
    "altklügerer": "altklug",
    "altklügeres": "altklug",
    "altklügsten": "altklug",
    "altmodische": "altmodisch",
    "altmodischem": "altmodisch",
    "altmodischen": "altmodisch",
    "altmodischer": "altmodisch",
    "altmodischere": "altmodisch",
    "altmodischerem": "altmodisch",
    "altmodischeren": "altmodisch",
    "altmodischerer": "altmodisch",
    "altmodischeres": "altmodisch",
    "altmodisches": "altmodisch",
    "altmodischste": "altmodisch",
    "altmodischstem": "altmodisch",
    "altmodischsten": "altmodisch",
    "altmodischster": "altmodisch",
    "altmodischstes": "altmodisch",
    "altpreußischem": "altpreußisch",
    "altpreußischen": "altpreußisch",
    "altpreußischer": "altpreußisch",
    "altpreußisches": "altpreußisch",
    "altsprachlichem": "altsprachlich",
    "altsprachlichen": "altsprachlich",
    "altsprachlicher": "altsprachlich",
    "altsprachliches": "altsprachlich",
    "alttestamentarischem": "alttestamentarisch",
    "alttestamentarischen": "alttestamentarisch",
    "alttestamentarischer": "alttestamentarisch",
    "alttestamentarisches": "alttestamentarisch",
    "alttestamentliche": "alttestamentlich",
    "alttestamentlichem": "alttestamentlich",
    "alttestamentlichen": "alttestamentlich",
    "alttestamentlicher": "alttestamentlich",
    "alttestamentliches": "alttestamentlich",
    "altüberlieferte": "altüberliefert",
    "altüberliefertem": "altüberliefert",
    "altüberlieferten": "altüberliefert",
    "altüberlieferter": "altüberliefert",
    "altüberliefertes": "altüberliefert",
    "ambitioniertem": "ambitioniert",
    "ambitionierten": "ambitioniert",
    "ambitionierter": "ambitioniert",
    "ambitioniertere": "ambitioniert",
    "ambitionierterem": "ambitioniert",
    "ambitionierteren": "ambitioniert",
    "ambitionierterer": "ambitioniert",
    "ambitionierteres": "ambitioniert",
    "ambitioniertes": "ambitioniert",
    "ambitionierteste": "ambitioniert",
    "ambitioniertestem": "ambitioniert",
    "ambitioniertesten": "ambitioniert",
    "ambitioniertester": "ambitioniert",
    "ambitioniertestes": "ambitioniert",
    "ambulantem": "ambulant",
    "ambulanten": "ambulant",
    "ambulanter": "ambulant",
    "ambulantes": "ambulant",
    "amerikanischem": "amerikanisch",
    "amerikanischen": "amerikanisch",
    "amerikanischer": "amerikanisch",
    "amerikanischere": "amerikanisch",
    "amerikanischerem": "amerikanisch",
    "amerikanischeren": "amerikanisch",
    "amerikanischerer": "amerikanisch",
    "amerikanischeres": "amerikanisch",
    "amerikanisches": "amerikanisch",
    "amerikanischste": "amerikanisch",
    "amerikanischstem": "amerikanisch",
    "amerikanischsten": "amerikanisch",
    "amerikanischster": "amerikanisch",
    "amerikanischstes": "amerikanisch",
    "amerikanisiere": "amerikanisieren",
    "amerikanisierend": "amerikanisieren",
    "amerikanisierende": "amerikanisierend",
    "amerikanisierendem": "amerikanisierend",
    "amerikanisierenden": "amerikanisierend",
    "amerikanisierender": "amerikanisierend",
    "amerikanisierendere": "amerikanisierend",
    "amerikanisierenderem": "amerikanisierend",
    "amerikanisierenderen": "amerikanisierend",
    "amerikanisierenderer": "amerikanisierend",
    "amerikanisierenderes": "amerikanisierend",
    "amerikanisierendes": "amerikanisierend",
    "amerikanisierendste": "amerikanisierend",
    "amerikanisierendstem": "amerikanisierend",
    "amerikanisierendsten": "amerikanisierend",
    "amerikanisierendster": "amerikanisierend",
    "amerikanisierendstes": "amerikanisierend",
    "amerikanisierest": "amerikanisieren",
    "amerikanisieret": "amerikanisieren",
    "amerikanisierst": "amerikanisieren",
    "amerikanisiert": "amerikanisieren",
    "amerikanisierte": "amerikanisieren",
    "amerikanisiertem": "amerikanisiert",
    "amerikanisierten": "amerikanisieren",
    "amerikanisierter": "amerikanisiert",
    "amerikanisiertere": "amerikanisiert",
    "amerikanisierterem": "amerikanisiert",
    "amerikanisierteren": "amerikanisiert",
    "amerikanisierterer": "amerikanisiert",
    "amerikanisierteres": "amerikanisiert",
    "amerikanisiertes": "amerikanisiert",
    "amerikanisiertest": "amerikanisieren",
    "amerikanisierteste": "amerikanisiert",
    "amerikanisiertestem": "amerikanisiert",
    "amerikanisiertesten": "amerikanisiert",
    "amerikanisiertester": "amerikanisiert",
    "amerikanisiertestes": "amerikanisiert",
    "amerikanisiertet": "amerikanisieren",
    "amortisiere": "amortisieren",
    "amortisierend": "amortisieren",
    "amortisierende": "amortisierend",
    "amortisierendem": "amortisierend",
    "amortisierenden": "amortisierend",
    "amortisierender": "amortisierend",
    "amortisierendere": "amortisierend",
    "amortisierenderem": "amortisierend",
    "amortisierenderen": "amortisierend",
    "amortisierenderer": "amortisierend",
    "amortisierenderes": "amortisierend",
    "amortisierendes": "amortisierend",
    "amortisierendste": "amortisierend",
    "amortisierendstem": "amortisierend",
    "amortisierendsten": "amortisierend",
    "amortisierendster": "amortisierend",
    "amortisierendstes": "amortisierend",
    "amortisierest": "amortisieren",
    "amortisieret": "amortisieren",
    "amortisierst": "amortisieren",
    "amortisiert": "amortisieren",
    "amortisierte": "amortisieren",
    "amortisiertem": "amortisiert",
    "amortisierten": "amortisieren",
    "amortisierter": "amortisiert",
    "amortisiertere": "amortisiert",
    "amortisierterem": "amortisiert",
    "amortisierteren": "amortisiert",
    "amortisierterer": "amortisiert",
    "amortisierteres": "amortisiert",
    "amortisiertes": "amortisiert",
    "amortisiertest": "amortisieren",
    "amortisierteste": "amortisiert",
    "amortisiertestem": "amortisiert",
    "amortisiertesten": "amortisiert",
    "amortisiertester": "amortisiert",
    "amortisiertestes": "amortisiert",
    "amortisiertet": "amortisieren",
    "amputiere": "amputieren",
    "amputierend": "amputieren",
    "amputierende": "amputierend",
    "amputierendem": "amputierend",
    "amputierenden": "amputierend",
    "amputierender": "amputierend",
    "amputierendes": "amputierend",
    "amputierest": "amputieren",
    "amputieret": "amputieren",
    "amputierst": "amputieren",
    "amputiert": "amputieren",
    "amputierte": "amputieren",
    "amputiertem": "amputiert",
    "amputierten": "amputieren",
    "amputierter": "amputiert",
    "amputiertes": "amputiert",
    "amputiertest": "amputieren",
    "amputiertet": "amputieren",
    "amtiere": "amtieren",
    "amtierend": "amtieren",
    "amtierende": "amtierend",
    "amtierendem": "amtierend",
    "amtierenden": "amtierend",
    "amtierender": "amtierend",
    "amtierendes": "amtierend",
    "amtierest": "amtieren",
    "amtieret": "amtieren",
    "amtierst": "amtieren",
    "amtiert": "amtieren",
    "amtierte": "amtieren",
    "amtiertem": "amtiert",
    "amtierten": "amtieren",
    "amtierter": "amtiert",
    "amtiertes": "amtiert",
    "amtiertest": "amtieren",
    "amtiertet": "amtieren",
    "amtliche": "amtlich",
    "amtlichem": "amtlich",
    "amtlichen": "amtlich",
    "amtlicher": "amtlich",
    "amtlichere": "amtlich",
    "amtlicherem": "amtlich",
    "amtlicheren": "amtlich",
    "amtlicherer": "amtlich",
    "amtlicheres": "amtlich",
    "amtliches": "amtlich",
    "amtlichste": "amtlich",
    "amtlichstem": "amtlich",
    "amtlichsten": "amtlich",
    "amtlichster": "amtlich",
    "amtlichstes": "amtlich",
    "amtsmüdem": "amtsmüde",
    "amtsmüden": "amtsmüde",
    "amtsmüder": "amtsmüde",
    "amtsmüdere": "amtsmüde",
    "amtsmüderem": "amtsmüde",
    "amtsmüderen": "amtsmüde",
    "amtsmüderer": "amtsmüde",
    "amtsmüderes": "amtsmüde",
    "amtsmüdes": "amtsmüde",
    "amtsmüdeste": "amtsmüde",
    "amtsmüdestem": "amtsmüde",
    "amtsmüdesten": "amtsmüde",
    "amtsmüdester": "amtsmüde",
    "amtsmüdestes": "amtsmüde",
    "amüsante": "amüsant",
    "amüsantem": "amüsant",
    "amüsanten": "amüsant",
    "amüsanter": "amüsant",
    "amüsantere": "amüsant",
    "amüsanterem": "amüsant",
    "amüsanteren": "amüsant",
    "amüsanterer": "amüsant",
    "amüsanteres": "amüsant",
    "amüsantes": "amüsant",
    "amüsanteste": "amüsant",
    "amüsantestem": "amüsant",
    "amüsantesten": "amüsant",
    "amüsantester": "amüsant",
    "amüsantestes": "amüsant",
    "amüsiere": "amüsieren",
    "amüsierend": "amüsieren",
    "amüsierende": "amüsierend",
    "amüsierendem": "amüsierend",
    "amüsierenden": "amüsierend",
    "amüsierender": "amüsierend",
    "amüsierendere": "amüsierend",
    "amüsierenderem": "amüsierend",
    "amüsierenderen": "amüsierend",
    "amüsierenderer": "amüsierend",
    "amüsierenderes": "amüsierend",
    "amüsierendes": "amüsierend",
    "amüsierendste": "amüsierend",
    "amüsierendstem": "amüsierend",
    "amüsierendsten": "amüsierend",
    "amüsierendster": "amüsierend",
    "amüsierendstes": "amüsierend",
    "amüsierest": "amüsieren",
    "amüsieret": "amüsieren",
    "amüsierst": "amüsieren",
    "amüsiert": "amüsieren",
    "amüsierte": "amüsieren",
    "amüsiertem": "amüsiert",
    "amüsierten": "amüsieren",
    "amüsierter": "amüsiert",
    "amüsiertere": "amüsiert",
    "amüsierterem": "amüsiert",
    "amüsierteren": "amüsiert",
    "amüsierterer": "amüsiert",
    "amüsierteres": "amüsiert",
    "amüsiertes": "amüsiert",
    "amüsiertest": "amüsieren",
    "amüsierteste": "amüsiert",
    "amüsiertestem": "amüsiert",
    "amüsiertesten": "amüsiert",
    "amüsiertester": "amüsiert",
    "amüsiertestes": "amüsiert",
    "amüsiertet": "amüsieren",
    "analogem": "analog",
    "analogen": "analog",
    "analoger": "analog",
    "analoges": "analog",
    "analysiere": "analysieren",
    "analysierend": "analysieren",
    "analysierende": "analysierend",
    "analysierendem": "analysierend",
    "analysierenden": "analysierend",
    "analysierender": "analysierend",
    "analysierendes": "analysierend",
    "analysierest": "analysieren",
    "analysieret": "analysieren",
    "analysierst": "analysieren",
    "analysiert": "analysieren",
    "analysierte": "analysieren",
    "analysiertem": "analysiert",
    "analysierten": "analysieren",
    "analysierter": "analysiert",
    "analysiertes": "analysiert",
    "analysiertest": "analysieren",
    "analysiertet": "analysieren",
    "analytischem": "analytisch",
    "analytischen": "analytisch",
    "analytischer": "analytisch",
    "analytisches": "analytisch",
    "anatomischem": "anatomisch",
    "anatomischen": "anatomisch",
    "anatomischer": "anatomisch",
    "anatomisches": "anatomisch",
    "anbacke": "anbacken",
    "anbackend": "anbacken",
    "anbackende": "anbackend",
    "anbackendem": "anbackend",
    "anbackenden": "anbackend",
    "anbackender": "anbackend",
    "anbackendere": "anbackend",
    "anbackenderem": "anbackend",
    "anbackenderen": "anbackend",
    "anbackenderer": "anbackend",
    "anbackenderes": "anbackend",
    "anbackendes": "anbackend",
    "anbackendste": "anbackend",
    "anbackendstem": "anbackend",
    "anbackendsten": "anbackend",
    "anbackendster": "anbackend",
    "anbackendstes": "anbackend",
    "anbackest": "anbacken",
    "anbacket": "anbacken",
    "anbackst": "anbacken",
    "anbackt": "anbacken",
    "anbackte": "anbacken",
    "anbackten": "anbacken",
    "anbacktest": "anbacken",
    "anbacktet": "anbacken",
    "anbaggere": "anbaggern",
    "anbaggernd": "anbaggern",
    "anbaggernde": "anbaggernd",
    "anbaggerndem": "anbaggernd",
    "anbaggernden": "anbaggernd",
    "anbaggernder": "anbaggernd",
    "anbaggerndes": "anbaggernd",
    "anbaggerst": "anbaggern",
    "anbaggert": "anbaggern",
    "anbaggerte": "anbaggern",
    "anbaggerten": "anbaggern",
    "anbaggertest": "anbaggern",
    "anbaggertet": "anbaggern",
    "anbahne": "anbahnen",
    "anbahnend": "anbahnen",
    "anbahnende": "anbahnend",
    "anbahnendem": "anbahnend",
    "anbahnenden": "anbahnend",
    "anbahnender": "anbahnend",
    "anbahnendes": "anbahnend",
    "anbahnest": "anbahnen",
    "anbahnet": "anbahnen",
    "anbahnst": "anbahnen",
    "anbahnt": "anbahnen",
    "anbahnte": "anbahnen",
    "anbahnten": "anbahnen",
    "anbahntest": "anbahnen",
    "anbahntet": "anbahnen",
    "anband": "anbinden",
    "anbandele": "anbandeln",
    "anbandelnd": "anbandeln",
    "anbandelnde": "anbandelnd",
    "anbandelndem": "anbandelnd",
    "anbandelnden": "anbandelnd",
    "anbandelnder": "anbandelnd",
    "anbandelndes": "anbandelnd",
    "anbandelst": "anbandeln",
    "anbandelt": "anbandeln",
    "anbandelte": "anbandeln",
    "anbandelten": "anbandeln",
    "anbandeltest": "anbandeln",
    "anbandeltet": "anbandeln",
    "anbanden": "anbinden",
    "anbandest": "anbinden",
    "anbandet": "anbinden",
    "anbandle": "anbandeln",
    "anbaue": "anbauen",
    "anbauend": "anbauen",
    "anbauende": "anbauend",
    "anbauendem": "anbauend",
    "anbauenden": "anbauend",
    "anbauender": "anbauend",
    "anbauendes": "anbauend",
    "anbauest": "anbauen",
    "anbauet": "anbauen",
    "anbaufähige": "anbaufähig",
    "anbaufähigem": "anbaufähig",
    "anbaufähigen": "anbaufähig",
    "anbaufähiger": "anbaufähig",
    "anbaufähigere": "anbaufähig",
    "anbaufähigerem": "anbaufähig",
    "anbaufähigeren": "anbaufähig",
    "anbaufähigerer": "anbaufähig",
    "anbaufähigeres": "anbaufähig",
    "anbaufähiges": "anbaufähig",
    "anbaufähigste": "anbaufähig",
    "anbaufähigstem": "anbaufähig",
    "anbaufähigsten": "anbaufähig",
    "anbaufähigster": "anbaufähig",
    "anbaufähigstes": "anbaufähig",
    "anbaust": "anbauen",
    "anbaut": "anbauen",
    "anbaute": "anbauen",
    "anbautest": "anbauen",
    "anbautet": "anbauen",
    "anbehalte": "anbehalten",
    "anbehaltend": "anbehalten",
    "anbehaltende": "anbehaltend",
    "anbehaltendem": "anbehaltend",
    "anbehaltenden": "anbehaltend",
    "anbehaltender": "anbehaltend",
    "anbehaltendes": "anbehaltend",
    "anbehaltene": "anbehalten",
    "anbehaltenem": "anbehalten",
    "anbehaltenen": "anbehalten",
    "anbehaltener": "anbehalten",
    "anbehaltenes": "anbehalten",
    "anbehaltest": "anbehalten",
    "anbehaltet": "anbehalten",
    "anbehielt": "anbehalten",
    "anbehielte": "anbehalten",
    "anbehielten": "anbehalten",
    "anbehieltest": "anbehalten",
    "anbehieltet": "anbehalten",
    "anbehält": "anbehalten",
    "anbehältst": "anbehalten",
    "anbeiße": "anbeißen",
    "anbeißend": "anbeißen",
    "anbeißende": "anbeißend",
    "anbeißendem": "anbeißend",
    "anbeißenden": "anbeißend",
    "anbeißender": "anbeißend",
    "anbeißendes": "anbeißend",
    "anbeißest": "anbeißen",
    "anbeißet": "anbeißen",
    "anbeißt": "anbeißen",
    "anbelange": "anbelangen",
    "anbelangend": "anbelangen",
    "anbelangende": "anbelangend",
    "anbelangendem": "anbelangend",
    "anbelangenden": "anbelangend",
    "anbelangender": "anbelangend",
    "anbelangendes": "anbelangend",
    "anbelangest": "anbelangen",
    "anbelanget": "anbelangen",
    "anbelangst": "anbelangen",
    "anbelangt": "anbelangen",
    "anbelangte": "anbelangen",
    "anbelangtem": "anbelangt",
    "anbelangten": "anbelangen",
    "anbelangter": "anbelangt",
    "anbelangtes": "anbelangt",
    "anbelangtest": "anbelangen",
    "anbelangtet": "anbelangen",
    "anbequeme": "anbequemen",
    "anbequemend": "anbequemen",
    "anbequemende": "anbequemend",
    "anbequemendem": "anbequemend",
    "anbequemenden": "anbequemend",
    "anbequemender": "anbequemend",
    "anbequemendes": "anbequemend",
    "anbequemest": "anbequemen",
    "anbequemet": "anbequemen",
    "anbequemst": "anbequemen",
    "anbequemt": "anbequemen",
    "anbequemte": "anbequemen",
    "anbequemtem": "anbequemt",
    "anbequemten": "anbequemen",
    "anbequemter": "anbequemt",
    "anbequemtes": "anbequemt",
    "anbequemtest": "anbequemen",
    "anbequemtet": "anbequemen",
    "anberaume": "anberaumen",
    "anberaumend": "anberaumen",
    "anberaumende": "anberaumend",
    "anberaumendem": "anberaumend",
    "anberaumenden": "anberaumend",
    "anberaumender": "anberaumend",
    "anberaumendes": "anberaumend",
    "anberaumest": "anberaumen",
    "anberaumet": "anberaumen",
    "anberaumst": "anberaumen",
    "anberaumt": "anberaumen",
    "anberaumte": "anberaumen",
    "anberaumtem": "anberaumt",
    "anberaumten": "anberaumen",
    "anberaumter": "anberaumt",
    "anberaumtes": "anberaumt",
    "anberaumtest": "anberaumen",
    "anberaumtet": "anberaumen",
    "anbete": "anbeten",
    "anbetend": "anbeten",
    "anbetende": "anbetend",
    "anbetendem": "anbetend",
    "anbetenden": "anbetend",
    "anbetender": "anbetend",
    "anbetendes": "anbetend",
    "anbetest": "anbeten",
    "anbetet": "anbeten",
    "anbetete": "anbeten",
    "anbeteten": "anbeten",
    "anbetetest": "anbeten",
    "anbetetet": "anbeten",
    "anbetraf": "anbetreffen",
    "anbetrafen": "anbetreffen",
    "anbetrafst": "anbetreffen",
    "anbetraft": "anbetreffen",
    "anbetreffe": "anbetreffen",
    "anbetreffend": "anbetreffen",
    "anbetreffende": "anbetreffend",
    "anbetreffendem": "anbetreffend",
    "anbetreffenden": "anbetreffend",
    "anbetreffender": "anbetreffend",
    "anbetreffendes": "anbetreffend",
    "anbetreffest": "anbetreffen",
    "anbetreffet": "anbetreffen",
    "anbetrefft": "anbetreffen",
    "anbetriffst": "anbetreffen",
    "anbetrifft": "anbetreffen",
    "anbetroffen": "anbetreffen",
    "anbetroffene": "anbetroffen",
    "anbetroffenem": "anbetroffen",
    "anbetroffenen": "anbetroffen",
    "anbetroffener": "anbetroffen",
    "anbetroffenes": "anbetroffen",
    "anbeträfe": "anbetreffen",
    "anbeträfen": "anbetreffen",
    "anbeträfest": "anbetreffen",
    "anbeträfet": "anbetreffen",
    "anbettele": "anbetteln",
    "anbettelnd": "anbetteln",
    "anbettelnde": "anbettelnd",
    "anbettelndem": "anbettelnd",
    "anbettelnden": "anbettelnd",
    "anbettelnder": "anbettelnd",
    "anbettelndere": "anbettelnd",
    "anbettelnderem": "anbettelnd",
    "anbettelnderen": "anbettelnd",
    "anbettelnderer": "anbettelnd",
    "anbettelnderes": "anbettelnd",
    "anbettelndes": "anbettelnd",
    "anbettelndste": "anbettelnd",
    "anbettelndstem": "anbettelnd",
    "anbettelndsten": "anbettelnd",
    "anbettelndster": "anbettelnd",
    "anbettelndstes": "anbettelnd",
    "anbettelst": "anbetteln",
    "anbettelt": "anbetteln",
    "anbettelte": "anbetteln",
    "anbettelten": "anbetteln",
    "anbetteltest": "anbetteln",
    "anbetteltet": "anbetteln",
    "anbettle": "anbetteln",
    "anbiedere": "anbiedern",
    "anbiedernd": "anbiedern",
    "anbiedernde": "anbiedernd",
    "anbiederndem": "anbiedernd",
    "anbiedernden": "anbiedernd",
    "anbiedernder": "anbiedernd",
    "anbiederndere": "anbiedernd",
    "anbiedernderem": "anbiedernd",
    "anbiedernderen": "anbiedernd",
    "anbiedernderer": "anbiedernd",
    "anbiedernderes": "anbiedernd",
    "anbiederndes": "anbiedernd",
    "anbiederndste": "anbiedernd",
    "anbiederndstem": "anbiedernd",
    "anbiederndsten": "anbiedernd",
    "anbiederndster": "anbiedernd",
    "anbiederndstes": "anbiedernd",
    "anbiederst": "anbiedern",
    "anbiedert": "anbiedern",
    "anbiederte": "anbiedern",
    "anbiederten": "anbiedern",
    "anbiedertest": "anbiedern",
    "anbiedertet": "anbiedern",
    "anbiete": "anbieten",
    "anbietend": "anbieten",
    "anbietende": "anbietend",
    "anbietendem": "anbietend",
    "anbietenden": "anbietend",
    "anbietender": "anbietend",
    "anbietendes": "anbietend",
    "anbietest": "anbieten",
    "anbietet": "anbieten",
    "anbinde": "anbinden",
    "anbindend": "anbinden",
    "anbindende": "anbindend",
    "anbindendem": "anbindend",
    "anbindenden": "anbindend",
    "anbindender": "anbindend",
    "anbindendes": "anbindend",
    "anbindest": "anbinden",
    "anbindet": "anbinden",
    "anbisse": "anbeißen",
    "anbissen": "anbeißen",
    "anbissest": "anbeißen",
    "anbisset": "anbeißen",
    "anbiß": "anbeißen",
    "anbißt": "anbeißen",
    "anblaffe": "anblaffen",
    "anblaffend": "anblaffen",
    "anblaffende": "anblaffend",
    "anblaffendem": "anblaffend",
    "anblaffenden": "anblaffend",
    "anblaffender": "anblaffend",
    "anblaffendere": "anblaffend",
    "anblaffenderem": "anblaffend",
    "anblaffenderen": "anblaffend",
    "anblaffenderer": "anblaffend",
    "anblaffenderes": "anblaffend",
    "anblaffendes": "anblaffend",
    "anblaffendste": "anblaffend",
    "anblaffendstem": "anblaffend",
    "anblaffendsten": "anblaffend",
    "anblaffendster": "anblaffend",
    "anblaffendstes": "anblaffend",
    "anblaffest": "anblaffen",
    "anblaffet": "anblaffen",
    "anblaffst": "anblaffen",
    "anblafft": "anblaffen",
    "anblaffte": "anblaffen",
    "anblafften": "anblaffen",
    "anblafftest": "anblaffen",
    "anblafftet": "anblaffen",
    "anblase": "anblasen",
    "anblasend": "anblasen",
    "anblasende": "anblasend",
    "anblasendem": "anblasend",
    "anblasenden": "anblasend",
    "anblasender": "anblasend",
    "anblasendes": "anblasend",
    "anblasest": "anblasen",
    "anblaset": "anblasen",
    "anblast": "anblasen",
    "anblickend": "anblicken",
    "anblickende": "anblickend",
    "anblickendem": "anblickend",
    "anblickenden": "anblickend",
    "anblickender": "anblickend",
    "anblickendes": "anblickend",
    "anblickest": "anblicken",
    "anblicket": "anblicken",
    "anblickst": "anblicken",
    "anblickt": "anblicken",
    "anblickte": "anblicken",
    "anblickten": "anblicken",
    "anblicktest": "anblicken",
    "anblicktet": "anblicken",
    "anblies": "anblasen",
    "anbliese": "anblasen",
    "anbliesen": "anblasen",
    "anbliesest": "anblasen",
    "anblieset": "anblasen",
    "anbliest": "anblasen",
    "anblinzele": "anblinzeln",
    "anblinzelnd": "anblinzeln",
    "anblinzelnde": "anblinzelnd",
    "anblinzelndem": "anblinzelnd",
    "anblinzelnden": "anblinzelnd",
    "anblinzelnder": "anblinzelnd",
    "anblinzelndes": "anblinzelnd",
    "anblinzelst": "anblinzeln",
    "anblinzelt": "anblinzeln",
    "anblinzelte": "anblinzeln",
    "anblinzelten": "anblinzeln",
    "anblinzeltest": "anblinzeln",
    "anblinzeltet": "anblinzeln",
    "anblinzle": "anblinzeln",
    "anblitze": "anblitzen",
    "anblitzend": "anblitzen",
    "anblitzende": "anblitzend",
    "anblitzendem": "anblitzend",
    "anblitzenden": "anblitzend",
    "anblitzender": "anblitzend",
    "anblitzendes": "anblitzend",
    "anblitzest": "anblitzen",
    "anblitzet": "anblitzen",
    "anblitzt": "anblitzen",
    "anblitzte": "anblitzen",
    "anblitzten": "anblitzen",
    "anblitztest": "anblitzen",
    "anblitztet": "anblitzen",
    "anbläst": "anblasen",
    "anbohre": "anbohren",
    "anbohrend": "anbohren",
    "anbohrende": "anbohrend",
    "anbohrendem": "anbohrend",
    "anbohrenden": "anbohrend",
    "anbohrender": "anbohrend",
    "anbohrendes": "anbohrend",
    "anbohrest": "anbohren",
    "anbohret": "anbohren",
    "anbohrst": "anbohren",
    "anbohrt": "anbohren",
    "anbohrte": "anbohren",
    "anbohrten": "anbohren",
    "anbohrtest": "anbohren",
    "anbohrtet": "anbohren",
    "anbot": "anbieten",
    "anboten": "anbieten",
    "anbotest": "anbieten",
    "anbotet": "anbieten",
    "anbrach": "anbrechen",
    "anbrachen": "anbrechen",
    "anbrachst": "anbrechen",
    "anbracht": "anbrechen",
    "anbrachte": "anbringen",
    "anbrachten": "anbringen",
    "anbrachtest": "anbringen",
    "anbrachtet": "anbringen",
    "anbrannte": "anbrennen",
    "anbrannten": "anbrennen",
    "anbranntest": "anbrennen",
    "anbranntet": "anbrennen",
    "anbrate": "anbraten",
    "anbratend": "anbraten",
    "anbratende": "anbratend",
    "anbratendem": "anbratend",
    "anbratenden": "anbratend",
    "anbratender": "anbratend",
    "anbratendes": "anbratend",
    "anbratest": "anbraten",
    "anbratet": "anbraten",
    "anbreche": "anbrechen",
    "anbrechend": "anbrechen",
    "anbrechende": "anbrechend",
    "anbrechendem": "anbrechend",
    "anbrechenden": "anbrechend",
    "anbrechender": "anbrechend",
    "anbrechendes": "anbrechend",
    "anbrechest": "anbrechen",
    "anbrechet": "anbrechen",
    "anbrecht": "anbrechen",
    "anbremse": "anbremsen",
    "anbremsend": "anbremsen",
    "anbremsende": "anbremsend",
    "anbremsendem": "anbremsend",
    "anbremsenden": "anbremsend",
    "anbremsender": "anbremsend",
    "anbremsendes": "anbremsend",
    "anbremsest": "anbremsen",
    "anbremset": "anbremsen",
    "anbremst": "anbremsen",
    "anbremste": "anbremsen",
    "anbremsten": "anbremsen",
    "anbremstest": "anbremsen",
    "anbremstet": "anbremsen",
    "anbrenne": "anbrennen",
    "anbrennend": "anbrennen",
    "anbrennende": "anbrennend",
    "anbrennendem": "anbrennend",
    "anbrennenden": "anbrennend",
    "anbrennender": "anbrennend",
    "anbrennendere": "anbrennend",
    "anbrennenderem": "anbrennend",
    "anbrennenderen": "anbrennend",
    "anbrennenderer": "anbrennend",
    "anbrennenderes": "anbrennend",
    "anbrennendes": "anbrennend",
    "anbrennendste": "anbrennend",
    "anbrennendstem": "anbrennend",
    "anbrennendsten": "anbrennend",
    "anbrennendster": "anbrennend",
    "anbrennendstes": "anbrennend",
    "anbrennest": "anbrennen",
    "anbrennet": "anbrennen",
    "anbrennst": "anbrennen",
    "anbrennt": "anbrennen",
    "anbrichst": "anbrechen",
    "anbricht": "anbrechen",
    "anbriet": "anbraten",
    "anbriete": "anbraten",
    "anbrieten": "anbraten",
    "anbrietest": "anbraten",
    "anbrietet": "anbraten",
    "anbringe": "anbringen",
    "anbringend": "anbringen",
    "anbringende": "anbringend",
    "anbringendem": "anbringend",
    "anbringenden": "anbringend",
    "anbringender": "anbringend",
    "anbringendes": "anbringend",
    "anbringest": "anbringen",
    "anbringet": "anbringen",
    "anbringst": "anbringen",
    "anbringt": "anbringen",
    "anbrumme": "anbrummen",
    "anbrummend": "anbrummen",
    "anbrummende": "anbrummend",
    "anbrummendem": "anbrummend",
    "anbrummenden": "anbrummend",
    "anbrummender": "anbrummend",
    "anbrummendes": "anbrummend",
    "anbrummest": "anbrummen",
    "anbrummet": "anbrummen",
    "anbrummst": "anbrummen",
    "anbrummt": "anbrummen",
    "anbrummte": "anbrummen",
    "anbrummten": "anbrummen",
    "anbrummtest": "anbrummen",
    "anbrummtet": "anbrummen",
    "anbräche": "anbrechen",
    "anbrächen": "anbrechen",
    "anbrächest": "anbrechen",
    "anbrächet": "anbrechen",
    "anbrächte": "anbringen",
    "anbrächten": "anbringen",
    "anbrächtest": "anbringen",
    "anbrächtet": "anbringen",
    "anbrät": "anbraten",
    "anbrätst": "anbraten",
    "anbrülle": "anbrüllen",
    "anbrüllend": "anbrüllen",
    "anbrüllende": "anbrüllend",
    "anbrüllendem": "anbrüllend",
    "anbrüllenden": "anbrüllend",
    "anbrüllender": "anbrüllend",
    "anbrüllendes": "anbrüllend",
    "anbrüllest": "anbrüllen",
    "anbrüllet": "anbrüllen",
    "anbrüllst": "anbrüllen",
    "anbrüllt": "anbrüllen",
    "anbrüllte": "anbrüllen",
    "anbrüllten": "anbrüllen",
    "anbrülltest": "anbrüllen",
    "anbrülltet": "anbrüllen",
    "anbrüte": "anbrüten",
    "anbrütend": "anbrüten",
    "anbrütende": "anbrütend",
    "anbrütendem": "anbrütend",
    "anbrütenden": "anbrütend",
    "anbrütender": "anbrütend",
    "anbrütendes": "anbrütend",
    "anbrütest": "anbrüten",
    "anbrütet": "anbrüten",
    "anbrütete": "anbrüten",
    "anbrüteten": "anbrüten",
    "anbrütetest": "anbrüten",
    "anbrütetet": "anbrüten",
    "anbände": "anbinden",
    "anbänden": "anbinden",
    "anbändest": "anbinden",
    "anbändet": "anbinden",
    "anböte": "anbieten",
    "anböten": "anbieten",
    "anbötest": "anbieten",
    "anbötet": "anbieten",
    "andachte": "andenken",
    "andachtest": "andenken",
    "andachtet": "andenken",
    "andauere": "andauern",
    "andauernd": "andauern",
    "andauernde": "andauernd",
    "andauerndem": "andauernd",
    "andauernden": "andauernd",
    "andauernder": "andauernd",
    "andauerndes": "andauernd",
    "andauerst": "andauern",
    "andauert": "andauern",
    "andauerte": "andauern",
    "andauerten": "andauern",
    "andauertest": "andauern",
    "andauertet": "andauern",
    "andenke": "andenken",
    "andenkend": "andenken",
    "andenkende": "andenkend",
    "andenkendem": "andenkend",
    "andenkenden": "andenkend",
    "andenkender": "andenkend",
    "andenkendes": "andenkend",
    "andenkest": "andenken",
    "andenket": "andenken",
    "andenkst": "andenken",
    "andenkt": "andenken",
    "andere": "ander",
    "anderem": "ander",
    "anderen": "ander",
    "anderer": "ander",
    "anderes": "ander",
    "andersartige": "andersartig",
    "andersartigem": "andersartig",
    "andersartigen": "andersartig",
    "andersartiger": "andersartig",
    "andersartiges": "andersartig",
    "andersgeartete": "andersgeartet",
    "andersgeartetem": "andersgeartet",
    "andersgearteten": "andersgeartet",
    "andersgearteter": "andersgeartet",
    "andersgeartetes": "andersgeartet",
    "andersgläubige": "andersgläubig",
    "andersgläubigem": "andersgläubig",
    "andersgläubigen": "andersgläubig",
    "andersgläubiger": "andersgläubig",
    "andersgläubiges": "andersgläubig",
    "anderssprachige": "anderssprachig",
    "anderssprachigem": "anderssprachig",
    "anderssprachigen": "anderssprachig",
    "anderssprachiger": "anderssprachig",
    "anderssprachiges": "anderssprachig",
    "anderweitige": "anderweitig",
    "anderweitigem": "anderweitig",
    "anderweitigen": "anderweitig",
    "anderweitiger": "anderweitig",
    "anderweitiges": "anderweitig",
    "andeute": "andeuten",
    "andeutend": "andeuten",
    "andeutende": "andeutend",
    "andeutendem": "andeutend",
    "andeutenden": "andeutend",
    "andeutender": "andeutend",
    "andeutendes": "andeutend",
    "andeutest": "andeuten",
    "andeutet": "andeuten",
    "andeutete": "andeuten",
    "andeuteten": "andeuten",
    "andeutetest": "andeuten",
    "andeutetet": "andeuten",
    "andichte": "andichten",
    "andichtend": "andichten",
    "andichtende": "andichtend",
    "andichtendem": "andichtend",
    "andichtenden": "andichtend",
    "andichtender": "andichtend",
    "andichtendes": "andichtend",
    "andichtest": "andichten",
    "andichtet": "andichten",
    "andichtete": "andichten",
    "andichteten": "andichten",
    "andichtetest": "andichten",
    "andichtetet": "andichten",
    "andiene": "andienen",
    "andienend": "andienen",
    "andienende": "andienend",
    "andienendem": "andienend",
    "andienenden": "andienend",
    "andienender": "andienend",
    "andienendes": "andienend",
    "andienest": "andienen",
    "andienet": "andienen",
    "andienst": "andienen",
    "andient": "andienen",
    "andiente": "andienen",
    "andienten": "andienen",
    "andientest": "andienen",
    "andientet": "andienen",
    "andiskutiere": "andiskutieren",
    "andiskutierend": "andiskutieren",
    "andiskutierende": "andiskutierend",
    "andiskutierendem": "andiskutierend",
    "andiskutierenden": "andiskutierend",
    "andiskutierender": "andiskutierend",
    "andiskutierendes": "andiskutierend",
    "andiskutierest": "andiskutieren",
    "andiskutieret": "andiskutieren",
    "andiskutierst": "andiskutieren",
    "andiskutiert": "andiskutieren",
    "andiskutierte": "andiskutieren",
    "andiskutiertem": "andiskutiert",
    "andiskutierten": "andiskutieren",
    "andiskutierter": "andiskutiert",
    "andiskutiertes": "andiskutiert",
    "andiskutiertest": "andiskutieren",
    "andiskutiertet": "andiskutieren",
    "andrang": "andringen",
    "andrangen": "andringen",
    "andrangst": "andringen",
    "andrangt": "andringen",
    "andrehe": "andrehen",
    "andrehend": "andrehen",
    "andrehende": "andrehend",
    "andrehendem": "andrehend",
    "andrehenden": "andrehend",
    "andrehender": "andrehend",
    "andrehendes": "andrehend",
    "andrehest": "andrehen",
    "andrehet": "andrehen",
    "andrehst": "andrehen",
    "andreht": "andrehen",
    "andrehte": "andrehen",
    "andrehten": "andrehen",
    "andrehtest": "andrehen",
    "andrehtet": "andrehen",
    "andringe": "andringen",
    "andringend": "andringen",
    "andringende": "andringend",
    "andringendem": "andringend",
    "andringenden": "andringend",
    "andringender": "andringend",
    "andringendes": "andringend",
    "andringest": "andringen",
    "andringet": "andringen",
    "andringst": "andringen",
    "andringt": "andringen",
    "androhe": "androhen",
    "androhend": "androhen",
    "androhende": "androhend",
    "androhendem": "androhend",
    "androhenden": "androhend",
    "androhender": "androhend",
    "androhendes": "androhend",
    "androhest": "androhen",
    "androhet": "androhen",
    "androhst": "androhen",
    "androht": "androhen",
    "androhte": "androhen",
    "androhten": "androhen",
    "androhtest": "androhen",
    "androhtet": "androhen",
    "andränge": "andringen",
    "andrängend": "andrängen",
    "andrängende": "andrängend",
    "andrängendem": "andrängend",
    "andrängenden": "andrängend",
    "andrängender": "andrängend",
    "andrängendes": "andrängend",
    "andrängest": "andringen",
    "andränget": "andringen",
    "andrängst": "andrängen",
    "andrängt": "andrängen",
    "andrängte": "andrängen",
    "andrängten": "andrängen",
    "andrängtest": "andrängen",
    "andrängtet": "andrängen",
    "andächte": "andenken",
    "andächten": "andenken",
    "andächtest": "andenken",
    "andächtet": "andenken",
    "andächtige": "andächtig",
    "andächtigem": "andächtig",
    "andächtigen": "andächtig",
    "andächtiger": "andächtig",
    "andächtigere": "andächtig",
    "andächtigerem": "andächtig",
    "andächtigeren": "andächtig",
    "andächtigerer": "andächtig",
    "andächtigeres": "andächtig",
    "andächtiges": "andächtig",
    "andächtigste": "andächtig",
    "andächtigstem": "andächtig",
    "andächtigsten": "andächtig",
    "andächtigster": "andächtig",
    "andächtigstes": "andächtig",
    "aneigne": "aneignen",
    "aneignend": "aneignen",
    "aneignende": "aneignend",
    "aneignendem": "aneignend",
    "aneignenden": "aneignend",
    "aneignender": "aneignend",
    "aneignendes": "aneignend",
    "aneignest": "aneignen",
    "aneignet": "aneignen",
    "aneignete": "aneignen",
    "aneigneten": "aneignen",
    "aneignetest": "aneignen",
    "aneignetet": "aneignen",
    "aneinanderfüge": "aneinanderfügen",
    "aneinanderfügend": "aneinanderfügen",
    "aneinanderfügende": "aneinanderfügend",
    "aneinanderfügendem": "aneinanderfügend",
    "aneinanderfügenden": "aneinanderfügend",
    "aneinanderfügender": "aneinanderfügend",
    "aneinanderfügendes": "aneinanderfügend",
    "aneinanderfügest": "aneinanderfügen",
    "aneinanderfüget": "aneinanderfügen",
    "aneinanderfügst": "aneinanderfügen",
    "aneinanderfügt": "aneinanderfügen",
    "aneinanderfügte": "aneinanderfügen",
    "aneinanderfügten": "aneinanderfügen",
    "aneinanderfügtest": "aneinanderfügen",
    "aneinanderfügtet": "aneinanderfügen",
    "aneinandergefügt": "aneinandergefügen",
    "aneinandergefügte": "aneinandergefügen",
    "aneinandergefügtem": "aneinandergefügt",
    "aneinandergefügten": "aneinandergefügen",
    "aneinandergefügter": "aneinandergefügt",
    "aneinandergefügtes": "aneinandergefügt",
    "aneinandergegrenzt": "aneinandergrenzen",
    "aneinandergegrenzte": "aneinandergegrenz",
    "aneinandergegrenztem": "aneinandergegrenzt",
    "aneinandergegrenzten": "aneinandergegrenz",
    "aneinandergegrenzter": "aneinandergegrenzt",
    "aneinandergegrenztes": "aneinandergegrenzt",
    "aneinandergehangen": "aneinanderhängen",
    "aneinandergehangene": "aneinandergehangen",
    "aneinandergehangenem": "aneinandergehangen",
    "aneinandergehangenen": "aneinandergehangen",
    "aneinandergehangener": "aneinandergehangen",
    "aneinandergehangenes": "aneinandergehangen",
    "aneinandergehängt": "aneinanderhängen",
    "aneinandergehängte": "aneinandergehänge",
    "aneinandergehängtem": "aneinandergehängt",
    "aneinandergehängten": "aneinandergehänge",
    "aneinandergehängter": "aneinandergehängt",
    "aneinandergehängtes": "aneinandergehängt",
    "aneinandergerate": "aneinandergeraten",
    "aneinandergeratend": "aneinandergeraten",
    "aneinandergeratende": "aneinandergeratend",
    "aneinandergeratendem": "aneinandergeratend",
    "aneinandergeratenden": "aneinandergeratend",
    "aneinandergeratender": "aneinandergeratend",
    "aneinandergeratendes": "aneinandergeratend",
    "aneinandergeratene": "aneinandergeraten",
    "aneinandergeratenem": "aneinandergeraten",
    "aneinandergeratenen": "aneinandergeraten",
    "aneinandergeratener": "aneinandergeraten",
    "aneinandergeratenes": "aneinandergeraten",
    "aneinandergeratest": "aneinandergeraten",
    "aneinandergeratet": "aneinandergeraten",
    "aneinandergeriet": "aneinandergeraten",
    "aneinandergeriete": "aneinandergeraten",
    "aneinandergerieten": "aneinandergeraten",
    "aneinandergerietest": "aneinandergeraten",
    "aneinandergerietet": "aneinandergeraten",
    "aneinandergerät": "aneinandergeraten",
    "aneinandergerätst": "aneinandergeraten",
    "aneinandergrenze": "aneinandergrenzen",
    "aneinandergrenzend": "aneinandergrenzen",
    "aneinandergrenzende": "aneinandergrenzend",
    "aneinandergrenzendem": "aneinandergrenzend",
    "aneinandergrenzenden": "aneinandergrenzend",
    "aneinandergrenzender": "aneinandergrenzend",
    "aneinandergrenzendes": "aneinandergrenzend",
    "aneinandergrenzest": "aneinandergrenzen",
    "aneinandergrenzet": "aneinandergrenzen",
    "aneinandergrenzt": "aneinandergrenzen",
    "aneinandergrenzte": "aneinandergrenzen",
    "aneinandergrenzten": "aneinandergrenzen",
    "aneinandergrenztest": "aneinandergrenzen",
    "aneinandergrenztet": "aneinandergrenzen",
    "aneinanderhing": "aneinanderhängen",
    "aneinanderhinge": "aneinanderhängen",
    "aneinanderhingen": "aneinanderhängen",
    "aneinanderhingest": "aneinanderhängen",
    "aneinanderhinget": "aneinanderhängen",
    "aneinanderhingst": "aneinanderhängen",
    "aneinanderhingt": "aneinanderhängen",
    "aneinanderhänge": "aneinanderhängen",
    "aneinanderhängend": "aneinanderhängen",
    "aneinanderhängende": "aneinanderhängend",
    "aneinanderhängendem": "aneinanderhängend",
    "aneinanderhängenden": "aneinanderhängend",
    "aneinanderhängender": "aneinanderhängend",
    "aneinanderhängendere": "aneinanderhängend",
    "aneinanderhängenderem": "aneinanderhängend",
    "aneinanderhängenderen": "aneinanderhängend",
    "aneinanderhängenderer": "aneinanderhängend",
    "aneinanderhängenderes": "aneinanderhängend",
    "aneinanderhängendes": "aneinanderhängend",
    "aneinanderhängendste": "aneinanderhängend",
    "aneinanderhängendstem": "aneinanderhängend",
    "aneinanderhängendsten": "aneinanderhängend",
    "aneinanderhängendster": "aneinanderhängend",
    "aneinanderhängendstes": "aneinanderhängend",
    "aneinanderhängest": "aneinanderhängen",
    "aneinanderhänget": "aneinanderhängen",
    "aneinanderhängst": "aneinanderhängen",
    "aneinanderhängt": "aneinanderhängen",
    "aneinanderhängte": "aneinanderhängen",
    "aneinanderhängten": "aneinanderhängen",
    "aneinanderhängtest": "aneinanderhängen",
    "aneinanderhängtet": "aneinanderhängen",
    "aneinanderzufügen": "aneinanderfügen",
    "aneinanderzugeraten": "aneinanderzugerat",
    "aneinanderzugrenzen": "aneinanderzugrenz",
    "aneinanderzuhängen": "aneinanderzuhänge",
    "anekele": "anekeln",
    "anekelnd": "anekeln",
    "anekelnde": "anekelnd",
    "anekelndem": "anekelnd",
    "anekelnden": "anekelnd",
    "anekelnder": "anekelnd",
    "anekelndere": "anekelnd",
    "anekelnderem": "anekelnd",
    "anekelnderen": "anekelnd",
    "anekelnderer": "anekelnd",
    "anekelnderes": "anekelnd",
    "anekelndes": "anekelnd",
    "anekelndste": "anekelnd",
    "anekelndstem": "anekelnd",
    "anekelndsten": "anekelnd",
    "anekelndster": "anekelnd",
    "anekelndstes": "anekelnd",
    "anekelst": "anekeln",
    "anekelt": "anekeln",
    "anekelte": "anekeln",
    "anekelten": "anekeln",
    "anekeltest": "anekeln",
    "anekeltet": "anekeln",
    "anekle": "anekeln",
    "anerkannt": "anerkennen",
    "anerkannte": "anerkannt",
    "anerkanntem": "anerkannt",
    "anerkannten": "anerkannt",
    "anerkannter": "anerkannt",
    "anerkanntere": "anerkannt",
    "anerkannterem": "anerkannt",
    "anerkannteren": "anerkannt",
    "anerkannterer": "anerkannt",
    "anerkannteres": "anerkannt",
    "anerkanntes": "anerkannt",
    "anerkanntest": "anerkennen",
    "anerkannteste": "anerkannt",
    "anerkanntestem": "anerkannt",
    "anerkanntesten": "anerkannt",
    "anerkanntester": "anerkannt",
    "anerkanntestes": "anerkannt",
    "anerkanntet": "anerkennen",
    "anerkenne": "anerkennen",
    "anerkennend": "anerkennen",
    "anerkennende": "anerkennend",
    "anerkennendem": "anerkennend",
    "anerkennenden": "anerkennend",
    "anerkennender": "anerkennend",
    "anerkennendere": "anerkennend",
    "anerkennenderem": "anerkennend",
    "anerkennenderen": "anerkennend",
    "anerkennenderer": "anerkennend",
    "anerkennenderes": "anerkennend",
    "anerkennendes": "anerkennend",
    "anerkennendste": "anerkennend",
    "anerkennendstem": "anerkennend",
    "anerkennendsten": "anerkennend",
    "anerkennendster": "anerkennend",
    "anerkennendstes": "anerkennend",
    "anerkennenswertem": "anerkennenswert",
    "anerkennenswerten": "anerkennenswert",
    "anerkennenswerter": "anerkennenswert",
    "anerkennenswertere": "anerkennenswert",
    "anerkennenswerterem": "anerkennenswert",
    "anerkennenswerteren": "anerkennenswert",
    "anerkennenswerterer": "anerkennenswert",
    "anerkennenswerteres": "anerkennenswert",
    "anerkennenswertes": "anerkennenswert",
    "anerkennenswerteste": "anerkennenswert",
    "anerkennenswertestem": "anerkennenswert",
    "anerkennenswertesten": "anerkennenswert",
    "anerkennenswertester": "anerkennenswert",
    "anerkennenswertestes": "anerkennenswert",
    "anerkennest": "anerkennen",
    "anerkennet": "anerkennen",
    "anerkennst": "anerkennen",
    "anerkennt": "anerkennen",
    "anerziehe": "anerziehen",
    "anerziehend": "anerziehen",
    "anerziehende": "anerziehend",
    "anerziehendem": "anerziehend",
    "anerziehenden": "anerziehend",
    "anerziehender": "anerziehend",
    "anerziehendes": "anerziehend",
    "anerziehest": "anerziehen",
    "anerziehet": "anerziehen",
    "anerziehst": "anerziehen",
    "anerzieht": "anerziehen",
    "anerzog": "anerziehen",
    "anerzogen": "anerziehen",
    "anerzogene": "anerzogen",
    "anerzogenem": "anerzogen",
    "anerzogenen": "anerzogen",
    "anerzogener": "anerzogen",
    "anerzogenes": "anerzogen",
    "anerzogst": "anerziehen",
    "anerzogt": "anerziehen",
    "anerzöge": "anerziehen",
    "anerzögen": "anerziehen",
    "anerzögest": "anerziehen",
    "anerzöget": "anerziehen",
    "anfache": "anfachen",
    "anfachend": "anfachen",
    "anfachende": "anfachend",
    "anfachendem": "anfachend",
    "anfachenden": "anfachend",
    "anfachender": "anfachend",
    "anfachendes": "anfachend",
    "anfachest": "anfachen",
    "anfachet": "anfachen",
    "anfachst": "anfachen",
    "anfacht": "anfachen",
    "anfachte": "anfachen",
    "anfachten": "anfachen",
    "anfachtest": "anfachen",
    "anfachtet": "anfachen",
    "anfahre": "anfahren",
    "anfahrend": "anfahren",
    "anfahrende": "anfahrend",
    "anfahrendem": "anfahrend",
    "anfahrenden": "anfahrend",
    "anfahrender": "anfahrend",
    "anfahrendes": "anfahrend",
    "anfahrest": "anfahren",
    "anfahret": "anfahren",
    "anfahrt": "anfahren",
    "anfallend": "anfallen",
    "anfallende": "anfallend",
    "anfallendem": "anfallend",
    "anfallenden": "anfallend",
    "anfallender": "anfallend",
    "anfallendes": "anfallend",
    "anfallest": "anfallen",
    "anfallet": "anfallen",
    "anfallt": "anfallen",
    "anfand": "anfinden",
    "anfanden": "anfinden",
    "anfandest": "anfinden",
    "anfandet": "anfinden",
    "anfangend": "anfangen",
    "anfangende": "anfangend",
    "anfangendem": "anfangend",
    "anfangenden": "anfangend",
    "anfangender": "anfangend",
    "anfangendes": "anfangend",
    "anfangest": "anfangen",
    "anfanget": "anfangen",
    "anfangt": "anfangen",
    "anfasse": "anfassen",
    "anfassend": "anfassen",
    "anfassende": "anfassend",
    "anfassendem": "anfassend",
    "anfassenden": "anfassend",
    "anfassender": "anfassend",
    "anfassendes": "anfassend",
    "anfassest": "anfassen",
    "anfasset": "anfassen",
    "anfauche": "anfauchen",
    "anfauchend": "anfauchen",
    "anfauchende": "anfauchend",
    "anfauchendem": "anfauchend",
    "anfauchenden": "anfauchend",
    "anfauchender": "anfauchend",
    "anfauchendere": "anfauchend",
    "anfauchenderem": "anfauchend",
    "anfauchenderen": "anfauchend",
    "anfauchenderer": "anfauchend",
    "anfauchenderes": "anfauchend",
    "anfauchendes": "anfauchend",
    "anfauchendste": "anfauchend",
    "anfauchendstem": "anfauchend",
    "anfauchendsten": "anfauchend",
    "anfauchendster": "anfauchend",
    "anfauchendstes": "anfauchend",
    "anfauchest": "anfauchen",
    "anfauchet": "anfauchen",
    "anfauchst": "anfauchen",
    "anfaucht": "anfauchen",
    "anfauchte": "anfauchen",
    "anfauchten": "anfauchen",
    "anfauchtest": "anfauchen",
    "anfauchtet": "anfauchen",
    "anfaule": "anfaulen",
    "anfaulend": "anfaulen",
    "anfaulende": "anfaulend",
    "anfaulendem": "anfaulend",
    "anfaulenden": "anfaulend",
    "anfaulender": "anfaulend",
    "anfaulendere": "anfaulend",
    "anfaulenderem": "anfaulend",
    "anfaulenderen": "anfaulend",
    "anfaulenderer": "anfaulend",
    "anfaulenderes": "anfaulend",
    "anfaulendes": "anfaulend",
    "anfaulendste": "anfaulend",
    "anfaulendstem": "anfaulend",
    "anfaulendsten": "anfaulend",
    "anfaulendster": "anfaulend",
    "anfaulendstes": "anfaulend",
    "anfaulest": "anfaulen",
    "anfaulet": "anfaulen",
    "anfaulst": "anfaulen",
    "anfault": "anfaulen",
    "anfaulte": "anfaulen",
    "anfaulten": "anfaulen",
    "anfaultest": "anfaulen",
    "anfaultet": "anfaulen",
    "anfaxe": "anfaxen",
    "anfaxend": "anfaxen",
    "anfaxende": "anfaxend",
    "anfaxendem": "anfaxend",
    "anfaxenden": "anfaxend",
    "anfaxender": "anfaxend",
    "anfaxendes": "anfaxend",
    "anfaxest": "anfaxen",
    "anfaxet": "anfaxen",
    "anfaxt": "anfaxen",
    "anfaxte": "anfaxen",
    "anfaxten": "anfaxen",
    "anfaxtest": "anfaxen",
    "anfaxtet": "anfaxen",
    "anfaßt": "anfassen",
    "anfaßte": "anfassen",
    "anfaßten": "anfassen",
    "anfaßtest": "anfassen",
    "anfaßtet": "anfassen",
    "anfechtbare": "anfechtbar",
    "anfechtbarem": "anfechtbar",
    "anfechtbaren": "anfechtbar",
    "anfechtbarer": "anfechtbar",
    "anfechtbarere": "anfechtbar",
    "anfechtbarerem": "anfechtbar",
    "anfechtbareren": "anfechtbar",
    "anfechtbarerer": "anfechtbar",
    "anfechtbareres": "anfechtbar",
    "anfechtbares": "anfechtbar",
    "anfechtbarste": "anfechtbar",
    "anfechtbarstem": "anfechtbar",
    "anfechtbarsten": "anfechtbar",
    "anfechtbarster": "anfechtbar",
    "anfechtbarstes": "anfechtbar",
    "anfechte": "anfechten",
    "anfechtend": "anfechten",
    "anfechtende": "anfechtend",
    "anfechtendem": "anfechtend",
    "anfechtenden": "anfechtend",
    "anfechtender": "anfechtend",
    "anfechtendes": "anfechtend",
    "anfechtest": "anfechten",
    "anfechtet": "anfechten",
    "anfeinde": "anfeinden",
    "anfeindend": "anfeinden",
    "anfeindende": "anfeindend",
    "anfeindendem": "anfeindend",
    "anfeindenden": "anfeindend",
    "anfeindender": "anfeindend",
    "anfeindendere": "anfeindend",
    "anfeindenderem": "anfeindend",
    "anfeindenderen": "anfeindend",
    "anfeindenderer": "anfeindend",
    "anfeindenderes": "anfeindend",
    "anfeindendes": "anfeindend",
    "anfeindendste": "anfeindend",
    "anfeindendstem": "anfeindend",
    "anfeindendsten": "anfeindend",
    "anfeindendster": "anfeindend",
    "anfeindendstes": "anfeindend",
    "anfeindest": "anfeinden",
    "anfeindet": "anfeinden",
    "anfeindete": "anfeinden",
    "anfeindeten": "anfeinden",
    "anfeindetest": "anfeinden",
    "anfeindetet": "anfeinden",
    "anfertige": "anfertigen",
    "anfertigend": "anfertigen",
    "anfertigende": "anfertigend",
    "anfertigendem": "anfertigend",
    "anfertigenden": "anfertigend",
    "anfertigender": "anfertigend",
    "anfertigendes": "anfertigend",
    "anfertigest": "anfertigen",
    "anfertiget": "anfertigen",
    "anfertigst": "anfertigen",
    "anfertigt": "anfertigen",
    "anfertigte": "anfertigen",
    "anfertigten": "anfertigen",
    "anfertigtest": "anfertigen",
    "anfertigtet": "anfertigen",
    "anfeuchte": "anfeuchten",
    "anfeuchtend": "anfeuchten",
    "anfeuchtende": "anfeuchtend",
    "anfeuchtendem": "anfeuchtend",
    "anfeuchtenden": "anfeuchtend",
    "anfeuchtender": "anfeuchtend",
    "anfeuchtendere": "anfeuchtend",
    "anfeuchtenderem": "anfeuchtend",
    "anfeuchtenderen": "anfeuchtend",
    "anfeuchtenderer": "anfeuchtend",
    "anfeuchtenderes": "anfeuchtend",
    "anfeuchtendes": "anfeuchtend",
    "anfeuchtendste": "anfeuchtend",
    "anfeuchtendstem": "anfeuchtend",
    "anfeuchtendsten": "anfeuchtend",
    "anfeuchtendster": "anfeuchtend",
    "anfeuchtendstes": "anfeuchtend",
    "anfeuchtest": "anfeuchten",
    "anfeuchtet": "anfeuchten",
    "anfeuchtete": "anfeuchten",
    "anfeuchteten": "anfeuchten",
    "anfeuchtetest": "anfeuchten",
    "anfeuchtetet": "anfeuchten",
    "anfeuere": "anfeuern",
    "anfeuernd": "anfeuern",
    "anfeuernde": "anfeuernd",
    "anfeuerndem": "anfeuernd",
    "anfeuernden": "anfeuernd",
    "anfeuernder": "anfeuernd",
    "anfeuerndere": "anfeuernd",
    "anfeuernderem": "anfeuernd",
    "anfeuernderen": "anfeuernd",
    "anfeuernderer": "anfeuernd",
    "anfeuernderes": "anfeuernd",
    "anfeuerndes": "anfeuernd",
    "anfeuerndste": "anfeuernd",
    "anfeuerndstem": "anfeuernd",
    "anfeuerndsten": "anfeuernd",
    "anfeuerndster": "anfeuernd",
    "anfeuerndstes": "anfeuernd",
    "anfeuerst": "anfeuern",
    "anfeuert": "anfeuern",
    "anfeuerte": "anfeuern",
    "anfeuerten": "anfeuern",
    "anfeuertest": "anfeuern",
    "anfeuertet": "anfeuern",
    "anficht": "anfechten",
    "anfichtst": "anfechten",
    "anfiel": "anfallen",
    "anfiele": "anfallen",
    "anfielen": "anfallen",
    "anfielest": "anfallen",
    "anfielet": "anfallen",
    "anfielst": "anfallen",
    "anfielt": "anfallen",
    "anfinde": "anfinden",
    "anfindend": "anfinden",
    "anfindende": "anfindend",
    "anfindendem": "anfindend",
    "anfindenden": "anfindend",
    "anfindender": "anfindend",
    "anfindendes": "anfindend",
    "anfindest": "anfinden",
    "anfindet": "anfinden",
    "anfing": "anfangen",
    "anfinge": "anfangen",
    "anfingen": "anfangen",
    "anfingest": "anfangen",
    "anfinget": "anfangen",
    "anfingst": "anfangen",
    "anfingt": "anfangen",
    "anfixe": "anfixen",
    "anfixend": "anfixen",
    "anfixende": "anfixend",
    "anfixendem": "anfixend",
    "anfixenden": "anfixend",
    "anfixender": "anfixend",
    "anfixendes": "anfixend",
    "anfixest": "anfixen",
    "anfixet": "anfixen",
    "anfixt": "anfixen",
    "anfixte": "anfixen",
    "anfixten": "anfixen",
    "anfixtest": "anfixen",
    "anfixtet": "anfixen",
    "anflehe": "anflehen",
    "anflehend": "anflehen",
    "anflehende": "anflehend",
    "anflehendem": "anflehend",
    "anflehenden": "anflehend",
    "anflehender": "anflehend",
    "anflehendere": "anflehend",
    "anflehenderem": "anflehend",
    "anflehenderen": "anflehend",
    "anflehenderer": "anflehend",
    "anflehenderes": "anflehend",
    "anflehendes": "anflehend",
    "anflehendste": "anflehend",
    "anflehendstem": "anflehend",
    "anflehendsten": "anflehend",
    "anflehendster": "anflehend",
    "anflehendstes": "anflehend",
    "anflehest": "anflehen",
    "anflehet": "anflehen",
    "anflehst": "anflehen",
    "anfleht": "anflehen",
    "anflehte": "anflehen",
    "anflehten": "anflehen",
    "anflehtest": "anflehen",
    "anflehtet": "anflehen",
    "anfliege": "anfliegen",
    "anfliegend": "anfliegen",
    "anfliegende": "anfliegend",
    "anfliegendem": "anfliegend",
    "anfliegenden": "anfliegend",
    "anfliegender": "anfliegend",
    "anfliegendes": "anfliegend",
    "anfliegest": "anfliegen",
    "anflieget": "anfliegen",
    "anfliegst": "anfliegen",
    "anfliegt": "anfliegen",
    "anflog": "anfliegen",
    "anflogen": "anfliegen",
    "anflogst": "anfliegen",
    "anflogt": "anfliegen",
    "anflöge": "anfliegen",
    "anflögen": "anfliegen",
    "anflögest": "anfliegen",
    "anflöget": "anfliegen",
    "anfocht": "anfechten",
    "anfochten": "anfechten",
    "anfochtest": "anfechten",
    "anfochtet": "anfechten",
    "anfordere": "anfordern",
    "anfordernd": "anfordern",
    "anfordernde": "anfordernd",
    "anforderndem": "anfordernd",
    "anfordernden": "anfordernd",
    "anfordernder": "anfordernd",
    "anforderndes": "anfordernd",
    "anforderst": "anfordern",
    "anfordert": "anfordern",
    "anforderte": "anfordern",
    "anforderten": "anfordern",
    "anfordertest": "anfordern",
    "anfordertet": "anfordern",
    "anfragend": "anfragen",
    "anfragende": "anfragend",
    "anfragendem": "anfragend",
    "anfragenden": "anfragend",
    "anfragender": "anfragend",
    "anfragendes": "anfragend",
    "anfragest": "anfragen",
    "anfraget": "anfragen",
    "anfragst": "anfragen",
    "anfragt": "anfragen",
    "anfragte": "anfragen",
    "anfragten": "anfragen",
    "anfragtest": "anfragen",
    "anfragtet": "anfragen",
    "anfraß": "anfressen",
    "anfraßen": "anfressen",
    "anfraßt": "anfressen",
    "anfresse": "anfressen",
    "anfressend": "anfressen",
    "anfressende": "anfressend",
    "anfressendem": "anfressend",
    "anfressenden": "anfressend",
    "anfressender": "anfressend",
    "anfressendere": "anfressend",
    "anfressenderem": "anfressend",
    "anfressenderen": "anfressend",
    "anfressenderer": "anfressend",
    "anfressenderes": "anfressend",
    "anfressendes": "anfressend",
    "anfressendste": "anfressend",
    "anfressendstem": "anfressend",
    "anfressendsten": "anfressend",
    "anfressendster": "anfressend",
    "anfressendstes": "anfressend",
    "anfressest": "anfressen",
    "anfresset": "anfressen",
    "anfreunde": "anfreunden",
    "anfreundend": "anfreunden",
    "anfreundende": "anfreundend",
    "anfreundendem": "anfreundend",
    "anfreundenden": "anfreundend",
    "anfreundender": "anfreundend",
    "anfreundendes": "anfreundend",
    "anfreundest": "anfreunden",
    "anfreundet": "anfreunden",
    "anfreundete": "anfreunden",
    "anfreundeten": "anfreunden",
    "anfreundetest": "anfreunden",
    "anfreundetet": "anfreunden",
    "anfreßt": "anfressen",
    "anfriere": "anfrieren",
    "anfrierend": "anfrieren",
    "anfrierende": "anfrierend",
    "anfrierendem": "anfrierend",
    "anfrierenden": "anfrierend",
    "anfrierender": "anfrierend",
    "anfrierendere": "anfrierend",
    "anfrierenderem": "anfrierend",
    "anfrierenderen": "anfrierend",
    "anfrierenderer": "anfrierend",
    "anfrierenderes": "anfrierend",
    "anfrierendes": "anfrierend",
    "anfrierendste": "anfrierend",
    "anfrierendstem": "anfrierend",
    "anfrierendsten": "anfrierend",
    "anfrierendster": "anfrierend",
    "anfrierendstes": "anfrierend",
    "anfrierest": "anfrieren",
    "anfrieret": "anfrieren",
    "anfrierst": "anfrieren",
    "anfriert": "anfrieren",
    "anfrißt": "anfressen",
    "anfror": "anfrieren",
    "anfroren": "anfrieren",
    "anfrorst": "anfrieren",
    "anfrort": "anfrieren",
    "anfräße": "anfressen",
    "anfräßen": "anfressen",
    "anfräßest": "anfressen",
    "anfräßet": "anfressen",
    "anfröre": "anfrieren",
    "anfrören": "anfrieren",
    "anfrörest": "anfrieren",
    "anfröret": "anfrieren",
    "anfuhr": "anfahren",
    "anfuhren": "anfahren",
    "anfuhrst": "anfahren",
    "anfuhrt": "anfahren",
    "anfunke": "anfunken",
    "anfunkele": "anfunkeln",
    "anfunkelnd": "anfunkeln",
    "anfunkelnde": "anfunkelnd",
    "anfunkelndem": "anfunkelnd",
    "anfunkelnden": "anfunkelnd",
    "anfunkelnder": "anfunkelnd",
    "anfunkelndes": "anfunkelnd",
    "anfunkelst": "anfunkeln",
    "anfunkelt": "anfunkeln",
    "anfunkelte": "anfunkeln",
    "anfunkelten": "anfunkeln",
    "anfunkeltest": "anfunkeln",
    "anfunkeltet": "anfunkeln",
    "anfunkend": "anfunken",
    "anfunkende": "anfunkend",
    "anfunkendem": "anfunkend",
    "anfunkenden": "anfunkend",
    "anfunkender": "anfunkend",
    "anfunkendes": "anfunkend",
    "anfunkest": "anfunken",
    "anfunket": "anfunken",
    "anfunkle": "anfunkeln",
    "anfunkst": "anfunken",
    "anfunkt": "anfunken",
    "anfunkte": "anfunken",
    "anfunkten": "anfunken",
    "anfunktest": "anfunken",
    "anfunktet": "anfunken",
    "anfährst": "anfahren",
    "anfährt": "anfahren",
    "anfällige": "anfällig",
    "anfälligem": "anfällig",
    "anfälligen": "anfällig",
    "anfälliger": "anfällig",
    "anfälligere": "anfällig",
    "anfälligerem": "anfällig",
    "anfälligeren": "anfällig",
    "anfälligerer": "anfällig",
    "anfälligeres": "anfällig",
    "anfälliges": "anfällig",
    "anfälligste": "anfällig",
    "anfälligstem": "anfällig",
    "anfälligsten": "anfällig",
    "anfälligster": "anfällig",
    "anfälligstes": "anfällig",
    "anfällst": "anfallen",
    "anfällt": "anfallen",
    "anfände": "anfinden",
    "anfänden": "anfinden",
    "anfändest": "anfinden",
    "anfändet": "anfinden",
    "anfängliche": "anfänglich",
    "anfänglichem": "anfänglich",
    "anfänglichen": "anfänglich",
    "anfänglicher": "anfänglich",
    "anfängliches": "anfänglich",
    "anfängst": "anfangen",
    "anfängt": "anfangen",
    "anföchte": "anfechten",
    "anföchten": "anfechten",
    "anföchtest": "anfechten",
    "anföchtet": "anfechten",
    "anfüge": "anfügen",
    "anfügend": "anfügen",
    "anfügende": "anfügend",
    "anfügendem": "anfügend",
    "anfügenden": "anfügend",
    "anfügender": "anfügend",
    "anfügendes": "anfügend",
    "anfügest": "anfügen",
    "anfüget": "anfügen",
    "anfügst": "anfügen",
    "anfügt": "anfügen",
    "anfügte": "anfügen",
    "anfügten": "anfügen",
    "anfügtest": "anfügen",
    "anfügtet": "anfügen",
    "anfühle": "anfühlen",
    "anfühlend": "anfühlen",
    "anfühlende": "anfühlend",
    "anfühlendem": "anfühlend",
    "anfühlenden": "anfühlend",
    "anfühlender": "anfühlend",
    "anfühlendes": "anfühlend",
    "anfühlest": "anfühlen",
    "anfühlet": "anfühlen",
    "anfühlst": "anfühlen",
    "anfühlt": "anfühlen",
    "anfühlte": "anfühlen",
    "anfühlten": "anfühlen",
    "anfühltest": "anfühlen",
    "anfühltet": "anfühlen",
    "anführe": "anführen",
    "anführen": "anfahren",
    "anführend": "anführen",
    "anführende": "anführend",
    "anführendem": "anführend",
    "anführenden": "anführend",
    "anführender": "anführend",
    "anführendes": "anführend",
    "anführest": "anführen",
    "anführet": "anführen",
    "anführst": "anführen",
    "anführt": "anführen",
    "anführte": "anführen",
    "anführten": "anführen",
    "anführtest": "anführen",
    "anführtet": "anführen",
    "anfülle": "anfüllen",
    "anfüllend": "anfüllen",
    "anfüllende": "anfüllend",
    "anfüllendem": "anfüllend",
    "anfüllenden": "anfüllend",
    "anfüllender": "anfüllend",
    "anfüllendes": "anfüllend",
    "anfüllest": "anfüllen",
    "anfüllet": "anfüllen",
    "anfüllst": "anfüllen",
    "anfüllt": "anfüllen",
    "anfüllte": "anfüllen",
    "anfüllten": "anfüllen",
    "anfülltest": "anfüllen",
    "anfülltet": "anfüllen",
    "angab": "angeben",
    "angabst": "angeben",
    "angabt": "angeben",
    "angaffe": "angaffen",
    "angaffend": "angaffen",
    "angaffende": "angaffend",
    "angaffendem": "angaffend",
    "angaffenden": "angaffend",
    "angaffender": "angaffend",
    "angaffendere": "angaffend",
    "angaffenderem": "angaffend",
    "angaffenderen": "angaffend",
    "angaffenderer": "angaffend",
    "angaffenderes": "angaffend",
    "angaffendes": "angaffend",
    "angaffendste": "angaffend",
    "angaffendstem": "angaffend",
    "angaffendsten": "angaffend",
    "angaffendster": "angaffend",
    "angaffendstes": "angaffend",
    "angaffest": "angaffen",
    "angaffet": "angaffen",
    "angaffst": "angaffen",
    "angafft": "angaffen",
    "angaffte": "angaffen",
    "angafften": "angaffen",
    "angafftest": "angaffen",
    "angafftet": "angaffen",
    "angaloppiere": "angaloppieren",
    "angaloppierend": "angaloppieren",
    "angaloppierende": "angaloppierend",
    "angaloppierendem": "angaloppierend",
    "angaloppierenden": "angaloppierend",
    "angaloppierender": "angaloppierend",
    "angaloppierendes": "angaloppierend",
    "angaloppierest": "angaloppieren",
    "angaloppieret": "angaloppieren",
    "angaloppierst": "angaloppieren",
    "angaloppiert": "angaloppieren",
    "angaloppierte": "angaloppieren",
    "angaloppiertem": "angaloppiert",
    "angaloppierten": "angaloppieren",
    "angaloppierter": "angaloppiert",
    "angaloppiertes": "angaloppiert",
    "angaloppiertest": "angaloppieren",
    "angaloppiertet": "angaloppieren",
    "angebacken": "anbacken",
    "angebackene": "angebacken",
    "angebackenem": "angebacken",
    "angebackenen": "angebacken",
    "angebackener": "angebacken",
    "angebackenere": "angebacken",
    "angebackenerem": "angebacken",
    "angebackeneren": "angebacken",
    "angebackenerer": "angebacken",
    "angebackeneres": "angebacken",
    "angebackenes": "angebacken",
    "angebackenste": "angebacken",
    "angebackenstem": "angebacken",
    "angebackensten": "angebacken",
    "angebackenster": "angebacken",
    "angebackenstes": "angebacken",
    "angebaggert": "anbaggern",
    "angebaggerte": "angebaggert",
    "angebaggertem": "angebaggert",
    "angebaggerten": "angebaggert",
    "angebaggerter": "angebaggert",
    "angebaggertes": "angebaggert",
    "angebahnt": "anbahnen",
    "angebahnte": "angebahnt",
    "angebahntem": "angebahnt",
    "angebahnten": "angebahnt",
    "angebahnter": "angebahnt",
    "angebahntes": "angebahnt",
    "angebandelt": "anbandeln",
    "angebandelte": "angebandelt",
    "angebandeltem": "angebandelt",
    "angebandelten": "angebandelt",
    "angebandelter": "angebandelt",
    "angebandeltes": "angebandelt",
    "angebaut": "anbauen",
    "angebaute": "angebaut",
    "angebautem": "angebaut",
    "angebauten": "angebaut",
    "angebauter": "angebaut",
    "angebautes": "angebaut",
    "angebe": "angeben",
    "angebend": "angeben",
    "angebende": "angebend",
    "angebendem": "angebend",
    "angebenden": "angebend",
    "angebender": "angebend",
    "angebendere": "angebend",
    "angebenderem": "angebend",
    "angebenderen": "angebend",
    "angebenderer": "angebend",
    "angebenderes": "angebend",
    "angebendes": "angebend",
    "angebendste": "angebend",
    "angebendstem": "angebend",
    "angebendsten": "angebend",
    "angebendster": "angebend",
    "angebendstes": "angebend",
    "angeberischem": "angeberisch",
    "angeberischen": "angeberisch",
    "angeberischer": "angeberisch",
    "angeberischere": "angeberisch",
    "angeberischerem": "angeberisch",
    "angeberischeren": "angeberisch",
    "angeberischerer": "angeberisch",
    "angeberischeres": "angeberisch",
    "angeberisches": "angeberisch",
    "angeberischste": "angeberisch",
    "angeberischstem": "angeberisch",
    "angeberischsten": "angeberisch",
    "angeberischster": "angeberisch",
    "angeberischstes": "angeberisch",
    "angebest": "angeben",
    "angebet": "angeben",
    "angebetet": "anbeten",
    "angebetete": "angebetet",
    "angebetetem": "angebetet",
    "angebeteten": "angebetet",
    "angebeteter": "angebetet",
    "angebetetes": "angebetet",
    "angebettelt": "anbetteln",
    "angebettelte": "angebettelt",
    "angebetteltem": "angebettelt",
    "angebettelten": "angebettelt",
    "angebettelter": "angebettelt",
    "angebetteltere": "angebettelt",
    "angebettelterem": "angebettelt",
    "angebettelteren": "angebettelt",
    "angebettelterer": "angebettelt",
    "angebettelteres": "angebettelt",
    "angebetteltes": "angebettelt",
    "angebettelteste": "angebettelt",
    "angebetteltestem": "angebettelt",
    "angebetteltesten": "angebettelt",
    "angebetteltester": "angebettelt",
    "angebetteltestes": "angebettelt",
    "angebiedert": "anbiedern",
    "angebiederte": "angebiedert",
    "angebiedertem": "angebiedert",
    "angebiederten": "angebiedert",
    "angebiederter": "angebiedert",
    "angebiedertere": "angebiedert",
    "angebiederterem": "angebiedert",
    "angebiederteren": "angebiedert",
    "angebiederterer": "angebiedert",
    "angebiederteres": "angebiedert",
    "angebiedertes": "angebiedert",
    "angebiederteste": "angebiedert",
    "angebiedertestem": "angebiedert",
    "angebiedertesten": "angebiedert",
    "angebiedertester": "angebiedert",
    "angebiedertestes": "angebiedert",
    "angebissen": "anbeißen",
    "angebissene": "angebissen",
    "angebissenem": "angebissen",
    "angebissenen": "angebissen",
    "angebissener": "angebissen",
    "angebissenere": "angebissen",
    "angebissenerem": "angebissen",
    "angebisseneren": "angebissen",
    "angebissenerer": "angebissen",
    "angebisseneres": "angebissen",
    "angebissenes": "angebissen",
    "angebissenste": "angebissen",
    "angebissenstem": "angebissen",
    "angebissensten": "angebissen",
    "angebissenster": "angebissen",
    "angebissenstes": "angebissen",
    "angeblafft": "anblaffen",
    "angeblaffte": "angeblafft",
    "angeblafftem": "angeblafft",
    "angeblafften": "angeblafft",
    "angeblaffter": "angeblafft",
    "angeblafftere": "angeblafft",
    "angeblaffterem": "angeblafft",
    "angeblaffteren": "angeblafft",
    "angeblaffterer": "angeblafft",
    "angeblaffteres": "angeblafft",
    "angeblafftes": "angeblafft",
    "angeblaffteste": "angeblafft",
    "angeblafftestem": "angeblafft",
    "angeblafftesten": "angeblafft",
    "angeblafftester": "angeblafft",
    "angeblafftestes": "angeblafft",
    "angeblasen": "anblasen",
    "angeblasene": "angeblasen",
    "angeblasenem": "angeblasen",
    "angeblasenen": "angeblasen",
    "angeblasener": "angeblasen",
    "angeblasenes": "angeblasen",
    "angebliche": "angeblich",
    "angeblichem": "angeblich",
    "angeblichen": "angeblich",
    "angeblicher": "angeblich",
    "angebliches": "angeblich",
    "angeblickt": "anblicken",
    "angeblickte": "angeblickt",
    "angeblicktem": "angeblickt",
    "angeblickten": "angeblickt",
    "angeblickter": "angeblickt",
    "angeblicktere": "angeblickt",
    "angeblickterem": "angeblickt",
    "angeblickteren": "angeblickt",
    "angeblickterer": "angeblickt",
    "angeblickteres": "angeblickt",
    "angeblicktes": "angeblickt",
    "angeblickteste": "angeblickt",
    "angeblicktestem": "angeblickt",
    "angeblicktesten": "angeblickt",
    "angeblicktester": "angeblickt",
    "angeblicktestes": "angeblickt",
    "angeblinzelt": "anblinzeln",
    "angeblinzelte": "angeblinzelt",
    "angeblinzeltem": "angeblinzelt",
    "angeblinzelten": "angeblinzelt",
    "angeblinzelter": "angeblinzelt",
    "angeblinzeltes": "angeblinzelt",
    "angeblitzt": "anblitzen",
    "angeblitzte": "angeblitzt",
    "angeblitztem": "angeblitzt",
    "angeblitzten": "angeblitzt",
    "angeblitzter": "angeblitzt",
    "angeblitztes": "angeblitzt",
    "angebohrt": "anbohren",
    "angebohrte": "angebohrt",
    "angebohrtem": "angebohrt",
    "angebohrten": "angebohrt",
    "angebohrter": "angebohrt",
    "angebohrtes": "angebohrt",
    "angeborene": "angeboren",
    "angeborenem": "angeboren",
    "angeborenen": "angeboren",
    "angeborener": "angeboren",
    "angeborenes": "angeboren",
    "angebotenem": "angeboten",
    "angebotenen": "angeboten",
    "angebotener": "angeboten",
    "angebotenes": "angeboten",
    "angebracht": "anbringen",
    "angebrachte": "angebracht",
    "angebrachtem": "angebracht",
    "angebrachten": "angebracht",
    "angebrachter": "angebracht",
    "angebrachtere": "angebracht",
    "angebrachterem": "angebracht",
    "angebrachteren": "angebracht",
    "angebrachterer": "angebracht",
    "angebrachteres": "angebracht",
    "angebrachtes": "angebracht",
    "angebrachteste": "angebracht",
    "angebrachtestem": "angebracht",
    "angebrachtesten": "angebracht",
    "angebrachtester": "angebracht",
    "angebrachtestes": "angebracht",
    "angebrannt": "anbrennen",
    "angebrannte": "angebrannt",
    "angebranntem": "angebrannt",
    "angebrannten": "angebrannt",
    "angebrannter": "angebrannt",
    "angebranntere": "angebrannt",
    "angebrannterem": "angebrannt",
    "angebrannteren": "angebrannt",
    "angebrannterer": "angebrannt",
    "angebrannteres": "angebrannt",
    "angebranntes": "angebrannt",
    "angebrannteste": "angebrannt",
    "angebranntestem": "angebrannt",
    "angebranntesten": "angebrannt",
    "angebranntester": "angebrannt",
    "angebranntestes": "angebrannt",
    "angebraten": "anbraten",
    "angebratene": "angebraten",
    "angebratenem": "angebraten",
    "angebratenen": "angebraten",
    "angebratener": "angebraten",
    "angebratenere": "angebraten",
    "angebratenerem": "angebraten",
    "angebrateneren": "angebraten",
    "angebratenerer": "angebraten",
    "angebrateneres": "angebraten",
    "angebratenes": "angebraten",
    "angebratenste": "angebraten",
    "angebratenstem": "angebraten",
    "angebratensten": "angebraten",
    "angebratenster": "angebraten",
    "angebratenstes": "angebraten",
    "angebremst": "anbremsen",
    "angebremste": "angebremst",
    "angebremstem": "angebremst",
    "angebremsten": "angebremst",
    "angebremster": "angebremst",
    "angebremstes": "angebremst",
    "angebrochen": "anbrechen",
    "angebrochene": "angebrochen",
    "angebrochenem": "angebrochen",
    "angebrochenen": "angebrochen",
    "angebrochener": "angebrochen",
    "angebrochenere": "angebrochen",
    "angebrochenerem": "angebrochen",
    "angebrocheneren": "angebrochen",
    "angebrochenerer": "angebrochen",
    "angebrocheneres": "angebrochen",
    "angebrochenes": "angebrochen",
    "angebrochenste": "angebrochen",
    "angebrochenstem": "angebrochen",
    "angebrochensten": "angebrochen",
    "angebrochenster": "angebrochen",
    "angebrochenstes": "angebrochen",
    "angebrummt": "anbrummen",
    "angebrummte": "angebrummt",
    "angebrummtem": "angebrummt",
    "angebrummten": "angebrummt",
    "angebrummter": "angebrummt",
    "angebrummtes": "angebrummt",
    "angebrüllt": "anbrüllen",
    "angebrüllte": "angebrüllt",
    "angebrülltem": "angebrüllt",
    "angebrüllten": "angebrüllt",
    "angebrüllter": "angebrüllt",
    "angebrülltes": "angebrüllt",
    "angebrütet": "anbrüten",
    "angebrütete": "angebrütet",
    "angebrütetem": "angebrütet",
    "angebrüteten": "angebrütet",
    "angebrüteter": "angebrütet",
    "angebrütetes": "angebrütet",
    "angebt": "angeben",
    "angebunden": "anbinden",
    "angebundene": "angebunden",
    "angebundenem": "angebunden",
    "angebundenen": "angebunden",
    "angebundener": "angebunden",
    "angebundenes": "angebunden",
    "angedacht": "andenken",
    "angedachte": "angedacht",
    "angedachtem": "angedacht",
    "angedachten": "angedacht",
    "angedachter": "angedacht",
    "angedachtes": "angedacht",
    "angedauert": "andauern",
    "angedauerte": "angedauert",
    "angedauertem": "angedauert",
    "angedauerten": "angedauert",
    "angedauerter": "angedauert",
    "angedauertes": "angedauert",
    "angedeutet": "andeuten",
    "angedeutete": "angedeutet",
    "angedeutetem": "angedeutet",
    "angedeuteten": "angedeutet",
    "angedeuteter": "angedeutet",
    "angedeutetes": "angedeutet",
    "angedichtet": "andichten",
    "angedichtete": "angedichtet",
    "angedichtetem": "angedichtet",
    "angedichteten": "angedichtet",
    "angedichteter": "angedichtet",
    "angedichtetes": "angedichtet",
    "angedient": "andienen",
    "angediente": "angedient",
    "angedientem": "angedient",
    "angedienten": "angedient",
    "angedienter": "angedient",
    "angedientes": "angedient",
    "angedreht": "andrehen",
    "angedrehte": "angedreht",
    "angedrehtem": "angedreht",
    "angedrehten": "angedreht",
    "angedrehter": "angedreht",
    "angedrehtes": "angedreht",
    "angedroht": "androhen",
    "angedrohte": "angedroht",
    "angedrohtem": "angedroht",
    "angedrohten": "angedroht",
    "angedrohter": "angedroht",
    "angedrohtes": "angedroht",
    "angedrungen": "andringen",
    "angedrungene": "angedrungen",
    "angedrungenem": "angedrungen",
    "angedrungenen": "angedrungen",
    "angedrungener": "angedrungen",
    "angedrungenes": "angedrungen",
    "angedrängt": "andrängen",
    "angedrängte": "angedrängt",
    "angedrängtem": "angedrängt",
    "angedrängten": "angedrängt",
    "angedrängter": "angedrängt",
    "angedrängtes": "angedrängt",
    "angeeignet": "aneignen",
    "angeeignete": "angeeignet",
    "angeeignetem": "angeeignet",
    "angeeigneten": "angeeignet",
    "angeeigneter": "angeeignet",
    "angeeignetes": "angeeignet",
    "angeekelt": "anekeln",
    "angeekelte": "angeekelt",
    "angeekeltem": "angeekelt",
    "angeekelten": "angeekelt",
    "angeekelter": "angeekelt",
    "angeekeltere": "angeekelt",
    "angeekelterem": "angeekelt",
    "angeekelteren": "angeekelt",
    "angeekelterer": "angeekelt",
    "angeekelteres": "angeekelt",
    "angeekeltes": "angeekelt",
    "angeekelteste": "angeekelt",
    "angeekeltestem": "angeekelt",
    "angeekeltesten": "angeekelt",
    "angeekeltester": "angeekelt",
    "angeekeltestes": "angeekelt",
    "angefacht": "anfachen",
    "angefachte": "angefacht",
    "angefachtem": "angefacht",
    "angefachten": "angefacht",
    "angefachter": "angefacht",
    "angefachtes": "angefacht",
    "angefahren": "anfahren",
    "angefahrene": "angefahren",
    "angefahrenem": "angefahren",
    "angefahrenen": "angefahren",
    "angefahrener": "angefahren",
    "angefahrenes": "angefahren",
    "angefallen": "anfallen",
    "angefallene": "angefallen",
    "angefallenem": "angefallen",
    "angefallenen": "angefallen",
    "angefallener": "angefallen",
    "angefallenere": "angefallen",
    "angefallenerem": "angefallen",
    "angefalleneren": "angefallen",
    "angefallenerer": "angefallen",
    "angefalleneres": "angefallen",
    "angefallenes": "angefallen",
    "angefallenste": "angefallen",
    "angefallenstem": "angefallen",
    "angefallensten": "angefallen",
    "angefallenster": "angefallen",
    "angefallenstes": "angefallen",
    "angefangen": "anfangen",
    "angefangene": "angefangen",
    "angefangenem": "angefangen",
    "angefangenen": "angefangen",
    "angefangener": "angefangen",
    "angefangenes": "angefangen",
    "angefaucht": "anfauchen",
    "angefauchte": "angefaucht",
    "angefauchtem": "angefaucht",
    "angefauchten": "angefaucht",
    "angefauchter": "angefaucht",
    "angefauchtere": "angefaucht",
    "angefauchterem": "angefaucht",
    "angefauchteren": "angefaucht",
    "angefauchterer": "angefaucht",
    "angefauchteres": "angefaucht",
    "angefauchtes": "angefaucht",
    "angefauchteste": "angefaucht",
    "angefauchtestem": "angefaucht",
    "angefauchtesten": "angefaucht",
    "angefauchtester": "angefaucht",
    "angefauchtestes": "angefaucht",
    "angefault": "anfaulen",
    "angefaulte": "angefault",
    "angefaultem": "angefault",
    "angefaulten": "angefault",
    "angefaulter": "angefault",
    "angefaultere": "angefault",
    "angefaulterem": "angefault",
    "angefaulteren": "angefault",
    "angefaulterer": "angefault",
    "angefaulteres": "angefault",
    "angefaultes": "angefault",
    "angefaulteste": "angefault",
    "angefaultestem": "angefault",
    "angefaultesten": "angefault",
    "angefaultester": "angefault",
    "angefaultestes": "angefault",
    "angefaxt": "anfaxen",
    "angefaxte": "angefaxt",
    "angefaxtem": "angefaxt",
    "angefaxten": "angefaxt",
    "angefaxter": "angefaxt",
    "angefaxtes": "angefaxt",
    "angefaßt": "anfassen",
    "angefaßte": "angefaßt",
    "angefaßtem": "angefaßt",
    "angefaßten": "angefaßt",
    "angefaßter": "angefaßt",
    "angefaßtes": "angefaßt",
    "angefeindet": "anfeinden",
    "angefeindete": "angefeindet",
    "angefeindetem": "angefeindet",
    "angefeindeten": "angefeindet",
    "angefeindeter": "angefeindet",
    "angefeindetere": "angefeindet",
    "angefeindeterem": "angefeindet",
    "angefeindeteren": "angefeindet",
    "angefeindeterer": "angefeindet",
    "angefeindeteres": "angefeindet",
    "angefeindetes": "angefeindet",
    "angefeindeteste": "angefeindet",
    "angefeindetestem": "angefeindet",
    "angefeindetesten": "angefeindet",
    "angefeindetester": "angefeindet",
    "angefeindetestes": "angefeindet",
    "angefertigt": "anfertigen",
    "angefertigte": "angefertigt",
    "angefertigtem": "angefertigt",
    "angefertigten": "angefertigt",
    "angefertigter": "angefertigt",
    "angefertigtes": "angefertigt",
    "angefeuchtet": "anfeuchten",
    "angefeuchtete": "angefeuchtet",
    "angefeuchtetem": "angefeuchtet",
    "angefeuchteten": "angefeuchtet",
    "angefeuchteter": "angefeuchtet",
    "angefeuchtetere": "angefeuchtet",
    "angefeuchteterem": "angefeuchtet",
    "angefeuchteteren": "angefeuchtet",
    "angefeuchteterer": "angefeuchtet",
    "angefeuchteteres": "angefeuchtet",
    "angefeuchtetes": "angefeuchtet",
    "angefeuchteteste": "angefeuchtet",
    "angefeuchtetestem": "angefeuchtet",
    "angefeuchtetesten": "angefeuchtet",
    "angefeuchtetester": "angefeuchtet",
    "angefeuchtetestes": "angefeuchtet",
    "angefeuert": "anfeuern",
    "angefeuerte": "angefeuert",
    "angefeuertem": "angefeuert",
    "angefeuerten": "angefeuert",
    "angefeuerter": "angefeuert",
    "angefeuertere": "angefeuert",
    "angefeuerterem": "angefeuert",
    "angefeuerteren": "angefeuert",
    "angefeuerterer": "angefeuert",
    "angefeuerteres": "angefeuert",
    "angefeuertes": "angefeuert",
    "angefeuerteste": "angefeuert",
    "angefeuertestem": "angefeuert",
    "angefeuertesten": "angefeuert",
    "angefeuertester": "angefeuert",
    "angefeuertestes": "angefeuert",
    "angefixt": "anfixen",
    "angefixte": "angefixt",
    "angefixtem": "angefixt",
    "angefixten": "angefixt",
    "angefixter": "angefixt",
    "angefixtes": "angefixt",
    "angefleht": "anflehen",
    "angeflehte": "angefleht",
    "angeflehtem": "angefleht",
    "angeflehten": "angefleht",
    "angeflehter": "angefleht",
    "angeflehtere": "angefleht",
    "angeflehterem": "angefleht",
    "angeflehteren": "angefleht",
    "angeflehterer": "angefleht",
    "angeflehteres": "angefleht",
    "angeflehtes": "angefleht",
    "angeflehteste": "angefleht",
    "angeflehtestem": "angefleht",
    "angeflehtesten": "angefleht",
    "angeflehtester": "angefleht",
    "angeflehtestes": "angefleht",
    "angeflogen": "anfliegen",
    "angeflogene": "angeflogen",
    "angeflogenem": "angeflogen",
    "angeflogenen": "angeflogen",
    "angeflogener": "angeflogen",
    "angeflogenes": "angeflogen",
    "angefochten": "anfechten",
    "angefochtene": "angefochten",
    "angefochtenem": "angefochten",
    "angefochtenen": "angefochten",
    "angefochtener": "angefochten",
    "angefochtenes": "angefochten",
    "angefordert": "anfordern",
    "angeforderte": "angefordert",
    "angefordertem": "angefordert",
    "angeforderten": "angefordert",
    "angeforderter": "angefordert",
    "angefordertes": "angefordert",
    "angefragt": "anfragen",
    "angefragte": "angefragt",
    "angefragtem": "angefragt",
    "angefragten": "angefragt",
    "angefragter": "angefragt",
    "angefragtes": "angefragt",
    "angefressen": "anfressen",
    "angefressene": "angefressen",
    "angefressenem": "angefressen",
    "angefressenen": "angefressen",
    "angefressener": "angefressen",
    "angefressenere": "angefressen",
    "angefressenerem": "angefressen",
    "angefresseneren": "angefressen",
    "angefressenerer": "angefressen",
    "angefresseneres": "angefressen",
    "angefressenes": "angefressen",
    "angefressenste": "angefressen",
    "angefressenstem": "angefressen",
    "angefressensten": "angefressen",
    "angefressenster": "angefressen",
    "angefressenstes": "angefressen",
    "angefreundet": "anfreunden",
    "angefreundete": "angefreundet",
    "angefreundetem": "angefreundet",
    "angefreundeten": "angefreundet",
    "angefreundeter": "angefreundet",
    "angefreundetes": "angefreundet",
    "angefroren": "anfrieren",
    "angefrorene": "angefroren",
    "angefrorenem": "angefroren",
    "angefrorenen": "angefroren",
    "angefrorener": "angefroren",
    "angefrorenere": "angefroren",
    "angefrorenerem": "angefroren",
    "angefroreneren": "angefroren",
    "angefrorenerer": "angefroren",
    "angefroreneres": "angefroren",
    "angefrorenes": "angefroren",
    "angefrorenste": "angefroren",
    "angefrorenstem": "angefroren",
    "angefrorensten": "angefroren",
    "angefrorenster": "angefroren",
    "angefrorenstes": "angefroren",
    "angefunden": "anfinden",
    "angefundene": "angefunden",
    "angefundenem": "angefunden",
    "angefundenen": "angefunden",
    "angefundener": "angefunden",
    "angefundenes": "angefunden",
    "angefunkelt": "anfunkeln",
    "angefunkelte": "angefunkelt",
    "angefunkeltem": "angefunkelt",
    "angefunkelten": "angefunkelt",
    "angefunkelter": "angefunkelt",
    "angefunkeltes": "angefunkelt",
    "angefunkt": "anfunken",
    "angefunkte": "angefunkt",
    "angefunktem": "angefunkt",
    "angefunkten": "angefunkt",
    "angefunkter": "angefunkt",
    "angefunktes": "angefunkt",
    "angefügt": "anfügen",
    "angefügte": "angefügt",
    "angefügtem": "angefügt",
    "angefügten": "angefügt",
    "angefügter": "angefügt",
    "angefügtes": "angefügt",
    "angefühlt": "anfühlen",
    "angefühlte": "angefühlt",
    "angefühltem": "angefühlt",
    "angefühlten": "angefühlt",
    "angefühlter": "angefühlt",
    "angefühltes": "angefühlt",
    "angeführt": "anführen",
    "angeführte": "angeführt",
    "angeführtem": "angeführt",
    "angeführten": "angeführt",
    "angeführter": "angeführt",
    "angeführtes": "angeführt",
    "angefüllt": "anfüllen",
    "angefüllte": "angefüllt",
    "angefülltem": "angefüllt",
    "angefüllten": "angefüllt",
    "angefüllter": "angefüllt",
    "angefülltes": "angefüllt",
    "angegafft": "angaffen",
    "angegaffte": "angegafft",
    "angegafftem": "angegafft",
    "angegafften": "angegafft",
    "angegaffter": "angegafft",
    "angegafftere": "angegafft",
    "angegaffterem": "angegafft",
    "angegaffteren": "angegafft",
    "angegaffterer": "angegafft",
    "angegaffteres": "angegafft",
    "angegafftes": "angegafft",
    "angegaffteste": "angegafft",
    "angegafftestem": "angegafft",
    "angegafftesten": "angegafft",
    "angegafftester": "angegafft",
    "angegafftestes": "angegafft",
    "angegangen": "angehen",
    "angegangene": "angegangen",
    "angegangenem": "angegangen",
    "angegangenen": "angegangen",
    "angegangener": "angegangen",
    "angegangenes": "angegangen",
    "angegeben": "angeben",
    "angegebene": "angegeben",
    "angegebenem": "angegeben",
    "angegebenen": "angegeben",
    "angegebener": "angegeben",
    "angegebenes": "angegeben",
    "angegiftet": "angiften",
    "angegiftete": "angegiftet",
    "angegiftetem": "angegiftet",
    "angegifteten": "angegiftet",
    "angegifteter": "angegiftet",
    "angegiftetere": "angegiftet",
    "angegifteterem": "angegiftet",
    "angegifteteren": "angegiftet",
    "angegifteterer": "angegiftet",
    "angegifteteres": "angegiftet",
    "angegiftetes": "angegiftet",
    "angegifteteste": "angegiftet",
    "angegiftetestem": "angegiftet",
    "angegiftetesten": "angegiftet",
    "angegiftetester": "angegiftet",
    "angegiftetestes": "angegiftet",
    "angeglichen": "angleichen",
    "angeglichene": "angeglichen",
    "angeglichenem": "angeglichen",
    "angeglichenen": "angeglichen",
    "angeglichener": "angeglichen",
    "angeglichenere": "angeglichen",
    "angeglichenerem": "angeglichen",
    "angeglicheneren": "angeglichen",
    "angeglichenerer": "angeglichen",
    "angeglicheneres": "angeglichen",
    "angeglichenes": "angeglichen",
    "angeglichenste": "angeglichen",
    "angeglichenstem": "angeglichen",
    "angeglichensten": "angeglichen",
    "angeglichenster": "angeglichen",
    "angeglichenstes": "angeglichen",
    "angegliedert": "angliedern",
    "angegliederte": "angegliedert",
    "angegliedertem": "angegliedert",
    "angegliederten": "angegliedert",
    "angegliederter": "angegliedert",
    "angegliedertere": "angegliedert",
    "angegliederterem": "angegliedert",
    "angegliederteren": "angegliedert",
    "angegliederterer": "angegliedert",
    "angegliederteres": "angegliedert",
    "angegliedertes": "angegliedert",
    "angegliederteste": "angegliedert",
    "angegliedertestem": "angegliedert",
    "angegliedertesten": "angegliedert",
    "angegliedertester": "angegliedert",
    "angegliedertestes": "angegliedert",
    "angeglotzt": "anglotzen",
    "angeglotzte": "angeglotzt",
    "angeglotztem": "angeglotzt",
    "angeglotzten": "angeglotzt",
    "angeglotzter": "angeglotzt",
    "angeglotztere": "angeglotzt",
    "angeglotzterem": "angeglotzt",
    "angeglotzteren": "angeglotzt",
    "angeglotzterer": "angeglotzt",
    "angeglotzteres": "angeglotzt",
    "angeglotztes": "angeglotzt",
    "angeglotzteste": "angeglotzt",
    "angeglotztestem": "angeglotzt",
    "angeglotztesten": "angeglotzt",
    "angeglotztester": "angeglotzt",
    "angeglotztestes": "angeglotzt",
    "angegossen": "angießen",
    "angegossene": "angegossen",
    "angegossenem": "angegossen",
    "angegossenen": "angegossen",
    "angegossener": "angegossen",
    "angegossenes": "angegossen",
    "angegraute": "angegraut",
    "angegrautem": "angegraut",
    "angegrauten": "angegraut",
    "angegrauter": "angegraut",
    "angegrautere": "angegraut",
    "angegrauterem": "angegraut",
    "angegrauteren": "angegraut",
    "angegrauterer": "angegraut",
    "angegrauteres": "angegraut",
    "angegrautes": "angegraut",
    "angegrauteste": "angegraut",
    "angegrautestem": "angegraut",
    "angegrautesten": "angegraut",
    "angegrautester": "angegraut",
    "angegrautestes": "angegraut",
    "angegrenzt": "angrenzen",
    "angegrenzte": "angegrenzt",
    "angegrenztem": "angegrenzt",
    "angegrenzten": "angegrenzt",
    "angegrenzter": "angegrenzt",
    "angegrenztes": "angegrenzt",
    "angegriffen": "angreifen",
    "angegriffene": "angegriffen",
    "angegriffenem": "angegriffen",
    "angegriffenen": "angegriffen",
    "angegriffener": "angegriffen",
    "angegriffenere": "angegriffen",
    "angegriffenerem": "angegriffen",
    "angegriffeneren": "angegriffen",
    "angegriffenerer": "angegriffen",
    "angegriffeneres": "angegriffen",
    "angegriffenes": "angegriffen",
    "angegriffenste": "angegriffen",
    "angegriffenstem": "angegriffen",
    "angegriffensten": "angegriffen",
    "angegriffenster": "angegriffen",
    "angegriffenstes": "angegriffen",
    "angegrinst": "angrinsen",
    "angegrinste": "angegrinst",
    "angegrinstem": "angegrinst",
    "angegrinsten": "angegrinst",
    "angegrinster": "angegrinst",
    "angegrinstere": "angegrinst",
    "angegrinsterem": "angegrinst",
    "angegrinsteren": "angegrinst",
    "angegrinsterer": "angegrinst",
    "angegrinsteres": "angegrinst",
    "angegrinstes": "angegrinst",
    "angegrinsteste": "angegrinst",
    "angegrinstestem": "angegrinst",
    "angegrinstesten": "angegrinst",
    "angegrinstester": "angegrinst",
    "angegrinstestes": "angegrinst",
    "angegurtet": "angurten",
    "angegurtete": "angegurtet",
    "angegurtetem": "angegurtet",
    "angegurteten": "angegurtet",
    "angegurteter": "angegurtet",
    "angegurtetes": "angegurtet",
    "angehaftet": "anhaften",
    "angehaftete": "angehaftet",
    "angehaftetem": "angehaftet",
    "angehafteten": "angehaftet",
    "angehafteter": "angehaftet",
    "angehaftetes": "angehaftet",
    "angehakt": "anhaken",
    "angehakte": "angehakt",
    "angehaktem": "angehakt",
    "angehakten": "angehakt",
    "angehakter": "angehakt",
    "angehaktes": "angehakt",
    "angehalftert": "anhalftern",
    "angehalfterte": "angehalftert",
    "angehalftertem": "angehalftert",
    "angehalfterten": "angehalftert",
    "angehalfterter": "angehalftert",
    "angehalftertes": "angehalftert",
    "angehalten": "anhalten",
    "angehaltene": "angehalten",
    "angehaltenem": "angehalten",
    "angehaltenen": "angehalten",
    "angehaltener": "angehalten",
    "angehaltenes": "angehalten",
    "angehangen": "anhängen",
    "angehaucht": "anhauchen",
    "angehauchte": "angehaucht",
    "angehauchtem": "angehaucht",
    "angehauchten": "angehaucht",
    "angehauchter": "angehaucht",
    "angehauchtes": "angehaucht",
    "angehauen": "anhauen",
    "angehauene": "angehauen",
    "angehauenem": "angehauen",
    "angehauenen": "angehauen",
    "angehauener": "angehauen",
    "angehauenes": "angehauen",
    "angehe": "angehen",
    "angeheftet": "anheften",
    "angeheftete": "angeheftet",
    "angeheftetem": "angeheftet",
    "angehefteten": "angeheftet",
    "angehefteter": "angeheftet",
    "angeheftetes": "angeheftet",
    "angeheimelt": "anheimeln",
    "angeheimelte": "angeheimelt",
    "angeheimeltem": "angeheimelt",
    "angeheimelten": "angeheimelt",
    "angeheimelter": "angeheimelt",
    "angeheimeltes": "angeheimelt",
    "angeheiratete": "angeheiratet",
    "angeheiratetem": "angeheiratet",
    "angeheirateten": "angeheiratet",
    "angeheirateter": "angeheiratet",
    "angeheiratetes": "angeheiratet",
    "angeheiterte": "angeheitert",
    "angeheitertem": "angeheitert",
    "angeheiterten": "angeheitert",
    "angeheiterter": "angeheitert",
    "angeheitertere": "angeheitert",
    "angeheiterterem": "angeheitert",
    "angeheiterteren": "angeheitert",
    "angeheiterterer": "angeheitert",
    "angeheiterteres": "angeheitert",
    "angeheitertes": "angeheitert",
    "angeheiterteste": "angeheitert",
    "angeheitertestem": "angeheitert",
    "angeheitertesten": "angeheitert",
    "angeheitertester": "angeheitert",
    "angeheitertestes": "angeheitert",
    "angeheizt": "anheizen",
    "angeheizte": "angeheizt",
    "angeheiztem": "angeheizt",
    "angeheizten": "angeheizt",
    "angeheizter": "angeheizt",
    "angeheiztere": "angeheizt",
    "angeheizterem": "angeheizt",
    "angeheizteren": "angeheizt",
    "angeheizterer": "angeheizt",
    "angeheizteres": "angeheizt",
    "angeheiztes": "angeheizt",
    "angeheizteste": "angeheizt",
    "angeheiztestem": "angeheizt",
    "angeheiztesten": "angeheizt",
    "angeheiztester": "angeheizt",
    "angeheiztestes": "angeheizt",
    "angehend": "angehen",
    "angehende": "angehend",
    "angehendem": "angehend",
    "angehenden": "angehend",
    "angehender": "angehend",
    "angehendes": "angehend",
    "angehest": "angehen",
    "angehet": "angehen",
    "angeheuert": "anheuern",
    "angeheuerte": "angeheuert",
    "angeheuertem": "angeheuert",
    "angeheuerten": "angeheuert",
    "angeheuerter": "angeheuert",
    "angeheuertes": "angeheuert",
    "angehimmelt": "anhimmeln",
    "angehimmelte": "angehimmelt",
    "angehimmeltem": "angehimmelt",
    "angehimmelten": "angehimmelt",
    "angehimmelter": "angehimmelt",
    "angehimmeltere": "angehimmelt",
    "angehimmelterem": "angehimmelt",
    "angehimmelteren": "angehimmelt",
    "angehimmelterer": "angehimmelt",
    "angehimmelteres": "angehimmelt",
    "angehimmeltes": "angehimmelt",
    "angehimmelteste": "angehimmelt",
    "angehimmeltestem": "angehimmelt",
    "angehimmeltesten": "angehimmelt",
    "angehimmeltester": "angehimmelt",
    "angehimmeltestes": "angehimmelt",
    "angehoben": "anheben",
    "angehobene": "angehoben",
    "angehobenem": "angehoben",
    "angehobenen": "angehoben",
    "angehobener": "angehoben",
    "angehobenes": "angehoben",
    "angeholt": "anholen",
    "angeholte": "angeholt",
    "angeholtem": "angeholt",
    "angeholten": "angeholt",
    "angeholter": "angeholt",
    "angeholtes": "angeholt",
    "angehst": "angehen",
    "angeht": "angehen",
    "angehängt": "anhängen",
    "angehängte": "angehängt",
    "angehängtem": "angehängt",
    "angehängten": "angehängt",
    "angehängter": "angehängt",
    "angehängtes": "angehängt",
    "angehärtet": "anhärten",
    "angehärtete": "angehärtet",
    "angehärtetem": "angehärtet",
    "angehärteten": "angehärtet",
    "angehärteter": "angehärtet",
    "angehärtetere": "angehärtet",
    "angehärteterem": "angehärtet",
    "angehärteteren": "angehärtet",
    "angehärteterer": "angehärtet",
    "angehärteteres": "angehärtet",
    "angehärtetes": "angehärtet",
    "angehärteteste": "angehärtet",
    "angehärtetestem": "angehärtet",
    "angehärtetesten": "angehärtet",
    "angehärtetester": "angehärtet",
    "angehärtetestes": "angehärtet",
    "angehöre": "angehören",
    "angehörend": "angehören",
    "angehörende": "angehörend",
    "angehörendem": "angehörend",
    "angehörenden": "angehörend",
    "angehörender": "angehörend",
    "angehörendes": "angehörend",
    "angehörest": "angehören",
    "angehöret": "angehören",
    "angehörige": "angehörig",
    "angehörigem": "angehörig",
    "angehörigen": "angehörig",
    "angehöriger": "angehörig",
    "angehöriges": "angehörig",
    "angehörst": "angehören",
    "angehört": "anhören",
    "angehörte": "angehören",
    "angehörtem": "angehört",
    "angehörten": "angehören",
    "angehörter": "angehört",
    "angehörtes": "angehört",
    "angehörtest": "angehören",
    "angehörtet": "angehören",
    "angejagt": "anjagen",
    "angejagte": "angejagt",
    "angejagtem": "angejagt",
    "angejagten": "angejagt",
    "angejagter": "angejagt",
    "angejagtes": "angejagt",
    "angejahrte": "angejahrt",
    "angejahrtem": "angejahrt",
    "angejahrten": "angejahrt",
    "angejahrter": "angejahrt",
    "angejahrtere": "angejahrt",
    "angejahrterem": "angejahrt",
    "angejahrteren": "angejahrt",
    "angejahrterer": "angejahrt",
    "angejahrteres": "angejahrt",
    "angejahrtes": "angejahrt",
    "angejahrteste": "angejahrt",
    "angejahrtestem": "angejahrt",
    "angejahrtesten": "angejahrt",
    "angejahrtester": "angejahrt",
    "angejahrtestes": "angejahrt",
    "angekauft": "ankaufen",
    "angekaufte": "angekauft",
    "angekauftem": "angekauft",
    "angekauften": "angekauft",
    "angekaufter": "angekauft",
    "angekauftes": "angekauft",
    "angekeilt": "ankeilen",
    "angekeilte": "angekeilt",
    "angekeiltem": "angekeilt",
    "angekeilten": "angekeilt",
    "angekeilter": "angekeilt",
    "angekeiltere": "angekeilt",
    "angekeilterem": "angekeilt",
    "angekeilteren": "angekeilt",
    "angekeilterer": "angekeilt",
    "angekeilteres": "angekeilt",
    "angekeiltes": "angekeilt",
    "angekeilteste": "angekeilt",
    "angekeiltestem": "angekeilt",
    "angekeiltesten": "angekeilt",
    "angekeiltester": "angekeilt",
    "angekeiltestes": "angekeilt",
    "angekettet": "anketten",
    "angekettete": "angekettet",
    "angekettetem": "angekettet",
    "angeketteten": "angekettet",
    "angeketteter": "angekettet",
    "angekettetes": "angekettet",
    "angeklagt": "anklagen",
    "angeklagte": "angeklagt",
    "angeklagtem": "angeklagt",
    "angeklagten": "angeklagt",
    "angeklagter": "angeklagt",
    "angeklagtes": "angeklagt",
    "angeklammert": "anklammern",
    "angeklammerte": "angeklammert",
    "angeklammertem": "angeklammert",
    "angeklammerten": "angeklammert",
    "angeklammerter": "angeklammert",
    "angeklammertes": "angeklammert",
    "angeklebt": "ankleben",
    "angeklebte": "angeklebt",
    "angeklebtem": "angeklebt",
    "angeklebten": "angeklebt",
    "angeklebter": "angeklebt",
    "angeklebtes": "angeklebt",
    "angekleidet": "ankleiden",
    "angekleidete": "angekleidet",
    "angekleidetem": "angekleidet",
    "angekleideten": "angekleidet",
    "angekleideter": "angekleidet",
    "angekleidetes": "angekleidet",
    "angeklingelt": "anklingeln",
    "angeklingelte": "angeklingelt",
    "angeklingeltem": "angeklingelt",
    "angeklingelten": "angeklingelt",
    "angeklingelter": "angeklingelt",
    "angeklingeltes": "angeklingelt",
    "angeklopft": "anklopfen",
    "angeklopfte": "angeklopft",
    "angeklopftem": "angeklopft",
    "angeklopften": "angeklopft",
    "angeklopfter": "angeklopft",
    "angeklopftes": "angeklopft",
    "angeklungen": "anklingen",
    "angeklungene": "angeklungen",
    "angeklungenem": "angeklungen",
    "angeklungenen": "angeklungen",
    "angeklungener": "angeklungen",
    "angeklungenes": "angeklungen",
    "angeknabbert": "anknabbern",
    "angeknabberte": "angeknabbert",
    "angeknabbertem": "angeknabbert",
    "angeknabberten": "angeknabbert",
    "angeknabberter": "angeknabbert",
    "angeknabbertere": "angeknabbert",
    "angeknabberterem": "angeknabbert",
    "angeknabberteren": "angeknabbert",
    "angeknabberterer": "angeknabbert",
    "angeknabberteres": "angeknabbert",
    "angeknabbertes": "angeknabbert",
    "angeknabberteste": "angeknabbert",
    "angeknabbertestem": "angeknabbert",
    "angeknabbertesten": "angeknabbert",
    "angeknabbertester": "angeknabbert",
    "angeknabbertestes": "angeknabbert",
    "angeknackst": "anknacksen",
    "angeknackste": "angeknackst",
    "angeknackstem": "angeknackst",
    "angeknacksten": "angeknackst",
    "angeknackster": "angeknackst",
    "angeknackstere": "angeknackst",
    "angeknacksterem": "angeknackst",
    "angeknacksteren": "angeknackst",
    "angeknacksterer": "angeknackst",
    "angeknacksteres": "angeknackst",
    "angeknackstes": "angeknackst",
    "angeknacksteste": "angeknackst",
    "angeknackstestem": "angeknackst",
    "angeknackstesten": "angeknackst",
    "angeknackstester": "angeknackst",
    "angeknackstestes": "angeknackst",
    "angeknipst": "anknipsen",
    "angeknipste": "angeknipst",
    "angeknipstem": "angeknipst",
    "angeknipsten": "angeknipst",
    "angeknipster": "angeknipst",
    "angeknipstes": "angeknipst",
    "angeknöpft": "anknöpfen",
    "angeknöpfte": "angeknöpft",
    "angeknöpftem": "angeknöpft",
    "angeknöpften": "angeknöpft",
    "angeknöpfter": "angeknöpft",
    "angeknöpftes": "angeknöpft",
    "angeknüpft": "anknüpfen",
    "angeknüpfte": "angeknüpft",
    "angeknüpftem": "angeknüpft",
    "angeknüpften": "angeknüpft",
    "angeknüpfter": "angeknüpft",
    "angeknüpftes": "angeknüpft",
    "angekohlt": "ankohlen",
    "angekohlte": "angekohlt",
    "angekohltem": "angekohlt",
    "angekohlten": "angekohlt",
    "angekohlter": "angekohlt",
    "angekohltere": "angekohlt",
    "angekohlterem": "angekohlt",
    "angekohlteren": "angekohlt",
    "angekohlterer": "angekohlt",
    "angekohlteres": "angekohlt",
    "angekohltes": "angekohlt",
    "angekohlteste": "angekohlt",
    "angekohltestem": "angekohlt",
    "angekohltesten": "angekohlt",
    "angekohltester": "angekohlt",
    "angekohltestes": "angekohlt",
    "angekommen": "ankommen",
    "angekommene": "angekommen",
    "angekommenem": "angekommen",
    "angekommenen": "angekommen",
    "angekommener": "angekommen",
    "angekommenes": "angekommen",
    "angekoppelt": "ankoppeln",
    "angekoppelte": "angekoppelt",
    "angekoppeltem": "angekoppelt",
    "angekoppelten": "angekoppelt",
    "angekoppelter": "angekoppelt",
    "angekoppeltes": "angekoppelt",
    "angekotzt": "ankotzen",
    "angekotzte": "angekotzt",
    "angekotztem": "angekotzt",
    "angekotzten": "angekotzt",
    "angekotzter": "angekotzt",
    "angekotztes": "angekotzt",
    "angekrallt": "ankrallen",
    "angekrallte": "angekrallt",
    "angekralltem": "angekrallt",
    "angekrallten": "angekrallt",
    "angekrallter": "angekrallt",
    "angekralltes": "angekrallt",
    "angekreidet": "ankreiden",
    "angekreidete": "angekreidet",
    "angekreidetem": "angekreidet",
    "angekreideten": "angekreidet",
    "angekreideter": "angekreidet",
    "angekreidetes": "angekreidet",
    "angekreuzt": "ankreuzen",
    "angekreuzte": "angekreuzt",
    "angekreuztem": "angekreuzt",
    "angekreuzten": "angekreuzt",
    "angekreuzter": "angekreuzt",
    "angekreuztes": "angekreuzt",
    "angekuppelt": "ankuppeln",
    "angekuppelte": "angekuppelt",
    "angekuppeltem": "angekuppelt",
    "angekuppelten": "angekuppelt",
    "angekuppelter": "angekuppelt",
    "angekuppeltes": "angekuppelt",
    "angekurbelt": "ankurbeln",
    "angekurbelte": "angekurbelt",
    "angekurbeltem": "angekurbelt",
    "angekurbelten": "angekurbelt",
    "angekurbelter": "angekurbelt",
    "angekurbeltere": "angekurbelt",
    "angekurbelterem": "angekurbelt",
    "angekurbelteren": "angekurbelt",
    "angekurbelterer": "angekurbelt",
    "angekurbelteres": "angekurbelt",
    "angekurbeltes": "angekurbelt",
    "angekurbelteste": "angekurbelt",
    "angekurbeltestem": "angekurbelt",
    "angekurbeltesten": "angekurbelt",
    "angekurbeltester": "angekurbelt",
    "angekurbeltestes": "angekurbelt",
    "angekämpft": "ankämpfen",
    "angekämpfte": "angekämpft",
    "angekämpftem": "angekämpft",
    "angekämpften": "angekämpft",
    "angekämpfter": "angekämpft",
    "angekämpftes": "angekämpft",
    "angeködert": "anködern",
    "angeköderte": "angeködert",
    "angeködertem": "angeködert",
    "angeköderten": "angeködert",
    "angeköderter": "angeködert",
    "angeködertes": "angeködert",
    "angekündigt": "ankündigen",
    "angekündigte": "angekündigt",
    "angekündigtem": "angekündigt",
    "angekündigten": "angekündigt",
    "angekündigter": "angekündigt",
    "angekündigtes": "angekündigt",
    "angelacht": "anlachen",
    "angelachte": "angelacht",
    "angelachtem": "angelacht",
    "angelachten": "angelacht",
    "angelachter": "angelacht",
    "angelachtes": "angelacht",
    "angelagert": "anlagern",
    "angelagerte": "angelagert",
    "angelagertem": "angelagert",
    "angelagerten": "angelagert",
    "angelagerter": "angelagert",
    "angelagertes": "angelagert",
    "angelassen": "anlassen",
    "angelassene": "angelassen",
    "angelassenem": "angelassen",
    "angelassenen": "angelassen",
    "angelassener": "angelassen",
    "angelassenes": "angelassen",
    "angelastet": "anlasten",
    "angelastete": "angelastet",
    "angelastetem": "angelastet",
    "angelasteten": "angelastet",
    "angelasteter": "angelastet",
    "angelastetes": "angelastet",
    "angelaufen": "anlaufen",
    "angelaufene": "angelaufen",
    "angelaufenem": "angelaufen",
    "angelaufenen": "angelaufen",
    "angelaufener": "angelaufen",
    "angelaufenes": "angelaufen",
    "angelautet": "anlauten",
    "angelautete": "angelautet",
    "angelautetem": "angelautet",
    "angelauteten": "angelautet",
    "angelauteter": "angelautet",
    "angelautetes": "angelautet",
    "angele": "angeln",
    "angelegen": "anliegen",
    "angelegene": "angelegen",
    "angelegenem": "angelegen",
    "angelegenen": "angelegen",
    "angelegener": "angelegen",
    "angelegenes": "angelegen",
    "angelegt": "anlegen",
    "angelegte": "angelegt",
    "angelegtem": "angelegt",
    "angelegten": "angelegt",
    "angelegter": "angelegt",
    "angelegtes": "angelegt",
    "angelehnt": "anlehnen",
    "angelehnte": "angelehnt",
    "angelehntem": "angelehnt",
    "angelehnten": "angelehnt",
    "angelehnter": "angelehnt",
    "angelehntes": "angelehnt",
    "angeleimt": "anleimen",
    "angeleimte": "angeleimt",
    "angeleimtem": "angeleimt",
    "angeleimten": "angeleimt",
    "angeleimter": "angeleimt",
    "angeleimtes": "angeleimt",
    "angeleint": "anleinen",
    "angeleinte": "angeleint",
    "angeleintem": "angeleint",
    "angeleinten": "angeleint",
    "angeleinter": "angeleint",
    "angeleintes": "angeleint",
    "angeleitet": "anleiten",
    "angeleitete": "angeleitet",
    "angeleitetem": "angeleitet",
    "angeleiteten": "angeleitet",
    "angeleiteter": "angeleitet",
    "angeleitetes": "angeleitet",
    "angelernt": "anlernen",
    "angelernte": "angelernt",
    "angelerntem": "angelernt",
    "angelernten": "angelernt",
    "angelernter": "angelernt",
    "angelerntes": "angelernt",
    "angelesen": "anlesen",
    "angelesene": "angelesen",
    "angelesenem": "angelesen",
    "angelesenen": "angelesen",
    "angelesener": "angelesen",
    "angelesenes": "angelesen",
    "angeleuchtet": "anleuchten",
    "angeleuchtete": "angeleuchtet",
    "angeleuchtetem": "angeleuchtet",
    "angeleuchteten": "angeleuchtet",
    "angeleuchteter": "angeleuchtet",
    "angeleuchtetes": "angeleuchtet",
    "angeliefert": "anliefern",
    "angelieferte": "angeliefert",
    "angeliefertem": "angeliefert",
    "angelieferten": "angeliefert",
    "angelieferter": "angeliefert",
    "angeliefertes": "angeliefert",
    "angelnd": "angeln",
    "angelnde": "angelnd",
    "angelndem": "angelnd",
    "angelnden": "angelnd",
    "angelnder": "angelnd",
    "angelndere": "angelnd",
    "angelnderem": "angelnd",
    "angelnderen": "angelnd",
    "angelnderer": "angelnd",
    "angelnderes": "angelnd",
    "angelndes": "angelnd",
    "angelndste": "angelnd",
    "angelndstem": "angelnd",
    "angelndsten": "angelnd",
    "angelndster": "angelnd",
    "angelndstes": "angelnd",
    "angelogen": "anlügen",
    "angelogene": "angelogen",
    "angelogenem": "angelogen",
    "angelogenen": "angelogen",
    "angelogener": "angelogen",
    "angelogenere": "angelogen",
    "angelogenerem": "angelogen",
    "angelogeneren": "angelogen",
    "angelogenerer": "angelogen",
    "angelogeneres": "angelogen",
    "angelogenes": "angelogen",
    "angelogenste": "angelogen",
    "angelogenstem": "angelogen",
    "angelogensten": "angelogen",
    "angelogenster": "angelogen",
    "angelogenstes": "angelogen",
    "angelst": "angeln",
    "angelsächsische": "angelsächsisch",
    "angelsächsischem": "angelsächsisch",
    "angelsächsischen": "angelsächsisch",
    "angelsächsischer": "angelsächsisch",
    "angelsächsisches": "angelsächsisch",
    "angelt": "angeln",
    "angelte": "angeln",
    "angelten": "angeln",
    "angeltest": "angeln",
    "angeltet": "angeln",
    "angelächelt": "anlächeln",
    "angelächelte": "angelächelt",
    "angelächeltem": "angelächelt",
    "angelächelten": "angelächelt",
    "angelächelter": "angelächelt",
    "angelächeltes": "angelächelt",
    "angeläutet": "anläuten",
    "angeläutetem": "angeläutet",
    "angeläuteter": "angeläutet",
    "angeläutetes": "angeläutet",
    "angelötet": "anlöten",
    "angelötete": "angelötet",
    "angelötetem": "angelötet",
    "angelöteten": "angelötet",
    "angelöteter": "angelötet",
    "angelötetes": "angelötet",
    "angemacht": "anmachen",
    "angemachte": "angemacht",
    "angemachtem": "angemacht",
    "angemachten": "angemacht",
    "angemachter": "angemacht",
    "angemachtes": "angemacht",
    "angemahnt": "anmahnen",
    "angemahnte": "angemahnt",
    "angemahntem": "angemahnt",
    "angemahnten": "angemahnt",
    "angemahnter": "angemahnt",
    "angemahntes": "angemahnt",
    "angemalt": "anmalen",
    "angemalte": "angemalt",
    "angemaltem": "angemalt",
    "angemalten": "angemalt",
    "angemalter": "angemalt",
    "angemaltere": "angemalt",
    "angemalterem": "angemalt",
    "angemalteren": "angemalt",
    "angemalterer": "angemalt",
    "angemalteres": "angemalt",
    "angemaltes": "angemalt",
    "angemalteste": "angemalt",
    "angemaltestem": "angemalt",
    "angemaltesten": "angemalt",
    "angemaltester": "angemalt",
    "angemaltestes": "angemalt",
    "angemaßt": "anmaßen",
    "angemaßte": "angemaßt",
    "angemaßtem": "angemaßt",
    "angemaßten": "angemaßt",
    "angemaßter": "angemaßt",
    "angemaßtes": "angemaßt",
    "angemeldet": "anmelden",
    "angemeldete": "angemeldet",
    "angemeldetem": "angemeldet",
    "angemeldeten": "angemeldet",
    "angemeldeter": "angemeldet",
    "angemeldetes": "angemeldet",
    "angemerkt": "anmerken",
    "angemerkte": "angemerkt",
    "angemerktem": "angemerkt",
    "angemerkten": "angemerkt",
    "angemerkter": "angemerkt",
    "angemerktes": "angemerkt",
    "angemessen": "anmessen",
    "angemessene": "angemessen",
    "angemessenem": "angemessen",
    "angemessenen": "angemessen",
    "angemessener": "angemessen",
    "angemessenere": "angemessen",
    "angemessenerem": "angemessen",
    "angemesseneren": "angemessen",
    "angemessenerer": "angemessen",
    "angemesseneres": "angemessen",
    "angemessenes": "angemessen",
    "angemessenste": "angemessen",
    "angemessenstem": "angemessen",
    "angemessensten": "angemessen",
    "angemessenster": "angemessen",
    "angemessenstes": "angemessen",
    "angemietet": "anmieten",
    "angemietete": "angemietet",
    "angemietetem": "angemietet",
    "angemieteten": "angemietet",
    "angemieteter": "angemietet",
    "angemietetes": "angemietet",
    "angemotzt": "anmotzen",
    "angemotzte": "angemotzt",
    "angemotztem": "angemotzt",
    "angemotzten": "angemotzt",
    "angemotzter": "angemotzt",
    "angemotztere": "angemotzt",
    "angemotzterem": "angemotzt",
    "angemotzteren": "angemotzt",
    "angemotzterer": "angemotzt",
    "angemotzteres": "angemotzt",
    "angemotztes": "angemotzt",
    "angemotzteste": "angemotzt",
    "angemotztestem": "angemotzt",
    "angemotztesten": "angemotzt",
    "angemotztester": "angemotzt",
    "angemotztestes": "angemotzt",
    "angemustert": "anmustern",
    "angemusterte": "angemustert",
    "angemustertem": "angemustert",
    "angemusterten": "angemustert",
    "angemusterter": "angemustert",
    "angemustertes": "angemustert",
    "angemutet": "anmuten",
    "angemutete": "angemutet",
    "angemutetem": "angemutet",
    "angemuteten": "angemutet",
    "angemuteter": "angemutet",
    "angemutetes": "angemutet",
    "angenagelt": "annageln",
    "angenagelte": "angenagelt",
    "angenageltem": "angenagelt",
    "angenagelten": "angenagelt",
    "angenagelter": "angenagelt",
    "angenageltes": "angenagelt",
    "angenagt": "annagen",
    "angenagte": "angenagt",
    "angenagtem": "angenagt",
    "angenagten": "angenagt",
    "angenagter": "angenagt",
    "angenagtere": "angenagt",
    "angenagterem": "angenagt",
    "angenagteren": "angenagt",
    "angenagterer": "angenagt",
    "angenagteres": "angenagt",
    "angenagtes": "angenagt",
    "angenagteste": "angenagt",
    "angenagtestem": "angenagt",
    "angenagtesten": "angenagt",
    "angenagtester": "angenagt",
    "angenagtestes": "angenagt",
    "angenehme": "angenehm",
    "angenehmem": "angenehm",
    "angenehmen": "angenehm",
    "angenehmer": "angenehm",
    "angenehmere": "angenehm",
    "angenehmerem": "angenehm",
    "angenehmeren": "angenehm",
    "angenehmerer": "angenehm",
    "angenehmeres": "angenehm",
    "angenehmes": "angenehm",
    "angenehmste": "angenehm",
    "angenehmstem": "angenehm",
    "angenehmsten": "angenehm",
    "angenehmster": "angenehm",
    "angenehmstes": "angenehm",
    "angenietet": "annieten",
    "angenietete": "angenietet",
    "angenietetem": "angenietet",
    "angenieteten": "angenietet",
    "angenieteter": "angenietet",
    "angenietetes": "angenietet",
    "angenommen": "annehmen",
    "angenommene": "angenommen",
    "angenommenem": "angenommen",
    "angenommenen": "angenommen",
    "angenommener": "angenommen",
    "angenommenere": "angenommen",
    "angenommenerem": "angenommen",
    "angenommeneren": "angenommen",
    "angenommenerer": "angenommen",
    "angenommeneres": "angenommen",
    "angenommenes": "angenommen",
    "angenommenste": "angenommen",
    "angenommenstem": "angenommen",
    "angenommensten": "angenommen",
    "angenommenster": "angenommen",
    "angenommenstes": "angenommen",
    "angenähert": "annähern",
    "angenäherte": "angenähert",
    "angenähertem": "angenähert",
    "angenäherten": "angenähert",
    "angenäherter": "angenähert",
    "angenähertes": "angenähert",
    "angenäht": "annähen",
    "angenähte": "angenäht",
    "angenähtem": "angenäht",
    "angenähten": "angenäht",
    "angenähter": "angenäht",
    "angenähtes": "angenäht",
    "angeordnet": "anordnen",
    "angeordnete": "angeordnet",
    "angeordnetem": "angeordnet",
    "angeordneten": "angeordnet",
    "angeordneter": "angeordnet",
    "angeordnetere": "angeordnet",
    "angeordneterem": "angeordnet",
    "angeordneteren": "angeordnet",
    "angeordneterer": "angeordnet",
    "angeordneteres": "angeordnet",
    "angeordnetes": "angeordnet",
    "angeordneteste": "angeordnet",
    "angeordnetestem": "angeordnet",
    "angeordnetesten": "angeordnet",
    "angeordnetester": "angeordnet",
    "angeordnetestes": "angeordnet",
    "angepackt": "anpacken",
    "angepackte": "angepackt",
    "angepacktem": "angepackt",
    "angepackten": "angepackt",
    "angepackter": "angepackt",
    "angepacktes": "angepackt",
    "angepaddelt": "anpaddeln",
    "angepaddelte": "angepaddelt",
    "angepaddeltem": "angepaddelt",
    "angepaddelten": "angepaddelt",
    "angepaddelter": "angepaddelt",
    "angepaddeltes": "angepaddelt",
    "angepaßt": "anpassen",
    "angepaßte": "angepaßt",
    "angepaßtem": "angepaßt",
    "angepaßten": "angepaßt",
    "angepaßter": "angepaßt",
    "angepaßtere": "angepaßt",
    "angepaßterem": "angepaßt",
    "angepaßteren": "angepaßt",
    "angepaßterer": "angepaßt",
    "angepaßteres": "angepaßt",
    "angepaßtes": "angepaßt",
    "angepaßteste": "angepaßt",
    "angepaßtestem": "angepaßt",
    "angepaßtesten": "angepaßt",
    "angepaßtester": "angepaßt",
    "angepaßtestes": "angepaßt",
    "angepeilt": "anpeilen",
    "angepeilte": "angepeilt",
    "angepeiltem": "angepeilt",
    "angepeilten": "angepeilt",
    "angepeilter": "angepeilt",
    "angepeiltes": "angepeilt",
    "angepfiffen": "anpfeifen",
    "angepfiffene": "angepfiffen",
    "angepfiffenem": "angepfiffen",
    "angepfiffenen": "angepfiffen",
    "angepfiffener": "angepfiffen",
    "angepfiffenes": "angepfiffen",
    "angepflanzt": "anpflanzen",
    "angepflanzte": "angepflanzt",
    "angepflanztem": "angepflanzt",
    "angepflanzten": "angepflanzt",
    "angepflanzter": "angepflanzt",
    "angepflanztes": "angepflanzt",
    "angepflaumt": "anpflaumen",
    "angepflaumte": "angepflaumt",
    "angepflaumtem": "angepflaumt",
    "angepflaumten": "angepflaumt",
    "angepflaumter": "angepflaumt",
    "angepflaumtere": "angepflaumt",
    "angepflaumterem": "angepflaumt",
    "angepflaumteren": "angepflaumt",
    "angepflaumterer": "angepflaumt",
    "angepflaumteres": "angepflaumt",
    "angepflaumtes": "angepflaumt",
    "angepflaumteste": "angepflaumt",
    "angepflaumtestem": "angepflaumt",
    "angepflaumtesten": "angepflaumt",
    "angepflaumtester": "angepflaumt",
    "angepflaumtestes": "angepflaumt",
    "angepirscht": "anpirschen",
    "angepirschte": "angepirscht",
    "angepirschtem": "angepirscht",
    "angepirschten": "angepirscht",
    "angepirschter": "angepirscht",
    "angepirschtes": "angepirscht",
    "angeprallt": "anprallen",
    "angeprallte": "angeprallt",
    "angepralltem": "angeprallt",
    "angeprallten": "angeprallt",
    "angeprallter": "angeprallt",
    "angepralltes": "angeprallt",
    "angeprangert": "anprangern",
    "angeprangerte": "angeprangert",
    "angeprangertem": "angeprangert",
    "angeprangerten": "angeprangert",
    "angeprangerter": "angeprangert",
    "angeprangertere": "angeprangert",
    "angeprangerterem": "angeprangert",
    "angeprangerteren": "angeprangert",
    "angeprangerterer": "angeprangert",
    "angeprangerteres": "angeprangert",
    "angeprangertes": "angeprangert",
    "angeprangerteste": "angeprangert",
    "angeprangertestem": "angeprangert",
    "angeprangertesten": "angeprangert",
    "angeprangertester": "angeprangert",
    "angeprangertestes": "angeprangert",
    "angepreßt": "anpressen",
    "angepreßte": "angepreßt",
    "angepreßtem": "angepreßt",
    "angepreßten": "angepreßt",
    "angepreßter": "angepreßt",
    "angepreßtes": "angepreßt",
    "angepriesen": "anpreisen",
    "angepriesene": "angepriesen",
    "angepriesenem": "angepriesen",
    "angepriesenen": "angepriesen",
    "angepriesener": "angepriesen",
    "angepriesenere": "angepriesen",
    "angepriesenerem": "angepriesen",
    "angeprieseneren": "angepriesen",
    "angepriesenerer": "angepriesen",
    "angeprieseneres": "angepriesen",
    "angepriesenes": "angepriesen",
    "angepriesenste": "angepriesen",
    "angepriesenstem": "angepriesen",
    "angepriesensten": "angepriesen",
    "angepriesenster": "angepriesen",
    "angepriesenstes": "angepriesen",
    "angepumpt": "anpumpen",
    "angepumpte": "angepumpt",
    "angepumptem": "angepumpt",
    "angepumpten": "angepumpt",
    "angepumpter": "angepumpt",
    "angepumptes": "angepumpt",
    "angeputzt": "anputzen",
    "angeputzte": "angeputzt",
    "angeputztem": "angeputzt",
    "angeputzten": "angeputzt",
    "angeputzter": "angeputzt",
    "angeputztes": "angeputzt",
    "angepöbelt": "anpöbeln",
    "angepöbelte": "angepöbelt",
    "angepöbeltem": "angepöbelt",
    "angepöbelten": "angepöbelt",
    "angepöbelter": "angepöbelt",
    "angepöbeltere": "angepöbelt",
    "angepöbelterem": "angepöbelt",
    "angepöbelteren": "angepöbelt",
    "angepöbelterer": "angepöbelt",
    "angepöbelteres": "angepöbelt",
    "angepöbeltes": "angepöbelt",
    "angepöbelteste": "angepöbelt",
    "angepöbeltestem": "angepöbelt",
    "angepöbeltesten": "angepöbelt",
    "angepöbeltester": "angepöbelt",
    "angepöbeltestes": "angepöbelt",
    "angequält": "anquälen",
    "angequälte": "angequält",
    "angequältem": "angequält",
    "angequälten": "angequält",
    "angequälter": "angequält",
    "angequältes": "angequält",
    "angerannt": "anrennen",
    "angerannte": "angerannt",
    "angeranntem": "angerannt",
    "angerannten": "angerannt",
    "angerannter": "angerannt",
    "angeranntes": "angerannt",
    "angeranzt": "anranzen",
    "angeranzte": "angeranzt",
    "angeranztem": "angeranzt",
    "angeranzten": "angeranzt",
    "angeranzter": "angeranzt",
    "angeranztere": "angeranzt",
    "angeranzterem": "angeranzt",
    "angeranzteren": "angeranzt",
    "angeranzterer": "angeranzt",
    "angeranzteres": "angeranzt",
    "angeranztes": "angeranzt",
    "angeranzteste": "angeranzt",
    "angeranztestem": "angeranzt",
    "angeranztesten": "angeranzt",
    "angeranztester": "angeranzt",
    "angeranztestes": "angeranzt",
    "angeraten": "anraten",
    "angeratene": "angeraten",
    "angeratenem": "angeraten",
    "angeratenen": "angeraten",
    "angeratener": "angeraten",
    "angeratenes": "angeraten",
    "angerauht": "anrauhen",
    "angerauhte": "angerauht",
    "angerauhtem": "angerauht",
    "angerauhten": "angerauht",
    "angerauhter": "angerauht",
    "angerauhtere": "angerauht",
    "angerauhterem": "angerauht",
    "angerauhteren": "angerauht",
    "angerauhterer": "angerauht",
    "angerauhteres": "angerauht",
    "angerauhtes": "angerauht",
    "angerauhteste": "angerauht",
    "angerauhtestem": "angerauht",
    "angerauhtesten": "angerauht",
    "angerauhtester": "angerauht",
    "angerauhtestes": "angerauht",
    "angerechnet": "anrechnen",
    "angerechnete": "angerechnet",
    "angerechnetem": "angerechnet",
    "angerechneten": "angerechnet",
    "angerechneter": "angerechnet",
    "angerechnetes": "angerechnet",
    "angeredet": "anreden",
    "angeredete": "angeredet",
    "angeredetem": "angeredet",
    "angeredeten": "angeredet",
    "angeredeter": "angeredet",
    "angeredetes": "angeredet",
    "angeregt": "anregen",
    "angeregte": "angeregt",
    "angeregtem": "angeregt",
    "angeregten": "angeregt",
    "angeregter": "angeregt",
    "angeregtere": "angeregt",
    "angeregterem": "angeregt",
    "angeregteren": "angeregt",
    "angeregterer": "angeregt",
    "angeregteres": "angeregt",
    "angeregtes": "angeregt",
    "angeregteste": "angeregt",
    "angeregtestem": "angeregt",
    "angeregtesten": "angeregt",
    "angeregtester": "angeregt",
    "angeregtestes": "angeregt",
    "angereichert": "anreichern",
    "angereicherte": "angereichert",
    "angereichertem": "angereichert",
    "angereicherten": "angereichert",
    "angereicherter": "angereichert",
    "angereichertes": "angereichert",
    "angereicht": "anreichen",
    "angereichte": "angereicht",
    "angereichtem": "angereicht",
    "angereichten": "angereicht",
    "angereichter": "angereicht",
    "angereichtes": "angereicht",
    "angereiht": "anreihen",
    "angereihte": "angereiht",
    "angereihtem": "angereiht",
    "angereihten": "angereiht",
    "angereihter": "angereiht",
    "angereihtes": "angereiht",
    "angereist": "anreisen",
    "angereiste": "angereist",
    "angereistem": "angereist",
    "angereisten": "angereist",
    "angereister": "angereist",
    "angereistes": "angereist",
    "angereizt": "anreizen",
    "angereizte": "angereizt",
    "angereiztem": "angereizt",
    "angereizten": "angereizt",
    "angereizter": "angereizt",
    "angereiztere": "angereizt",
    "angereizterem": "angereizt",
    "angereizteren": "angereizt",
    "angereizterer": "angereizt",
    "angereizteres": "angereizt",
    "angereiztes": "angereizt",
    "angereizteste": "angereizt",
    "angereiztestem": "angereizt",
    "angereiztesten": "angereizt",
    "angereiztester": "angereizt",
    "angereiztestes": "angereizt",
    "angerempelt": "anrempeln",
    "angerempelte": "angerempelt",
    "angerempeltem": "angerempelt",
    "angerempelten": "angerempelt",
    "angerempelter": "angerempelt",
    "angerempeltes": "angerempelt",
    "angerichtet": "anrichten",
    "angerichtete": "angerichtet",
    "angerichtetem": "angerichtet",
    "angerichteten": "angerichtet",
    "angerichteter": "angerichtet",
    "angerichtetes": "angerichtet",
    "angerieben": "anreiben",
    "angeriebene": "angerieben",
    "angeriebenem": "angerieben",
    "angeriebenen": "angerieben",
    "angeriebener": "angerieben",
    "angeriebenes": "angerieben",
    "angerissen": "anreißen",
    "angerissene": "angerissen",
    "angerissenem": "angerissen",
    "angerissenen": "angerissen",
    "angerissener": "angerissen",
    "angerissenere": "angerissen",
    "angerissenerem": "angerissen",
    "angerisseneren": "angerissen",
    "angerissenerer": "angerissen",
    "angerisseneres": "angerissen",
    "angerissenes": "angerissen",
    "angerissenste": "angerissen",
    "angerissenstem": "angerissen",
    "angerissensten": "angerissen",
    "angerissenster": "angerissen",
    "angerissenstes": "angerissen",
    "angeritten": "anreiten",
    "angerittene": "angeritten",
    "angerittenem": "angeritten",
    "angerittenen": "angeritten",
    "angerittener": "angeritten",
    "angerittenes": "angeritten",
    "angerollt": "anrollen",
    "angerollte": "angerollt",
    "angerolltem": "angerollt",
    "angerollten": "angerollt",
    "angerollter": "angerollt",
    "angerolltes": "angerollt",
    "angerudert": "anrudern",
    "angeruderte": "angerudert",
    "angerudertem": "angerudert",
    "angeruderten": "angerudert",
    "angeruderter": "angerudert",
    "angerudertes": "angerudert",
    "angerufen": "anrufen",
    "angerufene": "angerufen",
    "angerufenem": "angerufen",
    "angerufenen": "angerufen",
    "angerufener": "angerufen",
    "angerufenes": "angerufen",
    "angerückt": "anrücken",
    "angerückte": "angerückt",
    "angerücktem": "angerückt",
    "angerückten": "angerückt",
    "angerückter": "angerückt",
    "angerücktes": "angerückt",
    "angerührt": "anrühren",
    "angerührte": "angerührt",
    "angerührtem": "angerührt",
    "angerührten": "angerührt",
    "angerührter": "angerührt",
    "angerührtes": "angerührt",
    "angesagt": "ansagen",
    "angesagte": "angesagt",
    "angesagtem": "angesagt",
    "angesagten": "angesagt",
    "angesagter": "angesagt",
    "angesagtere": "angesagt",
    "angesagterem": "angesagt",
    "angesagteren": "angesagt",
    "angesagterer": "angesagt",
    "angesagteres": "angesagt",
    "angesagtes": "angesagt",
    "angesagteste": "angesagt",
    "angesagtestem": "angesagt",
    "angesagtesten": "angesagt",
    "angesagtester": "angesagt",
    "angesagtestes": "angesagt",
    "angesammelt": "ansammeln",
    "angesammelte": "angesammelt",
    "angesammeltem": "angesammelt",
    "angesammelten": "angesammelt",
    "angesammelter": "angesammelt",
    "angesammeltes": "angesammelt",
    "angesamt": "ansamen",
    "angesamte": "angesamt",
    "angesamtem": "angesamt",
    "angesamten": "angesamt",
    "angesamter": "angesamt",
    "angesamtes": "angesamt",
    "angesaugt": "ansaugen",
    "angesaugte": "angesaugt",
    "angesaugtem": "angesaugt",
    "angesaugten": "angesaugt",
    "angesaugter": "angesaugt",
    "angesaugtes": "angesaugt",
    "angeschafft": "anschaffen",
    "angeschaffte": "angeschafft",
    "angeschafftem": "angeschafft",
    "angeschafften": "angeschafft",
    "angeschaffter": "angeschafft",
    "angeschafftes": "angeschafft",
    "angeschaltet": "anschalten",
    "angeschaltete": "angeschaltet",
    "angeschaltetem": "angeschaltet",
    "angeschalteten": "angeschaltet",
    "angeschalteter": "angeschaltet",
    "angeschaltetes": "angeschaltet",
    "angeschaut": "anschauen",
    "angeschaute": "angeschaut",
    "angeschautem": "angeschaut",
    "angeschauten": "angeschaut",
    "angeschauter": "angeschaut",
    "angeschautes": "angeschaut",
    "angeschienen": "anscheinen",
    "angeschienene": "angeschienen",
    "angeschienenem": "angeschienen",
    "angeschienenen": "angeschienen",
    "angeschienener": "angeschienen",
    "angeschienenes": "angeschienen",
    "angeschifft": "anschiffen",
    "angeschiffte": "angeschifft",
    "angeschifftem": "angeschifft",
    "angeschifften": "angeschifft",
    "angeschiffter": "angeschifft",
    "angeschifftes": "angeschifft",
    "angeschirrt": "anschirren",
    "angeschirrte": "angeschirrt",
    "angeschirrtem": "angeschirrt",
    "angeschirrten": "angeschirrt",
    "angeschirrter": "angeschirrt",
    "angeschirrtes": "angeschirrt",
    "angeschissen": "anscheißen",
    "angeschissene": "angeschissen",
    "angeschissenem": "angeschissen",
    "angeschissenen": "angeschissen",
    "angeschissener": "angeschissen",
    "angeschissenere": "angeschissen",
    "angeschissenerem": "angeschissen",
    "angeschisseneren": "angeschissen",
    "angeschissenerer": "angeschissen",
    "angeschisseneres": "angeschissen",
    "angeschissenes": "angeschissen",
    "angeschissenste": "angeschissen",
    "angeschissenstem": "angeschissen",
    "angeschissensten": "angeschissen",
    "angeschissenster": "angeschissen",
    "angeschissenstes": "angeschissen",
    "angeschlagen": "anschlagen",
    "angeschlagene": "angeschlagen",
    "angeschlagenem": "angeschlagen",
    "angeschlagenen": "angeschlagen",
    "angeschlagener": "angeschlagen",
    "angeschlagenes": "angeschlagen",
    "angeschleift": "anschleifen",
    "angeschleifte": "angeschleift",
    "angeschleiftem": "angeschleift",
    "angeschleiften": "angeschleift",
    "angeschleifter": "angeschleift",
    "angeschleiftes": "angeschleift",
    "angeschlichen": "anschleichen",
    "angeschlichene": "angeschlichen",
    "angeschlichenem": "angeschlichen",
    "angeschlichenen": "angeschlichen",
    "angeschlichener": "angeschlichen",
    "angeschlichenes": "angeschlichen",
    "angeschliffen": "anschleifen",
    "angeschliffene": "angeschliffen",
    "angeschliffenem": "angeschliffen",
    "angeschliffenen": "angeschliffen",
    "angeschliffener": "angeschliffen",
    "angeschliffenere": "angeschliffen",
    "angeschliffenerem": "angeschliffen",
    "angeschliffeneren": "angeschliffen",
    "angeschliffenerer": "angeschliffen",
    "angeschliffeneres": "angeschliffen",
    "angeschliffenes": "angeschliffen",
    "angeschliffenste": "angeschliffen",
    "angeschliffenstem": "angeschliffen",
    "angeschliffensten": "angeschliffen",
    "angeschliffenster": "angeschliffen",
    "angeschliffenstes": "angeschliffen",
    "angeschlossen": "anschließen",
    "angeschlossene": "angeschlossen",
    "angeschlossenem": "angeschlossen",
    "angeschlossenen": "angeschlossen",
    "angeschlossener": "angeschlossen",
    "angeschlossenere": "angeschlossen",
    "angeschlossenerem": "angeschlossen",
    "angeschlosseneren": "angeschlossen",
    "angeschlossenerer": "angeschlossen",
    "angeschlosseneres": "angeschlossen",
    "angeschlossenes": "angeschlossen",
    "angeschlossenste": "angeschlossen",
    "angeschlossenstem": "angeschlossen",
    "angeschlossensten": "angeschlossen",
    "angeschlossenster": "angeschlossen",
    "angeschlossenstes": "angeschlossen",
    "angeschlämmt": "anschlämmen",
    "angeschlämmte": "angeschlämmt",
    "angeschlämmtem": "angeschlämmt",
    "angeschlämmten": "angeschlämmt",
    "angeschlämmter": "angeschlämmt",
    "angeschlämmtes": "angeschlämmt",
    "angeschmiegt": "anschmiegen",
    "angeschmiegte": "angeschmiegt",
    "angeschmiegtem": "angeschmiegt",
    "angeschmiegten": "angeschmiegt",
    "angeschmiegter": "angeschmiegt",
    "angeschmiegtere": "angeschmiegt",
    "angeschmiegterem": "angeschmiegt",
    "angeschmiegteren": "angeschmiegt",
    "angeschmiegterer": "angeschmiegt",
    "angeschmiegteres": "angeschmiegt",
    "angeschmiegtes": "angeschmiegt",
    "angeschmiegteste": "angeschmiegt",
    "angeschmiegtestem": "angeschmiegt",
    "angeschmiegtesten": "angeschmiegt",
    "angeschmiegtester": "angeschmiegt",
    "angeschmiegtestes": "angeschmiegt",
    "angeschmiert": "anschmieren",
    "angeschmierte": "angeschmiert",
    "angeschmiertem": "angeschmiert",
    "angeschmierten": "angeschmiert",
    "angeschmierter": "angeschmiert",
    "angeschmiertes": "angeschmiert",
    "angeschmissen": "anschmeißen",
    "angeschmissene": "angeschmissen",
    "angeschmissenem": "angeschmissen",
    "angeschmissenen": "angeschmissen",
    "angeschmissener": "angeschmissen",
    "angeschmissenes": "angeschmissen",
    "angeschnallt": "anschnallen",
    "angeschnallte": "angeschnallt",
    "angeschnalltem": "angeschnallt",
    "angeschnallten": "angeschnallt",
    "angeschnallter": "angeschnallt",
    "angeschnalltes": "angeschnallt",
    "angeschnauzt": "anschnauzen",
    "angeschnauzte": "angeschnauzt",
    "angeschnauztem": "angeschnauzt",
    "angeschnauzten": "angeschnauzt",
    "angeschnauzter": "angeschnauzt",
    "angeschnauztes": "angeschnauzt",
    "angeschnitten": "anschneiden",
    "angeschnittene": "angeschnitten",
    "angeschnittenem": "angeschnitten",
    "angeschnittenen": "angeschnitten",
    "angeschnittener": "angeschnitten",
    "angeschnittenere": "angeschnitten",
    "angeschnittenerem": "angeschnitten",
    "angeschnitteneren": "angeschnitten",
    "angeschnittenerer": "angeschnitten",
    "angeschnitteneres": "angeschnitten",
    "angeschnittenes": "angeschnitten",
    "angeschnittenste": "angeschnitten",
    "angeschnittenstem": "angeschnitten",
    "angeschnittensten": "angeschnitten",
    "angeschnittenster": "angeschnitten",
    "angeschnittenstes": "angeschnitten",
    "angeschoben": "anschieben",
    "angeschobene": "angeschoben",
    "angeschobenem": "angeschoben",
    "angeschobenen": "angeschoben",
    "angeschobener": "angeschoben",
    "angeschobenes": "angeschoben",
    "angeschossen": "anschießen",
    "angeschossene": "angeschossen",
    "angeschossenem": "angeschossen",
    "angeschossenen": "angeschossen",
    "angeschossener": "angeschossen",
    "angeschossenes": "angeschossen",
    "angeschraubt": "anschrauben",
    "angeschraubte": "angeschraubt",
    "angeschraubtem": "angeschraubt",
    "angeschraubten": "angeschraubt",
    "angeschraubter": "angeschraubt",
    "angeschraubtes": "angeschraubt",
    "angeschrieben": "anschreiben",
    "angeschriebene": "angeschrieben",
    "angeschriebenem": "angeschrieben",
    "angeschriebenen": "angeschrieben",
    "angeschriebener": "angeschrieben",
    "angeschriebenes": "angeschrieben",
    "angeschrien": "anschreien",
    "angeschriene": "angeschrien",
    "angeschrienem": "angeschrien",
    "angeschrienen": "angeschrien",
    "angeschriener": "angeschrien",
    "angeschrienere": "angeschrien",
    "angeschrienerem": "angeschrien",
    "angeschrieneren": "angeschrien",
    "angeschrienerer": "angeschrien",
    "angeschrieneres": "angeschrien",
    "angeschrienes": "angeschrien",
    "angeschrienste": "angeschrien",
    "angeschrienstem": "angeschrien",
    "angeschriensten": "angeschrien",
    "angeschrienster": "angeschrien",
    "angeschrienstes": "angeschrien",
    "angeschrägt": "anschrägen",
    "angeschrägte": "angeschrägt",
    "angeschrägtem": "angeschrägt",
    "angeschrägten": "angeschrägt",
    "angeschrägter": "angeschrägt",
    "angeschrägtere": "angeschrägt",
    "angeschrägterem": "angeschrägt",
    "angeschrägteren": "angeschrägt",
    "angeschrägterer": "angeschrägt",
    "angeschrägteres": "angeschrägt",
    "angeschrägtes": "angeschrägt",
    "angeschrägteste": "angeschrägt",
    "angeschrägtestem": "angeschrägt",
    "angeschrägtesten": "angeschrägt",
    "angeschrägtester": "angeschrägt",
    "angeschrägtestes": "angeschrägt",
    "angeschweißt": "anschweißen",
    "angeschweißte": "angeschweißt",
    "angeschweißtem": "angeschweißt",
    "angeschweißten": "angeschweißt",
    "angeschweißter": "angeschweißt",
    "angeschweißtes": "angeschweißt",
    "angeschwellt": "anschwellen",
    "angeschwellte": "angeschwellt",
    "angeschwelltem": "angeschwellt",
    "angeschwellten": "angeschwellt",
    "angeschwellter": "angeschwellt",
    "angeschwelltes": "angeschwellt",
    "angeschwemmt": "anschwemmen",
    "angeschwemmte": "angeschwemmt",
    "angeschwemmtem": "angeschwemmt",
    "angeschwemmten": "angeschwemmt",
    "angeschwemmter": "angeschwemmt",
    "angeschwemmtes": "angeschwemmt",
    "angeschwiegen": "anschweigen",
    "angeschwiegene": "angeschwiegen",
    "angeschwiegenem": "angeschwiegen",
    "angeschwiegenen": "angeschwiegen",
    "angeschwiegener": "angeschwiegen",
    "angeschwiegenes": "angeschwiegen",
    "angeschwindelt": "anschwindeln",
    "angeschwindelte": "angeschwindelt",
    "angeschwindeltem": "angeschwindelt",
    "angeschwindelten": "angeschwindelt",
    "angeschwindelter": "angeschwindelt",
    "angeschwindeltes": "angeschwindelt",
    "angeschwollen": "anschwellen",
    "angeschwollene": "angeschwollen",
    "angeschwollenem": "angeschwollen",
    "angeschwollenen": "angeschwollen",
    "angeschwollener": "angeschwollen",
    "angeschwollenere": "angeschwollen",
    "angeschwollenerem": "angeschwollen",
    "angeschwolleneren": "angeschwollen",
    "angeschwollenerer": "angeschwollen",
    "angeschwolleneres": "angeschwollen",
    "angeschwollenes": "angeschwollen",
    "angeschwollenste": "angeschwollen",
    "angeschwollenstem": "angeschwollen",
    "angeschwollensten": "angeschwollen",
    "angeschwollenster": "angeschwollen",
    "angeschwollenstes": "angeschwollen",
    "angeschwommen": "anschwimmen",
    "angeschwommene": "angeschwommen",
    "angeschwommenem": "angeschwommen",
    "angeschwommenen": "angeschwommen",
    "angeschwommener": "angeschwommen",
    "angeschwommenes": "angeschwommen",
    "angeschwärzt": "anschwärzen",
    "angeschwärzte": "angeschwärzt",
    "angeschwärztem": "angeschwärzt",
    "angeschwärzten": "angeschwärzt",
    "angeschwärzter": "angeschwärzt",
    "angeschwärztere": "angeschwärzt",
    "angeschwärzterem": "angeschwärzt",
    "angeschwärzteren": "angeschwärzt",
    "angeschwärzterer": "angeschwärzt",
    "angeschwärzteres": "angeschwärzt",
    "angeschwärztes": "angeschwärzt",
    "angeschwärzteste": "angeschwärzt",
    "angeschwärztestem": "angeschwärzt",
    "angeschwärztesten": "angeschwärzt",
    "angeschwärztester": "angeschwärzt",
    "angeschwärztestes": "angeschwärzt",
    "angesehen": "ansehen",
    "angesehene": "angesehen",
    "angesehenem": "angesehen",
    "angesehenen": "angesehen",
    "angesehener": "angesehen",
    "angesehenere": "angesehen",
    "angesehenerem": "angesehen",
    "angeseheneren": "angesehen",
    "angesehenerer": "angesehen",
    "angeseheneres": "angesehen",
    "angesehenes": "angesehen",
    "angesehenste": "angesehen",
    "angesehenstem": "angesehen",
    "angesehensten": "angesehen",
    "angesehenster": "angesehen",
    "angesehenstes": "angesehen",
    "angeseilt": "anseilen",
    "angeseilte": "angeseilt",
    "angeseiltem": "angeseilt",
    "angeseilten": "angeseilt",
    "angeseilter": "angeseilt",
    "angeseiltere": "angeseilt",
    "angeseilterem": "angeseilt",
    "angeseilteren": "angeseilt",
    "angeseilterer": "angeseilt",
    "angeseilteres": "angeseilt",
    "angeseiltes": "angeseilt",
    "angeseilteste": "angeseilt",
    "angeseiltestem": "angeseilt",
    "angeseiltesten": "angeseilt",
    "angeseiltester": "angeseilt",
    "angeseiltestes": "angeseilt",
    "angesengt": "ansengen",
    "angesengte": "angesengt",
    "angesengtem": "angesengt",
    "angesengten": "angesengt",
    "angesengter": "angesengt",
    "angesengtere": "angesengt",
    "angesengterem": "angesengt",
    "angesengteren": "angesengt",
    "angesengterer": "angesengt",
    "angesengteres": "angesengt",
    "angesengtes": "angesengt",
    "angesengteste": "angesengt",
    "angesengtestem": "angesengt",
    "angesengtesten": "angesengt",
    "angesengtester": "angesengt",
    "angesengtestes": "angesengt",
    "angesessen": "ansitzen",
    "angesessene": "angesessen",
    "angesessenem": "angesessen",
    "angesessenen": "angesessen",
    "angesessener": "angesessen",
    "angesessenes": "angesessen",
    "angesetzt": "ansetzen",
    "angesetzte": "angesetzt",
    "angesetztem": "angesetzt",
    "angesetzten": "angesetzt",
    "angesetzter": "angesetzt",
    "angesetztes": "angesetzt",
    "angesiedelt": "ansiedeln",
    "angesiedelte": "angesiedelt",
    "angesiedeltem": "angesiedelt",
    "angesiedelten": "angesiedelt",
    "angesiedelter": "angesiedelt",
    "angesiedeltes": "angesiedelt",
    "angesoffen": "ansaufen",
    "angesoffene": "angesoffen",
    "angesoffenem": "angesoffen",
    "angesoffenen": "angesoffen",
    "angesoffener": "angesoffen",
    "angesoffenere": "angesoffen",
    "angesoffenerem": "angesoffen",
    "angesoffeneren": "angesoffen",
    "angesoffenerer": "angesoffen",
    "angesoffeneres": "angesoffen",
    "angesoffenes": "angesoffen",
    "angesoffenste": "angesoffen",
    "angesoffenstem": "angesoffen",
    "angesoffensten": "angesoffen",
    "angesoffenster": "angesoffen",
    "angesoffenstes": "angesoffen",
    "angesogen": "ansaugen",
    "angesogene": "angesogen",
    "angesogenem": "angesogen",
    "angesogenen": "angesogen",
    "angesogener": "angesogen",
    "angesogenes": "angesogen",
    "angesohlt": "ansohlen",
    "angesohlte": "angesohlt",
    "angesohltem": "angesohlt",
    "angesohlten": "angesohlt",
    "angesohlter": "angesohlt",
    "angesohltere": "angesohlt",
    "angesohlterem": "angesohlt",
    "angesohlteren": "angesohlt",
    "angesohlterer": "angesohlt",
    "angesohlteres": "angesohlt",
    "angesohltes": "angesohlt",
    "angesohlteste": "angesohlt",
    "angesohltestem": "angesohlt",
    "angesohltesten": "angesohlt",
    "angesohltester": "angesohlt",
    "angesohltestes": "angesohlt",
    "angespannt": "anspannen",
    "angespannte": "angespannt",
    "angespanntem": "angespannt",
    "angespannten": "angespannt",
    "angespannter": "angespannt",
    "angespanntere": "angespannt",
    "angespannterem": "angespannt",
    "angespannteren": "angespannt",
    "angespannterer": "angespannt",
    "angespannteres": "angespannt",
    "angespanntes": "angespannt",
    "angespannteste": "angespannt",
    "angespanntestem": "angespannt",
    "angespanntesten": "angespannt",
    "angespanntester": "angespannt",
    "angespanntestes": "angespannt",
    "angespart": "ansparen",
    "angesparte": "angespart",
    "angespartem": "angespart",
    "angesparten": "angespart",
    "angesparter": "angespart",
    "angespartere": "angespart",
    "angesparterem": "angespart",
    "angesparteren": "angespart",
    "angesparterer": "angespart",
    "angesparteres": "angespart",
    "angespartes": "angespart",
    "angesparteste": "angespart",
    "angespartestem": "angespart",
    "angespartesten": "angespart",
    "angespartester": "angespart",
    "angespartestes": "angespart",
    "angespielt": "anspielen",
    "angespielte": "angespielt",
    "angespieltem": "angespielt",
    "angespielten": "angespielt",
    "angespielter": "angespielt",
    "angespieltes": "angespielt",
    "angespien": "anspeien",
    "angespiene": "angespien",
    "angespienem": "angespien",
    "angespienen": "angespien",
    "angespiener": "angespien",
    "angespienes": "angespien",
    "angespitzt": "anspitzen",
    "angespitzte": "angespitzt",
    "angespitztem": "angespitzt",
    "angespitzten": "angespitzt",
    "angespitzter": "angespitzt",
    "angespitztere": "angespitzt",
    "angespitzterem": "angespitzt",
    "angespitzteren": "angespitzt",
    "angespitzterer": "angespitzt",
    "angespitzteres": "angespitzt",
    "angespitztes": "angespitzt",
    "angespitzteste": "angespitzt",
    "angespitztestem": "angespitzt",
    "angespitztesten": "angespitzt",
    "angespitztester": "angespitzt",
    "angespitztestes": "angespitzt",
    "angespornt": "anspornen",
    "angespornte": "angespornt",
    "angesporntem": "angespornt",
    "angespornten": "angespornt",
    "angespornter": "angespornt",
    "angesporntere": "angespornt",
    "angespornterem": "angespornt",
    "angespornteren": "angespornt",
    "angespornterer": "angespornt",
    "angespornteres": "angespornt",
    "angesporntes": "angespornt",
    "angespornteste": "angespornt",
    "angesporntestem": "angespornt",
    "angesporntesten": "angespornt",
    "angesporntester": "angespornt",
    "angesporntestes": "angespornt",
    "angesprengt": "ansprengen",
    "angesprengte": "angesprengt",
    "angesprengtem": "angesprengt",
    "angesprengten": "angesprengt",
    "angesprengter": "angesprengt",
    "angesprengtes": "angesprengt",
    "angespritzt": "anspritzen",
    "angespritzte": "angespritzt",
    "angespritztem": "angespritzt",
    "angespritzten": "angespritzt",
    "angespritzter": "angespritzt",
    "angespritztes": "angespritzt",
    "angesprochen": "ansprechen",
    "angesprochene": "angesprochen",
    "angesprochenem": "angesprochen",
    "angesprochenen": "angesprochen",
    "angesprochener": "angesprochen",
    "angesprochenere": "angesprochen",
    "angesprochenerem": "angesprochen",
    "angesprocheneren": "angesprochen",
    "angesprochenerer": "angesprochen",
    "angesprocheneres": "angesprochen",
    "angesprochenes": "angesprochen",
    "angesprochenste": "angesprochen",
    "angesprochenstem": "angesprochen",
    "angesprochensten": "angesprochen",
    "angesprochenster": "angesprochen",
    "angesprochenstes": "angesprochen",
    "angesprungen": "anspringen",
    "angesprungene": "angesprungen",
    "angesprungenem": "angesprungen",
    "angesprungenen": "angesprungen",
    "angesprungener": "angesprungen",
    "angesprungenes": "angesprungen",
    "angesprüht": "ansprühen",
    "angesprühte": "angesprüht",
    "angesprühtem": "angesprüht",
    "angesprühten": "angesprüht",
    "angesprühter": "angesprüht",
    "angesprühtes": "angesprüht",
    "angespült": "anspülen",
    "angespülte": "angespült",
    "angespültem": "angespült",
    "angespülten": "angespült",
    "angespülter": "angespült",
    "angespültes": "angespült",
    "angestachelt": "anstacheln",
    "angestachelte": "angestachelt",
    "angestacheltem": "angestachelt",
    "angestachelten": "angestachelt",
    "angestachelter": "angestachelt",
    "angestacheltere": "angestachelt",
    "angestachelterem": "angestachelt",
    "angestachelteren": "angestachelt",
    "angestachelterer": "angestachelt",
    "angestachelteres": "angestachelt",
    "angestacheltes": "angestachelt",
    "angestachelteste": "angestachelt",
    "angestacheltestem": "angestachelt",
    "angestacheltesten": "angestachelt",
    "angestacheltester": "angestachelt",
    "angestacheltestes": "angestachelt",
    "angestammt": "anstammen",
    "angestammte": "angestammt",
    "angestammtem": "angestammt",
    "angestammten": "angestammt",
    "angestammter": "angestammt",
    "angestammtere": "angestammt",
    "angestammterem": "angestammt",
    "angestammteren": "angestammt",
    "angestammterer": "angestammt",
    "angestammteres": "angestammt",
    "angestammtes": "angestammt",
    "angestammteste": "angestammt",
    "angestammtestem": "angestammt",
    "angestammtesten": "angestammt",
    "angestammtester": "angestammt",
    "angestammtestes": "angestammt",
    "angestanden": "anstehen",
    "angestandene": "angestanden",
    "angestandenem": "angestanden",
    "angestandenen": "angestanden",
    "angestandener": "angestanden",
    "angestandenes": "angestanden",
    "angestarrt": "anstarren",
    "angestarrte": "angestarrt",
    "angestarrtem": "angestarrt",
    "angestarrten": "angestarrt",
    "angestarrter": "angestarrt",
    "angestarrtere": "angestarrt",
    "angestarrterem": "angestarrt",
    "angestarrteren": "angestarrt",
    "angestarrterer": "angestarrt",
    "angestarrteres": "angestarrt",
    "angestarrtes": "angestarrt",
    "angestarrteste": "angestarrt",
    "angestarrtestem": "angestarrt",
    "angestarrtesten": "angestarrt",
    "angestarrtester": "angestarrt",
    "angestarrtestes": "angestarrt",
    "angestaubt": "anstauben",
    "angestaubte": "angestaubt",
    "angestaubtem": "angestaubt",
    "angestaubten": "angestaubt",
    "angestaubter": "angestaubt",
    "angestaubtere": "angestaubt",
    "angestaubterem": "angestaubt",
    "angestaubteren": "angestaubt",
    "angestaubterer": "angestaubt",
    "angestaubteres": "angestaubt",
    "angestaubtes": "angestaubt",
    "angestaubteste": "angestaubt",
    "angestaubtestem": "angestaubt",
    "angestaubtesten": "angestaubt",
    "angestaubtester": "angestaubt",
    "angestaubtestes": "angestaubt",
    "angestaut": "anstauen",
    "angestaute": "angestaut",
    "angestautem": "angestaut",
    "angestauten": "angestaut",
    "angestauter": "angestaut",
    "angestautes": "angestaut",
    "angesteckt": "anstecken",
    "angesteckte": "angesteckt",
    "angestecktem": "angesteckt",
    "angesteckten": "angesteckt",
    "angesteckter": "angesteckt",
    "angestecktes": "angesteckt",
    "angestellt": "anstellen",
    "angestellte": "angestellt",
    "angestelltem": "angestellt",
    "angestellten": "angestellt",
    "angestellter": "angestellt",
    "angestelltes": "angestellt",
    "angestemmt": "anstemmen",
    "angestemmte": "angestemmt",
    "angestemmtem": "angestemmt",
    "angestemmten": "angestemmt",
    "angestemmter": "angestemmt",
    "angestemmtes": "angestemmt",
    "angestiegen": "ansteigen",
    "angestiegene": "angestiegen",
    "angestiegenem": "angestiegen",
    "angestiegenen": "angestiegen",
    "angestiegener": "angestiegen",
    "angestiegenere": "angestiegen",
    "angestiegenerem": "angestiegen",
    "angestiegeneren": "angestiegen",
    "angestiegenerer": "angestiegen",
    "angestiegeneres": "angestiegen",
    "angestiegenes": "angestiegen",
    "angestiegenste": "angestiegen",
    "angestiegenstem": "angestiegen",
    "angestiegensten": "angestiegen",
    "angestiegenster": "angestiegen",
    "angestiegenstes": "angestiegen",
    "angestiftet": "anstiften",
    "angestiftete": "angestiftet",
    "angestiftetem": "angestiftet",
    "angestifteten": "angestiftet",
    "angestifteter": "angestiftet",
    "angestiftetere": "angestiftet",
    "angestifteterem": "angestiftet",
    "angestifteteren": "angestiftet",
    "angestifteterer": "angestiftet",
    "angestifteteres": "angestiftet",
    "angestiftetes": "angestiftet",
    "angestifteteste": "angestiftet",
    "angestiftetestem": "angestiftet",
    "angestiftetesten": "angestiftet",
    "angestiftetester": "angestiftet",
    "angestiftetestes": "angestiftet",
    "angestimmt": "anstimmen",
    "angestimmte": "angestimmt",
    "angestimmtem": "angestimmt",
    "angestimmten": "angestimmt",
    "angestimmter": "angestimmt",
    "angestimmtes": "angestimmt",
    "angestochen": "anstechen",
    "angestochene": "angestochen",
    "angestochenem": "angestochen",
    "angestochenen": "angestochen",
    "angestochener": "angestochen",
    "angestochenes": "angestochen",
    "angestoßen": "anstoßen",
    "angestoßene": "angestoßen",
    "angestoßenem": "angestoßen",
    "angestoßenen": "angestoßen",
    "angestoßener": "angestoßen",
    "angestoßenes": "angestoßen",
    "angestrahlt": "anstrahlen",
    "angestrahlte": "angestrahlt",
    "angestrahltem": "angestrahlt",
    "angestrahlten": "angestrahlt",
    "angestrahlter": "angestrahlt",
    "angestrahltere": "angestrahlt",
    "angestrahlterem": "angestrahlt",
    "angestrahlteren": "angestrahlt",
    "angestrahlterer": "angestrahlt",
    "angestrahlteres": "angestrahlt",
    "angestrahltes": "angestrahlt",
    "angestrahlteste": "angestrahlt",
    "angestrahltestem": "angestrahlt",
    "angestrahltesten": "angestrahlt",
    "angestrahltester": "angestrahlt",
    "angestrahltestes": "angestrahlt",
    "angestrebt": "anstreben",
    "angestrebte": "angestrebt",
    "angestrebtem": "angestrebt",
    "angestrebten": "angestrebt",
    "angestrebter": "angestrebt",
    "angestrebtes": "angestrebt",
    "angestrengt": "anstrengen",
    "angestrengte": "angestrengt",
    "angestrengtem": "angestrengt",
    "angestrengten": "angestrengt",
    "angestrengter": "angestrengt",
    "angestrengtere": "angestrengt",
    "angestrengterem": "angestrengt",
    "angestrengteren": "angestrengt",
    "angestrengterer": "angestrengt",
    "angestrengteres": "angestrengt",
    "angestrengtes": "angestrengt",
    "angestrengteste": "angestrengt",
    "angestrengtestem": "angestrengt",
    "angestrengtesten": "angestrengt",
    "angestrengtester": "angestrengt",
    "angestrengtestes": "angestrengt",
    "angestrichen": "anstreichen",
    "angestrichene": "angestrichen",
    "angestrichenem": "angestrichen",
    "angestrichenen": "angestrichen",
    "angestrichener": "angestrichen",
    "angestrichenes": "angestrichen",
    "angestunken": "anstinken",
    "angestunkene": "angestunken",
    "angestunkenem": "angestunken",
    "angestunkenen": "angestunken",
    "angestunkener": "angestunken",
    "angestunkenes": "angestunken",
    "angestürmt": "anstürmen",
    "angestürmte": "angestürmt",
    "angestürmtem": "angestürmt",
    "angestürmten": "angestürmt",
    "angestürmter": "angestürmt",
    "angestürmtes": "angestürmt",
    "angesucht": "ansuchen",
    "angesuchte": "angesucht",
    "angesuchtem": "angesucht",
    "angesuchten": "angesucht",
    "angesuchter": "angesucht",
    "angesuchtes": "angesucht",
    "angesungen": "ansingen",
    "angesungene": "angesungen",
    "angesungenem": "angesungen",
    "angesungenen": "angesungen",
    "angesungener": "angesungen",
    "angesungenes": "angesungen",
    "angesägt": "ansägen",
    "angesägtem": "angesägt",
    "angesägter": "angesägt",
    "angesägtes": "angesägt",
    "angesät": "ansäen",
    "angesäte": "angesät",
    "angesätem": "angesät",
    "angesäten": "angesät",
    "angesäter": "angesät",
    "angesätes": "angesät",
    "angesäuert": "ansäuern",
    "angesäuerte": "angesäuert",
    "angesäuertem": "angesäuert",
    "angesäuerten": "angesäuert",
    "angesäuerter": "angesäuert",
    "angesäuertere": "angesäuert",
    "angesäuerterem": "angesäuert",
    "angesäuerteren": "angesäuert",
    "angesäuerterer": "angesäuert",
    "angesäuerteres": "angesäuert",
    "angesäuertes": "angesäuert",
    "angesäuerteste": "angesäuert",
    "angesäuertestem": "angesäuert",
    "angesäuertesten": "angesäuert",
    "angesäuertester": "angesäuert",
    "angesäuertestes": "angesäuert",
    "angesäuselt": "ansäuseln",
    "angesäuselte": "angesäuselt",
    "angesäuseltem": "angesäuselt",
    "angesäuselten": "angesäuselt",
    "angesäuselter": "angesäuselt",
    "angesäuseltere": "angesäuselt",
    "angesäuselterem": "angesäuselt",
    "angesäuselteren": "angesäuselt",
    "angesäuselterer": "angesäuselt",
    "angesäuselteres": "angesäuselt",
    "angesäuseltes": "angesäuselt",
    "angesäuselteste": "angesäuselt",
    "angesäuseltestem": "angesäuselt",
    "angesäuseltesten": "angesäuselt",
    "angesäuseltester": "angesäuselt",
    "angesäuseltestes": "angesäuselt",
    "angetanzt": "antanzen",
    "angetanzte": "angetanzt",
    "angetanztem": "angetanzt",
    "angetanzten": "angetanzt",
    "angetanzter": "angetanzt",
    "angetanztes": "angetanzt",
    "angetastet": "antasten",
    "angetastete": "angetastet",
    "angetastetem": "angetastet",
    "angetasteten": "angetastet",
    "angetasteter": "angetastet",
    "angetastetes": "angetastet",
    "angetestet": "antesten",
    "angetestete": "angetestet",
    "angetestetem": "angetestet",
    "angetesteten": "angetestet",
    "angetesteter": "angetestet",
    "angetestetere": "angetestet",
    "angetesteterem": "angetestet",
    "angetesteteren": "angetestet",
    "angetesteterer": "angetestet",
    "angetesteteres": "angetestet",
    "angetestetes": "angetestet",
    "angetesteteste": "angetestet",
    "angetestetestem": "angetestet",
    "angetestetesten": "angetestet",
    "angetestetester": "angetestet",
    "angetestetestes": "angetestet",
    "angetippt": "antippen",
    "angetippte": "angetippt",
    "angetipptem": "angetippt",
    "angetippten": "angetippt",
    "angetippter": "angetippt",
    "angetipptes": "angetippt",
    "angetrabt": "antraben",
    "angetrabte": "angetrabt",
    "angetrabtem": "angetrabt",
    "angetrabten": "angetrabt",
    "angetrabter": "angetrabt",
    "angetrabtes": "angetrabt",
    "angetragen": "antragen",
    "angetragene": "angetragen",
    "angetragenem": "angetragen",
    "angetragenen": "angetragen",
    "angetragener": "angetragen",
    "angetragenes": "angetragen",
    "angetraut": "antrauen",
    "angetraute": "angetraut",
    "angetrautem": "angetraut",
    "angetrauten": "angetraut",
    "angetrauter": "angetraut",
    "angetrautes": "angetraut",
    "angetreten": "antreten",
    "angetretene": "angetreten",
    "angetretenem": "angetreten",
    "angetretenen": "angetreten",
    "angetretener": "angetreten",
    "angetretenes": "angetreten",
    "angetrieben": "antreiben",
    "angetriebene": "angetrieben",
    "angetriebenem": "angetrieben",
    "angetriebenen": "angetrieben",
    "angetriebener": "angetrieben",
    "angetriebenes": "angetrieben",
    "angetroffen": "antreffen",
    "angetroffene": "angetroffen",
    "angetroffenem": "angetroffen",
    "angetroffenen": "angetroffen",
    "angetroffener": "angetroffen",
    "angetroffenes": "angetroffen",
    "angetrunken": "antrinken",
    "angetrunkene": "angetrunken",
    "angetrunkenem": "angetrunken",
    "angetrunkenen": "angetrunken",
    "angetrunkener": "angetrunken",
    "angetrunkenere": "angetrunken",
    "angetrunkenerem": "angetrunken",
    "angetrunkeneren": "angetrunken",
    "angetrunkenerer": "angetrunken",
    "angetrunkeneres": "angetrunken",
    "angetrunkenes": "angetrunken",
    "angetrunkenste": "angetrunken",
    "angetrunkenstem": "angetrunken",
    "angetrunkensten": "angetrunken",
    "angetrunkenster": "angetrunken",
    "angetrunkenstes": "angetrunken",
    "angetönt": "antönen",
    "angetönte": "angetönt",
    "angetöntem": "angetönt",
    "angetönten": "angetönt",
    "angetönter": "angetönt",
    "angetöntes": "angetönt",
    "angetörnt": "antörnen",
    "angetörnte": "angetörnt",
    "angetörntem": "angetörnt",
    "angetörnten": "angetörnt",
    "angetörnter": "angetörnt",
    "angetörntere": "angetörnt",
    "angetörnterem": "angetörnt",
    "angetörnteren": "angetörnt",
    "angetörnterer": "angetörnt",
    "angetörnteres": "angetörnt",
    "angetörntes": "angetörnt",
    "angetörnteste": "angetörnt",
    "angetörntestem": "angetörnt",
    "angetörntesten": "angetörnt",
    "angetörntester": "angetörnt",
    "angetörntestes": "angetörnt",
    "angewachsen": "anwachsen",
    "angewachsene": "angewachsen",
    "angewachsenem": "angewachsen",
    "angewachsenen": "angewachsen",
    "angewachsener": "angewachsen",
    "angewachsenes": "angewachsen",
    "angewachst": "anwachsen",
    "angewachste": "angewachst",
    "angewachstem": "angewachst",
    "angewachsten": "angewachst",
    "angewachster": "angewachst",
    "angewachstes": "angewachst",
    "angewandelt": "anwandeln",
    "angewandelte": "angewandelt",
    "angewandeltem": "angewandelt",
    "angewandelten": "angewandelt",
    "angewandelter": "angewandelt",
    "angewandeltes": "angewandelt",
    "angewandt": "anwenden",
    "angeweht": "anwehen",
    "angewehte": "angeweht",
    "angewehtem": "angeweht",
    "angewehten": "angeweht",
    "angewehter": "angeweht",
    "angewehtes": "angeweht",
    "angewendet": "anwenden",
    "angewendete": "angewendet",
    "angewendetem": "angewendet",
    "angewendeten": "angewendet",
    "angewendeter": "angewendet",
    "angewendetes": "angewendet",
    "angewidert": "anwidern",
    "angewiderte": "angewidert",
    "angewidertem": "angewidert",
    "angewiderten": "angewidert",
    "angewiderter": "angewidert",
    "angewidertere": "angewidert",
    "angewiderterem": "angewidert",
    "angewiderteren": "angewidert",
    "angewiderterer": "angewidert",
    "angewiderteres": "angewidert",
    "angewidertes": "angewidert",
    "angewiderteste": "angewidert",
    "angewidertestem": "angewidert",
    "angewidertesten": "angewidert",
    "angewidertester": "angewidert",
    "angewidertestes": "angewidert",
    "angewiesen": "anweisen",
    "angewiesene": "angewiesen",
    "angewiesenem": "angewiesen",
    "angewiesenen": "angewiesen",
    "angewiesener": "angewiesen",
    "angewiesenes": "angewiesen",
    "angewinkelt": "anwinkeln",
    "angewinkelte": "angewinkelt",
    "angewinkeltem": "angewinkelt",
    "angewinkelten": "angewinkelt",
    "angewinkelter": "angewinkelt",
    "angewinkeltes": "angewinkelt",
    "angewohnt": "anwohnen",
    "angewohnte": "angewohnt",
    "angewohntem": "angewohnt",
    "angewohnten": "angewohnt",
    "angewohnter": "angewohnt",
    "angewohntes": "angewohnt",
    "angeworben": "anwerben",
    "angeworbene": "angeworben",
    "angeworbenem": "angeworben",
    "angeworbenen": "angeworben",
    "angeworbener": "angeworben",
    "angeworbenes": "angeworben",
    "angeworfen": "anwerfen",
    "angeworfene": "angeworfen",
    "angeworfenem": "angeworfen",
    "angeworfenen": "angeworfen",
    "angeworfener": "angeworfen",
    "angeworfenes": "angeworfen",
    "angewurzelt": "anwurzeln",
    "angewurzelte": "angewurzelt",
    "angewurzeltem": "angewurzelt",
    "angewurzelten": "angewurzelt",
    "angewurzelter": "angewurzelt",
    "angewurzeltes": "angewurzelt",
    "angewählt": "anwählen",
    "angewählte": "angewählt",
    "angewähltem": "angewählt",
    "angewählten": "angewählt",
    "angewählter": "angewählt",
    "angewähltes": "angewählt",
    "angewärmt": "anwärmen",
    "angewärmte": "angewärmt",
    "angewärmtem": "angewärmt",
    "angewärmten": "angewärmt",
    "angewärmter": "angewärmt",
    "angewärmtes": "angewärmt",
    "angewöhne": "angewöhnen",
    "angewöhnend": "angewöhnen",
    "angewöhnende": "angewöhnend",
    "angewöhnendem": "angewöhnend",
    "angewöhnenden": "angewöhnend",
    "angewöhnender": "angewöhnend",
    "angewöhnendes": "angewöhnend",
    "angewöhnest": "angewöhnen",
    "angewöhnet": "angewöhnen",
    "angewöhnst": "angewöhnen",
    "angewöhnt": "angewöhnen",
    "angewöhnte": "angewöhnt",
    "angewöhntem": "angewöhnt",
    "angewöhnten": "angewöhnt",
    "angewöhnter": "angewöhnt",
    "angewöhntes": "angewöhnt",
    "angewöhntest": "angewöhnen",
    "angewöhntet": "angewöhnen",
    "angezahlt": "anzahlen",
    "angezahlte": "angezahlt",
    "angezahltem": "angezahlt",
    "angezahlten": "angezahlt",
    "angezahlter": "angezahlt",
    "angezahltes": "angezahlt",
    "angezapft": "anzapfen",
    "angezapfte": "angezapft",
    "angezapftem": "angezapft",
    "angezapften": "angezapft",
    "angezapfter": "angezapft",
    "angezapftes": "angezapft",
    "angezaubert": "anzaubern",
    "angezauberte": "angezaubert",
    "angezaubertem": "angezaubert",
    "angezauberten": "angezaubert",
    "angezauberter": "angezaubert",
    "angezaubertes": "angezaubert",
    "angezeichnet": "anzeichnen",
    "angezeichnete": "angezeichnet",
    "angezeichnetem": "angezeichnet",
    "angezeichneten": "angezeichnet",
    "angezeichneter": "angezeichnet",
    "angezeichnetes": "angezeichnet",
    "angezeigt": "anzeigen",
    "angezeigte": "angezeigt",
    "angezeigtem": "angezeigt",
    "angezeigten": "angezeigt",
    "angezeigter": "angezeigt",
    "angezeigtes": "angezeigt",
    "angezettelt": "anzetteln",
    "angezettelte": "angezettelt",
    "angezetteltem": "angezettelt",
    "angezettelten": "angezettelt",
    "angezettelter": "angezettelt",
    "angezetteltes": "angezettelt",
    "angezogen": "anziehen",
    "angezogene": "angezogen",
    "angezogenem": "angezogen",
    "angezogenen": "angezogen",
    "angezogener": "angezogen",
    "angezogenere": "angezogen",
    "angezogenerem": "angezogen",
    "angezogeneren": "angezogen",
    "angezogenerer": "angezogen",
    "angezogeneres": "angezogen",
    "angezogenes": "angezogen",
    "angezogenste": "angezogen",
    "angezogenstem": "angezogen",
    "angezogensten": "angezogen",
    "angezogenster": "angezogen",
    "angezogenstes": "angezogen",
    "angezweifelt": "anzweifeln",
    "angezweifelte": "angezweifelt",
    "angezweifeltem": "angezweifelt",
    "angezweifelten": "angezweifelt",
    "angezweifelter": "angezweifelt",
    "angezweifeltere": "angezweifelt",
    "angezweifelterem": "angezweifelt",
    "angezweifelteren": "angezweifelt",
    "angezweifelterer": "angezweifelt",
    "angezweifelteres": "angezweifelt",
    "angezweifeltes": "angezweifelt",
    "angezweifelteste": "angezweifelt",
    "angezweifeltestem": "angezweifelt",
    "angezweifeltesten": "angezweifelt",
    "angezweifeltester": "angezweifelt",
    "angezweifeltestes": "angezweifelt",
    "angezählt": "anzählen",
    "angezähltem": "angezählt",
    "angezählter": "angezählt",
    "angezähltere": "angezählt",
    "angezählterem": "angezählt",
    "angezählteren": "angezählt",
    "angezählterer": "angezählt",
    "angezählteres": "angezählt",
    "angezähltes": "angezählt",
    "angezählteste": "angezählt",
    "angezähltestem": "angezählt",
    "angezähltesten": "angezählt",
    "angezähltester": "angezählt",
    "angezähltestes": "angezählt",
    "angezündet": "anzünden",
    "angezündete": "angezündet",
    "angezündetem": "angezündet",
    "angezündeten": "angezündet",
    "angezündeter": "angezündet",
    "angezündetes": "angezündet",
    "angeödet": "anöden",
    "angeödete": "angeödet",
    "angeödetem": "angeödet",
    "angeödeten": "angeödet",
    "angeödeter": "angeödet",
    "angeödetere": "angeödet",
    "angeödeterem": "angeödet",
    "angeödeteren": "angeödet",
    "angeödeterer": "angeödet",
    "angeödeteres": "angeödet",
    "angeödetes": "angeödet",
    "angeödeteste": "angeödet",
    "angeödetestem": "angeödet",
    "angeödetesten": "angeödet",
    "angeödetester": "angeödet",
    "angeödetestes": "angeödet",
    "angibst": "angeben",
    "angibt": "angeben",
    "angieße": "angießen",
    "angießend": "angießen",
    "angießende": "angießend",
    "angießendem": "angießend",
    "angießenden": "angießend",
    "angießender": "angießend",
    "angießendes": "angießend",
    "angießest": "angießen",
    "angießet": "angießen",
    "angießt": "angießen",
    "angifte": "angiften",
    "angiftend": "angiften",
    "angiftende": "angiftend",
    "angiftendem": "angiftend",
    "angiftenden": "angiftend",
    "angiftender": "angiftend",
    "angiftendere": "angiftend",
    "angiftenderem": "angiftend",
    "angiftenderen": "angiftend",
    "angiftenderer": "angiftend",
    "angiftenderes": "angiftend",
    "angiftendes": "angiftend",
    "angiftendste": "angiftend",
    "angiftendstem": "angiftend",
    "angiftendsten": "angiftend",
    "angiftendster": "angiftend",
    "angiftendstes": "angiftend",
    "angiftest": "angiften",
    "angiftet": "angiften",
    "angiftete": "angiften",
    "angifteten": "angiften",
    "angiftetest": "angiften",
    "angiftetet": "angiften",
    "anging": "angehen",
    "anginge": "angehen",
    "angingen": "angehen",
    "angingest": "angehen",
    "anginget": "angehen",
    "angingst": "angehen",
    "angingt": "angehen",
    "angle": "angeln",
    "angleiche": "angleichen",
    "angleichend": "angleichen",
    "angleichende": "angleichend",
    "angleichendem": "angleichend",
    "angleichenden": "angleichend",
    "angleichender": "angleichend",
    "angleichendes": "angleichend",
    "angleichest": "angleichen",
    "angleichet": "angleichen",
    "angleichst": "angleichen",
    "angleicht": "angleichen",
    "anglich": "angleichen",
    "angliche": "angleichen",
    "anglichen": "angleichen",
    "anglichest": "angleichen",
    "anglichet": "angleichen",
    "anglichst": "angleichen",
    "anglicht": "angleichen",
    "angliedere": "angliedern",
    "angliedernd": "angliedern",
    "angliedernde": "angliedernd",
    "angliederndem": "angliedernd",
    "angliedernden": "angliedernd",
    "angliedernder": "angliedernd",
    "angliederndere": "angliedernd",
    "angliedernderem": "angliedernd",
    "angliedernderen": "angliedernd",
    "angliedernderer": "angliedernd",
    "angliedernderes": "angliedernd",
    "angliederndes": "angliedernd",
    "angliederndste": "angliedernd",
    "angliederndstem": "angliedernd",
    "angliederndsten": "angliedernd",
    "angliederndster": "angliedernd",
    "angliederndstes": "angliedernd",
    "angliederst": "angliedern",
    "angliedert": "angliedern",
    "angliederte": "angliedern",
    "angliederten": "angliedern",
    "angliedertest": "angliedern",
    "angliedertet": "angliedern",
    "anglotze": "anglotzen",
    "anglotzend": "anglotzen",
    "anglotzende": "anglotzend",
    "anglotzendem": "anglotzend",
    "anglotzenden": "anglotzend",
    "anglotzender": "anglotzend",
    "anglotzendere": "anglotzend",
    "anglotzenderem": "anglotzend",
    "anglotzenderen": "anglotzend",
    "anglotzenderer": "anglotzend",
    "anglotzenderes": "anglotzend",
    "anglotzendes": "anglotzend",
    "anglotzendste": "anglotzend",
    "anglotzendstem": "anglotzend",
    "anglotzendsten": "anglotzend",
    "anglotzendster": "anglotzend",
    "anglotzendstes": "anglotzend",
    "anglotzest": "anglotzen",
    "anglotzet": "anglotzen",
    "anglotzt": "anglotzen",
    "anglotzte": "anglotzen",
    "anglotzten": "anglotzen",
    "anglotztest": "anglotzen",
    "anglotztet": "anglotzen",
    "angossen": "angießen",
    "angoß": "angießen",
    "angoßt": "angießen",
    "angreifbare": "angreifbar",
    "angreifbarem": "angreifbar",
    "angreifbaren": "angreifbar",
    "angreifbarer": "angreifbar",
    "angreifbarere": "angreifbar",
    "angreifbarerem": "angreifbar",
    "angreifbareren": "angreifbar",
    "angreifbarerer": "angreifbar",
    "angreifbareres": "angreifbar",
    "angreifbares": "angreifbar",
    "angreifbarste": "angreifbar",
    "angreifbarstem": "angreifbar",
    "angreifbarsten": "angreifbar",
    "angreifbarster": "angreifbar",
    "angreifbarstes": "angreifbar",
    "angreife": "angreifen",
    "angreifend": "angreifen",
    "angreifende": "angreifend",
    "angreifendem": "angreifend",
    "angreifenden": "angreifend",
    "angreifender": "angreifend",
    "angreifendes": "angreifend",
    "angreifest": "angreifen",
    "angreifet": "angreifen",
    "angreifst": "angreifen",
    "angreift": "angreifen",
    "angrenze": "angrenzen",
    "angrenzend": "angrenzen",
    "angrenzende": "angrenzend",
    "angrenzendem": "angrenzend",
    "angrenzenden": "angrenzend",
    "angrenzender": "angrenzend",
    "angrenzendere": "angrenzend",
    "angrenzenderem": "angrenzend",
    "angrenzenderen": "angrenzend",
    "angrenzenderer": "angrenzend",
    "angrenzenderes": "angrenzend",
    "angrenzendes": "angrenzend",
    "angrenzendste": "angrenzend",
    "angrenzendstem": "angrenzend",
    "angrenzendsten": "angrenzend",
    "angrenzendster": "angrenzend",
    "angrenzendstes": "angrenzend",
    "angrenzest": "angrenzen",
    "angrenzet": "angrenzen",
    "angrenzt": "angrenzen",
    "angrenzte": "angrenzen",
    "angrenzten": "angrenzen",
    "angrenztest": "angrenzen",
    "angrenztet": "angrenzen",
    "angriff": "angreifen",
    "angriffest": "angreifen",
    "angriffet": "angreifen",
    "angriffslustigem": "angriffslustig",
    "angriffslustigen": "angriffslustig",
    "angriffslustiger": "angriffslustig",
    "angriffslustigere": "angriffslustig",
    "angriffslustigerem": "angriffslustig",
    "angriffslustigeren": "angriffslustig",
    "angriffslustigerer": "angriffslustig",
    "angriffslustigeres": "angriffslustig",
    "angriffslustiges": "angriffslustig",
    "angriffslustigste": "angriffslustig",
    "angriffslustigstem": "angriffslustig",
    "angriffslustigsten": "angriffslustig",
    "angriffslustigster": "angriffslustig",
    "angriffslustigstes": "angriffslustig",
    "angriffst": "angreifen",
    "angrifft": "angreifen",
    "angrinse": "angrinsen",
    "angrinsend": "angrinsen",
    "angrinsende": "angrinsend",
    "angrinsendem": "angrinsend",
    "angrinsenden": "angrinsend",
    "angrinsender": "angrinsend",
    "angrinsendere": "angrinsend",
    "angrinsenderem": "angrinsend",
    "angrinsenderen": "angrinsend",
    "angrinsenderer": "angrinsend",
    "angrinsenderes": "angrinsend",
    "angrinsendes": "angrinsend",
    "angrinsendste": "angrinsend",
    "angrinsendstem": "angrinsend",
    "angrinsendsten": "angrinsend",
    "angrinsendster": "angrinsend",
    "angrinsendstes": "angrinsend",
    "angrinsest": "angrinsen",
    "angrinset": "angrinsen",
    "angrinst": "angrinsen",
    "angrinste": "angrinsen",
    "angrinsten": "angrinsen",
    "angrinstest": "angrinsen",
    "angrinstet": "angrinsen",
    "angsterfüllte": "angsterfüllt",
    "angsterfülltem": "angsterfüllt",
    "angsterfüllten": "angsterfüllt",
    "angsterfüllter": "angsterfüllt",
    "angsterfülltere": "angsterfüllt",
    "angsterfüllterem": "angsterfüllt",
    "angsterfüllteren": "angsterfüllt",
    "angsterfüllterer": "angsterfüllt",
    "angsterfüllteres": "angsterfüllt",
    "angsterfülltes": "angsterfüllt",
    "angsterfüllteste": "angsterfüllt",
    "angsterfülltestem": "angsterfüllt",
    "angsterfülltesten": "angsterfüllt",
    "angsterfülltester": "angsterfüllt",
    "angsterfülltestes": "angsterfüllt",
    "angurte": "angurten",
    "angurtend": "angurten",
    "angurtende": "angurtend",
    "angurtendem": "angurtend",
    "angurtenden": "angurtend",
    "angurtender": "angurtend",
    "angurtendes": "angurtend",
    "angurtest": "angurten",
    "angurtet": "angurten",
    "angurtete": "angurten",
    "angurteten": "angurten",
    "angurtetest": "angurten",
    "angurtetet": "angurten",
    "angäbe": "angeben",
    "angäben": "angeben",
    "angäbest": "angeben",
    "angäbet": "angeben",
    "angösse": "angießen",
    "angössen": "angießen",
    "angössest": "angießen",
    "angösset": "angießen",
    "anhafte": "anhaften",
    "anhaftend": "anhaften",
    "anhaftende": "anhaftend",
    "anhaftendem": "anhaftend",
    "anhaftenden": "anhaftend",
    "anhaftender": "anhaftend",
    "anhaftendes": "anhaftend",
    "anhaftest": "anhaften",
    "anhaftet": "anhaften",
    "anhaftete": "anhaften",
    "anhafteten": "anhaften",
    "anhaftetest": "anhaften",
    "anhaftetet": "anhaften",
    "anhake": "anhaken",
    "anhakend": "anhaken",
    "anhakende": "anhakend",
    "anhakendem": "anhakend",
    "anhakenden": "anhakend",
    "anhakender": "anhakend",
    "anhakendes": "anhakend",
    "anhakest": "anhaken",
    "anhaket": "anhaken",
    "anhakst": "anhaken",
    "anhakt": "anhaken",
    "anhakte": "anhaken",
    "anhakten": "anhaken",
    "anhaktest": "anhaken",
    "anhaktet": "anhaken",
    "anhalftere": "anhalftern",
    "anhalfternd": "anhalftern",
    "anhalfternde": "anhalfternd",
    "anhalfterndem": "anhalfternd",
    "anhalfternden": "anhalfternd",
    "anhalfternder": "anhalfternd",
    "anhalfterndes": "anhalfternd",
    "anhalfterst": "anhalftern",
    "anhalftert": "anhalftern",
    "anhalfterte": "anhalftern",
    "anhalfterten": "anhalftern",
    "anhalftertest": "anhalftern",
    "anhalftertet": "anhalftern",
    "anhaltend": "anhalten",
    "anhaltende": "anhaltend",
    "anhaltendem": "anhaltend",
    "anhaltenden": "anhaltend",
    "anhaltender": "anhaltend",
    "anhaltendes": "anhaltend",
    "anhaltest": "anhalten",
    "anhaltet": "anhalten",
    "anhauche": "anhauchen",
    "anhauchend": "anhauchen",
    "anhauchende": "anhauchend",
    "anhauchendem": "anhauchend",
    "anhauchenden": "anhauchend",
    "anhauchender": "anhauchend",
    "anhauchendes": "anhauchend",
    "anhauchest": "anhauchen",
    "anhauchet": "anhauchen",
    "anhauchst": "anhauchen",
    "anhaucht": "anhauchen",
    "anhauchte": "anhauchen",
    "anhauchten": "anhauchen",
    "anhauchtest": "anhauchen",
    "anhauchtet": "anhauchen",
    "anhaue": "anhauen",
    "anhauend": "anhauen",
    "anhauende": "anhauend",
    "anhauendem": "anhauend",
    "anhauenden": "anhauend",
    "anhauender": "anhauend",
    "anhauendes": "anhauend",
    "anhauest": "anhauen",
    "anhauet": "anhauen",
    "anhaust": "anhauen",
    "anhaut": "anhauen",
    "anhaute": "anhauen",
    "anhauten": "anhauen",
    "anhautest": "anhauen",
    "anhautet": "anhauen",
    "anhebe": "anheben",
    "anhebend": "anheben",
    "anhebende": "anhebend",
    "anhebendem": "anhebend",
    "anhebenden": "anhebend",
    "anhebender": "anhebend",
    "anhebendes": "anhebend",
    "anhebest": "anheben",
    "anhebet": "anheben",
    "anhebst": "anheben",
    "anhebt": "anheben",
    "anhefte": "anheften",
    "anheftend": "anheften",
    "anheftende": "anheftend",
    "anheftendem": "anheftend",
    "anheftenden": "anheftend",
    "anheftender": "anheftend",
    "anheftendes": "anheftend",
    "anheftest": "anheften",
    "anheftet": "anheften",
    "anheftete": "anheften",
    "anhefteten": "anheften",
    "anheftetest": "anheften",
    "anheftetet": "anheften",
    "anheimele": "anheimeln",
    "anheimelnd": "anheimeln",
    "anheimelnde": "anheimelnd",
    "anheimelndem": "anheimelnd",
    "anheimelnden": "anheimelnd",
    "anheimelnder": "anheimelnd",
    "anheimelndere": "anheimelnd",
    "anheimelnderem": "anheimelnd",
    "anheimelnderen": "anheimelnd",
    "anheimelnderer": "anheimelnd",
    "anheimelnderes": "anheimelnd",
    "anheimelndes": "anheimelnd",
    "anheimelndste": "anheimelnd",
    "anheimelndstem": "anheimelnd",
    "anheimelndsten": "anheimelnd",
    "anheimelndster": "anheimelnd",
    "anheimelndstes": "anheimelnd",
    "anheimelst": "anheimeln",
    "anheimelt": "anheimeln",
    "anheimelte": "anheimeln",
    "anheimelten": "anheimeln",
    "anheimeltest": "anheimeln",
    "anheimeltet": "anheimeln",
    "anheimfalle": "anheimfallen",
    "anheimfallend": "anheimfallen",
    "anheimfallende": "anheimfallend",
    "anheimfallendem": "anheimfallend",
    "anheimfallenden": "anheimfallend",
    "anheimfallender": "anheimfallend",
    "anheimfallendes": "anheimfallend",
    "anheimfallest": "anheimfallen",
    "anheimfallet": "anheimfallen",
    "anheimfallt": "anheimfallen",
    "anheimfiel": "anheimfallen",
    "anheimfiele": "anheimfallen",
    "anheimfielen": "anheimfallen",
    "anheimfielest": "anheimfallen",
    "anheimfielet": "anheimfallen",
    "anheimfielst": "anheimfallen",
    "anheimfielt": "anheimfallen",
    "anheimfällst": "anheimfallen",
    "anheimfällt": "anheimfallen",
    "anheimgab": "anheimgeben",
    "anheimgaben": "anheimgeben",
    "anheimgabst": "anheimgeben",
    "anheimgabt": "anheimgeben",
    "anheimgebe": "anheimgeben",
    "anheimgebend": "anheimgeben",
    "anheimgebende": "anheimgebend",
    "anheimgebendem": "anheimgebend",
    "anheimgebenden": "anheimgebend",
    "anheimgebender": "anheimgebend",
    "anheimgebendes": "anheimgebend",
    "anheimgebest": "anheimgeben",
    "anheimgebet": "anheimgeben",
    "anheimgebt": "anheimgeben",
    "anheimgefallen": "anheimfallen",
    "anheimgefallene": "anheimgefallen",
    "anheimgefallenem": "anheimgefallen",
    "anheimgefallenen": "anheimgefallen",
    "anheimgefallener": "anheimgefallen",
    "anheimgefallenes": "anheimgefallen",
    "anheimgegeben": "anheimgeben",
    "anheimgegebene": "anheimgegeben",
    "anheimgegebenem": "anheimgegeben",
    "anheimgegebenen": "anheimgegeben",
    "anheimgegebener": "anheimgegeben",
    "anheimgegebenes": "anheimgegeben",
    "anheimgestellt": "anheimstellen",
    "anheimgestellte": "anheimgestellt",
    "anheimgestelltem": "anheimgestellt",
    "anheimgestellten": "anheimgestellt",
    "anheimgestellter": "anheimgestellt",
    "anheimgestelltes": "anheimgestellt",
    "anheimgibst": "anheimgeben",
    "anheimgibt": "anheimgeben",
    "anheimgäbe": "anheimgeben",
    "anheimgäben": "anheimgeben",
    "anheimgäbest": "anheimgeben",
    "anheimgäbet": "anheimgeben",
    "anheimle": "anheimeln",
    "anheimstelle": "anheimstellen",
    "anheimstellend": "anheimstellen",
    "anheimstellende": "anheimstellend",
    "anheimstellendem": "anheimstellend",
    "anheimstellenden": "anheimstellend",
    "anheimstellender": "anheimstellend",
    "anheimstellendes": "anheimstellend",
    "anheimstellest": "anheimstellen",
    "anheimstellet": "anheimstellen",
    "anheimstellst": "anheimstellen",
    "anheimstellt": "anheimstellen",
    "anheimstellte": "anheimstellen",
    "anheimstellten": "anheimstellen",
    "anheimstelltest": "anheimstellen",
    "anheimstelltet": "anheimstellen",
    "anheimzufallen": "anheimfallen",
    "anheimzugeben": "anheimgeben",
    "anheimzustellen": "anheimstellen",
    "anheize": "anheizen",
    "anheizend": "anheizen",
    "anheizende": "anheizend",
    "anheizendem": "anheizend",
    "anheizenden": "anheizend",
    "anheizender": "anheizend",
    "anheizendere": "anheizend",
    "anheizenderem": "anheizend",
    "anheizenderen": "anheizend",
    "anheizenderer": "anheizend",
    "anheizenderes": "anheizend",
    "anheizendes": "anheizend",
    "anheizendste": "anheizend",
    "anheizendstem": "anheizend",
    "anheizendsten": "anheizend",
    "anheizendster": "anheizend",
    "anheizendstes": "anheizend",
    "anheizest": "anheizen",
    "anheizet": "anheizen",
    "anheizt": "anheizen",
    "anheizte": "anheizen",
    "anheizten": "anheizen",
    "anheiztest": "anheizen",
    "anheiztet": "anheizen",
    "anheuere": "anheuern",
    "anheuernd": "anheuern",
    "anheuernde": "anheuernd",
    "anheuerndem": "anheuernd",
    "anheuernden": "anheuernd",
    "anheuernder": "anheuernd",
    "anheuerndes": "anheuernd",
    "anheuerst": "anheuern",
    "anheuert": "anheuern",
    "anheuerte": "anheuern",
    "anheuerten": "anheuern",
    "anheuertest": "anheuern",
    "anheuertet": "anheuern",
    "anhielt": "anhalten",
    "anhielte": "anhalten",
    "anhielten": "anhalten",
    "anhieltest": "anhalten",
    "anhieltet": "anhalten",
    "anhimmele": "anhimmeln",
    "anhimmelnd": "anhimmeln",
    "anhimmelnde": "anhimmelnd",
    "anhimmelndem": "anhimmelnd",
    "anhimmelnden": "anhimmelnd",
    "anhimmelnder": "anhimmelnd",
    "anhimmelndere": "anhimmelnd",
    "anhimmelnderem": "anhimmelnd",
    "anhimmelnderen": "anhimmelnd",
    "anhimmelnderer": "anhimmelnd",
    "anhimmelnderes": "anhimmelnd",
    "anhimmelndes": "anhimmelnd",
    "anhimmelndste": "anhimmelnd",
    "anhimmelndstem": "anhimmelnd",
    "anhimmelndsten": "anhimmelnd",
    "anhimmelndster": "anhimmelnd",
    "anhimmelndstes": "anhimmelnd",
    "anhimmelst": "anhimmeln",
    "anhimmelt": "anhimmeln",
    "anhimmelte": "anhimmeln",
    "anhimmelten": "anhimmeln",
    "anhimmeltest": "anhimmeln",
    "anhimmeltet": "anhimmeln",
    "anhimmle": "anhimmeln",
    "anhing": "anhängen",
    "anhinge": "anhängen",
    "anhingen": "anhängen",
    "anhingest": "anhängen",
    "anhinget": "anhängen",
    "anhingst": "anhängen",
    "anhingt": "anhängen",
    "anhob": "anheben",
    "anhoben": "anheben",
    "anhobst": "anheben",
    "anhobt": "anheben",
    "anhole": "anholen",
    "anholend": "anholen",
    "anholende": "anholend",
    "anholendem": "anholend",
    "anholenden": "anholend",
    "anholender": "anholend",
    "anholendes": "anholend",
    "anholest": "anholen",
    "anholet": "anholen",
    "anholst": "anholen",
    "anholt": "anholen",
    "anholte": "anholen",
    "anholten": "anholen",
    "anholtest": "anholen",
    "anholtet": "anholen",
    "anhält": "anhalten",
    "anhältst": "anhalten",
    "anhängend": "anhängen",
    "anhängende": "anhängend",
    "anhängendem": "anhängend",
    "anhängenden": "anhängend",
    "anhängender": "anhängend",
    "anhängendes": "anhängend",
    "anhängest": "anhängen",
    "anhänget": "anhängen",
    "anhängige": "anhängig",
    "anhängigem": "anhängig",
    "anhängigen": "anhängig",
    "anhängiger": "anhängig",
    "anhängiges": "anhängig",
    "anhängliche": "anhänglich",
    "anhänglichem": "anhänglich",
    "anhänglichen": "anhänglich",
    "anhänglicher": "anhänglich",
    "anhänglichere": "anhänglich",
    "anhänglicherem": "anhänglich",
    "anhänglicheren": "anhänglich",
    "anhänglicherer": "anhänglich",
    "anhänglicheres": "anhänglich",
    "anhängliches": "anhänglich",
    "anhänglichste": "anhänglich",
    "anhänglichstem": "anhänglich",
    "anhänglichsten": "anhänglich",
    "anhänglichster": "anhänglich",
    "anhänglichstes": "anhänglich",
    "anhängst": "anhängen",
    "anhängt": "anhängen",
    "anhängte": "anhängen",
    "anhängten": "anhängen",
    "anhängtest": "anhängen",
    "anhängtet": "anhängen",
    "anhärte": "anhärten",
    "anhärtend": "anhärten",
    "anhärtende": "anhärtend",
    "anhärtendem": "anhärtend",
    "anhärtenden": "anhärtend",
    "anhärtender": "anhärtend",
    "anhärtendere": "anhärtend",
    "anhärtenderem": "anhärtend",
    "anhärtenderen": "anhärtend",
    "anhärtenderer": "anhärtend",
    "anhärtenderes": "anhärtend",
    "anhärtendes": "anhärtend",
    "anhärtendste": "anhärtend",
    "anhärtendstem": "anhärtend",
    "anhärtendsten": "anhärtend",
    "anhärtendster": "anhärtend",
    "anhärtendstes": "anhärtend",
    "anhärtest": "anhärten",
    "anhärtet": "anhärten",
    "anhärtete": "anhärten",
    "anhärteten": "anhärten",
    "anhärtetest": "anhärten",
    "anhärtetet": "anhärten",
    "anhöbe": "anheben",
    "anhöben": "anheben",
    "anhöbest": "anheben",
    "anhöbet": "anheben",
    "anhöre": "anhören",
    "anhörend": "anhören",
    "anhörende": "anhörend",
    "anhörendem": "anhörend",
    "anhörenden": "anhörend",
    "anhörender": "anhörend",
    "anhörendes": "anhörend",
    "anhörest": "anhören",
    "anhöret": "anhören",
    "anhörst": "anhören",
    "anhört": "anhören",
    "anhörte": "anhören",
    "anhörten": "anhören",
    "anhörtest": "anhören",
    "anhörtet": "anhören",
    "animalischem": "animalisch",
    "animalischen": "animalisch",
    "animalischer": "animalisch",
    "animalischere": "animalisch",
    "animalischerem": "animalisch",
    "animalischeren": "animalisch",
    "animalischerer": "animalisch",
    "animalischeres": "animalisch",
    "animalisches": "animalisch",
    "animalischste": "animalisch",
    "animalischstem": "animalisch",
    "animalischsten": "animalisch",
    "animalischster": "animalisch",
    "animalischstes": "animalisch",
    "animalisiere": "animalisieren",
    "animalisierend": "animalisieren",
    "animalisierende": "animalisierend",
    "animalisierendem": "animalisierend",
    "animalisierenden": "animalisierend",
    "animalisierender": "animalisierend",
    "animalisierendes": "animalisierend",
    "animalisierest": "animalisieren",
    "animalisieret": "animalisieren",
    "animalisierst": "animalisieren",
    "animalisiert": "animalisieren",
    "animalisierte": "animalisieren",
    "animalisiertem": "animalisiert",
    "animalisierten": "animalisieren",
    "animalisierter": "animalisiert",
    "animalisiertere": "animalisiert",
    "animalisierterem": "animalisiert",
    "animalisierteren": "animalisiert",
    "animalisierterer": "animalisiert",
    "animalisierteres": "animalisiert",
    "animalisiertes": "animalisiert",
    "animalisiertest": "animalisieren",
    "animalisierteste": "animalisiert",
    "animalisiertestem": "animalisiert",
    "animalisiertesten": "animalisiert",
    "animalisiertester": "animalisiert",
    "animalisiertestes": "animalisiert",
    "animalisiertet": "animalisieren",
    "animiere": "animieren",
    "animierend": "animieren",
    "animierende": "animierend",
    "animierendem": "animierend",
    "animierenden": "animierend",
    "animierender": "animierend",
    "animierendere": "animierend",
    "animierenderem": "animierend",
    "animierenderen": "animierend",
    "animierenderer": "animierend",
    "animierenderes": "animierend",
    "animierendes": "animierend",
    "animierendste": "animierend",
    "animierendstem": "animierend",
    "animierendsten": "animierend",
    "animierendster": "animierend",
    "animierendstes": "animierend",
    "animierest": "animieren",
    "animieret": "animieren",
    "animierst": "animieren",
    "animiert": "animieren",
    "animierte": "animieren",
    "animiertem": "animiert",
    "animierten": "animieren",
    "animierter": "animiert",
    "animiertere": "animiert",
    "animierterem": "animiert",
    "animierteren": "animiert",
    "animierterer": "animiert",
    "animierteres": "animiert",
    "animiertes": "animiert",
    "animiertest": "animieren",
    "animierteste": "animiert",
    "animiertestem": "animiert",
    "animiertesten": "animiert",
    "animiertester": "animiert",
    "animiertestes": "animiert",
    "animiertet": "animieren",
    "anjage": "anjagen",
    "anjagend": "anjagen",
    "anjagende": "anjagend",
    "anjagendem": "anjagend",
    "anjagenden": "anjagend",
    "anjagender": "anjagend",
    "anjagendes": "anjagend",
    "anjagest": "anjagen",
    "anjaget": "anjagen",
    "anjagst": "anjagen",
    "anjagt": "anjagen",
    "anjagte": "anjagen",
    "anjagten": "anjagen",
    "anjagtest": "anjagen",
    "anjagtet": "anjagen",
    "ankam": "ankommen",
    "ankamen": "ankommen",
    "ankamst": "ankommen",
    "ankamt": "ankommen",
    "ankaufend": "ankaufen",
    "ankaufende": "ankaufend",
    "ankaufendem": "ankaufend",
    "ankaufenden": "ankaufend",
    "ankaufender": "ankaufend",
    "ankaufendes": "ankaufend",
    "ankaufest": "ankaufen",
    "ankaufet": "ankaufen",
    "ankaufst": "ankaufen",
    "ankauft": "ankaufen",
    "ankaufte": "ankaufen",
    "ankauften": "ankaufen",
    "ankauftest": "ankaufen",
    "ankauftet": "ankaufen",
    "ankeile": "ankeilen",
    "ankeilend": "ankeilen",
    "ankeilende": "ankeilend",
    "ankeilendem": "ankeilend",
    "ankeilenden": "ankeilend",
    "ankeilender": "ankeilend",
    "ankeilendere": "ankeilend",
    "ankeilenderem": "ankeilend",
    "ankeilenderen": "ankeilend",
    "ankeilenderer": "ankeilend",
    "ankeilenderes": "ankeilend",
    "ankeilendes": "ankeilend",
    "ankeilendste": "ankeilend",
    "ankeilendstem": "ankeilend",
    "ankeilendsten": "ankeilend",
    "ankeilendster": "ankeilend",
    "ankeilendstes": "ankeilend",
    "ankeilest": "ankeilen",
    "ankeilet": "ankeilen",
    "ankeilst": "ankeilen",
    "ankeilt": "ankeilen",
    "ankeilte": "ankeilen",
    "ankeilten": "ankeilen",
    "ankeiltest": "ankeilen",
    "ankeiltet": "ankeilen",
    "ankere": "ankern",
    "ankernd": "ankern",
    "ankernde": "ankernd",
    "ankerndem": "ankernd",
    "ankernden": "ankernd",
    "ankernder": "ankernd",
    "ankerndere": "ankernd",
    "ankernderem": "ankernd",
    "ankernderen": "ankernd",
    "ankernderer": "ankernd",
    "ankernderes": "ankernd",
    "ankerndes": "ankernd",
    "ankerndste": "ankernd",
    "ankerndstem": "ankernd",
    "ankerndsten": "ankernd",
    "ankerndster": "ankernd",
    "ankerndstes": "ankernd",
    "ankerst": "ankern",
    "ankert": "ankern",
    "ankerte": "ankern",
    "ankerten": "ankern",
    "ankertest": "ankern",
    "ankertet": "ankern",
    "ankette": "anketten",
    "ankettend": "anketten",
    "ankettende": "ankettend",
    "ankettendem": "ankettend",
    "ankettenden": "ankettend",
    "ankettender": "ankettend",
    "ankettendes": "ankettend",
    "ankettest": "anketten",
    "ankettet": "anketten",
    "ankettete": "anketten",
    "anketteten": "anketten",
    "ankettetest": "anketten",
    "ankettetet": "anketten",
    "anklage": "anklagen",
    "anklagend": "anklagen",
    "anklagende": "anklagend",
    "anklagendem": "anklagend",
    "anklagenden": "anklagend",
    "anklagender": "anklagend",
    "anklagendere": "anklagend",
    "anklagenderem": "anklagend",
    "anklagenderen": "anklagend",
    "anklagenderer": "anklagend",
    "anklagenderes": "anklagend",
    "anklagendes": "anklagend",
    "anklagendste": "anklagend",
    "anklagendstem": "anklagend",
    "anklagendsten": "anklagend",
    "anklagendster": "anklagend",
    "anklagendstes": "anklagend",
    "anklagest": "anklagen",
    "anklaget": "anklagen",
    "anklagst": "anklagen",
    "anklagt": "anklagen",
    "anklagte": "anklagen",
    "anklagten": "anklagen",
    "anklagtest": "anklagen",
    "anklagtet": "anklagen",
    "anklammere": "anklammern",
    "anklammernd": "anklammern",
    "anklammernde": "anklammernd",
    "anklammerndem": "anklammernd",
    "anklammernden": "anklammernd",
    "anklammernder": "anklammernd",
    "anklammerndes": "anklammernd",
    "anklammerst": "anklammern",
    "anklammert": "anklammern",
    "anklammerte": "anklammern",
    "anklammerten": "anklammern",
    "anklammertest": "anklammern",
    "anklammertet": "anklammern",
    "anklang": "anklingen",
    "anklangen": "anklingen",
    "anklangst": "anklingen",
    "anklangt": "anklingen",
    "anklebe": "ankleben",
    "anklebend": "ankleben",
    "anklebende": "anklebend",
    "anklebendem": "anklebend",
    "anklebenden": "anklebend",
    "anklebender": "anklebend",
    "anklebendes": "anklebend",
    "anklebest": "ankleben",
    "anklebet": "ankleben",
    "anklebst": "ankleben",
    "anklebt": "ankleben",
    "anklebte": "ankleben",
    "anklebten": "ankleben",
    "anklebtest": "ankleben",
    "anklebtet": "ankleben",
    "ankleide": "ankleiden",
    "ankleidend": "ankleiden",
    "ankleidende": "ankleidend",
    "ankleidendem": "ankleidend",
    "ankleidenden": "ankleidend",
    "ankleidender": "ankleidend",
    "ankleidendes": "ankleidend",
    "ankleidest": "ankleiden",
    "ankleidet": "ankleiden",
    "ankleidete": "ankleiden",
    "ankleideten": "ankleiden",
    "ankleidetest": "ankleiden",
    "ankleidetet": "ankleiden",
    "anklinge": "anklingen",
    "anklingele": "anklingeln",
    "anklingelnd": "anklingeln",
    "anklingelnde": "anklingelnd",
    "anklingelndem": "anklingelnd",
    "anklingelnden": "anklingelnd",
    "anklingelnder": "anklingelnd",
    "anklingelndes": "anklingelnd",
    "anklingelst": "anklingeln",
    "anklingelt": "anklingeln",
    "anklingelte": "anklingeln",
    "anklingelten": "anklingeln",
    "anklingeltest": "anklingeln",
    "anklingeltet": "anklingeln",
    "anklingend": "anklingen",
    "anklingende": "anklingend",
    "anklingendem": "anklingend",
    "anklingenden": "anklingend",
    "anklingender": "anklingend",
    "anklingendes": "anklingend",
    "anklingest": "anklingen",
    "anklinget": "anklingen",
    "anklingle": "anklingeln",
    "anklingst": "anklingen",
    "anklingt": "anklingen",
    "anklopfe": "anklopfen",
    "anklopfend": "anklopfen",
    "anklopfende": "anklopfend",
    "anklopfendem": "anklopfend",
    "anklopfenden": "anklopfend",
    "anklopfender": "anklopfend",
    "anklopfendes": "anklopfend",
    "anklopfest": "anklopfen",
    "anklopfet": "anklopfen",
    "anklopfst": "anklopfen",
    "anklopft": "anklopfen",
    "anklopfte": "anklopfen",
    "anklopften": "anklopfen",
    "anklopftest": "anklopfen",
    "anklopftet": "anklopfen",
    "anklänge": "anklingen",
    "anklängen": "anklingen",
    "anklängest": "anklingen",
    "anklänget": "anklingen",
    "anknabbere": "anknabbern",
    "anknabbernd": "anknabbern",
    "anknabbernde": "anknabbernd",
    "anknabberndem": "anknabbernd",
    "anknabbernden": "anknabbernd",
    "anknabbernder": "anknabbernd",
    "anknabberndere": "anknabbernd",
    "anknabbernderem": "anknabbernd",
    "anknabbernderen": "anknabbernd",
    "anknabbernderer": "anknabbernd",
    "anknabbernderes": "anknabbernd",
    "anknabberndes": "anknabbernd",
    "anknabberndste": "anknabbernd",
    "anknabberndstem": "anknabbernd",
    "anknabberndsten": "anknabbernd",
    "anknabberndster": "anknabbernd",
    "anknabberndstes": "anknabbernd",
    "anknabberst": "anknabbern",
    "anknabbert": "anknabbern",
    "anknabberte": "anknabbern",
    "anknabberten": "anknabbern",
    "anknabbertest": "anknabbern",
    "anknabbertet": "anknabbern",
    "anknackse": "anknacksen",
    "anknacksend": "anknacksen",
    "anknacksende": "anknacksend",
    "anknacksendem": "anknacksend",
    "anknacksenden": "anknacksend",
    "anknacksender": "anknacksend",
    "anknacksendere": "anknacksend",
    "anknacksenderem": "anknacksend",
    "anknacksenderen": "anknacksend",
    "anknacksenderer": "anknacksend",
    "anknacksenderes": "anknacksend",
    "anknacksendes": "anknacksend",
    "anknacksendste": "anknacksend",
    "anknacksendstem": "anknacksend",
    "anknacksendsten": "anknacksend",
    "anknacksendster": "anknacksend",
    "anknacksendstes": "anknacksend",
    "anknacksest": "anknacksen",
    "anknackset": "anknacksen",
    "anknackst": "anknacksen",
    "anknackste": "anknacksen",
    "anknacksten": "anknacksen",
    "anknackstest": "anknacksen",
    "anknackstet": "anknacksen",
    "anknipse": "anknipsen",
    "anknipsend": "anknipsen",
    "anknipsende": "anknipsend",
    "anknipsendem": "anknipsend",
    "anknipsenden": "anknipsend",
    "anknipsender": "anknipsend",
    "anknipsendes": "anknipsend",
    "anknipsest": "anknipsen",
    "anknipset": "anknipsen",
    "anknipst": "anknipsen",
    "anknipste": "anknipsen",
    "anknipsten": "anknipsen",
    "anknipstest": "anknipsen",
    "anknipstet": "anknipsen",
    "anknöpfe": "anknöpfen",
    "anknöpfend": "anknöpfen",
    "anknöpfende": "anknöpfend",
    "anknöpfendem": "anknöpfend",
    "anknöpfenden": "anknöpfend",
    "anknöpfender": "anknöpfend",
    "anknöpfendes": "anknöpfend",
    "anknöpfest": "anknöpfen",
    "anknöpfet": "anknöpfen",
    "anknöpfst": "anknöpfen",
    "anknöpft": "anknöpfen",
    "anknöpfte": "anknöpfen",
    "anknöpften": "anknöpfen",
    "anknöpftest": "anknöpfen",
    "anknöpftet": "anknöpfen",
    "anknüpfe": "anknüpfen",
    "anknüpfend": "anknüpfen",
    "anknüpfende": "anknüpfend",
    "anknüpfendem": "anknüpfend",
    "anknüpfenden": "anknüpfend",
    "anknüpfender": "anknüpfend",
    "anknüpfendes": "anknüpfend",
    "anknüpfest": "anknüpfen",
    "anknüpfet": "anknüpfen",
    "anknüpfst": "anknüpfen",
    "anknüpft": "anknüpfen",
    "anknüpfte": "anknüpfen",
    "anknüpften": "anknüpfen",
    "anknüpftest": "anknüpfen",
    "anknüpftet": "anknüpfen",
    "ankohle": "ankohlen",
    "ankohlend": "ankohlen",
    "ankohlende": "ankohlend",
    "ankohlendem": "ankohlend",
    "ankohlenden": "ankohlend",
    "ankohlender": "ankohlend",
    "ankohlendere": "ankohlend",
    "ankohlenderem": "ankohlend",
    "ankohlenderen": "ankohlend",
    "ankohlenderer": "ankohlend",
    "ankohlenderes": "ankohlend",
    "ankohlendes": "ankohlend",
    "ankohlendste": "ankohlend",
    "ankohlendstem": "ankohlend",
    "ankohlendsten": "ankohlend",
    "ankohlendster": "ankohlend",
    "ankohlendstes": "ankohlend",
    "ankohlest": "ankohlen",
    "ankohlet": "ankohlen",
    "ankohlst": "ankohlen",
    "ankohlt": "ankohlen",
    "ankohlte": "ankohlen",
    "ankohlten": "ankohlen",
    "ankohltest": "ankohlen",
    "ankohltet": "ankohlen",
    "ankomme": "ankommen",
    "ankommend": "ankommen",
    "ankommende": "ankommend",
    "ankommendem": "ankommend",
    "ankommenden": "ankommend",
    "ankommender": "ankommend",
    "ankommendes": "ankommend",
    "ankommest": "ankommen",
    "ankommet": "ankommen",
    "ankommst": "ankommen",
    "ankommt": "ankommen",
    "ankoppele": "ankoppeln",
    "ankoppelnd": "ankoppeln",
    "ankoppelnde": "ankoppelnd",
    "ankoppelndem": "ankoppelnd",
    "ankoppelnden": "ankoppelnd",
    "ankoppelnder": "ankoppelnd",
    "ankoppelndes": "ankoppelnd",
    "ankoppelst": "ankoppeln",
    "ankoppelt": "ankoppeln",
    "ankoppelte": "ankoppeln",
    "ankoppelten": "ankoppeln",
    "ankoppeltest": "ankoppeln",
    "ankoppeltet": "ankoppeln",
    "ankopple": "ankoppeln",
    "ankotze": "ankotzen",
    "ankotzend": "ankotzen",
    "ankotzende": "ankotzend",
    "ankotzendem": "ankotzend",
    "ankotzenden": "ankotzend",
    "ankotzender": "ankotzend",
    "ankotzendes": "ankotzend",
    "ankotzest": "ankotzen",
    "ankotzet": "ankotzen",
    "ankotzt": "ankotzen",
    "ankotzte": "ankotzen",
    "ankotzten": "ankotzen",
    "ankotztest": "ankotzen",
    "ankotztet": "ankotzen",
    "ankralle": "ankrallen",
    "ankrallend": "ankrallen",
    "ankrallende": "ankrallend",
    "ankrallendem": "ankrallend",
    "ankrallenden": "ankrallend",
    "ankrallender": "ankrallend",
    "ankrallendes": "ankrallend",
    "ankrallest": "ankrallen",
    "ankrallet": "ankrallen",
    "ankrallst": "ankrallen",
    "ankrallt": "ankrallen",
    "ankrallte": "ankrallen",
    "ankrallten": "ankrallen",
    "ankralltest": "ankrallen",
    "ankralltet": "ankrallen",
    "ankreide": "ankreiden",
    "ankreidend": "ankreiden",
    "ankreidende": "ankreidend",
    "ankreidendem": "ankreidend",
    "ankreidenden": "ankreidend",
    "ankreidender": "ankreidend",
    "ankreidendes": "ankreidend",
    "ankreidest": "ankreiden",
    "ankreidet": "ankreiden",
    "ankreidete": "ankreiden",
    "ankreideten": "ankreiden",
    "ankreidetest": "ankreiden",
    "ankreidetet": "ankreiden",
    "ankreuze": "ankreuzen",
    "ankreuzend": "ankreuzen",
    "ankreuzende": "ankreuzend",
    "ankreuzendem": "ankreuzend",
    "ankreuzenden": "ankreuzend",
    "ankreuzender": "ankreuzend",
    "ankreuzendes": "ankreuzend",
    "ankreuzest": "ankreuzen",
    "ankreuzet": "ankreuzen",
    "ankreuzt": "ankreuzen",
    "ankreuzte": "ankreuzen",
    "ankreuzten": "ankreuzen",
    "ankreuztest": "ankreuzen",
    "ankreuztet": "ankreuzen",
    "ankuppele": "ankuppeln",
    "ankuppelnd": "ankuppeln",
    "ankuppelnde": "ankuppelnd",
    "ankuppelndem": "ankuppelnd",
    "ankuppelnden": "ankuppelnd",
    "ankuppelnder": "ankuppelnd",
    "ankuppelndes": "ankuppelnd",
    "ankuppelst": "ankuppeln",
    "ankuppelt": "ankuppeln",
    "ankuppelte": "ankuppeln",
    "ankuppelten": "ankuppeln",
    "ankuppeltest": "ankuppeln",
    "ankuppeltet": "ankuppeln",
    "ankupple": "ankuppeln",
    "ankurbele": "ankurbeln",
    "ankurbelnd": "ankurbeln",
    "ankurbelnde": "ankurbelnd",
    "ankurbelndem": "ankurbelnd",
    "ankurbelnden": "ankurbelnd",
    "ankurbelnder": "ankurbelnd",
    "ankurbelndere": "ankurbelnd",
    "ankurbelnderem": "ankurbelnd",
    "ankurbelnderen": "ankurbelnd",
    "ankurbelnderer": "ankurbelnd",
    "ankurbelnderes": "ankurbelnd",
    "ankurbelndes": "ankurbelnd",
    "ankurbelndste": "ankurbelnd",
    "ankurbelndstem": "ankurbelnd",
    "ankurbelndsten": "ankurbelnd",
    "ankurbelndster": "ankurbelnd",
    "ankurbelndstes": "ankurbelnd",
    "ankurbelst": "ankurbeln",
    "ankurbelt": "ankurbeln",
    "ankurbelte": "ankurbeln",
    "ankurbelten": "ankurbeln",
    "ankurbeltest": "ankurbeln",
    "ankurbeltet": "ankurbeln",
    "ankurble": "ankurbeln",
    "ankäme": "ankommen",
    "ankämen": "ankommen",
    "ankämest": "ankommen",
    "ankämet": "ankommen",
    "ankämpfe": "ankämpfen",
    "ankämpfend": "ankämpfen",
    "ankämpfende": "ankämpfend",
    "ankämpfendem": "ankämpfend",
    "ankämpfenden": "ankämpfend",
    "ankämpfender": "ankämpfend",
    "ankämpfendes": "ankämpfend",
    "ankämpfest": "ankämpfen",
    "ankämpfet": "ankämpfen",
    "ankämpfst": "ankämpfen",
    "ankämpft": "ankämpfen",
    "ankämpfte": "ankämpfen",
    "ankämpften": "ankämpfen",
    "ankämpftest": "ankämpfen",
    "ankämpftet": "ankämpfen",
    "anködere": "anködern",
    "anködernd": "anködern",
    "anködernde": "anködernd",
    "anköderndem": "anködernd",
    "anködernden": "anködernd",
    "anködernder": "anködernd",
    "anköderndes": "anködernd",
    "anköderst": "anködern",
    "anködert": "anködern",
    "anköderte": "anködern",
    "anköderten": "anködern",
    "anködertest": "anködern",
    "anködertet": "anködern",
    "ankündige": "ankündigen",
    "ankündigend": "ankündigen",
    "ankündigende": "ankündigend",
    "ankündigendem": "ankündigend",
    "ankündigenden": "ankündigend",
    "ankündigender": "ankündigend",
    "ankündigendes": "ankündigend",
    "ankündigest": "ankündigen",
    "ankündiget": "ankündigen",
    "ankündigst": "ankündigen",
    "ankündigt": "ankündigen",
    "ankündigte": "ankündigen",
    "ankündigten": "ankündigen",
    "ankündigtest": "ankündigen",
    "ankündigtet": "ankündigen",
    "anlache": "anlachen",
    "anlachend": "anlachen",
    "anlachende": "anlachend",
    "anlachendem": "anlachend",
    "anlachenden": "anlachend",
    "anlachender": "anlachend",
    "anlachendes": "anlachend",
    "anlachest": "anlachen",
    "anlachet": "anlachen",
    "anlachst": "anlachen",
    "anlacht": "anlachen",
    "anlachte": "anlachen",
    "anlachten": "anlachen",
    "anlachtest": "anlachen",
    "anlachtet": "anlachen",
    "anlag": "anliegen",
    "anlagere": "anlagern",
    "anlagernd": "anlagern",
    "anlagernde": "anlagernd",
    "anlagerndem": "anlagernd",
    "anlagernden": "anlagernd",
    "anlagernder": "anlagernd",
    "anlagerndes": "anlagernd",
    "anlagerst": "anlagern",
    "anlagert": "anlagern",
    "anlagerte": "anlagern",
    "anlagerten": "anlagern",
    "anlagertest": "anlagern",
    "anlagertet": "anlagern",
    "anlagst": "anliegen",
    "anlagt": "anliegen",
    "anlas": "anlesen",
    "anlasen": "anlesen",
    "anlassend": "anlassen",
    "anlassende": "anlassend",
    "anlassendem": "anlassend",
    "anlassenden": "anlassend",
    "anlassender": "anlassend",
    "anlassendes": "anlassend",
    "anlassest": "anlassen",
    "anlasset": "anlassen",
    "anlast": "anlesen",
    "anlaste": "anlasten",
    "anlastend": "anlasten",
    "anlastende": "anlastend",
    "anlastendem": "anlastend",
    "anlastenden": "anlastend",
    "anlastender": "anlastend",
    "anlastendere": "anlastend",
    "anlastenderem": "anlastend",
    "anlastenderen": "anlastend",
    "anlastenderer": "anlastend",
    "anlastenderes": "anlastend",
    "anlastendes": "anlastend",
    "anlastendste": "anlastend",
    "anlastendstem": "anlastend",
    "anlastendsten": "anlastend",
    "anlastendster": "anlastend",
    "anlastendstes": "anlastend",
    "anlastest": "anlasten",
    "anlastet": "anlasten",
    "anlastete": "anlasten",
    "anlasteten": "anlasten",
    "anlastetest": "anlasten",
    "anlastetet": "anlasten",
    "anlaufend": "anlaufen",
    "anlaufende": "anlaufend",
    "anlaufendem": "anlaufend",
    "anlaufenden": "anlaufend",
    "anlaufender": "anlaufend",
    "anlaufendes": "anlaufend",
    "anlaufest": "anlaufen",
    "anlaufet": "anlaufen",
    "anlauft": "anlaufen",
    "anlaute": "anlauten",
    "anlautend": "anlauten",
    "anlautende": "anlautend",
    "anlautendem": "anlautend",
    "anlautenden": "anlautend",
    "anlautender": "anlautend",
    "anlautendes": "anlautend",
    "anlautest": "anlauten",
    "anlautet": "anlauten",
    "anlautete": "anlauten",
    "anlauteten": "anlauten",
    "anlautetest": "anlauten",
    "anlautetet": "anlauten",
    "anlaßt": "anlassen",
    "anlege": "anlegen",
    "anlegend": "anlegen",
    "anlegende": "anlegend",
    "anlegendem": "anlegend",
    "anlegenden": "anlegend",
    "anlegender": "anlegend",
    "anlegendes": "anlegend",
    "anlegest": "anlegen",
    "anleget": "anlegen",
    "anlegst": "anlegen",
    "anlegt": "anlegen",
    "anlegte": "anlegen",
    "anlegten": "anlegen",
    "anlegtest": "anlegen",
    "anlegtet": "anlegen",
    "anlehne": "anlehnen",
    "anlehnend": "anlehnen",
    "anlehnende": "anlehnend",
    "anlehnendem": "anlehnend",
    "anlehnenden": "anlehnend",
    "anlehnender": "anlehnend",
    "anlehnendes": "anlehnend",
    "anlehnest": "anlehnen",
    "anlehnet": "anlehnen",
    "anlehnst": "anlehnen",
    "anlehnt": "anlehnen",
    "anlehnte": "anlehnen",
    "anlehnten": "anlehnen",
    "anlehntest": "anlehnen",
    "anlehntet": "anlehnen",
    "anlehnungsbedürftigem": "anlehnungsbedürftig",
    "anlehnungsbedürftigen": "anlehnungsbedürftig",
    "anlehnungsbedürftiger": "anlehnungsbedürftig",
    "anlehnungsbedürftigere": "anlehnungsbedürftig",
    "anlehnungsbedürftigerem": "anlehnungsbedürftig",
    "anlehnungsbedürftigeren": "anlehnungsbedürftig",
    "anlehnungsbedürftigerer": "anlehnungsbedürftig",
    "anlehnungsbedürftigeres": "anlehnungsbedürftig",
    "anlehnungsbedürftiges": "anlehnungsbedürftig",
    "anlehnungsbedürftigste": "anlehnungsbedürftig",
    "anlehnungsbedürftigstem": "anlehnungsbedürftig",
    "anlehnungsbedürftigsten": "anlehnungsbedürftig",
    "anlehnungsbedürftigster": "anlehnungsbedürftig",
    "anlehnungsbedürftigstes": "anlehnungsbedürftig",
    "anleime": "anleimen",
    "anleimend": "anleimen",
    "anleimende": "anleimend",
    "anleimendem": "anleimend",
    "anleimenden": "anleimend",
    "anleimender": "anleimend",
    "anleimendes": "anleimend",
    "anleimest": "anleimen",
    "anleimet": "anleimen",
    "anleimst": "anleimen",
    "anleimt": "anleimen",
    "anleimte": "anleimen",
    "anleimten": "anleimen",
    "anleimtest": "anleimen",
    "anleimtet": "anleimen",
    "anleine": "anleinen",
    "anleinend": "anleinen",
    "anleinende": "anleinend",
    "anleinendem": "anleinend",
    "anleinenden": "anleinend",
    "anleinender": "anleinend",
    "anleinendes": "anleinend",
    "anleinest": "anleinen",
    "anleinet": "anleinen",
    "anleinst": "anleinen",
    "anleint": "anleinen",
    "anleinte": "anleinen",
    "anleinten": "anleinen",
    "anleintest": "anleinen",
    "anleintet": "anleinen",
    "anleite": "anleiten",
    "anleitend": "anleiten",
    "anleitende": "anleitend",
    "anleitendem": "anleitend",
    "anleitenden": "anleitend",
    "anleitender": "anleitend",
    "anleitendes": "anleitend",
    "anleitest": "anleiten",
    "anleitet": "anleiten",
    "anleitete": "anleiten",
    "anleiteten": "anleiten",
    "anleitetest": "anleiten",
    "anleitetet": "anleiten",
    "anlerne": "anlernen",
    "anlernend": "anlernen",
    "anlernende": "anlernend",
    "anlernendem": "anlernend",
    "anlernenden": "anlernend",
    "anlernender": "anlernend",
    "anlernendes": "anlernend",
    "anlernest": "anlernen",
    "anlernet": "anlernen",
    "anlernst": "anlernen",
    "anlernt": "anlernen",
    "anlernte": "anlernen",
    "anlernten": "anlernen",
    "anlerntest": "anlernen",
    "anlerntet": "anlernen",
    "anlese": "anlesen",
    "anlesend": "anlesen",
    "anlesende": "anlesend",
    "anlesendem": "anlesend",
    "anlesenden": "anlesend",
    "anlesender": "anlesend",
    "anlesendes": "anlesend",
    "anlesest": "anlesen",
    "anleset": "anlesen",
    "anlest": "anlesen",
    "anleuchte": "anleuchten",
    "anleuchtend": "anleuchten",
    "anleuchtende": "anleuchtend",
    "anleuchtendem": "anleuchtend",
    "anleuchtenden": "anleuchtend",
    "anleuchtender": "anleuchtend",
    "anleuchtendes": "anleuchtend",
    "anleuchtest": "anleuchten",
    "anleuchtet": "anleuchten",
    "anleuchtete": "anleuchten",
    "anleuchteten": "anleuchten",
    "anleuchtetest": "anleuchten",
    "anleuchtetet": "anleuchten",
    "anlief": "anlaufen",
    "anliefe": "anlaufen",
    "anliefen": "anlaufen",
    "anliefere": "anliefern",
    "anliefernd": "anliefern",
    "anliefernde": "anliefernd",
    "anlieferndem": "anliefernd",
    "anliefernden": "anliefernd",
    "anliefernder": "anliefernd",
    "anlieferndes": "anliefernd",
    "anlieferst": "anliefern",
    "anliefert": "anliefern",
    "anlieferte": "anliefern",
    "anlieferten": "anliefern",
    "anliefertest": "anliefern",
    "anliefertet": "anliefern",
    "anliefest": "anlaufen",
    "anliefet": "anlaufen",
    "anliefst": "anlaufen",
    "anlieft": "anlaufen",
    "anliege": "anliegen",
    "anliegend": "anliegen",
    "anliegende": "anliegend",
    "anliegendem": "anliegend",
    "anliegenden": "anliegend",
    "anliegender": "anliegend",
    "anliegendes": "anliegend",
    "anliegest": "anliegen",
    "anlieget": "anliegen",
    "anliegst": "anliegen",
    "anliegt": "anliegen",
    "anliest": "anlesen",
    "anließ": "anlassen",
    "anließe": "anlassen",
    "anließen": "anlassen",
    "anließest": "anlassen",
    "anließet": "anlassen",
    "anließt": "anlassen",
    "anlog": "anlügen",
    "anlogen": "anlügen",
    "anlogst": "anlügen",
    "anlogt": "anlügen",
    "anlächele": "anlächeln",
    "anlächelnd": "anlächeln",
    "anlächelnde": "anlächelnd",
    "anlächelndem": "anlächelnd",
    "anlächelnden": "anlächelnd",
    "anlächelnder": "anlächelnd",
    "anlächelndes": "anlächelnd",
    "anlächelst": "anlächeln",
    "anlächelt": "anlächeln",
    "anlächelte": "anlächeln",
    "anlächelten": "anlächeln",
    "anlächeltest": "anlächeln",
    "anlächeltet": "anlächeln",
    "anlächle": "anlächeln",
    "anläge": "anliegen",
    "anlägen": "anliegen",
    "anlägest": "anliegen",
    "anläget": "anliegen",
    "anläse": "anlesen",
    "anläsen": "anlesen",
    "anläsest": "anlesen",
    "anläset": "anlesen",
    "anläufst": "anlaufen",
    "anläuft": "anlaufen",
    "anläute": "anläuten",
    "anläutend": "anläuten",
    "anläutendem": "anläutend",
    "anläutender": "anläutend",
    "anläutendes": "anläutend",
    "anläutest": "anläuten",
    "anläutet": "anläuten",
    "anläutete": "anläuten",
    "anläuteten": "anläuten",
    "anläutetest": "anläuten",
    "anläutetet": "anläuten",
    "anläßt": "anlassen",
    "anlöge": "anlügen",
    "anlögen": "anlügen",
    "anlögest": "anlügen",
    "anlöget": "anlügen",
    "anlöte": "anlöten",
    "anlötend": "anlöten",
    "anlötende": "anlötend",
    "anlötendem": "anlötend",
    "anlötenden": "anlötend",
    "anlötender": "anlötend",
    "anlötendes": "anlötend",
    "anlötest": "anlöten",
    "anlötet": "anlöten",
    "anlötete": "anlöten",
    "anlöteten": "anlöten",
    "anlötetest": "anlöten",
    "anlötetet": "anlöten",
    "anlüge": "anlügen",
    "anlügend": "anlügen",
    "anlügende": "anlügend",
    "anlügendem": "anlügend",
    "anlügenden": "anlügend",
    "anlügender": "anlügend",
    "anlügendes": "anlügend",
    "anlügest": "anlügen",
    "anlüget": "anlügen",
    "anlügst": "anlügen",
    "anlügt": "anlügen",
    "anmache": "anmachen",
    "anmachend": "anmachen",
    "anmachende": "anmachend",
    "anmachendem": "anmachend",
    "anmachenden": "anmachend",
    "anmachender": "anmachend",
    "anmachendes": "anmachend",
    "anmachest": "anmachen",
    "anmachet": "anmachen",
    "anmachst": "anmachen",
    "anmacht": "anmachen",
    "anmachte": "anmachen",
    "anmachten": "anmachen",
    "anmachtest": "anmachen",
    "anmachtet": "anmachen",
    "anmahne": "anmahnen",
    "anmahnend": "anmahnen",
    "anmahnende": "anmahnend",
    "anmahnendem": "anmahnend",
    "anmahnenden": "anmahnend",
    "anmahnender": "anmahnend",
    "anmahnendes": "anmahnend",
    "anmahnest": "anmahnen",
    "anmahnet": "anmahnen",
    "anmahnst": "anmahnen",
    "anmahnt": "anmahnen",
    "anmahnte": "anmahnen",
    "anmahnten": "anmahnen",
    "anmahntest": "anmahnen",
    "anmahntet": "anmahnen",
    "anmale": "anmalen",
    "anmalend": "anmalen",
    "anmalende": "anmalend",
    "anmalendem": "anmalend",
    "anmalenden": "anmalend",
    "anmalender": "anmalend",
    "anmalendes": "anmalend",
    "anmalest": "anmalen",
    "anmalet": "anmalen",
    "anmalst": "anmalen",
    "anmalt": "anmalen",
    "anmalte": "anmalen",
    "anmalten": "anmalen",
    "anmaltest": "anmalen",
    "anmaltet": "anmalen",
    "anmarschiere": "anmarschieren",
    "anmarschierend": "anmarschieren",
    "anmarschierende": "anmarschierend",
    "anmarschierendem": "anmarschierend",
    "anmarschierenden": "anmarschierend",
    "anmarschierender": "anmarschierend",
    "anmarschierendes": "anmarschierend",
    "anmarschierest": "anmarschieren",
    "anmarschieret": "anmarschieren",
    "anmarschierst": "anmarschieren",
    "anmarschiert": "anmarschieren",
    "anmarschierte": "anmarschieren",
    "anmarschiertem": "anmarschiert",
    "anmarschierten": "anmarschieren",
    "anmarschierter": "anmarschiert",
    "anmarschiertes": "anmarschiert",
    "anmarschiertest": "anmarschieren",
    "anmarschiertet": "anmarschieren",
    "anmaß": "anmessen",
    "anmaße": "anmaßen",
    "anmaßen": "anmessen",
    "anmaßend": "anmaßen",
    "anmaßende": "anmaßend",
    "anmaßendem": "anmaßend",
    "anmaßenden": "anmaßend",
    "anmaßender": "anmaßend",
    "anmaßendere": "anmaßend",
    "anmaßenderem": "anmaßend",
    "anmaßenderen": "anmaßend",
    "anmaßenderer": "anmaßend",
    "anmaßenderes": "anmaßend",
    "anmaßendes": "anmaßend",
    "anmaßendste": "anmaßend",
    "anmaßendstem": "anmaßend",
    "anmaßendsten": "anmaßend",
    "anmaßendster": "anmaßend",
    "anmaßendstes": "anmaßend",
    "anmaßest": "anmaßen",
    "anmaßet": "anmaßen",
    "anmaßt": "anmessen",
    "anmaßte": "anmaßen",
    "anmaßten": "anmaßen",
    "anmaßtest": "anmaßen",
    "anmaßtet": "anmaßen",
    "anmelde": "anmelden",
    "anmeldend": "anmelden",
    "anmeldende": "anmeldend",
    "anmeldendem": "anmeldend",
    "anmeldenden": "anmeldend",
    "anmeldender": "anmeldend",
    "anmeldendes": "anmeldend",
    "anmeldepflichtigem": "anmeldepflichtig",
    "anmeldepflichtigen": "anmeldepflichtig",
    "anmeldepflichtiger": "anmeldepflichtig",
    "anmeldepflichtiges": "anmeldepflichtig",
    "anmeldest": "anmelden",
    "anmeldet": "anmelden",
    "anmeldete": "anmelden",
    "anmeldeten": "anmelden",
    "anmeldetest": "anmelden",
    "anmeldetet": "anmelden",
    "anmerke": "anmerken",
    "anmerkend": "anmerken",
    "anmerkende": "anmerkend",
    "anmerkendem": "anmerkend",
    "anmerkenden": "anmerkend",
    "anmerkender": "anmerkend",
    "anmerkendes": "anmerkend",
    "anmerkest": "anmerken",
    "anmerket": "anmerken",
    "anmerkst": "anmerken",
    "anmerkt": "anmerken",
    "anmerkte": "anmerken",
    "anmerkten": "anmerken",
    "anmerktest": "anmerken",
    "anmerktet": "anmerken",
    "anmesse": "anmessen",
    "anmessend": "anmessen",
    "anmessende": "anmessend",
    "anmessendem": "anmessend",
    "anmessenden": "anmessend",
    "anmessender": "anmessend",
    "anmessendes": "anmessend",
    "anmessest": "anmessen",
    "anmesset": "anmessen",
    "anmeßt": "anmessen",
    "anmiete": "anmieten",
    "anmietend": "anmieten",
    "anmietende": "anmietend",
    "anmietendem": "anmietend",
    "anmietenden": "anmietend",
    "anmietender": "anmietend",
    "anmietendes": "anmietend",
    "anmietest": "anmieten",
    "anmietet": "anmieten",
    "anmietete": "anmieten",
    "anmieteten": "anmieten",
    "anmietetest": "anmieten",
    "anmietetet": "anmieten",
    "anmißt": "anmessen",
    "anmotze": "anmotzen",
    "anmotzend": "anmotzen",
    "anmotzende": "anmotzend",
    "anmotzendem": "anmotzend",
    "anmotzenden": "anmotzend",
    "anmotzender": "anmotzend",
    "anmotzendere": "anmotzend",
    "anmotzenderem": "anmotzend",
    "anmotzenderen": "anmotzend",
    "anmotzenderer": "anmotzend",
    "anmotzenderes": "anmotzend",
    "anmotzendes": "anmotzend",
    "anmotzendste": "anmotzend",
    "anmotzendstem": "anmotzend",
    "anmotzendsten": "anmotzend",
    "anmotzendster": "anmotzend",
    "anmotzendstes": "anmotzend",
    "anmotzest": "anmotzen",
    "anmotzet": "anmotzen",
    "anmotzt": "anmotzen",
    "anmotzte": "anmotzen",
    "anmotzten": "anmotzen",
    "anmotztest": "anmotzen",
    "anmotztet": "anmotzen",
    "anmustere": "anmustern",
    "anmusternd": "anmustern",
    "anmusternde": "anmusternd",
    "anmusterndem": "anmusternd",
    "anmusternden": "anmusternd",
    "anmusternder": "anmusternd",
    "anmusterndes": "anmusternd",
    "anmusterst": "anmustern",
    "anmustert": "anmustern",
    "anmusterte": "anmustern",
    "anmusterten": "anmustern",
    "anmustertest": "anmustern",
    "anmustertet": "anmustern",
    "anmutend": "anmuten",
    "anmutende": "anmutend",
    "anmutendem": "anmutend",
    "anmutenden": "anmutend",
    "anmutender": "anmutend",
    "anmutendes": "anmutend",
    "anmutest": "anmuten",
    "anmutet": "anmuten",
    "anmutete": "anmuten",
    "anmuteten": "anmuten",
    "anmutetest": "anmuten",
    "anmutetet": "anmuten",
    "anmutige": "anmutig",
    "anmutigem": "anmutig",
    "anmutigen": "anmutig",
    "anmutiger": "anmutig",
    "anmutigere": "anmutig",
    "anmutigerem": "anmutig",
    "anmutigeren": "anmutig",
    "anmutigerer": "anmutig",
    "anmutigeres": "anmutig",
    "anmutiges": "anmutig",
    "anmutigste": "anmutig",
    "anmutigstem": "anmutig",
    "anmutigsten": "anmutig",
    "anmutigster": "anmutig",
    "anmutigstes": "anmutig",
    "anmäße": "anmessen",
    "anmäßen": "anmessen",
    "anmäßest": "anmessen",
    "anmäßet": "anmessen",
    "annage": "annagen",
    "annagele": "annageln",
    "annagelnd": "annageln",
    "annagelnde": "annagelnd",
    "annagelndem": "annagelnd",
    "annagelnden": "annagelnd",
    "annagelnder": "annagelnd",
    "annagelndes": "annagelnd",
    "annagelst": "annageln",
    "annagelt": "annageln",
    "annagelte": "annageln",
    "annagelten": "annageln",
    "annageltest": "annageln",
    "annageltet": "annageln",
    "annagend": "annagen",
    "annagende": "annagend",
    "annagendem": "annagend",
    "annagenden": "annagend",
    "annagender": "annagend",
    "annagendere": "annagend",
    "annagenderem": "annagend",
    "annagenderen": "annagend",
    "annagenderer": "annagend",
    "annagenderes": "annagend",
    "annagendes": "annagend",
    "annagendste": "annagend",
    "annagendstem": "annagend",
    "annagendsten": "annagend",
    "annagendster": "annagend",
    "annagendstes": "annagend",
    "annagest": "annagen",
    "annaget": "annagen",
    "annagle": "annageln",
    "annagst": "annagen",
    "annagt": "annagen",
    "annagte": "annagen",
    "annagten": "annagen",
    "annagtest": "annagen",
    "annagtet": "annagen",
    "annahm": "annehmen",
    "annahmst": "annehmen",
    "annahmt": "annehmen",
    "annehmbarem": "annehmbar",
    "annehmbaren": "annehmbar",
    "annehmbarer": "annehmbar",
    "annehmbares": "annehmbar",
    "annehme": "annehmen",
    "annehmend": "annehmen",
    "annehmende": "annehmend",
    "annehmendem": "annehmend",
    "annehmenden": "annehmend",
    "annehmender": "annehmend",
    "annehmendere": "annehmend",
    "annehmenderem": "annehmend",
    "annehmenderen": "annehmend",
    "annehmenderer": "annehmend",
    "annehmenderes": "annehmend",
    "annehmendes": "annehmend",
    "annehmendste": "annehmend",
    "annehmendstem": "annehmend",
    "annehmendsten": "annehmend",
    "annehmendster": "annehmend",
    "annehmendstes": "annehmend",
    "annehmest": "annehmen",
    "annehmet": "annehmen",
    "annehmliche": "annehmlich",
    "annehmlichem": "annehmlich",
    "annehmlichen": "annehmlich",
    "annehmlicher": "annehmlich",
    "annehmliches": "annehmlich",
    "annehmt": "annehmen",
    "annektiere": "annektieren",
    "annektierend": "annektieren",
    "annektierende": "annektierend",
    "annektierendem": "annektierend",
    "annektierenden": "annektierend",
    "annektierender": "annektierend",
    "annektierendere": "annektierend",
    "annektierenderem": "annektierend",
    "annektierenderen": "annektierend",
    "annektierenderer": "annektierend",
    "annektierenderes": "annektierend",
    "annektierendes": "annektierend",
    "annektierendste": "annektierend",
    "annektierendstem": "annektierend",
    "annektierendsten": "annektierend",
    "annektierendster": "annektierend",
    "annektierendstes": "annektierend",
    "annektierest": "annektieren",
    "annektieret": "annektieren",
    "annektierst": "annektieren",
    "annektiert": "annektieren",
    "annektierte": "annektieren",
    "annektiertem": "annektiert",
    "annektierten": "annektieren",
    "annektierter": "annektiert",
    "annektiertes": "annektiert",
    "annektiertest": "annektieren",
    "annektiertet": "annektieren",
    "anniete": "annieten",
    "annietend": "annieten",
    "annietende": "annietend",
    "annietendem": "annietend",
    "annietenden": "annietend",
    "annietender": "annietend",
    "annietendes": "annietend",
    "annietest": "annieten",
    "annietet": "annieten",
    "annietete": "annieten",
    "annieteten": "annieten",
    "annietetest": "annieten",
    "annietetet": "annieten",
    "annimmst": "annehmen",
    "annimmt": "annehmen",
    "annulliere": "annullieren",
    "annullierend": "annullieren",
    "annullierende": "annullierend",
    "annullierendem": "annullierend",
    "annullierenden": "annullierend",
    "annullierender": "annullierend",
    "annullierendere": "annullierend",
    "annullierenderem": "annullierend",
    "annullierenderen": "annullierend",
    "annullierenderer": "annullierend",
    "annullierenderes": "annullierend",
    "annullierendes": "annullierend",
    "annullierendste": "annullierend",
    "annullierendstem": "annullierend",
    "annullierendsten": "annullierend",
    "annullierendster": "annullierend",
    "annullierendstes": "annullierend",
    "annullierest": "annullieren",
    "annullieret": "annullieren",
    "annullierst": "annullieren",
    "annulliert": "annullieren",
    "annullierte": "annullieren",
    "annulliertem": "annulliert",
    "annullierten": "annullieren",
    "annullierter": "annulliert",
    "annulliertes": "annulliert",
    "annulliertest": "annullieren",
    "annulliertet": "annullieren",
    "annähe": "annähen",
    "annähend": "annähen",
    "annähende": "annähend",
    "annähendem": "annähend",
    "annähenden": "annähend",
    "annähender": "annähend",
    "annähendes": "annähend",
    "annähere": "annähern",
    "annähernd": "annähern",
    "annähernde": "annähernd",
    "annäherndem": "annähernd",
    "annähernden": "annähernd",
    "annähernder": "annähernd",
    "annäherndes": "annähernd",
    "annäherst": "annähern",
    "annähert": "annähern",
    "annäherte": "annähern",
    "annäherten": "annähern",
    "annähertest": "annähern",
    "annähertet": "annähern",
    "annähest": "annähen",
    "annähet": "annähen",
    "annähme": "annehmen",
    "annähmen": "annehmen",
    "annähmest": "annehmen",
    "annähmet": "annehmen",
    "annähst": "annähen",
    "annäht": "annähen",
    "annähte": "annähen",
    "annähten": "annähen",
    "annähtest": "annähen",
    "annähtet": "annähen",
    "anonyme": "anonym",
    "anonymem": "anonym",
    "anonymen": "anonym",
    "anonymer": "anonym",
    "anonymere": "anonym",
    "anonymerem": "anonym",
    "anonymeren": "anonym",
    "anonymerer": "anonym",
    "anonymeres": "anonym",
    "anonymes": "anonym",
    "anonymste": "anonym",
    "anonymstem": "anonym",
    "anonymsten": "anonym",
    "anonymster": "anonym",
    "anonymstes": "anonym",
    "anordne": "anordnen",
    "anordnend": "anordnen",
    "anordnende": "anordnend",
    "anordnendem": "anordnend",
    "anordnenden": "anordnend",
    "anordnender": "anordnend",
    "anordnendes": "anordnend",
    "anordnest": "anordnen",
    "anordnet": "anordnen",
    "anordnete": "anordnen",
    "anordneten": "anordnen",
    "anordnetest": "anordnen",
    "anordnetet": "anordnen",
    "anorganischem": "anorganisch",
    "anorganischen": "anorganisch",
    "anorganischer": "anorganisch",
    "anorganisches": "anorganisch",
    "anpacke": "anpacken",
    "anpackend": "anpacken",
    "anpackende": "anpackend",
    "anpackendem": "anpackend",
    "anpackenden": "anpackend",
    "anpackender": "anpackend",
    "anpackendes": "anpackend",
    "anpackest": "anpacken",
    "anpacket": "anpacken",
    "anpackst": "anpacken",
    "anpackt": "anpacken",
    "anpackte": "anpacken",
    "anpackten": "anpacken",
    "anpacktest": "anpacken",
    "anpacktet": "anpacken",
    "anpaddele": "anpaddeln",
    "anpaddelnd": "anpaddeln",
    "anpaddelnde": "anpaddelnd",
    "anpaddelndem": "anpaddelnd",
    "anpaddelnden": "anpaddelnd",
    "anpaddelnder": "anpaddelnd",
    "anpaddelndes": "anpaddelnd",
    "anpaddelst": "anpaddeln",
    "anpaddelt": "anpaddeln",
    "anpaddelte": "anpaddeln",
    "anpaddelten": "anpaddeln",
    "anpaddeltest": "anpaddeln",
    "anpaddeltet": "anpaddeln",
    "anpaddle": "anpaddeln",
    "anpasse": "anpassen",
    "anpassend": "anpassen",
    "anpassende": "anpassend",
    "anpassendem": "anpassend",
    "anpassenden": "anpassend",
    "anpassender": "anpassend",
    "anpassendere": "anpassend",
    "anpassenderem": "anpassend",
    "anpassenderen": "anpassend",
    "anpassenderer": "anpassend",
    "anpassenderes": "anpassend",
    "anpassendes": "anpassend",
    "anpassendste": "anpassend",
    "anpassendstem": "anpassend",
    "anpassendsten": "anpassend",
    "anpassendster": "anpassend",
    "anpassendstes": "anpassend",
    "anpassest": "anpassen",
    "anpasset": "anpassen",
    "anpassungsfähige": "anpassungsfähig",
    "anpassungsfähigem": "anpassungsfähig",
    "anpassungsfähigen": "anpassungsfähig",
    "anpassungsfähiger": "anpassungsfähig",
    "anpassungsfähigere": "anpassungsfähig",
    "anpassungsfähigerem": "anpassungsfähig",
    "anpassungsfähigeren": "anpassungsfähig",
    "anpassungsfähigerer": "anpassungsfähig",
    "anpassungsfähigeres": "anpassungsfähig",
    "anpassungsfähiges": "anpassungsfähig",
    "anpassungsfähigste": "anpassungsfähig",
    "anpassungsfähigstem": "anpassungsfähig",
    "anpassungsfähigsten": "anpassungsfähig",
    "anpassungsfähigster": "anpassungsfähig",
    "anpassungsfähigstes": "anpassungsfähig",
    "anpaßt": "anpassen",
    "anpaßte": "anpassen",
    "anpaßten": "anpassen",
    "anpaßtest": "anpassen",
    "anpaßtet": "anpassen",
    "anpeile": "anpeilen",
    "anpeilend": "anpeilen",
    "anpeilende": "anpeilend",
    "anpeilendem": "anpeilend",
    "anpeilenden": "anpeilend",
    "anpeilender": "anpeilend",
    "anpeilendes": "anpeilend",
    "anpeilest": "anpeilen",
    "anpeilet": "anpeilen",
    "anpeilst": "anpeilen",
    "anpeilt": "anpeilen",
    "anpeilte": "anpeilen",
    "anpeilten": "anpeilen",
    "anpeiltest": "anpeilen",
    "anpeiltet": "anpeilen",
    "anpfeife": "anpfeifen",
    "anpfeifend": "anpfeifen",
    "anpfeifende": "anpfeifend",
    "anpfeifendem": "anpfeifend",
    "anpfeifenden": "anpfeifend",
    "anpfeifender": "anpfeifend",
    "anpfeifendere": "anpfeifend",
    "anpfeifenderem": "anpfeifend",
    "anpfeifenderen": "anpfeifend",
    "anpfeifenderer": "anpfeifend",
    "anpfeifenderes": "anpfeifend",
    "anpfeifendes": "anpfeifend",
    "anpfeifendste": "anpfeifend",
    "anpfeifendstem": "anpfeifend",
    "anpfeifendsten": "anpfeifend",
    "anpfeifendster": "anpfeifend",
    "anpfeifendstes": "anpfeifend",
    "anpfeifest": "anpfeifen",
    "anpfeifet": "anpfeifen",
    "anpfeifst": "anpfeifen",
    "anpfeift": "anpfeifen",
    "anpfiff": "anpfeifen",
    "anpfiffe": "anpfeifen",
    "anpfiffen": "anpfeifen",
    "anpfiffest": "anpfeifen",
    "anpfiffet": "anpfeifen",
    "anpfiffst": "anpfeifen",
    "anpfifft": "anpfeifen",
    "anpflanze": "anpflanzen",
    "anpflanzend": "anpflanzen",
    "anpflanzende": "anpflanzend",
    "anpflanzendem": "anpflanzend",
    "anpflanzenden": "anpflanzend",
    "anpflanzender": "anpflanzend",
    "anpflanzendes": "anpflanzend",
    "anpflanzest": "anpflanzen",
    "anpflanzet": "anpflanzen",
    "anpflanzt": "anpflanzen",
    "anpflanzte": "anpflanzen",
    "anpflanzten": "anpflanzen",
    "anpflanztest": "anpflanzen",
    "anpflanztet": "anpflanzen",
    "anpflaume": "anpflaumen",
    "anpflaumend": "anpflaumen",
    "anpflaumende": "anpflaumend",
    "anpflaumendem": "anpflaumend",
    "anpflaumenden": "anpflaumend",
    "anpflaumender": "anpflaumend",
    "anpflaumendere": "anpflaumend",
    "anpflaumenderem": "anpflaumend",
    "anpflaumenderen": "anpflaumend",
    "anpflaumenderer": "anpflaumend",
    "anpflaumenderes": "anpflaumend",
    "anpflaumendes": "anpflaumend",
    "anpflaumendste": "anpflaumend",
    "anpflaumendstem": "anpflaumend",
    "anpflaumendsten": "anpflaumend",
    "anpflaumendster": "anpflaumend",
    "anpflaumendstes": "anpflaumend",
    "anpflaumest": "anpflaumen",
    "anpflaumet": "anpflaumen",
    "anpflaumst": "anpflaumen",
    "anpflaumt": "anpflaumen",
    "anpflaumte": "anpflaumen",
    "anpflaumten": "anpflaumen",
    "anpflaumtest": "anpflaumen",
    "anpflaumtet": "anpflaumen",
    "anpirsche": "anpirschen",
    "anpirschend": "anpirschen",
    "anpirschende": "anpirschend",
    "anpirschendem": "anpirschend",
    "anpirschenden": "anpirschend",
    "anpirschender": "anpirschend",
    "anpirschendes": "anpirschend",
    "anpirschest": "anpirschen",
    "anpirschet": "anpirschen",
    "anpirschst": "anpirschen",
    "anpirscht": "anpirschen",
    "anpirschte": "anpirschen",
    "anpirschten": "anpirschen",
    "anpirschtest": "anpirschen",
    "anpirschtet": "anpirschen",
    "anpralle": "anprallen",
    "anprallend": "anprallen",
    "anprallende": "anprallend",
    "anprallendem": "anprallend",
    "anprallenden": "anprallend",
    "anprallender": "anprallend",
    "anprallendes": "anprallend",
    "anprallest": "anprallen",
    "anprallet": "anprallen",
    "anprallst": "anprallen",
    "anprallt": "anprallen",
    "anprallte": "anprallen",
    "anprallten": "anprallen",
    "anpralltest": "anprallen",
    "anpralltet": "anprallen",
    "anprangere": "anprangern",
    "anprangernd": "anprangern",
    "anprangernde": "anprangernd",
    "anprangerndem": "anprangernd",
    "anprangernden": "anprangernd",
    "anprangernder": "anprangernd",
    "anprangerndere": "anprangernd",
    "anprangernderem": "anprangernd",
    "anprangernderen": "anprangernd",
    "anprangernderer": "anprangernd",
    "anprangernderes": "anprangernd",
    "anprangerndes": "anprangernd",
    "anprangerndste": "anprangernd",
    "anprangerndstem": "anprangernd",
    "anprangerndsten": "anprangernd",
    "anprangerndster": "anprangernd",
    "anprangerndstes": "anprangernd",
    "anprangerst": "anprangern",
    "anprangert": "anprangern",
    "anprangerte": "anprangern",
    "anprangerten": "anprangern",
    "anprangertest": "anprangern",
    "anprangertet": "anprangern",
    "anpreise": "anpreisen",
    "anpreisend": "anpreisen",
    "anpreisende": "anpreisend",
    "anpreisendem": "anpreisend",
    "anpreisenden": "anpreisend",
    "anpreisender": "anpreisend",
    "anpreisendes": "anpreisend",
    "anpreisest": "anpreisen",
    "anpreiset": "anpreisen",
    "anpreist": "anpreisen",
    "anpresse": "anpressen",
    "anpressend": "anpressen",
    "anpressende": "anpressend",
    "anpressendem": "anpressend",
    "anpressenden": "anpressend",
    "anpressender": "anpressend",
    "anpressendes": "anpressend",
    "anpressest": "anpressen",
    "anpresset": "anpressen",
    "anpreßt": "anpressen",
    "anpreßte": "anpressen",
    "anpreßten": "anpressen",
    "anpreßtest": "anpressen",
    "anpreßtet": "anpressen",
    "anpries": "anpreisen",
    "anpriese": "anpreisen",
    "anpriesen": "anpreisen",
    "anpriesest": "anpreisen",
    "anprieset": "anpreisen",
    "anpriest": "anpreisen",
    "anprobiere": "anprobieren",
    "anprobierend": "anprobieren",
    "anprobierende": "anprobierend",
    "anprobierendem": "anprobierend",
    "anprobierenden": "anprobierend",
    "anprobierender": "anprobierend",
    "anprobierendes": "anprobierend",
    "anprobierest": "anprobieren",
    "anprobieret": "anprobieren",
    "anprobierst": "anprobieren",
    "anprobiert": "anprobieren",
    "anprobierte": "anprobieren",
    "anprobiertem": "anprobiert",
    "anprobierten": "anprobieren",
    "anprobierter": "anprobiert",
    "anprobiertes": "anprobiert",
    "anprobiertest": "anprobieren",
    "anprobiertet": "anprobieren",
    "anpumpe": "anpumpen",
    "anpumpend": "anpumpen",
    "anpumpende": "anpumpend",
    "anpumpendem": "anpumpend",
    "anpumpenden": "anpumpend",
    "anpumpender": "anpumpend",
    "anpumpendes": "anpumpend",
    "anpumpest": "anpumpen",
    "anpumpet": "anpumpen",
    "anpumpst": "anpumpen",
    "anpumpt": "anpumpen",
    "anpumpte": "anpumpen",
    "anpumpten": "anpumpen",
    "anpumptest": "anpumpen",
    "anpumptet": "anpumpen",
    "anputze": "anputzen",
    "anputzend": "anputzen",
    "anputzende": "anputzend",
    "anputzendem": "anputzend",
    "anputzenden": "anputzend",
    "anputzender": "anputzend",
    "anputzendes": "anputzend",
    "anputzest": "anputzen",
    "anputzet": "anputzen",
    "anputzt": "anputzen",
    "anputzte": "anputzen",
    "anputzten": "anputzen",
    "anputztest": "anputzen",
    "anputztet": "anputzen",
    "anpöbele": "anpöbeln",
    "anpöbelnd": "anpöbeln",
    "anpöbelnde": "anpöbelnd",
    "anpöbelndem": "anpöbelnd",
    "anpöbelnden": "anpöbelnd",
    "anpöbelnder": "anpöbelnd",
    "anpöbelndere": "anpöbelnd",
    "anpöbelnderem": "anpöbelnd",
    "anpöbelnderen": "anpöbelnd",
    "anpöbelnderer": "anpöbelnd",
    "anpöbelnderes": "anpöbelnd",
    "anpöbelndes": "anpöbelnd",
    "anpöbelndste": "anpöbelnd",
    "anpöbelndstem": "anpöbelnd",
    "anpöbelndsten": "anpöbelnd",
    "anpöbelndster": "anpöbelnd",
    "anpöbelndstes": "anpöbelnd",
    "anpöbelst": "anpöbeln",
    "anpöbelt": "anpöbeln",
    "anpöbelte": "anpöbeln",
    "anpöbelten": "anpöbeln",
    "anpöbeltest": "anpöbeln",
    "anpöbeltet": "anpöbeln",
    "anpöble": "anpöbeln",
    "anquäle": "anquälen",
    "anquälend": "anquälen",
    "anquälende": "anquälend",
    "anquälendem": "anquälend",
    "anquälenden": "anquälend",
    "anquälender": "anquälend",
    "anquälendes": "anquälend",
    "anquälest": "anquälen",
    "anquälet": "anquälen",
    "anquälst": "anquälen",
    "anquält": "anquälen",
    "anquälte": "anquälen",
    "anquälten": "anquälen",
    "anquältest": "anquälen",
    "anquältet": "anquälen",
    "anrannte": "anrennen",
    "anrannten": "anrennen",
    "anranntest": "anrennen",
    "anranntet": "anrennen",
    "anranze": "anranzen",
    "anranzend": "anranzen",
    "anranzende": "anranzend",
    "anranzendem": "anranzend",
    "anranzenden": "anranzend",
    "anranzender": "anranzend",
    "anranzendere": "anranzend",
    "anranzenderem": "anranzend",
    "anranzenderen": "anranzend",
    "anranzenderer": "anranzend",
    "anranzenderes": "anranzend",
    "anranzendes": "anranzend",
    "anranzendste": "anranzend",
    "anranzendstem": "anranzend",
    "anranzendsten": "anranzend",
    "anranzendster": "anranzend",
    "anranzendstes": "anranzend",
    "anranzest": "anranzen",
    "anranzet": "anranzen",
    "anranzt": "anranzen",
    "anranzte": "anranzen",
    "anranzten": "anranzen",
    "anranztest": "anranzen",
    "anranztet": "anranzen",
    "anrate": "anraten",
    "anratend": "anraten",
    "anratende": "anratend",
    "anratendem": "anratend",
    "anratenden": "anratend",
    "anratender": "anratend",
    "anratendes": "anratend",
    "anratest": "anraten",
    "anratet": "anraten",
    "anrauhe": "anrauhen",
    "anrauhend": "anrauhen",
    "anrauhende": "anrauhend",
    "anrauhendem": "anrauhend",
    "anrauhenden": "anrauhend",
    "anrauhender": "anrauhend",
    "anrauhendere": "anrauhend",
    "anrauhenderem": "anrauhend",
    "anrauhenderen": "anrauhend",
    "anrauhenderer": "anrauhend",
    "anrauhenderes": "anrauhend",
    "anrauhendes": "anrauhend",
    "anrauhendste": "anrauhend",
    "anrauhendstem": "anrauhend",
    "anrauhendsten": "anrauhend",
    "anrauhendster": "anrauhend",
    "anrauhendstes": "anrauhend",
    "anrauhest": "anrauhen",
    "anrauhet": "anrauhen",
    "anrauhst": "anrauhen",
    "anrauht": "anrauhen",
    "anrauhte": "anrauhen",
    "anrauhten": "anrauhen",
    "anrauhtest": "anrauhen",
    "anrauhtet": "anrauhen",
    "anrechne": "anrechnen",
    "anrechnend": "anrechnen",
    "anrechnende": "anrechnend",
    "anrechnendem": "anrechnend",
    "anrechnenden": "anrechnend",
    "anrechnender": "anrechnend",
    "anrechnendes": "anrechnend",
    "anrechnest": "anrechnen",
    "anrechnet": "anrechnen",
    "anrechnete": "anrechnen",
    "anrechneten": "anrechnen",
    "anrechnetest": "anrechnen",
    "anrechnetet": "anrechnen",
    "anredend": "anreden",
    "anredende": "anredend",
    "anredendem": "anredend",
    "anredenden": "anredend",
    "anredender": "anredend",
    "anredendes": "anredend",
    "anredest": "anreden",
    "anredet": "anreden",
    "anredete": "anreden",
    "anredeten": "anreden",
    "anredetest": "anreden",
    "anredetet": "anreden",
    "anrege": "anregen",
    "anregend": "anregen",
    "anregende": "anregend",
    "anregendem": "anregend",
    "anregenden": "anregend",
    "anregender": "anregend",
    "anregendere": "anregend",
    "anregenderem": "anregend",
    "anregenderen": "anregend",
    "anregenderer": "anregend",
    "anregenderes": "anregend",
    "anregendes": "anregend",
    "anregendste": "anregend",
    "anregendstem": "anregend",
    "anregendsten": "anregend",
    "anregendster": "anregend",
    "anregendstes": "anregend",
    "anregest": "anregen",
    "anreget": "anregen",
    "anregst": "anregen",
    "anregt": "anregen",
    "anregte": "anregen",
    "anregten": "anregen",
    "anregtest": "anregen",
    "anregtet": "anregen",
    "anreibe": "anreiben",
    "anreibend": "anreiben",
    "anreibende": "anreibend",
    "anreibendem": "anreibend",
    "anreibenden": "anreibend",
    "anreibender": "anreibend",
    "anreibendes": "anreibend",
    "anreibest": "anreiben",
    "anreibet": "anreiben",
    "anreibst": "anreiben",
    "anreibt": "anreiben",
    "anreiche": "anreichen",
    "anreichend": "anreichen",
    "anreichende": "anreichend",
    "anreichendem": "anreichend",
    "anreichenden": "anreichend",
    "anreichender": "anreichend",
    "anreichendes": "anreichend",
    "anreichere": "anreichern",
    "anreichernd": "anreichern",
    "anreichernde": "anreichernd",
    "anreicherndem": "anreichernd",
    "anreichernden": "anreichernd",
    "anreichernder": "anreichernd",
    "anreicherndes": "anreichernd",
    "anreicherst": "anreichern",
    "anreichert": "anreichern",
    "anreicherte": "anreichern",
    "anreicherten": "anreichern",
    "anreichertest": "anreichern",
    "anreichertet": "anreichern",
    "anreichest": "anreichen",
    "anreichet": "anreichen",
    "anreichst": "anreichen",
    "anreicht": "anreichen",
    "anreichte": "anreichen",
    "anreichten": "anreichen",
    "anreichtest": "anreichen",
    "anreichtet": "anreichen",
    "anreihe": "anreihen",
    "anreihend": "anreihen",
    "anreihende": "anreihend",
    "anreihendem": "anreihend",
    "anreihenden": "anreihend",
    "anreihender": "anreihend",
    "anreihendes": "anreihend",
    "anreihest": "anreihen",
    "anreihet": "anreihen",
    "anreihst": "anreihen",
    "anreiht": "anreihen",
    "anreihte": "anreihen",
    "anreihten": "anreihen",
    "anreihtest": "anreihen",
    "anreihtet": "anreihen",
    "anreise": "anreisen",
    "anreisend": "anreisen",
    "anreisende": "anreisend",
    "anreisendem": "anreisend",
    "anreisenden": "anreisend",
    "anreisender": "anreisend",
    "anreisendes": "anreisend",
    "anreisest": "anreisen",
    "anreiset": "anreisen",
    "anreist": "anreisen",
    "anreiste": "anreisen",
    "anreisten": "anreisen",
    "anreistest": "anreisen",
    "anreistet": "anreisen",
    "anreite": "anreiten",
    "anreitend": "anreiten",
    "anreitende": "anreitend",
    "anreitendem": "anreitend",
    "anreitenden": "anreitend",
    "anreitender": "anreitend",
    "anreitendes": "anreitend",
    "anreitest": "anreiten",
    "anreitet": "anreiten",
    "anreizend": "anreizen",
    "anreizende": "anreizend",
    "anreizendem": "anreizend",
    "anreizenden": "anreizend",
    "anreizender": "anreizend",
    "anreizendere": "anreizend",
    "anreizenderem": "anreizend",
    "anreizenderen": "anreizend",
    "anreizenderer": "anreizend",
    "anreizenderes": "anreizend",
    "anreizendes": "anreizend",
    "anreizendste": "anreizend",
    "anreizendstem": "anreizend",
    "anreizendsten": "anreizend",
    "anreizendster": "anreizend",
    "anreizendstes": "anreizend",
    "anreizest": "anreizen",
    "anreizet": "anreizen",
    "anreizt": "anreizen",
    "anreizte": "anreizen",
    "anreizten": "anreizen",
    "anreiztest": "anreizen",
    "anreiztet": "anreizen",
    "anreiße": "anreißen",
    "anreißend": "anreißen",
    "anreißende": "anreißend",
    "anreißendem": "anreißend",
    "anreißenden": "anreißend",
    "anreißender": "anreißend",
    "anreißendes": "anreißend",
    "anreißest": "anreißen",
    "anreißet": "anreißen",
    "anreißt": "anreißen",
    "anrempele": "anrempeln",
    "anrempelnd": "anrempeln",
    "anrempelnde": "anrempelnd",
    "anrempelndem": "anrempelnd",
    "anrempelnden": "anrempelnd",
    "anrempelnder": "anrempelnd",
    "anrempelndes": "anrempelnd",
    "anrempelst": "anrempeln",
    "anrempelt": "anrempeln",
    "anrempelte": "anrempeln",
    "anrempelten": "anrempeln",
    "anrempeltest": "anrempeln",
    "anrempeltet": "anrempeln",
    "anremple": "anrempeln",
    "anrenne": "anrennen",
    "anrennend": "anrennen",
    "anrennende": "anrennend",
    "anrennendem": "anrennend",
    "anrennenden": "anrennend",
    "anrennender": "anrennend",
    "anrennendes": "anrennend",
    "anrennest": "anrennen",
    "anrennet": "anrennen",
    "anrennst": "anrennen",
    "anrennt": "anrennen",
    "anrichte": "anrichten",
    "anrichtend": "anrichten",
    "anrichtende": "anrichtend",
    "anrichtendem": "anrichtend",
    "anrichtenden": "anrichtend",
    "anrichtender": "anrichtend",
    "anrichtendes": "anrichtend",
    "anrichtest": "anrichten",
    "anrichtet": "anrichten",
    "anrichtete": "anrichten",
    "anrichteten": "anrichten",
    "anrichtetest": "anrichten",
    "anrichtetet": "anrichten",
    "anrieb": "anreiben",
    "anriebe": "anreiben",
    "anrieben": "anreiben",
    "anriebest": "anreiben",
    "anriebet": "anreiben",
    "anriebst": "anreiben",
    "anriebt": "anreiben",
    "anrief": "anrufen",
    "anriefe": "anrufen",
    "anriefen": "anrufen",
    "anriefest": "anrufen",
    "anriefet": "anrufen",
    "anriefst": "anrufen",
    "anrieft": "anrufen",
    "anriet": "anraten",
    "anriete": "anraten",
    "anrieten": "anraten",
    "anrietest": "anraten",
    "anrietet": "anraten",
    "anrisse": "anreißen",
    "anrissen": "anreißen",
    "anrissest": "anreißen",
    "anrisset": "anreißen",
    "anritt": "anreiten",
    "anritte": "anreiten",
    "anritten": "anreiten",
    "anrittest": "anreiten",
    "anrittet": "anreiten",
    "anriß": "anreißen",
    "anrißt": "anreißen",
    "anrolle": "anrollen",
    "anrollend": "anrollen",
    "anrollende": "anrollend",
    "anrollendem": "anrollend",
    "anrollenden": "anrollend",
    "anrollender": "anrollend",
    "anrollendes": "anrollend",
    "anrollest": "anrollen",
    "anrollet": "anrollen",
    "anrollst": "anrollen",
    "anrollt": "anrollen",
    "anrollte": "anrollen",
    "anrollten": "anrollen",
    "anrolltest": "anrollen",
    "anrolltet": "anrollen",
    "anrudere": "anrudern",
    "anrudernd": "anrudern",
    "anrudernde": "anrudernd",
    "anruderndem": "anrudernd",
    "anrudernden": "anrudernd",
    "anrudernder": "anrudernd",
    "anruderndes": "anrudernd",
    "anruderst": "anrudern",
    "anrudert": "anrudern",
    "anruderte": "anrudern",
    "anruderten": "anrudern",
    "anrudertest": "anrudern",
    "anrudertet": "anrudern",
    "anrufend": "anrufen",
    "anrufende": "anrufend",
    "anrufendem": "anrufend",
    "anrufenden": "anrufend",
    "anrufender": "anrufend",
    "anrufendes": "anrufend",
    "anrufest": "anrufen",
    "anrufet": "anrufen",
    "anrufst": "anrufen",
    "anruft": "anrufen",
    "anrät": "anraten",
    "anrätst": "anraten",
    "anrüchige": "anrüchig",
    "anrüchigem": "anrüchig",
    "anrüchigen": "anrüchig",
    "anrüchiger": "anrüchig",
    "anrüchigere": "anrüchig",
    "anrüchigerem": "anrüchig",
    "anrüchigeren": "anrüchig",
    "anrüchigerer": "anrüchig",
    "anrüchigeres": "anrüchig",
    "anrüchiges": "anrüchig",
    "anrüchigste": "anrüchig",
    "anrüchigstem": "anrüchig",
    "anrüchigsten": "anrüchig",
    "anrüchigster": "anrüchig",
    "anrüchigstes": "anrüchig",
    "anrücke": "anrücken",
    "anrückend": "anrücken",
    "anrückende": "anrückend",
    "anrückendem": "anrückend",
    "anrückenden": "anrückend",
    "anrückender": "anrückend",
    "anrückendes": "anrückend",
    "anrückest": "anrücken",
    "anrücket": "anrücken",
    "anrückst": "anrücken",
    "anrückt": "anrücken",
    "anrückte": "anrücken",
    "anrückten": "anrücken",
    "anrücktest": "anrücken",
    "anrücktet": "anrücken",
    "anrühre": "anrühren",
    "anrührend": "anrühren",
    "anrührende": "anrührend",
    "anrührendem": "anrührend",
    "anrührenden": "anrührend",
    "anrührender": "anrührend",
    "anrührendes": "anrührend",
    "anrührest": "anrühren",
    "anrühret": "anrühren",
    "anrührst": "anrühren",
    "anrührt": "anrühren",
    "anrührte": "anrühren",
    "anrührten": "anrühren",
    "anrührtest": "anrühren",
    "anrührtet": "anrühren",
    "ansage": "ansagen",
    "ansagend": "ansagen",
    "ansagende": "ansagend",
    "ansagendem": "ansagend",
    "ansagenden": "ansagend",
    "ansagender": "ansagend",
    "ansagendes": "ansagend",
    "ansagest": "ansagen",
    "ansaget": "ansagen",
    "ansagst": "ansagen",
    "ansagt": "ansagen",
    "ansagte": "ansagen",
    "ansagten": "ansagen",
    "ansagtest": "ansagen",
    "ansagtet": "ansagen",
    "ansah": "ansehen",
    "ansahen": "ansehen",
    "ansahst": "ansehen",
    "ansaht": "ansehen",
    "ansame": "ansamen",
    "ansamend": "ansamen",
    "ansamende": "ansamend",
    "ansamendem": "ansamend",
    "ansamenden": "ansamend",
    "ansamender": "ansamend",
    "ansamendes": "ansamend",
    "ansamest": "ansamen",
    "ansamet": "ansamen",
    "ansammele": "ansammeln",
    "ansammelnd": "ansammeln",
    "ansammelnde": "ansammelnd",
    "ansammelndem": "ansammelnd",
    "ansammelnden": "ansammelnd",
    "ansammelnder": "ansammelnd",
    "ansammelndes": "ansammelnd",
    "ansammelst": "ansammeln",
    "ansammelt": "ansammeln",
    "ansammelte": "ansammeln",
    "ansammelten": "ansammeln",
    "ansammeltest": "ansammeln",
    "ansammeltet": "ansammeln",
    "ansammle": "ansammeln",
    "ansamst": "ansamen",
    "ansamt": "ansamen",
    "ansamte": "ansamen",
    "ansamten": "ansamen",
    "ansamtest": "ansamen",
    "ansamtet": "ansamen",
    "ansang": "ansingen",
    "ansangen": "ansingen",
    "ansangst": "ansingen",
    "ansangt": "ansingen",
    "ansaufe": "ansaufen",
    "ansaufend": "ansaufen",
    "ansaufende": "ansaufend",
    "ansaufendem": "ansaufend",
    "ansaufenden": "ansaufend",
    "ansaufender": "ansaufend",
    "ansaufendere": "ansaufend",
    "ansaufenderem": "ansaufend",
    "ansaufenderen": "ansaufend",
    "ansaufenderer": "ansaufend",
    "ansaufenderes": "ansaufend",
    "ansaufendes": "ansaufend",
    "ansaufendste": "ansaufend",
    "ansaufendstem": "ansaufend",
    "ansaufendsten": "ansaufend",
    "ansaufendster": "ansaufend",
    "ansaufendstes": "ansaufend",
    "ansaufest": "ansaufen",
    "ansaufet": "ansaufen",
    "ansauft": "ansaufen",
    "ansauge": "ansaugen",
    "ansaugend": "ansaugen",
    "ansaugende": "ansaugend",
    "ansaugendem": "ansaugend",
    "ansaugenden": "ansaugend",
    "ansaugender": "ansaugend",
    "ansaugendes": "ansaugend",
    "ansaugest": "ansaugen",
    "ansauget": "ansaugen",
    "ansaugst": "ansaugen",
    "ansaugt": "ansaugen",
    "ansaugte": "ansaugen",
    "ansaugten": "ansaugen",
    "ansaugtest": "ansaugen",
    "ansaugtet": "ansaugen",
    "ansaß": "ansitzen",
    "ansaßen": "ansitzen",
    "ansaßt": "ansitzen",
    "anschaffe": "anschaffen",
    "anschaffend": "anschaffen",
    "anschaffende": "anschaffend",
    "anschaffendem": "anschaffend",
    "anschaffenden": "anschaffend",
    "anschaffender": "anschaffend",
    "anschaffendes": "anschaffend",
    "anschaffest": "anschaffen",
    "anschaffet": "anschaffen",
    "anschaffst": "anschaffen",
    "anschafft": "anschaffen",
    "anschaffte": "anschaffen",
    "anschafften": "anschaffen",
    "anschafftest": "anschaffen",
    "anschafftet": "anschaffen",
    "anschalte": "anschalten",
    "anschaltend": "anschalten",
    "anschaltende": "anschaltend",
    "anschaltendem": "anschaltend",
    "anschaltenden": "anschaltend",
    "anschaltender": "anschaltend",
    "anschaltendes": "anschaltend",
    "anschaltest": "anschalten",
    "anschaltet": "anschalten",
    "anschaltete": "anschalten",
    "anschalteten": "anschalten",
    "anschaltetest": "anschalten",
    "anschaltetet": "anschalten",
    "anschaue": "anschauen",
    "anschauend": "anschauen",
    "anschauende": "anschauend",
    "anschauendem": "anschauend",
    "anschauenden": "anschauend",
    "anschauender": "anschauend",
    "anschauendes": "anschauend",
    "anschauest": "anschauen",
    "anschauet": "anschauen",
    "anschauliche": "anschaulich",
    "anschaulichem": "anschaulich",
    "anschaulichen": "anschaulich",
    "anschaulicher": "anschaulich",
    "anschaulichere": "anschaulich",
    "anschaulicherem": "anschaulich",
    "anschaulicheren": "anschaulich",
    "anschaulicherer": "anschaulich",
    "anschaulicheres": "anschaulich",
    "anschauliches": "anschaulich",
    "anschaulichste": "anschaulich",
    "anschaulichstem": "anschaulich",
    "anschaulichsten": "anschaulich",
    "anschaulichster": "anschaulich",
    "anschaulichstes": "anschaulich",
    "anschaust": "anschauen",
    "anschaut": "anschauen",
    "anschaute": "anschauen",
    "anschauten": "anschauen",
    "anschautest": "anschauen",
    "anschautet": "anschauen",
    "anscheine": "anscheinen",
    "anscheinend": "anscheinen",
    "anscheinende": "anscheinend",
    "anscheinendem": "anscheinend",
    "anscheinenden": "anscheinend",
    "anscheinender": "anscheinend",
    "anscheinendes": "anscheinend",
    "anscheinest": "anscheinen",
    "anscheinet": "anscheinen",
    "anscheinst": "anscheinen",
    "anscheint": "anscheinen",
    "anscheiße": "anscheißen",
    "anscheißend": "anscheißen",
    "anscheißende": "anscheißend",
    "anscheißendem": "anscheißend",
    "anscheißenden": "anscheißend",
    "anscheißender": "anscheißend",
    "anscheißendere": "anscheißend",
    "anscheißenderem": "anscheißend",
    "anscheißenderen": "anscheißend",
    "anscheißenderer": "anscheißend",
    "anscheißenderes": "anscheißend",
    "anscheißendes": "anscheißend",
    "anscheißendste": "anscheißend",
    "anscheißendstem": "anscheißend",
    "anscheißendsten": "anscheißend",
    "anscheißendster": "anscheißend",
    "anscheißendstes": "anscheißend",
    "anscheißest": "anscheißen",
    "anscheißet": "anscheißen",
    "anscheißt": "anscheißen",
    "anschiebe": "anschieben",
    "anschiebend": "anschieben",
    "anschiebende": "anschiebend",
    "anschiebendem": "anschiebend",
    "anschiebenden": "anschiebend",
    "anschiebender": "anschiebend",
    "anschiebendes": "anschiebend",
    "anschiebest": "anschieben",
    "anschiebet": "anschieben",
    "anschiebst": "anschieben",
    "anschiebt": "anschieben",
    "anschien": "anscheinen",
    "anschiene": "anscheinen",
    "anschienen": "anscheinen",
    "anschienest": "anscheinen",
    "anschienet": "anscheinen",
    "anschienst": "anscheinen",
    "anschient": "anscheinen",
    "anschieße": "anschießen",
    "anschießend": "anschießen",
    "anschießende": "anschießend",
    "anschießendem": "anschießend",
    "anschießenden": "anschießend",
    "anschießender": "anschießend",
    "anschießendes": "anschießend",
    "anschießest": "anschießen",
    "anschießet": "anschießen",
    "anschießt": "anschießen",
    "anschiffe": "anschiffen",
    "anschiffend": "anschiffen",
    "anschiffende": "anschiffend",
    "anschiffendem": "anschiffend",
    "anschiffenden": "anschiffend",
    "anschiffender": "anschiffend",
    "anschiffendes": "anschiffend",
    "anschiffest": "anschiffen",
    "anschiffet": "anschiffen",
    "anschiffst": "anschiffen",
    "anschifft": "anschiffen",
    "anschiffte": "anschiffen",
    "anschifften": "anschiffen",
    "anschifftest": "anschiffen",
    "anschifftet": "anschiffen",
    "anschirre": "anschirren",
    "anschirrend": "anschirren",
    "anschirrende": "anschirrend",
    "anschirrendem": "anschirrend",
    "anschirrenden": "anschirrend",
    "anschirrender": "anschirrend",
    "anschirrendes": "anschirrend",
    "anschirrest": "anschirren",
    "anschirret": "anschirren",
    "anschirrst": "anschirren",
    "anschirrt": "anschirren",
    "anschirrte": "anschirren",
    "anschirrten": "anschirren",
    "anschirrtest": "anschirren",
    "anschirrtet": "anschirren",
    "anschisse": "anscheißen",
    "anschissen": "anscheißen",
    "anschissest": "anscheißen",
    "anschisset": "anscheißen",
    "anschiß": "anscheißen",
    "anschißt": "anscheißen",
    "anschlagend": "anschlagen",
    "anschlagende": "anschlagend",
    "anschlagendem": "anschlagend",
    "anschlagenden": "anschlagend",
    "anschlagender": "anschlagend",
    "anschlagendes": "anschlagend",
    "anschlagest": "anschlagen",
    "anschlaget": "anschlagen",
    "anschlagt": "anschlagen",
    "anschleiche": "anschleichen",
    "anschleichend": "anschleichen",
    "anschleichende": "anschleichend",
    "anschleichendem": "anschleichend",
    "anschleichenden": "anschleichend",
    "anschleichender": "anschleichend",
    "anschleichendes": "anschleichend",
    "anschleichest": "anschleichen",
    "anschleichet": "anschleichen",
    "anschleichst": "anschleichen",
    "anschleicht": "anschleichen",
    "anschleife": "anschleifen",
    "anschleifend": "anschleifen",
    "anschleifende": "anschleifend",
    "anschleifendem": "anschleifend",
    "anschleifenden": "anschleifend",
    "anschleifender": "anschleifend",
    "anschleifendes": "anschleifend",
    "anschleifest": "anschleifen",
    "anschleifet": "anschleifen",
    "anschleifst": "anschleifen",
    "anschleift": "anschleifen",
    "anschleifte": "anschleifen",
    "anschleiften": "anschleifen",
    "anschleiftest": "anschleifen",
    "anschleiftet": "anschleifen",
    "anschlich": "anschleichen",
    "anschliche": "anschleichen",
    "anschlichen": "anschleichen",
    "anschlichest": "anschleichen",
    "anschlichet": "anschleichen",
    "anschlichst": "anschleichen",
    "anschlicht": "anschleichen",
    "anschließe": "anschließen",
    "anschließend": "anschließen",
    "anschließende": "anschließend",
    "anschließendem": "anschließend",
    "anschließenden": "anschließend",
    "anschließender": "anschließend",
    "anschließendes": "anschließend",
    "anschließest": "anschließen",
    "anschließet": "anschließen",
    "anschließt": "anschließen",
    "anschliff": "anschleifen",
    "anschliffe": "anschleifen",
    "anschliffen": "anschleifen",
    "anschliffest": "anschleifen",
    "anschliffet": "anschleifen",
    "anschliffst": "anschleifen",
    "anschlifft": "anschleifen",
    "anschlossen": "anschließen",
    "anschloß": "anschließen",
    "anschloßt": "anschließen",
    "anschlug": "anschlagen",
    "anschlugen": "anschlagen",
    "anschlugst": "anschlagen",
    "anschlugt": "anschlagen",
    "anschlägst": "anschlagen",
    "anschlägt": "anschlagen",
    "anschlämme": "anschlämmen",
    "anschlämmend": "anschlämmen",
    "anschlämmende": "anschlämmend",
    "anschlämmendem": "anschlämmend",
    "anschlämmenden": "anschlämmend",
    "anschlämmender": "anschlämmend",
    "anschlämmendes": "anschlämmend",
    "anschlämmest": "anschlämmen",
    "anschlämmet": "anschlämmen",
    "anschlämmst": "anschlämmen",
    "anschlämmt": "anschlämmen",
    "anschlämmte": "anschlämmen",
    "anschlämmten": "anschlämmen",
    "anschlämmtest": "anschlämmen",
    "anschlämmtet": "anschlämmen",
    "anschlösse": "anschließen",
    "anschlössen": "anschließen",
    "anschlössest": "anschließen",
    "anschlösset": "anschließen",
    "anschlüge": "anschlagen",
    "anschlügen": "anschlagen",
    "anschlügest": "anschlagen",
    "anschlüget": "anschlagen",
    "anschmeiße": "anschmeißen",
    "anschmeißend": "anschmeißen",
    "anschmeißende": "anschmeißend",
    "anschmeißendem": "anschmeißend",
    "anschmeißenden": "anschmeißend",
    "anschmeißender": "anschmeißend",
    "anschmeißendes": "anschmeißend",
    "anschmeißest": "anschmeißen",
    "anschmeißet": "anschmeißen",
    "anschmeißt": "anschmeißen",
    "anschmiege": "anschmiegen",
    "anschmiegend": "anschmiegen",
    "anschmiegende": "anschmiegend",
    "anschmiegendem": "anschmiegend",
    "anschmiegenden": "anschmiegend",
    "anschmiegender": "anschmiegend",
    "anschmiegendere": "anschmiegend",
    "anschmiegenderem": "anschmiegend",
    "anschmiegenderen": "anschmiegend",
    "anschmiegenderer": "anschmiegend",
    "anschmiegenderes": "anschmiegend",
    "anschmiegendes": "anschmiegend",
    "anschmiegendste": "anschmiegend",
    "anschmiegendstem": "anschmiegend",
    "anschmiegendsten": "anschmiegend",
    "anschmiegendster": "anschmiegend",
    "anschmiegendstes": "anschmiegend",
    "anschmiegest": "anschmiegen",
    "anschmieget": "anschmiegen",
    "anschmiegsame": "anschmiegsam",
    "anschmiegsamem": "anschmiegsam",
    "anschmiegsamen": "anschmiegsam",
    "anschmiegsamer": "anschmiegsam",
    "anschmiegsamere": "anschmiegsam",
    "anschmiegsamerem": "anschmiegsam",
    "anschmiegsameren": "anschmiegsam",
    "anschmiegsamerer": "anschmiegsam",
    "anschmiegsameres": "anschmiegsam",
    "anschmiegsames": "anschmiegsam",
    "anschmiegsamste": "anschmiegsam",
    "anschmiegsamstem": "anschmiegsam",
    "anschmiegsamsten": "anschmiegsam",
    "anschmiegsamster": "anschmiegsam",
    "anschmiegsamstes": "anschmiegsam",
    "anschmiegst": "anschmiegen",
    "anschmiegt": "anschmiegen",
    "anschmiegte": "anschmiegen",
    "anschmiegten": "anschmiegen",
    "anschmiegtest": "anschmiegen",
    "anschmiegtet": "anschmiegen",
    "anschmiere": "anschmieren",
    "anschmierend": "anschmieren",
    "anschmierende": "anschmierend",
    "anschmierendem": "anschmierend",
    "anschmierenden": "anschmierend",
    "anschmierender": "anschmierend",
    "anschmierendes": "anschmierend",
    "anschmierest": "anschmieren",
    "anschmieret": "anschmieren",
    "anschmierst": "anschmieren",
    "anschmiert": "anschmieren",
    "anschmierte": "anschmieren",
    "anschmierten": "anschmieren",
    "anschmiertest": "anschmieren",
    "anschmiertet": "anschmieren",
    "anschmisse": "anschmeißen",
    "anschmissen": "anschmeißen",
    "anschmissest": "anschmeißen",
    "anschmisset": "anschmeißen",
    "anschmiß": "anschmeißen",
    "anschmißt": "anschmeißen",
    "anschnalle": "anschnallen",
    "anschnallend": "anschnallen",
    "anschnallende": "anschnallend",
    "anschnallendem": "anschnallend",
    "anschnallenden": "anschnallend",
    "anschnallender": "anschnallend",
    "anschnallendes": "anschnallend",
    "anschnallest": "anschnallen",
    "anschnallet": "anschnallen",
    "anschnallst": "anschnallen",
    "anschnallt": "anschnallen",
    "anschnallte": "anschnallen",
    "anschnallten": "anschnallen",
    "anschnalltest": "anschnallen",
    "anschnalltet": "anschnallen",
    "anschnauze": "anschnauzen",
    "anschnauzend": "anschnauzen",
    "anschnauzende": "anschnauzend",
    "anschnauzendem": "anschnauzend",
    "anschnauzenden": "anschnauzend",
    "anschnauzender": "anschnauzend",
    "anschnauzendes": "anschnauzend",
    "anschnauzest": "anschnauzen",
    "anschnauzet": "anschnauzen",
    "anschnauzt": "anschnauzen",
    "anschnauzte": "anschnauzen",
    "anschnauzten": "anschnauzen",
    "anschnauztest": "anschnauzen",
    "anschnauztet": "anschnauzen",
    "anschneide": "anschneiden",
    "anschneidend": "anschneiden",
    "anschneidende": "anschneidend",
    "anschneidendem": "anschneidend",
    "anschneidenden": "anschneidend",
    "anschneidender": "anschneidend",
    "anschneidendes": "anschneidend",
    "anschneidest": "anschneiden",
    "anschneidet": "anschneiden",
    "anschnitt": "anschneiden",
    "anschnittest": "anschneiden",
    "anschnittet": "anschneiden",
    "anschob": "anschieben",
    "anschoben": "anschieben",
    "anschobst": "anschieben",
    "anschobt": "anschieben",
    "anschossen": "anschießen",
    "anschoß": "anschießen",
    "anschoßt": "anschießen",
    "anschraube": "anschrauben",
    "anschraubend": "anschrauben",
    "anschraubende": "anschraubend",
    "anschraubendem": "anschraubend",
    "anschraubenden": "anschraubend",
    "anschraubender": "anschraubend",
    "anschraubendes": "anschraubend",
    "anschraubest": "anschrauben",
    "anschraubet": "anschrauben",
    "anschraubst": "anschrauben",
    "anschraubt": "anschrauben",
    "anschraubte": "anschrauben",
    "anschraubten": "anschrauben",
    "anschraubtest": "anschrauben",
    "anschraubtet": "anschrauben",
    "anschreibe": "anschreiben",
    "anschreibend": "anschreiben",
    "anschreibende": "anschreibend",
    "anschreibendem": "anschreibend",
    "anschreibenden": "anschreibend",
    "anschreibender": "anschreibend",
    "anschreibendes": "anschreibend",
    "anschreibest": "anschreiben",
    "anschreibet": "anschreiben",
    "anschreibst": "anschreiben",
    "anschreibt": "anschreiben",
    "anschreie": "anschreien",
    "anschreiend": "anschreien",
    "anschreiende": "anschreiend",
    "anschreiendem": "anschreiend",
    "anschreienden": "anschreiend",
    "anschreiender": "anschreiend",
    "anschreiendere": "anschreiend",
    "anschreienderem": "anschreiend",
    "anschreienderen": "anschreiend",
    "anschreienderer": "anschreiend",
    "anschreienderes": "anschreiend",
    "anschreiendes": "anschreiend",
    "anschreiendste": "anschreiend",
    "anschreiendstem": "anschreiend",
    "anschreiendsten": "anschreiend",
    "anschreiendster": "anschreiend",
    "anschreiendstes": "anschreiend",
    "anschreiest": "anschreien",
    "anschreiet": "anschreien",
    "anschreist": "anschreien",
    "anschreit": "anschreien",
    "anschrie": "anschreien",
    "anschrieb": "anschreiben",
    "anschriebe": "anschreiben",
    "anschrieben": "anschreiben",
    "anschriebest": "anschreiben",
    "anschriebet": "anschreiben",
    "anschriebst": "anschreiben",
    "anschriebt": "anschreiben",
    "anschriee": "anschreien",
    "anschrieen": "anschreien",
    "anschrieest": "anschreien",
    "anschrieet": "anschreien",
    "anschrien": "anschreien",
    "anschriest": "anschreien",
    "anschriet": "anschreien",
    "anschräge": "anschrägen",
    "anschrägend": "anschrägen",
    "anschrägende": "anschrägend",
    "anschrägendem": "anschrägend",
    "anschrägenden": "anschrägend",
    "anschrägender": "anschrägend",
    "anschrägendere": "anschrägend",
    "anschrägenderem": "anschrägend",
    "anschrägenderen": "anschrägend",
    "anschrägenderer": "anschrägend",
    "anschrägenderes": "anschrägend",
    "anschrägendes": "anschrägend",
    "anschrägendste": "anschrägend",
    "anschrägendstem": "anschrägend",
    "anschrägendsten": "anschrägend",
    "anschrägendster": "anschrägend",
    "anschrägendstes": "anschrägend",
    "anschrägest": "anschrägen",
    "anschräget": "anschrägen",
    "anschrägst": "anschrägen",
    "anschrägt": "anschrägen",
    "anschrägte": "anschrägen",
    "anschrägten": "anschrägen",
    "anschrägtest": "anschrägen",
    "anschrägtet": "anschrägen",
    "anschwamm": "anschwimmen",
    "anschwammen": "anschwimmen",
    "anschwammst": "anschwimmen",
    "anschwammt": "anschwimmen",
    "anschweige": "anschweigen",
    "anschweigend": "anschweigen",
    "anschweigende": "anschweigend",
    "anschweigendem": "anschweigend",
    "anschweigenden": "anschweigend",
    "anschweigender": "anschweigend",
    "anschweigendes": "anschweigend",
    "anschweigest": "anschweigen",
    "anschweiget": "anschweigen",
    "anschweigst": "anschweigen",
    "anschweigt": "anschweigen",
    "anschweiße": "anschweißen",
    "anschweißend": "anschweißen",
    "anschweißende": "anschweißend",
    "anschweißendem": "anschweißend",
    "anschweißenden": "anschweißend",
    "anschweißender": "anschweißend",
    "anschweißendes": "anschweißend",
    "anschweißest": "anschweißen",
    "anschweißet": "anschweißen",
    "anschweißt": "anschweißen",
    "anschweißte": "anschweißen",
    "anschweißten": "anschweißen",
    "anschweißtest": "anschweißen",
    "anschweißtet": "anschweißen",
    "anschwelle": "anschwellen",
    "anschwellend": "anschwellen",
    "anschwellende": "anschwellend",
    "anschwellendem": "anschwellend",
    "anschwellenden": "anschwellend",
    "anschwellender": "anschwellend",
    "anschwellendere": "anschwellend",
    "anschwellenderem": "anschwellend",
    "anschwellenderen": "anschwellend",
    "anschwellenderer": "anschwellend",
    "anschwellenderes": "anschwellend",
    "anschwellendes": "anschwellend",
    "anschwellendste": "anschwellend",
    "anschwellendstem": "anschwellend",
    "anschwellendsten": "anschwellend",
    "anschwellendster": "anschwellend",
    "anschwellendstes": "anschwellend",
    "anschwellest": "anschwellen",
    "anschwellet": "anschwellen",
    "anschwellst": "anschwellen",
    "anschwellt": "anschwellen",
    "anschwellte": "anschwellen",
    "anschwellten": "anschwellen",
    "anschwelltest": "anschwellen",
    "anschwelltet": "anschwellen",
    "anschwemme": "anschwemmen",
    "anschwemmend": "anschwemmen",
    "anschwemmende": "anschwemmend",
    "anschwemmendem": "anschwemmend",
    "anschwemmenden": "anschwemmend",
    "anschwemmender": "anschwemmend",
    "anschwemmendes": "anschwemmend",
    "anschwemmest": "anschwemmen",
    "anschwemmet": "anschwemmen",
    "anschwemmst": "anschwemmen",
    "anschwemmt": "anschwemmen",
    "anschwemmte": "anschwemmen",
    "anschwemmten": "anschwemmen",
    "anschwemmtest": "anschwemmen",
    "anschwemmtet": "anschwemmen",
    "anschwieg": "anschweigen",
    "anschwiege": "anschweigen",
    "anschwiegen": "anschweigen",
    "anschwiegest": "anschweigen",
    "anschwieget": "anschweigen",
    "anschwiegst": "anschweigen",
    "anschwiegt": "anschweigen",
    "anschwillst": "anschwellen",
    "anschwillt": "anschwellen",
    "anschwimme": "anschwimmen",
    "anschwimmend": "anschwimmen",
    "anschwimmende": "anschwimmend",
    "anschwimmendem": "anschwimmend",
    "anschwimmenden": "anschwimmend",
    "anschwimmender": "anschwimmend",
    "anschwimmendes": "anschwimmend",
    "anschwimmest": "anschwimmen",
    "anschwimmet": "anschwimmen",
    "anschwimmst": "anschwimmen",
    "anschwimmt": "anschwimmen",
    "anschwindele": "anschwindeln",
    "anschwindelnd": "anschwindeln",
    "anschwindelnde": "anschwindelnd",
    "anschwindelndem": "anschwindelnd",
    "anschwindelnden": "anschwindelnd",
    "anschwindelnder": "anschwindelnd",
    "anschwindelndes": "anschwindelnd",
    "anschwindelst": "anschwindeln",
    "anschwindelt": "anschwindeln",
    "anschwindelte": "anschwindeln",
    "anschwindelten": "anschwindeln",
    "anschwindeltest": "anschwindeln",
    "anschwindeltet": "anschwindeln",
    "anschwindle": "anschwindeln",
    "anschwoll": "anschwellen",
    "anschwollen": "anschwellen",
    "anschwollst": "anschwellen",
    "anschwollt": "anschwellen",
    "anschwämme": "anschwimmen",
    "anschwämmen": "anschwimmen",
    "anschwämmest": "anschwimmen",
    "anschwämmet": "anschwimmen",
    "anschwärze": "anschwärzen",
    "anschwärzend": "anschwärzen",
    "anschwärzende": "anschwärzend",
    "anschwärzendem": "anschwärzend",
    "anschwärzenden": "anschwärzend",
    "anschwärzender": "anschwärzend",
    "anschwärzendere": "anschwärzend",
    "anschwärzenderem": "anschwärzend",
    "anschwärzenderen": "anschwärzend",
    "anschwärzenderer": "anschwärzend",
    "anschwärzenderes": "anschwärzend",
    "anschwärzendes": "anschwärzend",
    "anschwärzendste": "anschwärzend",
    "anschwärzendstem": "anschwärzend",
    "anschwärzendsten": "anschwärzend",
    "anschwärzendster": "anschwärzend",
    "anschwärzendstes": "anschwärzend",
    "anschwärzest": "anschwärzen",
    "anschwärzet": "anschwärzen",
    "anschwärzt": "anschwärzen",
    "anschwärzte": "anschwärzen",
    "anschwärzten": "anschwärzen",
    "anschwärztest": "anschwärzen",
    "anschwärztet": "anschwärzen",
    "anschwölle": "anschwellen",
    "anschwöllen": "anschwellen",
    "anschwöllest": "anschwellen",
    "anschwöllet": "anschwellen",
    "anschöbe": "anschieben",
    "anschöben": "anschieben",
    "anschöbest": "anschieben",
    "anschöbet": "anschieben",
    "anschösse": "anschießen",
    "anschössen": "anschießen",
    "anschössest": "anschießen",
    "anschösset": "anschießen",
    "ansehe": "ansehen",
    "ansehend": "ansehen",
    "ansehende": "ansehend",
    "ansehendem": "ansehend",
    "ansehenden": "ansehend",
    "ansehender": "ansehend",
    "ansehendes": "ansehend",
    "ansehest": "ansehen",
    "ansehet": "ansehen",
    "ansehnliche": "ansehnlich",
    "ansehnlichem": "ansehnlich",
    "ansehnlichen": "ansehnlich",
    "ansehnlicher": "ansehnlich",
    "ansehnlichere": "ansehnlich",
    "ansehnlicherem": "ansehnlich",
    "ansehnlicheren": "ansehnlich",
    "ansehnlicherer": "ansehnlich",
    "ansehnlicheres": "ansehnlich",
    "ansehnliches": "ansehnlich",
    "ansehnlichste": "ansehnlich",
    "ansehnlichstem": "ansehnlich",
    "ansehnlichsten": "ansehnlich",
    "ansehnlichster": "ansehnlich",
    "ansehnlichstes": "ansehnlich",
    "anseht": "ansehen",
    "anseile": "anseilen",
    "anseilend": "anseilen",
    "anseilende": "anseilend",
    "anseilendem": "anseilend",
    "anseilenden": "anseilend",
    "anseilender": "anseilend",
    "anseilendere": "anseilend",
    "anseilenderem": "anseilend",
    "anseilenderen": "anseilend",
    "anseilenderer": "anseilend",
    "anseilenderes": "anseilend",
    "anseilendes": "anseilend",
    "anseilendste": "anseilend",
    "anseilendstem": "anseilend",
    "anseilendsten": "anseilend",
    "anseilendster": "anseilend",
    "anseilendstes": "anseilend",
    "anseilest": "anseilen",
    "anseilet": "anseilen",
    "anseilst": "anseilen",
    "anseilt": "anseilen",
    "anseilte": "anseilen",
    "anseilten": "anseilen",
    "anseiltest": "anseilen",
    "anseiltet": "anseilen",
    "ansenge": "ansengen",
    "ansengend": "ansengen",
    "ansengende": "ansengend",
    "ansengendem": "ansengend",
    "ansengenden": "ansengend",
    "ansengender": "ansengend",
    "ansengendere": "ansengend",
    "ansengenderem": "ansengend",
    "ansengenderen": "ansengend",
    "ansengenderer": "ansengend",
    "ansengenderes": "ansengend",
    "ansengendes": "ansengend",
    "ansengendste": "ansengend",
    "ansengendstem": "ansengend",
    "ansengendsten": "ansengend",
    "ansengendster": "ansengend",
    "ansengendstes": "ansengend",
    "ansengest": "ansengen",
    "ansenget": "ansengen",
    "ansengst": "ansengen",
    "ansengt": "ansengen",
    "ansengte": "ansengen",
    "ansengten": "ansengen",
    "ansengtest": "ansengen",
    "ansengtet": "ansengen",
    "ansetze": "ansetzen",
    "ansetzend": "ansetzen",
    "ansetzende": "ansetzend",
    "ansetzendem": "ansetzend",
    "ansetzenden": "ansetzend",
    "ansetzender": "ansetzend",
    "ansetzendes": "ansetzend",
    "ansetzest": "ansetzen",
    "ansetzet": "ansetzen",
    "ansetzt": "ansetzen",
    "ansetzte": "ansetzen",
    "ansetzten": "ansetzen",
    "ansetztest": "ansetzen",
    "ansetztet": "ansetzen",
    "ansiedele": "ansiedeln",
    "ansiedelnd": "ansiedeln",
    "ansiedelnde": "ansiedelnd",
    "ansiedelndem": "ansiedelnd",
    "ansiedelnden": "ansiedelnd",
    "ansiedelnder": "ansiedelnd",
    "ansiedelndes": "ansiedelnd",
    "ansiedelst": "ansiedeln",
    "ansiedelt": "ansiedeln",
    "ansiedelte": "ansiedeln",
    "ansiedelten": "ansiedeln",
    "ansiedeltest": "ansiedeln",
    "ansiedeltet": "ansiedeln",
    "ansiedle": "ansiedeln",
    "ansiehst": "ansehen",
    "ansieht": "ansehen",
    "ansinge": "ansingen",
    "ansingend": "ansingen",
    "ansingende": "ansingend",
    "ansingendem": "ansingend",
    "ansingenden": "ansingend",
    "ansingender": "ansingend",
    "ansingendes": "ansingend",
    "ansingest": "ansingen",
    "ansinget": "ansingen",
    "ansingst": "ansingen",
    "ansingt": "ansingen",
    "ansitze": "ansitzen",
    "ansitzend": "ansitzen",
    "ansitzende": "ansitzend",
    "ansitzendem": "ansitzend",
    "ansitzenden": "ansitzend",
    "ansitzender": "ansitzend",
    "ansitzendes": "ansitzend",
    "ansitzest": "ansitzen",
    "ansitzet": "ansitzen",
    "ansitzt": "ansitzen",
    "ansoff": "ansaufen",
    "ansoffen": "ansaufen",
    "ansoffst": "ansaufen",
    "ansofft": "ansaufen",
    "ansog": "ansaugen",
    "ansogen": "ansaugen",
    "ansogst": "ansaugen",
    "ansogt": "ansaugen",
    "ansohle": "ansohlen",
    "ansohlend": "ansohlen",
    "ansohlende": "ansohlend",
    "ansohlendem": "ansohlend",
    "ansohlenden": "ansohlend",
    "ansohlender": "ansohlend",
    "ansohlendere": "ansohlend",
    "ansohlenderem": "ansohlend",
    "ansohlenderen": "ansohlend",
    "ansohlenderer": "ansohlend",
    "ansohlenderes": "ansohlend",
    "ansohlendes": "ansohlend",
    "ansohlendste": "ansohlend",
    "ansohlendstem": "ansohlend",
    "ansohlendsten": "ansohlend",
    "ansohlendster": "ansohlend",
    "ansohlendstes": "ansohlend",
    "ansohlest": "ansohlen",
    "ansohlet": "ansohlen",
    "ansohlst": "ansohlen",
    "ansohlt": "ansohlen",
    "ansohlte": "ansohlen",
    "ansohlten": "ansohlen",
    "ansohltest": "ansohlen",
    "ansohltet": "ansohlen",
    "anspanne": "anspannen",
    "anspannend": "anspannen",
    "anspannende": "anspannend",
    "anspannendem": "anspannend",
    "anspannenden": "anspannend",
    "anspannender": "anspannend",
    "anspannendere": "anspannend",
    "anspannenderem": "anspannend",
    "anspannenderen": "anspannend",
    "anspannenderer": "anspannend",
    "anspannenderes": "anspannend",
    "anspannendes": "anspannend",
    "anspannendste": "anspannend",
    "anspannendstem": "anspannend",
    "anspannendsten": "anspannend",
    "anspannendster": "anspannend",
    "anspannendstes": "anspannend",
    "anspannest": "anspannen",
    "anspannet": "anspannen",
    "anspannst": "anspannen",
    "anspannt": "anspannen",
    "anspannte": "anspannen",
    "anspannten": "anspannen",
    "anspanntest": "anspannen",
    "anspanntet": "anspannen",
    "anspare": "ansparen",
    "ansparend": "ansparen",
    "ansparende": "ansparend",
    "ansparendem": "ansparend",
    "ansparenden": "ansparend",
    "ansparender": "ansparend",
    "ansparendere": "ansparend",
    "ansparenderem": "ansparend",
    "ansparenderen": "ansparend",
    "ansparenderer": "ansparend",
    "ansparenderes": "ansparend",
    "ansparendes": "ansparend",
    "ansparendste": "ansparend",
    "ansparendstem": "ansparend",
    "ansparendsten": "ansparend",
    "ansparendster": "ansparend",
    "ansparendstes": "ansparend",
    "ansparest": "ansparen",
    "ansparet": "ansparen",
    "ansparst": "ansparen",
    "anspart": "ansparen",
    "ansparte": "ansparen",
    "ansparten": "ansparen",
    "anspartest": "ansparen",
    "anspartet": "ansparen",
    "anspeie": "anspeien",
    "anspeiend": "anspeien",
    "anspeiende": "anspeiend",
    "anspeiendem": "anspeiend",
    "anspeienden": "anspeiend",
    "anspeiender": "anspeiend",
    "anspeiendes": "anspeiend",
    "anspeiest": "anspeien",
    "anspeiet": "anspeien",
    "anspeist": "anspeien",
    "anspeit": "anspeien",
    "anspie": "anspeien",
    "anspiee": "anspeien",
    "anspieen": "anspeien",
    "anspieest": "anspeien",
    "anspieet": "anspeien",
    "anspiele": "anspielen",
    "anspielend": "anspielen",
    "anspielende": "anspielend",
    "anspielendem": "anspielend",
    "anspielenden": "anspielend",
    "anspielender": "anspielend",
    "anspielendes": "anspielend",
    "anspielest": "anspielen",
    "anspielet": "anspielen",
    "anspielst": "anspielen",
    "anspielt": "anspielen",
    "anspielte": "anspielen",
    "anspielten": "anspielen",
    "anspieltest": "anspielen",
    "anspieltet": "anspielen",
    "anspien": "anspeien",
    "anspiest": "anspeien",
    "anspiet": "anspeien",
    "anspitze": "anspitzen",
    "anspitzend": "anspitzen",
    "anspitzende": "anspitzend",
    "anspitzendem": "anspitzend",
    "anspitzenden": "anspitzend",
    "anspitzender": "anspitzend",
    "anspitzendere": "anspitzend",
    "anspitzenderem": "anspitzend",
    "anspitzenderen": "anspitzend",
    "anspitzenderer": "anspitzend",
    "anspitzenderes": "anspitzend",
    "anspitzendes": "anspitzend",
    "anspitzendste": "anspitzend",
    "anspitzendstem": "anspitzend",
    "anspitzendsten": "anspitzend",
    "anspitzendster": "anspitzend",
    "anspitzendstes": "anspitzend",
    "anspitzest": "anspitzen",
    "anspitzet": "anspitzen",
    "anspitzt": "anspitzen",
    "anspitzte": "anspitzen",
    "anspitzten": "anspitzen",
    "anspitztest": "anspitzen",
    "anspitztet": "anspitzen",
    "ansporne": "anspornen",
    "anspornend": "anspornen",
    "anspornende": "anspornend",
    "anspornendem": "anspornend",
    "anspornenden": "anspornend",
    "anspornender": "anspornend",
    "anspornendere": "anspornend",
    "anspornenderem": "anspornend",
    "anspornenderen": "anspornend",
    "anspornenderer": "anspornend",
    "anspornenderes": "anspornend",
    "anspornendes": "anspornend",
    "anspornendste": "anspornend",
    "anspornendstem": "anspornend",
    "anspornendsten": "anspornend",
    "anspornendster": "anspornend",
    "anspornendstes": "anspornend",
    "anspornest": "anspornen",
    "anspornet": "anspornen",
    "anspornst": "anspornen",
    "anspornt": "anspornen",
    "anspornte": "anspornen",
    "anspornten": "anspornen",
    "ansporntest": "anspornen",
    "ansporntet": "anspornen",
    "ansprach": "ansprechen",
    "ansprachst": "ansprechen",
    "anspracht": "ansprechen",
    "ansprang": "anspringen",
    "ansprangen": "anspringen",
    "ansprangst": "anspringen",
    "ansprangt": "anspringen",
    "anspreche": "ansprechen",
    "ansprechend": "ansprechen",
    "ansprechende": "ansprechend",
    "ansprechendem": "ansprechend",
    "ansprechenden": "ansprechend",
    "ansprechender": "ansprechend",
    "ansprechendere": "ansprechend",
    "ansprechenderem": "ansprechend",
    "ansprechenderen": "ansprechend",
    "ansprechenderer": "ansprechend",
    "ansprechenderes": "ansprechend",
    "ansprechendes": "ansprechend",
    "ansprechendste": "ansprechend",
    "ansprechendstem": "ansprechend",
    "ansprechendsten": "ansprechend",
    "ansprechendster": "ansprechend",
    "ansprechendstes": "ansprechend",
    "ansprechest": "ansprechen",
    "ansprechet": "ansprechen",
    "ansprecht": "ansprechen",
    "ansprenge": "ansprengen",
    "ansprengend": "ansprengen",
    "ansprengende": "ansprengend",
    "ansprengendem": "ansprengend",
    "ansprengenden": "ansprengend",
    "ansprengender": "ansprengend",
    "ansprengendes": "ansprengend",
    "ansprengest": "ansprengen",
    "ansprenget": "ansprengen",
    "ansprengst": "ansprengen",
    "ansprengt": "ansprengen",
    "ansprengte": "ansprengen",
    "ansprengten": "ansprengen",
    "ansprengtest": "ansprengen",
    "ansprengtet": "ansprengen",
    "ansprichst": "ansprechen",
    "anspricht": "ansprechen",
    "anspringe": "anspringen",
    "anspringend": "anspringen",
    "anspringende": "anspringend",
    "anspringendem": "anspringend",
    "anspringenden": "anspringend",
    "anspringender": "anspringend",
    "anspringendes": "anspringend",
    "anspringest": "anspringen",
    "anspringet": "anspringen",
    "anspringst": "anspringen",
    "anspringt": "anspringen",
    "anspritze": "anspritzen",
    "anspritzend": "anspritzen",
    "anspritzende": "anspritzend",
    "anspritzendem": "anspritzend",
    "anspritzenden": "anspritzend",
    "anspritzender": "anspritzend",
    "anspritzendes": "anspritzend",
    "anspritzest": "anspritzen",
    "anspritzet": "anspritzen",
    "anspritzt": "anspritzen",
    "anspritzte": "anspritzen",
    "anspritzten": "anspritzen",
    "anspritztest": "anspritzen",
    "anspritztet": "anspritzen",
    "anspruchslosem": "anspruchslos",
    "anspruchslosen": "anspruchslos",
    "anspruchsloser": "anspruchslos",
    "anspruchslosere": "anspruchslos",
    "anspruchsloserem": "anspruchslos",
    "anspruchsloseren": "anspruchslos",
    "anspruchsloserer": "anspruchslos",
    "anspruchsloseres": "anspruchslos",
    "anspruchsloses": "anspruchslos",
    "anspruchsloseste": "anspruchslos",
    "anspruchslosestem": "anspruchslos",
    "anspruchslosesten": "anspruchslos",
    "anspruchslosester": "anspruchslos",
    "anspruchslosestes": "anspruchslos",
    "anspruchsvollem": "anspruchsvoll",
    "anspruchsvollen": "anspruchsvoll",
    "anspruchsvoller": "anspruchsvoll",
    "anspruchsvollere": "anspruchsvoll",
    "anspruchsvollerem": "anspruchsvoll",
    "anspruchsvolleren": "anspruchsvoll",
    "anspruchsvollerer": "anspruchsvoll",
    "anspruchsvolleres": "anspruchsvoll",
    "anspruchsvolles": "anspruchsvoll",
    "anspruchsvollste": "anspruchsvoll",
    "anspruchsvollstem": "anspruchsvoll",
    "anspruchsvollsten": "anspruchsvoll",
    "anspruchsvollster": "anspruchsvoll",
    "anspruchsvollstes": "anspruchsvoll",
    "anspräche": "ansprechen",
    "ansprächen": "ansprechen",
    "ansprächest": "ansprechen",
    "ansprächet": "ansprechen",
    "anspränge": "anspringen",
    "ansprängen": "anspringen",
    "ansprängest": "anspringen",
    "anspränget": "anspringen",
    "ansprühe": "ansprühen",
    "ansprühend": "ansprühen",
    "ansprühende": "ansprühend",
    "ansprühendem": "ansprühend",
    "ansprühenden": "ansprühend",
    "ansprühender": "ansprühend",
    "ansprühendere": "ansprühend",
    "ansprühenderem": "ansprühend",
    "ansprühenderen": "ansprühend",
    "ansprühenderer": "ansprühend",
    "ansprühenderes": "ansprühend",
    "ansprühendes": "ansprühend",
    "ansprühendste": "ansprühend",
    "ansprühendstem": "ansprühend",
    "ansprühendsten": "ansprühend",
    "ansprühendster": "ansprühend",
    "ansprühendstes": "ansprühend",
    "ansprühest": "ansprühen",
    "ansprühet": "ansprühen",
    "ansprühst": "ansprühen",
    "ansprüht": "ansprühen",
    "ansprühte": "ansprühen",
    "ansprühten": "ansprühen",
    "ansprühtest": "ansprühen",
    "ansprühtet": "ansprühen",
    "anspüle": "anspülen",
    "anspülend": "anspülen",
    "anspülende": "anspülend",
    "anspülendem": "anspülend",
    "anspülenden": "anspülend",
    "anspülender": "anspülend",
    "anspülendes": "anspülend",
    "anspülest": "anspülen",
    "anspület": "anspülen",
    "anspülst": "anspülen",
    "anspült": "anspülen",
    "anspülte": "anspülen",
    "anspülten": "anspülen",
    "anspültest": "anspülen",
    "anspültet": "anspülen",
    "anstach": "anstechen",
    "anstachele": "anstacheln",
    "anstachelnd": "anstacheln",
    "anstachelnde": "anstachelnd",
    "anstachelndem": "anstachelnd",
    "anstachelnden": "anstachelnd",
    "anstachelnder": "anstachelnd",
    "anstachelndere": "anstachelnd",
    "anstachelnderem": "anstachelnd",
    "anstachelnderen": "anstachelnd",
    "anstachelnderer": "anstachelnd",
    "anstachelnderes": "anstachelnd",
    "anstachelndes": "anstachelnd",
    "anstachelndste": "anstachelnd",
    "anstachelndstem": "anstachelnd",
    "anstachelndsten": "anstachelnd",
    "anstachelndster": "anstachelnd",
    "anstachelndstes": "anstachelnd",
    "anstachelst": "anstacheln",
    "anstachelt": "anstacheln",
    "anstachelte": "anstacheln",
    "anstachelten": "anstacheln",
    "anstacheltest": "anstacheln",
    "anstacheltet": "anstacheln",
    "anstachen": "anstechen",
    "anstachle": "anstacheln",
    "anstachst": "anstechen",
    "anstacht": "anstechen",
    "anstamme": "anstammen",
    "anstammend": "anstammen",
    "anstammende": "anstammend",
    "anstammendem": "anstammend",
    "anstammenden": "anstammend",
    "anstammender": "anstammend",
    "anstammendes": "anstammend",
    "anstammest": "anstammen",
    "anstammet": "anstammen",
    "anstammst": "anstammen",
    "anstammt": "anstammen",
    "anstammte": "anstammen",
    "anstammten": "anstammen",
    "anstammtest": "anstammen",
    "anstammtet": "anstammen",
    "anstand": "anstehen",
    "anstanden": "anstehen",
    "anstandest": "anstehen",
    "anstandet": "anstehen",
    "anstandslosem": "anstandslos",
    "anstandslosen": "anstandslos",
    "anstandsloser": "anstandslos",
    "anstandsloses": "anstandslos",
    "anstank": "anstinken",
    "anstanken": "anstinken",
    "anstankst": "anstinken",
    "anstankt": "anstinken",
    "anstarre": "anstarren",
    "anstarrend": "anstarren",
    "anstarrende": "anstarrend",
    "anstarrendem": "anstarrend",
    "anstarrenden": "anstarrend",
    "anstarrender": "anstarrend",
    "anstarrendere": "anstarrend",
    "anstarrenderem": "anstarrend",
    "anstarrenderen": "anstarrend",
    "anstarrenderer": "anstarrend",
    "anstarrenderes": "anstarrend",
    "anstarrendes": "anstarrend",
    "anstarrendste": "anstarrend",
    "anstarrendstem": "anstarrend",
    "anstarrendsten": "anstarrend",
    "anstarrendster": "anstarrend",
    "anstarrendstes": "anstarrend",
    "anstarrest": "anstarren",
    "anstarret": "anstarren",
    "anstarrst": "anstarren",
    "anstarrt": "anstarren",
    "anstarrte": "anstarren",
    "anstarrten": "anstarren",
    "anstarrtest": "anstarren",
    "anstarrtet": "anstarren",
    "anstaube": "anstauben",
    "anstaubend": "anstauben",
    "anstaubende": "anstaubend",
    "anstaubendem": "anstaubend",
    "anstaubenden": "anstaubend",
    "anstaubender": "anstaubend",
    "anstaubendere": "anstaubend",
    "anstaubenderem": "anstaubend",
    "anstaubenderen": "anstaubend",
    "anstaubenderer": "anstaubend",
    "anstaubenderes": "anstaubend",
    "anstaubendes": "anstaubend",
    "anstaubendste": "anstaubend",
    "anstaubendstem": "anstaubend",
    "anstaubendsten": "anstaubend",
    "anstaubendster": "anstaubend",
    "anstaubendstes": "anstaubend",
    "anstaubest": "anstauben",
    "anstaubet": "anstauben",
    "anstaubst": "anstauben",
    "anstaubt": "anstauben",
    "anstaubte": "anstauben",
    "anstaubten": "anstauben",
    "anstaubtest": "anstauben",
    "anstaubtet": "anstauben",
    "anstaue": "anstauen",
    "anstauend": "anstauen",
    "anstauende": "anstauend",
    "anstauendem": "anstauend",
    "anstauenden": "anstauend",
    "anstauender": "anstauend",
    "anstauendes": "anstauend",
    "anstauest": "anstauen",
    "anstauet": "anstauen",
    "anstaust": "anstauen",
    "anstaut": "anstauen",
    "anstaute": "anstauen",
    "anstauten": "anstauen",
    "anstautest": "anstauen",
    "anstautet": "anstauen",
    "ansteche": "anstechen",
    "anstechend": "anstechen",
    "anstechende": "anstechend",
    "anstechendem": "anstechend",
    "anstechenden": "anstechend",
    "anstechender": "anstechend",
    "anstechendes": "anstechend",
    "anstechest": "anstechen",
    "anstechet": "anstechen",
    "anstecht": "anstechen",
    "anstecke": "anstecken",
    "ansteckend": "anstecken",
    "ansteckende": "ansteckend",
    "ansteckendem": "ansteckend",
    "ansteckenden": "ansteckend",
    "ansteckender": "ansteckend",
    "ansteckendere": "ansteckend",
    "ansteckenderem": "ansteckend",
    "ansteckenderen": "ansteckend",
    "ansteckenderer": "ansteckend",
    "ansteckenderes": "ansteckend",
    "ansteckendes": "ansteckend",
    "ansteckendste": "ansteckend",
    "ansteckendstem": "ansteckend",
    "ansteckendsten": "ansteckend",
    "ansteckendster": "ansteckend",
    "ansteckendstes": "ansteckend",
    "ansteckest": "anstecken",
    "anstecket": "anstecken",
    "ansteckst": "anstecken",
    "ansteckt": "anstecken",
    "ansteckte": "anstecken",
    "ansteckten": "anstecken",
    "anstecktest": "anstecken",
    "anstecktet": "anstecken",
    "anstehe": "anstehen",
    "anstehend": "anstehen",
    "anstehende": "anstehend",
    "anstehendem": "anstehend",
    "anstehenden": "anstehend",
    "anstehender": "anstehend",
    "anstehendes": "anstehend",
    "anstehest": "anstehen",
    "anstehet": "anstehen",
    "anstehst": "anstehen",
    "ansteht": "anstehen",
    "ansteige": "ansteigen",
    "ansteigend": "ansteigen",
    "ansteigende": "ansteigend",
    "ansteigendem": "ansteigend",
    "ansteigenden": "ansteigend",
    "ansteigender": "ansteigend",
    "ansteigendere": "ansteigend",
    "ansteigenderem": "ansteigend",
    "ansteigenderen": "ansteigend",
    "ansteigenderer": "ansteigend",
    "ansteigenderes": "ansteigend",
    "ansteigendes": "ansteigend",
    "ansteigendste": "ansteigend",
    "ansteigendstem": "ansteigend",
    "ansteigendsten": "ansteigend",
    "ansteigendster": "ansteigend",
    "ansteigendstes": "ansteigend",
    "ansteigest": "ansteigen",
    "ansteiget": "ansteigen",
    "ansteigst": "ansteigen",
    "ansteigt": "ansteigen",
    "anstelle": "anstellen",
    "anstellend": "anstellen",
    "anstellende": "anstellend",
    "anstellendem": "anstellend",
    "anstellenden": "anstellend",
    "anstellender": "anstellend",
    "anstellendes": "anstellend",
    "anstellest": "anstellen",
    "anstellet": "anstellen",
    "anstellst": "anstellen",
    "anstellt": "anstellen",
    "anstellte": "anstellen",
    "anstellten": "anstellen",
    "anstelltest": "anstellen",
    "anstelltet": "anstellen",
    "anstemme": "anstemmen",
    "anstemmend": "anstemmen",
    "anstemmende": "anstemmend",
    "anstemmendem": "anstemmend",
    "anstemmenden": "anstemmend",
    "anstemmender": "anstemmend",
    "anstemmendes": "anstemmend",
    "anstemmest": "anstemmen",
    "anstemmet": "anstemmen",
    "anstemmst": "anstemmen",
    "anstemmt": "anstemmen",
    "anstemmte": "anstemmen",
    "anstemmten": "anstemmen",
    "anstemmtest": "anstemmen",
    "anstemmtet": "anstemmen",
    "ansteuernde": "ansteuernd",
    "ansteuerndem": "ansteuernd",
    "ansteuernden": "ansteuernd",
    "ansteuernder": "ansteuernd",
    "ansteuerndes": "ansteuernd",
    "ansteuertem": "ansteuert",
    "ansteuerten": "ansteuert",
    "ansteuerter": "ansteuert",
    "ansteuertes": "ansteuert",
    "anstichst": "anstechen",
    "ansticht": "anstechen",
    "anstieg": "ansteigen",
    "anstiegest": "ansteigen",
    "anstieget": "ansteigen",
    "anstiegst": "ansteigen",
    "anstiegt": "ansteigen",
    "anstieß": "anstoßen",
    "anstieße": "anstoßen",
    "anstießen": "anstoßen",
    "anstießest": "anstoßen",
    "anstießet": "anstoßen",
    "anstießt": "anstoßen",
    "anstifte": "anstiften",
    "anstiftend": "anstiften",
    "anstiftende": "anstiftend",
    "anstiftendem": "anstiftend",
    "anstiftenden": "anstiftend",
    "anstiftender": "anstiftend",
    "anstiftendere": "anstiftend",
    "anstiftenderem": "anstiftend",
    "anstiftenderen": "anstiftend",
    "anstiftenderer": "anstiftend",
    "anstiftenderes": "anstiftend",
    "anstiftendes": "anstiftend",
    "anstiftendste": "anstiftend",
    "anstiftendstem": "anstiftend",
    "anstiftendsten": "anstiftend",
    "anstiftendster": "anstiftend",
    "anstiftendstes": "anstiftend",
    "anstiftest": "anstiften",
    "anstiftet": "anstiften",
    "anstiftete": "anstiften",
    "anstifteten": "anstiften",
    "anstiftetest": "anstiften",
    "anstiftetet": "anstiften",
    "anstimme": "anstimmen",
    "anstimmend": "anstimmen",
    "anstimmende": "anstimmend",
    "anstimmendem": "anstimmend",
    "anstimmenden": "anstimmend",
    "anstimmender": "anstimmend",
    "anstimmendes": "anstimmend",
    "anstimmest": "anstimmen",
    "anstimmet": "anstimmen",
    "anstimmst": "anstimmen",
    "anstimmt": "anstimmen",
    "anstimmte": "anstimmen",
    "anstimmten": "anstimmen",
    "anstimmtest": "anstimmen",
    "anstimmtet": "anstimmen",
    "anstinke": "anstinken",
    "anstinkend": "anstinken",
    "anstinkende": "anstinkend",
    "anstinkendem": "anstinkend",
    "anstinkenden": "anstinkend",
    "anstinkender": "anstinkend",
    "anstinkendes": "anstinkend",
    "anstinkest": "anstinken",
    "anstinket": "anstinken",
    "anstinkst": "anstinken",
    "anstinkt": "anstinken",
    "anstoßend": "anstoßen",
    "anstoßende": "anstoßend",
    "anstoßendem": "anstoßend",
    "anstoßenden": "anstoßend",
    "anstoßender": "anstoßend",
    "anstoßendes": "anstoßend",
    "anstoßest": "anstoßen",
    "anstoßet": "anstoßen",
    "anstoßt": "anstoßen",
    "anstrahle": "anstrahlen",
    "anstrahlend": "anstrahlen",
    "anstrahlende": "anstrahlend",
    "anstrahlendem": "anstrahlend",
    "anstrahlenden": "anstrahlend",
    "anstrahlender": "anstrahlend",
    "anstrahlendere": "anstrahlend",
    "anstrahlenderem": "anstrahlend",
    "anstrahlenderen": "anstrahlend",
    "anstrahlenderer": "anstrahlend",
    "anstrahlenderes": "anstrahlend",
    "anstrahlendes": "anstrahlend",
    "anstrahlendste": "anstrahlend",
    "anstrahlendstem": "anstrahlend",
    "anstrahlendsten": "anstrahlend",
    "anstrahlendster": "anstrahlend",
    "anstrahlendstes": "anstrahlend",
    "anstrahlest": "anstrahlen",
    "anstrahlet": "anstrahlen",
    "anstrahlst": "anstrahlen",
    "anstrahlt": "anstrahlen",
    "anstrahlte": "anstrahlen",
    "anstrahlten": "anstrahlen",
    "anstrahltest": "anstrahlen",
    "anstrahltet": "anstrahlen",
    "anstrebe": "anstreben",
    "anstrebend": "anstreben",
    "anstrebende": "anstrebend",
    "anstrebendem": "anstrebend",
    "anstrebenden": "anstrebend",
    "anstrebender": "anstrebend",
    "anstrebendes": "anstrebend",
    "anstrebest": "anstreben",
    "anstrebet": "anstreben",
    "anstrebst": "anstreben",
    "anstrebt": "anstreben",
    "anstrebte": "anstreben",
    "anstrebten": "anstreben",
    "anstrebtest": "anstreben",
    "anstrebtet": "anstreben",
    "anstreiche": "anstreichen",
    "anstreichend": "anstreichen",
    "anstreichende": "anstreichend",
    "anstreichendem": "anstreichend",
    "anstreichenden": "anstreichend",
    "anstreichender": "anstreichend",
    "anstreichendes": "anstreichend",
    "anstreichest": "anstreichen",
    "anstreichet": "anstreichen",
    "anstreichst": "anstreichen",
    "anstreicht": "anstreichen",
    "anstrenge": "anstrengen",
    "anstrengend": "anstrengen",
    "anstrengende": "anstrengend",
    "anstrengendem": "anstrengend",
    "anstrengenden": "anstrengend",
    "anstrengender": "anstrengend",
    "anstrengendere": "anstrengend",
    "anstrengenderem": "anstrengend",
    "anstrengenderen": "anstrengend",
    "anstrengenderer": "anstrengend",
    "anstrengenderes": "anstrengend",
    "anstrengendes": "anstrengend",
    "anstrengendste": "anstrengend",
    "anstrengendstem": "anstrengend",
    "anstrengendsten": "anstrengend",
    "anstrengendster": "anstrengend",
    "anstrengendstes": "anstrengend",
    "anstrengest": "anstrengen",
    "anstrenget": "anstrengen",
    "anstrengst": "anstrengen",
    "anstrengt": "anstrengen",
    "anstrengte": "anstrengen",
    "anstrengten": "anstrengen",
    "anstrengtest": "anstrengen",
    "anstrengtet": "anstrengen",
    "anstrich": "anstreichen",
    "anstriche": "anstreichen",
    "anstrichen": "anstreichen",
    "anstrichest": "anstreichen",
    "anstrichet": "anstreichen",
    "anstrichst": "anstreichen",
    "anstricht": "anstreichen",
    "anstäche": "anstechen",
    "anstächen": "anstechen",
    "anstächest": "anstechen",
    "anstächet": "anstechen",
    "anständige": "anständig",
    "anständigem": "anständig",
    "anständigen": "anständig",
    "anständiger": "anständig",
    "anständigere": "anständig",
    "anständigerem": "anständig",
    "anständigeren": "anständig",
    "anständigerer": "anständig",
    "anständigeres": "anständig",
    "anständiges": "anständig",
    "anständigste": "anständig",
    "anständigstem": "anständig",
    "anständigsten": "anständig",
    "anständigster": "anständig",
    "anständigstes": "anständig",
    "anstänke": "anstinken",
    "anstänken": "anstinken",
    "anstänkest": "anstinken",
    "anstänket": "anstinken",
    "anstößige": "anstößig",
    "anstößigem": "anstößig",
    "anstößigen": "anstößig",
    "anstößiger": "anstößig",
    "anstößigere": "anstößig",
    "anstößigerem": "anstößig",
    "anstößigeren": "anstößig",
    "anstößigerer": "anstößig",
    "anstößigeres": "anstößig",
    "anstößiges": "anstößig",
    "anstößigstem": "anstößig",
    "anstößigsten": "anstößig",
    "anstößigster": "anstößig",
    "anstößigstes": "anstößig",
    "anstößt": "anstoßen",
    "anstünde": "anstehen",
    "anstünden": "anstehen",
    "anstündest": "anstehen",
    "anstündet": "anstehen",
    "anstürmend": "anstürmen",
    "anstürmende": "anstürmend",
    "anstürmendem": "anstürmend",
    "anstürmenden": "anstürmend",
    "anstürmender": "anstürmend",
    "anstürmendere": "anstürmend",
    "anstürmenderem": "anstürmend",
    "anstürmenderen": "anstürmend",
    "anstürmenderer": "anstürmend",
    "anstürmenderes": "anstürmend",
    "anstürmendes": "anstürmend",
    "anstürmendste": "anstürmend",
    "anstürmendstem": "anstürmend",
    "anstürmendsten": "anstürmend",
    "anstürmendster": "anstürmend",
    "anstürmendstes": "anstürmend",
    "anstürmest": "anstürmen",
    "anstürmet": "anstürmen",
    "anstürmst": "anstürmen",
    "anstürmt": "anstürmen",
    "anstürmte": "anstürmen",
    "anstürmten": "anstürmen",
    "anstürmtest": "anstürmen",
    "anstürmtet": "anstürmen",
    "ansuche": "ansuchen",
    "ansuchend": "ansuchen",
    "ansuchende": "ansuchend",
    "ansuchendem": "ansuchend",
    "ansuchenden": "ansuchend",
    "ansuchender": "ansuchend",
    "ansuchendes": "ansuchend",
    "ansuchest": "ansuchen",
    "ansuchet": "ansuchen",
    "ansuchst": "ansuchen",
    "ansucht": "ansuchen",
    "ansuchte": "ansuchen",
    "ansuchten": "ansuchen",
    "ansuchtest": "ansuchen",
    "ansuchtet": "ansuchen",
    "ansäe": "ansäen",
    "ansäend": "ansäen",
    "ansäende": "ansäend",
    "ansäendem": "ansäend",
    "ansäenden": "ansäend",
    "ansäender": "ansäend",
    "ansäendes": "ansäend",
    "ansäest": "ansäen",
    "ansäet": "ansäen",
    "ansäge": "ansägen",
    "ansägend": "ansägen",
    "ansägendem": "ansägend",
    "ansägender": "ansägend",
    "ansägendes": "ansägend",
    "ansägest": "ansägen",
    "ansäget": "ansägen",
    "ansägst": "ansägen",
    "ansägt": "ansägen",
    "ansägte": "ansägen",
    "ansägten": "ansägen",
    "ansägtest": "ansägen",
    "ansägtet": "ansägen",
    "ansähe": "ansehen",
    "ansähen": "ansehen",
    "ansähest": "ansehen",
    "ansähet": "ansehen",
    "ansänge": "ansingen",
    "ansängen": "ansingen",
    "ansängest": "ansingen",
    "ansänget": "ansingen",
    "ansässige": "ansässig",
    "ansässigem": "ansässig",
    "ansässigen": "ansässig",
    "ansässiger": "ansässig",
    "ansässiges": "ansässig",
    "ansäst": "ansäen",
    "ansät": "ansäen",
    "ansäte": "ansäen",
    "ansäten": "ansäen",
    "ansätest": "ansäen",
    "ansätet": "ansäen",
    "ansäuere": "ansäuern",
    "ansäuernd": "ansäuern",
    "ansäuernde": "ansäuernd",
    "ansäuerndem": "ansäuernd",
    "ansäuernden": "ansäuernd",
    "ansäuernder": "ansäuernd",
    "ansäuerndere": "ansäuernd",
    "ansäuernderem": "ansäuernd",
    "ansäuernderen": "ansäuernd",
    "ansäuernderer": "ansäuernd",
    "ansäuernderes": "ansäuernd",
    "ansäuerndes": "ansäuernd",
    "ansäuerndste": "ansäuernd",
    "ansäuerndstem": "ansäuernd",
    "ansäuerndsten": "ansäuernd",
    "ansäuerndster": "ansäuernd",
    "ansäuerndstes": "ansäuernd",
    "ansäuerst": "ansäuern",
    "ansäuert": "ansäuern",
    "ansäuerte": "ansäuern",
    "ansäuerten": "ansäuern",
    "ansäuertest": "ansäuern",
    "ansäuertet": "ansäuern",
    "ansäufst": "ansaufen",
    "ansäuft": "ansaufen",
    "ansäusele": "ansäuseln",
    "ansäuselnd": "ansäuseln",
    "ansäuselnde": "ansäuselnd",
    "ansäuselndem": "ansäuselnd",
    "ansäuselnden": "ansäuselnd",
    "ansäuselnder": "ansäuselnd",
    "ansäuselndere": "ansäuselnd",
    "ansäuselnderem": "ansäuselnd",
    "ansäuselnderen": "ansäuselnd",
    "ansäuselnderer": "ansäuselnd",
    "ansäuselnderes": "ansäuselnd",
    "ansäuselndes": "ansäuselnd",
    "ansäuselndste": "ansäuselnd",
    "ansäuselndstem": "ansäuselnd",
    "ansäuselndsten": "ansäuselnd",
    "ansäuselndster": "ansäuselnd",
    "ansäuselndstes": "ansäuselnd",
    "ansäuselst": "ansäuseln",
    "ansäuselt": "ansäuseln",
    "ansäuselte": "ansäuseln",
    "ansäuselten": "ansäuseln",
    "ansäuseltest": "ansäuseln",
    "ansäuseltet": "ansäuseln",
    "ansäusle": "ansäuseln",
    "ansäße": "ansitzen",
    "ansäßen": "ansitzen",
    "ansäßest": "ansitzen",
    "ansäßet": "ansitzen",
    "ansöffe": "ansaufen",
    "ansöffen": "ansaufen",
    "ansöffest": "ansaufen",
    "ansöffet": "ansaufen",
    "ansöge": "ansaugen",
    "ansögen": "ansaugen",
    "ansögest": "ansaugen",
    "ansöget": "ansaugen",
    "antanze": "antanzen",
    "antanzend": "antanzen",
    "antanzende": "antanzend",
    "antanzendem": "antanzend",
    "antanzenden": "antanzend",
    "antanzender": "antanzend",
    "antanzendes": "antanzend",
    "antanzest": "antanzen",
    "antanzet": "antanzen",
    "antanzt": "antanzen",
    "antanzte": "antanzen",
    "antanzten": "antanzen",
    "antanztest": "antanzen",
    "antanztet": "antanzen",
    "antarktische": "antarktisch",
    "antarktischem": "antarktisch",
    "antarktischen": "antarktisch",
    "antarktischer": "antarktisch",
    "antarktisches": "antarktisch",
    "antaste": "antasten",
    "antastend": "antasten",
    "antastende": "antastend",
    "antastendem": "antastend",
    "antastenden": "antastend",
    "antastender": "antastend",
    "antastendes": "antastend",
    "antastest": "antasten",
    "antastet": "antasten",
    "antastete": "antasten",
    "antasteten": "antasten",
    "antastetest": "antasten",
    "antastetet": "antasten",
    "anteiligem": "anteilig",
    "anteiligen": "anteilig",
    "anteiliger": "anteilig",
    "anteiliges": "anteilig",
    "anteste": "antesten",
    "antestend": "antesten",
    "antestende": "antestend",
    "antestendem": "antestend",
    "antestenden": "antestend",
    "antestender": "antestend",
    "antestendes": "antestend",
    "antestest": "antesten",
    "antestet": "antesten",
    "antestete": "antesten",
    "antesteten": "antesten",
    "antestetest": "antesten",
    "antestetet": "antesten",
    "anthropologischem": "anthropologisch",
    "anthropologischen": "anthropologisch",
    "anthropologischer": "anthropologisch",
    "anthropologisches": "anthropologisch",
    "antibakteriellem": "antibakteriell",
    "antibakteriellen": "antibakteriell",
    "antibakterieller": "antibakteriell",
    "antibakterielles": "antibakteriell",
    "antifaschistischem": "antifaschistisch",
    "antifaschistischen": "antifaschistisch",
    "antifaschistischer": "antifaschistisch",
    "antifaschistisches": "antifaschistisch",
    "antikem": "antik",
    "antiken": "antik",
    "antiker": "antik",
    "antikere": "antik",
    "antikerem": "antik",
    "antikeren": "antik",
    "antikerer": "antik",
    "antikeres": "antik",
    "antikes": "antik",
    "antikommunistischem": "antikommunistisch",
    "antikommunistischen": "antikommunistisch",
    "antikommunistischer": "antikommunistisch",
    "antikommunistisches": "antikommunistisch",
    "antikonzeptionelle": "antikonzeptionell",
    "antikonzeptionellem": "antikonzeptionell",
    "antikonzeptionellen": "antikonzeptionell",
    "antikonzeptioneller": "antikonzeptionell",
    "antikonzeptionelles": "antikonzeptionell",
    "antikstem": "antik",
    "antiksten": "antik",
    "antikster": "antik",
    "antikstes": "antik",
    "antimilitaristischem": "antimilitaristisch",
    "antimilitaristischen": "antimilitaristisch",
    "antimilitaristischer": "antimilitaristisch",
    "antimilitaristisches": "antimilitaristisch",
    "antippe": "antippen",
    "antippend": "antippen",
    "antippende": "antippend",
    "antippendem": "antippend",
    "antippenden": "antippend",
    "antippender": "antippend",
    "antippendes": "antippend",
    "antippest": "antippen",
    "antippet": "antippen",
    "antippst": "antippen",
    "antippt": "antippen",
    "antippte": "antippen",
    "antippten": "antippen",
    "antipptest": "antippen",
    "antipptet": "antippen",
    "antiquarischem": "antiquarisch",
    "antiquarischen": "antiquarisch",
    "antiquarischer": "antiquarisch",
    "antiquarischere": "antiquarisch",
    "antiquarischerem": "antiquarisch",
    "antiquarischeren": "antiquarisch",
    "antiquarischerer": "antiquarisch",
    "antiquarischeres": "antiquarisch",
    "antiquarisches": "antiquarisch",
    "antiquarischste": "antiquarisch",
    "antiquarischstem": "antiquarisch",
    "antiquarischsten": "antiquarisch",
    "antiquarischster": "antiquarisch",
    "antiquarischstes": "antiquarisch",
    "antiquierte": "antiquiert",
    "antiquiertem": "antiquiert",
    "antiquierten": "antiquiert",
    "antiquierter": "antiquiert",
    "antiquiertere": "antiquiert",
    "antiquierterem": "antiquiert",
    "antiquierteren": "antiquiert",
    "antiquierterer": "antiquiert",
    "antiquierteres": "antiquiert",
    "antiquiertes": "antiquiert",
    "antiquierteste": "antiquiert",
    "antiquiertestem": "antiquiert",
    "antiquiertesten": "antiquiert",
    "antiquiertester": "antiquiert",
    "antiquiertestes": "antiquiert",
    "antisemitischem": "antisemitisch",
    "antisemitischen": "antisemitisch",
    "antisemitischer": "antisemitisch",
    "antisemitisches": "antisemitisch",
    "antiseptische": "antiseptisch",
    "antiseptischem": "antiseptisch",
    "antiseptischen": "antiseptisch",
    "antiseptischer": "antiseptisch",
    "antiseptisches": "antiseptisch",
    "antistatische": "antistatisch",
    "antistatischem": "antistatisch",
    "antistatischen": "antistatisch",
    "antistatischer": "antistatisch",
    "antistatisches": "antistatisch",
    "antizipiere": "antizipieren",
    "antizipierend": "antizipieren",
    "antizipierende": "antizipierend",
    "antizipierendem": "antizipierend",
    "antizipierenden": "antizipierend",
    "antizipierender": "antizipierend",
    "antizipierendere": "antizipierend",
    "antizipierenderem": "antizipierend",
    "antizipierenderen": "antizipierend",
    "antizipierenderer": "antizipierend",
    "antizipierenderes": "antizipierend",
    "antizipierendes": "antizipierend",
    "antizipierendste": "antizipierend",
    "antizipierendstem": "antizipierend",
    "antizipierendsten": "antizipierend",
    "antizipierendster": "antizipierend",
    "antizipierendstes": "antizipierend",
    "antizipierest": "antizipieren",
    "antizipieret": "antizipieren",
    "antizipierst": "antizipieren",
    "antizipiert": "antizipieren",
    "antizipierte": "antizipieren",
    "antizipiertem": "antizipiert",
    "antizipierten": "antizipieren",
    "antizipierter": "antizipiert",
    "antizipiertes": "antizipiert",
    "antizipiertest": "antizipieren",
    "antizipiertet": "antizipieren",
    "antrabe": "antraben",
    "antrabend": "antraben",
    "antrabende": "antrabend",
    "antrabendem": "antrabend",
    "antrabenden": "antrabend",
    "antrabender": "antrabend",
    "antrabendes": "antrabend",
    "antrabest": "antraben",
    "antrabet": "antraben",
    "antrabst": "antraben",
    "antrabt": "antraben",
    "antrabte": "antraben",
    "antrabten": "antraben",
    "antrabtest": "antraben",
    "antrabtet": "antraben",
    "antraf": "antreffen",
    "antrafen": "antreffen",
    "antrafst": "antreffen",
    "antraft": "antreffen",
    "antragend": "antragen",
    "antragende": "antragend",
    "antragendem": "antragend",
    "antragenden": "antragend",
    "antragender": "antragend",
    "antragendes": "antragend",
    "antragest": "antragen",
    "antraget": "antragen",
    "antragt": "antragen",
    "antrank": "antrinken",
    "antranken": "antrinken",
    "antrankst": "antrinken",
    "antrankt": "antrinken",
    "antrat": "antreten",
    "antraten": "antreten",
    "antratest": "antreten",
    "antratet": "antreten",
    "antraue": "antrauen",
    "antrauend": "antrauen",
    "antrauende": "antrauend",
    "antrauendem": "antrauend",
    "antrauenden": "antrauend",
    "antrauender": "antrauend",
    "antrauendes": "antrauend",
    "antrauest": "antrauen",
    "antrauet": "antrauen",
    "antraust": "antrauen",
    "antraut": "antrauen",
    "antraute": "antrauen",
    "antrauten": "antrauen",
    "antrautest": "antrauen",
    "antrautet": "antrauen",
    "antreffe": "antreffen",
    "antreffend": "antreffen",
    "antreffende": "antreffend",
    "antreffendem": "antreffend",
    "antreffenden": "antreffend",
    "antreffender": "antreffend",
    "antreffendes": "antreffend",
    "antreffest": "antreffen",
    "antreffet": "antreffen",
    "antrefft": "antreffen",
    "antreibe": "antreiben",
    "antreibend": "antreiben",
    "antreibende": "antreibend",
    "antreibendem": "antreibend",
    "antreibenden": "antreibend",
    "antreibender": "antreibend",
    "antreibendes": "antreibend",
    "antreibest": "antreiben",
    "antreibet": "antreiben",
    "antreibst": "antreiben",
    "antreibt": "antreiben",
    "antrete": "antreten",
    "antretend": "antreten",
    "antretende": "antretend",
    "antretendem": "antretend",
    "antretenden": "antretend",
    "antretender": "antretend",
    "antretendes": "antretend",
    "antretest": "antreten",
    "antretet": "antreten",
    "antrieb": "antreiben",
    "antriebest": "antreiben",
    "antriebet": "antreiben",
    "antriebst": "antreiben",
    "antriebt": "antreiben",
    "antriffst": "antreffen",
    "antrifft": "antreffen",
    "antrinke": "antrinken",
    "antrinkend": "antrinken",
    "antrinkende": "antrinkend",
    "antrinkendem": "antrinkend",
    "antrinkenden": "antrinkend",
    "antrinkender": "antrinkend",
    "antrinkendere": "antrinkend",
    "antrinkenderem": "antrinkend",
    "antrinkenderen": "antrinkend",
    "antrinkenderer": "antrinkend",
    "antrinkenderes": "antrinkend",
    "antrinkendes": "antrinkend",
    "antrinkendste": "antrinkend",
    "antrinkendstem": "antrinkend",
    "antrinkendsten": "antrinkend",
    "antrinkendster": "antrinkend",
    "antrinkendstes": "antrinkend",
    "antrinkest": "antrinken",
    "antrinket": "antrinken",
    "antrinkst": "antrinken",
    "antrinkt": "antrinken",
    "antritt": "antreten",
    "antrittst": "antreten",
    "antrug": "antragen",
    "antrugen": "antragen",
    "antrugst": "antragen",
    "antrugt": "antragen",
    "anträfe": "antreffen",
    "anträfen": "antreffen",
    "anträfest": "antreffen",
    "anträfet": "antreffen",
    "anträgst": "antragen",
    "anträgt": "antragen",
    "antränke": "antrinken",
    "antränken": "antrinken",
    "antränkest": "antrinken",
    "antränket": "antrinken",
    "anträte": "antreten",
    "anträten": "antreten",
    "anträtest": "antreten",
    "anträtet": "antreten",
    "antrüge": "antragen",
    "antrügen": "antragen",
    "antrügest": "antragen",
    "antrüget": "antragen",
    "antworte": "antworten",
    "antwortend": "antworten",
    "antwortende": "antwortend",
    "antwortendem": "antwortend",
    "antwortenden": "antwortend",
    "antwortender": "antwortend",
    "antwortendere": "antwortend",
    "antwortenderem": "antwortend",
    "antwortenderen": "antwortend",
    "antwortenderer": "antwortend",
    "antwortenderes": "antwortend",
    "antwortendes": "antwortend",
    "antwortendste": "antwortend",
    "antwortendstem": "antwortend",
    "antwortendsten": "antwortend",
    "antwortendster": "antwortend",
    "antwortendstes": "antwortend",
    "antwortest": "antworten",
    "antwortet": "antworten",
    "antwortete": "antworten",
    "antworteten": "antworten",
    "antwortetest": "antworten",
    "antwortetet": "antworten",
    "antöne": "antönen",
    "antönend": "antönen",
    "antönende": "antönend",
    "antönendem": "antönend",
    "antönenden": "antönend",
    "antönender": "antönend",
    "antönendes": "antönend",
    "antönest": "antönen",
    "antönet": "antönen",
    "antönst": "antönen",
    "antönt": "antönen",
    "antönte": "antönen",
    "antönten": "antönen",
    "antöntest": "antönen",
    "antöntet": "antönen",
    "antörne": "antörnen",
    "antörnend": "antörnen",
    "antörnende": "antörnend",
    "antörnendem": "antörnend",
    "antörnenden": "antörnend",
    "antörnender": "antörnend",
    "antörnendere": "antörnend",
    "antörnenderem": "antörnend",
    "antörnenderen": "antörnend",
    "antörnenderer": "antörnend",
    "antörnenderes": "antörnend",
    "antörnendes": "antörnend",
    "antörnendste": "antörnend",
    "antörnendstem": "antörnend",
    "antörnendsten": "antörnend",
    "antörnendster": "antörnend",
    "antörnendstes": "antörnend",
    "antörnest": "antörnen",
    "antörnet": "antörnen",
    "antörnst": "antörnen",
    "antörnt": "antörnen",
    "antörnte": "antörnen",
    "antörnten": "antörnen",
    "antörntest": "antörnen",
    "antörntet": "antörnen",
    "anvertraue": "anvertrauen",
    "anvertrauend": "anvertrauen",
    "anvertrauende": "anvertrauend",
    "anvertrauendem": "anvertrauend",
    "anvertrauenden": "anvertrauend",
    "anvertrauender": "anvertrauend",
    "anvertrauendes": "anvertrauend",
    "anvertrauest": "anvertrauen",
    "anvertrauet": "anvertrauen",
    "anvertraust": "anvertrauen",
    "anvertraut": "anvertrauen",
    "anvertraute": "anvertrauen",
    "anvertrautem": "anvertraut",
    "anvertrauten": "anvertrauen",
    "anvertrauter": "anvertraut",
    "anvertrautes": "anvertraut",
    "anvertrautest": "anvertrauen",
    "anvertrautet": "anvertrauen",
    "anverwandte": "anverwandt",
    "anverwandtem": "anverwandt",
    "anverwandten": "anverwandt",
    "anverwandter": "anverwandt",
    "anverwandtes": "anverwandt",
    "anwachse": "anwachsen",
    "anwachsend": "anwachsen",
    "anwachsende": "anwachsend",
    "anwachsendem": "anwachsend",
    "anwachsenden": "anwachsend",
    "anwachsender": "anwachsend",
    "anwachsendes": "anwachsend",
    "anwachsest": "anwachsen",
    "anwachset": "anwachsen",
    "anwachst": "anwachsen",
    "anwachste": "anwachsen",
    "anwachsten": "anwachsen",
    "anwachstest": "anwachsen",
    "anwachstet": "anwachsen",
    "anwandele": "anwandeln",
    "anwandelnd": "anwandeln",
    "anwandelnde": "anwandelnd",
    "anwandelndem": "anwandelnd",
    "anwandelnden": "anwandelnd",
    "anwandelnder": "anwandelnd",
    "anwandelndes": "anwandelnd",
    "anwandelst": "anwandeln",
    "anwandelt": "anwandeln",
    "anwandelte": "anwandeln",
    "anwandelten": "anwandeln",
    "anwandeltest": "anwandeln",
    "anwandeltet": "anwandeln",
    "anwandle": "anwandeln",
    "anwandte": "anwenden",
    "anwandten": "anwenden",
    "anwandtest": "anwenden",
    "anwandtet": "anwenden",
    "anwarb": "anwerben",
    "anwarben": "anwerben",
    "anwarbst": "anwerben",
    "anwarbt": "anwerben",
    "anwarf": "anwerfen",
    "anwarfen": "anwerfen",
    "anwarfst": "anwerfen",
    "anwarft": "anwerfen",
    "anwehe": "anwehen",
    "anwehend": "anwehen",
    "anwehende": "anwehend",
    "anwehendem": "anwehend",
    "anwehenden": "anwehend",
    "anwehender": "anwehend",
    "anwehendes": "anwehend",
    "anwehest": "anwehen",
    "anwehet": "anwehen",
    "anwehst": "anwehen",
    "anweht": "anwehen",
    "anwehte": "anwehen",
    "anwehten": "anwehen",
    "anwehtest": "anwehen",
    "anwehtet": "anwehen",
    "anweise": "anweisen",
    "anweisend": "anweisen",
    "anweisende": "anweisend",
    "anweisendem": "anweisend",
    "anweisenden": "anweisend",
    "anweisender": "anweisend",
    "anweisendes": "anweisend",
    "anweisest": "anweisen",
    "anweiset": "anweisen",
    "anweist": "anweisen",
    "anwendbarem": "anwendbar",
    "anwendbaren": "anwendbar",
    "anwendbarer": "anwendbar",
    "anwendbarere": "anwendbar",
    "anwendbarerem": "anwendbar",
    "anwendbareren": "anwendbar",
    "anwendbarerer": "anwendbar",
    "anwendbareres": "anwendbar",
    "anwendbares": "anwendbar",
    "anwendbarste": "anwendbar",
    "anwendbarstem": "anwendbar",
    "anwendbarsten": "anwendbar",
    "anwendbarster": "anwendbar",
    "anwendbarstes": "anwendbar",
    "anwende": "anwenden",
    "anwendend": "anwenden",
    "anwendende": "anwendend",
    "anwendendem": "anwendend",
    "anwendenden": "anwendend",
    "anwendender": "anwendend",
    "anwendendes": "anwendend",
    "anwendest": "anwenden",
    "anwendet": "anwenden",
    "anwendete": "anwenden",
    "anwendeten": "anwenden",
    "anwendetest": "anwenden",
    "anwendetet": "anwenden",
    "anwerbe": "anwerben",
    "anwerbend": "anwerben",
    "anwerbende": "anwerbend",
    "anwerbendem": "anwerbend",
    "anwerbenden": "anwerbend",
    "anwerbender": "anwerbend",
    "anwerbendes": "anwerbend",
    "anwerbest": "anwerben",
    "anwerbet": "anwerben",
    "anwerbt": "anwerben",
    "anwerfe": "anwerfen",
    "anwerfend": "anwerfen",
    "anwerfende": "anwerfend",
    "anwerfendem": "anwerfend",
    "anwerfenden": "anwerfend",
    "anwerfender": "anwerfend",
    "anwerfendes": "anwerfend",
    "anwerfest": "anwerfen",
    "anwerfet": "anwerfen",
    "anwerft": "anwerfen",
    "anwesende": "anwesend",
    "anwesendem": "anwesend",
    "anwesenden": "anwesend",
    "anwesender": "anwesend",
    "anwesendes": "anwesend",
    "anwidere": "anwidern",
    "anwidernd": "anwidern",
    "anwidernde": "anwidernd",
    "anwiderndem": "anwidernd",
    "anwidernden": "anwidernd",
    "anwidernder": "anwidernd",
    "anwiderndere": "anwidernd",
    "anwidernderem": "anwidernd",
    "anwidernderen": "anwidernd",
    "anwidernderer": "anwidernd",
    "anwidernderes": "anwidernd",
    "anwiderndes": "anwidernd",
    "anwiderndste": "anwidernd",
    "anwiderndstem": "anwidernd",
    "anwiderndsten": "anwidernd",
    "anwiderndster": "anwidernd",
    "anwiderndstes": "anwidernd",
    "anwiderst": "anwidern",
    "anwidert": "anwidern",
    "anwiderte": "anwidern",
    "anwiderten": "anwidern",
    "anwidertest": "anwidern",
    "anwidertet": "anwidern",
    "anwies": "anweisen",
    "anwiese": "anweisen",
    "anwiesen": "anweisen",
    "anwiesest": "anweisen",
    "anwieset": "anweisen",
    "anwiest": "anweisen",
    "anwinkele": "anwinkeln",
    "anwinkelnd": "anwinkeln",
    "anwinkelnde": "anwinkelnd",
    "anwinkelndem": "anwinkelnd",
    "anwinkelnden": "anwinkelnd",
    "anwinkelnder": "anwinkelnd",
    "anwinkelndes": "anwinkelnd",
    "anwinkelst": "anwinkeln",
    "anwinkelt": "anwinkeln",
    "anwinkelte": "anwinkeln",
    "anwinkelten": "anwinkeln",
    "anwinkeltest": "anwinkeln",
    "anwinkeltet": "anwinkeln",
    "anwinkle": "anwinkeln",
    "anwirbst": "anwerben",
    "anwirbt": "anwerben",
    "anwirfst": "anwerfen",
    "anwirft": "anwerfen",
    "anwohne": "anwohnen",
    "anwohnend": "anwohnen",
    "anwohnende": "anwohnend",
    "anwohnendem": "anwohnend",
    "anwohnenden": "anwohnend",
    "anwohnender": "anwohnend",
    "anwohnendes": "anwohnend",
    "anwohnest": "anwohnen",
    "anwohnet": "anwohnen",
    "anwohnst": "anwohnen",
    "anwohnt": "anwohnen",
    "anwohnte": "anwohnen",
    "anwohnten": "anwohnen",
    "anwohntest": "anwohnen",
    "anwohntet": "anwohnen",
    "anwuchs": "anwachsen",
    "anwuchsen": "anwachsen",
    "anwuchst": "anwachsen",
    "anwurzele": "anwurzeln",
    "anwurzelnd": "anwurzeln",
    "anwurzelnde": "anwurzelnd",
    "anwurzelndem": "anwurzelnd",
    "anwurzelnden": "anwurzelnd",
    "anwurzelnder": "anwurzelnd",
    "anwurzelndes": "anwurzelnd",
    "anwurzelst": "anwurzeln",
    "anwurzelt": "anwurzeln",
    "anwurzelte": "anwurzeln",
    "anwurzelten": "anwurzeln",
    "anwurzeltest": "anwurzeln",
    "anwurzeltet": "anwurzeln",
    "anwurzle": "anwurzeln",
    "anwächst": "anwachsen",
    "anwähle": "anwählen",
    "anwählend": "anwählen",
    "anwählende": "anwählend",
    "anwählendem": "anwählend",
    "anwählenden": "anwählend",
    "anwählender": "anwählend",
    "anwählendes": "anwählend",
    "anwählest": "anwählen",
    "anwählet": "anwählen",
    "anwählst": "anwählen",
    "anwählt": "anwählen",
    "anwählte": "anwählen",
    "anwählten": "anwählen",
    "anwähltest": "anwählen",
    "anwähltet": "anwählen",
    "anwärbe": "anwerben",
    "anwärben": "anwerben",
    "anwärbest": "anwerben",
    "anwärbet": "anwerben",
    "anwärfe": "anwerfen",
    "anwärfen": "anwerfen",
    "anwärfest": "anwerfen",
    "anwärfet": "anwerfen",
    "anwärme": "anwärmen",
    "anwärmend": "anwärmen",
    "anwärmende": "anwärmend",
    "anwärmendem": "anwärmend",
    "anwärmenden": "anwärmend",
    "anwärmender": "anwärmend",
    "anwärmendes": "anwärmend",
    "anwärmest": "anwärmen",
    "anwärmet": "anwärmen",
    "anwärmst": "anwärmen",
    "anwärmt": "anwärmen",
    "anwärmte": "anwärmen",
    "anwärmten": "anwärmen",
    "anwärmtest": "anwärmen",
    "anwärmtet": "anwärmen",
    "anwüchse": "anwachsen",
    "anwüchsen": "anwachsen",
    "anwüchsest": "anwachsen",
    "anwüchset": "anwachsen",
    "anzahle": "anzahlen",
    "anzahlend": "anzahlen",
    "anzahlende": "anzahlend",
    "anzahlendem": "anzahlend",
    "anzahlenden": "anzahlend",
    "anzahlender": "anzahlend",
    "anzahlendes": "anzahlend",
    "anzahlest": "anzahlen",
    "anzahlet": "anzahlen",
    "anzahlst": "anzahlen",
    "anzahlt": "anzahlen",
    "anzahlte": "anzahlen",
    "anzahlten": "anzahlen",
    "anzahltest": "anzahlen",
    "anzahltet": "anzahlen",
    "anzapfe": "anzapfen",
    "anzapfend": "anzapfen",
    "anzapfende": "anzapfend",
    "anzapfendem": "anzapfend",
    "anzapfenden": "anzapfend",
    "anzapfender": "anzapfend",
    "anzapfendes": "anzapfend",
    "anzapfest": "anzapfen",
    "anzapfet": "anzapfen",
    "anzapfst": "anzapfen",
    "anzapft": "anzapfen",
    "anzapfte": "anzapfen",
    "anzapften": "anzapfen",
    "anzapftest": "anzapfen",
    "anzapftet": "anzapfen",
    "anzaubere": "anzaubern",
    "anzaubernd": "anzaubern",
    "anzaubernde": "anzaubernd",
    "anzauberndem": "anzaubernd",
    "anzaubernden": "anzaubernd",
    "anzaubernder": "anzaubernd",
    "anzauberndes": "anzaubernd",
    "anzauberst": "anzaubern",
    "anzaubert": "anzaubern",
    "anzauberte": "anzaubern",
    "anzauberten": "anzaubern",
    "anzaubertest": "anzaubern",
    "anzaubertet": "anzaubern",
    "anzeichne": "anzeichnen",
    "anzeichnend": "anzeichnen",
    "anzeichnende": "anzeichnend",
    "anzeichnendem": "anzeichnend",
    "anzeichnenden": "anzeichnend",
    "anzeichnender": "anzeichnend",
    "anzeichnendes": "anzeichnend",
    "anzeichnest": "anzeichnen",
    "anzeichnet": "anzeichnen",
    "anzeichnete": "anzeichnen",
    "anzeichneten": "anzeichnen",
    "anzeichnetest": "anzeichnen",
    "anzeichnetet": "anzeichnen",
    "anzeige": "anzeigen",
    "anzeigend": "anzeigen",
    "anzeigende": "anzeigend",
    "anzeigendem": "anzeigend",
    "anzeigenden": "anzeigend",
    "anzeigender": "anzeigend",
    "anzeigendes": "anzeigend",
    "anzeigest": "anzeigen",
    "anzeiget": "anzeigen",
    "anzeigst": "anzeigen",
    "anzeigt": "anzeigen",
    "anzeigte": "anzeigen",
    "anzeigten": "anzeigen",
    "anzeigtest": "anzeigen",
    "anzeigtet": "anzeigen",
    "anzettele": "anzetteln",
    "anzettelnd": "anzetteln",
    "anzettelnde": "anzettelnd",
    "anzettelndem": "anzettelnd",
    "anzettelnden": "anzettelnd",
    "anzettelnder": "anzettelnd",
    "anzettelndes": "anzettelnd",
    "anzettelst": "anzetteln",
    "anzettelt": "anzetteln",
    "anzettelte": "anzetteln",
    "anzettelten": "anzetteln",
    "anzetteltest": "anzetteln",
    "anzetteltet": "anzetteln",
    "anzettle": "anzetteln",
    "anziehe": "anziehen",
    "anziehend": "anziehen",
    "anziehende": "anziehend",
    "anziehendem": "anziehend",
    "anziehenden": "anziehend",
    "anziehender": "anziehend",
    "anziehendere": "anziehend",
    "anziehenderem": "anziehend",
    "anziehenderen": "anziehend",
    "anziehenderer": "anziehend",
    "anziehenderes": "anziehend",
    "anziehendes": "anziehend",
    "anziehendste": "anziehend",
    "anziehendstem": "anziehend",
    "anziehendsten": "anziehend",
    "anziehendster": "anziehend",
    "anziehendstes": "anziehend",
    "anziehest": "anziehen",
    "anziehet": "anziehen",
    "anziehst": "anziehen",
    "anzieht": "anziehen",
    "anzog": "anziehen",
    "anzogen": "anziehen",
    "anzogst": "anziehen",
    "anzogt": "anziehen",
    "anzubacken": "anbacken",
    "anzubaggern": "anbaggern",
    "anzubahnen": "anbahnen",
    "anzubandeln": "anbandeln",
    "anzubauen": "anbauen",
    "anzubehalten": "anbehalten",
    "anzubeißen": "anbeißen",
    "anzubelangen": "anbelangen",
    "anzubequemen": "anbequemen",
    "anzuberaumen": "anberaumen",
    "anzubeten": "anbeten",
    "anzubetreffen": "anbetreffen",
    "anzubetteln": "anbetteln",
    "anzubiedern": "anbiedern",
    "anzubieten": "anbieten",
    "anzubinden": "anbinden",
    "anzublaffen": "anblaffen",
    "anzublasen": "anblasen",
    "anzublicken": "anblicken",
    "anzublinzeln": "anblinzeln",
    "anzublitzen": "anblitzen",
    "anzubohren": "anbohren",
    "anzubraten": "anbraten",
    "anzubrechen": "anbrechen",
    "anzubremsen": "anbremsen",
    "anzubrennen": "anbrennen",
    "anzubringen": "anbringen",
    "anzubrummen": "anbrummen",
    "anzubrüllen": "anbrüllen",
    "anzubrüten": "anbrüten",
    "anzudauern": "andauern",
    "anzudenken": "andenken",
    "anzudeuten": "andeuten",
    "anzudichten": "andichten",
    "anzudienen": "andienen",
    "anzudiskutieren": "andiskutieren",
    "anzudrehen": "andrehen",
    "anzudringen": "andringen",
    "anzudrohen": "androhen",
    "anzudrängen": "andrängen",
    "anzueignen": "aneignen",
    "anzuekeln": "anekeln",
    "anzuerkennen": "anerkennen",
    "anzuerziehen": "anerziehen",
    "anzufachen": "anfachen",
    "anzufahren": "anfahren",
    "anzufallen": "anfallen",
    "anzufangen": "anfangen",
    "anzufassen": "anfassen",
    "anzufauchen": "anfauchen",
    "anzufaulen": "anfaulen",
    "anzufaxen": "anfaxen",
    "anzufechten": "anfechten",
    "anzufeinden": "anfeinden",
    "anzufertigen": "anfertigen",
    "anzufeuchten": "anfeuchten",
    "anzufeuern": "anfeuern",
    "anzufinden": "anfinden",
    "anzufixen": "anfixen",
    "anzuflehen": "anflehen",
    "anzufliegen": "anfliegen",
    "anzufordern": "anfordern",
    "anzufragen": "anfragen",
    "anzufressen": "anfressen",
    "anzufreunden": "anfreunden",
    "anzufrieren": "anfrieren",
    "anzufunkeln": "anfunkeln",
    "anzufunken": "anfunken",
    "anzufügen": "anfügen",
    "anzufühlen": "anfühlen",
    "anzuführen": "anführen",
    "anzufüllen": "anfüllen",
    "anzugaffen": "angaffen",
    "anzugaloppieren": "angaloppieren",
    "anzugeben": "angeben",
    "anzugehen": "angehen",
    "anzugehören": "angehören",
    "anzugewöhnen": "angewöhnen",
    "anzugießen": "angießen",
    "anzugiften": "angiften",
    "anzugleichen": "angleichen",
    "anzugliedern": "angliedern",
    "anzuglotzen": "anglotzen",
    "anzugreifen": "angreifen",
    "anzugrenzen": "angrenzen",
    "anzugrinsen": "angrinsen",
    "anzugurten": "angurten",
    "anzuhaften": "anhaften",
    "anzuhaken": "anhaken",
    "anzuhalftern": "anhalftern",
    "anzuhalten": "anhalten",
    "anzuhauchen": "anhauchen",
    "anzuhauen": "anhauen",
    "anzuheben": "anheben",
    "anzuheften": "anheften",
    "anzuheimeln": "anheimeln",
    "anzuheizen": "anheizen",
    "anzuheuern": "anheuern",
    "anzuhimmeln": "anhimmeln",
    "anzuholen": "anholen",
    "anzuhängen": "anhängen",
    "anzuhärten": "anhärten",
    "anzuhören": "anhören",
    "anzujagen": "anjagen",
    "anzukaufen": "ankaufen",
    "anzukeilen": "ankeilen",
    "anzuketten": "anketten",
    "anzuklagen": "anklagen",
    "anzuklammern": "anklammern",
    "anzukleben": "ankleben",
    "anzukleiden": "ankleiden",
    "anzuklingeln": "anklingeln",
    "anzuklingen": "anklingen",
    "anzuklopfen": "anklopfen",
    "anzuknabbern": "anknabbern",
    "anzuknacksen": "anknacksen",
    "anzuknipsen": "anknipsen",
    "anzuknöpfen": "anknöpfen",
    "anzuknüpfen": "anknüpfen",
    "anzukohlen": "ankohlen",
    "anzukommen": "ankommen",
    "anzukoppeln": "ankoppeln",
    "anzukotzen": "ankotzen",
    "anzukrallen": "ankrallen",
    "anzukreiden": "ankreiden",
    "anzukreuzen": "ankreuzen",
    "anzukuppeln": "ankuppeln",
    "anzukurbeln": "ankurbeln",
    "anzukämpfen": "ankämpfen",
    "anzuködern": "anködern",
    "anzukündigen": "ankündigen",
    "anzulachen": "anlachen",
    "anzulagern": "anlagern",
    "anzulassen": "anlassen",
    "anzulasten": "anlasten",
    "anzulaufen": "anlaufen",
    "anzulauten": "anlauten",
    "anzulegen": "anlegen",
    "anzulehnen": "anlehnen",
    "anzuleimen": "anleimen",
    "anzuleinen": "anleinen",
    "anzuleiten": "anleiten",
    "anzulernen": "anlernen",
    "anzulesen": "anlesen",
    "anzuleuchten": "anleuchten",
    "anzuliefern": "anliefern",
    "anzuliegen": "anliegen",
    "anzulächeln": "anlächeln",
    "anzuläuten": "anläuten",
    "anzulöten": "anlöten",
    "anzulügen": "anlügen",
    "anzumachen": "anmachen",
    "anzumahnen": "anmahnen",
    "anzumalen": "anmalen",
    "anzumarschieren": "anmarschieren",
    "anzumaßen": "anmaßen",
    "anzumelden": "anmelden",
    "anzumerken": "anmerken",
    "anzumessen": "anmessen",
    "anzumieten": "anmieten",
    "anzumotzen": "anmotzen",
    "anzumustern": "anmustern",
    "anzumuten": "anmuten",
    "anzunageln": "annageln",
    "anzunagen": "annagen",
    "anzunehmen": "annehmen",
    "anzunieten": "annieten",
    "anzunähen": "annähen",
    "anzunähern": "annähern",
    "anzuordnen": "anordnen",
    "anzupacken": "anpacken",
    "anzupaddeln": "anpaddeln",
    "anzupassen": "anpassen",
    "anzupeilen": "anpeilen",
    "anzupfeifen": "anpfeifen",
    "anzupflanzen": "anpflanzen",
    "anzupflaumen": "anpflaumen",
    "anzupirschen": "anpirschen",
    "anzuprallen": "anprallen",
    "anzuprangern": "anprangern",
    "anzupreisen": "anpreisen",
    "anzupressen": "anpressen",
    "anzuprobieren": "anprobieren",
    "anzupumpen": "anpumpen",
    "anzuputzen": "anputzen",
    "anzupöbeln": "anpöbeln",
    "anzuquälen": "anquälen",
    "anzuranzen": "anranzen",
    "anzuraten": "anraten",
    "anzurauhen": "anrauhen",
    "anzurechnen": "anrechnen",
    "anzureden": "anreden",
    "anzuregen": "anregen",
    "anzureiben": "anreiben",
    "anzureichen": "anreichen",
    "anzureichern": "anreichern",
    "anzureihen": "anreihen",
    "anzureisen": "anreisen",
    "anzureiten": "anreiten",
    "anzureizen": "anreizen",
    "anzureißen": "anreißen",
    "anzurempeln": "anrempeln",
    "anzurennen": "anrennen",
    "anzurichten": "anrichten",
    "anzurollen": "anrollen",
    "anzurudern": "anrudern",
    "anzurufen": "anrufen",
    "anzurücken": "anrücken",
    "anzurühren": "anrühren",
    "anzusagen": "ansagen",
    "anzusamen": "ansamen",
    "anzusammeln": "ansammeln",
    "anzusaufen": "ansaufen",
    "anzusaugen": "ansaugen",
    "anzuschaffen": "anschaffen",
    "anzuschalten": "anschalten",
    "anzuschauen": "anschauen",
    "anzuscheinen": "anscheinen",
    "anzuscheißen": "anscheißen",
    "anzuschieben": "anschieben",
    "anzuschießen": "anschießen",
    "anzuschiffen": "anschiffen",
    "anzuschirren": "anschirren",
    "anzuschlagen": "anschlagen",
    "anzuschleichen": "anschleichen",
    "anzuschleifen": "anschleifen",
    "anzuschließen": "anschließen",
    "anzuschlämmen": "anschlämmen",
    "anzuschmeißen": "anschmeißen",
    "anzuschmiegen": "anschmiegen",
    "anzuschmieren": "anschmieren",
    "anzuschnallen": "anschnallen",
    "anzuschnauzen": "anschnauzen",
    "anzuschneiden": "anschneiden",
    "anzuschrauben": "anschrauben",
    "anzuschreiben": "anschreiben",
    "anzuschreien": "anschreien",
    "anzuschrägen": "anschrägen",
    "anzuschweigen": "anschweigen",
    "anzuschweißen": "anschweißen",
    "anzuschwellen": "anschwellen",
    "anzuschwemmen": "anschwemmen",
    "anzuschwimmen": "anschwimmen",
    "anzuschwindeln": "anschwindeln",
    "anzuschwärzen": "anschwärzen",
    "anzusehen": "ansehen",
    "anzuseilen": "anseilen",
    "anzusengen": "ansengen",
    "anzusetzen": "ansetzen",
    "anzusiedeln": "ansiedeln",
    "anzusingen": "ansingen",
    "anzusitzen": "ansitzen",
    "anzusohlen": "ansohlen",
    "anzuspannen": "anspannen",
    "anzusparen": "ansparen",
    "anzuspeien": "anspeien",
    "anzuspielen": "anspielen",
    "anzuspitzen": "anspitzen",
    "anzuspornen": "anspornen",
    "anzusprechen": "ansprechen",
    "anzusprengen": "ansprengen",
    "anzuspringen": "anspringen",
    "anzuspritzen": "anspritzen",
    "anzusprühen": "ansprühen",
    "anzuspülen": "anspülen",
    "anzustacheln": "anstacheln",
    "anzustammen": "anstammen",
    "anzustarren": "anstarren",
    "anzustauben": "anstauben",
    "anzustauen": "anstauen",
    "anzustechen": "anstechen",
    "anzustecken": "anstecken",
    "anzustehen": "anstehen",
    "anzusteigen": "ansteigen",
    "anzustellen": "anstellen",
    "anzustemmen": "anstemmen",
    "anzustiften": "anstiften",
    "anzustimmen": "anstimmen",
    "anzustinken": "anstinken",
    "anzustoßen": "anstoßen",
    "anzustrahlen": "anstrahlen",
    "anzustreben": "anstreben",
    "anzustreichen": "anstreichen",
    "anzustrengen": "anstrengen",
    "anzustürmen": "anstürmen",
    "anzusuchen": "ansuchen",
    "anzusäen": "ansäen",
    "anzusägen": "ansägen",
    "anzusäuern": "ansäuern",
    "anzusäuseln": "ansäuseln",
    "anzutanzen": "antanzen",
    "anzutasten": "antasten",
    "anzutesten": "antesten",
    "anzutippen": "antippen",
    "anzutraben": "antraben",
    "anzutragen": "antragen",
    "anzutrauen": "antrauen",
    "anzutreffen": "antreffen",
    "anzutreiben": "antreiben",
    "anzutreten": "antreten",
    "anzutrinken": "antrinken",
    "anzutönen": "antönen",
    "anzutörnen": "antörnen",
    "anzuvertrauen": "anvertrauen",
    "anzuwachsen": "anwachsen",
    "anzuwandeln": "anwandeln",
    "anzuwehen": "anwehen",
    "anzuweisen": "anweisen",
    "anzuwenden": "anwenden",
    "anzuwerben": "anwerben",
    "anzuwerfen": "anwerfen",
    "anzuwidern": "anwidern",
    "anzuwinkeln": "anwinkeln",
    "anzuwohnen": "anwohnen",
    "anzuwurzeln": "anwurzeln",
    "anzuwählen": "anwählen",
    "anzuwärmen": "anwärmen",
    "anzuzahlen": "anzahlen",
    "anzuzapfen": "anzapfen",
    "anzuzaubern": "anzaubern",
    "anzuzeichnen": "anzeichnen",
    "anzuzeigen": "anzeigen",
    "anzuzetteln": "anzetteln",
    "anzuziehen": "anziehen",
    "anzuzweifeln": "anzweifeln",
    "anzuzählen": "anzählen",
    "anzuzünden": "anzünden",
    "anzuöden": "anöden",
    "anzweifele": "anzweifeln",
    "anzweifelnd": "anzweifeln",
    "anzweifelnde": "anzweifelnd",
    "anzweifelndem": "anzweifelnd",
    "anzweifelnden": "anzweifelnd",
    "anzweifelnder": "anzweifelnd",
    "anzweifelndere": "anzweifelnd",
    "anzweifelnderem": "anzweifelnd",
    "anzweifelnderen": "anzweifelnd",
    "anzweifelnderer": "anzweifelnd",
    "anzweifelnderes": "anzweifelnd",
    "anzweifelndes": "anzweifelnd",
    "anzweifelndste": "anzweifelnd",
    "anzweifelndstem": "anzweifelnd",
    "anzweifelndsten": "anzweifelnd",
    "anzweifelndster": "anzweifelnd",
    "anzweifelndstes": "anzweifelnd",
    "anzweifelst": "anzweifeln",
    "anzweifelt": "anzweifeln",
    "anzweifelte": "anzweifeln",
    "anzweifelten": "anzweifeln",
    "anzweifeltest": "anzweifeln",
    "anzweifeltet": "anzweifeln",
    "anzweifle": "anzweifeln",
    "anzähle": "anzählen",
    "anzählend": "anzählen",
    "anzählendem": "anzählend",
    "anzählender": "anzählend",
    "anzählendere": "anzählend",
    "anzählenderem": "anzählend",
    "anzählenderen": "anzählend",
    "anzählenderer": "anzählend",
    "anzählenderes": "anzählend",
    "anzählendes": "anzählend",
    "anzählendste": "anzählend",
    "anzählendstem": "anzählend",
    "anzählendsten": "anzählend",
    "anzählendster": "anzählend",
    "anzählendstes": "anzählend",
    "anzählest": "anzählen",
    "anzählet": "anzählen",
    "anzählst": "anzählen",
    "anzählt": "anzählen",
    "anzählte": "anzählen",
    "anzählten": "anzählen",
    "anzähltest": "anzählen",
    "anzähltet": "anzählen",
    "anzöge": "anziehen",
    "anzögen": "anziehen",
    "anzögest": "anziehen",
    "anzöget": "anziehen",
    "anzügliche": "anzüglich",
    "anzüglichem": "anzüglich",
    "anzüglichen": "anzüglich",
    "anzüglicher": "anzüglich",
    "anzüglichere": "anzüglich",
    "anzüglicherem": "anzüglich",
    "anzüglicheren": "anzüglich",
    "anzüglicherer": "anzüglich",
    "anzüglicheres": "anzüglich",
    "anzügliches": "anzüglich",
    "anzüglichste": "anzüglich",
    "anzüglichstem": "anzüglich",
    "anzüglichsten": "anzüglich",
    "anzüglichster": "anzüglich",
    "anzüglichstes": "anzüglich",
    "anzünde": "anzünden",
    "anzündend": "anzünden",
    "anzündende": "anzündend",
    "anzündendem": "anzündend",
    "anzündenden": "anzündend",
    "anzündender": "anzündend",
    "anzündendes": "anzündend",
    "anzündest": "anzünden",
    "anzündet": "anzünden",
    "anzündete": "anzünden",
    "anzündeten": "anzünden",
    "anzündetest": "anzünden",
    "anzündetet": "anzünden",
    "anöde": "anöden",
    "anödend": "anöden",
    "anödende": "anödend",
    "anödendem": "anödend",
    "anödenden": "anödend",
    "anödender": "anödend",
    "anödendere": "anödend",
    "anödenderem": "anödend",
    "anödenderen": "anödend",
    "anödenderer": "anödend",
    "anödenderes": "anödend",
    "anödendes": "anödend",
    "anödendste": "anödend",
    "anödendstem": "anödend",
    "anödendsten": "anödend",
    "anödendster": "anödend",
    "anödendstes": "anödend",
    "anödest": "anöden",
    "anödet": "anöden",
    "anödete": "anöden",
    "anödeten": "anöden",
    "anödetest": "anöden",
    "anödetet": "anöden",
    "aperiodischem": "aperiodisch",
    "aperiodischen": "aperiodisch",
    "aperiodischer": "aperiodisch",
    "aperiodisches": "aperiodisch",
    "apfelgrünem": "apfelgrün",
    "apfelgrünen": "apfelgrün",
    "apfelgrüner": "apfelgrün",
    "apfelgrünes": "apfelgrün",
    "apokalyptischem": "apokalyptisch",
    "apokalyptischen": "apokalyptisch",
    "apokalyptischer": "apokalyptisch",
    "apokalyptisches": "apokalyptisch",
    "apolitische": "apolitisch",
    "apolitischem": "apolitisch",
    "apolitischen": "apolitisch",
    "apolitischer": "apolitisch",
    "apolitisches": "apolitisch",
    "apostolischem": "apostolisch",
    "apostolischen": "apostolisch",
    "apostolischer": "apostolisch",
    "apostolisches": "apostolisch",
    "apothekenpflichtigem": "apothekenpflichtig",
    "apothekenpflichtigen": "apothekenpflichtig",
    "apothekenpflichtiger": "apothekenpflichtig",
    "apothekenpflichtiges": "apothekenpflichtig",
    "apparativem": "apparativ",
    "apparativen": "apparativ",
    "apparativer": "apparativ",
    "apparatives": "apparativ",
    "appelliere": "appellieren",
    "appellierend": "appellieren",
    "appellierende": "appellierend",
    "appellierendem": "appellierend",
    "appellierenden": "appellierend",
    "appellierender": "appellierend",
    "appellierendes": "appellierend",
    "appellierest": "appellieren",
    "appellieret": "appellieren",
    "appellierst": "appellieren",
    "appelliert": "appellieren",
    "appellierte": "appellieren",
    "appelliertem": "appelliert",
    "appellierten": "appellieren",
    "appellierter": "appelliert",
    "appelliertes": "appelliert",
    "appelliertest": "appellieren",
    "appelliertet": "appellieren",
    "appetitanregendem": "appetitanregend",
    "appetitanregenden": "appetitanregend",
    "appetitanregender": "appetitanregend",
    "appetitanregendere": "appetitanregend",
    "appetitanregenderem": "appetitanregend",
    "appetitanregenderen": "appetitanregend",
    "appetitanregenderer": "appetitanregend",
    "appetitanregenderes": "appetitanregend",
    "appetitanregendes": "appetitanregend",
    "appetitanregendste": "appetitanregend",
    "appetitanregendstem": "appetitanregend",
    "appetitanregendsten": "appetitanregend",
    "appetitanregendster": "appetitanregend",
    "appetitanregendstes": "appetitanregend",
    "appetitlichem": "appetitlich",
    "appetitlichen": "appetitlich",
    "appetitlicher": "appetitlich",
    "appetitlichere": "appetitlich",
    "appetitlicherem": "appetitlich",
    "appetitlicheren": "appetitlich",
    "appetitlicherer": "appetitlich",
    "appetitlicheres": "appetitlich",
    "appetitliches": "appetitlich",
    "appetitlichste": "appetitlich",
    "appetitlichstem": "appetitlich",
    "appetitlichsten": "appetitlich",
    "appetitlichster": "appetitlich",
    "appetitlichstes": "appetitlich",
    "appetitlose": "appetitlos",
    "appetitlosem": "appetitlos",
    "appetitlosen": "appetitlos",
    "appetitloser": "appetitlos",
    "appetitlosere": "appetitlos",
    "appetitloserem": "appetitlos",
    "appetitloseren": "appetitlos",
    "appetitloserer": "appetitlos",
    "appetitloseres": "appetitlos",
    "appetitloses": "appetitlos",
    "appetitloseste": "appetitlos",
    "appetitlosestem": "appetitlos",
    "appetitlosesten": "appetitlos",
    "appetitlosester": "appetitlos",
    "appetitlosestes": "appetitlos",
    "applaudiere": "applaudieren",
    "applaudierend": "applaudieren",
    "applaudierende": "applaudierend",
    "applaudierendem": "applaudierend",
    "applaudierenden": "applaudierend",
    "applaudierender": "applaudierend",
    "applaudierendere": "applaudierend",
    "applaudierenderem": "applaudierend",
    "applaudierenderen": "applaudierend",
    "applaudierenderer": "applaudierend",
    "applaudierenderes": "applaudierend",
    "applaudierendes": "applaudierend",
    "applaudierendste": "applaudierend",
    "applaudierendstem": "applaudierend",
    "applaudierendsten": "applaudierend",
    "applaudierendster": "applaudierend",
    "applaudierendstes": "applaudierend",
    "applaudierest": "applaudieren",
    "applaudieret": "applaudieren",
    "applaudierst": "applaudieren",
    "applaudiert": "applaudieren",
    "applaudierte": "applaudieren",
    "applaudiertem": "applaudiert",
    "applaudierten": "applaudieren",
    "applaudierter": "applaudiert",
    "applaudiertes": "applaudiert",
    "applaudiertest": "applaudieren",
    "applaudiertet": "applaudieren",
    "apportiere": "apportieren",
    "apportierend": "apportieren",
    "apportierende": "apportierend",
    "apportierendem": "apportierend",
    "apportierenden": "apportierend",
    "apportierender": "apportierend",
    "apportierendere": "apportierend",
    "apportierenderem": "apportierend",
    "apportierenderen": "apportierend",
    "apportierenderer": "apportierend",
    "apportierenderes": "apportierend",
    "apportierendes": "apportierend",
    "apportierendste": "apportierend",
    "apportierendstem": "apportierend",
    "apportierendsten": "apportierend",
    "apportierendster": "apportierend",
    "apportierendstes": "apportierend",
    "apportierest": "apportieren",
    "apportieret": "apportieren",
    "apportierst": "apportieren",
    "apportiert": "apportieren",
    "apportierte": "apportieren",
    "apportiertem": "apportiert",
    "apportierten": "apportieren",
    "apportierter": "apportiert",
    "apportiertes": "apportiert",
    "apportiertest": "apportieren",
    "apportiertet": "apportieren",
    "appretiere": "appretieren",
    "appretierend": "appretieren",
    "appretierende": "appretierend",
    "appretierendem": "appretierend",
    "appretierenden": "appretierend",
    "appretierender": "appretierend",
    "appretierendere": "appretierend",
    "appretierenderem": "appretierend",
    "appretierenderen": "appretierend",
    "appretierenderer": "appretierend",
    "appretierenderes": "appretierend",
    "appretierendes": "appretierend",
    "appretierendste": "appretierend",
    "appretierendstem": "appretierend",
    "appretierendsten": "appretierend",
    "appretierendster": "appretierend",
    "appretierendstes": "appretierend",
    "appretierest": "appretieren",
    "appretieret": "appretieren",
    "appretierst": "appretieren",
    "appretiert": "appretieren",
    "appretierte": "appretieren",
    "appretiertem": "appretiert",
    "appretierten": "appretieren",
    "appretierter": "appretiert",
    "appretiertere": "appretiert",
    "appretierterem": "appretiert",
    "appretierteren": "appretiert",
    "appretierterer": "appretiert",
    "appretierteres": "appretiert",
    "appretiertes": "appretiert",
    "appretiertest": "appretieren",
    "appretierteste": "appretiert",
    "appretiertestem": "appretiert",
    "appretiertesten": "appretiert",
    "appretiertester": "appretiert",
    "appretiertestes": "appretiert",
    "appretiertet": "appretieren",
    "approximativem": "approximativ",
    "approximativen": "approximativ",
    "approximativer": "approximativ",
    "approximatives": "approximativ",
    "arabischem": "arabisch",
    "arabischen": "arabisch",
    "arabischer": "arabisch",
    "arabisches": "arabisch",
    "arbeite": "arbeiten",
    "arbeitend": "arbeiten",
    "arbeitende": "arbeitend",
    "arbeitendem": "arbeitend",
    "arbeitenden": "arbeitend",
    "arbeitender": "arbeitend",
    "arbeitendes": "arbeitend",
    "arbeitest": "arbeiten",
    "arbeitet": "arbeiten",
    "arbeitete": "arbeiten",
    "arbeiteten": "arbeiten",
    "arbeitetest": "arbeiten",
    "arbeitetet": "arbeiten",
    "arbeitsamem": "arbeitsam",
    "arbeitsamen": "arbeitsam",
    "arbeitsamer": "arbeitsam",
    "arbeitsamere": "arbeitsam",
    "arbeitsamerem": "arbeitsam",
    "arbeitsameren": "arbeitsam",
    "arbeitsamerer": "arbeitsam",
    "arbeitsameres": "arbeitsam",
    "arbeitsames": "arbeitsam",
    "arbeitsamste": "arbeitsam",
    "arbeitsamstem": "arbeitsam",
    "arbeitsamsten": "arbeitsam",
    "arbeitsamster": "arbeitsam",
    "arbeitsamstes": "arbeitsam",
    "arbeitsfähigem": "arbeitsfähig",
    "arbeitsfähigen": "arbeitsfähig",
    "arbeitsfähiger": "arbeitsfähig",
    "arbeitsfähigere": "arbeitsfähig",
    "arbeitsfähigerem": "arbeitsfähig",
    "arbeitsfähigeren": "arbeitsfähig",
    "arbeitsfähigerer": "arbeitsfähig",
    "arbeitsfähigeres": "arbeitsfähig",
    "arbeitsfähiges": "arbeitsfähig",
    "arbeitsfähigste": "arbeitsfähig",
    "arbeitsfähigstem": "arbeitsfähig",
    "arbeitsfähigsten": "arbeitsfähig",
    "arbeitsfähigster": "arbeitsfähig",
    "arbeitsfähigstes": "arbeitsfähig",
    "arbeitsintensive": "arbeitsintensiv",
    "arbeitsintensivem": "arbeitsintensiv",
    "arbeitsintensiven": "arbeitsintensiv",
    "arbeitsintensiver": "arbeitsintensiv",
    "arbeitsintensivere": "arbeitsintensiv",
    "arbeitsintensiverem": "arbeitsintensiv",
    "arbeitsintensiveren": "arbeitsintensiv",
    "arbeitsintensiverer": "arbeitsintensiv",
    "arbeitsintensiveres": "arbeitsintensiv",
    "arbeitsintensives": "arbeitsintensiv",
    "arbeitsintensivste": "arbeitsintensiv",
    "arbeitsintensivstem": "arbeitsintensiv",
    "arbeitsintensivsten": "arbeitsintensiv",
    "arbeitsintensivster": "arbeitsintensiv",
    "arbeitsintensivstes": "arbeitsintensiv",
    "arbeitslose": "arbeitslos",
    "arbeitslosem": "arbeitslos",
    "arbeitslosen": "arbeitslos",
    "arbeitsloser": "arbeitslos",
    "arbeitsloses": "arbeitslos",
    "arbeitsrechtliche": "arbeitsrechtlich",
    "arbeitsrechtlichem": "arbeitsrechtlich",
    "arbeitsrechtlichen": "arbeitsrechtlich",
    "arbeitsrechtlicher": "arbeitsrechtlich",
    "arbeitsrechtliches": "arbeitsrechtlich",
    "arbeitsscheue": "arbeitsscheu",
    "arbeitsscheuem": "arbeitsscheu",
    "arbeitsscheuen": "arbeitsscheu",
    "arbeitsscheuer": "arbeitsscheu",
    "arbeitsscheuere": "arbeitsscheu",
    "arbeitsscheuerem": "arbeitsscheu",
    "arbeitsscheueren": "arbeitsscheu",
    "arbeitsscheuerer": "arbeitsscheu",
    "arbeitsscheueres": "arbeitsscheu",
    "arbeitsscheues": "arbeitsscheu",
    "arbeitsscheueste": "arbeitsscheu",
    "arbeitsscheuestem": "arbeitsscheu",
    "arbeitsscheuesten": "arbeitsscheu",
    "arbeitsscheuester": "arbeitsscheu",
    "arbeitsscheuestes": "arbeitsscheu",
    "arbeitsunfähige": "arbeitsunfähig",
    "arbeitsunfähigem": "arbeitsunfähig",
    "arbeitsunfähigen": "arbeitsunfähig",
    "arbeitsunfähiger": "arbeitsunfähig",
    "arbeitsunfähiges": "arbeitsunfähig",
    "archäologischem": "archäologisch",
    "archäologischen": "archäologisch",
    "archäologischer": "archäologisch",
    "archäologisches": "archäologisch",
    "argem": "arg",
    "argen": "arg",
    "arger": "arg",
    "arges": "arg",
    "arglistige": "arglistig",
    "arglistigem": "arglistig",
    "arglistigen": "arglistig",
    "arglistiger": "arglistig",
    "arglistigere": "arglistig",
    "arglistigerem": "arglistig",
    "arglistigeren": "arglistig",
    "arglistigerer": "arglistig",
    "arglistigeres": "arglistig",
    "arglistiges": "arglistig",
    "arglistigste": "arglistig",
    "arglistigstem": "arglistig",
    "arglistigsten": "arglistig",
    "arglistigster": "arglistig",
    "arglistigstes": "arglistig",
    "arglose": "arglos",
    "arglosem": "arglos",
    "arglosen": "arglos",
    "argloser": "arglos",
    "arglosere": "arglos",
    "argloserem": "arglos",
    "argloseren": "arglos",
    "argloserer": "arglos",
    "argloseres": "arglos",
    "argloses": "arglos",
    "argloseste": "arglos",
    "arglosestem": "arglos",
    "arglosesten": "arglos",
    "arglosester": "arglos",
    "arglosestes": "arglos",
    "argumentativem": "argumentativ",
    "argumentativen": "argumentativ",
    "argumentativer": "argumentativ",
    "argumentatives": "argumentativ",
    "argumentierend": "argumentieren",
    "argumentierende": "argumentierend",
    "argumentierendem": "argumentierend",
    "argumentierenden": "argumentierend",
    "argumentierender": "argumentierend",
    "argumentierendere": "argumentierend",
    "argumentierenderem": "argumentierend",
    "argumentierenderen": "argumentierend",
    "argumentierenderer": "argumentierend",
    "argumentierenderes": "argumentierend",
    "argumentierendes": "argumentierend",
    "argumentierendste": "argumentierend",
    "argumentierendstem": "argumentierend",
    "argumentierendsten": "argumentierend",
    "argumentierendster": "argumentierend",
    "argumentierendstes": "argumentierend",
    "argumentierest": "argumentieren",
    "argumentieret": "argumentieren",
    "argumentierst": "argumentieren",
    "argumentiert": "argumentieren",
    "argumentierte": "argumentieren",
    "argumentiertem": "argumentiert",
    "argumentierten": "argumentieren",
    "argumentierter": "argumentiert",
    "argumentiertes": "argumentiert",
    "argumentiertest": "argumentieren",
    "argumentiertet": "argumentieren",
    "argwöhne": "argwöhnen",
    "argwöhnend": "argwöhnen",
    "argwöhnende": "argwöhnend",
    "argwöhnendem": "argwöhnend",
    "argwöhnenden": "argwöhnend",
    "argwöhnender": "argwöhnend",
    "argwöhnendere": "argwöhnend",
    "argwöhnenderem": "argwöhnend",
    "argwöhnenderen": "argwöhnend",
    "argwöhnenderer": "argwöhnend",
    "argwöhnenderes": "argwöhnend",
    "argwöhnendes": "argwöhnend",
    "argwöhnendste": "argwöhnend",
    "argwöhnendstem": "argwöhnend",
    "argwöhnendsten": "argwöhnend",
    "argwöhnendster": "argwöhnend",
    "argwöhnendstes": "argwöhnend",
    "argwöhnest": "argwöhnen",
    "argwöhnet": "argwöhnen",
    "argwöhnische": "argwöhnisch",
    "argwöhnischem": "argwöhnisch",
    "argwöhnischen": "argwöhnisch",
    "argwöhnischer": "argwöhnisch",
    "argwöhnischere": "argwöhnisch",
    "argwöhnischerem": "argwöhnisch",
    "argwöhnischeren": "argwöhnisch",
    "argwöhnischerer": "argwöhnisch",
    "argwöhnischeres": "argwöhnisch",
    "argwöhnisches": "argwöhnisch",
    "argwöhnischste": "argwöhnisch",
    "argwöhnischstem": "argwöhnisch",
    "argwöhnischsten": "argwöhnisch",
    "argwöhnischster": "argwöhnisch",
    "argwöhnischstes": "argwöhnisch",
    "argwöhnst": "argwöhnen",
    "argwöhnt": "argwöhnen",
    "argwöhnte": "argwöhnen",
    "argwöhnten": "argwöhnen",
    "argwöhntest": "argwöhnen",
    "argwöhntet": "argwöhnen",
    "arhythmische": "arhythmisch",
    "arhythmischem": "arhythmisch",
    "arhythmischen": "arhythmisch",
    "arhythmischer": "arhythmisch",
    "arhythmisches": "arhythmisch",
    "arischem": "arisch",
    "arischen": "arisch",
    "arischer": "arisch",
    "arisches": "arisch",
    "aristokratischem": "aristokratisch",
    "aristokratischen": "aristokratisch",
    "aristokratischer": "aristokratisch",
    "aristokratisches": "aristokratisch",
    "arithmetischem": "arithmetisch",
    "arithmetischen": "arithmetisch",
    "arithmetischer": "arithmetisch",
    "arithmetisches": "arithmetisch",
    "arktischem": "arktisch",
    "arktischen": "arktisch",
    "arktischer": "arktisch",
    "arktisches": "arktisch",
    "armem": "arm",
    "armen": "arm",
    "armenischem": "armenisch",
    "armenischen": "armenisch",
    "armenischer": "armenisch",
    "armenisches": "armenisch",
    "armer": "arm",
    "armes": "arm",
    "armseligem": "armselig",
    "armseligen": "armselig",
    "armseliger": "armselig",
    "armseligere": "armselig",
    "armseligerem": "armselig",
    "armseligeren": "armselig",
    "armseligerer": "armselig",
    "armseligeres": "armselig",
    "armseliges": "armselig",
    "armseligste": "armselig",
    "armseligstem": "armselig",
    "armseligsten": "armselig",
    "armseligster": "armselig",
    "armseligstes": "armselig",
    "aromatischem": "aromatisch",
    "aromatischen": "aromatisch",
    "aromatischer": "aromatisch",
    "aromatischere": "aromatisch",
    "aromatischerem": "aromatisch",
    "aromatischeren": "aromatisch",
    "aromatischerer": "aromatisch",
    "aromatischeres": "aromatisch",
    "aromatisches": "aromatisch",
    "aromatischste": "aromatisch",
    "aromatischstem": "aromatisch",
    "aromatischsten": "aromatisch",
    "aromatischster": "aromatisch",
    "aromatischstes": "aromatisch",
    "aromatisiere": "aromatisieren",
    "aromatisierend": "aromatisieren",
    "aromatisierende": "aromatisierend",
    "aromatisierendem": "aromatisierend",
    "aromatisierenden": "aromatisierend",
    "aromatisierender": "aromatisierend",
    "aromatisierendere": "aromatisierend",
    "aromatisierenderem": "aromatisierend",
    "aromatisierenderen": "aromatisierend",
    "aromatisierenderer": "aromatisierend",
    "aromatisierenderes": "aromatisierend",
    "aromatisierendes": "aromatisierend",
    "aromatisierendste": "aromatisierend",
    "aromatisierendstem": "aromatisierend",
    "aromatisierendsten": "aromatisierend",
    "aromatisierendster": "aromatisierend",
    "aromatisierendstes": "aromatisierend",
    "aromatisierest": "aromatisieren",
    "aromatisieret": "aromatisieren",
    "aromatisierst": "aromatisieren",
    "aromatisiert": "aromatisieren",
    "aromatisierte": "aromatisieren",
    "aromatisiertem": "aromatisiert",
    "aromatisierten": "aromatisieren",
    "aromatisierter": "aromatisiert",
    "aromatisiertere": "aromatisiert",
    "aromatisierterem": "aromatisiert",
    "aromatisierteren": "aromatisiert",
    "aromatisierterer": "aromatisiert",
    "aromatisierteres": "aromatisiert",
    "aromatisiertes": "aromatisiert",
    "aromatisiertest": "aromatisieren",
    "aromatisierteste": "aromatisiert",
    "aromatisiertestem": "aromatisiert",
    "aromatisiertesten": "aromatisiert",
    "aromatisiertester": "aromatisiert",
    "aromatisiertestes": "aromatisiert",
    "aromatisiertet": "aromatisieren",
    "arrangiere": "arrangieren",
    "arrangierend": "arrangieren",
    "arrangierende": "arrangierend",
    "arrangierendem": "arrangierend",
    "arrangierenden": "arrangierend",
    "arrangierender": "arrangierend",
    "arrangierendes": "arrangierend",
    "arrangierest": "arrangieren",
    "arrangieret": "arrangieren",
    "arrangierst": "arrangieren",
    "arrangiert": "arrangieren",
    "arrangierte": "arrangieren",
    "arrangiertem": "arrangiert",
    "arrangierten": "arrangieren",
    "arrangierter": "arrangiert",
    "arrangiertes": "arrangiert",
    "arrangiertest": "arrangieren",
    "arrangiertet": "arrangieren",
    "arrogantem": "arrogant",
    "arroganten": "arrogant",
    "arroganter": "arrogant",
    "arrogantere": "arrogant",
    "arroganterem": "arrogant",
    "arroganteren": "arrogant",
    "arroganterer": "arrogant",
    "arroganteres": "arrogant",
    "arrogantes": "arrogant",
    "arroganteste": "arrogant",
    "arrogantestem": "arrogant",
    "arrogantesten": "arrogant",
    "arrogantester": "arrogant",
    "arrogantestes": "arrogant",
    "arschkalte": "arschkalt",
    "arschkaltem": "arschkalt",
    "arschkalten": "arschkalt",
    "arschkalter": "arschkalt",
    "arschkaltes": "arschkalt",
    "arte": "arten",
    "artend": "arten",
    "artende": "artend",
    "artendem": "artend",
    "artenden": "artend",
    "artender": "artend",
    "artendes": "artend",
    "artest": "arten",
    "artet": "arten",
    "artete": "arten",
    "arteten": "arten",
    "artetest": "arten",
    "artetet": "arten",
    "artfremde": "artfremd",
    "artfremdem": "artfremd",
    "artfremden": "artfremd",
    "artfremder": "artfremd",
    "artfremdes": "artfremd",
    "artgleichem": "artgleich",
    "artgleichen": "artgleich",
    "artgleicher": "artgleich",
    "artgleiches": "artgleich",
    "artigem": "artig",
    "artigen": "artig",
    "artiger": "artig",
    "artigere": "artig",
    "artigerem": "artig",
    "artigeren": "artig",
    "artigerer": "artig",
    "artigeres": "artig",
    "artiges": "artig",
    "artigste": "artig",
    "artigstem": "artig",
    "artigsten": "artig",
    "artigster": "artig",
    "artigstes": "artig",
    "artikuliere": "artikulieren",
    "artikulierend": "artikulieren",
    "artikulierende": "artikulierend",
    "artikulierendem": "artikulierend",
    "artikulierenden": "artikulierend",
    "artikulierender": "artikulierend",
    "artikulierendere": "artikulierend",
    "artikulierenderem": "artikulierend",
    "artikulierenderen": "artikulierend",
    "artikulierenderer": "artikulierend",
    "artikulierenderes": "artikulierend",
    "artikulierendes": "artikulierend",
    "artikulierendste": "artikulierend",
    "artikulierendstem": "artikulierend",
    "artikulierendsten": "artikulierend",
    "artikulierendster": "artikulierend",
    "artikulierendstes": "artikulierend",
    "artikulierest": "artikulieren",
    "artikulieret": "artikulieren",
    "artikulierst": "artikulieren",
    "artikuliert": "artikulieren",
    "artikulierte": "artikulieren",
    "artikuliertem": "artikuliert",
    "artikulierten": "artikulieren",
    "artikulierter": "artikuliert",
    "artikuliertes": "artikuliert",
    "artikuliertest": "artikulieren",
    "artikuliertet": "artikulieren",
    "artverwandtem": "artverwandt",
    "artverwandten": "artverwandt",
    "artverwandter": "artverwandt",
    "artverwandtes": "artverwandt",
    "aschbleichem": "aschbleich",
    "aschbleichen": "aschbleich",
    "aschbleicher": "aschbleich",
    "aschbleichere": "aschbleich",
    "aschbleicherem": "aschbleich",
    "aschbleicheren": "aschbleich",
    "aschbleicherer": "aschbleich",
    "aschbleicheres": "aschbleich",
    "aschbleiches": "aschbleich",
    "aschbleichste": "aschbleich",
    "aschbleichstem": "aschbleich",
    "aschbleichsten": "aschbleich",
    "aschbleichster": "aschbleich",
    "aschbleichstes": "aschbleich",
    "aschblonde": "aschblond",
    "aschblondem": "aschblond",
    "aschblonden": "aschblond",
    "aschblonder": "aschblond",
    "aschblondere": "aschblond",
    "aschblonderem": "aschblond",
    "aschblonderen": "aschblond",
    "aschblonderer": "aschblond",
    "aschblonderes": "aschblond",
    "aschblondes": "aschblond",
    "aschblondeste": "aschblond",
    "aschblondestem": "aschblond",
    "aschblondesten": "aschblond",
    "aschblondester": "aschblond",
    "aschblondestes": "aschblond",
    "aserbaidschanischem": "aserbaidschanisch",
    "aserbaidschanischen": "aserbaidschanisch",
    "aserbaidschanischer": "aserbaidschanisch",
    "aserbaidschanisches": "aserbaidschanisch",
    "asiatischem": "asiatisch",
    "asiatischen": "asiatisch",
    "asiatischer": "asiatisch",
    "asiatischere": "asiatisch",
    "asiatischerem": "asiatisch",
    "asiatischeren": "asiatisch",
    "asiatischerer": "asiatisch",
    "asiatischeres": "asiatisch",
    "asiatisches": "asiatisch",
    "asiatischste": "asiatisch",
    "asiatischstem": "asiatisch",
    "asiatischsten": "asiatisch",
    "asiatischster": "asiatisch",
    "asiatischstes": "asiatisch",
    "asketischem": "asketisch",
    "asketischen": "asketisch",
    "asketischer": "asketisch",
    "asketisches": "asketisch",
    "asoziale": "asozial",
    "asozialem": "asozial",
    "asozialen": "asozial",
    "asozialer": "asozial",
    "asoziales": "asozial",
    "asphaltiere": "asphaltieren",
    "asphaltierend": "asphaltieren",
    "asphaltierende": "asphaltierend",
    "asphaltierendem": "asphaltierend",
    "asphaltierenden": "asphaltierend",
    "asphaltierender": "asphaltierend",
    "asphaltierendes": "asphaltierend",
    "asphaltierest": "asphaltieren",
    "asphaltieret": "asphaltieren",
    "asphaltierst": "asphaltieren",
    "asphaltiert": "asphaltieren",
    "asphaltierte": "asphaltieren",
    "asphaltiertem": "asphaltiert",
    "asphaltierten": "asphaltieren",
    "asphaltierter": "asphaltiert",
    "asphaltiertere": "asphaltiert",
    "asphaltierterem": "asphaltiert",
    "asphaltierteren": "asphaltiert",
    "asphaltierterer": "asphaltiert",
    "asphaltierteres": "asphaltiert",
    "asphaltiertes": "asphaltiert",
    "asphaltiertest": "asphaltieren",
    "asphaltierteste": "asphaltiert",
    "asphaltiertestem": "asphaltiert",
    "asphaltiertesten": "asphaltiert",
    "asphaltiertester": "asphaltiert",
    "asphaltiertestes": "asphaltiert",
    "asphaltiertet": "asphaltieren",
    "assimiliere": "assimilieren",
    "assimilierend": "assimilieren",
    "assimilierende": "assimilierend",
    "assimilierendem": "assimilierend",
    "assimilierenden": "assimilierend",
    "assimilierender": "assimilierend",
    "assimilierendere": "assimilierend",
    "assimilierenderem": "assimilierend",
    "assimilierenderen": "assimilierend",
    "assimilierenderer": "assimilierend",
    "assimilierenderes": "assimilierend",
    "assimilierendes": "assimilierend",
    "assimilierendste": "assimilierend",
    "assimilierendstem": "assimilierend",
    "assimilierendsten": "assimilierend",
    "assimilierendster": "assimilierend",
    "assimilierendstes": "assimilierend",
    "assimilierest": "assimilieren",
    "assimilieret": "assimilieren",
    "assimilierst": "assimilieren",
    "assimiliert": "assimilieren",
    "assimilierte": "assimilieren",
    "assimiliertem": "assimiliert",
    "assimilierten": "assimilieren",
    "assimilierter": "assimiliert",
    "assimiliertere": "assimiliert",
    "assimilierterem": "assimiliert",
    "assimilierteren": "assimiliert",
    "assimilierterer": "assimiliert",
    "assimilierteres": "assimiliert",
    "assimiliertes": "assimiliert",
    "assimiliertest": "assimilieren",
    "assimilierteste": "assimiliert",
    "assimiliertestem": "assimiliert",
    "assimiliertesten": "assimiliert",
    "assimiliertester": "assimiliert",
    "assimiliertestes": "assimiliert",
    "assimiliertet": "assimilieren",
    "assistiere": "assistieren",
    "assistierend": "assistieren",
    "assistierende": "assistierend",
    "assistierendem": "assistierend",
    "assistierenden": "assistierend",
    "assistierender": "assistierend",
    "assistierendes": "assistierend",
    "assistierest": "assistieren",
    "assistieret": "assistieren",
    "assistierst": "assistieren",
    "assistiert": "assistieren",
    "assistierte": "assistieren",
    "assistiertem": "assistiert",
    "assistierten": "assistieren",
    "assistierter": "assistiert",
    "assistiertes": "assistiert",
    "assistiertest": "assistieren",
    "assistiertet": "assistieren",
    "assoziativem": "assoziativ",
    "assoziativen": "assoziativ",
    "assoziativer": "assoziativ",
    "assoziativere": "assoziativ",
    "assoziativerem": "assoziativ",
    "assoziativeren": "assoziativ",
    "assoziativerer": "assoziativ",
    "assoziativeres": "assoziativ",
    "assoziatives": "assoziativ",
    "assoziativste": "assoziativ",
    "assoziativstem": "assoziativ",
    "assoziativsten": "assoziativ",
    "assoziativster": "assoziativ",
    "assoziativstes": "assoziativ",
    "assoziiere": "assoziieren",
    "assoziierend": "assoziieren",
    "assoziierende": "assoziierend",
    "assoziierendem": "assoziierend",
    "assoziierenden": "assoziierend",
    "assoziierender": "assoziierend",
    "assoziierendere": "assoziierend",
    "assoziierenderem": "assoziierend",
    "assoziierenderen": "assoziierend",
    "assoziierenderer": "assoziierend",
    "assoziierenderes": "assoziierend",
    "assoziierendes": "assoziierend",
    "assoziierendste": "assoziierend",
    "assoziierendstem": "assoziierend",
    "assoziierendsten": "assoziierend",
    "assoziierendster": "assoziierend",
    "assoziierendstes": "assoziierend",
    "assoziierest": "assoziieren",
    "assoziieret": "assoziieren",
    "assoziierst": "assoziieren",
    "assoziiert": "assoziieren",
    "assoziierte": "assoziieren",
    "assoziiertem": "assoziiert",
    "assoziierten": "assoziieren",
    "assoziierter": "assoziiert",
    "assoziiertere": "assoziiert",
    "assoziierterem": "assoziiert",
    "assoziierteren": "assoziiert",
    "assoziierterer": "assoziiert",
    "assoziierteres": "assoziiert",
    "assoziiertes": "assoziiert",
    "assoziiertest": "assoziieren",
    "assoziierteste": "assoziiert",
    "assoziiertestem": "assoziiert",
    "assoziiertesten": "assoziiert",
    "assoziiertester": "assoziiert",
    "assoziiertestes": "assoziiert",
    "assoziiertet": "assoziieren",
    "asthmatischem": "asthmatisch",
    "asthmatischen": "asthmatisch",
    "asthmatischer": "asthmatisch",
    "asthmatisches": "asthmatisch",
    "astreine": "astrein",
    "astreinem": "astrein",
    "astreinen": "astrein",
    "astreiner": "astrein",
    "astreines": "astrein",
    "astrologischem": "astrologisch",
    "astrologischen": "astrologisch",
    "astrologischer": "astrologisch",
    "astrologisches": "astrologisch",
    "astronomischem": "astronomisch",
    "astronomischen": "astronomisch",
    "astronomischer": "astronomisch",
    "astronomisches": "astronomisch",
    "atemberaubendem": "atemberaubend",
    "atemberaubenden": "atemberaubend",
    "atemberaubender": "atemberaubend",
    "atemberaubendere": "atemberaubend",
    "atemberaubenderem": "atemberaubend",
    "atemberaubenderen": "atemberaubend",
    "atemberaubenderer": "atemberaubend",
    "atemberaubenderes": "atemberaubend",
    "atemberaubendes": "atemberaubend",
    "atemberaubendste": "atemberaubend",
    "atemberaubendstem": "atemberaubend",
    "atemberaubendsten": "atemberaubend",
    "atemberaubendster": "atemberaubend",
    "atemberaubendstes": "atemberaubend",
    "atemlose": "atemlos",
    "atemlosem": "atemlos",
    "atemlosen": "atemlos",
    "atemloser": "atemlos",
    "atemlosere": "atemlos",
    "atemloserem": "atemlos",
    "atemloseren": "atemlos",
    "atemloserer": "atemlos",
    "atemloseres": "atemlos",
    "atemloses": "atemlos",
    "atemloseste": "atemlos",
    "atemlosestem": "atemlos",
    "atemlosesten": "atemlos",
    "atemlosester": "atemlos",
    "atemlosestes": "atemlos",
    "atemraubende": "atemraubend",
    "atemraubendem": "atemraubend",
    "atemraubenden": "atemraubend",
    "atemraubender": "atemraubend",
    "atemraubendes": "atemraubend",
    "atheistischem": "atheistisch",
    "atheistischen": "atheistisch",
    "atheistischer": "atheistisch",
    "atheistisches": "atheistisch",
    "athletischem": "athletisch",
    "athletischen": "athletisch",
    "athletischer": "athletisch",
    "athletischere": "athletisch",
    "athletischerem": "athletisch",
    "athletischeren": "athletisch",
    "athletischerer": "athletisch",
    "athletischeres": "athletisch",
    "athletisches": "athletisch",
    "athletischste": "athletisch",
    "athletischstem": "athletisch",
    "athletischsten": "athletisch",
    "athletischster": "athletisch",
    "athletischstes": "athletisch",
    "atlantischem": "atlantisch",
    "atlantischen": "atlantisch",
    "atlantischer": "atlantisch",
    "atlantisches": "atlantisch",
    "atme": "atmen",
    "atmend": "atmen",
    "atmende": "atmend",
    "atmendem": "atmend",
    "atmenden": "atmend",
    "atmender": "atmend",
    "atmendes": "atmend",
    "atmest": "atmen",
    "atmet": "atmen",
    "atmete": "atmen",
    "atmeten": "atmen",
    "atmetest": "atmen",
    "atmetet": "atmen",
    "atomarem": "atomar",
    "atomaren": "atomar",
    "atomarer": "atomar",
    "atomares": "atomar",
    "atomisiere": "atomisieren",
    "atomisierend": "atomisieren",
    "atomisierende": "atomisierend",
    "atomisierendem": "atomisierend",
    "atomisierenden": "atomisierend",
    "atomisierender": "atomisierend",
    "atomisierendere": "atomisierend",
    "atomisierenderem": "atomisierend",
    "atomisierenderen": "atomisierend",
    "atomisierenderer": "atomisierend",
    "atomisierenderes": "atomisierend",
    "atomisierendes": "atomisierend",
    "atomisierendste": "atomisierend",
    "atomisierendstem": "atomisierend",
    "atomisierendsten": "atomisierend",
    "atomisierendster": "atomisierend",
    "atomisierendstes": "atomisierend",
    "atomisierest": "atomisieren",
    "atomisieret": "atomisieren",
    "atomisierst": "atomisieren",
    "atomisiert": "atomisieren",
    "atomisierte": "atomisieren",
    "atomisiertem": "atomisiert",
    "atomisierten": "atomisieren",
    "atomisierter": "atomisiert",
    "atomisiertere": "atomisiert",
    "atomisierterem": "atomisiert",
    "atomisierteren": "atomisiert",
    "atomisierterer": "atomisiert",
    "atomisierteres": "atomisiert",
    "atomisiertes": "atomisiert",
    "atomisiertest": "atomisieren",
    "atomisierteste": "atomisiert",
    "atomisiertestem": "atomisiert",
    "atomisiertesten": "atomisiert",
    "atomisiertester": "atomisiert",
    "atomisiertestes": "atomisiert",
    "atomisiertet": "atomisieren",
    "atoxische": "atoxisch",
    "atoxischem": "atoxisch",
    "atoxischen": "atoxisch",
    "atoxischer": "atoxisch",
    "atoxisches": "atoxisch",
    "attackiere": "attackieren",
    "attackierend": "attackieren",
    "attackierende": "attackierend",
    "attackierendem": "attackierend",
    "attackierenden": "attackierend",
    "attackierender": "attackierend",
    "attackierendere": "attackierend",
    "attackierenderem": "attackierend",
    "attackierenderen": "attackierend",
    "attackierenderer": "attackierend",
    "attackierenderes": "attackierend",
    "attackierendes": "attackierend",
    "attackierendste": "attackierend",
    "attackierendstem": "attackierend",
    "attackierendsten": "attackierend",
    "attackierendster": "attackierend",
    "attackierendstes": "attackierend",
    "attackierest": "attackieren",
    "attackieret": "attackieren",
    "attackierst": "attackieren",
    "attackiert": "attackieren",
    "attackierte": "attackieren",
    "attackiertem": "attackiert",
    "attackierten": "attackieren",
    "attackierter": "attackiert",
    "attackiertere": "attackiert",
    "attackierterem": "attackiert",
    "attackierteren": "attackiert",
    "attackierterer": "attackiert",
    "attackierteres": "attackiert",
    "attackiertes": "attackiert",
    "attackiertest": "attackieren",
    "attackierteste": "attackiert",
    "attackiertestem": "attackiert",
    "attackiertesten": "attackiert",
    "attackiertester": "attackiert",
    "attackiertestes": "attackiert",
    "attackiertet": "attackieren",
    "attestiere": "attestieren",
    "attestierend": "attestieren",
    "attestierende": "attestierend",
    "attestierendem": "attestierend",
    "attestierenden": "attestierend",
    "attestierender": "attestierend",
    "attestierendes": "attestierend",
    "attestierest": "attestieren",
    "attestieret": "attestieren",
    "attestierst": "attestieren",
    "attestiert": "attestieren",
    "attestierte": "attestieren",
    "attestiertem": "attestiert",
    "attestierten": "attestieren",
    "attestierter": "attestiert",
    "attestiertes": "attestiert",
    "attestiertest": "attestieren",
    "attestiertet": "attestieren",
    "attraktivem": "attraktiv",
    "attraktiven": "attraktiv",
    "attraktiver": "attraktiv",
    "attraktivere": "attraktiv",
    "attraktiverem": "attraktiv",
    "attraktiveren": "attraktiv",
    "attraktiverer": "attraktiv",
    "attraktiveres": "attraktiv",
    "attraktives": "attraktiv",
    "attraktivstem": "attraktiv",
    "attraktivsten": "attraktiv",
    "attraktivster": "attraktiv",
    "attraktivstes": "attraktiv",
    "attributivem": "attributiv",
    "attributiven": "attributiv",
    "attributiver": "attributiv",
    "attributives": "attributiv",
    "audiovisuellem": "audiovisuell",
    "audiovisuellen": "audiovisuell",
    "audiovisueller": "audiovisuell",
    "audiovisuelles": "audiovisuell",
    "auditive": "auditiv",
    "auditivem": "auditiv",
    "auditiven": "auditiv",
    "auditiver": "auditiv",
    "auditives": "auditiv",
    "aufarbeite": "aufarbeiten",
    "aufarbeitend": "aufarbeiten",
    "aufarbeitende": "aufarbeitend",
    "aufarbeitendem": "aufarbeitend",
    "aufarbeitenden": "aufarbeitend",
    "aufarbeitender": "aufarbeitend",
    "aufarbeitendes": "aufarbeitend",
    "aufarbeitest": "aufarbeiten",
    "aufarbeitet": "aufarbeiten",
    "aufarbeitete": "aufarbeiten",
    "aufarbeiteten": "aufarbeiten",
    "aufarbeitetest": "aufarbeiten",
    "aufarbeitetet": "aufarbeiten",
    "aufatme": "aufatmen",
    "aufatmend": "aufatmen",
    "aufatmende": "aufatmend",
    "aufatmendem": "aufatmend",
    "aufatmenden": "aufatmend",
    "aufatmender": "aufatmend",
    "aufatmendes": "aufatmend",
    "aufatmest": "aufatmen",
    "aufatmet": "aufatmen",
    "aufatmete": "aufatmen",
    "aufatmeten": "aufatmen",
    "aufatmetest": "aufatmen",
    "aufatmetet": "aufatmen",
    "aufaß": "aufessen",
    "aufaßen": "aufessen",
    "aufaßt": "aufessen",
    "aufbacke": "aufbacken",
    "aufbackend": "aufbacken",
    "aufbackende": "aufbackend",
    "aufbackendem": "aufbackend",
    "aufbackenden": "aufbackend",
    "aufbackender": "aufbackend",
    "aufbackendes": "aufbackend",
    "aufbackest": "aufbacken",
    "aufbacket": "aufbacken",
    "aufbackst": "aufbacken",
    "aufbackt": "aufbacken",
    "aufbackte": "aufbacken",
    "aufbackten": "aufbacken",
    "aufbacktest": "aufbacken",
    "aufbacktet": "aufbacken",
    "aufbahre": "aufbahren",
    "aufbahrend": "aufbahren",
    "aufbahrende": "aufbahrend",
    "aufbahrendem": "aufbahrend",
    "aufbahrenden": "aufbahrend",
    "aufbahrender": "aufbahrend",
    "aufbahrendes": "aufbahrend",
    "aufbahrest": "aufbahren",
    "aufbahret": "aufbahren",
    "aufbahrst": "aufbahren",
    "aufbahrt": "aufbahren",
    "aufbahrte": "aufbahren",
    "aufbahrten": "aufbahren",
    "aufbahrtest": "aufbahren",
    "aufbahrtet": "aufbahren",
    "aufband": "aufbinden",
    "aufbanden": "aufbinden",
    "aufbandest": "aufbinden",
    "aufbandet": "aufbinden",
    "aufbaue": "aufbauen",
    "aufbauend": "aufbauen",
    "aufbauende": "aufbauend",
    "aufbauendem": "aufbauend",
    "aufbauenden": "aufbauend",
    "aufbauender": "aufbauend",
    "aufbauendes": "aufbauend",
    "aufbauest": "aufbauen",
    "aufbauet": "aufbauen",
    "aufbausche": "aufbauschen",
    "aufbauschend": "aufbauschen",
    "aufbauschende": "aufbauschend",
    "aufbauschendem": "aufbauschend",
    "aufbauschenden": "aufbauschend",
    "aufbauschender": "aufbauschend",
    "aufbauschendere": "aufbauschend",
    "aufbauschenderem": "aufbauschend",
    "aufbauschenderen": "aufbauschend",
    "aufbauschenderer": "aufbauschend",
    "aufbauschenderes": "aufbauschend",
    "aufbauschendes": "aufbauschend",
    "aufbauschendste": "aufbauschend",
    "aufbauschendstem": "aufbauschend",
    "aufbauschendsten": "aufbauschend",
    "aufbauschendster": "aufbauschend",
    "aufbauschendstes": "aufbauschend",
    "aufbauschest": "aufbauschen",
    "aufbauschet": "aufbauschen",
    "aufbauschst": "aufbauschen",
    "aufbauscht": "aufbauschen",
    "aufbauschte": "aufbauschen",
    "aufbauschten": "aufbauschen",
    "aufbauschtest": "aufbauschen",
    "aufbauschtet": "aufbauschen",
    "aufbaust": "aufbauen",
    "aufbaut": "aufbauen",
    "aufbaute": "aufbauen",
    "aufbautest": "aufbauen",
    "aufbautet": "aufbauen",
    "aufbegehre": "aufbegehren",
    "aufbegehrend": "aufbegehren",
    "aufbegehrende": "aufbegehrend",
    "aufbegehrendem": "aufbegehrend",
    "aufbegehrenden": "aufbegehrend",
    "aufbegehrender": "aufbegehrend",
    "aufbegehrendere": "aufbegehrend",
    "aufbegehrenderem": "aufbegehrend",
    "aufbegehrenderen": "aufbegehrend",
    "aufbegehrenderer": "aufbegehrend",
    "aufbegehrenderes": "aufbegehrend",
    "aufbegehrendes": "aufbegehrend",
    "aufbegehrendste": "aufbegehrend",
    "aufbegehrendstem": "aufbegehrend",
    "aufbegehrendsten": "aufbegehrend",
    "aufbegehrendster": "aufbegehrend",
    "aufbegehrendstes": "aufbegehrend",
    "aufbegehrest": "aufbegehren",
    "aufbegehret": "aufbegehren",
    "aufbegehrst": "aufbegehren",
    "aufbegehrt": "aufbegehren",
    "aufbegehrte": "aufbegehren",
    "aufbegehrtem": "aufbegehrt",
    "aufbegehrten": "aufbegehren",
    "aufbegehrter": "aufbegehrt",
    "aufbegehrtere": "aufbegehrt",
    "aufbegehrterem": "aufbegehrt",
    "aufbegehrteren": "aufbegehrt",
    "aufbegehrterer": "aufbegehrt",
    "aufbegehrteres": "aufbegehrt",
    "aufbegehrtes": "aufbegehrt",
    "aufbegehrtest": "aufbegehren",
    "aufbegehrteste": "aufbegehrt",
    "aufbegehrtestem": "aufbegehrt",
    "aufbegehrtesten": "aufbegehrt",
    "aufbegehrtester": "aufbegehrt",
    "aufbegehrtestes": "aufbegehrt",
    "aufbegehrtet": "aufbegehren",
    "aufbehalte": "aufbehalten",
    "aufbehaltend": "aufbehalten",
    "aufbehaltende": "aufbehaltend",
    "aufbehaltendem": "aufbehaltend",
    "aufbehaltenden": "aufbehaltend",
    "aufbehaltender": "aufbehaltend",
    "aufbehaltendes": "aufbehaltend",
    "aufbehaltene": "aufbehalten",
    "aufbehaltenem": "aufbehalten",
    "aufbehaltenen": "aufbehalten",
    "aufbehaltener": "aufbehalten",
    "aufbehaltenes": "aufbehalten",
    "aufbehaltest": "aufbehalten",
    "aufbehaltet": "aufbehalten",
    "aufbehielt": "aufbehalten",
    "aufbehielte": "aufbehalten",
    "aufbehielten": "aufbehalten",
    "aufbehieltest": "aufbehalten",
    "aufbehieltet": "aufbehalten",
    "aufbehält": "aufbehalten",
    "aufbehältst": "aufbehalten",
    "aufbeiße": "aufbeißen",
    "aufbeißend": "aufbeißen",
    "aufbeißende": "aufbeißend",
    "aufbeißendem": "aufbeißend",
    "aufbeißenden": "aufbeißend",
    "aufbeißender": "aufbeißend",
    "aufbeißendes": "aufbeißend",
    "aufbeißest": "aufbeißen",
    "aufbeißet": "aufbeißen",
    "aufbeißt": "aufbeißen",
    "aufbekam": "aufbekommen",
    "aufbekamen": "aufbekommen",
    "aufbekamst": "aufbekommen",
    "aufbekamt": "aufbekommen",
    "aufbekomme": "aufbekommen",
    "aufbekommend": "aufbekommen",
    "aufbekommende": "aufbekommend",
    "aufbekommendem": "aufbekommend",
    "aufbekommenden": "aufbekommend",
    "aufbekommender": "aufbekommend",
    "aufbekommendes": "aufbekommend",
    "aufbekommene": "aufbekommen",
    "aufbekommenem": "aufbekommen",
    "aufbekommenen": "aufbekommen",
    "aufbekommener": "aufbekommen",
    "aufbekommenes": "aufbekommen",
    "aufbekommest": "aufbekommen",
    "aufbekommet": "aufbekommen",
    "aufbekommst": "aufbekommen",
    "aufbekommt": "aufbekommen",
    "aufbekäme": "aufbekommen",
    "aufbekämen": "aufbekommen",
    "aufbekämest": "aufbekommen",
    "aufbekämet": "aufbekommen",
    "aufbereite": "aufbereiten",
    "aufbereitend": "aufbereiten",
    "aufbereitende": "aufbereitend",
    "aufbereitendem": "aufbereitend",
    "aufbereitenden": "aufbereitend",
    "aufbereitender": "aufbereitend",
    "aufbereitendere": "aufbereitend",
    "aufbereitenderem": "aufbereitend",
    "aufbereitenderen": "aufbereitend",
    "aufbereitenderer": "aufbereitend",
    "aufbereitenderes": "aufbereitend",
    "aufbereitendes": "aufbereitend",
    "aufbereitendste": "aufbereitend",
    "aufbereitendstem": "aufbereitend",
    "aufbereitendsten": "aufbereitend",
    "aufbereitendster": "aufbereitend",
    "aufbereitendstes": "aufbereitend",
    "aufbereitest": "aufbereiten",
    "aufbereitet": "aufbereiten",
    "aufbereitete": "aufbereiten",
    "aufbereitetem": "aufbereitet",
    "aufbereiteten": "aufbereiten",
    "aufbereiteter": "aufbereitet",
    "aufbereitetere": "aufbereitet",
    "aufbereiteterem": "aufbereitet",
    "aufbereiteteren": "aufbereitet",
    "aufbereiteterer": "aufbereitet",
    "aufbereiteteres": "aufbereitet",
    "aufbereitetes": "aufbereitet",
    "aufbereitetest": "aufbereiten",
    "aufbereiteteste": "aufbereitet",
    "aufbereitetestem": "aufbereitet",
    "aufbereitetesten": "aufbereitet",
    "aufbereitetester": "aufbereitet",
    "aufbereitetestes": "aufbereitet",
    "aufbereitetet": "aufbereiten",
    "aufberitt": "aufbereiten",
    "aufberitte": "aufbereiten",
    "aufberitten": "aufbereiten",
    "aufberittene": "aufberitten",
    "aufberittenem": "aufberitten",
    "aufberittenen": "aufberitten",
    "aufberittener": "aufberitten",
    "aufberittenes": "aufberitten",
    "aufberittest": "aufbereiten",
    "aufberittet": "aufbereiten",
    "aufbeschwor": "aufbeschwören",
    "aufbeschworen": "aufbeschwören",
    "aufbeschworene": "aufbeschworen",
    "aufbeschworenem": "aufbeschworen",
    "aufbeschworenen": "aufbeschworen",
    "aufbeschworener": "aufbeschworen",
    "aufbeschworenes": "aufbeschworen",
    "aufbeschworst": "aufbeschwören",
    "aufbeschwort": "aufbeschwören",
    "aufbeschwöre": "aufbeschwören",
    "aufbeschwörend": "aufbeschwören",
    "aufbeschwörende": "aufbeschwörend",
    "aufbeschwörendem": "aufbeschwörend",
    "aufbeschwörenden": "aufbeschwörend",
    "aufbeschwörender": "aufbeschwörend",
    "aufbeschwörendes": "aufbeschwörend",
    "aufbeschwörest": "aufbeschwören",
    "aufbeschwöret": "aufbeschwören",
    "aufbeschwörst": "aufbeschwören",
    "aufbeschwört": "aufbeschwören",
    "aufbessere": "aufbessern",
    "aufbessernd": "aufbessern",
    "aufbessernde": "aufbessernd",
    "aufbesserndem": "aufbessernd",
    "aufbessernden": "aufbessernd",
    "aufbessernder": "aufbessernd",
    "aufbesserndes": "aufbessernd",
    "aufbesserst": "aufbessern",
    "aufbessert": "aufbessern",
    "aufbesserte": "aufbessern",
    "aufbesserten": "aufbessern",
    "aufbessertest": "aufbessern",
    "aufbessertet": "aufbessern",
    "aufbette": "aufbetten",
    "aufbettend": "aufbetten",
    "aufbettende": "aufbettend",
    "aufbettendem": "aufbettend",
    "aufbettenden": "aufbettend",
    "aufbettender": "aufbettend",
    "aufbettendes": "aufbettend",
    "aufbettest": "aufbetten",
    "aufbettet": "aufbetten",
    "aufbettete": "aufbetten",
    "aufbetteten": "aufbetten",
    "aufbettetest": "aufbetten",
    "aufbettetet": "aufbetten",
    "aufbewahre": "aufbewahren",
    "aufbewahrend": "aufbewahren",
    "aufbewahrende": "aufbewahrend",
    "aufbewahrendem": "aufbewahrend",
    "aufbewahrenden": "aufbewahrend",
    "aufbewahrender": "aufbewahrend",
    "aufbewahrendes": "aufbewahrend",
    "aufbewahrest": "aufbewahren",
    "aufbewahret": "aufbewahren",
    "aufbewahrst": "aufbewahren",
    "aufbewahrt": "aufbewahren",
    "aufbewahrte": "aufbewahren",
    "aufbewahrtem": "aufbewahrt",
    "aufbewahrten": "aufbewahren",
    "aufbewahrter": "aufbewahrt",
    "aufbewahrtes": "aufbewahrt",
    "aufbewahrtest": "aufbewahren",
    "aufbewahrtet": "aufbewahren",
    "aufbiege": "aufbiegen",
    "aufbiegend": "aufbiegen",
    "aufbiegende": "aufbiegend",
    "aufbiegendem": "aufbiegend",
    "aufbiegenden": "aufbiegend",
    "aufbiegender": "aufbiegend",
    "aufbiegendes": "aufbiegend",
    "aufbiegest": "aufbiegen",
    "aufbieget": "aufbiegen",
    "aufbiegst": "aufbiegen",
    "aufbiegt": "aufbiegen",
    "aufbiete": "aufbieten",
    "aufbietend": "aufbieten",
    "aufbietende": "aufbietend",
    "aufbietendem": "aufbietend",
    "aufbietenden": "aufbietend",
    "aufbietender": "aufbietend",
    "aufbietendes": "aufbietend",
    "aufbietest": "aufbieten",
    "aufbietet": "aufbieten",
    "aufbinde": "aufbinden",
    "aufbindend": "aufbinden",
    "aufbindende": "aufbindend",
    "aufbindendem": "aufbindend",
    "aufbindenden": "aufbindend",
    "aufbindender": "aufbindend",
    "aufbindendes": "aufbindend",
    "aufbindest": "aufbinden",
    "aufbindet": "aufbinden",
    "aufbisse": "aufbeißen",
    "aufbissen": "aufbeißen",
    "aufbissest": "aufbeißen",
    "aufbisset": "aufbeißen",
    "aufbiß": "aufbeißen",
    "aufbißt": "aufbeißen",
    "aufblase": "aufblasen",
    "aufblasend": "aufblasen",
    "aufblasende": "aufblasend",
    "aufblasendem": "aufblasend",
    "aufblasenden": "aufblasend",
    "aufblasender": "aufblasend",
    "aufblasendes": "aufblasend",
    "aufblasest": "aufblasen",
    "aufblaset": "aufblasen",
    "aufblast": "aufblasen",
    "aufbleibe": "aufbleiben",
    "aufbleibend": "aufbleiben",
    "aufbleibende": "aufbleibend",
    "aufbleibendem": "aufbleibend",
    "aufbleibenden": "aufbleibend",
    "aufbleibender": "aufbleibend",
    "aufbleibendes": "aufbleibend",
    "aufbleibest": "aufbleiben",
    "aufbleibet": "aufbleiben",
    "aufbleibst": "aufbleiben",
    "aufbleibt": "aufbleiben",
    "aufblende": "aufblenden",
    "aufblendend": "aufblenden",
    "aufblendende": "aufblendend",
    "aufblendendem": "aufblendend",
    "aufblendenden": "aufblendend",
    "aufblendender": "aufblendend",
    "aufblendendes": "aufblendend",
    "aufblendest": "aufblenden",
    "aufblendet": "aufblenden",
    "aufblendete": "aufblenden",
    "aufblendeten": "aufblenden",
    "aufblendetest": "aufblenden",
    "aufblendetet": "aufblenden",
    "aufblieb": "aufbleiben",
    "aufbliebe": "aufbleiben",
    "aufblieben": "aufbleiben",
    "aufbliebest": "aufbleiben",
    "aufbliebet": "aufbleiben",
    "aufbliebst": "aufbleiben",
    "aufbliebt": "aufbleiben",
    "aufblies": "aufblasen",
    "aufbliese": "aufblasen",
    "aufbliesen": "aufblasen",
    "aufbliesest": "aufblasen",
    "aufblieset": "aufblasen",
    "aufbliest": "aufblasen",
    "aufblitze": "aufblitzen",
    "aufblitzend": "aufblitzen",
    "aufblitzende": "aufblitzend",
    "aufblitzendem": "aufblitzend",
    "aufblitzenden": "aufblitzend",
    "aufblitzender": "aufblitzend",
    "aufblitzendes": "aufblitzend",
    "aufblitzest": "aufblitzen",
    "aufblitzet": "aufblitzen",
    "aufblitzt": "aufblitzen",
    "aufblitzte": "aufblitzen",
    "aufblitzten": "aufblitzen",
    "aufblitztest": "aufblitzen",
    "aufblitztet": "aufblitzen",
    "aufblähe": "aufblähen",
    "aufblähend": "aufblähen",
    "aufblähende": "aufblähend",
    "aufblähendem": "aufblähend",
    "aufblähenden": "aufblähend",
    "aufblähender": "aufblähend",
    "aufblähendere": "aufblähend",
    "aufblähenderem": "aufblähend",
    "aufblähenderen": "aufblähend",
    "aufblähenderer": "aufblähend",
    "aufblähenderes": "aufblähend",
    "aufblähendes": "aufblähend",
    "aufblähendste": "aufblähend",
    "aufblähendstem": "aufblähend",
    "aufblähendsten": "aufblähend",
    "aufblähendster": "aufblähend",
    "aufblähendstes": "aufblähend",
    "aufblähest": "aufblähen",
    "aufblähet": "aufblähen",
    "aufblähst": "aufblähen",
    "aufbläht": "aufblähen",
    "aufblähte": "aufblähen",
    "aufblähten": "aufblähen",
    "aufblähtest": "aufblähen",
    "aufblähtet": "aufblähen",
    "aufbläst": "aufblasen",
    "aufblättere": "aufblättern",
    "aufblätternd": "aufblättern",
    "aufblätternde": "aufblätternd",
    "aufblätterndem": "aufblätternd",
    "aufblätternden": "aufblätternd",
    "aufblätternder": "aufblätternd",
    "aufblätterndes": "aufblätternd",
    "aufblätterst": "aufblättern",
    "aufblättert": "aufblättern",
    "aufblätterte": "aufblättern",
    "aufblätterten": "aufblättern",
    "aufblättertest": "aufblättern",
    "aufblättertet": "aufblättern",
    "aufblühe": "aufblühen",
    "aufblühend": "aufblühen",
    "aufblühende": "aufblühend",
    "aufblühendem": "aufblühend",
    "aufblühenden": "aufblühend",
    "aufblühender": "aufblühend",
    "aufblühendere": "aufblühend",
    "aufblühenderem": "aufblühend",
    "aufblühenderen": "aufblühend",
    "aufblühenderer": "aufblühend",
    "aufblühenderes": "aufblühend",
    "aufblühendes": "aufblühend",
    "aufblühendste": "aufblühend",
    "aufblühendstem": "aufblühend",
    "aufblühendsten": "aufblühend",
    "aufblühendster": "aufblühend",
    "aufblühendstes": "aufblühend",
    "aufblühest": "aufblühen",
    "aufblühet": "aufblühen",
    "aufblühst": "aufblühen",
    "aufblüht": "aufblühen",
    "aufblühte": "aufblühen",
    "aufblühten": "aufblühen",
    "aufblühtest": "aufblühen",
    "aufblühtet": "aufblühen",
    "aufbog": "aufbiegen",
    "aufbogen": "aufbiegen",
    "aufbogst": "aufbiegen",
    "aufbogt": "aufbiegen",
    "aufbot": "aufbieten",
    "aufboten": "aufbieten",
    "aufbotest": "aufbieten",
    "aufbotet": "aufbieten",
    "aufbrach": "aufbrechen",
    "aufbrachen": "aufbrechen",
    "aufbrachst": "aufbrechen",
    "aufbracht": "aufbrechen",
    "aufbrachte": "aufbringen",
    "aufbrachten": "aufbringen",
    "aufbrachtest": "aufbringen",
    "aufbrachtet": "aufbringen",
    "aufbrannte": "aufbrennen",
    "aufbrannten": "aufbrennen",
    "aufbranntest": "aufbrennen",
    "aufbranntet": "aufbrennen",
    "aufbrate": "aufbraten",
    "aufbratend": "aufbraten",
    "aufbratende": "aufbratend",
    "aufbratendem": "aufbratend",
    "aufbratenden": "aufbratend",
    "aufbratender": "aufbratend",
    "aufbratendes": "aufbratend",
    "aufbratest": "aufbraten",
    "aufbratet": "aufbraten",
    "aufbrauche": "aufbrauchen",
    "aufbrauchend": "aufbrauchen",
    "aufbrauchende": "aufbrauchend",
    "aufbrauchendem": "aufbrauchend",
    "aufbrauchenden": "aufbrauchend",
    "aufbrauchender": "aufbrauchend",
    "aufbrauchendes": "aufbrauchend",
    "aufbrauchest": "aufbrauchen",
    "aufbrauchet": "aufbrauchen",
    "aufbrauchst": "aufbrauchen",
    "aufbraucht": "aufbrauchen",
    "aufbrauchte": "aufbrauchen",
    "aufbrauchten": "aufbrauchen",
    "aufbrauchtest": "aufbrauchen",
    "aufbrauchtet": "aufbrauchen",
    "aufbrause": "aufbrausen",
    "aufbrausend": "aufbrausen",
    "aufbrausende": "aufbrausend",
    "aufbrausendem": "aufbrausend",
    "aufbrausenden": "aufbrausend",
    "aufbrausender": "aufbrausend",
    "aufbrausendere": "aufbrausend",
    "aufbrausenderem": "aufbrausend",
    "aufbrausenderen": "aufbrausend",
    "aufbrausenderer": "aufbrausend",
    "aufbrausenderes": "aufbrausend",
    "aufbrausendes": "aufbrausend",
    "aufbrausendste": "aufbrausend",
    "aufbrausendstem": "aufbrausend",
    "aufbrausendsten": "aufbrausend",
    "aufbrausendster": "aufbrausend",
    "aufbrausendstes": "aufbrausend",
    "aufbrausest": "aufbrausen",
    "aufbrauset": "aufbrausen",
    "aufbraust": "aufbrausen",
    "aufbrauste": "aufbrausen",
    "aufbrausten": "aufbrausen",
    "aufbraustest": "aufbrausen",
    "aufbraustet": "aufbrausen",
    "aufbreche": "aufbrechen",
    "aufbrechend": "aufbrechen",
    "aufbrechende": "aufbrechend",
    "aufbrechendem": "aufbrechend",
    "aufbrechenden": "aufbrechend",
    "aufbrechender": "aufbrechend",
    "aufbrechendes": "aufbrechend",
    "aufbrechest": "aufbrechen",
    "aufbrechet": "aufbrechen",
    "aufbrecht": "aufbrechen",
    "aufbrenne": "aufbrennen",
    "aufbrennend": "aufbrennen",
    "aufbrennende": "aufbrennend",
    "aufbrennendem": "aufbrennend",
    "aufbrennenden": "aufbrennend",
    "aufbrennender": "aufbrennend",
    "aufbrennendes": "aufbrennend",
    "aufbrennest": "aufbrennen",
    "aufbrennet": "aufbrennen",
    "aufbrennst": "aufbrennen",
    "aufbrennt": "aufbrennen",
    "aufbrichst": "aufbrechen",
    "aufbricht": "aufbrechen",
    "aufbriet": "aufbraten",
    "aufbriete": "aufbraten",
    "aufbrieten": "aufbraten",
    "aufbrietest": "aufbraten",
    "aufbrietet": "aufbraten",
    "aufbringe": "aufbringen",
    "aufbringend": "aufbringen",
    "aufbringende": "aufbringend",
    "aufbringendem": "aufbringend",
    "aufbringenden": "aufbringend",
    "aufbringender": "aufbringend",
    "aufbringendes": "aufbringend",
    "aufbringest": "aufbringen",
    "aufbringet": "aufbringen",
    "aufbringst": "aufbringen",
    "aufbringt": "aufbringen",
    "aufbrumme": "aufbrummen",
    "aufbrummend": "aufbrummen",
    "aufbrummende": "aufbrummend",
    "aufbrummendem": "aufbrummend",
    "aufbrummenden": "aufbrummend",
    "aufbrummender": "aufbrummend",
    "aufbrummendere": "aufbrummend",
    "aufbrummenderem": "aufbrummend",
    "aufbrummenderen": "aufbrummend",
    "aufbrummenderer": "aufbrummend",
    "aufbrummenderes": "aufbrummend",
    "aufbrummendes": "aufbrummend",
    "aufbrummendste": "aufbrummend",
    "aufbrummendstem": "aufbrummend",
    "aufbrummendsten": "aufbrummend",
    "aufbrummendster": "aufbrummend",
    "aufbrummendstes": "aufbrummend",
    "aufbrummest": "aufbrummen",
    "aufbrummet": "aufbrummen",
    "aufbrummst": "aufbrummen",
    "aufbrummt": "aufbrummen",
    "aufbrummte": "aufbrummen",
    "aufbrummten": "aufbrummen",
    "aufbrummtest": "aufbrummen",
    "aufbrummtet": "aufbrummen",
    "aufbräche": "aufbrechen",
    "aufbrächen": "aufbrechen",
    "aufbrächest": "aufbrechen",
    "aufbrächet": "aufbrechen",
    "aufbrächte": "aufbringen",
    "aufbrächten": "aufbringen",
    "aufbrächtest": "aufbringen",
    "aufbrächtet": "aufbringen",
    "aufbrät": "aufbraten",
    "aufbrätst": "aufbraten",
    "aufbrühe": "aufbrühen",
    "aufbrühend": "aufbrühen",
    "aufbrühende": "aufbrühend",
    "aufbrühendem": "aufbrühend",
    "aufbrühenden": "aufbrühend",
    "aufbrühender": "aufbrühend",
    "aufbrühendes": "aufbrühend",
    "aufbrühest": "aufbrühen",
    "aufbrühet": "aufbrühen",
    "aufbrühst": "aufbrühen",
    "aufbrüht": "aufbrühen",
    "aufbrühte": "aufbrühen",
    "aufbrühten": "aufbrühen",
    "aufbrühtest": "aufbrühen",
    "aufbrühtet": "aufbrühen",
    "aufbände": "aufbinden",
    "aufbänden": "aufbinden",
    "aufbändest": "aufbinden",
    "aufbändet": "aufbinden",
    "aufbäume": "aufbäumen",
    "aufbäumend": "aufbäumen",
    "aufbäumende": "aufbäumend",
    "aufbäumendem": "aufbäumend",
    "aufbäumenden": "aufbäumend",
    "aufbäumender": "aufbäumend",
    "aufbäumendere": "aufbäumend",
    "aufbäumenderem": "aufbäumend",
    "aufbäumenderen": "aufbäumend",
    "aufbäumenderer": "aufbäumend",
    "aufbäumenderes": "aufbäumend",
    "aufbäumendes": "aufbäumend",
    "aufbäumendste": "aufbäumend",
    "aufbäumendstem": "aufbäumend",
    "aufbäumendsten": "aufbäumend",
    "aufbäumendster": "aufbäumend",
    "aufbäumendstes": "aufbäumend",
    "aufbäumest": "aufbäumen",
    "aufbäumet": "aufbäumen",
    "aufbäumst": "aufbäumen",
    "aufbäumt": "aufbäumen",
    "aufbäumte": "aufbäumen",
    "aufbäumten": "aufbäumen",
    "aufbäumtest": "aufbäumen",
    "aufbäumtet": "aufbäumen",
    "aufböge": "aufbiegen",
    "aufbögen": "aufbiegen",
    "aufbögest": "aufbiegen",
    "aufböget": "aufbiegen",
    "aufböte": "aufbieten",
    "aufböten": "aufbieten",
    "aufbötest": "aufbieten",
    "aufbötet": "aufbieten",
    "aufbügele": "aufbügeln",
    "aufbügelnd": "aufbügeln",
    "aufbügelnde": "aufbügelnd",
    "aufbügelndem": "aufbügelnd",
    "aufbügelnden": "aufbügelnd",
    "aufbügelnder": "aufbügelnd",
    "aufbügelndes": "aufbügelnd",
    "aufbügelst": "aufbügeln",
    "aufbügelt": "aufbügeln",
    "aufbügelte": "aufbügeln",
    "aufbügelten": "aufbügeln",
    "aufbügeltest": "aufbügeln",
    "aufbügeltet": "aufbügeln",
    "aufbügle": "aufbügeln",
    "aufbürde": "aufbürden",
    "aufbürdend": "aufbürden",
    "aufbürdende": "aufbürdend",
    "aufbürdendem": "aufbürdend",
    "aufbürdenden": "aufbürdend",
    "aufbürdender": "aufbürdend",
    "aufbürdendes": "aufbürdend",
    "aufbürdest": "aufbürden",
    "aufbürdet": "aufbürden",
    "aufbürdete": "aufbürden",
    "aufbürdeten": "aufbürden",
    "aufbürdetest": "aufbürden",
    "aufbürdetet": "aufbürden",
    "aufdampfe": "aufdampfen",
    "aufdampfend": "aufdampfen",
    "aufdampfende": "aufdampfend",
    "aufdampfendem": "aufdampfend",
    "aufdampfenden": "aufdampfend",
    "aufdampfender": "aufdampfend",
    "aufdampfendes": "aufdampfend",
    "aufdampfest": "aufdampfen",
    "aufdampfet": "aufdampfen",
    "aufdampfst": "aufdampfen",
    "aufdampft": "aufdampfen",
    "aufdampfte": "aufdampfen",
    "aufdampften": "aufdampfen",
    "aufdampftest": "aufdampfen",
    "aufdampftet": "aufdampfen",
    "aufdecke": "aufdecken",
    "aufdeckend": "aufdecken",
    "aufdeckende": "aufdeckend",
    "aufdeckendem": "aufdeckend",
    "aufdeckenden": "aufdeckend",
    "aufdeckender": "aufdeckend",
    "aufdeckendes": "aufdeckend",
    "aufdeckest": "aufdecken",
    "aufdecket": "aufdecken",
    "aufdeckst": "aufdecken",
    "aufdeckt": "aufdecken",
    "aufdeckte": "aufdecken",
    "aufdeckten": "aufdecken",
    "aufdecktest": "aufdecken",
    "aufdecktet": "aufdecken",
    "aufdonnere": "aufdonnern",
    "aufdonnernd": "aufdonnern",
    "aufdonnernde": "aufdonnernd",
    "aufdonnerndem": "aufdonnernd",
    "aufdonnernden": "aufdonnernd",
    "aufdonnernder": "aufdonnernd",
    "aufdonnerndere": "aufdonnernd",
    "aufdonnernderem": "aufdonnernd",
    "aufdonnernderen": "aufdonnernd",
    "aufdonnernderer": "aufdonnernd",
    "aufdonnernderes": "aufdonnernd",
    "aufdonnerndes": "aufdonnernd",
    "aufdonnerndste": "aufdonnernd",
    "aufdonnerndstem": "aufdonnernd",
    "aufdonnerndsten": "aufdonnernd",
    "aufdonnerndster": "aufdonnernd",
    "aufdonnerndstes": "aufdonnernd",
    "aufdonnerst": "aufdonnern",
    "aufdonnert": "aufdonnern",
    "aufdonnerte": "aufdonnern",
    "aufdonnerten": "aufdonnern",
    "aufdonnertest": "aufdonnern",
    "aufdonnertet": "aufdonnern",
    "aufdrehe": "aufdrehen",
    "aufdrehend": "aufdrehen",
    "aufdrehende": "aufdrehend",
    "aufdrehendem": "aufdrehend",
    "aufdrehenden": "aufdrehend",
    "aufdrehender": "aufdrehend",
    "aufdrehendere": "aufdrehend",
    "aufdrehenderem": "aufdrehend",
    "aufdrehenderen": "aufdrehend",
    "aufdrehenderer": "aufdrehend",
    "aufdrehenderes": "aufdrehend",
    "aufdrehendes": "aufdrehend",
    "aufdrehendste": "aufdrehend",
    "aufdrehendstem": "aufdrehend",
    "aufdrehendsten": "aufdrehend",
    "aufdrehendster": "aufdrehend",
    "aufdrehendstes": "aufdrehend",
    "aufdrehest": "aufdrehen",
    "aufdrehet": "aufdrehen",
    "aufdrehst": "aufdrehen",
    "aufdreht": "aufdrehen",
    "aufdrehte": "aufdrehen",
    "aufdrehten": "aufdrehen",
    "aufdrehtest": "aufdrehen",
    "aufdrehtet": "aufdrehen",
    "aufdringliche": "aufdringlich",
    "aufdringlichem": "aufdringlich",
    "aufdringlichen": "aufdringlich",
    "aufdringlicher": "aufdringlich",
    "aufdringlichere": "aufdringlich",
    "aufdringlicherem": "aufdringlich",
    "aufdringlicheren": "aufdringlich",
    "aufdringlicherer": "aufdringlich",
    "aufdringlicheres": "aufdringlich",
    "aufdringliches": "aufdringlich",
    "aufdringlichste": "aufdringlich",
    "aufdringlichstem": "aufdringlich",
    "aufdringlichsten": "aufdringlich",
    "aufdringlichster": "aufdringlich",
    "aufdringlichstes": "aufdringlich",
    "aufdränge": "aufdrängen",
    "aufdrängend": "aufdrängen",
    "aufdrängende": "aufdrängend",
    "aufdrängendem": "aufdrängend",
    "aufdrängenden": "aufdrängend",
    "aufdrängender": "aufdrängend",
    "aufdrängendere": "aufdrängend",
    "aufdrängenderem": "aufdrängend",
    "aufdrängenderen": "aufdrängend",
    "aufdrängenderer": "aufdrängend",
    "aufdrängenderes": "aufdrängend",
    "aufdrängendes": "aufdrängend",
    "aufdrängendste": "aufdrängend",
    "aufdrängendstem": "aufdrängend",
    "aufdrängendsten": "aufdrängend",
    "aufdrängendster": "aufdrängend",
    "aufdrängendstes": "aufdrängend",
    "aufdrängest": "aufdrängen",
    "aufdränget": "aufdrängen",
    "aufdrängst": "aufdrängen",
    "aufdrängt": "aufdrängen",
    "aufdrängte": "aufdrängen",
    "aufdrängten": "aufdrängen",
    "aufdrängtest": "aufdrängen",
    "aufdrängtet": "aufdrängen",
    "aufdrösele": "aufdröseln",
    "aufdröselnd": "aufdröseln",
    "aufdröselnde": "aufdröselnd",
    "aufdröselndem": "aufdröselnd",
    "aufdröselnden": "aufdröselnd",
    "aufdröselnder": "aufdröselnd",
    "aufdröselndere": "aufdröselnd",
    "aufdröselnderem": "aufdröselnd",
    "aufdröselnderen": "aufdröselnd",
    "aufdröselnderer": "aufdröselnd",
    "aufdröselnderes": "aufdröselnd",
    "aufdröselndes": "aufdröselnd",
    "aufdröselndste": "aufdröselnd",
    "aufdröselndstem": "aufdröselnd",
    "aufdröselndsten": "aufdröselnd",
    "aufdröselndster": "aufdröselnd",
    "aufdröselndstes": "aufdröselnd",
    "aufdröselst": "aufdröseln",
    "aufdröselt": "aufdröseln",
    "aufdröselte": "aufdröseln",
    "aufdröselten": "aufdröseln",
    "aufdröseltest": "aufdröseln",
    "aufdröseltet": "aufdröseln",
    "aufdrösle": "aufdröseln",
    "aufdrücke": "aufdrücken",
    "aufdrückend": "aufdrücken",
    "aufdrückende": "aufdrückend",
    "aufdrückendem": "aufdrückend",
    "aufdrückenden": "aufdrückend",
    "aufdrückender": "aufdrückend",
    "aufdrückendes": "aufdrückend",
    "aufdrückest": "aufdrücken",
    "aufdrücket": "aufdrücken",
    "aufdrückst": "aufdrücken",
    "aufdrückt": "aufdrücken",
    "aufdrückte": "aufdrücken",
    "aufdrückten": "aufdrücken",
    "aufdrücktest": "aufdrücken",
    "aufdrücktet": "aufdrücken",
    "aufdämme": "aufdämmen",
    "aufdämmend": "aufdämmen",
    "aufdämmende": "aufdämmend",
    "aufdämmendem": "aufdämmend",
    "aufdämmenden": "aufdämmend",
    "aufdämmender": "aufdämmend",
    "aufdämmendes": "aufdämmend",
    "aufdämmest": "aufdämmen",
    "aufdämmet": "aufdämmen",
    "aufdämmst": "aufdämmen",
    "aufdämmt": "aufdämmen",
    "aufdämmte": "aufdämmen",
    "aufdämmten": "aufdämmen",
    "aufdämmtest": "aufdämmen",
    "aufdämmtet": "aufdämmen",
    "auferlege": "auferlegen",
    "auferlegend": "auferlegen",
    "auferlegende": "auferlegend",
    "auferlegendem": "auferlegend",
    "auferlegenden": "auferlegend",
    "auferlegender": "auferlegend",
    "auferlegendes": "auferlegend",
    "auferlegest": "auferlegen",
    "auferleget": "auferlegen",
    "auferlegst": "auferlegen",
    "auferlegt": "auferlegen",
    "auferlegte": "auferlegen",
    "auferlegtem": "auferlegt",
    "auferlegten": "auferlegen",
    "auferlegter": "auferlegt",
    "auferlegtes": "auferlegt",
    "auferlegtest": "auferlegen",
    "auferlegtet": "auferlegen",
    "auferstand": "auferstehen",
    "auferstanden": "auferstehen",
    "auferstandene": "auferstanden",
    "auferstandenem": "auferstanden",
    "auferstandenen": "auferstanden",
    "auferstandener": "auferstanden",
    "auferstandenes": "auferstanden",
    "auferstandest": "auferstehen",
    "auferstandet": "auferstehen",
    "auferstehe": "auferstehen",
    "auferstehend": "auferstehen",
    "auferstehende": "auferstehend",
    "auferstehendem": "auferstehend",
    "auferstehenden": "auferstehend",
    "auferstehender": "auferstehend",
    "auferstehendes": "auferstehend",
    "auferstehest": "auferstehen",
    "auferstehet": "auferstehen",
    "auferstehst": "auferstehen",
    "aufersteht": "auferstehen",
    "auferstünde": "auferstehen",
    "auferstünden": "auferstehen",
    "auferstündest": "auferstehen",
    "auferstündet": "auferstehen",
    "aufesse": "aufessen",
    "aufessend": "aufessen",
    "aufessende": "aufessend",
    "aufessendem": "aufessend",
    "aufessenden": "aufessend",
    "aufessender": "aufessend",
    "aufessendes": "aufessend",
    "aufessest": "aufessen",
    "aufesset": "aufessen",
    "aufeßt": "aufessen",
    "auffahre": "auffahren",
    "auffahrend": "auffahren",
    "auffahrende": "auffahrend",
    "auffahrendem": "auffahrend",
    "auffahrenden": "auffahrend",
    "auffahrender": "auffahrend",
    "auffahrendes": "auffahrend",
    "auffahrest": "auffahren",
    "auffahret": "auffahren",
    "auffahrt": "auffahren",
    "auffalle": "auffallen",
    "auffallend": "auffallen",
    "auffallende": "auffallend",
    "auffallendem": "auffallend",
    "auffallenden": "auffallend",
    "auffallender": "auffallend",
    "auffallendere": "auffallend",
    "auffallenderem": "auffallend",
    "auffallenderen": "auffallend",
    "auffallenderer": "auffallend",
    "auffallenderes": "auffallend",
    "auffallendes": "auffallend",
    "auffallendste": "auffallend",
    "auffallendstem": "auffallend",
    "auffallendsten": "auffallend",
    "auffallendster": "auffallend",
    "auffallendstes": "auffallend",
    "auffallest": "auffallen",
    "auffallet": "auffallen",
    "auffallt": "auffallen",
    "auffand": "auffinden",
    "auffanden": "auffinden",
    "auffandest": "auffinden",
    "auffandet": "auffinden",
    "auffange": "auffangen",
    "auffangend": "auffangen",
    "auffangende": "auffangend",
    "auffangendem": "auffangend",
    "auffangenden": "auffangend",
    "auffangender": "auffangend",
    "auffangendes": "auffangend",
    "auffangest": "auffangen",
    "auffanget": "auffangen",
    "auffangt": "auffangen",
    "auffasse": "auffassen",
    "auffassend": "auffassen",
    "auffassende": "auffassend",
    "auffassendem": "auffassend",
    "auffassenden": "auffassend",
    "auffassender": "auffassend",
    "auffassendes": "auffassend",
    "auffassest": "auffassen",
    "auffasset": "auffassen",
    "auffaßt": "auffassen",
    "auffaßte": "auffassen",
    "auffaßten": "auffassen",
    "auffaßtest": "auffassen",
    "auffaßtet": "auffassen",
    "auffiel": "auffallen",
    "auffiele": "auffallen",
    "auffielen": "auffallen",
    "auffielest": "auffallen",
    "auffielet": "auffallen",
    "auffielst": "auffallen",
    "auffielt": "auffallen",
    "auffinde": "auffinden",
    "auffindend": "auffinden",
    "auffindende": "auffindend",
    "auffindendem": "auffindend",
    "auffindenden": "auffindend",
    "auffindender": "auffindend",
    "auffindendes": "auffindend",
    "auffindest": "auffinden",
    "auffindet": "auffinden",
    "auffing": "auffangen",
    "auffinge": "auffangen",
    "auffingen": "auffangen",
    "auffingest": "auffangen",
    "auffinget": "auffangen",
    "auffingst": "auffangen",
    "auffingt": "auffangen",
    "auffische": "auffischen",
    "auffischend": "auffischen",
    "auffischende": "auffischend",
    "auffischendem": "auffischend",
    "auffischenden": "auffischend",
    "auffischender": "auffischend",
    "auffischendes": "auffischend",
    "auffischest": "auffischen",
    "auffischet": "auffischen",
    "auffischst": "auffischen",
    "auffischt": "auffischen",
    "auffischte": "auffischen",
    "auffischten": "auffischen",
    "auffischtest": "auffischen",
    "auffischtet": "auffischen",
    "aufflamme": "aufflammen",
    "aufflammend": "aufflammen",
    "aufflammende": "aufflammend",
    "aufflammendem": "aufflammend",
    "aufflammenden": "aufflammend",
    "aufflammender": "aufflammend",
    "aufflammendere": "aufflammend",
    "aufflammenderem": "aufflammend",
    "aufflammenderen": "aufflammend",
    "aufflammenderer": "aufflammend",
    "aufflammenderes": "aufflammend",
    "aufflammendes": "aufflammend",
    "aufflammendste": "aufflammend",
    "aufflammendstem": "aufflammend",
    "aufflammendsten": "aufflammend",
    "aufflammendster": "aufflammend",
    "aufflammendstes": "aufflammend",
    "aufflammest": "aufflammen",
    "aufflammet": "aufflammen",
    "aufflammst": "aufflammen",
    "aufflammt": "aufflammen",
    "aufflammte": "aufflammen",
    "aufflammten": "aufflammen",
    "aufflammtest": "aufflammen",
    "aufflammtet": "aufflammen",
    "auffliege": "auffliegen",
    "auffliegend": "auffliegen",
    "auffliegende": "auffliegend",
    "auffliegendem": "auffliegend",
    "auffliegenden": "auffliegend",
    "auffliegender": "auffliegend",
    "auffliegendes": "auffliegend",
    "auffliegest": "auffliegen",
    "aufflieget": "auffliegen",
    "auffliegst": "auffliegen",
    "auffliegt": "auffliegen",
    "aufflog": "auffliegen",
    "aufflogen": "auffliegen",
    "aufflogst": "auffliegen",
    "aufflogt": "auffliegen",
    "aufflöge": "auffliegen",
    "aufflögen": "auffliegen",
    "aufflögest": "auffliegen",
    "aufflöget": "auffliegen",
    "auffordere": "auffordern",
    "auffordernd": "auffordern",
    "auffordernde": "auffordernd",
    "aufforderndem": "auffordernd",
    "auffordernden": "auffordernd",
    "auffordernder": "auffordernd",
    "aufforderndere": "auffordernd",
    "auffordernderem": "auffordernd",
    "auffordernderen": "auffordernd",
    "auffordernderer": "auffordernd",
    "auffordernderes": "auffordernd",
    "aufforderndes": "auffordernd",
    "aufforderndste": "auffordernd",
    "aufforderndstem": "auffordernd",
    "aufforderndsten": "auffordernd",
    "aufforderndster": "auffordernd",
    "aufforderndstes": "auffordernd",
    "aufforderst": "auffordern",
    "auffordert": "auffordern",
    "aufforderte": "auffordern",
    "aufforderten": "auffordern",
    "auffordertest": "auffordern",
    "auffordertet": "auffordern",
    "aufforste": "aufforsten",
    "aufforstend": "aufforsten",
    "aufforstende": "aufforstend",
    "aufforstendem": "aufforstend",
    "aufforstenden": "aufforstend",
    "aufforstender": "aufforstend",
    "aufforstendes": "aufforstend",
    "aufforstest": "aufforsten",
    "aufforstet": "aufforsten",
    "aufforstete": "aufforsten",
    "aufforsteten": "aufforsten",
    "aufforstetest": "aufforsten",
    "aufforstetet": "aufforsten",
    "auffraß": "auffressen",
    "auffraßen": "auffressen",
    "auffraßt": "auffressen",
    "auffresse": "auffressen",
    "auffressend": "auffressen",
    "auffressende": "auffressend",
    "auffressendem": "auffressend",
    "auffressenden": "auffressend",
    "auffressender": "auffressend",
    "auffressendes": "auffressend",
    "auffressest": "auffressen",
    "auffresset": "auffressen",
    "auffreßt": "auffressen",
    "auffrische": "auffrischen",
    "auffrischend": "auffrischen",
    "auffrischende": "auffrischend",
    "auffrischendem": "auffrischend",
    "auffrischenden": "auffrischend",
    "auffrischender": "auffrischend",
    "auffrischendere": "auffrischend",
    "auffrischenderem": "auffrischend",
    "auffrischenderen": "auffrischend",
    "auffrischenderer": "auffrischend",
    "auffrischenderes": "auffrischend",
    "auffrischendes": "auffrischend",
    "auffrischendste": "auffrischend",
    "auffrischendstem": "auffrischend",
    "auffrischendsten": "auffrischend",
    "auffrischendster": "auffrischend",
    "auffrischendstes": "auffrischend",
    "auffrischest": "auffrischen",
    "auffrischet": "auffrischen",
    "auffrischst": "auffrischen",
    "auffrischt": "auffrischen",
    "auffrischte": "auffrischen",
    "auffrischten": "auffrischen",
    "auffrischtest": "auffrischen",
    "auffrischtet": "auffrischen",
    "auffrißt": "auffressen",
    "auffräße": "auffressen",
    "auffräßen": "auffressen",
    "auffräßest": "auffressen",
    "auffräßet": "auffressen",
    "auffuhr": "auffahren",
    "auffuhren": "auffahren",
    "auffuhrst": "auffahren",
    "auffuhrt": "auffahren",
    "auffädele": "auffädeln",
    "auffädelnd": "auffädeln",
    "auffädelnde": "auffädelnd",
    "auffädelndem": "auffädelnd",
    "auffädelnden": "auffädelnd",
    "auffädelnder": "auffädelnd",
    "auffädelndes": "auffädelnd",
    "auffädelst": "auffädeln",
    "auffädelt": "auffädeln",
    "auffädelte": "auffädeln",
    "auffädelten": "auffädeln",
    "auffädeltest": "auffädeln",
    "auffädeltet": "auffädeln",
    "auffädle": "auffädeln",
    "auffährst": "auffahren",
    "auffährt": "auffahren",
    "auffällige": "auffällig",
    "auffälligem": "auffällig",
    "auffälligen": "auffällig",
    "auffälliger": "auffällig",
    "auffälligere": "auffällig",
    "auffälligerem": "auffällig",
    "auffälligeren": "auffällig",
    "auffälligerer": "auffällig",
    "auffälligeres": "auffällig",
    "auffälliges": "auffällig",
    "auffälligste": "auffällig",
    "auffälligstem": "auffällig",
    "auffälligsten": "auffällig",
    "auffälligster": "auffällig",
    "auffälligstes": "auffällig",
    "auffällst": "auffallen",
    "auffällt": "auffallen",
    "auffände": "auffinden",
    "auffänden": "auffinden",
    "auffändest": "auffinden",
    "auffändet": "auffinden",
    "auffängst": "auffangen",
    "auffängt": "auffangen",
    "auffärbe": "auffärben",
    "auffärbend": "auffärben",
    "auffärbende": "auffärbend",
    "auffärbendem": "auffärbend",
    "auffärbenden": "auffärbend",
    "auffärbender": "auffärbend",
    "auffärbendes": "auffärbend",
    "auffärbest": "auffärben",
    "auffärbet": "auffärben",
    "auffärbst": "auffärben",
    "auffärbt": "auffärben",
    "auffärbte": "auffärben",
    "auffärbten": "auffärben",
    "auffärbtest": "auffärben",
    "auffärbtet": "auffärben",
    "aufführe": "aufführen",
    "aufführen": "auffahren",
    "aufführend": "aufführen",
    "aufführende": "aufführend",
    "aufführendem": "aufführend",
    "aufführenden": "aufführend",
    "aufführender": "aufführend",
    "aufführendes": "aufführend",
    "aufführest": "aufführen",
    "aufführet": "aufführen",
    "aufführst": "aufführen",
    "aufführt": "aufführen",
    "aufführte": "aufführen",
    "aufführten": "aufführen",
    "aufführtest": "aufführen",
    "aufführtet": "aufführen",
    "auffülle": "auffüllen",
    "auffüllend": "auffüllen",
    "auffüllende": "auffüllend",
    "auffüllendem": "auffüllend",
    "auffüllenden": "auffüllend",
    "auffüllender": "auffüllend",
    "auffüllendes": "auffüllend",
    "auffüllest": "auffüllen",
    "auffüllet": "auffüllen",
    "auffüllst": "auffüllen",
    "auffüllt": "auffüllen",
    "auffüllte": "auffüllen",
    "auffüllten": "auffüllen",
    "auffülltest": "auffüllen",
    "auffülltet": "auffüllen",
    "aufgab": "aufgeben",
    "aufgabele": "aufgabeln",
    "aufgabelnd": "aufgabeln",
    "aufgabelnde": "aufgabelnd",
    "aufgabelndem": "aufgabelnd",
    "aufgabelnden": "aufgabelnd",
    "aufgabelnder": "aufgabelnd",
    "aufgabelndes": "aufgabelnd",
    "aufgabelst": "aufgabeln",
    "aufgabelt": "aufgabeln",
    "aufgabelte": "aufgabeln",
    "aufgabelten": "aufgabeln",
    "aufgabeltest": "aufgabeln",
    "aufgabeltet": "aufgabeln",
    "aufgable": "aufgabeln",
    "aufgabst": "aufgeben",
    "aufgabt": "aufgeben",
    "aufgaloppiere": "aufgaloppieren",
    "aufgaloppierend": "aufgaloppieren",
    "aufgaloppierende": "aufgaloppierend",
    "aufgaloppierendem": "aufgaloppierend",
    "aufgaloppierenden": "aufgaloppierend",
    "aufgaloppierender": "aufgaloppierend",
    "aufgaloppierendes": "aufgaloppierend",
    "aufgaloppierest": "aufgaloppieren",
    "aufgaloppieret": "aufgaloppieren",
    "aufgaloppierst": "aufgaloppieren",
    "aufgaloppiert": "aufgaloppieren",
    "aufgaloppierte": "aufgaloppieren",
    "aufgaloppiertem": "aufgaloppiert",
    "aufgaloppierten": "aufgaloppieren",
    "aufgaloppierter": "aufgaloppiert",
    "aufgaloppiertes": "aufgaloppiert",
    "aufgaloppiertest": "aufgaloppieren",
    "aufgaloppiertet": "aufgaloppieren",
    "aufgearbeitet": "aufarbeiten",
    "aufgearbeitete": "aufgearbeitet",
    "aufgearbeitetem": "aufgearbeitet",
    "aufgearbeiteten": "aufgearbeitet",
    "aufgearbeiteter": "aufgearbeitet",
    "aufgearbeitetes": "aufgearbeitet",
    "aufgeatmet": "aufatmen",
    "aufgeatmete": "aufgeatmet",
    "aufgeatmetem": "aufgeatmet",
    "aufgeatmeten": "aufgeatmet",
    "aufgeatmeter": "aufgeatmet",
    "aufgeatmetes": "aufgeatmet",
    "aufgebacken": "aufbacken",
    "aufgebackene": "aufgebacken",
    "aufgebackenem": "aufgebacken",
    "aufgebackenen": "aufgebacken",
    "aufgebackener": "aufgebacken",
    "aufgebackenere": "aufgebacken",
    "aufgebackenerem": "aufgebacken",
    "aufgebackeneren": "aufgebacken",
    "aufgebackenerer": "aufgebacken",
    "aufgebackeneres": "aufgebacken",
    "aufgebackenes": "aufgebacken",
    "aufgebackenste": "aufgebacken",
    "aufgebackenstem": "aufgebacken",
    "aufgebackensten": "aufgebacken",
    "aufgebackenster": "aufgebacken",
    "aufgebackenstes": "aufgebacken",
    "aufgebahrt": "aufbahren",
    "aufgebahrte": "aufgebahrt",
    "aufgebahrtem": "aufgebahrt",
    "aufgebahrten": "aufgebahrt",
    "aufgebahrter": "aufgebahrt",
    "aufgebahrtes": "aufgebahrt",
    "aufgebauscht": "aufbauschen",
    "aufgebauschte": "aufgebauscht",
    "aufgebauschtem": "aufgebauscht",
    "aufgebauschten": "aufgebauscht",
    "aufgebauschter": "aufgebauscht",
    "aufgebauschtere": "aufgebauscht",
    "aufgebauschterem": "aufgebauscht",
    "aufgebauschteren": "aufgebauscht",
    "aufgebauschterer": "aufgebauscht",
    "aufgebauschteres": "aufgebauscht",
    "aufgebauschtes": "aufgebauscht",
    "aufgebauschteste": "aufgebauscht",
    "aufgebauschtestem": "aufgebauscht",
    "aufgebauschtesten": "aufgebauscht",
    "aufgebauschtester": "aufgebauscht",
    "aufgebauschtestes": "aufgebauscht",
    "aufgebaut": "aufbauen",
    "aufgebaute": "aufgebaut",
    "aufgebautem": "aufgebaut",
    "aufgebauten": "aufgebaut",
    "aufgebauter": "aufgebaut",
    "aufgebautes": "aufgebaut",
    "aufgebe": "aufgeben",
    "aufgebend": "aufgeben",
    "aufgebende": "aufgebend",
    "aufgebendem": "aufgebend",
    "aufgebenden": "aufgebend",
    "aufgebender": "aufgebend",
    "aufgebendes": "aufgebend",
    "aufgebessert": "aufbessern",
    "aufgebesserte": "aufgebessert",
    "aufgebessertem": "aufgebessert",
    "aufgebesserten": "aufgebessert",
    "aufgebesserter": "aufgebessert",
    "aufgebessertes": "aufgebessert",
    "aufgebest": "aufgeben",
    "aufgebet": "aufgeben",
    "aufgebettet": "aufbetten",
    "aufgebettete": "aufgebettet",
    "aufgebettetem": "aufgebettet",
    "aufgebetteten": "aufgebettet",
    "aufgebetteter": "aufgebettet",
    "aufgebettetes": "aufgebettet",
    "aufgebissen": "aufbeißen",
    "aufgebissene": "aufgebissen",
    "aufgebissenem": "aufgebissen",
    "aufgebissenen": "aufgebissen",
    "aufgebissener": "aufgebissen",
    "aufgebissenes": "aufgebissen",
    "aufgeblasen": "aufblasen",
    "aufgeblasene": "aufgeblasen",
    "aufgeblasenem": "aufgeblasen",
    "aufgeblasenen": "aufgeblasen",
    "aufgeblasener": "aufgeblasen",
    "aufgeblasenere": "aufgeblasen",
    "aufgeblasenerem": "aufgeblasen",
    "aufgeblaseneren": "aufgeblasen",
    "aufgeblasenerer": "aufgeblasen",
    "aufgeblaseneres": "aufgeblasen",
    "aufgeblasenes": "aufgeblasen",
    "aufgeblasenste": "aufgeblasen",
    "aufgeblasenstem": "aufgeblasen",
    "aufgeblasensten": "aufgeblasen",
    "aufgeblasenster": "aufgeblasen",
    "aufgeblasenstes": "aufgeblasen",
    "aufgeblendet": "aufblenden",
    "aufgeblendete": "aufgeblendet",
    "aufgeblendetem": "aufgeblendet",
    "aufgeblendeten": "aufgeblendet",
    "aufgeblendeter": "aufgeblendet",
    "aufgeblendetes": "aufgeblendet",
    "aufgeblieben": "aufbleiben",
    "aufgebliebene": "aufgeblieben",
    "aufgebliebenem": "aufgeblieben",
    "aufgebliebenen": "aufgeblieben",
    "aufgebliebener": "aufgeblieben",
    "aufgebliebenes": "aufgeblieben",
    "aufgeblitzt": "aufblitzen",
    "aufgeblitzte": "aufgeblitzt",
    "aufgeblitztem": "aufgeblitzt",
    "aufgeblitzten": "aufgeblitzt",
    "aufgeblitzter": "aufgeblitzt",
    "aufgeblitztes": "aufgeblitzt",
    "aufgebläht": "aufblähen",
    "aufgeblähte": "aufgebläht",
    "aufgeblähtem": "aufgebläht",
    "aufgeblähten": "aufgebläht",
    "aufgeblähter": "aufgebläht",
    "aufgeblähtere": "aufgebläht",
    "aufgeblähterem": "aufgebläht",
    "aufgeblähteren": "aufgebläht",
    "aufgeblähterer": "aufgebläht",
    "aufgeblähteres": "aufgebläht",
    "aufgeblähtes": "aufgebläht",
    "aufgeblähteste": "aufgebläht",
    "aufgeblähtestem": "aufgebläht",
    "aufgeblähtesten": "aufgebläht",
    "aufgeblähtester": "aufgebläht",
    "aufgeblähtestes": "aufgebläht",
    "aufgeblättert": "aufblättern",
    "aufgeblätterte": "aufgeblättert",
    "aufgeblättertem": "aufgeblättert",
    "aufgeblätterten": "aufgeblättert",
    "aufgeblätterter": "aufgeblättert",
    "aufgeblättertes": "aufgeblättert",
    "aufgeblüht": "aufblühen",
    "aufgeblühte": "aufgeblüht",
    "aufgeblühtem": "aufgeblüht",
    "aufgeblühten": "aufgeblüht",
    "aufgeblühter": "aufgeblüht",
    "aufgeblühtere": "aufgeblüht",
    "aufgeblühterem": "aufgeblüht",
    "aufgeblühteren": "aufgeblüht",
    "aufgeblühterer": "aufgeblüht",
    "aufgeblühteres": "aufgeblüht",
    "aufgeblühtes": "aufgeblüht",
    "aufgeblühteste": "aufgeblüht",
    "aufgeblühtestem": "aufgeblüht",
    "aufgeblühtesten": "aufgeblüht",
    "aufgeblühtester": "aufgeblüht",
    "aufgeblühtestes": "aufgeblüht",
    "aufgebogen": "aufbiegen",
    "aufgebogene": "aufgebogen",
    "aufgebogenem": "aufgebogen",
    "aufgebogenen": "aufgebogen",
    "aufgebogener": "aufgebogen",
    "aufgebogenes": "aufgebogen",
    "aufgebotenem": "aufgeboten",
    "aufgebotenen": "aufgeboten",
    "aufgebotener": "aufgeboten",
    "aufgebotenere": "aufgeboten",
    "aufgebotenerem": "aufgeboten",
    "aufgeboteneren": "aufgeboten",
    "aufgebotenerer": "aufgeboten",
    "aufgeboteneres": "aufgeboten",
    "aufgebotenes": "aufgeboten",
    "aufgebotenste": "aufgeboten",
    "aufgebotenstem": "aufgeboten",
    "aufgebotensten": "aufgeboten",
    "aufgebotenster": "aufgeboten",
    "aufgebotenstes": "aufgeboten",
    "aufgebracht": "aufbringen",
    "aufgebrachte": "aufgebracht",
    "aufgebrachtem": "aufgebracht",
    "aufgebrachten": "aufgebracht",
    "aufgebrachter": "aufgebracht",
    "aufgebrachtere": "aufgebracht",
    "aufgebrachterem": "aufgebracht",
    "aufgebrachteren": "aufgebracht",
    "aufgebrachterer": "aufgebracht",
    "aufgebrachteres": "aufgebracht",
    "aufgebrachtes": "aufgebracht",
    "aufgebrachteste": "aufgebracht",
    "aufgebrachtestem": "aufgebracht",
    "aufgebrachtesten": "aufgebracht",
    "aufgebrachtester": "aufgebracht",
    "aufgebrachtestes": "aufgebracht",
    "aufgebrannt": "aufbrennen",
    "aufgebrannte": "aufgebrannt",
    "aufgebranntem": "aufgebrannt",
    "aufgebrannten": "aufgebrannt",
    "aufgebrannter": "aufgebrannt",
    "aufgebranntes": "aufgebrannt",
    "aufgebraten": "aufbraten",
    "aufgebratene": "aufgebraten",
    "aufgebratenem": "aufgebraten",
    "aufgebratenen": "aufgebraten",
    "aufgebratener": "aufgebraten",
    "aufgebratenes": "aufgebraten",
    "aufgebraucht": "aufbrauchen",
    "aufgebrauchte": "aufgebraucht",
    "aufgebrauchtem": "aufgebraucht",
    "aufgebrauchten": "aufgebraucht",
    "aufgebrauchter": "aufgebraucht",
    "aufgebrauchtes": "aufgebraucht",
    "aufgebraust": "aufbrausen",
    "aufgebrauste": "aufgebraust",
    "aufgebraustem": "aufgebraust",
    "aufgebrausten": "aufgebraust",
    "aufgebrauster": "aufgebraust",
    "aufgebraustere": "aufgebraust",
    "aufgebrausterem": "aufgebraust",
    "aufgebrausteren": "aufgebraust",
    "aufgebrausterer": "aufgebraust",
    "aufgebrausteres": "aufgebraust",
    "aufgebraustes": "aufgebraust",
    "aufgebrausteste": "aufgebraust",
    "aufgebraustestem": "aufgebraust",
    "aufgebraustesten": "aufgebraust",
    "aufgebraustester": "aufgebraust",
    "aufgebraustestes": "aufgebraust",
    "aufgebrochen": "aufbrechen",
    "aufgebrochene": "aufgebrochen",
    "aufgebrochenem": "aufgebrochen",
    "aufgebrochenen": "aufgebrochen",
    "aufgebrochener": "aufgebrochen",
    "aufgebrochenere": "aufgebrochen",
    "aufgebrochenerem": "aufgebrochen",
    "aufgebrocheneren": "aufgebrochen",
    "aufgebrochenerer": "aufgebrochen",
    "aufgebrocheneres": "aufgebrochen",
    "aufgebrochenes": "aufgebrochen",
    "aufgebrochenste": "aufgebrochen",
    "aufgebrochenstem": "aufgebrochen",
    "aufgebrochensten": "aufgebrochen",
    "aufgebrochenster": "aufgebrochen",
    "aufgebrochenstes": "aufgebrochen",
    "aufgebrummt": "aufbrummen",
    "aufgebrummte": "aufgebrummt",
    "aufgebrummtem": "aufgebrummt",
    "aufgebrummten": "aufgebrummt",
    "aufgebrummter": "aufgebrummt",
    "aufgebrummtere": "aufgebrummt",
    "aufgebrummterem": "aufgebrummt",
    "aufgebrummteren": "aufgebrummt",
    "aufgebrummterer": "aufgebrummt",
    "aufgebrummteres": "aufgebrummt",
    "aufgebrummtes": "aufgebrummt",
    "aufgebrummteste": "aufgebrummt",
    "aufgebrummtestem": "aufgebrummt",
    "aufgebrummtesten": "aufgebrummt",
    "aufgebrummtester": "aufgebrummt",
    "aufgebrummtestes": "aufgebrummt",
    "aufgebrüht": "aufbrühen",
    "aufgebrühte": "aufgebrüht",
    "aufgebrühtem": "aufgebrüht",
    "aufgebrühten": "aufgebrüht",
    "aufgebrühter": "aufgebrüht",
    "aufgebrühtes": "aufgebrüht",
    "aufgebt": "aufgeben",
    "aufgebunden": "aufbinden",
    "aufgebundene": "aufgebunden",
    "aufgebundenem": "aufgebunden",
    "aufgebundenen": "aufgebunden",
    "aufgebundener": "aufgebunden",
    "aufgebundenes": "aufgebunden",
    "aufgebäumt": "aufbäumen",
    "aufgebäumte": "aufgebäumt",
    "aufgebäumtem": "aufgebäumt",
    "aufgebäumten": "aufgebäumt",
    "aufgebäumter": "aufgebäumt",
    "aufgebäumtere": "aufgebäumt",
    "aufgebäumterem": "aufgebäumt",
    "aufgebäumteren": "aufgebäumt",
    "aufgebäumterer": "aufgebäumt",
    "aufgebäumteres": "aufgebäumt",
    "aufgebäumtes": "aufgebäumt",
    "aufgebäumteste": "aufgebäumt",
    "aufgebäumtestem": "aufgebäumt",
    "aufgebäumtesten": "aufgebäumt",
    "aufgebäumtester": "aufgebäumt",
    "aufgebäumtestes": "aufgebäumt",
    "aufgebügelt": "aufbügeln",
    "aufgebügelte": "aufgebügelt",
    "aufgebügeltem": "aufgebügelt",
    "aufgebügelten": "aufgebügelt",
    "aufgebügelter": "aufgebügelt",
    "aufgebügeltes": "aufgebügelt",
    "aufgebürdet": "aufbürden",
    "aufgebürdete": "aufgebürdet",
    "aufgebürdetem": "aufgebürdet",
    "aufgebürdeten": "aufgebürdet",
    "aufgebürdeter": "aufgebürdet",
    "aufgebürdetes": "aufgebürdet",
    "aufgedampft": "aufdampfen",
    "aufgedampfte": "aufgedampft",
    "aufgedampftem": "aufgedampft",
    "aufgedampften": "aufgedampft",
    "aufgedampfter": "aufgedampft",
    "aufgedampftes": "aufgedampft",
    "aufgedeckt": "aufdecken",
    "aufgedeckte": "aufgedeckt",
    "aufgedecktem": "aufgedeckt",
    "aufgedeckten": "aufgedeckt",
    "aufgedeckter": "aufgedeckt",
    "aufgedecktes": "aufgedeckt",
    "aufgedonnert": "aufdonnern",
    "aufgedonnerte": "aufgedonnert",
    "aufgedonnertem": "aufgedonnert",
    "aufgedonnerten": "aufgedonnert",
    "aufgedonnerter": "aufgedonnert",
    "aufgedonnertere": "aufgedonnert",
    "aufgedonnerterem": "aufgedonnert",
    "aufgedonnerteren": "aufgedonnert",
    "aufgedonnerterer": "aufgedonnert",
    "aufgedonnerteres": "aufgedonnert",
    "aufgedonnertes": "aufgedonnert",
    "aufgedonnerteste": "aufgedonnert",
    "aufgedonnertestem": "aufgedonnert",
    "aufgedonnertesten": "aufgedonnert",
    "aufgedonnertester": "aufgedonnert",
    "aufgedonnertestes": "aufgedonnert",
    "aufgedreht": "aufdrehen",
    "aufgedrehte": "aufgedreht",
    "aufgedrehtem": "aufgedreht",
    "aufgedrehten": "aufgedreht",
    "aufgedrehter": "aufgedreht",
    "aufgedrehtere": "aufgedreht",
    "aufgedrehterem": "aufgedreht",
    "aufgedrehteren": "aufgedreht",
    "aufgedrehterer": "aufgedreht",
    "aufgedrehteres": "aufgedreht",
    "aufgedrehtes": "aufgedreht",
    "aufgedrehteste": "aufgedreht",
    "aufgedrehtestem": "aufgedreht",
    "aufgedrehtesten": "aufgedreht",
    "aufgedrehtester": "aufgedreht",
    "aufgedrehtestes": "aufgedreht",
    "aufgedrängt": "aufdrängen",
    "aufgedrängte": "aufgedrängt",
    "aufgedrängtem": "aufgedrängt",
    "aufgedrängten": "aufgedrängt",
    "aufgedrängter": "aufgedrängt",
    "aufgedrängtere": "aufgedrängt",
    "aufgedrängterem": "aufgedrängt",
    "aufgedrängteren": "aufgedrängt",
    "aufgedrängterer": "aufgedrängt",
    "aufgedrängteres": "aufgedrängt",
    "aufgedrängtes": "aufgedrängt",
    "aufgedrängteste": "aufgedrängt",
    "aufgedrängtestem": "aufgedrängt",
    "aufgedrängtesten": "aufgedrängt",
    "aufgedrängtester": "aufgedrängt",
    "aufgedrängtestes": "aufgedrängt",
    "aufgedröselt": "aufdröseln",
    "aufgedröselte": "aufgedröselt",
    "aufgedröseltem": "aufgedröselt",
    "aufgedröselten": "aufgedröselt",
    "aufgedröselter": "aufgedröselt",
    "aufgedröseltere": "aufgedröselt",
    "aufgedröselterem": "aufgedröselt",
    "aufgedröselteren": "aufgedröselt",
    "aufgedröselterer": "aufgedröselt",
    "aufgedröselteres": "aufgedröselt",
    "aufgedröseltes": "aufgedröselt",
    "aufgedröselteste": "aufgedröselt",
    "aufgedröseltestem": "aufgedröselt",
    "aufgedröseltesten": "aufgedröselt",
    "aufgedröseltester": "aufgedröselt",
    "aufgedröseltestes": "aufgedröselt",
    "aufgedrückt": "aufdrücken",
    "aufgedrückte": "aufgedrückt",
    "aufgedrücktem": "aufgedrückt",
    "aufgedrückten": "aufgedrückt",
    "aufgedrückter": "aufgedrückt",
    "aufgedrücktes": "aufgedrückt",
    "aufgedunsene": "aufgedunsen",
    "aufgedunsenem": "aufgedunsen",
    "aufgedunsenen": "aufgedunsen",
    "aufgedunsener": "aufgedunsen",
    "aufgedunsenere": "aufgedunsen",
    "aufgedunsenerem": "aufgedunsen",
    "aufgedunseneren": "aufgedunsen",
    "aufgedunsenerer": "aufgedunsen",
    "aufgedunseneres": "aufgedunsen",
    "aufgedunsenes": "aufgedunsen",
    "aufgedunsenste": "aufgedunsen",
    "aufgedunsenstem": "aufgedunsen",
    "aufgedunsensten": "aufgedunsen",
    "aufgedunsenster": "aufgedunsen",
    "aufgedunsenstes": "aufgedunsen",
    "aufgedämmt": "aufdämmen",
    "aufgedämmte": "aufgedämmt",
    "aufgedämmtem": "aufgedämmt",
    "aufgedämmten": "aufgedämmt",
    "aufgedämmter": "aufgedämmt",
    "aufgedämmtes": "aufgedämmt",
    "aufgefahren": "auffahren",
    "aufgefahrene": "aufgefahren",
    "aufgefahrenem": "aufgefahren",
    "aufgefahrenen": "aufgefahren",
    "aufgefahrener": "aufgefahren",
    "aufgefahrenes": "aufgefahren",
    "aufgefallen": "auffallen",
    "aufgefallene": "aufgefallen",
    "aufgefallenem": "aufgefallen",
    "aufgefallenen": "aufgefallen",
    "aufgefallener": "aufgefallen",
    "aufgefallenes": "aufgefallen",
    "aufgefangen": "auffangen",
    "aufgefangene": "aufgefangen",
    "aufgefangenem": "aufgefangen",
    "aufgefangenen": "aufgefangen",
    "aufgefangener": "aufgefangen",
    "aufgefangenere": "aufgefangen",
    "aufgefangenerem": "aufgefangen",
    "aufgefangeneren": "aufgefangen",
    "aufgefangenerer": "aufgefangen",
    "aufgefangeneres": "aufgefangen",
    "aufgefangenes": "aufgefangen",
    "aufgefangenste": "aufgefangen",
    "aufgefangenstem": "aufgefangen",
    "aufgefangensten": "aufgefangen",
    "aufgefangenster": "aufgefangen",
    "aufgefangenstes": "aufgefangen",
    "aufgefaßt": "auffassen",
    "aufgefaßte": "aufgefaßt",
    "aufgefaßtem": "aufgefaßt",
    "aufgefaßten": "aufgefaßt",
    "aufgefaßter": "aufgefaßt",
    "aufgefaßtes": "aufgefaßt",
    "aufgefischt": "auffischen",
    "aufgefischte": "aufgefischt",
    "aufgefischtem": "aufgefischt",
    "aufgefischten": "aufgefischt",
    "aufgefischter": "aufgefischt",
    "aufgefischtes": "aufgefischt",
    "aufgeflammt": "aufflammen",
    "aufgeflammte": "aufgeflammt",
    "aufgeflammtem": "aufgeflammt",
    "aufgeflammten": "aufgeflammt",
    "aufgeflammter": "aufgeflammt",
    "aufgeflammtere": "aufgeflammt",
    "aufgeflammterem": "aufgeflammt",
    "aufgeflammteren": "aufgeflammt",
    "aufgeflammterer": "aufgeflammt",
    "aufgeflammteres": "aufgeflammt",
    "aufgeflammtes": "aufgeflammt",
    "aufgeflammteste": "aufgeflammt",
    "aufgeflammtestem": "aufgeflammt",
    "aufgeflammtesten": "aufgeflammt",
    "aufgeflammtester": "aufgeflammt",
    "aufgeflammtestes": "aufgeflammt",
    "aufgeflogen": "auffliegen",
    "aufgeflogene": "aufgeflogen",
    "aufgeflogenem": "aufgeflogen",
    "aufgeflogenen": "aufgeflogen",
    "aufgeflogener": "aufgeflogen",
    "aufgeflogenere": "aufgeflogen",
    "aufgeflogenerem": "aufgeflogen",
    "aufgeflogeneren": "aufgeflogen",
    "aufgeflogenerer": "aufgeflogen",
    "aufgeflogeneres": "aufgeflogen",
    "aufgeflogenes": "aufgeflogen",
    "aufgeflogenste": "aufgeflogen",
    "aufgeflogenstem": "aufgeflogen",
    "aufgeflogensten": "aufgeflogen",
    "aufgeflogenster": "aufgeflogen",
    "aufgeflogenstes": "aufgeflogen",
    "aufgefordert": "auffordern",
    "aufgeforderte": "aufgefordert",
    "aufgefordertem": "aufgefordert",
    "aufgeforderten": "aufgefordert",
    "aufgeforderter": "aufgefordert",
    "aufgefordertes": "aufgefordert",
    "aufgeforstet": "aufforsten",
    "aufgeforstete": "aufgeforstet",
    "aufgeforstetem": "aufgeforstet",
    "aufgeforsteten": "aufgeforstet",
    "aufgeforsteter": "aufgeforstet",
    "aufgeforstetere": "aufgeforstet",
    "aufgeforsteterem": "aufgeforstet",
    "aufgeforsteteren": "aufgeforstet",
    "aufgeforsteterer": "aufgeforstet",
    "aufgeforsteteres": "aufgeforstet",
    "aufgeforstetes": "aufgeforstet",
    "aufgeforsteteste": "aufgeforstet",
    "aufgeforstetestem": "aufgeforstet",
    "aufgeforstetesten": "aufgeforstet",
    "aufgeforstetester": "aufgeforstet",
    "aufgeforstetestes": "aufgeforstet",
    "aufgefressen": "auffressen",
    "aufgefressene": "aufgefressen",
    "aufgefressenem": "aufgefressen",
    "aufgefressenen": "aufgefressen",
    "aufgefressener": "aufgefressen",
    "aufgefressenere": "aufgefressen",
    "aufgefressenerem": "aufgefressen",
    "aufgefresseneren": "aufgefressen",
    "aufgefressenerer": "aufgefressen",
    "aufgefresseneres": "aufgefressen",
    "aufgefressenes": "aufgefressen",
    "aufgefressenste": "aufgefressen",
    "aufgefressenstem": "aufgefressen",
    "aufgefressensten": "aufgefressen",
    "aufgefressenster": "aufgefressen",
    "aufgefressenstes": "aufgefressen",
    "aufgefrischt": "auffrischen",
    "aufgefrischte": "aufgefrischt",
    "aufgefrischtem": "aufgefrischt",
    "aufgefrischten": "aufgefrischt",
    "aufgefrischter": "aufgefrischt",
    "aufgefrischtere": "aufgefrischt",
    "aufgefrischterem": "aufgefrischt",
    "aufgefrischteren": "aufgefrischt",
    "aufgefrischterer": "aufgefrischt",
    "aufgefrischteres": "aufgefrischt",
    "aufgefrischtes": "aufgefrischt",
    "aufgefrischteste": "aufgefrischt",
    "aufgefrischtestem": "aufgefrischt",
    "aufgefrischtesten": "aufgefrischt",
    "aufgefrischtester": "aufgefrischt",
    "aufgefrischtestes": "aufgefrischt",
    "aufgefunden": "auffinden",
    "aufgefundene": "aufgefunden",
    "aufgefundenem": "aufgefunden",
    "aufgefundenen": "aufgefunden",
    "aufgefundener": "aufgefunden",
    "aufgefundenes": "aufgefunden",
    "aufgefädelt": "auffädeln",
    "aufgefädelte": "aufgefädelt",
    "aufgefädeltem": "aufgefädelt",
    "aufgefädelten": "aufgefädelt",
    "aufgefädelter": "aufgefädelt",
    "aufgefädeltes": "aufgefädelt",
    "aufgefärbt": "auffärben",
    "aufgefärbte": "aufgefärbt",
    "aufgefärbtem": "aufgefärbt",
    "aufgefärbten": "aufgefärbt",
    "aufgefärbter": "aufgefärbt",
    "aufgefärbtes": "aufgefärbt",
    "aufgeführt": "aufführen",
    "aufgeführte": "aufgeführt",
    "aufgeführtem": "aufgeführt",
    "aufgeführten": "aufgeführt",
    "aufgeführter": "aufgeführt",
    "aufgeführtes": "aufgeführt",
    "aufgefüllt": "auffüllen",
    "aufgefüllte": "aufgefüllt",
    "aufgefülltem": "aufgefüllt",
    "aufgefüllten": "aufgefüllt",
    "aufgefüllter": "aufgefüllt",
    "aufgefülltes": "aufgefüllt",
    "aufgegabelt": "aufgabeln",
    "aufgegabelte": "aufgegabelt",
    "aufgegabeltem": "aufgegabelt",
    "aufgegabelten": "aufgegabelt",
    "aufgegabelter": "aufgegabelt",
    "aufgegabeltes": "aufgegabelt",
    "aufgegangen": "aufgehen",
    "aufgegangene": "aufgegangen",
    "aufgegangenem": "aufgegangen",
    "aufgegangenen": "aufgegangen",
    "aufgegangener": "aufgegangen",
    "aufgegangenes": "aufgegangen",
    "aufgegeben": "aufgeben",
    "aufgegebene": "aufgegeben",
    "aufgegebenem": "aufgegeben",
    "aufgegebenen": "aufgegeben",
    "aufgegebener": "aufgegeben",
    "aufgegebenes": "aufgegeben",
    "aufgegeilt": "aufgeilen",
    "aufgegeilte": "aufgegeilt",
    "aufgegeiltem": "aufgegeilt",
    "aufgegeilten": "aufgegeilt",
    "aufgegeilter": "aufgegeilt",
    "aufgegeiltere": "aufgegeilt",
    "aufgegeilterem": "aufgegeilt",
    "aufgegeilteren": "aufgegeilt",
    "aufgegeilterer": "aufgegeilt",
    "aufgegeilteres": "aufgegeilt",
    "aufgegeiltes": "aufgegeilt",
    "aufgegeilteste": "aufgegeilt",
    "aufgegeiltestem": "aufgegeilt",
    "aufgegeiltesten": "aufgegeilt",
    "aufgegeiltester": "aufgegeilt",
    "aufgegeiltestes": "aufgegeilt",
    "aufgegessen": "aufessen",
    "aufgegessene": "aufgegessen",
    "aufgegessenem": "aufgegessen",
    "aufgegessenen": "aufgegessen",
    "aufgegessener": "aufgegessen",
    "aufgegessenere": "aufgegessen",
    "aufgegessenerem": "aufgegessen",
    "aufgegesseneren": "aufgegessen",
    "aufgegessenerer": "aufgegessen",
    "aufgegesseneres": "aufgegessen",
    "aufgegessenes": "aufgegessen",
    "aufgegessenste": "aufgegessen",
    "aufgegessenstem": "aufgegessen",
    "aufgegessensten": "aufgegessen",
    "aufgegessenster": "aufgegessen",
    "aufgegessenstes": "aufgegessen",
    "aufgegleist": "aufgleisen",
    "aufgegleiste": "aufgegleist",
    "aufgegleistem": "aufgegleist",
    "aufgegleisten": "aufgegleist",
    "aufgegleister": "aufgegleist",
    "aufgegleistes": "aufgegleist",
    "aufgegliedert": "aufgliedern",
    "aufgegliederte": "aufgegliedert",
    "aufgegliedertem": "aufgegliedert",
    "aufgegliederten": "aufgegliedert",
    "aufgegliederter": "aufgegliedert",
    "aufgegliedertes": "aufgegliedert",
    "aufgeglommen": "aufglimmen",
    "aufgeglommene": "aufgeglommen",
    "aufgeglommenem": "aufgeglommen",
    "aufgeglommenen": "aufgeglommen",
    "aufgeglommener": "aufgeglommen",
    "aufgeglommenere": "aufgeglommen",
    "aufgeglommenerem": "aufgeglommen",
    "aufgeglommeneren": "aufgeglommen",
    "aufgeglommenerer": "aufgeglommen",
    "aufgeglommeneres": "aufgeglommen",
    "aufgeglommenes": "aufgeglommen",
    "aufgeglommenste": "aufgeglommen",
    "aufgeglommenstem": "aufgeglommen",
    "aufgeglommensten": "aufgeglommen",
    "aufgeglommenster": "aufgeglommen",
    "aufgeglommenstes": "aufgeglommen",
    "aufgeglüht": "aufglühen",
    "aufgeglühte": "aufgeglüht",
    "aufgeglühtem": "aufgeglüht",
    "aufgeglühten": "aufgeglüht",
    "aufgeglühter": "aufgeglüht",
    "aufgeglühtere": "aufgeglüht",
    "aufgeglühterem": "aufgeglüht",
    "aufgeglühteren": "aufgeglüht",
    "aufgeglühterer": "aufgeglüht",
    "aufgeglühteres": "aufgeglüht",
    "aufgeglühtes": "aufgeglüht",
    "aufgeglühteste": "aufgeglüht",
    "aufgeglühtestem": "aufgeglüht",
    "aufgeglühtesten": "aufgeglüht",
    "aufgeglühtester": "aufgeglüht",
    "aufgeglühtestes": "aufgeglüht",
    "aufgegossen": "aufgießen",
    "aufgegossene": "aufgegossen",
    "aufgegossenem": "aufgegossen",
    "aufgegossenen": "aufgegossen",
    "aufgegossener": "aufgegossen",
    "aufgegossenes": "aufgegossen",
    "aufgegriffen": "aufgreifen",
    "aufgegriffene": "aufgegriffen",
    "aufgegriffenem": "aufgegriffen",
    "aufgegriffenen": "aufgegriffen",
    "aufgegriffener": "aufgegriffen",
    "aufgegriffenes": "aufgegriffen",
    "aufgehakt": "aufhaken",
    "aufgehakte": "aufgehakt",
    "aufgehaktem": "aufgehakt",
    "aufgehakten": "aufgehakt",
    "aufgehakter": "aufgehakt",
    "aufgehaktes": "aufgehakt",
    "aufgehalst": "aufhalsen",
    "aufgehalste": "aufgehalst",
    "aufgehalstem": "aufgehalst",
    "aufgehalsten": "aufgehalst",
    "aufgehalster": "aufgehalst",
    "aufgehalstes": "aufgehalst",
    "aufgehalten": "aufhalten",
    "aufgehaltene": "aufgehalten",
    "aufgehaltenem": "aufgehalten",
    "aufgehaltenen": "aufgehalten",
    "aufgehaltener": "aufgehalten",
    "aufgehaltenes": "aufgehalten",
    "aufgehangen": "aufhängen",
    "aufgehauen": "aufhauen",
    "aufgehauene": "aufgehauen",
    "aufgehauenem": "aufgehauen",
    "aufgehauenen": "aufgehauen",
    "aufgehauener": "aufgehauen",
    "aufgehauenes": "aufgehauen",
    "aufgehe": "aufgehen",
    "aufgeheitert": "aufheitern",
    "aufgeheiterte": "aufgeheitert",
    "aufgeheitertem": "aufgeheitert",
    "aufgeheiterten": "aufgeheitert",
    "aufgeheiterter": "aufgeheitert",
    "aufgeheitertere": "aufgeheitert",
    "aufgeheiterterem": "aufgeheitert",
    "aufgeheiterteren": "aufgeheitert",
    "aufgeheiterterer": "aufgeheitert",
    "aufgeheiterteres": "aufgeheitert",
    "aufgeheitertes": "aufgeheitert",
    "aufgeheiterteste": "aufgeheitert",
    "aufgeheitertestem": "aufgeheitert",
    "aufgeheitertesten": "aufgeheitert",
    "aufgeheitertester": "aufgeheitert",
    "aufgeheitertestes": "aufgeheitert",
    "aufgehellt": "aufhellen",
    "aufgehellte": "aufgehellt",
    "aufgehelltem": "aufgehellt",
    "aufgehellten": "aufgehellt",
    "aufgehellter": "aufgehellt",
    "aufgehelltere": "aufgehellt",
    "aufgehellterem": "aufgehellt",
    "aufgehellteren": "aufgehellt",
    "aufgehellterer": "aufgehellt",
    "aufgehellteres": "aufgehellt",
    "aufgehelltes": "aufgehellt",
    "aufgehellteste": "aufgehellt",
    "aufgehelltestem": "aufgehellt",
    "aufgehelltesten": "aufgehellt",
    "aufgehelltester": "aufgehellt",
    "aufgehelltestes": "aufgehellt",
    "aufgehend": "aufgehen",
    "aufgehende": "aufgehend",
    "aufgehendem": "aufgehend",
    "aufgehenden": "aufgehend",
    "aufgehender": "aufgehend",
    "aufgehendes": "aufgehend",
    "aufgehest": "aufgehen",
    "aufgehet": "aufgehen",
    "aufgehetzt": "aufhetzen",
    "aufgehetzte": "aufgehetzt",
    "aufgehetztem": "aufgehetzt",
    "aufgehetzten": "aufgehetzt",
    "aufgehetzter": "aufgehetzt",
    "aufgehetztere": "aufgehetzt",
    "aufgehetzterem": "aufgehetzt",
    "aufgehetzteren": "aufgehetzt",
    "aufgehetzterer": "aufgehetzt",
    "aufgehetzteres": "aufgehetzt",
    "aufgehetztes": "aufgehetzt",
    "aufgehetzteste": "aufgehetzt",
    "aufgehetztestem": "aufgehetzt",
    "aufgehetztesten": "aufgehetzt",
    "aufgehetztester": "aufgehetzt",
    "aufgehetztestes": "aufgehetzt",
    "aufgehoben": "aufheben",
    "aufgehobene": "aufgehoben",
    "aufgehobenem": "aufgehoben",
    "aufgehobenen": "aufgehoben",
    "aufgehobener": "aufgehoben",
    "aufgehobenes": "aufgehoben",
    "aufgeholt": "aufholen",
    "aufgeholte": "aufgeholt",
    "aufgeholtem": "aufgeholt",
    "aufgeholten": "aufgeholt",
    "aufgeholter": "aufgeholt",
    "aufgeholtere": "aufgeholt",
    "aufgeholterem": "aufgeholt",
    "aufgeholteren": "aufgeholt",
    "aufgeholterer": "aufgeholt",
    "aufgeholteres": "aufgeholt",
    "aufgeholtes": "aufgeholt",
    "aufgeholteste": "aufgeholt",
    "aufgeholtestem": "aufgeholt",
    "aufgeholtesten": "aufgeholt",
    "aufgeholtester": "aufgeholt",
    "aufgeholtestes": "aufgeholt",
    "aufgehorcht": "aufhorchen",
    "aufgehorchte": "aufgehorcht",
    "aufgehorchtem": "aufgehorcht",
    "aufgehorchten": "aufgehorcht",
    "aufgehorchter": "aufgehorcht",
    "aufgehorchtere": "aufgehorcht",
    "aufgehorchterem": "aufgehorcht",
    "aufgehorchteren": "aufgehorcht",
    "aufgehorchterer": "aufgehorcht",
    "aufgehorchteres": "aufgehorcht",
    "aufgehorchtes": "aufgehorcht",
    "aufgehorchteste": "aufgehorcht",
    "aufgehorchtestem": "aufgehorcht",
    "aufgehorchtesten": "aufgehorcht",
    "aufgehorchtester": "aufgehorcht",
    "aufgehorchtestes": "aufgehorcht",
    "aufgehst": "aufgehen",
    "aufgeht": "aufgehen",
    "aufgehängt": "aufhängen",
    "aufgehängte": "aufgehängt",
    "aufgehängtem": "aufgehängt",
    "aufgehängten": "aufgehängt",
    "aufgehängter": "aufgehängt",
    "aufgehängtes": "aufgehängt",
    "aufgehärtet": "aufhärten",
    "aufgehärtete": "aufgehärtet",
    "aufgehärtetem": "aufgehärtet",
    "aufgehärteten": "aufgehärtet",
    "aufgehärteter": "aufgehärtet",
    "aufgehärtetes": "aufgehärtet",
    "aufgehört": "aufhören",
    "aufgehörte": "aufgehört",
    "aufgehörtem": "aufgehört",
    "aufgehörten": "aufgehört",
    "aufgehörter": "aufgehört",
    "aufgehörtes": "aufgehört",
    "aufgeile": "aufgeilen",
    "aufgeilend": "aufgeilen",
    "aufgeilende": "aufgeilend",
    "aufgeilendem": "aufgeilend",
    "aufgeilenden": "aufgeilend",
    "aufgeilender": "aufgeilend",
    "aufgeilendere": "aufgeilend",
    "aufgeilenderem": "aufgeilend",
    "aufgeilenderen": "aufgeilend",
    "aufgeilenderer": "aufgeilend",
    "aufgeilenderes": "aufgeilend",
    "aufgeilendes": "aufgeilend",
    "aufgeilendste": "aufgeilend",
    "aufgeilendstem": "aufgeilend",
    "aufgeilendsten": "aufgeilend",
    "aufgeilendster": "aufgeilend",
    "aufgeilendstes": "aufgeilend",
    "aufgeilest": "aufgeilen",
    "aufgeilet": "aufgeilen",
    "aufgeilst": "aufgeilen",
    "aufgeilt": "aufgeilen",
    "aufgeilte": "aufgeilen",
    "aufgeilten": "aufgeilen",
    "aufgeiltest": "aufgeilen",
    "aufgeiltet": "aufgeilen",
    "aufgejagt": "aufjagen",
    "aufgejagte": "aufgejagt",
    "aufgejagtem": "aufgejagt",
    "aufgejagten": "aufgejagt",
    "aufgejagter": "aufgejagt",
    "aufgejagtes": "aufgejagt",
    "aufgejauchzt": "aufjauchzen",
    "aufgejauchzte": "aufgejauchzt",
    "aufgejauchztem": "aufgejauchzt",
    "aufgejauchzten": "aufgejauchzt",
    "aufgejauchzter": "aufgejauchzt",
    "aufgejauchztere": "aufgejauchzt",
    "aufgejauchzterem": "aufgejauchzt",
    "aufgejauchzteren": "aufgejauchzt",
    "aufgejauchzterer": "aufgejauchzt",
    "aufgejauchzteres": "aufgejauchzt",
    "aufgejauchztes": "aufgejauchzt",
    "aufgejauchzteste": "aufgejauchzt",
    "aufgejauchztestem": "aufgejauchzt",
    "aufgejauchztesten": "aufgejauchzt",
    "aufgejauchztester": "aufgejauchzt",
    "aufgejauchztestes": "aufgejauchzt",
    "aufgekauft": "aufkaufen",
    "aufgekaufte": "aufgekauft",
    "aufgekauftem": "aufgekauft",
    "aufgekauften": "aufgekauft",
    "aufgekaufter": "aufgekauft",
    "aufgekauftes": "aufgekauft",
    "aufgekeimt": "aufkeimen",
    "aufgekeimte": "aufgekeimt",
    "aufgekeimtem": "aufgekeimt",
    "aufgekeimten": "aufgekeimt",
    "aufgekeimter": "aufgekeimt",
    "aufgekeimtere": "aufgekeimt",
    "aufgekeimterem": "aufgekeimt",
    "aufgekeimteren": "aufgekeimt",
    "aufgekeimterer": "aufgekeimt",
    "aufgekeimteres": "aufgekeimt",
    "aufgekeimtes": "aufgekeimt",
    "aufgekeimteste": "aufgekeimt",
    "aufgekeimtestem": "aufgekeimt",
    "aufgekeimtesten": "aufgekeimt",
    "aufgekeimtester": "aufgekeimt",
    "aufgekeimtestes": "aufgekeimt",
    "aufgeklappt": "aufklappen",
    "aufgeklappte": "aufgeklappt",
    "aufgeklapptem": "aufgeklappt",
    "aufgeklappten": "aufgeklappt",
    "aufgeklappter": "aufgeklappt",
    "aufgeklapptes": "aufgeklappt",
    "aufgeklart": "aufklaren",
    "aufgeklarte": "aufgeklart",
    "aufgeklartem": "aufgeklart",
    "aufgeklarten": "aufgeklart",
    "aufgeklarter": "aufgeklart",
    "aufgeklartere": "aufgeklart",
    "aufgeklarterem": "aufgeklart",
    "aufgeklarteren": "aufgeklart",
    "aufgeklarterer": "aufgeklart",
    "aufgeklarteres": "aufgeklart",
    "aufgeklartes": "aufgeklart",
    "aufgeklarteste": "aufgeklart",
    "aufgeklartestem": "aufgeklart",
    "aufgeklartesten": "aufgeklart",
    "aufgeklartester": "aufgeklart",
    "aufgeklartestes": "aufgeklart",
    "aufgeklaubt": "aufklauben",
    "aufgeklaubte": "aufgeklaubt",
    "aufgeklaubtem": "aufgeklaubt",
    "aufgeklaubten": "aufgeklaubt",
    "aufgeklaubter": "aufgeklaubt",
    "aufgeklaubtere": "aufgeklaubt",
    "aufgeklaubterem": "aufgeklaubt",
    "aufgeklaubteren": "aufgeklaubt",
    "aufgeklaubterer": "aufgeklaubt",
    "aufgeklaubteres": "aufgeklaubt",
    "aufgeklaubtes": "aufgeklaubt",
    "aufgeklaubteste": "aufgeklaubt",
    "aufgeklaubtestem": "aufgeklaubt",
    "aufgeklaubtesten": "aufgeklaubt",
    "aufgeklaubtester": "aufgeklaubt",
    "aufgeklaubtestes": "aufgeklaubt",
    "aufgeklebt": "aufkleben",
    "aufgeklebte": "aufgeklebt",
    "aufgeklebtem": "aufgeklebt",
    "aufgeklebten": "aufgeklebt",
    "aufgeklebter": "aufgeklebt",
    "aufgeklebtes": "aufgeklebt",
    "aufgeklingelt": "aufklingeln",
    "aufgeklingelte": "aufgeklingelt",
    "aufgeklingeltem": "aufgeklingelt",
    "aufgeklingelten": "aufgeklingelt",
    "aufgeklingelter": "aufgeklingelt",
    "aufgeklingeltes": "aufgeklingelt",
    "aufgeklinkt": "aufklinken",
    "aufgeklinkte": "aufgeklinkt",
    "aufgeklinktem": "aufgeklinkt",
    "aufgeklinkten": "aufgeklinkt",
    "aufgeklinkter": "aufgeklinkt",
    "aufgeklinktes": "aufgeklinkt",
    "aufgeklärt": "aufklären",
    "aufgeklärtem": "aufgeklärt",
    "aufgeklärter": "aufgeklärt",
    "aufgeklärterem": "aufgeklärt",
    "aufgeklärterer": "aufgeklärt",
    "aufgeklärteres": "aufgeklärt",
    "aufgeklärtes": "aufgeklärt",
    "aufgeklärtestem": "aufgeklärt",
    "aufgeklärtester": "aufgeklärt",
    "aufgeklärtestes": "aufgeklärt",
    "aufgeknotet": "aufknoten",
    "aufgeknotete": "aufgeknotet",
    "aufgeknotetem": "aufgeknotet",
    "aufgeknoteten": "aufgeknotet",
    "aufgeknoteter": "aufgeknotet",
    "aufgeknotetes": "aufgeknotet",
    "aufgeknöpft": "aufknöpfen",
    "aufgeknöpfte": "aufgeknöpft",
    "aufgeknöpftem": "aufgeknöpft",
    "aufgeknöpften": "aufgeknöpft",
    "aufgeknöpfter": "aufgeknöpft",
    "aufgeknöpftes": "aufgeknöpft",
    "aufgeknüpft": "aufknüpfen",
    "aufgeknüpfte": "aufgeknüpft",
    "aufgeknüpftem": "aufgeknüpft",
    "aufgeknüpften": "aufgeknüpft",
    "aufgeknüpfter": "aufgeknüpft",
    "aufgeknüpftes": "aufgeknüpft",
    "aufgekocht": "aufkochen",
    "aufgekochte": "aufgekocht",
    "aufgekochtem": "aufgekocht",
    "aufgekochten": "aufgekocht",
    "aufgekochter": "aufgekocht",
    "aufgekochtere": "aufgekocht",
    "aufgekochterem": "aufgekocht",
    "aufgekochteren": "aufgekocht",
    "aufgekochterer": "aufgekocht",
    "aufgekochteres": "aufgekocht",
    "aufgekochtes": "aufgekocht",
    "aufgekochteste": "aufgekocht",
    "aufgekochtestem": "aufgekocht",
    "aufgekochtesten": "aufgekocht",
    "aufgekochtester": "aufgekocht",
    "aufgekochtestes": "aufgekocht",
    "aufgekommen": "aufkommen",
    "aufgekommene": "aufgekommen",
    "aufgekommenem": "aufgekommen",
    "aufgekommenen": "aufgekommen",
    "aufgekommener": "aufgekommen",
    "aufgekommenes": "aufgekommen",
    "aufgekratzt": "aufkratzen",
    "aufgekratzte": "aufgekratzt",
    "aufgekratztem": "aufgekratzt",
    "aufgekratzten": "aufgekratzt",
    "aufgekratzter": "aufgekratzt",
    "aufgekratztere": "aufgekratzt",
    "aufgekratzterem": "aufgekratzt",
    "aufgekratzteren": "aufgekratzt",
    "aufgekratzterer": "aufgekratzt",
    "aufgekratzteres": "aufgekratzt",
    "aufgekratztes": "aufgekratzt",
    "aufgekratzteste": "aufgekratzt",
    "aufgekratztestem": "aufgekratzt",
    "aufgekratztesten": "aufgekratzt",
    "aufgekratztester": "aufgekratzt",
    "aufgekratztestes": "aufgekratzt",
    "aufgekrempelt": "aufkrempeln",
    "aufgekrempelte": "aufgekrempelt",
    "aufgekrempeltem": "aufgekrempelt",
    "aufgekrempelten": "aufgekrempelt",
    "aufgekrempelter": "aufgekrempelt",
    "aufgekrempeltere": "aufgekrempelt",
    "aufgekrempelterem": "aufgekrempelt",
    "aufgekrempelteren": "aufgekrempelt",
    "aufgekrempelterer": "aufgekrempelt",
    "aufgekrempelteres": "aufgekrempelt",
    "aufgekrempeltes": "aufgekrempelt",
    "aufgekrempelteste": "aufgekrempelt",
    "aufgekrempeltestem": "aufgekrempelt",
    "aufgekrempeltesten": "aufgekrempelt",
    "aufgekrempeltester": "aufgekrempelt",
    "aufgekrempeltestes": "aufgekrempelt",
    "aufgekreuzt": "aufkreuzen",
    "aufgekreuzte": "aufgekreuzt",
    "aufgekreuztem": "aufgekreuzt",
    "aufgekreuzten": "aufgekreuzt",
    "aufgekreuzter": "aufgekreuzt",
    "aufgekreuztes": "aufgekreuzt",
    "aufgekriegt": "aufkriegen",
    "aufgekriegte": "aufgekriegt",
    "aufgekriegtem": "aufgekriegt",
    "aufgekriegten": "aufgekriegt",
    "aufgekriegter": "aufgekriegt",
    "aufgekriegtes": "aufgekriegt",
    "aufgekämmt": "aufkämmen",
    "aufgekämmte": "aufgekämmt",
    "aufgekämmtem": "aufgekämmt",
    "aufgekämmten": "aufgekämmt",
    "aufgekämmter": "aufgekämmt",
    "aufgekämmtes": "aufgekämmt",
    "aufgekündigt": "aufkündigen",
    "aufgekündigte": "aufgekündigt",
    "aufgekündigtem": "aufgekündigt",
    "aufgekündigten": "aufgekündigt",
    "aufgekündigter": "aufgekündigt",
    "aufgekündigtes": "aufgekündigt",
    "aufgelacht": "auflachen",
    "aufgelachte": "aufgelacht",
    "aufgelachtem": "aufgelacht",
    "aufgelachten": "aufgelacht",
    "aufgelachter": "aufgelacht",
    "aufgelachtes": "aufgelacht",
    "aufgeladen": "aufladen",
    "aufgeladene": "aufgeladen",
    "aufgeladenem": "aufgeladen",
    "aufgeladenen": "aufgeladen",
    "aufgeladener": "aufgeladen",
    "aufgeladenere": "aufgeladen",
    "aufgeladenerem": "aufgeladen",
    "aufgeladeneren": "aufgeladen",
    "aufgeladenerer": "aufgeladen",
    "aufgeladeneres": "aufgeladen",
    "aufgeladenes": "aufgeladen",
    "aufgeladenste": "aufgeladen",
    "aufgeladenstem": "aufgeladen",
    "aufgeladensten": "aufgeladen",
    "aufgeladenster": "aufgeladen",
    "aufgeladenstes": "aufgeladen",
    "aufgelassen": "auflassen",
    "aufgelassene": "aufgelassen",
    "aufgelassenem": "aufgelassen",
    "aufgelassenen": "aufgelassen",
    "aufgelassener": "aufgelassen",
    "aufgelassenes": "aufgelassen",
    "aufgelastet": "auflasten",
    "aufgelastete": "aufgelastet",
    "aufgelastetem": "aufgelastet",
    "aufgelasteten": "aufgelastet",
    "aufgelasteter": "aufgelastet",
    "aufgelastetes": "aufgelastet",
    "aufgelauert": "auflauern",
    "aufgelauerte": "aufgelauert",
    "aufgelauertem": "aufgelauert",
    "aufgelauerten": "aufgelauert",
    "aufgelauerter": "aufgelauert",
    "aufgelauertes": "aufgelauert",
    "aufgelaufen": "auflaufen",
    "aufgelaufene": "aufgelaufen",
    "aufgelaufenem": "aufgelaufen",
    "aufgelaufenen": "aufgelaufen",
    "aufgelaufener": "aufgelaufen",
    "aufgelaufenes": "aufgelaufen",
    "aufgelebt": "aufleben",
    "aufgelebte": "aufgelebt",
    "aufgelebtem": "aufgelebt",
    "aufgelebten": "aufgelebt",
    "aufgelebter": "aufgelebt",
    "aufgelebtes": "aufgelebt",
    "aufgelegen": "aufliegen",
    "aufgelegene": "aufgelegen",
    "aufgelegenem": "aufgelegen",
    "aufgelegenen": "aufgelegen",
    "aufgelegener": "aufgelegen",
    "aufgelegenes": "aufgelegen",
    "aufgelegt": "auflegen",
    "aufgelegte": "aufgelegt",
    "aufgelegtem": "aufgelegt",
    "aufgelegten": "aufgelegt",
    "aufgelegter": "aufgelegt",
    "aufgelegtes": "aufgelegt",
    "aufgelehnt": "auflehnen",
    "aufgelehnte": "aufgelehnt",
    "aufgelehntem": "aufgelehnt",
    "aufgelehnten": "aufgelehnt",
    "aufgelehnter": "aufgelehnt",
    "aufgelehntere": "aufgelehnt",
    "aufgelehnterem": "aufgelehnt",
    "aufgelehnteren": "aufgelehnt",
    "aufgelehnterer": "aufgelehnt",
    "aufgelehnteres": "aufgelehnt",
    "aufgelehntes": "aufgelehnt",
    "aufgelehnteste": "aufgelehnt",
    "aufgelehntestem": "aufgelehnt",
    "aufgelehntesten": "aufgelehnt",
    "aufgelehntester": "aufgelehnt",
    "aufgelehntestes": "aufgelehnt",
    "aufgeleimt": "aufleimen",
    "aufgeleimte": "aufgeleimt",
    "aufgeleimtem": "aufgeleimt",
    "aufgeleimten": "aufgeleimt",
    "aufgeleimter": "aufgeleimt",
    "aufgeleimtes": "aufgeleimt",
    "aufgelesen": "auflesen",
    "aufgelesene": "aufgelesen",
    "aufgelesenem": "aufgelesen",
    "aufgelesenen": "aufgelesen",
    "aufgelesener": "aufgelesen",
    "aufgelesenes": "aufgelesen",
    "aufgeleuchtet": "aufleuchten",
    "aufgeleuchtete": "aufgeleuchtet",
    "aufgeleuchtetem": "aufgeleuchtet",
    "aufgeleuchteten": "aufgeleuchtet",
    "aufgeleuchteter": "aufgeleuchtet",
    "aufgeleuchtetes": "aufgeleuchtet",
    "aufgelichtet": "auflichten",
    "aufgelichtete": "aufgelichtet",
    "aufgelichtetem": "aufgelichtet",
    "aufgelichteten": "aufgelichtet",
    "aufgelichteter": "aufgelichtet",
    "aufgelichtetes": "aufgelichtet",
    "aufgeliefert": "aufliefern",
    "aufgelieferte": "aufgeliefert",
    "aufgeliefertem": "aufgeliefert",
    "aufgelieferten": "aufgeliefert",
    "aufgelieferter": "aufgeliefert",
    "aufgeliefertes": "aufgeliefert",
    "aufgelistet": "auflisten",
    "aufgelistete": "aufgelistet",
    "aufgelistetem": "aufgelistet",
    "aufgelisteten": "aufgelistet",
    "aufgelisteter": "aufgelistet",
    "aufgelistetes": "aufgelistet",
    "aufgelockert": "auflockern",
    "aufgelockerte": "aufgelockert",
    "aufgelockertem": "aufgelockert",
    "aufgelockerten": "aufgelockert",
    "aufgelockerter": "aufgelockert",
    "aufgelockertere": "aufgelockert",
    "aufgelockerterem": "aufgelockert",
    "aufgelockerteren": "aufgelockert",
    "aufgelockerterer": "aufgelockert",
    "aufgelockerteres": "aufgelockert",
    "aufgelockertes": "aufgelockert",
    "aufgelockerteste": "aufgelockert",
    "aufgelockertestem": "aufgelockert",
    "aufgelockertesten": "aufgelockert",
    "aufgelockertester": "aufgelockert",
    "aufgelockertestes": "aufgelockert",
    "aufgelodert": "auflodern",
    "aufgeloderte": "aufgelodert",
    "aufgelodertem": "aufgelodert",
    "aufgeloderten": "aufgelodert",
    "aufgeloderter": "aufgelodert",
    "aufgelodertere": "aufgelodert",
    "aufgeloderterem": "aufgelodert",
    "aufgeloderteren": "aufgelodert",
    "aufgeloderterer": "aufgelodert",
    "aufgeloderteres": "aufgelodert",
    "aufgelodertes": "aufgelodert",
    "aufgeloderteste": "aufgelodert",
    "aufgelodertestem": "aufgelodert",
    "aufgelodertesten": "aufgelodert",
    "aufgelodertester": "aufgelodert",
    "aufgelodertestes": "aufgelodert",
    "aufgelöst": "auflösen",
    "aufgelöste": "aufgelöst",
    "aufgelöstem": "aufgelöst",
    "aufgelösten": "aufgelöst",
    "aufgelöster": "aufgelöst",
    "aufgelöstere": "aufgelöst",
    "aufgelösterem": "aufgelöst",
    "aufgelösteren": "aufgelöst",
    "aufgelösterer": "aufgelöst",
    "aufgelösteres": "aufgelöst",
    "aufgelöstes": "aufgelöst",
    "aufgelösteste": "aufgelöst",
    "aufgelöstestem": "aufgelöst",
    "aufgelöstesten": "aufgelöst",
    "aufgelöstester": "aufgelöst",
    "aufgelöstestes": "aufgelöst",
    "aufgemacht": "aufmachen",
    "aufgemachte": "aufgemacht",
    "aufgemachtem": "aufgemacht",
    "aufgemachten": "aufgemacht",
    "aufgemachter": "aufgemacht",
    "aufgemachtere": "aufgemacht",
    "aufgemachterem": "aufgemacht",
    "aufgemachteren": "aufgemacht",
    "aufgemachterer": "aufgemacht",
    "aufgemachteres": "aufgemacht",
    "aufgemachtes": "aufgemacht",
    "aufgemachteste": "aufgemacht",
    "aufgemachtestem": "aufgemacht",
    "aufgemachtesten": "aufgemacht",
    "aufgemachtester": "aufgemacht",
    "aufgemachtestes": "aufgemacht",
    "aufgemeißelt": "aufmeißeln",
    "aufgemeißelte": "aufgemeißelt",
    "aufgemeißeltem": "aufgemeißelt",
    "aufgemeißelten": "aufgemeißelt",
    "aufgemeißelter": "aufgemeißelt",
    "aufgemeißeltes": "aufgemeißelt",
    "aufgemerkt": "aufmerken",
    "aufgemerkte": "aufgemerkt",
    "aufgemerktem": "aufgemerkt",
    "aufgemerkten": "aufgemerkt",
    "aufgemerkter": "aufgemerkt",
    "aufgemerktes": "aufgemerkt",
    "aufgemotzt": "aufmotzen",
    "aufgemotzte": "aufgemotzt",
    "aufgemotztem": "aufgemotzt",
    "aufgemotzten": "aufgemotzt",
    "aufgemotzter": "aufgemotzt",
    "aufgemotztere": "aufgemotzt",
    "aufgemotzterem": "aufgemotzt",
    "aufgemotzteren": "aufgemotzt",
    "aufgemotzterer": "aufgemotzt",
    "aufgemotzteres": "aufgemotzt",
    "aufgemotztes": "aufgemotzt",
    "aufgemotzteste": "aufgemotzt",
    "aufgemotztestem": "aufgemotzt",
    "aufgemotztesten": "aufgemotzt",
    "aufgemotztester": "aufgemotzt",
    "aufgemotztestes": "aufgemotzt",
    "aufgemuntert": "aufmuntern",
    "aufgemunterte": "aufgemuntert",
    "aufgemuntertem": "aufgemuntert",
    "aufgemunterten": "aufgemuntert",
    "aufgemunterter": "aufgemuntert",
    "aufgemuntertere": "aufgemuntert",
    "aufgemunterterem": "aufgemuntert",
    "aufgemunterteren": "aufgemuntert",
    "aufgemunterterer": "aufgemuntert",
    "aufgemunterteres": "aufgemuntert",
    "aufgemuntertes": "aufgemuntert",
    "aufgemunterteste": "aufgemuntert",
    "aufgemuntertestem": "aufgemuntert",
    "aufgemuntertesten": "aufgemuntert",
    "aufgemuntertester": "aufgemuntert",
    "aufgemuntertestes": "aufgemuntert",
    "aufgemöbelt": "aufmöbeln",
    "aufgemöbelte": "aufgemöbelt",
    "aufgemöbeltem": "aufgemöbelt",
    "aufgemöbelten": "aufgemöbelt",
    "aufgemöbelter": "aufgemöbelt",
    "aufgemöbeltere": "aufgemöbelt",
    "aufgemöbelterem": "aufgemöbelt",
    "aufgemöbelteren": "aufgemöbelt",
    "aufgemöbelterer": "aufgemöbelt",
    "aufgemöbelteres": "aufgemöbelt",
    "aufgemöbeltes": "aufgemöbelt",
    "aufgemöbelteste": "aufgemöbelt",
    "aufgemöbeltestem": "aufgemöbelt",
    "aufgemöbeltesten": "aufgemöbelt",
    "aufgemöbeltester": "aufgemöbelt",
    "aufgemöbeltestes": "aufgemöbelt",
    "aufgenagelt": "aufnageln",
    "aufgenagelte": "aufgenagelt",
    "aufgenageltem": "aufgenagelt",
    "aufgenagelten": "aufgenagelt",
    "aufgenagelter": "aufgenagelt",
    "aufgenageltes": "aufgenagelt",
    "aufgenommen": "aufnehmen",
    "aufgenommene": "aufgenommen",
    "aufgenommenem": "aufgenommen",
    "aufgenommenen": "aufgenommen",
    "aufgenommener": "aufgenommen",
    "aufgenommenes": "aufgenommen",
    "aufgenäht": "aufnähen",
    "aufgenähte": "aufgenäht",
    "aufgenähtem": "aufgenäht",
    "aufgenähten": "aufgenäht",
    "aufgenähter": "aufgenäht",
    "aufgenähtes": "aufgenäht",
    "aufgeopfert": "aufopfern",
    "aufgeopferte": "aufgeopfert",
    "aufgeopfertem": "aufgeopfert",
    "aufgeopferten": "aufgeopfert",
    "aufgeopferter": "aufgeopfert",
    "aufgeopfertere": "aufgeopfert",
    "aufgeopferterem": "aufgeopfert",
    "aufgeopferteren": "aufgeopfert",
    "aufgeopferterer": "aufgeopfert",
    "aufgeopferteres": "aufgeopfert",
    "aufgeopfertes": "aufgeopfert",
    "aufgeopferteste": "aufgeopfert",
    "aufgeopfertestem": "aufgeopfert",
    "aufgeopfertesten": "aufgeopfert",
    "aufgeopfertester": "aufgeopfert",
    "aufgeopfertestes": "aufgeopfert",
    "aufgepasstem": "aufgepasst",
    "aufgepasstes": "aufgepasst",
    "aufgepaßt": "aufpassen",
    "aufgepaßte": "aufgepaßt",
    "aufgepaßten": "aufgepaßt",
    "aufgepaßter": "aufgepaßt",
    "aufgepflanzt": "aufpflanzen",
    "aufgepflanzte": "aufgepflanzt",
    "aufgepflanztem": "aufgepflanzt",
    "aufgepflanzten": "aufgepflanzt",
    "aufgepflanzter": "aufgepflanzt",
    "aufgepflanztes": "aufgepflanzt",
    "aufgepfropft": "aufpfropfen",
    "aufgepfropfte": "aufgepfropft",
    "aufgepfropftem": "aufgepfropft",
    "aufgepfropften": "aufgepfropft",
    "aufgepfropfter": "aufgepfropft",
    "aufgepfropftere": "aufgepfropft",
    "aufgepfropfterem": "aufgepfropft",
    "aufgepfropfteren": "aufgepfropft",
    "aufgepfropfterer": "aufgepfropft",
    "aufgepfropfteres": "aufgepfropft",
    "aufgepfropftes": "aufgepfropft",
    "aufgepfropfteste": "aufgepfropft",
    "aufgepfropftestem": "aufgepfropft",
    "aufgepfropftesten": "aufgepfropft",
    "aufgepfropftester": "aufgepfropft",
    "aufgepfropftestes": "aufgepfropft",
    "aufgeplatzt": "aufplatzen",
    "aufgeplatzte": "aufgeplatzt",
    "aufgeplatztem": "aufgeplatzt",
    "aufgeplatzten": "aufgeplatzt",
    "aufgeplatzter": "aufgeplatzt",
    "aufgeplatztere": "aufgeplatzt",
    "aufgeplatzterem": "aufgeplatzt",
    "aufgeplatzteren": "aufgeplatzt",
    "aufgeplatzterer": "aufgeplatzt",
    "aufgeplatzteres": "aufgeplatzt",
    "aufgeplatztes": "aufgeplatzt",
    "aufgeplatzteste": "aufgeplatzt",
    "aufgeplatztestem": "aufgeplatzt",
    "aufgeplatztesten": "aufgeplatzt",
    "aufgeplatztester": "aufgeplatzt",
    "aufgeplatztestes": "aufgeplatzt",
    "aufgeplustert": "aufplustern",
    "aufgeplusterte": "aufgeplustert",
    "aufgeplustertem": "aufgeplustert",
    "aufgeplusterten": "aufgeplustert",
    "aufgeplusterter": "aufgeplustert",
    "aufgeplustertere": "aufgeplustert",
    "aufgeplusterterem": "aufgeplustert",
    "aufgeplusterteren": "aufgeplustert",
    "aufgeplusterterer": "aufgeplustert",
    "aufgeplusterteres": "aufgeplustert",
    "aufgeplustertes": "aufgeplustert",
    "aufgeplusterteste": "aufgeplustert",
    "aufgeplustertestem": "aufgeplustert",
    "aufgeplustertesten": "aufgeplustert",
    "aufgeplustertester": "aufgeplustert",
    "aufgeplustertestes": "aufgeplustert",
    "aufgepolstert": "aufpolstern",
    "aufgepolsterte": "aufgepolstert",
    "aufgepolstertem": "aufgepolstert",
    "aufgepolsterten": "aufgepolstert",
    "aufgepolsterter": "aufgepolstert",
    "aufgepolstertere": "aufgepolstert",
    "aufgepolsterterem": "aufgepolstert",
    "aufgepolsterteren": "aufgepolstert",
    "aufgepolsterterer": "aufgepolstert",
    "aufgepolsterteres": "aufgepolstert",
    "aufgepolstertes": "aufgepolstert",
    "aufgepolsterteste": "aufgepolstert",
    "aufgepolstertestem": "aufgepolstert",
    "aufgepolstertesten": "aufgepolstert",
    "aufgepolstertester": "aufgepolstert",
    "aufgepolstertestes": "aufgepolstert",
    "aufgepoppt": "aufpoppen",
    "aufgepoppte": "aufgepoppt",
    "aufgepopptem": "aufgepoppt",
    "aufgepoppten": "aufgepoppt",
    "aufgepoppter": "aufgepoppt",
    "aufgepopptes": "aufgepoppt",
    "aufgeprallt": "aufprallen",
    "aufgeprallte": "aufgeprallt",
    "aufgepralltem": "aufgeprallt",
    "aufgeprallten": "aufgeprallt",
    "aufgeprallter": "aufgeprallt",
    "aufgepralltes": "aufgeprallt",
    "aufgeprägt": "aufprägen",
    "aufgeprägte": "aufgeprägt",
    "aufgeprägtem": "aufgeprägt",
    "aufgeprägten": "aufgeprägt",
    "aufgeprägter": "aufgeprägt",
    "aufgeprägtes": "aufgeprägt",
    "aufgepumpt": "aufpumpen",
    "aufgepumpte": "aufgepumpt",
    "aufgepumptem": "aufgepumpt",
    "aufgepumpten": "aufgepumpt",
    "aufgepumpter": "aufgepumpt",
    "aufgepumptere": "aufgepumpt",
    "aufgepumpterem": "aufgepumpt",
    "aufgepumpteren": "aufgepumpt",
    "aufgepumpterer": "aufgepumpt",
    "aufgepumpteres": "aufgepumpt",
    "aufgepumptes": "aufgepumpt",
    "aufgepumpteste": "aufgepumpt",
    "aufgepumptestem": "aufgepumpt",
    "aufgepumptesten": "aufgepumpt",
    "aufgepumptester": "aufgepumpt",
    "aufgepumptestes": "aufgepumpt",
    "aufgeputscht": "aufputschen",
    "aufgeputschte": "aufgeputscht",
    "aufgeputschtem": "aufgeputscht",
    "aufgeputschten": "aufgeputscht",
    "aufgeputschter": "aufgeputscht",
    "aufgeputschtere": "aufgeputscht",
    "aufgeputschterem": "aufgeputscht",
    "aufgeputschteren": "aufgeputscht",
    "aufgeputschterer": "aufgeputscht",
    "aufgeputschteres": "aufgeputscht",
    "aufgeputschtes": "aufgeputscht",
    "aufgeputschteste": "aufgeputscht",
    "aufgeputschtestem": "aufgeputscht",
    "aufgeputschtesten": "aufgeputscht",
    "aufgeputschtester": "aufgeputscht",
    "aufgeputschtestes": "aufgeputscht",
    "aufgeputzt": "aufputzen",
    "aufgeputzte": "aufgeputzt",
    "aufgeputztem": "aufgeputzt",
    "aufgeputzten": "aufgeputzt",
    "aufgeputzter": "aufgeputzt",
    "aufgeputztes": "aufgeputzt",
    "aufgepäppelt": "aufpäppeln",
    "aufgepäppelte": "aufgepäppelt",
    "aufgepäppeltem": "aufgepäppelt",
    "aufgepäppelten": "aufgepäppelt",
    "aufgepäppelter": "aufgepäppelt",
    "aufgepäppeltere": "aufgepäppelt",
    "aufgepäppelterem": "aufgepäppelt",
    "aufgepäppelteren": "aufgepäppelt",
    "aufgepäppelterer": "aufgepäppelt",
    "aufgepäppelteres": "aufgepäppelt",
    "aufgepäppeltes": "aufgepäppelt",
    "aufgepäppelteste": "aufgepäppelt",
    "aufgepäppeltestem": "aufgepäppelt",
    "aufgepäppeltesten": "aufgepäppelt",
    "aufgepäppeltester": "aufgepäppelt",
    "aufgepäppeltestes": "aufgepäppelt",
    "aufgequellt": "aufquellen",
    "aufgequellte": "aufgequellt",
    "aufgequelltem": "aufgequellt",
    "aufgequellten": "aufgequellt",
    "aufgequellter": "aufgequellt",
    "aufgequelltere": "aufgequellt",
    "aufgequellterem": "aufgequellt",
    "aufgequellteren": "aufgequellt",
    "aufgequellterer": "aufgequellt",
    "aufgequellteres": "aufgequellt",
    "aufgequelltes": "aufgequellt",
    "aufgequellteste": "aufgequellt",
    "aufgequelltestem": "aufgequellt",
    "aufgequelltesten": "aufgequellt",
    "aufgequelltester": "aufgequellt",
    "aufgequelltestes": "aufgequellt",
    "aufgequollen": "aufquellen",
    "aufgequollene": "aufgequollen",
    "aufgequollenem": "aufgequollen",
    "aufgequollenen": "aufgequollen",
    "aufgequollener": "aufgequollen",
    "aufgequollenere": "aufgequollen",
    "aufgequollenerem": "aufgequollen",
    "aufgequolleneren": "aufgequollen",
    "aufgequollenerer": "aufgequollen",
    "aufgequolleneres": "aufgequollen",
    "aufgequollenes": "aufgequollen",
    "aufgequollenste": "aufgequollen",
    "aufgequollenstem": "aufgequollen",
    "aufgequollensten": "aufgequollen",
    "aufgequollenster": "aufgequollen",
    "aufgequollenstes": "aufgequollen",
    "aufgerafft": "aufraffen",
    "aufgeraffte": "aufgerafft",
    "aufgerafftem": "aufgerafft",
    "aufgerafften": "aufgerafft",
    "aufgeraffter": "aufgerafft",
    "aufgerafftes": "aufgerafft",
    "aufgeragt": "aufragen",
    "aufgeragte": "aufgeragt",
    "aufgeragtem": "aufgeragt",
    "aufgeragten": "aufgeragt",
    "aufgeragter": "aufgeragt",
    "aufgeragtes": "aufgeragt",
    "aufgerappelt": "aufrappeln",
    "aufgerappelte": "aufgerappelt",
    "aufgerappeltem": "aufgerappelt",
    "aufgerappelten": "aufgerappelt",
    "aufgerappelter": "aufgerappelt",
    "aufgerappeltere": "aufgerappelt",
    "aufgerappelterem": "aufgerappelt",
    "aufgerappelteren": "aufgerappelt",
    "aufgerappelterer": "aufgerappelt",
    "aufgerappelteres": "aufgerappelt",
    "aufgerappeltes": "aufgerappelt",
    "aufgerappelteste": "aufgerappelt",
    "aufgerappeltestem": "aufgerappelt",
    "aufgerappeltesten": "aufgerappelt",
    "aufgerappeltester": "aufgerappelt",
    "aufgerappeltestes": "aufgerappelt",
    "aufgeraucht": "aufrauchen",
    "aufgerauchte": "aufgeraucht",
    "aufgerauchtem": "aufgeraucht",
    "aufgerauchten": "aufgeraucht",
    "aufgerauchter": "aufgeraucht",
    "aufgerauchtes": "aufgeraucht",
    "aufgerauht": "aufrauhen",
    "aufgerauhte": "aufgerauht",
    "aufgerauhtem": "aufgerauht",
    "aufgerauhten": "aufgerauht",
    "aufgerauhter": "aufgerauht",
    "aufgerauhtere": "aufgerauht",
    "aufgerauhterem": "aufgerauht",
    "aufgerauhteren": "aufgerauht",
    "aufgerauhterer": "aufgerauht",
    "aufgerauhteres": "aufgerauht",
    "aufgerauhtes": "aufgerauht",
    "aufgerauhteste": "aufgerauht",
    "aufgerauhtestem": "aufgerauht",
    "aufgerauhtesten": "aufgerauht",
    "aufgerauhtester": "aufgerauht",
    "aufgerauhtestes": "aufgerauht",
    "aufgeraut": "aufrauen",
    "aufgeraute": "aufgeraut",
    "aufgerautem": "aufgeraut",
    "aufgerauten": "aufgeraut",
    "aufgerauter": "aufgeraut",
    "aufgerautere": "aufgeraut",
    "aufgerauterem": "aufgeraut",
    "aufgerauteren": "aufgeraut",
    "aufgerauterer": "aufgeraut",
    "aufgerauteres": "aufgeraut",
    "aufgerautes": "aufgeraut",
    "aufgerauteste": "aufgeraut",
    "aufgerautestem": "aufgeraut",
    "aufgerautesten": "aufgeraut",
    "aufgerautester": "aufgeraut",
    "aufgerautestes": "aufgeraut",
    "aufgerechnet": "aufrechnen",
    "aufgerechnete": "aufgerechnet",
    "aufgerechnetem": "aufgerechnet",
    "aufgerechneten": "aufgerechnet",
    "aufgerechneter": "aufgerechnet",
    "aufgerechnetes": "aufgerechnet",
    "aufgeregt": "aufregen",
    "aufgeregte": "aufgeregt",
    "aufgeregtem": "aufgeregt",
    "aufgeregten": "aufgeregt",
    "aufgeregter": "aufgeregt",
    "aufgeregtere": "aufgeregt",
    "aufgeregterem": "aufgeregt",
    "aufgeregteren": "aufgeregt",
    "aufgeregterer": "aufgeregt",
    "aufgeregteres": "aufgeregt",
    "aufgeregtes": "aufgeregt",
    "aufgeregteste": "aufgeregt",
    "aufgeregtestem": "aufgeregt",
    "aufgeregtesten": "aufgeregt",
    "aufgeregtester": "aufgeregt",
    "aufgeregtestes": "aufgeregt",
    "aufgereiht": "aufreihen",
    "aufgereihte": "aufgereiht",
    "aufgereihtem": "aufgereiht",
    "aufgereihten": "aufgereiht",
    "aufgereihter": "aufgereiht",
    "aufgereihtes": "aufgereiht",
    "aufgereizt": "aufreizen",
    "aufgereizte": "aufgereizt",
    "aufgereiztem": "aufgereizt",
    "aufgereizten": "aufgereizt",
    "aufgereizter": "aufgereizt",
    "aufgereiztere": "aufgereizt",
    "aufgereizterem": "aufgereizt",
    "aufgereizteren": "aufgereizt",
    "aufgereizterer": "aufgereizt",
    "aufgereizteres": "aufgereizt",
    "aufgereiztes": "aufgereizt",
    "aufgereizteste": "aufgereizt",
    "aufgereiztestem": "aufgereizt",
    "aufgereiztesten": "aufgereizt",
    "aufgereiztester": "aufgereizt",
    "aufgereiztestes": "aufgereizt",
    "aufgeribbelt": "aufribbeln",
    "aufgeribbelte": "aufgeribbelt",
    "aufgeribbeltem": "aufgeribbelt",
    "aufgeribbelten": "aufgeribbelt",
    "aufgeribbelter": "aufgeribbelt",
    "aufgeribbeltes": "aufgeribbelt",
    "aufgerichtet": "aufrichten",
    "aufgerichtete": "aufgerichtet",
    "aufgerichtetem": "aufgerichtet",
    "aufgerichteten": "aufgerichtet",
    "aufgerichteter": "aufgerichtet",
    "aufgerichtetes": "aufgerichtet",
    "aufgerieben": "aufreiben",
    "aufgeriebene": "aufgerieben",
    "aufgeriebenem": "aufgerieben",
    "aufgeriebenen": "aufgerieben",
    "aufgeriebener": "aufgerieben",
    "aufgeriebenere": "aufgerieben",
    "aufgeriebenerem": "aufgerieben",
    "aufgeriebeneren": "aufgerieben",
    "aufgeriebenerer": "aufgerieben",
    "aufgeriebeneres": "aufgerieben",
    "aufgeriebenes": "aufgerieben",
    "aufgeriebenste": "aufgerieben",
    "aufgeriebenstem": "aufgerieben",
    "aufgeriebensten": "aufgerieben",
    "aufgeriebenster": "aufgerieben",
    "aufgeriebenstes": "aufgerieben",
    "aufgerissen": "aufreißen",
    "aufgerissene": "aufgerissen",
    "aufgerissenem": "aufgerissen",
    "aufgerissenen": "aufgerissen",
    "aufgerissener": "aufgerissen",
    "aufgerissenes": "aufgerissen",
    "aufgeritten": "aufreiten",
    "aufgerittene": "aufgeritten",
    "aufgerittenem": "aufgeritten",
    "aufgerittenen": "aufgeritten",
    "aufgerittener": "aufgeritten",
    "aufgerittenes": "aufgeritten",
    "aufgerollt": "aufrollen",
    "aufgerollte": "aufgerollt",
    "aufgerolltem": "aufgerollt",
    "aufgerollten": "aufgerollt",
    "aufgerollter": "aufgerollt",
    "aufgerolltere": "aufgerollt",
    "aufgerollterem": "aufgerollt",
    "aufgerollteren": "aufgerollt",
    "aufgerollterer": "aufgerollt",
    "aufgerollteres": "aufgerollt",
    "aufgerolltes": "aufgerollt",
    "aufgerollteste": "aufgerollt",
    "aufgerolltestem": "aufgerollt",
    "aufgerolltesten": "aufgerollt",
    "aufgerolltester": "aufgerollt",
    "aufgerolltestes": "aufgerollt",
    "aufgerufen": "aufrufen",
    "aufgerufene": "aufgerufen",
    "aufgerufenem": "aufgerufen",
    "aufgerufenen": "aufgerufen",
    "aufgerufener": "aufgerufen",
    "aufgerufenes": "aufgerufen",
    "aufgerundet": "aufrunden",
    "aufgerundete": "aufgerundet",
    "aufgerundetem": "aufgerundet",
    "aufgerundeten": "aufgerundet",
    "aufgerundeter": "aufgerundet",
    "aufgerundetes": "aufgerundet",
    "aufgeräumt": "aufräumen",
    "aufgeräumte": "aufgeräumt",
    "aufgeräumtem": "aufgeräumt",
    "aufgeräumten": "aufgeräumt",
    "aufgeräumter": "aufgeräumt",
    "aufgeräumtere": "aufgeräumt",
    "aufgeräumterem": "aufgeräumt",
    "aufgeräumteren": "aufgeräumt",
    "aufgeräumterer": "aufgeräumt",
    "aufgeräumteres": "aufgeräumt",
    "aufgeräumtes": "aufgeräumt",
    "aufgeräumteste": "aufgeräumt",
    "aufgeräumtestem": "aufgeräumt",
    "aufgeräumtesten": "aufgeräumt",
    "aufgeräumtester": "aufgeräumt",
    "aufgeräumtestes": "aufgeräumt",
    "aufgerührt": "aufrühren",
    "aufgerührte": "aufgerührt",
    "aufgerührtem": "aufgerührt",
    "aufgerührten": "aufgerührt",
    "aufgerührter": "aufgerührt",
    "aufgerührtere": "aufgerührt",
    "aufgerührterem": "aufgerührt",
    "aufgerührteren": "aufgerührt",
    "aufgerührterer": "aufgerührt",
    "aufgerührteres": "aufgerührt",
    "aufgerührtes": "aufgerührt",
    "aufgerührteste": "aufgerührt",
    "aufgerührtestem": "aufgerührt",
    "aufgerührtesten": "aufgerührt",
    "aufgerührtester": "aufgerührt",
    "aufgerührtestes": "aufgerührt",
    "aufgerüstet": "aufrüsten",
    "aufgerüstete": "aufgerüstet",
    "aufgerüstetem": "aufgerüstet",
    "aufgerüsteten": "aufgerüstet",
    "aufgerüsteter": "aufgerüstet",
    "aufgerüstetes": "aufgerüstet",
    "aufgerüttelt": "aufrütteln",
    "aufgerüttelte": "aufgerüttelt",
    "aufgerütteltem": "aufgerüttelt",
    "aufgerüttelten": "aufgerüttelt",
    "aufgerüttelter": "aufgerüttelt",
    "aufgerütteltes": "aufgerüttelt",
    "aufgesagt": "aufsagen",
    "aufgesagte": "aufgesagt",
    "aufgesagtem": "aufgesagt",
    "aufgesagten": "aufgesagt",
    "aufgesagter": "aufgesagt",
    "aufgesagtes": "aufgesagt",
    "aufgesammelt": "aufsammeln",
    "aufgesammelte": "aufgesammelt",
    "aufgesammeltem": "aufgesammelt",
    "aufgesammelten": "aufgesammelt",
    "aufgesammelter": "aufgesammelt",
    "aufgesammeltes": "aufgesammelt",
    "aufgesaugt": "aufsaugen",
    "aufgesaugte": "aufgesaugt",
    "aufgesaugtem": "aufgesaugt",
    "aufgesaugten": "aufgesaugt",
    "aufgesaugter": "aufgesaugt",
    "aufgesaugtere": "aufgesaugt",
    "aufgesaugterem": "aufgesaugt",
    "aufgesaugteren": "aufgesaugt",
    "aufgesaugterer": "aufgesaugt",
    "aufgesaugteres": "aufgesaugt",
    "aufgesaugtes": "aufgesaugt",
    "aufgesaugteste": "aufgesaugt",
    "aufgesaugtestem": "aufgesaugt",
    "aufgesaugtesten": "aufgesaugt",
    "aufgesaugtester": "aufgesaugt",
    "aufgesaugtestes": "aufgesaugt",
    "aufgeschaukelt": "aufschaukeln",
    "aufgeschaukelte": "aufgeschaukelt",
    "aufgeschaukeltem": "aufgeschaukelt",
    "aufgeschaukelten": "aufgeschaukelt",
    "aufgeschaukelter": "aufgeschaukelt",
    "aufgeschaukeltere": "aufgeschaukelt",
    "aufgeschaukelterem": "aufgeschaukelt",
    "aufgeschaukelteren": "aufgeschaukelt",
    "aufgeschaukelterer": "aufgeschaukelt",
    "aufgeschaukelteres": "aufgeschaukelt",
    "aufgeschaukeltes": "aufgeschaukelt",
    "aufgeschaukelteste": "aufgeschaukelt",
    "aufgeschaukeltestem": "aufgeschaukelt",
    "aufgeschaukeltesten": "aufgeschaukelt",
    "aufgeschaukeltester": "aufgeschaukelt",
    "aufgeschaukeltestes": "aufgeschaukelt",
    "aufgeschaut": "aufschauen",
    "aufgeschaute": "aufgeschaut",
    "aufgeschautem": "aufgeschaut",
    "aufgeschauten": "aufgeschaut",
    "aufgeschauter": "aufgeschaut",
    "aufgeschautes": "aufgeschaut",
    "aufgescheucht": "aufscheuchen",
    "aufgescheuchte": "aufgescheucht",
    "aufgescheuchtem": "aufgescheucht",
    "aufgescheuchten": "aufgescheucht",
    "aufgescheuchter": "aufgescheucht",
    "aufgescheuchtere": "aufgescheucht",
    "aufgescheuchterem": "aufgescheucht",
    "aufgescheuchteren": "aufgescheucht",
    "aufgescheuchterer": "aufgescheucht",
    "aufgescheuchteres": "aufgescheucht",
    "aufgescheuchtes": "aufgescheucht",
    "aufgescheuchteste": "aufgescheucht",
    "aufgescheuchtestem": "aufgescheucht",
    "aufgescheuchtesten": "aufgescheucht",
    "aufgescheuchtester": "aufgescheucht",
    "aufgescheuchtestes": "aufgescheucht",
    "aufgescheuert": "aufscheuern",
    "aufgescheuerte": "aufgescheuert",
    "aufgescheuertem": "aufgescheuert",
    "aufgescheuerten": "aufgescheuert",
    "aufgescheuerter": "aufgescheuert",
    "aufgescheuertere": "aufgescheuert",
    "aufgescheuerterem": "aufgescheuert",
    "aufgescheuerteren": "aufgescheuert",
    "aufgescheuerterer": "aufgescheuert",
    "aufgescheuerteres": "aufgescheuert",
    "aufgescheuertes": "aufgescheuert",
    "aufgescheuerteste": "aufgescheuert",
    "aufgescheuertestem": "aufgescheuert",
    "aufgescheuertesten": "aufgescheuert",
    "aufgescheuertester": "aufgescheuert",
    "aufgescheuertestes": "aufgescheuert",
    "aufgeschichtet": "aufschichten",
    "aufgeschichtete": "aufgeschichtet",
    "aufgeschichtetem": "aufgeschichtet",
    "aufgeschichteten": "aufgeschichtet",
    "aufgeschichteter": "aufgeschichtet",
    "aufgeschichtetes": "aufgeschichtet",
    "aufgeschienen": "aufscheinen",
    "aufgeschienene": "aufgeschienen",
    "aufgeschienenem": "aufgeschienen",
    "aufgeschienenen": "aufgeschienen",
    "aufgeschienener": "aufgeschienen",
    "aufgeschienenes": "aufgeschienen",
    "aufgeschlagen": "aufschlagen",
    "aufgeschlagene": "aufgeschlagen",
    "aufgeschlagenem": "aufgeschlagen",
    "aufgeschlagenen": "aufgeschlagen",
    "aufgeschlagener": "aufgeschlagen",
    "aufgeschlagenes": "aufgeschlagen",
    "aufgeschlitzt": "aufschlitzen",
    "aufgeschlitzte": "aufgeschlitzt",
    "aufgeschlitztem": "aufgeschlitzt",
    "aufgeschlitzten": "aufgeschlitzt",
    "aufgeschlitzter": "aufgeschlitzt",
    "aufgeschlitztere": "aufgeschlitzt",
    "aufgeschlitzterem": "aufgeschlitzt",
    "aufgeschlitzteren": "aufgeschlitzt",
    "aufgeschlitzterer": "aufgeschlitzt",
    "aufgeschlitzteres": "aufgeschlitzt",
    "aufgeschlitztes": "aufgeschlitzt",
    "aufgeschlitzteste": "aufgeschlitzt",
    "aufgeschlitztestem": "aufgeschlitzt",
    "aufgeschlitztesten": "aufgeschlitzt",
    "aufgeschlitztester": "aufgeschlitzt",
    "aufgeschlitztestes": "aufgeschlitzt",
    "aufgeschlossen": "aufschließen",
    "aufgeschlossene": "aufgeschlossen",
    "aufgeschlossenem": "aufgeschlossen",
    "aufgeschlossenen": "aufgeschlossen",
    "aufgeschlossener": "aufgeschlossen",
    "aufgeschlossenes": "aufgeschlossen",
    "aufgeschluchzt": "aufschluchzen",
    "aufgeschluchzte": "aufgeschluchzt",
    "aufgeschluchztem": "aufgeschluchzt",
    "aufgeschluchzten": "aufgeschluchzt",
    "aufgeschluchzter": "aufgeschluchzt",
    "aufgeschluchztes": "aufgeschluchzt",
    "aufgeschlämmt": "aufschlämmen",
    "aufgeschlämmte": "aufgeschlämmt",
    "aufgeschlämmtem": "aufgeschlämmt",
    "aufgeschlämmten": "aufgeschlämmt",
    "aufgeschlämmter": "aufgeschlämmt",
    "aufgeschlämmtes": "aufgeschlämmt",
    "aufgeschlüsselt": "aufschlüsseln",
    "aufgeschlüsselte": "aufgeschlüsselt",
    "aufgeschlüsseltem": "aufgeschlüsselt",
    "aufgeschlüsselten": "aufgeschlüsselt",
    "aufgeschlüsselter": "aufgeschlüsselt",
    "aufgeschlüsseltere": "aufgeschlüsselt",
    "aufgeschlüsselterem": "aufgeschlüsselt",
    "aufgeschlüsselteren": "aufgeschlüsselt",
    "aufgeschlüsselterer": "aufgeschlüsselt",
    "aufgeschlüsselteres": "aufgeschlüsselt",
    "aufgeschlüsseltes": "aufgeschlüsselt",
    "aufgeschlüsselteste": "aufgeschlüsselt",
    "aufgeschlüsseltestem": "aufgeschlüsselt",
    "aufgeschlüsseltesten": "aufgeschlüsselt",
    "aufgeschlüsseltester": "aufgeschlüsselt",
    "aufgeschlüsseltestes": "aufgeschlüsselt",
    "aufgeschmissen": "aufschmeißen",
    "aufgeschmissene": "aufgeschmissen",
    "aufgeschmissenem": "aufgeschmissen",
    "aufgeschmissenen": "aufgeschmissen",
    "aufgeschmissener": "aufgeschmissen",
    "aufgeschmissenere": "aufgeschmissen",
    "aufgeschmissenerem": "aufgeschmissen",
    "aufgeschmisseneren": "aufgeschmissen",
    "aufgeschmissenerer": "aufgeschmissen",
    "aufgeschmisseneres": "aufgeschmissen",
    "aufgeschmissenes": "aufgeschmissen",
    "aufgeschmissenste": "aufgeschmissen",
    "aufgeschmissenstem": "aufgeschmissen",
    "aufgeschmissensten": "aufgeschmissen",
    "aufgeschmissenster": "aufgeschmissen",
    "aufgeschmissenstes": "aufgeschmissen",
    "aufgeschnallt": "aufschnallen",
    "aufgeschnallte": "aufgeschnallt",
    "aufgeschnalltem": "aufgeschnallt",
    "aufgeschnallten": "aufgeschnallt",
    "aufgeschnallter": "aufgeschnallt",
    "aufgeschnalltes": "aufgeschnallt",
    "aufgeschnappt": "aufschnappen",
    "aufgeschnappte": "aufgeschnappt",
    "aufgeschnapptem": "aufgeschnappt",
    "aufgeschnappten": "aufgeschnappt",
    "aufgeschnappter": "aufgeschnappt",
    "aufgeschnapptes": "aufgeschnappt",
    "aufgeschnellt": "aufschnellen",
    "aufgeschnellte": "aufgeschnellt",
    "aufgeschnelltem": "aufgeschnellt",
    "aufgeschnellten": "aufgeschnellt",
    "aufgeschnellter": "aufgeschnellt",
    "aufgeschnelltes": "aufgeschnellt",
    "aufgeschnitten": "aufschneiden",
    "aufgeschnittene": "aufgeschnitten",
    "aufgeschnittenem": "aufgeschnitten",
    "aufgeschnittenen": "aufgeschnitten",
    "aufgeschnittener": "aufgeschnitten",
    "aufgeschnittenes": "aufgeschnitten",
    "aufgeschnürt": "aufschnüren",
    "aufgeschnürte": "aufgeschnürt",
    "aufgeschnürtem": "aufgeschnürt",
    "aufgeschnürten": "aufgeschnürt",
    "aufgeschnürter": "aufgeschnürt",
    "aufgeschnürtes": "aufgeschnürt",
    "aufgeschoben": "aufschieben",
    "aufgeschobene": "aufgeschoben",
    "aufgeschobenem": "aufgeschoben",
    "aufgeschobenen": "aufgeschoben",
    "aufgeschobener": "aufgeschoben",
    "aufgeschobenere": "aufgeschoben",
    "aufgeschobenerem": "aufgeschoben",
    "aufgeschobeneren": "aufgeschoben",
    "aufgeschobenerer": "aufgeschoben",
    "aufgeschobeneres": "aufgeschoben",
    "aufgeschobenes": "aufgeschoben",
    "aufgeschobenste": "aufgeschoben",
    "aufgeschobenstem": "aufgeschoben",
    "aufgeschobensten": "aufgeschoben",
    "aufgeschobenster": "aufgeschoben",
    "aufgeschobenstes": "aufgeschoben",
    "aufgeschossen": "aufschießen",
    "aufgeschossene": "aufgeschossen",
    "aufgeschossenem": "aufgeschossen",
    "aufgeschossenen": "aufgeschossen",
    "aufgeschossener": "aufgeschossen",
    "aufgeschossenes": "aufgeschossen",
    "aufgeschraubt": "aufschrauben",
    "aufgeschraubte": "aufgeschraubt",
    "aufgeschraubtem": "aufgeschraubt",
    "aufgeschraubten": "aufgeschraubt",
    "aufgeschraubter": "aufgeschraubt",
    "aufgeschraubtes": "aufgeschraubt",
    "aufgeschreckt": "aufschrecken",
    "aufgeschreckte": "aufgeschreckt",
    "aufgeschrecktem": "aufgeschreckt",
    "aufgeschreckten": "aufgeschreckt",
    "aufgeschreckter": "aufgeschreckt",
    "aufgeschrecktere": "aufgeschreckt",
    "aufgeschreckterem": "aufgeschreckt",
    "aufgeschreckteren": "aufgeschreckt",
    "aufgeschreckterer": "aufgeschreckt",
    "aufgeschreckteres": "aufgeschreckt",
    "aufgeschrecktes": "aufgeschreckt",
    "aufgeschreckteste": "aufgeschreckt",
    "aufgeschrecktestem": "aufgeschreckt",
    "aufgeschrecktesten": "aufgeschreckt",
    "aufgeschrecktester": "aufgeschreckt",
    "aufgeschrecktestes": "aufgeschreckt",
    "aufgeschrieben": "aufschreiben",
    "aufgeschriebene": "aufgeschrieben",
    "aufgeschriebenem": "aufgeschrieben",
    "aufgeschriebenen": "aufgeschrieben",
    "aufgeschriebener": "aufgeschrieben",
    "aufgeschriebenere": "aufgeschrieben",
    "aufgeschriebenerem": "aufgeschrieben",
    "aufgeschriebeneren": "aufgeschrieben",
    "aufgeschriebenerer": "aufgeschrieben",
    "aufgeschriebeneres": "aufgeschrieben",
    "aufgeschriebenes": "aufgeschrieben",
    "aufgeschriebenste": "aufgeschrieben",
    "aufgeschriebenstem": "aufgeschrieben",
    "aufgeschriebensten": "aufgeschrieben",
    "aufgeschriebenster": "aufgeschrieben",
    "aufgeschriebenstes": "aufgeschrieben",
    "aufgeschrien": "aufschreien",
    "aufgeschriene": "aufgeschrien",
    "aufgeschrienem": "aufgeschrien",
    "aufgeschrienen": "aufgeschrien",
    "aufgeschriener": "aufgeschrien",
    "aufgeschrienere": "aufgeschrien",
    "aufgeschrienerem": "aufgeschrien",
    "aufgeschrieneren": "aufgeschrien",
    "aufgeschrienerer": "aufgeschrien",
    "aufgeschrieneres": "aufgeschrien",
    "aufgeschrienes": "aufgeschrien",
    "aufgeschrienste": "aufgeschrien",
    "aufgeschrienstem": "aufgeschrien",
    "aufgeschriensten": "aufgeschrien",
    "aufgeschrienster": "aufgeschrien",
    "aufgeschrienstes": "aufgeschrien",
    "aufgeschrocken": "aufschrecken",
    "aufgeschrockene": "aufgeschrocken",
    "aufgeschrockenem": "aufgeschrocken",
    "aufgeschrockenen": "aufgeschrocken",
    "aufgeschrockener": "aufgeschrocken",
    "aufgeschrockenere": "aufgeschrocken",
    "aufgeschrockenerem": "aufgeschrocken",
    "aufgeschrockeneren": "aufgeschrocken",
    "aufgeschrockenerer": "aufgeschrocken",
    "aufgeschrockeneres": "aufgeschrocken",
    "aufgeschrockenes": "aufgeschrocken",
    "aufgeschrockenste": "aufgeschrocken",
    "aufgeschrockenstem": "aufgeschrocken",
    "aufgeschrockensten": "aufgeschrocken",
    "aufgeschrockenster": "aufgeschrocken",
    "aufgeschrockenstes": "aufgeschrocken",
    "aufgeschrumpft": "aufschrumpfen",
    "aufgeschrumpfte": "aufgeschrumpft",
    "aufgeschrumpftem": "aufgeschrumpft",
    "aufgeschrumpften": "aufgeschrumpft",
    "aufgeschrumpfter": "aufgeschrumpft",
    "aufgeschrumpftes": "aufgeschrumpft",
    "aufgeschunden": "aufschinden",
    "aufgeschundene": "aufgeschunden",
    "aufgeschundenem": "aufgeschunden",
    "aufgeschundenen": "aufgeschunden",
    "aufgeschundener": "aufgeschunden",
    "aufgeschundenes": "aufgeschunden",
    "aufgeschwatzt": "aufschwatzen",
    "aufgeschwatzte": "aufgeschwatzt",
    "aufgeschwatztem": "aufgeschwatzt",
    "aufgeschwatzten": "aufgeschwatzt",
    "aufgeschwatzter": "aufgeschwatzt",
    "aufgeschwatztes": "aufgeschwatzt",
    "aufgeschwemmt": "aufschwemmen",
    "aufgeschwemmte": "aufgeschwemmt",
    "aufgeschwemmtem": "aufgeschwemmt",
    "aufgeschwemmten": "aufgeschwemmt",
    "aufgeschwemmter": "aufgeschwemmt",
    "aufgeschwemmtes": "aufgeschwemmt",
    "aufgeschwungen": "aufschwingen",
    "aufgeschwungene": "aufgeschwungen",
    "aufgeschwungenem": "aufgeschwungen",
    "aufgeschwungenen": "aufgeschwungen",
    "aufgeschwungener": "aufgeschwungen",
    "aufgeschwungenes": "aufgeschwungen",
    "aufgeschürft": "aufschürfen",
    "aufgeschürfte": "aufgeschürft",
    "aufgeschürftem": "aufgeschürft",
    "aufgeschürften": "aufgeschürft",
    "aufgeschürfter": "aufgeschürft",
    "aufgeschürftere": "aufgeschürft",
    "aufgeschürfterem": "aufgeschürft",
    "aufgeschürfteren": "aufgeschürft",
    "aufgeschürfterer": "aufgeschürft",
    "aufgeschürfteres": "aufgeschürft",
    "aufgeschürftes": "aufgeschürft",
    "aufgeschürfteste": "aufgeschürft",
    "aufgeschürftestem": "aufgeschürft",
    "aufgeschürftesten": "aufgeschürft",
    "aufgeschürftester": "aufgeschürft",
    "aufgeschürftestes": "aufgeschürft",
    "aufgeschüttelt": "aufschütteln",
    "aufgeschüttelte": "aufgeschüttelt",
    "aufgeschütteltem": "aufgeschüttelt",
    "aufgeschüttelten": "aufgeschüttelt",
    "aufgeschüttelter": "aufgeschüttelt",
    "aufgeschütteltere": "aufgeschüttelt",
    "aufgeschüttelterem": "aufgeschüttelt",
    "aufgeschüttelteren": "aufgeschüttelt",
    "aufgeschüttelterer": "aufgeschüttelt",
    "aufgeschüttelteres": "aufgeschüttelt",
    "aufgeschütteltes": "aufgeschüttelt",
    "aufgeschüttelteste": "aufgeschüttelt",
    "aufgeschütteltestem": "aufgeschüttelt",
    "aufgeschütteltesten": "aufgeschüttelt",
    "aufgeschütteltester": "aufgeschüttelt",
    "aufgeschütteltestes": "aufgeschüttelt",
    "aufgeschüttet": "aufschütten",
    "aufgeschüttete": "aufgeschüttet",
    "aufgeschüttetem": "aufgeschüttet",
    "aufgeschütteten": "aufgeschüttet",
    "aufgeschütteter": "aufgeschüttet",
    "aufgeschüttetes": "aufgeschüttet",
    "aufgesehen": "aufsehen",
    "aufgesehene": "aufgesehen",
    "aufgesehenem": "aufgesehen",
    "aufgesehenen": "aufgesehen",
    "aufgesehener": "aufgesehen",
    "aufgesehenes": "aufgesehen",
    "aufgesessen": "aufsitzen",
    "aufgesessene": "aufgesessen",
    "aufgesessenem": "aufgesessen",
    "aufgesessenen": "aufgesessen",
    "aufgesessener": "aufgesessen",
    "aufgesessenes": "aufgesessen",
    "aufgesetzt": "aufsetzen",
    "aufgesetzte": "aufgesetzt",
    "aufgesetztem": "aufgesetzt",
    "aufgesetzten": "aufgesetzt",
    "aufgesetzter": "aufgesetzt",
    "aufgesetztes": "aufgesetzt",
    "aufgeseufzt": "aufseufzen",
    "aufgeseufzte": "aufgeseufzt",
    "aufgeseufztem": "aufgeseufzt",
    "aufgeseufzten": "aufgeseufzt",
    "aufgeseufzter": "aufgeseufzt",
    "aufgeseufztere": "aufgeseufzt",
    "aufgeseufzterem": "aufgeseufzt",
    "aufgeseufzteren": "aufgeseufzt",
    "aufgeseufzterer": "aufgeseufzt",
    "aufgeseufzteres": "aufgeseufzt",
    "aufgeseufztes": "aufgeseufzt",
    "aufgeseufzteste": "aufgeseufzt",
    "aufgeseufztestem": "aufgeseufzt",
    "aufgeseufztesten": "aufgeseufzt",
    "aufgeseufztester": "aufgeseufzt",
    "aufgeseufztestes": "aufgeseufzt",
    "aufgesogen": "aufsaugen",
    "aufgesogene": "aufgesogen",
    "aufgesogenem": "aufgesogen",
    "aufgesogenen": "aufgesogen",
    "aufgesogener": "aufgesogen",
    "aufgesogenere": "aufgesogen",
    "aufgesogenerem": "aufgesogen",
    "aufgesogeneren": "aufgesogen",
    "aufgesogenerer": "aufgesogen",
    "aufgesogeneres": "aufgesogen",
    "aufgesogenes": "aufgesogen",
    "aufgesogenste": "aufgesogen",
    "aufgesogenstem": "aufgesogen",
    "aufgesogensten": "aufgesogen",
    "aufgesogenster": "aufgesogen",
    "aufgesogenstes": "aufgesogen",
    "aufgespalten": "aufspalten",
    "aufgespaltene": "aufgespalten",
    "aufgespaltenem": "aufgespalten",
    "aufgespaltenen": "aufgespalten",
    "aufgespaltener": "aufgespalten",
    "aufgespaltenere": "aufgespalten",
    "aufgespaltenerem": "aufgespalten",
    "aufgespalteneren": "aufgespalten",
    "aufgespaltenerer": "aufgespalten",
    "aufgespalteneres": "aufgespalten",
    "aufgespaltenes": "aufgespalten",
    "aufgespaltenste": "aufgespalten",
    "aufgespaltenstem": "aufgespalten",
    "aufgespaltensten": "aufgespalten",
    "aufgespaltenster": "aufgespalten",
    "aufgespaltenstes": "aufgespalten",
    "aufgespart": "aufsparen",
    "aufgesparte": "aufgespart",
    "aufgespartem": "aufgespart",
    "aufgesparten": "aufgespart",
    "aufgesparter": "aufgespart",
    "aufgespartere": "aufgespart",
    "aufgesparterem": "aufgespart",
    "aufgesparteren": "aufgespart",
    "aufgesparterer": "aufgespart",
    "aufgesparteres": "aufgespart",
    "aufgespartes": "aufgespart",
    "aufgesparteste": "aufgespart",
    "aufgespartestem": "aufgespart",
    "aufgespartesten": "aufgespart",
    "aufgespartester": "aufgespart",
    "aufgespartestes": "aufgespart",
    "aufgespeichert": "aufspeichern",
    "aufgespeicherte": "aufgespeichert",
    "aufgespeichertem": "aufgespeichert",
    "aufgespeicherten": "aufgespeichert",
    "aufgespeicherter": "aufgespeichert",
    "aufgespeichertes": "aufgespeichert",
    "aufgesperrt": "aufsperren",
    "aufgesperrte": "aufgesperrt",
    "aufgesperrtem": "aufgesperrt",
    "aufgesperrten": "aufgesperrt",
    "aufgesperrter": "aufgesperrt",
    "aufgesperrtes": "aufgesperrt",
    "aufgespielt": "aufspielen",
    "aufgespielte": "aufgespielt",
    "aufgespieltem": "aufgespielt",
    "aufgespielten": "aufgespielt",
    "aufgespielter": "aufgespielt",
    "aufgespieltes": "aufgespielt",
    "aufgespießt": "aufspießen",
    "aufgespießte": "aufgespießt",
    "aufgespießtem": "aufgespießt",
    "aufgespießten": "aufgespießt",
    "aufgespießter": "aufgespießt",
    "aufgespießtes": "aufgespießt",
    "aufgesponnen": "aufspinnen",
    "aufgesponnene": "aufgesponnen",
    "aufgesponnenem": "aufgesponnen",
    "aufgesponnenen": "aufgesponnen",
    "aufgesponnener": "aufgesponnen",
    "aufgesponnenes": "aufgesponnen",
    "aufgesprengt": "aufsprengen",
    "aufgesprengte": "aufgesprengt",
    "aufgesprengtem": "aufgesprengt",
    "aufgesprengten": "aufgesprengt",
    "aufgesprengter": "aufgesprengt",
    "aufgesprengtes": "aufgesprengt",
    "aufgespritzt": "aufspritzen",
    "aufgespritzte": "aufgespritzt",
    "aufgespritztem": "aufgespritzt",
    "aufgespritzten": "aufgespritzt",
    "aufgespritzter": "aufgespritzt",
    "aufgespritztes": "aufgespritzt",
    "aufgesprungen": "aufspringen",
    "aufgesprungene": "aufgesprungen",
    "aufgesprungenem": "aufgesprungen",
    "aufgesprungenen": "aufgesprungen",
    "aufgesprungener": "aufgesprungen",
    "aufgesprungenes": "aufgesprungen",
    "aufgespult": "aufspulen",
    "aufgespulte": "aufgespult",
    "aufgespultem": "aufgespult",
    "aufgespulten": "aufgespult",
    "aufgespulter": "aufgespult",
    "aufgespultes": "aufgespult",
    "aufgespürt": "aufspüren",
    "aufgespürte": "aufgespürt",
    "aufgespürtem": "aufgespürt",
    "aufgespürten": "aufgespürt",
    "aufgespürter": "aufgespürt",
    "aufgespürtes": "aufgespürt",
    "aufgestachelt": "aufstacheln",
    "aufgestachelte": "aufgestachelt",
    "aufgestacheltem": "aufgestachelt",
    "aufgestachelten": "aufgestachelt",
    "aufgestachelter": "aufgestachelt",
    "aufgestacheltes": "aufgestachelt",
    "aufgestampft": "aufstampfen",
    "aufgestampfte": "aufgestampft",
    "aufgestampftem": "aufgestampft",
    "aufgestampften": "aufgestampft",
    "aufgestampfter": "aufgestampft",
    "aufgestampftes": "aufgestampft",
    "aufgestanden": "aufstehen",
    "aufgestandene": "aufgestanden",
    "aufgestandenem": "aufgestanden",
    "aufgestandenen": "aufgestanden",
    "aufgestandener": "aufgestanden",
    "aufgestandenes": "aufgestanden",
    "aufgestapelt": "aufstapeln",
    "aufgestapelte": "aufgestapelt",
    "aufgestapeltem": "aufgestapelt",
    "aufgestapelten": "aufgestapelt",
    "aufgestapelter": "aufgestapelt",
    "aufgestapeltes": "aufgestapelt",
    "aufgestaut": "aufstauen",
    "aufgestaute": "aufgestaut",
    "aufgestautem": "aufgestaut",
    "aufgestauten": "aufgestaut",
    "aufgestauter": "aufgestaut",
    "aufgestautere": "aufgestaut",
    "aufgestauterem": "aufgestaut",
    "aufgestauteren": "aufgestaut",
    "aufgestauterer": "aufgestaut",
    "aufgestauteres": "aufgestaut",
    "aufgestautes": "aufgestaut",
    "aufgestauteste": "aufgestaut",
    "aufgestautestem": "aufgestaut",
    "aufgestautesten": "aufgestaut",
    "aufgestautester": "aufgestaut",
    "aufgestautestes": "aufgestaut",
    "aufgesteckt": "aufstecken",
    "aufgesteckte": "aufgesteckt",
    "aufgestecktem": "aufgesteckt",
    "aufgesteckten": "aufgesteckt",
    "aufgesteckter": "aufgesteckt",
    "aufgestecktes": "aufgesteckt",
    "aufgestellt": "aufstellen",
    "aufgestellte": "aufgestellt",
    "aufgestelltem": "aufgestellt",
    "aufgestellten": "aufgestellt",
    "aufgestellter": "aufgestellt",
    "aufgestelltes": "aufgestellt",
    "aufgestemmt": "aufstemmen",
    "aufgestemmte": "aufgestemmt",
    "aufgestemmtem": "aufgestemmt",
    "aufgestemmten": "aufgestemmt",
    "aufgestemmter": "aufgestemmt",
    "aufgestemmtes": "aufgestemmt",
    "aufgestiegen": "aufsteigen",
    "aufgestiegene": "aufgestiegen",
    "aufgestiegenem": "aufgestiegen",
    "aufgestiegenen": "aufgestiegen",
    "aufgestiegener": "aufgestiegen",
    "aufgestiegenes": "aufgestiegen",
    "aufgestielt": "aufstielen",
    "aufgestielte": "aufgestielt",
    "aufgestieltem": "aufgestielt",
    "aufgestielten": "aufgestielt",
    "aufgestielter": "aufgestielt",
    "aufgestieltes": "aufgestielt",
    "aufgestiftet": "aufstiften",
    "aufgestiftete": "aufgestiftet",
    "aufgestiftetem": "aufgestiftet",
    "aufgestifteten": "aufgestiftet",
    "aufgestifteter": "aufgestiftet",
    "aufgestiftetes": "aufgestiftet",
    "aufgestochen": "aufstechen",
    "aufgestochene": "aufgestochen",
    "aufgestochenem": "aufgestochen",
    "aufgestochenen": "aufgestochen",
    "aufgestochener": "aufgestochen",
    "aufgestochenere": "aufgestochen",
    "aufgestochenerem": "aufgestochen",
    "aufgestocheneren": "aufgestochen",
    "aufgestochenerer": "aufgestochen",
    "aufgestocheneres": "aufgestochen",
    "aufgestochenes": "aufgestochen",
    "aufgestochenste": "aufgestochen",
    "aufgestochenstem": "aufgestochen",
    "aufgestochensten": "aufgestochen",
    "aufgestochenster": "aufgestochen",
    "aufgestochenstes": "aufgestochen",
    "aufgestockt": "aufstocken",
    "aufgestockte": "aufgestockt",
    "aufgestocktem": "aufgestockt",
    "aufgestockten": "aufgestockt",
    "aufgestockter": "aufgestockt",
    "aufgestocktes": "aufgestockt",
    "aufgestoßen": "aufstoßen",
    "aufgestoßene": "aufgestoßen",
    "aufgestoßenem": "aufgestoßen",
    "aufgestoßenen": "aufgestoßen",
    "aufgestoßener": "aufgestoßen",
    "aufgestoßenes": "aufgestoßen",
    "aufgestrebt": "aufstreben",
    "aufgestrebte": "aufgestrebt",
    "aufgestrebtem": "aufgestrebt",
    "aufgestrebten": "aufgestrebt",
    "aufgestrebter": "aufgestrebt",
    "aufgestrebtere": "aufgestrebt",
    "aufgestrebterem": "aufgestrebt",
    "aufgestrebteren": "aufgestrebt",
    "aufgestrebterer": "aufgestrebt",
    "aufgestrebteres": "aufgestrebt",
    "aufgestrebtes": "aufgestrebt",
    "aufgestrebteste": "aufgestrebt",
    "aufgestrebtestem": "aufgestrebt",
    "aufgestrebtesten": "aufgestrebt",
    "aufgestrebtester": "aufgestrebt",
    "aufgestrebtestes": "aufgestrebt",
    "aufgestrichen": "aufstreichen",
    "aufgestrichene": "aufgestrichen",
    "aufgestrichenem": "aufgestrichen",
    "aufgestrichenen": "aufgestrichen",
    "aufgestrichener": "aufgestrichen",
    "aufgestrichenes": "aufgestrichen",
    "aufgestöbert": "aufstöbern",
    "aufgestöberte": "aufgestöbert",
    "aufgestöbertem": "aufgestöbert",
    "aufgestöberten": "aufgestöbert",
    "aufgestöberter": "aufgestöbert",
    "aufgestöbertes": "aufgestöbert",
    "aufgestülpt": "aufstülpen",
    "aufgestülpte": "aufgestülpt",
    "aufgestülptem": "aufgestülpt",
    "aufgestülpten": "aufgestülpt",
    "aufgestülpter": "aufgestülpt",
    "aufgestülptes": "aufgestülpt",
    "aufgestützt": "aufstützen",
    "aufgestützte": "aufgestützt",
    "aufgestütztem": "aufgestützt",
    "aufgestützten": "aufgestützt",
    "aufgestützter": "aufgestützt",
    "aufgestütztes": "aufgestützt",
    "aufgesucht": "aufsuchen",
    "aufgesuchte": "aufgesucht",
    "aufgesuchtem": "aufgesucht",
    "aufgesuchten": "aufgesucht",
    "aufgesuchter": "aufgesucht",
    "aufgesuchtes": "aufgesucht",
    "aufgetakelt": "auftakeln",
    "aufgetakelte": "aufgetakelt",
    "aufgetakeltem": "aufgetakelt",
    "aufgetakelten": "aufgetakelt",
    "aufgetakelter": "aufgetakelt",
    "aufgetakeltere": "aufgetakelt",
    "aufgetakelterem": "aufgetakelt",
    "aufgetakelteren": "aufgetakelt",
    "aufgetakelterer": "aufgetakelt",
    "aufgetakelteres": "aufgetakelt",
    "aufgetakeltes": "aufgetakelt",
    "aufgetakelteste": "aufgetakelt",
    "aufgetakeltestem": "aufgetakelt",
    "aufgetakeltesten": "aufgetakelt",
    "aufgetakeltester": "aufgetakelt",
    "aufgetakeltestes": "aufgetakelt",
    "aufgetankt": "auftanken",
    "aufgetankte": "aufgetankt",
    "aufgetanktem": "aufgetankt",
    "aufgetankten": "aufgetankt",
    "aufgetankter": "aufgetankt",
    "aufgetanktes": "aufgetankt",
    "aufgetaucht": "auftauchen",
    "aufgetauchte": "aufgetaucht",
    "aufgetauchtem": "aufgetaucht",
    "aufgetauchten": "aufgetaucht",
    "aufgetauchter": "aufgetaucht",
    "aufgetauchtes": "aufgetaucht",
    "aufgetaut": "auftauen",
    "aufgetaute": "aufgetaut",
    "aufgetautem": "aufgetaut",
    "aufgetauten": "aufgetaut",
    "aufgetauter": "aufgetaut",
    "aufgetautes": "aufgetaut",
    "aufgeteilt": "aufteilen",
    "aufgeteilte": "aufgeteilt",
    "aufgeteiltem": "aufgeteilt",
    "aufgeteilten": "aufgeteilt",
    "aufgeteilter": "aufgeteilt",
    "aufgeteiltes": "aufgeteilt",
    "aufgetischt": "auftischen",
    "aufgetischte": "aufgetischt",
    "aufgetischtem": "aufgetischt",
    "aufgetischten": "aufgetischt",
    "aufgetischter": "aufgetischt",
    "aufgetischtes": "aufgetischt",
    "aufgetragen": "auftragen",
    "aufgetragene": "aufgetragen",
    "aufgetragenem": "aufgetragen",
    "aufgetragenen": "aufgetragen",
    "aufgetragener": "aufgetragen",
    "aufgetragenere": "aufgetragen",
    "aufgetragenerem": "aufgetragen",
    "aufgetrageneren": "aufgetragen",
    "aufgetragenerer": "aufgetragen",
    "aufgetrageneres": "aufgetragen",
    "aufgetragenes": "aufgetragen",
    "aufgetragenste": "aufgetragen",
    "aufgetragenstem": "aufgetragen",
    "aufgetragensten": "aufgetragen",
    "aufgetragenster": "aufgetragen",
    "aufgetragenstes": "aufgetragen",
    "aufgetrennt": "auftrennen",
    "aufgetrennte": "aufgetrennt",
    "aufgetrenntem": "aufgetrennt",
    "aufgetrennten": "aufgetrennt",
    "aufgetrennter": "aufgetrennt",
    "aufgetrenntes": "aufgetrennt",
    "aufgetreten": "auftreten",
    "aufgetretene": "aufgetreten",
    "aufgetretenem": "aufgetreten",
    "aufgetretenen": "aufgetreten",
    "aufgetretener": "aufgetreten",
    "aufgetretenes": "aufgetreten",
    "aufgetrieben": "auftreiben",
    "aufgetriebene": "aufgetrieben",
    "aufgetriebenem": "aufgetrieben",
    "aufgetriebenen": "aufgetrieben",
    "aufgetriebener": "aufgetrieben",
    "aufgetriebenes": "aufgetrieben",
    "aufgetroffen": "auftreffen",
    "aufgetroffene": "aufgetroffen",
    "aufgetroffenem": "aufgetroffen",
    "aufgetroffenen": "aufgetroffen",
    "aufgetroffener": "aufgetroffen",
    "aufgetroffenes": "aufgetroffen",
    "aufgetrumpft": "auftrumpfen",
    "aufgetrumpfte": "aufgetrumpft",
    "aufgetrumpftem": "aufgetrumpft",
    "aufgetrumpften": "aufgetrumpft",
    "aufgetrumpfter": "aufgetrumpft",
    "aufgetrumpftes": "aufgetrumpft",
    "aufgetürmt": "auftürmen",
    "aufgetürmte": "aufgetürmt",
    "aufgetürmtem": "aufgetürmt",
    "aufgetürmten": "aufgetürmt",
    "aufgetürmter": "aufgetürmt",
    "aufgetürmtes": "aufgetürmt",
    "aufgewachsen": "aufwachsen",
    "aufgewachsene": "aufgewachsen",
    "aufgewachsenem": "aufgewachsen",
    "aufgewachsenen": "aufgewachsen",
    "aufgewachsener": "aufgewachsen",
    "aufgewachsenes": "aufgewachsen",
    "aufgewachst": "aufwachsen",
    "aufgewachste": "aufgewachst",
    "aufgewachstem": "aufgewachst",
    "aufgewachsten": "aufgewachst",
    "aufgewachster": "aufgewachst",
    "aufgewachstes": "aufgewachst",
    "aufgewacht": "aufwachen",
    "aufgewachte": "aufgewacht",
    "aufgewachtem": "aufgewacht",
    "aufgewachten": "aufgewacht",
    "aufgewachter": "aufgewacht",
    "aufgewachtes": "aufgewacht",
    "aufgewallt": "aufwallen",
    "aufgewallte": "aufgewallt",
    "aufgewalltem": "aufgewallt",
    "aufgewallten": "aufgewallt",
    "aufgewallter": "aufgewallt",
    "aufgewalltere": "aufgewallt",
    "aufgewallterem": "aufgewallt",
    "aufgewallteren": "aufgewallt",
    "aufgewallterer": "aufgewallt",
    "aufgewallteres": "aufgewallt",
    "aufgewalltes": "aufgewallt",
    "aufgewallteste": "aufgewallt",
    "aufgewalltestem": "aufgewallt",
    "aufgewalltesten": "aufgewallt",
    "aufgewalltester": "aufgewallt",
    "aufgewalltestes": "aufgewallt",
    "aufgewalzt": "aufwalzen",
    "aufgewalzte": "aufgewalzt",
    "aufgewalztem": "aufgewalzt",
    "aufgewalzten": "aufgewalzt",
    "aufgewalzter": "aufgewalzt",
    "aufgewalztes": "aufgewalzt",
    "aufgewandt": "aufwenden",
    "aufgewartet": "aufwarten",
    "aufgewartete": "aufgewartet",
    "aufgewartetem": "aufgewartet",
    "aufgewarteten": "aufgewartet",
    "aufgewarteter": "aufgewartet",
    "aufgewartetes": "aufgewartet",
    "aufgewaschen": "aufwaschen",
    "aufgewaschene": "aufgewaschen",
    "aufgewaschenem": "aufgewaschen",
    "aufgewaschenen": "aufgewaschen",
    "aufgewaschener": "aufgewaschen",
    "aufgewaschenes": "aufgewaschen",
    "aufgeweckt": "aufwecken",
    "aufgeweckte": "aufgeweckt",
    "aufgewecktem": "aufgeweckt",
    "aufgeweckten": "aufgeweckt",
    "aufgeweckter": "aufgeweckt",
    "aufgewecktere": "aufgeweckt",
    "aufgeweckterem": "aufgeweckt",
    "aufgeweckteren": "aufgeweckt",
    "aufgeweckterer": "aufgeweckt",
    "aufgeweckteres": "aufgeweckt",
    "aufgewecktes": "aufgeweckt",
    "aufgeweckteste": "aufgeweckt",
    "aufgewecktestem": "aufgeweckt",
    "aufgewecktesten": "aufgeweckt",
    "aufgewecktester": "aufgeweckt",
    "aufgewecktestes": "aufgeweckt",
    "aufgeweicht": "aufweichen",
    "aufgeweichte": "aufgeweicht",
    "aufgeweichtem": "aufgeweicht",
    "aufgeweichten": "aufgeweicht",
    "aufgeweichter": "aufgeweicht",
    "aufgeweichtere": "aufgeweicht",
    "aufgeweichterem": "aufgeweicht",
    "aufgeweichteren": "aufgeweicht",
    "aufgeweichterer": "aufgeweicht",
    "aufgeweichteres": "aufgeweicht",
    "aufgeweichtes": "aufgeweicht",
    "aufgeweichteste": "aufgeweicht",
    "aufgeweichtestem": "aufgeweicht",
    "aufgeweichtesten": "aufgeweicht",
    "aufgeweichtester": "aufgeweicht",
    "aufgeweichtestes": "aufgeweicht",
    "aufgewendet": "aufwenden",
    "aufgewendete": "aufgewendet",
    "aufgewendetem": "aufgewendet",
    "aufgewendeten": "aufgewendet",
    "aufgewendeter": "aufgewendet",
    "aufgewendetes": "aufgewendet",
    "aufgewertet": "aufwerten",
    "aufgewertete": "aufgewertet",
    "aufgewertetem": "aufgewertet",
    "aufgewerteten": "aufgewertet",
    "aufgewerteter": "aufgewertet",
    "aufgewertetes": "aufgewertet",
    "aufgewichen": "aufweichen",
    "aufgewichene": "aufgewichen",
    "aufgewichenem": "aufgewichen",
    "aufgewichenen": "aufgewichen",
    "aufgewichener": "aufgewichen",
    "aufgewichenere": "aufgewichen",
    "aufgewichenerem": "aufgewichen",
    "aufgewicheneren": "aufgewichen",
    "aufgewichenerer": "aufgewichen",
    "aufgewicheneres": "aufgewichen",
    "aufgewichenes": "aufgewichen",
    "aufgewichenste": "aufgewichen",
    "aufgewichenstem": "aufgewichen",
    "aufgewichensten": "aufgewichen",
    "aufgewichenster": "aufgewichen",
    "aufgewichenstes": "aufgewichen",
    "aufgewiegelt": "aufwiegeln",
    "aufgewiegelte": "aufgewiegelt",
    "aufgewiegeltem": "aufgewiegelt",
    "aufgewiegelten": "aufgewiegelt",
    "aufgewiegelter": "aufgewiegelt",
    "aufgewiegeltere": "aufgewiegelt",
    "aufgewiegelterem": "aufgewiegelt",
    "aufgewiegelteren": "aufgewiegelt",
    "aufgewiegelterer": "aufgewiegelt",
    "aufgewiegelteres": "aufgewiegelt",
    "aufgewiegeltes": "aufgewiegelt",
    "aufgewiegelteste": "aufgewiegelt",
    "aufgewiegeltestem": "aufgewiegelt",
    "aufgewiegeltesten": "aufgewiegelt",
    "aufgewiegeltester": "aufgewiegelt",
    "aufgewiegeltestes": "aufgewiegelt",
    "aufgewiesen": "aufweisen",
    "aufgewiesene": "aufgewiesen",
    "aufgewiesenem": "aufgewiesen",
    "aufgewiesenen": "aufgewiesen",
    "aufgewiesener": "aufgewiesen",
    "aufgewiesenes": "aufgewiesen",
    "aufgewirbelt": "aufwirbeln",
    "aufgewirbelte": "aufgewirbelt",
    "aufgewirbeltem": "aufgewirbelt",
    "aufgewirbelten": "aufgewirbelt",
    "aufgewirbelter": "aufgewirbelt",
    "aufgewirbeltere": "aufgewirbelt",
    "aufgewirbelterem": "aufgewirbelt",
    "aufgewirbelteren": "aufgewirbelt",
    "aufgewirbelterer": "aufgewirbelt",
    "aufgewirbelteres": "aufgewirbelt",
    "aufgewirbeltes": "aufgewirbelt",
    "aufgewirbelteste": "aufgewirbelt",
    "aufgewirbeltestem": "aufgewirbelt",
    "aufgewirbeltesten": "aufgewirbelt",
    "aufgewirbeltester": "aufgewirbelt",
    "aufgewirbeltestes": "aufgewirbelt",
    "aufgewischt": "aufwischen",
    "aufgewischte": "aufgewischt",
    "aufgewischtem": "aufgewischt",
    "aufgewischten": "aufgewischt",
    "aufgewischter": "aufgewischt",
    "aufgewischtes": "aufgewischt",
    "aufgewogen": "aufwiegen",
    "aufgewogene": "aufgewogen",
    "aufgewogenem": "aufgewogen",
    "aufgewogenen": "aufgewogen",
    "aufgewogener": "aufgewogen",
    "aufgewogenes": "aufgewogen",
    "aufgeworfen": "aufwerfen",
    "aufgeworfene": "aufgeworfen",
    "aufgeworfenem": "aufgeworfen",
    "aufgeworfenen": "aufgeworfen",
    "aufgeworfener": "aufgeworfen",
    "aufgeworfenes": "aufgeworfen",
    "aufgewunden": "aufwinden",
    "aufgewundene": "aufgewunden",
    "aufgewundenem": "aufgewunden",
    "aufgewundenen": "aufgewunden",
    "aufgewundener": "aufgewunden",
    "aufgewundenes": "aufgewunden",
    "aufgewärmt": "aufwärmen",
    "aufgewärmte": "aufgewärmt",
    "aufgewärmtem": "aufgewärmt",
    "aufgewärmten": "aufgewärmt",
    "aufgewärmter": "aufgewärmt",
    "aufgewärmtere": "aufgewärmt",
    "aufgewärmterem": "aufgewärmt",
    "aufgewärmteren": "aufgewärmt",
    "aufgewärmterer": "aufgewärmt",
    "aufgewärmteres": "aufgewärmt",
    "aufgewärmtes": "aufgewärmt",
    "aufgewärmteste": "aufgewärmt",
    "aufgewärmtestem": "aufgewärmt",
    "aufgewärmtesten": "aufgewärmt",
    "aufgewärmtester": "aufgewärmt",
    "aufgewärmtestes": "aufgewärmt",
    "aufgewühlt": "aufwühlen",
    "aufgewühlte": "aufgewühlt",
    "aufgewühltem": "aufgewühlt",
    "aufgewühlten": "aufgewühlt",
    "aufgewühlter": "aufgewühlt",
    "aufgewühltere": "aufgewühlt",
    "aufgewühlterem": "aufgewühlt",
    "aufgewühlteren": "aufgewühlt",
    "aufgewühlterer": "aufgewühlt",
    "aufgewühlteres": "aufgewühlt",
    "aufgewühltes": "aufgewühlt",
    "aufgewühlteste": "aufgewühlt",
    "aufgewühltestem": "aufgewühlt",
    "aufgewühltesten": "aufgewühlt",
    "aufgewühltester": "aufgewühlt",
    "aufgewühltestes": "aufgewühlt",
    "aufgezehrt": "aufzehren",
    "aufgezehrte": "aufgezehrt",
    "aufgezehrtem": "aufgezehrt",
    "aufgezehrten": "aufgezehrt",
    "aufgezehrter": "aufgezehrt",
    "aufgezehrtere": "aufgezehrt",
    "aufgezehrterem": "aufgezehrt",
    "aufgezehrteren": "aufgezehrt",
    "aufgezehrterer": "aufgezehrt",
    "aufgezehrteres": "aufgezehrt",
    "aufgezehrtes": "aufgezehrt",
    "aufgezehrteste": "aufgezehrt",
    "aufgezehrtestem": "aufgezehrt",
    "aufgezehrtesten": "aufgezehrt",
    "aufgezehrtester": "aufgezehrt",
    "aufgezehrtestes": "aufgezehrt",
    "aufgezeichnet": "aufzeichnen",
    "aufgezeichnete": "aufgezeichnet",
    "aufgezeichnetem": "aufgezeichnet",
    "aufgezeichneten": "aufgezeichnet",
    "aufgezeichneter": "aufgezeichnet",
    "aufgezeichnetes": "aufgezeichnet",
    "aufgezeigt": "aufzeigen",
    "aufgezeigte": "aufgezeigt",
    "aufgezeigtem": "aufgezeigt",
    "aufgezeigten": "aufgezeigt",
    "aufgezeigter": "aufgezeigt",
    "aufgezeigtes": "aufgezeigt",
    "aufgezogen": "aufziehen",
    "aufgezogene": "aufgezogen",
    "aufgezogenem": "aufgezogen",
    "aufgezogenen": "aufgezogen",
    "aufgezogener": "aufgezogen",
    "aufgezogenes": "aufgezogen",
    "aufgezwirbelt": "aufzwirbeln",
    "aufgezwirbelte": "aufgezwirbelt",
    "aufgezwirbeltem": "aufgezwirbelt",
    "aufgezwirbelten": "aufgezwirbelt",
    "aufgezwirbelter": "aufgezwirbelt",
    "aufgezwirbeltere": "aufgezwirbelt",
    "aufgezwirbelterem": "aufgezwirbelt",
    "aufgezwirbelteren": "aufgezwirbelt",
    "aufgezwirbelterer": "aufgezwirbelt",
    "aufgezwirbelteres": "aufgezwirbelt",
    "aufgezwirbeltes": "aufgezwirbelt",
    "aufgezwirbelteste": "aufgezwirbelt",
    "aufgezwirbeltestem": "aufgezwirbelt",
    "aufgezwirbeltesten": "aufgezwirbelt",
    "aufgezwirbeltester": "aufgezwirbelt",
    "aufgezwirbeltestes": "aufgezwirbelt",
    "aufgezwungen": "aufzwingen",
    "aufgezwungene": "aufgezwungen",
    "aufgezwungenem": "aufgezwungen",
    "aufgezwungenen": "aufgezwungen",
    "aufgezwungener": "aufgezwungen",
    "aufgezwungenes": "aufgezwungen",
    "aufgezählt": "aufzählen",
    "aufgezählte": "aufgezählt",
    "aufgezähltem": "aufgezählt",
    "aufgezählten": "aufgezählt",
    "aufgezählter": "aufgezählt",
    "aufgezähltes": "aufgezählt",
    "aufgezäumt": "aufzäumen",
    "aufgezäumte": "aufgezäumt",
    "aufgezäumtem": "aufgezäumt",
    "aufgezäumten": "aufgezäumt",
    "aufgezäumter": "aufgezäumt",
    "aufgezäumtere": "aufgezäumt",
    "aufgezäumterem": "aufgezäumt",
    "aufgezäumteren": "aufgezäumt",
    "aufgezäumterer": "aufgezäumt",
    "aufgezäumteres": "aufgezäumt",
    "aufgezäumtes": "aufgezäumt",
    "aufgezäumteste": "aufgezäumt",
    "aufgezäumtestem": "aufgezäumt",
    "aufgezäumtesten": "aufgezäumt",
    "aufgezäumtester": "aufgezäumt",
    "aufgezäumtestes": "aufgezäumt",
    "aufgibst": "aufgeben",
    "aufgibt": "aufgeben",
    "aufgieße": "aufgießen",
    "aufgießend": "aufgießen",
    "aufgießende": "aufgießend",
    "aufgießendem": "aufgießend",
    "aufgießenden": "aufgießend",
    "aufgießender": "aufgießend",
    "aufgießendes": "aufgießend",
    "aufgießest": "aufgießen",
    "aufgießet": "aufgießen",
    "aufgießt": "aufgießen",
    "aufging": "aufgehen",
    "aufginge": "aufgehen",
    "aufgingen": "aufgehen",
    "aufgingest": "aufgehen",
    "aufginget": "aufgehen",
    "aufgingst": "aufgehen",
    "aufgingt": "aufgehen",
    "aufgleise": "aufgleisen",
    "aufgleisend": "aufgleisen",
    "aufgleisende": "aufgleisend",
    "aufgleisendem": "aufgleisend",
    "aufgleisenden": "aufgleisend",
    "aufgleisender": "aufgleisend",
    "aufgleisendes": "aufgleisend",
    "aufgleisest": "aufgleisen",
    "aufgleiset": "aufgleisen",
    "aufgleist": "aufgleisen",
    "aufgleiste": "aufgleisen",
    "aufgleisten": "aufgleisen",
    "aufgleistest": "aufgleisen",
    "aufgleistet": "aufgleisen",
    "aufgliedere": "aufgliedern",
    "aufgliedernd": "aufgliedern",
    "aufgliedernde": "aufgliedernd",
    "aufgliederndem": "aufgliedernd",
    "aufgliedernden": "aufgliedernd",
    "aufgliedernder": "aufgliedernd",
    "aufgliederndes": "aufgliedernd",
    "aufgliederst": "aufgliedern",
    "aufgliedert": "aufgliedern",
    "aufgliederte": "aufgliedern",
    "aufgliederten": "aufgliedern",
    "aufgliedertest": "aufgliedern",
    "aufgliedertet": "aufgliedern",
    "aufglimme": "aufglimmen",
    "aufglimmend": "aufglimmen",
    "aufglimmende": "aufglimmend",
    "aufglimmendem": "aufglimmend",
    "aufglimmenden": "aufglimmend",
    "aufglimmender": "aufglimmend",
    "aufglimmendere": "aufglimmend",
    "aufglimmenderem": "aufglimmend",
    "aufglimmenderen": "aufglimmend",
    "aufglimmenderer": "aufglimmend",
    "aufglimmenderes": "aufglimmend",
    "aufglimmendes": "aufglimmend",
    "aufglimmendste": "aufglimmend",
    "aufglimmendstem": "aufglimmend",
    "aufglimmendsten": "aufglimmend",
    "aufglimmendster": "aufglimmend",
    "aufglimmendstes": "aufglimmend",
    "aufglimmest": "aufglimmen",
    "aufglimmet": "aufglimmen",
    "aufglimmst": "aufglimmen",
    "aufglimmt": "aufglimmen",
    "aufglomm": "aufglimmen",
    "aufglommen": "aufglimmen",
    "aufglommst": "aufglimmen",
    "aufglommt": "aufglimmen",
    "aufglömme": "aufglimmen",
    "aufglömmen": "aufglimmen",
    "aufglömmest": "aufglimmen",
    "aufglömmet": "aufglimmen",
    "aufglühe": "aufglühen",
    "aufglühend": "aufglühen",
    "aufglühende": "aufglühend",
    "aufglühendem": "aufglühend",
    "aufglühenden": "aufglühend",
    "aufglühender": "aufglühend",
    "aufglühendere": "aufglühend",
    "aufglühenderem": "aufglühend",
    "aufglühenderen": "aufglühend",
    "aufglühenderer": "aufglühend",
    "aufglühenderes": "aufglühend",
    "aufglühendes": "aufglühend",
    "aufglühendste": "aufglühend",
    "aufglühendstem": "aufglühend",
    "aufglühendsten": "aufglühend",
    "aufglühendster": "aufglühend",
    "aufglühendstes": "aufglühend",
    "aufglühest": "aufglühen",
    "aufglühet": "aufglühen",
    "aufglühst": "aufglühen",
    "aufglüht": "aufglühen",
    "aufglühte": "aufglühen",
    "aufglühten": "aufglühen",
    "aufglühtest": "aufglühen",
    "aufglühtet": "aufglühen",
    "aufgossen": "aufgießen",
    "aufgoß": "aufgießen",
    "aufgoßt": "aufgießen",
    "aufgreife": "aufgreifen",
    "aufgreifend": "aufgreifen",
    "aufgreifende": "aufgreifend",
    "aufgreifendem": "aufgreifend",
    "aufgreifenden": "aufgreifend",
    "aufgreifender": "aufgreifend",
    "aufgreifendes": "aufgreifend",
    "aufgreifest": "aufgreifen",
    "aufgreifet": "aufgreifen",
    "aufgreifst": "aufgreifen",
    "aufgreift": "aufgreifen",
    "aufgriff": "aufgreifen",
    "aufgriffe": "aufgreifen",
    "aufgriffen": "aufgreifen",
    "aufgriffest": "aufgreifen",
    "aufgriffet": "aufgreifen",
    "aufgriffst": "aufgreifen",
    "aufgrifft": "aufgreifen",
    "aufgäbe": "aufgeben",
    "aufgäben": "aufgeben",
    "aufgäbest": "aufgeben",
    "aufgäbet": "aufgeben",
    "aufgösse": "aufgießen",
    "aufgössen": "aufgießen",
    "aufgössest": "aufgießen",
    "aufgösset": "aufgießen",
    "aufhake": "aufhaken",
    "aufhakend": "aufhaken",
    "aufhakende": "aufhakend",
    "aufhakendem": "aufhakend",
    "aufhakenden": "aufhakend",
    "aufhakender": "aufhakend",
    "aufhakendes": "aufhakend",
    "aufhakest": "aufhaken",
    "aufhaket": "aufhaken",
    "aufhakst": "aufhaken",
    "aufhakt": "aufhaken",
    "aufhakte": "aufhaken",
    "aufhakten": "aufhaken",
    "aufhaktest": "aufhaken",
    "aufhaktet": "aufhaken",
    "aufhalse": "aufhalsen",
    "aufhalsend": "aufhalsen",
    "aufhalsende": "aufhalsend",
    "aufhalsendem": "aufhalsend",
    "aufhalsenden": "aufhalsend",
    "aufhalsender": "aufhalsend",
    "aufhalsendes": "aufhalsend",
    "aufhalsest": "aufhalsen",
    "aufhalset": "aufhalsen",
    "aufhalst": "aufhalsen",
    "aufhalste": "aufhalsen",
    "aufhalsten": "aufhalsen",
    "aufhalstest": "aufhalsen",
    "aufhalstet": "aufhalsen",
    "aufhalte": "aufhalten",
    "aufhaltend": "aufhalten",
    "aufhaltende": "aufhaltend",
    "aufhaltendem": "aufhaltend",
    "aufhaltenden": "aufhaltend",
    "aufhaltender": "aufhaltend",
    "aufhaltendere": "aufhaltend",
    "aufhaltenderem": "aufhaltend",
    "aufhaltenderen": "aufhaltend",
    "aufhaltenderer": "aufhaltend",
    "aufhaltenderes": "aufhaltend",
    "aufhaltendes": "aufhaltend",
    "aufhaltendste": "aufhaltend",
    "aufhaltendstem": "aufhaltend",
    "aufhaltendsten": "aufhaltend",
    "aufhaltendster": "aufhaltend",
    "aufhaltendstes": "aufhaltend",
    "aufhaltest": "aufhalten",
    "aufhaltet": "aufhalten",
    "aufhaue": "aufhauen",
    "aufhauend": "aufhauen",
    "aufhauende": "aufhauend",
    "aufhauendem": "aufhauend",
    "aufhauenden": "aufhauend",
    "aufhauender": "aufhauend",
    "aufhauendes": "aufhauend",
    "aufhauest": "aufhauen",
    "aufhauet": "aufhauen",
    "aufhaust": "aufhauen",
    "aufhaut": "aufhauen",
    "aufhaute": "aufhauen",
    "aufhauten": "aufhauen",
    "aufhautest": "aufhauen",
    "aufhautet": "aufhauen",
    "aufhebe": "aufheben",
    "aufhebend": "aufheben",
    "aufhebende": "aufhebend",
    "aufhebendem": "aufhebend",
    "aufhebenden": "aufhebend",
    "aufhebender": "aufhebend",
    "aufhebendes": "aufhebend",
    "aufhebest": "aufheben",
    "aufhebet": "aufheben",
    "aufhebst": "aufheben",
    "aufhebt": "aufheben",
    "aufheitere": "aufheitern",
    "aufheiternd": "aufheitern",
    "aufheiternde": "aufheiternd",
    "aufheiterndem": "aufheiternd",
    "aufheiternden": "aufheiternd",
    "aufheiternder": "aufheiternd",
    "aufheiterndere": "aufheiternd",
    "aufheiternderem": "aufheiternd",
    "aufheiternderen": "aufheiternd",
    "aufheiternderer": "aufheiternd",
    "aufheiternderes": "aufheiternd",
    "aufheiterndes": "aufheiternd",
    "aufheiterndste": "aufheiternd",
    "aufheiterndstem": "aufheiternd",
    "aufheiterndsten": "aufheiternd",
    "aufheiterndster": "aufheiternd",
    "aufheiterndstes": "aufheiternd",
    "aufheiterst": "aufheitern",
    "aufheitert": "aufheitern",
    "aufheiterte": "aufheitern",
    "aufheiterten": "aufheitern",
    "aufheitertest": "aufheitern",
    "aufheitertet": "aufheitern",
    "aufhelle": "aufhellen",
    "aufhellend": "aufhellen",
    "aufhellende": "aufhellend",
    "aufhellendem": "aufhellend",
    "aufhellenden": "aufhellend",
    "aufhellender": "aufhellend",
    "aufhellendere": "aufhellend",
    "aufhellenderem": "aufhellend",
    "aufhellenderen": "aufhellend",
    "aufhellenderer": "aufhellend",
    "aufhellenderes": "aufhellend",
    "aufhellendes": "aufhellend",
    "aufhellendste": "aufhellend",
    "aufhellendstem": "aufhellend",
    "aufhellendsten": "aufhellend",
    "aufhellendster": "aufhellend",
    "aufhellendstes": "aufhellend",
    "aufhellest": "aufhellen",
    "aufhellet": "aufhellen",
    "aufhellst": "aufhellen",
    "aufhellt": "aufhellen",
    "aufhellte": "aufhellen",
    "aufhellten": "aufhellen",
    "aufhelltest": "aufhellen",
    "aufhelltet": "aufhellen",
    "aufhetze": "aufhetzen",
    "aufhetzend": "aufhetzen",
    "aufhetzende": "aufhetzend",
    "aufhetzendem": "aufhetzend",
    "aufhetzenden": "aufhetzend",
    "aufhetzender": "aufhetzend",
    "aufhetzendere": "aufhetzend",
    "aufhetzenderem": "aufhetzend",
    "aufhetzenderen": "aufhetzend",
    "aufhetzenderer": "aufhetzend",
    "aufhetzenderes": "aufhetzend",
    "aufhetzendes": "aufhetzend",
    "aufhetzendste": "aufhetzend",
    "aufhetzendstem": "aufhetzend",
    "aufhetzendsten": "aufhetzend",
    "aufhetzendster": "aufhetzend",
    "aufhetzendstes": "aufhetzend",
    "aufhetzest": "aufhetzen",
    "aufhetzet": "aufhetzen",
    "aufhetzt": "aufhetzen",
    "aufhetzte": "aufhetzen",
    "aufhetzten": "aufhetzen",
    "aufhetztest": "aufhetzen",
    "aufhetztet": "aufhetzen",
    "aufhielt": "aufhalten",
    "aufhielte": "aufhalten",
    "aufhielten": "aufhalten",
    "aufhieltest": "aufhalten",
    "aufhieltet": "aufhalten",
    "aufhing": "aufhängen",
    "aufhinge": "aufhängen",
    "aufhingen": "aufhängen",
    "aufhingest": "aufhängen",
    "aufhinget": "aufhängen",
    "aufhingst": "aufhängen",
    "aufhingt": "aufhängen",
    "aufhob": "aufheben",
    "aufhoben": "aufheben",
    "aufhobst": "aufheben",
    "aufhobt": "aufheben",
    "aufhole": "aufholen",
    "aufholend": "aufholen",
    "aufholende": "aufholend",
    "aufholendem": "aufholend",
    "aufholenden": "aufholend",
    "aufholender": "aufholend",
    "aufholendere": "aufholend",
    "aufholenderem": "aufholend",
    "aufholenderen": "aufholend",
    "aufholenderer": "aufholend",
    "aufholenderes": "aufholend",
    "aufholendes": "aufholend",
    "aufholendste": "aufholend",
    "aufholendstem": "aufholend",
    "aufholendsten": "aufholend",
    "aufholendster": "aufholend",
    "aufholendstes": "aufholend",
    "aufholest": "aufholen",
    "aufholet": "aufholen",
    "aufholst": "aufholen",
    "aufholt": "aufholen",
    "aufholte": "aufholen",
    "aufholten": "aufholen",
    "aufholtest": "aufholen",
    "aufholtet": "aufholen",
    "aufhorche": "aufhorchen",
    "aufhorchend": "aufhorchen",
    "aufhorchende": "aufhorchend",
    "aufhorchendem": "aufhorchend",
    "aufhorchenden": "aufhorchend",
    "aufhorchender": "aufhorchend",
    "aufhorchendere": "aufhorchend",
    "aufhorchenderem": "aufhorchend",
    "aufhorchenderen": "aufhorchend",
    "aufhorchenderer": "aufhorchend",
    "aufhorchenderes": "aufhorchend",
    "aufhorchendes": "aufhorchend",
    "aufhorchendste": "aufhorchend",
    "aufhorchendstem": "aufhorchend",
    "aufhorchendsten": "aufhorchend",
    "aufhorchendster": "aufhorchend",
    "aufhorchendstes": "aufhorchend",
    "aufhorchest": "aufhorchen",
    "aufhorchet": "aufhorchen",
    "aufhorchst": "aufhorchen",
    "aufhorcht": "aufhorchen",
    "aufhorchte": "aufhorchen",
    "aufhorchten": "aufhorchen",
    "aufhorchtest": "aufhorchen",
    "aufhorchtet": "aufhorchen",
    "aufhält": "aufhalten",
    "aufhältst": "aufhalten",
    "aufhänge": "aufhängen",
    "aufhängend": "aufhängen",
    "aufhängende": "aufhängend",
    "aufhängendem": "aufhängend",
    "aufhängenden": "aufhängend",
    "aufhängender": "aufhängend",
    "aufhängendes": "aufhängend",
    "aufhängest": "aufhängen",
    "aufhänget": "aufhängen",
    "aufhängst": "aufhängen",
    "aufhängt": "aufhängen",
    "aufhängte": "aufhängen",
    "aufhängten": "aufhängen",
    "aufhängtest": "aufhängen",
    "aufhängtet": "aufhängen",
    "aufhärte": "aufhärten",
    "aufhärtend": "aufhärten",
    "aufhärtende": "aufhärtend",
    "aufhärtendem": "aufhärtend",
    "aufhärtenden": "aufhärtend",
    "aufhärtender": "aufhärtend",
    "aufhärtendes": "aufhärtend",
    "aufhärtest": "aufhärten",
    "aufhärtet": "aufhärten",
    "aufhärtete": "aufhärten",
    "aufhärteten": "aufhärten",
    "aufhärtetest": "aufhärten",
    "aufhärtetet": "aufhärten",
    "aufhöbe": "aufheben",
    "aufhöben": "aufheben",
    "aufhöbest": "aufheben",
    "aufhöbet": "aufheben",
    "aufhöre": "aufhören",
    "aufhörend": "aufhören",
    "aufhörende": "aufhörend",
    "aufhörendem": "aufhörend",
    "aufhörenden": "aufhörend",
    "aufhörender": "aufhörend",
    "aufhörendes": "aufhörend",
    "aufhörest": "aufhören",
    "aufhöret": "aufhören",
    "aufhörst": "aufhören",
    "aufhört": "aufhören",
    "aufhörte": "aufhören",
    "aufhörten": "aufhören",
    "aufhörtest": "aufhören",
    "aufhörtet": "aufhören",
    "aufißt": "aufessen",
    "aufjage": "aufjagen",
    "aufjagend": "aufjagen",
    "aufjagende": "aufjagend",
    "aufjagendem": "aufjagend",
    "aufjagenden": "aufjagend",
    "aufjagender": "aufjagend",
    "aufjagendes": "aufjagend",
    "aufjagest": "aufjagen",
    "aufjaget": "aufjagen",
    "aufjagst": "aufjagen",
    "aufjagt": "aufjagen",
    "aufjagte": "aufjagen",
    "aufjagten": "aufjagen",
    "aufjagtest": "aufjagen",
    "aufjagtet": "aufjagen",
    "aufjauchze": "aufjauchzen",
    "aufjauchzend": "aufjauchzen",
    "aufjauchzende": "aufjauchzend",
    "aufjauchzendem": "aufjauchzend",
    "aufjauchzenden": "aufjauchzend",
    "aufjauchzender": "aufjauchzend",
    "aufjauchzendere": "aufjauchzend",
    "aufjauchzenderem": "aufjauchzend",
    "aufjauchzenderen": "aufjauchzend",
    "aufjauchzenderer": "aufjauchzend",
    "aufjauchzenderes": "aufjauchzend",
    "aufjauchzendes": "aufjauchzend",
    "aufjauchzendste": "aufjauchzend",
    "aufjauchzendstem": "aufjauchzend",
    "aufjauchzendsten": "aufjauchzend",
    "aufjauchzendster": "aufjauchzend",
    "aufjauchzendstes": "aufjauchzend",
    "aufjauchzest": "aufjauchzen",
    "aufjauchzet": "aufjauchzen",
    "aufjauchzt": "aufjauchzen",
    "aufjauchzte": "aufjauchzen",
    "aufjauchzten": "aufjauchzen",
    "aufjauchztest": "aufjauchzen",
    "aufjauchztet": "aufjauchzen",
    "aufkam": "aufkommen",
    "aufkamen": "aufkommen",
    "aufkamst": "aufkommen",
    "aufkamt": "aufkommen",
    "aufkaufend": "aufkaufen",
    "aufkaufende": "aufkaufend",
    "aufkaufendem": "aufkaufend",
    "aufkaufenden": "aufkaufend",
    "aufkaufender": "aufkaufend",
    "aufkaufendes": "aufkaufend",
    "aufkaufest": "aufkaufen",
    "aufkaufet": "aufkaufen",
    "aufkaufst": "aufkaufen",
    "aufkauft": "aufkaufen",
    "aufkaufte": "aufkaufen",
    "aufkauften": "aufkaufen",
    "aufkauftest": "aufkaufen",
    "aufkauftet": "aufkaufen",
    "aufkeime": "aufkeimen",
    "aufkeimend": "aufkeimen",
    "aufkeimende": "aufkeimend",
    "aufkeimendem": "aufkeimend",
    "aufkeimenden": "aufkeimend",
    "aufkeimender": "aufkeimend",
    "aufkeimendere": "aufkeimend",
    "aufkeimenderem": "aufkeimend",
    "aufkeimenderen": "aufkeimend",
    "aufkeimenderer": "aufkeimend",
    "aufkeimenderes": "aufkeimend",
    "aufkeimendes": "aufkeimend",
    "aufkeimendste": "aufkeimend",
    "aufkeimendstem": "aufkeimend",
    "aufkeimendsten": "aufkeimend",
    "aufkeimendster": "aufkeimend",
    "aufkeimendstes": "aufkeimend",
    "aufkeimest": "aufkeimen",
    "aufkeimet": "aufkeimen",
    "aufkeimst": "aufkeimen",
    "aufkeimt": "aufkeimen",
    "aufkeimte": "aufkeimen",
    "aufkeimten": "aufkeimen",
    "aufkeimtest": "aufkeimen",
    "aufkeimtet": "aufkeimen",
    "aufklappe": "aufklappen",
    "aufklappend": "aufklappen",
    "aufklappende": "aufklappend",
    "aufklappendem": "aufklappend",
    "aufklappenden": "aufklappend",
    "aufklappender": "aufklappend",
    "aufklappendes": "aufklappend",
    "aufklappest": "aufklappen",
    "aufklappet": "aufklappen",
    "aufklappst": "aufklappen",
    "aufklappt": "aufklappen",
    "aufklappte": "aufklappen",
    "aufklappten": "aufklappen",
    "aufklapptest": "aufklappen",
    "aufklapptet": "aufklappen",
    "aufklare": "aufklaren",
    "aufklarend": "aufklaren",
    "aufklarende": "aufklarend",
    "aufklarendem": "aufklarend",
    "aufklarenden": "aufklarend",
    "aufklarender": "aufklarend",
    "aufklarendere": "aufklarend",
    "aufklarenderem": "aufklarend",
    "aufklarenderen": "aufklarend",
    "aufklarenderer": "aufklarend",
    "aufklarenderes": "aufklarend",
    "aufklarendes": "aufklarend",
    "aufklarendste": "aufklarend",
    "aufklarendstem": "aufklarend",
    "aufklarendsten": "aufklarend",
    "aufklarendster": "aufklarend",
    "aufklarendstes": "aufklarend",
    "aufklarest": "aufklaren",
    "aufklaret": "aufklaren",
    "aufklarst": "aufklaren",
    "aufklart": "aufklaren",
    "aufklarte": "aufklaren",
    "aufklarten": "aufklaren",
    "aufklartest": "aufklaren",
    "aufklartet": "aufklaren",
    "aufklaube": "aufklauben",
    "aufklaubend": "aufklauben",
    "aufklaubende": "aufklaubend",
    "aufklaubendem": "aufklaubend",
    "aufklaubenden": "aufklaubend",
    "aufklaubender": "aufklaubend",
    "aufklaubendere": "aufklaubend",
    "aufklaubenderem": "aufklaubend",
    "aufklaubenderen": "aufklaubend",
    "aufklaubenderer": "aufklaubend",
    "aufklaubenderes": "aufklaubend",
    "aufklaubendes": "aufklaubend",
    "aufklaubendste": "aufklaubend",
    "aufklaubendstem": "aufklaubend",
    "aufklaubendsten": "aufklaubend",
    "aufklaubendster": "aufklaubend",
    "aufklaubendstes": "aufklaubend",
    "aufklaubest": "aufklauben",
    "aufklaubet": "aufklauben",
    "aufklaubst": "aufklauben",
    "aufklaubt": "aufklauben",
    "aufklaubte": "aufklauben",
    "aufklaubten": "aufklauben",
    "aufklaubtest": "aufklauben",
    "aufklaubtet": "aufklauben",
    "aufklebe": "aufkleben",
    "aufklebend": "aufkleben",
    "aufklebende": "aufklebend",
    "aufklebendem": "aufklebend",
    "aufklebenden": "aufklebend",
    "aufklebender": "aufklebend",
    "aufklebendes": "aufklebend",
    "aufklebest": "aufkleben",
    "aufklebet": "aufkleben",
    "aufklebst": "aufkleben",
    "aufklebt": "aufkleben",
    "aufklebte": "aufkleben",
    "aufklebten": "aufkleben",
    "aufklebtest": "aufkleben",
    "aufklebtet": "aufkleben",
    "aufklingele": "aufklingeln",
    "aufklingelnd": "aufklingeln",
    "aufklingelnde": "aufklingelnd",
    "aufklingelndem": "aufklingelnd",
    "aufklingelnden": "aufklingelnd",
    "aufklingelnder": "aufklingelnd",
    "aufklingelndes": "aufklingelnd",
    "aufklingelst": "aufklingeln",
    "aufklingelt": "aufklingeln",
    "aufklingelte": "aufklingeln",
    "aufklingelten": "aufklingeln",
    "aufklingeltest": "aufklingeln",
    "aufklingeltet": "aufklingeln",
    "aufklingle": "aufklingeln",
    "aufklinke": "aufklinken",
    "aufklinkend": "aufklinken",
    "aufklinkende": "aufklinkend",
    "aufklinkendem": "aufklinkend",
    "aufklinkenden": "aufklinkend",
    "aufklinkender": "aufklinkend",
    "aufklinkendes": "aufklinkend",
    "aufklinkest": "aufklinken",
    "aufklinket": "aufklinken",
    "aufklinkst": "aufklinken",
    "aufklinkt": "aufklinken",
    "aufklinkte": "aufklinken",
    "aufklinkten": "aufklinken",
    "aufklinktest": "aufklinken",
    "aufklinktet": "aufklinken",
    "aufkläre": "aufklären",
    "aufklärend": "aufklären",
    "aufklärendem": "aufklärend",
    "aufklärender": "aufklärend",
    "aufklärendes": "aufklärend",
    "aufklärerischem": "aufklärerisch",
    "aufklärerischen": "aufklärerisch",
    "aufklärerischer": "aufklärerisch",
    "aufklärerisches": "aufklärerisch",
    "aufklärest": "aufklären",
    "aufkläret": "aufklären",
    "aufklärst": "aufklären",
    "aufklärt": "aufklären",
    "aufklärte": "aufklären",
    "aufklärten": "aufklären",
    "aufklärtest": "aufklären",
    "aufklärtet": "aufklären",
    "aufknote": "aufknoten",
    "aufknotend": "aufknoten",
    "aufknotende": "aufknotend",
    "aufknotendem": "aufknotend",
    "aufknotenden": "aufknotend",
    "aufknotender": "aufknotend",
    "aufknotendes": "aufknotend",
    "aufknotest": "aufknoten",
    "aufknotet": "aufknoten",
    "aufknotete": "aufknoten",
    "aufknoteten": "aufknoten",
    "aufknotetest": "aufknoten",
    "aufknotetet": "aufknoten",
    "aufknöpfe": "aufknöpfen",
    "aufknöpfend": "aufknöpfen",
    "aufknöpfende": "aufknöpfend",
    "aufknöpfendem": "aufknöpfend",
    "aufknöpfenden": "aufknöpfend",
    "aufknöpfender": "aufknöpfend",
    "aufknöpfendes": "aufknöpfend",
    "aufknöpfest": "aufknöpfen",
    "aufknöpfet": "aufknöpfen",
    "aufknöpfst": "aufknöpfen",
    "aufknöpft": "aufknöpfen",
    "aufknöpfte": "aufknöpfen",
    "aufknöpften": "aufknöpfen",
    "aufknöpftest": "aufknöpfen",
    "aufknöpftet": "aufknöpfen",
    "aufknüpfe": "aufknüpfen",
    "aufknüpfend": "aufknüpfen",
    "aufknüpfende": "aufknüpfend",
    "aufknüpfendem": "aufknüpfend",
    "aufknüpfenden": "aufknüpfend",
    "aufknüpfender": "aufknüpfend",
    "aufknüpfendes": "aufknüpfend",
    "aufknüpfest": "aufknüpfen",
    "aufknüpfet": "aufknüpfen",
    "aufknüpfst": "aufknüpfen",
    "aufknüpft": "aufknüpfen",
    "aufknüpfte": "aufknüpfen",
    "aufknüpften": "aufknüpfen",
    "aufknüpftest": "aufknüpfen",
    "aufknüpftet": "aufknüpfen",
    "aufkoche": "aufkochen",
    "aufkochend": "aufkochen",
    "aufkochende": "aufkochend",
    "aufkochendem": "aufkochend",
    "aufkochenden": "aufkochend",
    "aufkochender": "aufkochend",
    "aufkochendere": "aufkochend",
    "aufkochenderem": "aufkochend",
    "aufkochenderen": "aufkochend",
    "aufkochenderer": "aufkochend",
    "aufkochenderes": "aufkochend",
    "aufkochendes": "aufkochend",
    "aufkochendste": "aufkochend",
    "aufkochendstem": "aufkochend",
    "aufkochendsten": "aufkochend",
    "aufkochendster": "aufkochend",
    "aufkochendstes": "aufkochend",
    "aufkochest": "aufkochen",
    "aufkochet": "aufkochen",
    "aufkochst": "aufkochen",
    "aufkocht": "aufkochen",
    "aufkochte": "aufkochen",
    "aufkochten": "aufkochen",
    "aufkochtest": "aufkochen",
    "aufkochtet": "aufkochen",
    "aufkomme": "aufkommen",
    "aufkommend": "aufkommen",
    "aufkommende": "aufkommend",
    "aufkommendem": "aufkommend",
    "aufkommenden": "aufkommend",
    "aufkommender": "aufkommend",
    "aufkommendes": "aufkommend",
    "aufkommest": "aufkommen",
    "aufkommet": "aufkommen",
    "aufkommst": "aufkommen",
    "aufkommt": "aufkommen",
    "aufkratze": "aufkratzen",
    "aufkratzend": "aufkratzen",
    "aufkratzende": "aufkratzend",
    "aufkratzendem": "aufkratzend",
    "aufkratzenden": "aufkratzend",
    "aufkratzender": "aufkratzend",
    "aufkratzendere": "aufkratzend",
    "aufkratzenderem": "aufkratzend",
    "aufkratzenderen": "aufkratzend",
    "aufkratzenderer": "aufkratzend",
    "aufkratzenderes": "aufkratzend",
    "aufkratzendes": "aufkratzend",
    "aufkratzendste": "aufkratzend",
    "aufkratzendstem": "aufkratzend",
    "aufkratzendsten": "aufkratzend",
    "aufkratzendster": "aufkratzend",
    "aufkratzendstes": "aufkratzend",
    "aufkratzest": "aufkratzen",
    "aufkratzet": "aufkratzen",
    "aufkratzt": "aufkratzen",
    "aufkratzte": "aufkratzen",
    "aufkratzten": "aufkratzen",
    "aufkratztest": "aufkratzen",
    "aufkratztet": "aufkratzen",
    "aufkrempele": "aufkrempeln",
    "aufkrempelnd": "aufkrempeln",
    "aufkrempelnde": "aufkrempelnd",
    "aufkrempelndem": "aufkrempelnd",
    "aufkrempelnden": "aufkrempelnd",
    "aufkrempelnder": "aufkrempelnd",
    "aufkrempelndere": "aufkrempelnd",
    "aufkrempelnderem": "aufkrempelnd",
    "aufkrempelnderen": "aufkrempelnd",
    "aufkrempelnderer": "aufkrempelnd",
    "aufkrempelnderes": "aufkrempelnd",
    "aufkrempelndes": "aufkrempelnd",
    "aufkrempelndste": "aufkrempelnd",
    "aufkrempelndstem": "aufkrempelnd",
    "aufkrempelndsten": "aufkrempelnd",
    "aufkrempelndster": "aufkrempelnd",
    "aufkrempelndstes": "aufkrempelnd",
    "aufkrempelst": "aufkrempeln",
    "aufkrempelt": "aufkrempeln",
    "aufkrempelte": "aufkrempeln",
    "aufkrempelten": "aufkrempeln",
    "aufkrempeltest": "aufkrempeln",
    "aufkrempeltet": "aufkrempeln",
    "aufkremple": "aufkrempeln",
    "aufkreuze": "aufkreuzen",
    "aufkreuzend": "aufkreuzen",
    "aufkreuzende": "aufkreuzend",
    "aufkreuzendem": "aufkreuzend",
    "aufkreuzenden": "aufkreuzend",
    "aufkreuzender": "aufkreuzend",
    "aufkreuzendes": "aufkreuzend",
    "aufkreuzest": "aufkreuzen",
    "aufkreuzet": "aufkreuzen",
    "aufkreuzt": "aufkreuzen",
    "aufkreuzte": "aufkreuzen",
    "aufkreuzten": "aufkreuzen",
    "aufkreuztest": "aufkreuzen",
    "aufkreuztet": "aufkreuzen",
    "aufkriege": "aufkriegen",
    "aufkriegend": "aufkriegen",
    "aufkriegende": "aufkriegend",
    "aufkriegendem": "aufkriegend",
    "aufkriegenden": "aufkriegend",
    "aufkriegender": "aufkriegend",
    "aufkriegendes": "aufkriegend",
    "aufkriegest": "aufkriegen",
    "aufkrieget": "aufkriegen",
    "aufkriegst": "aufkriegen",
    "aufkriegt": "aufkriegen",
    "aufkriegte": "aufkriegen",
    "aufkriegten": "aufkriegen",
    "aufkriegtest": "aufkriegen",
    "aufkriegtet": "aufkriegen",
    "aufkäme": "aufkommen",
    "aufkämen": "aufkommen",
    "aufkämest": "aufkommen",
    "aufkämet": "aufkommen",
    "aufkämme": "aufkämmen",
    "aufkämmend": "aufkämmen",
    "aufkämmende": "aufkämmend",
    "aufkämmendem": "aufkämmend",
    "aufkämmenden": "aufkämmend",
    "aufkämmender": "aufkämmend",
    "aufkämmendes": "aufkämmend",
    "aufkämmest": "aufkämmen",
    "aufkämmet": "aufkämmen",
    "aufkämmst": "aufkämmen",
    "aufkämmt": "aufkämmen",
    "aufkämmte": "aufkämmen",
    "aufkämmten": "aufkämmen",
    "aufkämmtest": "aufkämmen",
    "aufkämmtet": "aufkämmen",
    "aufkündige": "aufkündigen",
    "aufkündigend": "aufkündigen",
    "aufkündigende": "aufkündigend",
    "aufkündigendem": "aufkündigend",
    "aufkündigenden": "aufkündigend",
    "aufkündigender": "aufkündigend",
    "aufkündigendes": "aufkündigend",
    "aufkündigest": "aufkündigen",
    "aufkündiget": "aufkündigen",
    "aufkündigst": "aufkündigen",
    "aufkündigt": "aufkündigen",
    "aufkündigte": "aufkündigen",
    "aufkündigten": "aufkündigen",
    "aufkündigtest": "aufkündigen",
    "aufkündigtet": "aufkündigen",
    "auflache": "auflachen",
    "auflachend": "auflachen",
    "auflachende": "auflachend",
    "auflachendem": "auflachend",
    "auflachenden": "auflachend",
    "auflachender": "auflachend",
    "auflachendes": "auflachend",
    "auflachest": "auflachen",
    "auflachet": "auflachen",
    "auflachst": "auflachen",
    "auflacht": "auflachen",
    "auflachte": "auflachen",
    "auflachten": "auflachen",
    "auflachtest": "auflachen",
    "auflachtet": "auflachen",
    "auflade": "aufladen",
    "aufladend": "aufladen",
    "aufladende": "aufladend",
    "aufladendem": "aufladend",
    "aufladenden": "aufladend",
    "aufladender": "aufladend",
    "aufladendes": "aufladend",
    "aufladest": "aufladen",
    "aufladet": "aufladen",
    "auflag": "aufliegen",
    "auflagenschwache": "auflagenschwach",
    "auflagenschwachem": "auflagenschwach",
    "auflagenschwachen": "auflagenschwach",
    "auflagenschwacher": "auflagenschwach",
    "auflagenschwaches": "auflagenschwach",
    "auflagenschwächer": "auflagenschwach",
    "auflagenschwächere": "auflagenschwach",
    "auflagenschwächerem": "auflagenschwach",
    "auflagenschwächeren": "auflagenschwach",
    "auflagenschwächerer": "auflagenschwach",
    "auflagenschwächeres": "auflagenschwach",
    "auflagenschwächsten": "auflagenschwach",
    "auflagenstarke": "auflagenstark",
    "auflagenstarkem": "auflagenstark",
    "auflagenstarken": "auflagenstark",
    "auflagenstarker": "auflagenstark",
    "auflagenstarkes": "auflagenstark",
    "auflagenstärker": "auflagenstark",
    "auflagenstärkere": "auflagenstark",
    "auflagenstärkerem": "auflagenstark",
    "auflagenstärkeren": "auflagenstark",
    "auflagenstärkerer": "auflagenstark",
    "auflagenstärkeres": "auflagenstark",
    "auflagenstärksten": "auflagenstark",
    "auflagst": "aufliegen",
    "auflagt": "aufliegen",
    "auflas": "auflesen",
    "auflasen": "auflesen",
    "auflasse": "auflassen",
    "auflassend": "auflassen",
    "auflassende": "auflassend",
    "auflassendem": "auflassend",
    "auflassenden": "auflassend",
    "auflassender": "auflassend",
    "auflassendes": "auflassend",
    "auflassest": "auflassen",
    "auflasset": "auflassen",
    "auflast": "auflesen",
    "auflaste": "auflasten",
    "auflastend": "auflasten",
    "auflastende": "auflastend",
    "auflastendem": "auflastend",
    "auflastenden": "auflastend",
    "auflastender": "auflastend",
    "auflastendes": "auflastend",
    "auflastest": "auflasten",
    "auflastet": "auflasten",
    "auflastete": "auflasten",
    "auflasteten": "auflasten",
    "auflastetest": "auflasten",
    "auflastetet": "auflasten",
    "auflauere": "auflauern",
    "auflauernd": "auflauern",
    "auflauernde": "auflauernd",
    "auflauerndem": "auflauernd",
    "auflauernden": "auflauernd",
    "auflauernder": "auflauernd",
    "auflauerndes": "auflauernd",
    "auflauerst": "auflauern",
    "auflauert": "auflauern",
    "auflauerte": "auflauern",
    "auflauerten": "auflauern",
    "auflauertest": "auflauern",
    "auflauertet": "auflauern",
    "auflaufend": "auflaufen",
    "auflaufende": "auflaufend",
    "auflaufendem": "auflaufend",
    "auflaufenden": "auflaufend",
    "auflaufender": "auflaufend",
    "auflaufendes": "auflaufend",
    "auflaufest": "auflaufen",
    "auflaufet": "auflaufen",
    "auflauft": "auflaufen",
    "auflaßt": "auflassen",
    "auflebe": "aufleben",
    "auflebend": "aufleben",
    "auflebende": "auflebend",
    "auflebendem": "auflebend",
    "auflebenden": "auflebend",
    "auflebender": "auflebend",
    "auflebendes": "auflebend",
    "auflebest": "aufleben",
    "auflebet": "aufleben",
    "auflebst": "aufleben",
    "auflebt": "aufleben",
    "auflebte": "aufleben",
    "auflebten": "aufleben",
    "auflebtest": "aufleben",
    "auflebtet": "aufleben",
    "auflege": "auflegen",
    "auflegend": "auflegen",
    "auflegende": "auflegend",
    "auflegendem": "auflegend",
    "auflegenden": "auflegend",
    "auflegender": "auflegend",
    "auflegendes": "auflegend",
    "auflegest": "auflegen",
    "aufleget": "auflegen",
    "auflegst": "auflegen",
    "auflegt": "auflegen",
    "auflegte": "auflegen",
    "auflegten": "auflegen",
    "auflegtest": "auflegen",
    "auflegtet": "auflegen",
    "auflehne": "auflehnen",
    "auflehnend": "auflehnen",
    "auflehnende": "auflehnend",
    "auflehnendem": "auflehnend",
    "auflehnenden": "auflehnend",
    "auflehnender": "auflehnend",
    "auflehnendere": "auflehnend",
    "auflehnenderem": "auflehnend",
    "auflehnenderen": "auflehnend",
    "auflehnenderer": "auflehnend",
    "auflehnenderes": "auflehnend",
    "auflehnendes": "auflehnend",
    "auflehnendste": "auflehnend",
    "auflehnendstem": "auflehnend",
    "auflehnendsten": "auflehnend",
    "auflehnendster": "auflehnend",
    "auflehnendstes": "auflehnend",
    "auflehnest": "auflehnen",
    "auflehnet": "auflehnen",
    "auflehnst": "auflehnen",
    "auflehnt": "auflehnen",
    "auflehnte": "auflehnen",
    "auflehnten": "auflehnen",
    "auflehntest": "auflehnen",
    "auflehntet": "auflehnen",
    "aufleime": "aufleimen",
    "aufleimend": "aufleimen",
    "aufleimende": "aufleimend",
    "aufleimendem": "aufleimend",
    "aufleimenden": "aufleimend",
    "aufleimender": "aufleimend",
    "aufleimendes": "aufleimend",
    "aufleimest": "aufleimen",
    "aufleimet": "aufleimen",
    "aufleimst": "aufleimen",
    "aufleimt": "aufleimen",
    "aufleimte": "aufleimen",
    "aufleimten": "aufleimen",
    "aufleimtest": "aufleimen",
    "aufleimtet": "aufleimen",
    "auflese": "auflesen",
    "auflesend": "auflesen",
    "auflesende": "auflesend",
    "auflesendem": "auflesend",
    "auflesenden": "auflesend",
    "auflesender": "auflesend",
    "auflesendes": "auflesend",
    "auflesest": "auflesen",
    "aufleset": "auflesen",
    "auflest": "auflesen",
    "aufleuchte": "aufleuchten",
    "aufleuchtend": "aufleuchten",
    "aufleuchtende": "aufleuchtend",
    "aufleuchtendem": "aufleuchtend",
    "aufleuchtenden": "aufleuchtend",
    "aufleuchtender": "aufleuchtend",
    "aufleuchtendes": "aufleuchtend",
    "aufleuchtest": "aufleuchten",
    "aufleuchtet": "aufleuchten",
    "aufleuchtete": "aufleuchten",
    "aufleuchteten": "aufleuchten",
    "aufleuchtetest": "aufleuchten",
    "aufleuchtetet": "aufleuchten",
    "auflichte": "auflichten",
    "auflichtend": "auflichten",
    "auflichtende": "auflichtend",
    "auflichtendem": "auflichtend",
    "auflichtenden": "auflichtend",
    "auflichtender": "auflichtend",
    "auflichtendes": "auflichtend",
    "auflichtest": "auflichten",
    "auflichtet": "auflichten",
    "auflichtete": "auflichten",
    "auflichteten": "auflichten",
    "auflichtetest": "auflichten",
    "auflichtetet": "auflichten",
    "auflief": "auflaufen",
    "aufliefe": "auflaufen",
    "aufliefen": "auflaufen",
    "aufliefere": "aufliefern",
    "aufliefernd": "aufliefern",
    "aufliefernde": "aufliefernd",
    "auflieferndem": "aufliefernd",
    "aufliefernden": "aufliefernd",
    "aufliefernder": "aufliefernd",
    "auflieferndes": "aufliefernd",
    "auflieferst": "aufliefern",
    "aufliefert": "aufliefern",
    "auflieferte": "aufliefern",
    "auflieferten": "aufliefern",
    "aufliefertest": "aufliefern",
    "aufliefertet": "aufliefern",
    "aufliefest": "auflaufen",
    "aufliefet": "auflaufen",
    "aufliefst": "auflaufen",
    "auflieft": "auflaufen",
    "aufliege": "aufliegen",
    "aufliegend": "aufliegen",
    "aufliegende": "aufliegend",
    "aufliegendem": "aufliegend",
    "aufliegenden": "aufliegend",
    "aufliegender": "aufliegend",
    "aufliegendes": "aufliegend",
    "aufliegest": "aufliegen",
    "auflieget": "aufliegen",
    "aufliegst": "aufliegen",
    "aufliegt": "aufliegen",
    "aufliest": "auflesen",
    "aufließ": "auflassen",
    "aufließe": "auflassen",
    "aufließen": "auflassen",
    "aufließest": "auflassen",
    "aufließet": "auflassen",
    "aufließt": "auflassen",
    "aufliste": "auflisten",
    "auflistend": "auflisten",
    "auflistende": "auflistend",
    "auflistendem": "auflistend",
    "auflistenden": "auflistend",
    "auflistender": "auflistend",
    "auflistendes": "auflistend",
    "auflistest": "auflisten",
    "auflistet": "auflisten",
    "auflistete": "auflisten",
    "auflisteten": "auflisten",
    "auflistetest": "auflisten",
    "auflistetet": "auflisten",
    "auflockere": "auflockern",
    "auflockernd": "auflockern",
    "auflockernde": "auflockernd",
    "auflockerndem": "auflockernd",
    "auflockernden": "auflockernd",
    "auflockernder": "auflockernd",
    "auflockerndere": "auflockernd",
    "auflockernderem": "auflockernd",
    "auflockernderen": "auflockernd",
    "auflockernderer": "auflockernd",
    "auflockernderes": "auflockernd",
    "auflockerndes": "auflockernd",
    "auflockerndste": "auflockernd",
    "auflockerndstem": "auflockernd",
    "auflockerndsten": "auflockernd",
    "auflockerndster": "auflockernd",
    "auflockerndstes": "auflockernd",
    "auflockerst": "auflockern",
    "auflockert": "auflockern",
    "auflockerte": "auflockern",
    "auflockerten": "auflockern",
    "auflockertest": "auflockern",
    "auflockertet": "auflockern",
    "auflodere": "auflodern",
    "auflodernd": "auflodern",
    "auflodernde": "auflodernd",
    "aufloderndem": "auflodernd",
    "auflodernden": "auflodernd",
    "auflodernder": "auflodernd",
    "aufloderndere": "auflodernd",
    "auflodernderem": "auflodernd",
    "auflodernderen": "auflodernd",
    "auflodernderer": "auflodernd",
    "auflodernderes": "auflodernd",
    "aufloderndes": "auflodernd",
    "aufloderndste": "auflodernd",
    "aufloderndstem": "auflodernd",
    "aufloderndsten": "auflodernd",
    "aufloderndster": "auflodernd",
    "aufloderndstes": "auflodernd",
    "aufloderst": "auflodern",
    "auflodert": "auflodern",
    "aufloderte": "auflodern",
    "aufloderten": "auflodern",
    "auflodertest": "auflodern",
    "auflodertet": "auflodern",
    "auflud": "aufladen",
    "aufluden": "aufladen",
    "aufludest": "aufladen",
    "aufludet": "aufladen",
    "auflädst": "aufladen",
    "auflädt": "aufladen",
    "aufläge": "aufliegen",
    "auflägen": "aufliegen",
    "auflägest": "aufliegen",
    "aufläget": "aufliegen",
    "aufläse": "auflesen",
    "aufläsen": "auflesen",
    "aufläsest": "auflesen",
    "aufläset": "auflesen",
    "aufläufst": "auflaufen",
    "aufläuft": "auflaufen",
    "aufläßt": "auflassen",
    "auflösbare": "auflösbar",
    "auflösbarem": "auflösbar",
    "auflösbaren": "auflösbar",
    "auflösbarer": "auflösbar",
    "auflösbarere": "auflösbar",
    "auflösbarerem": "auflösbar",
    "auflösbareren": "auflösbar",
    "auflösbarerer": "auflösbar",
    "auflösbareres": "auflösbar",
    "auflösbares": "auflösbar",
    "auflösbarste": "auflösbar",
    "auflösbarstem": "auflösbar",
    "auflösbarsten": "auflösbar",
    "auflösbarster": "auflösbar",
    "auflösbarstes": "auflösbar",
    "auflöse": "auflösen",
    "auflösend": "auflösen",
    "auflösende": "auflösend",
    "auflösendem": "auflösend",
    "auflösenden": "auflösend",
    "auflösender": "auflösend",
    "auflösendere": "auflösend",
    "auflösenderem": "auflösend",
    "auflösenderen": "auflösend",
    "auflösenderer": "auflösend",
    "auflösenderes": "auflösend",
    "auflösendes": "auflösend",
    "auflösendste": "auflösend",
    "auflösendstem": "auflösend",
    "auflösendsten": "auflösend",
    "auflösendster": "auflösend",
    "auflösendstes": "auflösend",
    "auflösest": "auflösen",
    "auflöset": "auflösen",
    "auflöst": "auflösen",
    "auflöste": "auflösen",
    "auflösten": "auflösen",
    "auflöstest": "auflösen",
    "auflöstet": "auflösen",
    "auflüde": "aufladen",
    "auflüden": "aufladen",
    "auflüdest": "aufladen",
    "auflüdet": "aufladen",
    "aufmache": "aufmachen",
    "aufmachend": "aufmachen",
    "aufmachende": "aufmachend",
    "aufmachendem": "aufmachend",
    "aufmachenden": "aufmachend",
    "aufmachender": "aufmachend",
    "aufmachendere": "aufmachend",
    "aufmachenderem": "aufmachend",
    "aufmachenderen": "aufmachend",
    "aufmachenderer": "aufmachend",
    "aufmachenderes": "aufmachend",
    "aufmachendes": "aufmachend",
    "aufmachendste": "aufmachend",
    "aufmachendstem": "aufmachend",
    "aufmachendsten": "aufmachend",
    "aufmachendster": "aufmachend",
    "aufmachendstes": "aufmachend",
    "aufmachest": "aufmachen",
    "aufmachet": "aufmachen",
    "aufmachst": "aufmachen",
    "aufmacht": "aufmachen",
    "aufmachte": "aufmachen",
    "aufmachten": "aufmachen",
    "aufmachtest": "aufmachen",
    "aufmachtet": "aufmachen",
    "aufmarschiere": "aufmarschieren",
    "aufmarschierend": "aufmarschieren",
    "aufmarschierende": "aufmarschierend",
    "aufmarschierendem": "aufmarschierend",
    "aufmarschierenden": "aufmarschierend",
    "aufmarschierender": "aufmarschierend",
    "aufmarschierendes": "aufmarschierend",
    "aufmarschierest": "aufmarschieren",
    "aufmarschieret": "aufmarschieren",
    "aufmarschierst": "aufmarschieren",
    "aufmarschiert": "aufmarschieren",
    "aufmarschierte": "aufmarschieren",
    "aufmarschiertem": "aufmarschiert",
    "aufmarschierten": "aufmarschieren",
    "aufmarschierter": "aufmarschiert",
    "aufmarschiertes": "aufmarschiert",
    "aufmarschiertest": "aufmarschieren",
    "aufmarschiertet": "aufmarschieren",
    "aufmeißele": "aufmeißeln",
    "aufmeißelnd": "aufmeißeln",
    "aufmeißelnde": "aufmeißelnd",
    "aufmeißelndem": "aufmeißelnd",
    "aufmeißelnden": "aufmeißelnd",
    "aufmeißelnder": "aufmeißelnd",
    "aufmeißelndes": "aufmeißelnd",
    "aufmeißelst": "aufmeißeln",
    "aufmeißelt": "aufmeißeln",
    "aufmeißelte": "aufmeißeln",
    "aufmeißelten": "aufmeißeln",
    "aufmeißeltest": "aufmeißeln",
    "aufmeißeltet": "aufmeißeln",
    "aufmeißle": "aufmeißeln",
    "aufmerke": "aufmerken",
    "aufmerkend": "aufmerken",
    "aufmerkende": "aufmerkend",
    "aufmerkendem": "aufmerkend",
    "aufmerkenden": "aufmerkend",
    "aufmerkender": "aufmerkend",
    "aufmerkendes": "aufmerkend",
    "aufmerkest": "aufmerken",
    "aufmerket": "aufmerken",
    "aufmerksame": "aufmerksam",
    "aufmerksamem": "aufmerksam",
    "aufmerksamen": "aufmerksam",
    "aufmerksamer": "aufmerksam",
    "aufmerksamere": "aufmerksam",
    "aufmerksamerem": "aufmerksam",
    "aufmerksameren": "aufmerksam",
    "aufmerksamerer": "aufmerksam",
    "aufmerksameres": "aufmerksam",
    "aufmerksames": "aufmerksam",
    "aufmerksamstem": "aufmerksam",
    "aufmerksamsten": "aufmerksam",
    "aufmerksamster": "aufmerksam",
    "aufmerksamstes": "aufmerksam",
    "aufmerkst": "aufmerken",
    "aufmerkt": "aufmerken",
    "aufmerkte": "aufmerken",
    "aufmerkten": "aufmerken",
    "aufmerktest": "aufmerken",
    "aufmerktet": "aufmerken",
    "aufmotze": "aufmotzen",
    "aufmotzend": "aufmotzen",
    "aufmotzende": "aufmotzend",
    "aufmotzendem": "aufmotzend",
    "aufmotzenden": "aufmotzend",
    "aufmotzender": "aufmotzend",
    "aufmotzendere": "aufmotzend",
    "aufmotzenderem": "aufmotzend",
    "aufmotzenderen": "aufmotzend",
    "aufmotzenderer": "aufmotzend",
    "aufmotzenderes": "aufmotzend",
    "aufmotzendes": "aufmotzend",
    "aufmotzendste": "aufmotzend",
    "aufmotzendstem": "aufmotzend",
    "aufmotzendsten": "aufmotzend",
    "aufmotzendster": "aufmotzend",
    "aufmotzendstes": "aufmotzend",
    "aufmotzest": "aufmotzen",
    "aufmotzet": "aufmotzen",
    "aufmotzt": "aufmotzen",
    "aufmotzte": "aufmotzen",
    "aufmotzten": "aufmotzen",
    "aufmotztest": "aufmotzen",
    "aufmotztet": "aufmotzen",
    "aufmuntere": "aufmuntern",
    "aufmunternd": "aufmuntern",
    "aufmunternde": "aufmunternd",
    "aufmunterndem": "aufmunternd",
    "aufmunternden": "aufmunternd",
    "aufmunternder": "aufmunternd",
    "aufmunterndere": "aufmunternd",
    "aufmunternderem": "aufmunternd",
    "aufmunternderen": "aufmunternd",
    "aufmunternderer": "aufmunternd",
    "aufmunternderes": "aufmunternd",
    "aufmunterndes": "aufmunternd",
    "aufmunterndste": "aufmunternd",
    "aufmunterndstem": "aufmunternd",
    "aufmunterndsten": "aufmunternd",
    "aufmunterndster": "aufmunternd",
    "aufmunterndstes": "aufmunternd",
    "aufmunterst": "aufmuntern",
    "aufmuntert": "aufmuntern",
    "aufmunterte": "aufmuntern",
    "aufmunterten": "aufmuntern",
    "aufmuntertest": "aufmuntern",
    "aufmuntertet": "aufmuntern",
    "aufmöbele": "aufmöbeln",
    "aufmöbelnd": "aufmöbeln",
    "aufmöbelnde": "aufmöbelnd",
    "aufmöbelndem": "aufmöbelnd",
    "aufmöbelnden": "aufmöbelnd",
    "aufmöbelnder": "aufmöbelnd",
    "aufmöbelndere": "aufmöbelnd",
    "aufmöbelnderem": "aufmöbelnd",
    "aufmöbelnderen": "aufmöbelnd",
    "aufmöbelnderer": "aufmöbelnd",
    "aufmöbelnderes": "aufmöbelnd",
    "aufmöbelndes": "aufmöbelnd",
    "aufmöbelndste": "aufmöbelnd",
    "aufmöbelndstem": "aufmöbelnd",
    "aufmöbelndsten": "aufmöbelnd",
    "aufmöbelndster": "aufmöbelnd",
    "aufmöbelndstes": "aufmöbelnd",
    "aufmöbelst": "aufmöbeln",
    "aufmöbelt": "aufmöbeln",
    "aufmöbelte": "aufmöbeln",
    "aufmöbelten": "aufmöbeln",
    "aufmöbeltest": "aufmöbeln",
    "aufmöbeltet": "aufmöbeln",
    "aufmöble": "aufmöbeln",
    "aufmüpfige": "aufmüpfig",
    "aufmüpfigem": "aufmüpfig",
    "aufmüpfigen": "aufmüpfig",
    "aufmüpfiger": "aufmüpfig",
    "aufmüpfigere": "aufmüpfig",
    "aufmüpfigerem": "aufmüpfig",
    "aufmüpfigeren": "aufmüpfig",
    "aufmüpfigerer": "aufmüpfig",
    "aufmüpfigeres": "aufmüpfig",
    "aufmüpfiges": "aufmüpfig",
    "aufmüpfigste": "aufmüpfig",
    "aufmüpfigstem": "aufmüpfig",
    "aufmüpfigsten": "aufmüpfig",
    "aufmüpfigster": "aufmüpfig",
    "aufmüpfigstes": "aufmüpfig",
    "aufnagele": "aufnageln",
    "aufnagelnd": "aufnageln",
    "aufnagelnde": "aufnagelnd",
    "aufnagelndem": "aufnagelnd",
    "aufnagelnden": "aufnagelnd",
    "aufnagelnder": "aufnagelnd",
    "aufnagelndes": "aufnagelnd",
    "aufnagelst": "aufnageln",
    "aufnagelt": "aufnageln",
    "aufnagelte": "aufnageln",
    "aufnagelten": "aufnageln",
    "aufnageltest": "aufnageln",
    "aufnageltet": "aufnageln",
    "aufnagle": "aufnageln",
    "aufnahm": "aufnehmen",
    "aufnahmefähige": "aufnahmefähig",
    "aufnahmefähigem": "aufnahmefähig",
    "aufnahmefähigen": "aufnahmefähig",
    "aufnahmefähiger": "aufnahmefähig",
    "aufnahmefähigere": "aufnahmefähig",
    "aufnahmefähigerem": "aufnahmefähig",
    "aufnahmefähigeren": "aufnahmefähig",
    "aufnahmefähigerer": "aufnahmefähig",
    "aufnahmefähigeres": "aufnahmefähig",
    "aufnahmefähiges": "aufnahmefähig",
    "aufnahmefähigste": "aufnahmefähig",
    "aufnahmefähigstem": "aufnahmefähig",
    "aufnahmefähigsten": "aufnahmefähig",
    "aufnahmefähigster": "aufnahmefähig",
    "aufnahmefähigstes": "aufnahmefähig",
    "aufnahmst": "aufnehmen",
    "aufnahmt": "aufnehmen",
    "aufnehme": "aufnehmen",
    "aufnehmend": "aufnehmen",
    "aufnehmende": "aufnehmend",
    "aufnehmendem": "aufnehmend",
    "aufnehmenden": "aufnehmend",
    "aufnehmender": "aufnehmend",
    "aufnehmendes": "aufnehmend",
    "aufnehmest": "aufnehmen",
    "aufnehmet": "aufnehmen",
    "aufnehmt": "aufnehmen",
    "aufnimmst": "aufnehmen",
    "aufnimmt": "aufnehmen",
    "aufnähe": "aufnähen",
    "aufnähend": "aufnähen",
    "aufnähende": "aufnähend",
    "aufnähendem": "aufnähend",
    "aufnähenden": "aufnähend",
    "aufnähender": "aufnähend",
    "aufnähendes": "aufnähend",
    "aufnähest": "aufnähen",
    "aufnähet": "aufnähen",
    "aufnähme": "aufnehmen",
    "aufnähmen": "aufnehmen",
    "aufnähmest": "aufnehmen",
    "aufnähmet": "aufnehmen",
    "aufnähst": "aufnähen",
    "aufnäht": "aufnähen",
    "aufnähte": "aufnähen",
    "aufnähten": "aufnähen",
    "aufnähtest": "aufnähen",
    "aufnähtet": "aufnähen",
    "aufopfere": "aufopfern",
    "aufopfernd": "aufopfern",
    "aufopfernde": "aufopfernd",
    "aufopferndem": "aufopfernd",
    "aufopfernden": "aufopfernd",
    "aufopfernder": "aufopfernd",
    "aufopferndere": "aufopfernd",
    "aufopfernderem": "aufopfernd",
    "aufopfernderen": "aufopfernd",
    "aufopfernderer": "aufopfernd",
    "aufopfernderes": "aufopfernd",
    "aufopferndes": "aufopfernd",
    "aufopferndste": "aufopfernd",
    "aufopferndstem": "aufopfernd",
    "aufopferndsten": "aufopfernd",
    "aufopferndster": "aufopfernd",
    "aufopferndstes": "aufopfernd",
    "aufopferst": "aufopfern",
    "aufopfert": "aufopfern",
    "aufopferte": "aufopfern",
    "aufopferten": "aufopfern",
    "aufopfertest": "aufopfern",
    "aufopfertet": "aufopfern",
    "aufpasse": "aufpassen",
    "aufpassend": "aufpassen",
    "aufpassende": "aufpassend",
    "aufpassendem": "aufpassend",
    "aufpassenden": "aufpassend",
    "aufpassender": "aufpassend",
    "aufpassendes": "aufpassend",
    "aufpassest": "aufpassen",
    "aufpasset": "aufpassen",
    "aufpaßt": "aufpassen",
    "aufpaßte": "aufpassen",
    "aufpaßten": "aufpassen",
    "aufpaßtest": "aufpassen",
    "aufpaßtet": "aufpassen",
    "aufpflanze": "aufpflanzen",
    "aufpflanzend": "aufpflanzen",
    "aufpflanzende": "aufpflanzend",
    "aufpflanzendem": "aufpflanzend",
    "aufpflanzenden": "aufpflanzend",
    "aufpflanzender": "aufpflanzend",
    "aufpflanzendes": "aufpflanzend",
    "aufpflanzest": "aufpflanzen",
    "aufpflanzet": "aufpflanzen",
    "aufpflanzt": "aufpflanzen",
    "aufpflanzte": "aufpflanzen",
    "aufpflanzten": "aufpflanzen",
    "aufpflanztest": "aufpflanzen",
    "aufpflanztet": "aufpflanzen",
    "aufpfropfe": "aufpfropfen",
    "aufpfropfend": "aufpfropfen",
    "aufpfropfende": "aufpfropfend",
    "aufpfropfendem": "aufpfropfend",
    "aufpfropfenden": "aufpfropfend",
    "aufpfropfender": "aufpfropfend",
    "aufpfropfendere": "aufpfropfend",
    "aufpfropfenderem": "aufpfropfend",
    "aufpfropfenderen": "aufpfropfend",
    "aufpfropfenderer": "aufpfropfend",
    "aufpfropfenderes": "aufpfropfend",
    "aufpfropfendes": "aufpfropfend",
    "aufpfropfendste": "aufpfropfend",
    "aufpfropfendstem": "aufpfropfend",
    "aufpfropfendsten": "aufpfropfend",
    "aufpfropfendster": "aufpfropfend",
    "aufpfropfendstes": "aufpfropfend",
    "aufpfropfest": "aufpfropfen",
    "aufpfropfet": "aufpfropfen",
    "aufpfropfst": "aufpfropfen",
    "aufpfropft": "aufpfropfen",
    "aufpfropfte": "aufpfropfen",
    "aufpfropften": "aufpfropfen",
    "aufpfropftest": "aufpfropfen",
    "aufpfropftet": "aufpfropfen",
    "aufplatze": "aufplatzen",
    "aufplatzend": "aufplatzen",
    "aufplatzende": "aufplatzend",
    "aufplatzendem": "aufplatzend",
    "aufplatzenden": "aufplatzend",
    "aufplatzender": "aufplatzend",
    "aufplatzendere": "aufplatzend",
    "aufplatzenderem": "aufplatzend",
    "aufplatzenderen": "aufplatzend",
    "aufplatzenderer": "aufplatzend",
    "aufplatzenderes": "aufplatzend",
    "aufplatzendes": "aufplatzend",
    "aufplatzendste": "aufplatzend",
    "aufplatzendstem": "aufplatzend",
    "aufplatzendsten": "aufplatzend",
    "aufplatzendster": "aufplatzend",
    "aufplatzendstes": "aufplatzend",
    "aufplatzest": "aufplatzen",
    "aufplatzet": "aufplatzen",
    "aufplatzt": "aufplatzen",
    "aufplatzte": "aufplatzen",
    "aufplatzten": "aufplatzen",
    "aufplatztest": "aufplatzen",
    "aufplatztet": "aufplatzen",
    "aufplustere": "aufplustern",
    "aufplusternd": "aufplustern",
    "aufplusternde": "aufplusternd",
    "aufplusterndem": "aufplusternd",
    "aufplusternden": "aufplusternd",
    "aufplusternder": "aufplusternd",
    "aufplusterndere": "aufplusternd",
    "aufplusternderem": "aufplusternd",
    "aufplusternderen": "aufplusternd",
    "aufplusternderer": "aufplusternd",
    "aufplusternderes": "aufplusternd",
    "aufplusterndes": "aufplusternd",
    "aufplusterndste": "aufplusternd",
    "aufplusterndstem": "aufplusternd",
    "aufplusterndsten": "aufplusternd",
    "aufplusterndster": "aufplusternd",
    "aufplusterndstes": "aufplusternd",
    "aufplusterst": "aufplustern",
    "aufplustert": "aufplustern",
    "aufplusterte": "aufplustern",
    "aufplusterten": "aufplustern",
    "aufplustertest": "aufplustern",
    "aufplustertet": "aufplustern",
    "aufpoliere": "aufpolieren",
    "aufpolierend": "aufpolieren",
    "aufpolierende": "aufpolierend",
    "aufpolierendem": "aufpolierend",
    "aufpolierenden": "aufpolierend",
    "aufpolierender": "aufpolierend",
    "aufpolierendere": "aufpolierend",
    "aufpolierenderem": "aufpolierend",
    "aufpolierenderen": "aufpolierend",
    "aufpolierenderer": "aufpolierend",
    "aufpolierenderes": "aufpolierend",
    "aufpolierendes": "aufpolierend",
    "aufpolierendste": "aufpolierend",
    "aufpolierendstem": "aufpolierend",
    "aufpolierendsten": "aufpolierend",
    "aufpolierendster": "aufpolierend",
    "aufpolierendstes": "aufpolierend",
    "aufpolierest": "aufpolieren",
    "aufpolieret": "aufpolieren",
    "aufpolierst": "aufpolieren",
    "aufpoliert": "aufpolieren",
    "aufpolierte": "aufpolieren",
    "aufpoliertem": "aufpoliert",
    "aufpolierten": "aufpolieren",
    "aufpolierter": "aufpoliert",
    "aufpoliertere": "aufpoliert",
    "aufpolierterem": "aufpoliert",
    "aufpolierteren": "aufpoliert",
    "aufpolierterer": "aufpoliert",
    "aufpolierteres": "aufpoliert",
    "aufpoliertes": "aufpoliert",
    "aufpoliertest": "aufpolieren",
    "aufpolierteste": "aufpoliert",
    "aufpoliertestem": "aufpoliert",
    "aufpoliertesten": "aufpoliert",
    "aufpoliertester": "aufpoliert",
    "aufpoliertestes": "aufpoliert",
    "aufpoliertet": "aufpolieren",
    "aufpolstere": "aufpolstern",
    "aufpolsternd": "aufpolstern",
    "aufpolsternde": "aufpolsternd",
    "aufpolsterndem": "aufpolsternd",
    "aufpolsternden": "aufpolsternd",
    "aufpolsternder": "aufpolsternd",
    "aufpolsterndere": "aufpolsternd",
    "aufpolsternderem": "aufpolsternd",
    "aufpolsternderen": "aufpolsternd",
    "aufpolsternderer": "aufpolsternd",
    "aufpolsternderes": "aufpolsternd",
    "aufpolsterndes": "aufpolsternd",
    "aufpolsterndste": "aufpolsternd",
    "aufpolsterndstem": "aufpolsternd",
    "aufpolsterndsten": "aufpolsternd",
    "aufpolsterndster": "aufpolsternd",
    "aufpolsterndstes": "aufpolsternd",
    "aufpolsterst": "aufpolstern",
    "aufpolstert": "aufpolstern",
    "aufpolsterte": "aufpolstern",
    "aufpolsterten": "aufpolstern",
    "aufpolstertest": "aufpolstern",
    "aufpolstertet": "aufpolstern",
    "aufpoppe": "aufpoppen",
    "aufpoppend": "aufpoppen",
    "aufpoppende": "aufpoppend",
    "aufpoppendem": "aufpoppend",
    "aufpoppenden": "aufpoppend",
    "aufpoppender": "aufpoppend",
    "aufpoppendes": "aufpoppend",
    "aufpoppest": "aufpoppen",
    "aufpoppet": "aufpoppen",
    "aufpoppst": "aufpoppen",
    "aufpoppt": "aufpoppen",
    "aufpoppte": "aufpoppen",
    "aufpoppten": "aufpoppen",
    "aufpopptest": "aufpoppen",
    "aufpopptet": "aufpoppen",
    "aufprallend": "aufprallen",
    "aufprallende": "aufprallend",
    "aufprallendem": "aufprallend",
    "aufprallenden": "aufprallend",
    "aufprallender": "aufprallend",
    "aufprallendes": "aufprallend",
    "aufprallest": "aufprallen",
    "aufprallet": "aufprallen",
    "aufprallst": "aufprallen",
    "aufprallt": "aufprallen",
    "aufprallte": "aufprallen",
    "aufprallten": "aufprallen",
    "aufpralltest": "aufprallen",
    "aufpralltet": "aufprallen",
    "aufprobiere": "aufprobieren",
    "aufprobierend": "aufprobieren",
    "aufprobierende": "aufprobierend",
    "aufprobierendem": "aufprobierend",
    "aufprobierenden": "aufprobierend",
    "aufprobierender": "aufprobierend",
    "aufprobierendes": "aufprobierend",
    "aufprobierest": "aufprobieren",
    "aufprobieret": "aufprobieren",
    "aufprobierst": "aufprobieren",
    "aufprobiert": "aufprobieren",
    "aufprobierte": "aufprobieren",
    "aufprobiertem": "aufprobiert",
    "aufprobierten": "aufprobieren",
    "aufprobierter": "aufprobiert",
    "aufprobiertes": "aufprobiert",
    "aufprobiertest": "aufprobieren",
    "aufprobiertet": "aufprobieren",
    "aufpräge": "aufprägen",
    "aufprägend": "aufprägen",
    "aufprägende": "aufprägend",
    "aufprägendem": "aufprägend",
    "aufprägenden": "aufprägend",
    "aufprägender": "aufprägend",
    "aufprägendes": "aufprägend",
    "aufprägest": "aufprägen",
    "aufpräget": "aufprägen",
    "aufprägst": "aufprägen",
    "aufprägt": "aufprägen",
    "aufprägte": "aufprägen",
    "aufprägten": "aufprägen",
    "aufprägtest": "aufprägen",
    "aufprägtet": "aufprägen",
    "aufpumpe": "aufpumpen",
    "aufpumpend": "aufpumpen",
    "aufpumpende": "aufpumpend",
    "aufpumpendem": "aufpumpend",
    "aufpumpenden": "aufpumpend",
    "aufpumpender": "aufpumpend",
    "aufpumpendere": "aufpumpend",
    "aufpumpenderem": "aufpumpend",
    "aufpumpenderen": "aufpumpend",
    "aufpumpenderer": "aufpumpend",
    "aufpumpenderes": "aufpumpend",
    "aufpumpendes": "aufpumpend",
    "aufpumpendste": "aufpumpend",
    "aufpumpendstem": "aufpumpend",
    "aufpumpendsten": "aufpumpend",
    "aufpumpendster": "aufpumpend",
    "aufpumpendstes": "aufpumpend",
    "aufpumpest": "aufpumpen",
    "aufpumpet": "aufpumpen",
    "aufpumpst": "aufpumpen",
    "aufpumpt": "aufpumpen",
    "aufpumpte": "aufpumpen",
    "aufpumpten": "aufpumpen",
    "aufpumptest": "aufpumpen",
    "aufpumptet": "aufpumpen",
    "aufputsche": "aufputschen",
    "aufputschend": "aufputschen",
    "aufputschende": "aufputschend",
    "aufputschendem": "aufputschend",
    "aufputschenden": "aufputschend",
    "aufputschender": "aufputschend",
    "aufputschendere": "aufputschend",
    "aufputschenderem": "aufputschend",
    "aufputschenderen": "aufputschend",
    "aufputschenderer": "aufputschend",
    "aufputschenderes": "aufputschend",
    "aufputschendes": "aufputschend",
    "aufputschendste": "aufputschend",
    "aufputschendstem": "aufputschend",
    "aufputschendsten": "aufputschend",
    "aufputschendster": "aufputschend",
    "aufputschendstes": "aufputschend",
    "aufputschest": "aufputschen",
    "aufputschet": "aufputschen",
    "aufputschst": "aufputschen",
    "aufputscht": "aufputschen",
    "aufputschte": "aufputschen",
    "aufputschten": "aufputschen",
    "aufputschtest": "aufputschen",
    "aufputschtet": "aufputschen",
    "aufputze": "aufputzen",
    "aufputzend": "aufputzen",
    "aufputzende": "aufputzend",
    "aufputzendem": "aufputzend",
    "aufputzenden": "aufputzend",
    "aufputzender": "aufputzend",
    "aufputzendes": "aufputzend",
    "aufputzest": "aufputzen",
    "aufputzet": "aufputzen",
    "aufputzt": "aufputzen",
    "aufputzte": "aufputzen",
    "aufputzten": "aufputzen",
    "aufputztest": "aufputzen",
    "aufputztet": "aufputzen",
    "aufpäppele": "aufpäppeln",
    "aufpäppelnd": "aufpäppeln",
    "aufpäppelnde": "aufpäppelnd",
    "aufpäppelndem": "aufpäppelnd",
    "aufpäppelnden": "aufpäppelnd",
    "aufpäppelnder": "aufpäppelnd",
    "aufpäppelndere": "aufpäppelnd",
    "aufpäppelnderem": "aufpäppelnd",
    "aufpäppelnderen": "aufpäppelnd",
    "aufpäppelnderer": "aufpäppelnd",
    "aufpäppelnderes": "aufpäppelnd",
    "aufpäppelndes": "aufpäppelnd",
    "aufpäppelndste": "aufpäppelnd",
    "aufpäppelndstem": "aufpäppelnd",
    "aufpäppelndsten": "aufpäppelnd",
    "aufpäppelndster": "aufpäppelnd",
    "aufpäppelndstes": "aufpäppelnd",
    "aufpäppelst": "aufpäppeln",
    "aufpäppelt": "aufpäppeln",
    "aufpäppelte": "aufpäppeln",
    "aufpäppelten": "aufpäppeln",
    "aufpäppeltest": "aufpäppeln",
    "aufpäppeltet": "aufpäppeln",
    "aufpäpple": "aufpäppeln",
    "aufquelle": "aufquellen",
    "aufquellend": "aufquellen",
    "aufquellende": "aufquellend",
    "aufquellendem": "aufquellend",
    "aufquellenden": "aufquellend",
    "aufquellender": "aufquellend",
    "aufquellendere": "aufquellend",
    "aufquellenderem": "aufquellend",
    "aufquellenderen": "aufquellend",
    "aufquellenderer": "aufquellend",
    "aufquellenderes": "aufquellend",
    "aufquellendes": "aufquellend",
    "aufquellendste": "aufquellend",
    "aufquellendstem": "aufquellend",
    "aufquellendsten": "aufquellend",
    "aufquellendster": "aufquellend",
    "aufquellendstes": "aufquellend",
    "aufquellest": "aufquellen",
    "aufquellet": "aufquellen",
    "aufquellst": "aufquellen",
    "aufquellt": "aufquellen",
    "aufquellte": "aufquellen",
    "aufquellten": "aufquellen",
    "aufquelltest": "aufquellen",
    "aufquelltet": "aufquellen",
    "aufquillst": "aufquellen",
    "aufquillt": "aufquellen",
    "aufquoll": "aufquellen",
    "aufquollen": "aufquellen",
    "aufquollst": "aufquellen",
    "aufquollt": "aufquellen",
    "aufquölle": "aufquellen",
    "aufquöllen": "aufquellen",
    "aufquöllest": "aufquellen",
    "aufquöllet": "aufquellen",
    "aufraffe": "aufraffen",
    "aufraffend": "aufraffen",
    "aufraffende": "aufraffend",
    "aufraffendem": "aufraffend",
    "aufraffenden": "aufraffend",
    "aufraffender": "aufraffend",
    "aufraffendes": "aufraffend",
    "aufraffest": "aufraffen",
    "aufraffet": "aufraffen",
    "aufraffst": "aufraffen",
    "aufrafft": "aufraffen",
    "aufraffte": "aufraffen",
    "aufrafften": "aufraffen",
    "aufrafftest": "aufraffen",
    "aufrafftet": "aufraffen",
    "aufrage": "aufragen",
    "aufragend": "aufragen",
    "aufragende": "aufragend",
    "aufragendem": "aufragend",
    "aufragenden": "aufragend",
    "aufragender": "aufragend",
    "aufragendes": "aufragend",
    "aufragest": "aufragen",
    "aufraget": "aufragen",
    "aufragst": "aufragen",
    "aufragt": "aufragen",
    "aufragte": "aufragen",
    "aufragten": "aufragen",
    "aufragtest": "aufragen",
    "aufragtet": "aufragen",
    "aufrappele": "aufrappeln",
    "aufrappelnd": "aufrappeln",
    "aufrappelnde": "aufrappelnd",
    "aufrappelndem": "aufrappelnd",
    "aufrappelnden": "aufrappelnd",
    "aufrappelnder": "aufrappelnd",
    "aufrappelndere": "aufrappelnd",
    "aufrappelnderem": "aufrappelnd",
    "aufrappelnderen": "aufrappelnd",
    "aufrappelnderer": "aufrappelnd",
    "aufrappelnderes": "aufrappelnd",
    "aufrappelndes": "aufrappelnd",
    "aufrappelndste": "aufrappelnd",
    "aufrappelndstem": "aufrappelnd",
    "aufrappelndsten": "aufrappelnd",
    "aufrappelndster": "aufrappelnd",
    "aufrappelndstes": "aufrappelnd",
    "aufrappelst": "aufrappeln",
    "aufrappelt": "aufrappeln",
    "aufrappelte": "aufrappeln",
    "aufrappelten": "aufrappeln",
    "aufrappeltest": "aufrappeln",
    "aufrappeltet": "aufrappeln",
    "aufrapple": "aufrappeln",
    "aufrauche": "aufrauchen",
    "aufrauchend": "aufrauchen",
    "aufrauchende": "aufrauchend",
    "aufrauchendem": "aufrauchend",
    "aufrauchenden": "aufrauchend",
    "aufrauchender": "aufrauchend",
    "aufrauchendes": "aufrauchend",
    "aufrauchest": "aufrauchen",
    "aufrauchet": "aufrauchen",
    "aufrauchst": "aufrauchen",
    "aufraucht": "aufrauchen",
    "aufrauchte": "aufrauchen",
    "aufrauchten": "aufrauchen",
    "aufrauchtest": "aufrauchen",
    "aufrauchtet": "aufrauchen",
    "aufraue": "aufrauen",
    "aufrauend": "aufrauen",
    "aufrauende": "aufrauend",
    "aufrauendem": "aufrauend",
    "aufrauenden": "aufrauend",
    "aufrauender": "aufrauend",
    "aufrauendere": "aufrauend",
    "aufrauenderem": "aufrauend",
    "aufrauenderen": "aufrauend",
    "aufrauenderer": "aufrauend",
    "aufrauenderes": "aufrauend",
    "aufrauendes": "aufrauend",
    "aufrauendste": "aufrauend",
    "aufrauendstem": "aufrauend",
    "aufrauendsten": "aufrauend",
    "aufrauendster": "aufrauend",
    "aufrauendstes": "aufrauend",
    "aufrauest": "aufrauen",
    "aufrauet": "aufrauen",
    "aufrauhe": "aufrauhen",
    "aufrauhend": "aufrauhen",
    "aufrauhende": "aufrauhend",
    "aufrauhendem": "aufrauhend",
    "aufrauhenden": "aufrauhend",
    "aufrauhender": "aufrauhend",
    "aufrauhendere": "aufrauhend",
    "aufrauhenderem": "aufrauhend",
    "aufrauhenderen": "aufrauhend",
    "aufrauhenderer": "aufrauhend",
    "aufrauhenderes": "aufrauhend",
    "aufrauhendes": "aufrauhend",
    "aufrauhendste": "aufrauhend",
    "aufrauhendstem": "aufrauhend",
    "aufrauhendsten": "aufrauhend",
    "aufrauhendster": "aufrauhend",
    "aufrauhendstes": "aufrauhend",
    "aufrauhest": "aufrauhen",
    "aufrauhet": "aufrauhen",
    "aufrauhst": "aufrauhen",
    "aufrauht": "aufrauhen",
    "aufrauhte": "aufrauhen",
    "aufrauhten": "aufrauhen",
    "aufrauhtest": "aufrauhen",
    "aufrauhtet": "aufrauhen",
    "aufraust": "aufrauen",
    "aufraut": "aufrauen",
    "aufraute": "aufrauen",
    "aufrauten": "aufrauen",
    "aufrautest": "aufrauen",
    "aufrautet": "aufrauen",
    "aufrechne": "aufrechnen",
    "aufrechnend": "aufrechnen",
    "aufrechnende": "aufrechnend",
    "aufrechnendem": "aufrechnend",
    "aufrechnenden": "aufrechnend",
    "aufrechnender": "aufrechnend",
    "aufrechnendes": "aufrechnend",
    "aufrechnest": "aufrechnen",
    "aufrechnet": "aufrechnen",
    "aufrechnete": "aufrechnen",
    "aufrechneten": "aufrechnen",
    "aufrechnetest": "aufrechnen",
    "aufrechnetet": "aufrechnen",
    "aufrechterhalten": "aufrechterhalte",
    "aufrechterhaltend": "aufrechterhalte",
    "aufrechterhaltende": "aufrechterhaltend",
    "aufrechterhaltendem": "aufrechterhaltend",
    "aufrechterhaltenden": "aufrechterhaltend",
    "aufrechterhaltender": "aufrechterhaltend",
    "aufrechterhaltendere": "aufrechterhaltend",
    "aufrechterhaltenderem": "aufrechterhaltend",
    "aufrechterhaltenderen": "aufrechterhaltend",
    "aufrechterhaltenderer": "aufrechterhaltend",
    "aufrechterhaltenderes": "aufrechterhaltend",
    "aufrechterhaltendes": "aufrechterhaltend",
    "aufrechterhaltendste": "aufrechterhaltend",
    "aufrechterhaltendstem": "aufrechterhaltend",
    "aufrechterhaltendsten": "aufrechterhaltend",
    "aufrechterhaltendster": "aufrechterhaltend",
    "aufrechterhaltendstes": "aufrechterhaltend",
    "aufrechterhaltene": "aufrechterhalten",
    "aufrechterhaltenem": "aufrechterhalten",
    "aufrechterhaltenen": "aufrechterhalten",
    "aufrechterhaltener": "aufrechterhalten",
    "aufrechterhaltenere": "aufrechterhalten",
    "aufrechterhaltenerem": "aufrechterhalten",
    "aufrechterhalteneren": "aufrechterhalten",
    "aufrechterhaltenerer": "aufrechterhalten",
    "aufrechterhalteneres": "aufrechterhalten",
    "aufrechterhaltenes": "aufrechterhalten",
    "aufrechterhaltenstem": "aufrechterhalten",
    "aufrechterhaltensten": "aufrechterhalten",
    "aufrechterhaltenster": "aufrechterhalten",
    "aufrechterhaltenstes": "aufrechterhalten",
    "aufrechterhaltest": "aufrechterhalte",
    "aufrechterhaltet": "aufrechterhalte",
    "aufrechterhielt": "aufrechterhalte",
    "aufrechterhielte": "aufrechterhalte",
    "aufrechterhielten": "aufrechterhalte",
    "aufrechterhieltest": "aufrechterhalte",
    "aufrechterhieltet": "aufrechterhalte",
    "aufrechterhält": "aufrechterhalte",
    "aufrechterhältst": "aufrechterhalte",
    "aufrechtzuerhalten": "aufrechterhalten",
    "aufrege": "aufregen",
    "aufregend": "aufregen",
    "aufregende": "aufregend",
    "aufregendem": "aufregend",
    "aufregenden": "aufregend",
    "aufregender": "aufregend",
    "aufregendere": "aufregend",
    "aufregenderem": "aufregend",
    "aufregenderen": "aufregend",
    "aufregenderer": "aufregend",
    "aufregenderes": "aufregend",
    "aufregendes": "aufregend",
    "aufregendste": "aufregend",
    "aufregendstem": "aufregend",
    "aufregendsten": "aufregend",
    "aufregendster": "aufregend",
    "aufregendstes": "aufregend",
    "aufregest": "aufregen",
    "aufreget": "aufregen",
    "aufregst": "aufregen",
    "aufregt": "aufregen",
    "aufregte": "aufregen",
    "aufregten": "aufregen",
    "aufregtest": "aufregen",
    "aufregtet": "aufregen",
    "aufreibe": "aufreiben",
    "aufreibend": "aufreiben",
    "aufreibende": "aufreibend",
    "aufreibendem": "aufreibend",
    "aufreibenden": "aufreibend",
    "aufreibender": "aufreibend",
    "aufreibendere": "aufreibend",
    "aufreibenderem": "aufreibend",
    "aufreibenderen": "aufreibend",
    "aufreibenderer": "aufreibend",
    "aufreibenderes": "aufreibend",
    "aufreibendes": "aufreibend",
    "aufreibendste": "aufreibend",
    "aufreibendstem": "aufreibend",
    "aufreibendsten": "aufreibend",
    "aufreibendster": "aufreibend",
    "aufreibendstes": "aufreibend",
    "aufreibest": "aufreiben",
    "aufreibet": "aufreiben",
    "aufreibst": "aufreiben",
    "aufreibt": "aufreiben",
    "aufreihe": "aufreihen",
    "aufreihend": "aufreihen",
    "aufreihende": "aufreihend",
    "aufreihendem": "aufreihend",
    "aufreihenden": "aufreihend",
    "aufreihender": "aufreihend",
    "aufreihendes": "aufreihend",
    "aufreihest": "aufreihen",
    "aufreihet": "aufreihen",
    "aufreihst": "aufreihen",
    "aufreiht": "aufreihen",
    "aufreihte": "aufreihen",
    "aufreihten": "aufreihen",
    "aufreihtest": "aufreihen",
    "aufreihtet": "aufreihen",
    "aufreite": "aufreiten",
    "aufreitend": "aufreiten",
    "aufreitende": "aufreitend",
    "aufreitendem": "aufreitend",
    "aufreitenden": "aufreitend",
    "aufreitender": "aufreitend",
    "aufreitendes": "aufreitend",
    "aufreitest": "aufreiten",
    "aufreitet": "aufreiten",
    "aufreize": "aufreizen",
    "aufreizend": "aufreizen",
    "aufreizende": "aufreizend",
    "aufreizendem": "aufreizend",
    "aufreizenden": "aufreizend",
    "aufreizender": "aufreizend",
    "aufreizendere": "aufreizend",
    "aufreizenderem": "aufreizend",
    "aufreizenderen": "aufreizend",
    "aufreizenderer": "aufreizend",
    "aufreizenderes": "aufreizend",
    "aufreizendes": "aufreizend",
    "aufreizendste": "aufreizend",
    "aufreizendstem": "aufreizend",
    "aufreizendsten": "aufreizend",
    "aufreizendster": "aufreizend",
    "aufreizendstes": "aufreizend",
    "aufreizest": "aufreizen",
    "aufreizet": "aufreizen",
    "aufreizt": "aufreizen",
    "aufreizte": "aufreizen",
    "aufreizten": "aufreizen",
    "aufreiztest": "aufreizen",
    "aufreiztet": "aufreizen",
    "aufreiße": "aufreißen",
    "aufreißend": "aufreißen",
    "aufreißende": "aufreißend",
    "aufreißendem": "aufreißend",
    "aufreißenden": "aufreißend",
    "aufreißender": "aufreißend",
    "aufreißendere": "aufreißend",
    "aufreißenderem": "aufreißend",
    "aufreißenderen": "aufreißend",
    "aufreißenderer": "aufreißend",
    "aufreißenderes": "aufreißend",
    "aufreißendes": "aufreißend",
    "aufreißendste": "aufreißend",
    "aufreißendstem": "aufreißend",
    "aufreißendsten": "aufreißend",
    "aufreißendster": "aufreißend",
    "aufreißendstes": "aufreißend",
    "aufreißerischem": "aufreißerisch",
    "aufreißerischen": "aufreißerisch",
    "aufreißerischer": "aufreißerisch",
    "aufreißerischere": "aufreißerisch",
    "aufreißerischerem": "aufreißerisch",
    "aufreißerischeren": "aufreißerisch",
    "aufreißerischerer": "aufreißerisch",
    "aufreißerischeres": "aufreißerisch",
    "aufreißerisches": "aufreißerisch",
    "aufreißerischste": "aufreißerisch",
    "aufreißerischstem": "aufreißerisch",
    "aufreißerischsten": "aufreißerisch",
    "aufreißerischster": "aufreißerisch",
    "aufreißerischstes": "aufreißerisch",
    "aufreißest": "aufreißen",
    "aufreißet": "aufreißen",
    "aufreißt": "aufreißen",
    "aufribbele": "aufribbeln",
    "aufribbelnd": "aufribbeln",
    "aufribbelnde": "aufribbelnd",
    "aufribbelndem": "aufribbelnd",
    "aufribbelnden": "aufribbelnd",
    "aufribbelnder": "aufribbelnd",
    "aufribbelndes": "aufribbelnd",
    "aufribbelst": "aufribbeln",
    "aufribbelt": "aufribbeln",
    "aufribbelte": "aufribbeln",
    "aufribbelten": "aufribbeln",
    "aufribbeltest": "aufribbeln",
    "aufribbeltet": "aufribbeln",
    "aufribble": "aufribbeln",
    "aufrichte": "aufrichten",
    "aufrichtend": "aufrichten",
    "aufrichtende": "aufrichtend",
    "aufrichtendem": "aufrichtend",
    "aufrichtenden": "aufrichtend",
    "aufrichtender": "aufrichtend",
    "aufrichtendes": "aufrichtend",
    "aufrichtest": "aufrichten",
    "aufrichtet": "aufrichten",
    "aufrichtete": "aufrichten",
    "aufrichteten": "aufrichten",
    "aufrichtetest": "aufrichten",
    "aufrichtetet": "aufrichten",
    "aufrichtige": "aufrichtig",
    "aufrichtigem": "aufrichtig",
    "aufrichtigen": "aufrichtig",
    "aufrichtiger": "aufrichtig",
    "aufrichtigere": "aufrichtig",
    "aufrichtigerem": "aufrichtig",
    "aufrichtigeren": "aufrichtig",
    "aufrichtigerer": "aufrichtig",
    "aufrichtigeres": "aufrichtig",
    "aufrichtiges": "aufrichtig",
    "aufrichtigste": "aufrichtig",
    "aufrichtigstem": "aufrichtig",
    "aufrichtigsten": "aufrichtig",
    "aufrichtigster": "aufrichtig",
    "aufrichtigstes": "aufrichtig",
    "aufrieb": "aufreiben",
    "aufriebe": "aufreiben",
    "aufrieben": "aufreiben",
    "aufriebest": "aufreiben",
    "aufriebet": "aufreiben",
    "aufriebst": "aufreiben",
    "aufriebt": "aufreiben",
    "aufrief": "aufrufen",
    "aufriefe": "aufrufen",
    "aufriefen": "aufrufen",
    "aufriefest": "aufrufen",
    "aufriefet": "aufrufen",
    "aufriefst": "aufrufen",
    "aufrieft": "aufrufen",
    "aufrisse": "aufreißen",
    "aufrissen": "aufreißen",
    "aufrissest": "aufreißen",
    "aufrisset": "aufreißen",
    "aufritt": "aufreiten",
    "aufritte": "aufreiten",
    "aufritten": "aufreiten",
    "aufrittest": "aufreiten",
    "aufrittet": "aufreiten",
    "aufriß": "aufreißen",
    "aufrißt": "aufreißen",
    "aufrolle": "aufrollen",
    "aufrollend": "aufrollen",
    "aufrollende": "aufrollend",
    "aufrollendem": "aufrollend",
    "aufrollenden": "aufrollend",
    "aufrollender": "aufrollend",
    "aufrollendes": "aufrollend",
    "aufrollest": "aufrollen",
    "aufrollet": "aufrollen",
    "aufrollst": "aufrollen",
    "aufrollt": "aufrollen",
    "aufrollte": "aufrollen",
    "aufrollten": "aufrollen",
    "aufrolltest": "aufrollen",
    "aufrolltet": "aufrollen",
    "aufrufend": "aufrufen",
    "aufrufende": "aufrufend",
    "aufrufendem": "aufrufend",
    "aufrufenden": "aufrufend",
    "aufrufender": "aufrufend",
    "aufrufendes": "aufrufend",
    "aufrufest": "aufrufen",
    "aufrufet": "aufrufen",
    "aufrufst": "aufrufen",
    "aufruft": "aufrufen",
    "aufrunde": "aufrunden",
    "aufrundend": "aufrunden",
    "aufrundende": "aufrundend",
    "aufrundendem": "aufrundend",
    "aufrundenden": "aufrundend",
    "aufrundender": "aufrundend",
    "aufrundendes": "aufrundend",
    "aufrundest": "aufrunden",
    "aufrundet": "aufrunden",
    "aufrundete": "aufrunden",
    "aufrundeten": "aufrunden",
    "aufrundetest": "aufrunden",
    "aufrundetet": "aufrunden",
    "aufräume": "aufräumen",
    "aufräumend": "aufräumen",
    "aufräumende": "aufräumend",
    "aufräumendem": "aufräumend",
    "aufräumenden": "aufräumend",
    "aufräumender": "aufräumend",
    "aufräumendes": "aufräumend",
    "aufräumest": "aufräumen",
    "aufräumet": "aufräumen",
    "aufräumst": "aufräumen",
    "aufräumt": "aufräumen",
    "aufräumte": "aufräumen",
    "aufräumten": "aufräumen",
    "aufräumtest": "aufräumen",
    "aufräumtet": "aufräumen",
    "aufrühre": "aufrühren",
    "aufrührend": "aufrühren",
    "aufrührende": "aufrührend",
    "aufrührendem": "aufrührend",
    "aufrührenden": "aufrührend",
    "aufrührender": "aufrührend",
    "aufrührendere": "aufrührend",
    "aufrührenderem": "aufrührend",
    "aufrührenderen": "aufrührend",
    "aufrührenderer": "aufrührend",
    "aufrührenderes": "aufrührend",
    "aufrührendes": "aufrührend",
    "aufrührendste": "aufrührend",
    "aufrührendstem": "aufrührend",
    "aufrührendsten": "aufrührend",
    "aufrührendster": "aufrührend",
    "aufrührendstes": "aufrührend",
    "aufrührerischem": "aufrührerisch",
    "aufrührerischen": "aufrührerisch",
    "aufrührerischer": "aufrührerisch",
    "aufrührerischere": "aufrührerisch",
    "aufrührerischerem": "aufrührerisch",
    "aufrührerischeren": "aufrührerisch",
    "aufrührerischerer": "aufrührerisch",
    "aufrührerischeres": "aufrührerisch",
    "aufrührerisches": "aufrührerisch",
    "aufrührerischste": "aufrührerisch",
    "aufrührerischstem": "aufrührerisch",
    "aufrührerischsten": "aufrührerisch",
    "aufrührerischster": "aufrührerisch",
    "aufrührerischstes": "aufrührerisch",
    "aufrührest": "aufrühren",
    "aufrühret": "aufrühren",
    "aufrührst": "aufrühren",
    "aufrührt": "aufrühren",
    "aufrührte": "aufrühren",
    "aufrührten": "aufrühren",
    "aufrührtest": "aufrühren",
    "aufrührtet": "aufrühren",
    "aufrüste": "aufrüsten",
    "aufrüstend": "aufrüsten",
    "aufrüstende": "aufrüstend",
    "aufrüstendem": "aufrüstend",
    "aufrüstenden": "aufrüstend",
    "aufrüstender": "aufrüstend",
    "aufrüstendes": "aufrüstend",
    "aufrüstest": "aufrüsten",
    "aufrüstet": "aufrüsten",
    "aufrüstete": "aufrüsten",
    "aufrüsteten": "aufrüsten",
    "aufrüstetest": "aufrüsten",
    "aufrüstetet": "aufrüsten",
    "aufrüttele": "aufrütteln",
    "aufrüttelnd": "aufrütteln",
    "aufrüttelnde": "aufrüttelnd",
    "aufrüttelndem": "aufrüttelnd",
    "aufrüttelnden": "aufrüttelnd",
    "aufrüttelnder": "aufrüttelnd",
    "aufrüttelndes": "aufrüttelnd",
    "aufrüttelst": "aufrütteln",
    "aufrüttelt": "aufrütteln",
    "aufrüttelte": "aufrütteln",
    "aufrüttelten": "aufrütteln",
    "aufrütteltest": "aufrütteln",
    "aufrütteltet": "aufrütteln",
    "aufrüttle": "aufrütteln",
    "aufsage": "aufsagen",
    "aufsagend": "aufsagen",
    "aufsagende": "aufsagend",
    "aufsagendem": "aufsagend",
    "aufsagenden": "aufsagend",
    "aufsagender": "aufsagend",
    "aufsagendes": "aufsagend",
    "aufsagest": "aufsagen",
    "aufsaget": "aufsagen",
    "aufsagst": "aufsagen",
    "aufsagt": "aufsagen",
    "aufsagte": "aufsagen",
    "aufsagten": "aufsagen",
    "aufsagtest": "aufsagen",
    "aufsagtet": "aufsagen",
    "aufsah": "aufsehen",
    "aufsahen": "aufsehen",
    "aufsahst": "aufsehen",
    "aufsaht": "aufsehen",
    "aufsammele": "aufsammeln",
    "aufsammelnd": "aufsammeln",
    "aufsammelnde": "aufsammelnd",
    "aufsammelndem": "aufsammelnd",
    "aufsammelnden": "aufsammelnd",
    "aufsammelnder": "aufsammelnd",
    "aufsammelndes": "aufsammelnd",
    "aufsammelst": "aufsammeln",
    "aufsammelt": "aufsammeln",
    "aufsammelte": "aufsammeln",
    "aufsammelten": "aufsammeln",
    "aufsammeltest": "aufsammeln",
    "aufsammeltet": "aufsammeln",
    "aufsammle": "aufsammeln",
    "aufsauge": "aufsaugen",
    "aufsaugend": "aufsaugen",
    "aufsaugende": "aufsaugend",
    "aufsaugendem": "aufsaugend",
    "aufsaugenden": "aufsaugend",
    "aufsaugender": "aufsaugend",
    "aufsaugendere": "aufsaugend",
    "aufsaugenderem": "aufsaugend",
    "aufsaugenderen": "aufsaugend",
    "aufsaugenderer": "aufsaugend",
    "aufsaugenderes": "aufsaugend",
    "aufsaugendes": "aufsaugend",
    "aufsaugendste": "aufsaugend",
    "aufsaugendstem": "aufsaugend",
    "aufsaugendsten": "aufsaugend",
    "aufsaugendster": "aufsaugend",
    "aufsaugendstes": "aufsaugend",
    "aufsaugest": "aufsaugen",
    "aufsauget": "aufsaugen",
    "aufsaugst": "aufsaugen",
    "aufsaugt": "aufsaugen",
    "aufsaugte": "aufsaugen",
    "aufsaugten": "aufsaugen",
    "aufsaugtest": "aufsaugen",
    "aufsaugtet": "aufsaugen",
    "aufsaß": "aufsitzen",
    "aufsaßen": "aufsitzen",
    "aufsaßt": "aufsitzen",
    "aufschaue": "aufschauen",
    "aufschauend": "aufschauen",
    "aufschauende": "aufschauend",
    "aufschauendem": "aufschauend",
    "aufschauenden": "aufschauend",
    "aufschauender": "aufschauend",
    "aufschauendes": "aufschauend",
    "aufschauest": "aufschauen",
    "aufschauet": "aufschauen",
    "aufschaukele": "aufschaukeln",
    "aufschaukelnd": "aufschaukeln",
    "aufschaukelnde": "aufschaukelnd",
    "aufschaukelndem": "aufschaukelnd",
    "aufschaukelnden": "aufschaukelnd",
    "aufschaukelnder": "aufschaukelnd",
    "aufschaukelndere": "aufschaukelnd",
    "aufschaukelnderem": "aufschaukelnd",
    "aufschaukelnderen": "aufschaukelnd",
    "aufschaukelnderer": "aufschaukelnd",
    "aufschaukelnderes": "aufschaukelnd",
    "aufschaukelndes": "aufschaukelnd",
    "aufschaukelndste": "aufschaukelnd",
    "aufschaukelndstem": "aufschaukelnd",
    "aufschaukelndsten": "aufschaukelnd",
    "aufschaukelndster": "aufschaukelnd",
    "aufschaukelndstes": "aufschaukelnd",
    "aufschaukelst": "aufschaukeln",
    "aufschaukelt": "aufschaukeln",
    "aufschaukelte": "aufschaukeln",
    "aufschaukelten": "aufschaukeln",
    "aufschaukeltest": "aufschaukeln",
    "aufschaukeltet": "aufschaukeln",
    "aufschaukle": "aufschaukeln",
    "aufschaust": "aufschauen",
    "aufschaut": "aufschauen",
    "aufschaute": "aufschauen",
    "aufschauten": "aufschauen",
    "aufschautest": "aufschauen",
    "aufschautet": "aufschauen",
    "aufscheine": "aufscheinen",
    "aufscheinend": "aufscheinen",
    "aufscheinende": "aufscheinend",
    "aufscheinendem": "aufscheinend",
    "aufscheinenden": "aufscheinend",
    "aufscheinender": "aufscheinend",
    "aufscheinendes": "aufscheinend",
    "aufscheinest": "aufscheinen",
    "aufscheinet": "aufscheinen",
    "aufscheinst": "aufscheinen",
    "aufscheint": "aufscheinen",
    "aufscheuche": "aufscheuchen",
    "aufscheuchend": "aufscheuchen",
    "aufscheuchende": "aufscheuchend",
    "aufscheuchendem": "aufscheuchend",
    "aufscheuchenden": "aufscheuchend",
    "aufscheuchender": "aufscheuchend",
    "aufscheuchendere": "aufscheuchend",
    "aufscheuchenderem": "aufscheuchend",
    "aufscheuchenderen": "aufscheuchend",
    "aufscheuchenderer": "aufscheuchend",
    "aufscheuchenderes": "aufscheuchend",
    "aufscheuchendes": "aufscheuchend",
    "aufscheuchendste": "aufscheuchend",
    "aufscheuchendstem": "aufscheuchend",
    "aufscheuchendsten": "aufscheuchend",
    "aufscheuchendster": "aufscheuchend",
    "aufscheuchendstes": "aufscheuchend",
    "aufscheuchest": "aufscheuchen",
    "aufscheuchet": "aufscheuchen",
    "aufscheuchst": "aufscheuchen",
    "aufscheucht": "aufscheuchen",
    "aufscheuchte": "aufscheuchen",
    "aufscheuchten": "aufscheuchen",
    "aufscheuchtest": "aufscheuchen",
    "aufscheuchtet": "aufscheuchen",
    "aufscheuere": "aufscheuern",
    "aufscheuernd": "aufscheuern",
    "aufscheuernde": "aufscheuernd",
    "aufscheuerndem": "aufscheuernd",
    "aufscheuernden": "aufscheuernd",
    "aufscheuernder": "aufscheuernd",
    "aufscheuerndere": "aufscheuernd",
    "aufscheuernderem": "aufscheuernd",
    "aufscheuernderen": "aufscheuernd",
    "aufscheuernderer": "aufscheuernd",
    "aufscheuernderes": "aufscheuernd",
    "aufscheuerndes": "aufscheuernd",
    "aufscheuerndste": "aufscheuernd",
    "aufscheuerndstem": "aufscheuernd",
    "aufscheuerndsten": "aufscheuernd",
    "aufscheuerndster": "aufscheuernd",
    "aufscheuerndstes": "aufscheuernd",
    "aufscheuerst": "aufscheuern",
    "aufscheuert": "aufscheuern",
    "aufscheuerte": "aufscheuern",
    "aufscheuerten": "aufscheuern",
    "aufscheuertest": "aufscheuern",
    "aufscheuertet": "aufscheuern",
    "aufschichte": "aufschichten",
    "aufschichtend": "aufschichten",
    "aufschichtende": "aufschichtend",
    "aufschichtendem": "aufschichtend",
    "aufschichtenden": "aufschichtend",
    "aufschichtender": "aufschichtend",
    "aufschichtendes": "aufschichtend",
    "aufschichtest": "aufschichten",
    "aufschichtet": "aufschichten",
    "aufschichtete": "aufschichten",
    "aufschichteten": "aufschichten",
    "aufschichtetest": "aufschichten",
    "aufschichtetet": "aufschichten",
    "aufschiebe": "aufschieben",
    "aufschiebend": "aufschieben",
    "aufschiebende": "aufschiebend",
    "aufschiebendem": "aufschiebend",
    "aufschiebenden": "aufschiebend",
    "aufschiebender": "aufschiebend",
    "aufschiebendere": "aufschiebend",
    "aufschiebenderem": "aufschiebend",
    "aufschiebenderen": "aufschiebend",
    "aufschiebenderer": "aufschiebend",
    "aufschiebenderes": "aufschiebend",
    "aufschiebendes": "aufschiebend",
    "aufschiebendste": "aufschiebend",
    "aufschiebendstem": "aufschiebend",
    "aufschiebendsten": "aufschiebend",
    "aufschiebendster": "aufschiebend",
    "aufschiebendstes": "aufschiebend",
    "aufschiebest": "aufschieben",
    "aufschiebet": "aufschieben",
    "aufschiebst": "aufschieben",
    "aufschiebt": "aufschieben",
    "aufschien": "aufscheinen",
    "aufschiene": "aufscheinen",
    "aufschienen": "aufscheinen",
    "aufschienest": "aufscheinen",
    "aufschienet": "aufscheinen",
    "aufschienst": "aufscheinen",
    "aufschient": "aufscheinen",
    "aufschieße": "aufschießen",
    "aufschießend": "aufschießen",
    "aufschießende": "aufschießend",
    "aufschießendem": "aufschießend",
    "aufschießenden": "aufschießend",
    "aufschießender": "aufschießend",
    "aufschießendes": "aufschießend",
    "aufschießest": "aufschießen",
    "aufschießet": "aufschießen",
    "aufschießt": "aufschießen",
    "aufschinde": "aufschinden",
    "aufschindend": "aufschinden",
    "aufschindende": "aufschindend",
    "aufschindendem": "aufschindend",
    "aufschindenden": "aufschindend",
    "aufschindender": "aufschindend",
    "aufschindendes": "aufschindend",
    "aufschindest": "aufschinden",
    "aufschindet": "aufschinden",
    "aufschindete": "aufschinden",
    "aufschindeten": "aufschinden",
    "aufschindetest": "aufschinden",
    "aufschindetet": "aufschinden",
    "aufschlagend": "aufschlagen",
    "aufschlagende": "aufschlagend",
    "aufschlagendem": "aufschlagend",
    "aufschlagenden": "aufschlagend",
    "aufschlagender": "aufschlagend",
    "aufschlagendes": "aufschlagend",
    "aufschlagest": "aufschlagen",
    "aufschlaget": "aufschlagen",
    "aufschlagt": "aufschlagen",
    "aufschließe": "aufschließen",
    "aufschließend": "aufschließen",
    "aufschließende": "aufschließend",
    "aufschließendem": "aufschließend",
    "aufschließenden": "aufschließend",
    "aufschließender": "aufschließend",
    "aufschließendes": "aufschließend",
    "aufschließest": "aufschließen",
    "aufschließet": "aufschließen",
    "aufschließt": "aufschließen",
    "aufschlitze": "aufschlitzen",
    "aufschlitzend": "aufschlitzen",
    "aufschlitzende": "aufschlitzend",
    "aufschlitzendem": "aufschlitzend",
    "aufschlitzenden": "aufschlitzend",
    "aufschlitzender": "aufschlitzend",
    "aufschlitzendere": "aufschlitzend",
    "aufschlitzenderem": "aufschlitzend",
    "aufschlitzenderen": "aufschlitzend",
    "aufschlitzenderer": "aufschlitzend",
    "aufschlitzenderes": "aufschlitzend",
    "aufschlitzendes": "aufschlitzend",
    "aufschlitzendste": "aufschlitzend",
    "aufschlitzendstem": "aufschlitzend",
    "aufschlitzendsten": "aufschlitzend",
    "aufschlitzendster": "aufschlitzend",
    "aufschlitzendstes": "aufschlitzend",
    "aufschlitzest": "aufschlitzen",
    "aufschlitzet": "aufschlitzen",
    "aufschlitzt": "aufschlitzen",
    "aufschlitzte": "aufschlitzen",
    "aufschlitzten": "aufschlitzen",
    "aufschlitztest": "aufschlitzen",
    "aufschlitztet": "aufschlitzen",
    "aufschlossen": "aufschließen",
    "aufschloß": "aufschließen",
    "aufschloßt": "aufschließen",
    "aufschluchze": "aufschluchzen",
    "aufschluchzend": "aufschluchzen",
    "aufschluchzende": "aufschluchzend",
    "aufschluchzendem": "aufschluchzend",
    "aufschluchzenden": "aufschluchzend",
    "aufschluchzender": "aufschluchzend",
    "aufschluchzendes": "aufschluchzend",
    "aufschluchzest": "aufschluchzen",
    "aufschluchzet": "aufschluchzen",
    "aufschluchzt": "aufschluchzen",
    "aufschluchzte": "aufschluchzen",
    "aufschluchzten": "aufschluchzen",
    "aufschluchztest": "aufschluchzen",
    "aufschluchztet": "aufschluchzen",
    "aufschlug": "aufschlagen",
    "aufschlugen": "aufschlagen",
    "aufschlugst": "aufschlagen",
    "aufschlugt": "aufschlagen",
    "aufschlußreiche": "aufschlußreich",
    "aufschlußreichem": "aufschlußreich",
    "aufschlußreichen": "aufschlußreich",
    "aufschlußreicher": "aufschlußreich",
    "aufschlußreichere": "aufschlußreich",
    "aufschlußreicherem": "aufschlußreich",
    "aufschlußreicheren": "aufschlußreich",
    "aufschlußreicherer": "aufschlußreich",
    "aufschlußreicheres": "aufschlußreich",
    "aufschlußreiches": "aufschlußreich",
    "aufschlußreichste": "aufschlußreich",
    "aufschlußreichstem": "aufschlußreich",
    "aufschlußreichsten": "aufschlußreich",
    "aufschlußreichster": "aufschlußreich",
    "aufschlußreichstes": "aufschlußreich",
    "aufschlägst": "aufschlagen",
    "aufschlägt": "aufschlagen",
    "aufschlämme": "aufschlämmen",
    "aufschlämmend": "aufschlämmen",
    "aufschlämmende": "aufschlämmend",
    "aufschlämmendem": "aufschlämmend",
    "aufschlämmenden": "aufschlämmend",
    "aufschlämmender": "aufschlämmend",
    "aufschlämmendes": "aufschlämmend",
    "aufschlämmest": "aufschlämmen",
    "aufschlämmet": "aufschlämmen",
    "aufschlämmst": "aufschlämmen",
    "aufschlämmt": "aufschlämmen",
    "aufschlämmte": "aufschlämmen",
    "aufschlämmten": "aufschlämmen",
    "aufschlämmtest": "aufschlämmen",
    "aufschlämmtet": "aufschlämmen",
    "aufschlösse": "aufschließen",
    "aufschlössen": "aufschließen",
    "aufschlössest": "aufschließen",
    "aufschlösset": "aufschließen",
    "aufschlüge": "aufschlagen",
    "aufschlügen": "aufschlagen",
    "aufschlügest": "aufschlagen",
    "aufschlüget": "aufschlagen",
    "aufschlüssele": "aufschlüsseln",
    "aufschlüsselnd": "aufschlüsseln",
    "aufschlüsselnde": "aufschlüsselnd",
    "aufschlüsselndem": "aufschlüsselnd",
    "aufschlüsselnden": "aufschlüsselnd",
    "aufschlüsselnder": "aufschlüsselnd",
    "aufschlüsselndere": "aufschlüsselnd",
    "aufschlüsselnderem": "aufschlüsselnd",
    "aufschlüsselnderen": "aufschlüsselnd",
    "aufschlüsselnderer": "aufschlüsselnd",
    "aufschlüsselnderes": "aufschlüsselnd",
    "aufschlüsselndes": "aufschlüsselnd",
    "aufschlüsselndste": "aufschlüsselnd",
    "aufschlüsselndstem": "aufschlüsselnd",
    "aufschlüsselndsten": "aufschlüsselnd",
    "aufschlüsselndster": "aufschlüsselnd",
    "aufschlüsselndstes": "aufschlüsselnd",
    "aufschlüsselst": "aufschlüsseln",
    "aufschlüsselt": "aufschlüsseln",
    "aufschlüsselte": "aufschlüsseln",
    "aufschlüsselten": "aufschlüsseln",
    "aufschlüsseltest": "aufschlüsseln",
    "aufschlüsseltet": "aufschlüsseln",
    "aufschlüssle": "aufschlüsseln",
    "aufschmeiße": "aufschmeißen",
    "aufschmeißend": "aufschmeißen",
    "aufschmeißende": "aufschmeißend",
    "aufschmeißendem": "aufschmeißend",
    "aufschmeißenden": "aufschmeißend",
    "aufschmeißender": "aufschmeißend",
    "aufschmeißendes": "aufschmeißend",
    "aufschmeißest": "aufschmeißen",
    "aufschmeißet": "aufschmeißen",
    "aufschmeißt": "aufschmeißen",
    "aufschmisse": "aufschmeißen",
    "aufschmissen": "aufschmeißen",
    "aufschmissest": "aufschmeißen",
    "aufschmisset": "aufschmeißen",
    "aufschmiß": "aufschmeißen",
    "aufschmißt": "aufschmeißen",
    "aufschnalle": "aufschnallen",
    "aufschnallend": "aufschnallen",
    "aufschnallende": "aufschnallend",
    "aufschnallendem": "aufschnallend",
    "aufschnallenden": "aufschnallend",
    "aufschnallender": "aufschnallend",
    "aufschnallendes": "aufschnallend",
    "aufschnallest": "aufschnallen",
    "aufschnallet": "aufschnallen",
    "aufschnallst": "aufschnallen",
    "aufschnallt": "aufschnallen",
    "aufschnallte": "aufschnallen",
    "aufschnallten": "aufschnallen",
    "aufschnalltest": "aufschnallen",
    "aufschnalltet": "aufschnallen",
    "aufschnappe": "aufschnappen",
    "aufschnappend": "aufschnappen",
    "aufschnappende": "aufschnappend",
    "aufschnappendem": "aufschnappend",
    "aufschnappenden": "aufschnappend",
    "aufschnappender": "aufschnappend",
    "aufschnappendes": "aufschnappend",
    "aufschnappest": "aufschnappen",
    "aufschnappet": "aufschnappen",
    "aufschnappst": "aufschnappen",
    "aufschnappt": "aufschnappen",
    "aufschnappte": "aufschnappen",
    "aufschnappten": "aufschnappen",
    "aufschnapptest": "aufschnappen",
    "aufschnapptet": "aufschnappen",
    "aufschneide": "aufschneiden",
    "aufschneidend": "aufschneiden",
    "aufschneidende": "aufschneidend",
    "aufschneidendem": "aufschneidend",
    "aufschneidenden": "aufschneidend",
    "aufschneidender": "aufschneidend",
    "aufschneidendes": "aufschneidend",
    "aufschneiderischem": "aufschneiderisch",
    "aufschneiderischen": "aufschneiderisch",
    "aufschneiderischer": "aufschneiderisch",
    "aufschneiderischere": "aufschneiderisch",
    "aufschneiderischerem": "aufschneiderisch",
    "aufschneiderischeren": "aufschneiderisch",
    "aufschneiderischerer": "aufschneiderisch",
    "aufschneiderischeres": "aufschneiderisch",
    "aufschneiderisches": "aufschneiderisch",
    "aufschneiderischste": "aufschneiderisch",
    "aufschneiderischstem": "aufschneiderisch",
    "aufschneiderischsten": "aufschneiderisch",
    "aufschneiderischster": "aufschneiderisch",
    "aufschneiderischstes": "aufschneiderisch",
    "aufschneidest": "aufschneiden",
    "aufschneidet": "aufschneiden",
    "aufschnelle": "aufschnellen",
    "aufschnellend": "aufschnellen",
    "aufschnellende": "aufschnellend",
    "aufschnellendem": "aufschnellend",
    "aufschnellenden": "aufschnellend",
    "aufschnellender": "aufschnellend",
    "aufschnellendes": "aufschnellend",
    "aufschnellest": "aufschnellen",
    "aufschnellet": "aufschnellen",
    "aufschnellst": "aufschnellen",
    "aufschnellt": "aufschnellen",
    "aufschnellte": "aufschnellen",
    "aufschnellten": "aufschnellen",
    "aufschnelltest": "aufschnellen",
    "aufschnelltet": "aufschnellen",
    "aufschnitt": "aufschneiden",
    "aufschnitte": "aufschneiden",
    "aufschnitten": "aufschneiden",
    "aufschnittest": "aufschneiden",
    "aufschnittet": "aufschneiden",
    "aufschnüre": "aufschnüren",
    "aufschnürend": "aufschnüren",
    "aufschnürende": "aufschnürend",
    "aufschnürendem": "aufschnürend",
    "aufschnürenden": "aufschnürend",
    "aufschnürender": "aufschnürend",
    "aufschnürendes": "aufschnürend",
    "aufschnürest": "aufschnüren",
    "aufschnüret": "aufschnüren",
    "aufschnürst": "aufschnüren",
    "aufschnürt": "aufschnüren",
    "aufschnürte": "aufschnüren",
    "aufschnürten": "aufschnüren",
    "aufschnürtest": "aufschnüren",
    "aufschnürtet": "aufschnüren",
    "aufschob": "aufschieben",
    "aufschoben": "aufschieben",
    "aufschobst": "aufschieben",
    "aufschobt": "aufschieben",
    "aufschossen": "aufschießen",
    "aufschoß": "aufschießen",
    "aufschoßt": "aufschießen",
    "aufschrak": "aufschrecken",
    "aufschraken": "aufschrecken",
    "aufschrakst": "aufschrecken",
    "aufschrakt": "aufschrecken",
    "aufschraube": "aufschrauben",
    "aufschraubend": "aufschrauben",
    "aufschraubende": "aufschraubend",
    "aufschraubendem": "aufschraubend",
    "aufschraubenden": "aufschraubend",
    "aufschraubender": "aufschraubend",
    "aufschraubendes": "aufschraubend",
    "aufschraubest": "aufschrauben",
    "aufschraubet": "aufschrauben",
    "aufschraubst": "aufschrauben",
    "aufschraubt": "aufschrauben",
    "aufschraubte": "aufschrauben",
    "aufschraubten": "aufschrauben",
    "aufschraubtest": "aufschrauben",
    "aufschraubtet": "aufschrauben",
    "aufschrecke": "aufschrecken",
    "aufschreckend": "aufschrecken",
    "aufschreckende": "aufschreckend",
    "aufschreckendem": "aufschreckend",
    "aufschreckenden": "aufschreckend",
    "aufschreckender": "aufschreckend",
    "aufschreckendere": "aufschreckend",
    "aufschreckenderem": "aufschreckend",
    "aufschreckenderen": "aufschreckend",
    "aufschreckenderer": "aufschreckend",
    "aufschreckenderes": "aufschreckend",
    "aufschreckendes": "aufschreckend",
    "aufschreckendste": "aufschreckend",
    "aufschreckendstem": "aufschreckend",
    "aufschreckendsten": "aufschreckend",
    "aufschreckendster": "aufschreckend",
    "aufschreckendstes": "aufschreckend",
    "aufschreckest": "aufschrecken",
    "aufschrecket": "aufschrecken",
    "aufschreckst": "aufschrecken",
    "aufschreckt": "aufschrecken",
    "aufschreckte": "aufschrecken",
    "aufschreckten": "aufschrecken",
    "aufschrecktest": "aufschrecken",
    "aufschrecktet": "aufschrecken",
    "aufschreibe": "aufschreiben",
    "aufschreibend": "aufschreiben",
    "aufschreibende": "aufschreibend",
    "aufschreibendem": "aufschreibend",
    "aufschreibenden": "aufschreibend",
    "aufschreibender": "aufschreibend",
    "aufschreibendes": "aufschreibend",
    "aufschreibest": "aufschreiben",
    "aufschreibet": "aufschreiben",
    "aufschreibst": "aufschreiben",
    "aufschreibt": "aufschreiben",
    "aufschreiend": "aufschreien",
    "aufschreiende": "aufschreiend",
    "aufschreiendem": "aufschreiend",
    "aufschreienden": "aufschreiend",
    "aufschreiender": "aufschreiend",
    "aufschreiendere": "aufschreiend",
    "aufschreienderem": "aufschreiend",
    "aufschreienderen": "aufschreiend",
    "aufschreienderer": "aufschreiend",
    "aufschreienderes": "aufschreiend",
    "aufschreiendes": "aufschreiend",
    "aufschreiendste": "aufschreiend",
    "aufschreiendstem": "aufschreiend",
    "aufschreiendsten": "aufschreiend",
    "aufschreiendster": "aufschreiend",
    "aufschreiendstes": "aufschreiend",
    "aufschreiest": "aufschreien",
    "aufschreiet": "aufschreien",
    "aufschreist": "aufschreien",
    "aufschreit": "aufschreien",
    "aufschrickst": "aufschrecken",
    "aufschrickt": "aufschrecken",
    "aufschrie": "aufschreien",
    "aufschrieb": "aufschreiben",
    "aufschriebe": "aufschreiben",
    "aufschrieben": "aufschreiben",
    "aufschriebest": "aufschreiben",
    "aufschriebet": "aufschreiben",
    "aufschriebst": "aufschreiben",
    "aufschriebt": "aufschreiben",
    "aufschriee": "aufschreien",
    "aufschrieen": "aufschreien",
    "aufschrieest": "aufschreien",
    "aufschrieet": "aufschreien",
    "aufschrien": "aufschreien",
    "aufschriest": "aufschreien",
    "aufschriet": "aufschreien",
    "aufschrumpfe": "aufschrumpfen",
    "aufschrumpfend": "aufschrumpfen",
    "aufschrumpfende": "aufschrumpfend",
    "aufschrumpfendem": "aufschrumpfend",
    "aufschrumpfenden": "aufschrumpfend",
    "aufschrumpfender": "aufschrumpfend",
    "aufschrumpfendes": "aufschrumpfend",
    "aufschrumpfest": "aufschrumpfen",
    "aufschrumpfet": "aufschrumpfen",
    "aufschrumpfst": "aufschrumpfen",
    "aufschrumpft": "aufschrumpfen",
    "aufschrumpfte": "aufschrumpfen",
    "aufschrumpften": "aufschrumpfen",
    "aufschrumpftest": "aufschrumpfen",
    "aufschrumpftet": "aufschrumpfen",
    "aufschräke": "aufschrecken",
    "aufschräken": "aufschrecken",
    "aufschräkest": "aufschrecken",
    "aufschräket": "aufschrecken",
    "aufschwang": "aufschwingen",
    "aufschwangen": "aufschwingen",
    "aufschwangst": "aufschwingen",
    "aufschwangt": "aufschwingen",
    "aufschwatze": "aufschwatzen",
    "aufschwatzend": "aufschwatzen",
    "aufschwatzende": "aufschwatzend",
    "aufschwatzendem": "aufschwatzend",
    "aufschwatzenden": "aufschwatzend",
    "aufschwatzender": "aufschwatzend",
    "aufschwatzendere": "aufschwatzend",
    "aufschwatzenderem": "aufschwatzend",
    "aufschwatzenderen": "aufschwatzend",
    "aufschwatzenderer": "aufschwatzend",
    "aufschwatzenderes": "aufschwatzend",
    "aufschwatzendes": "aufschwatzend",
    "aufschwatzendste": "aufschwatzend",
    "aufschwatzendstem": "aufschwatzend",
    "aufschwatzendsten": "aufschwatzend",
    "aufschwatzendster": "aufschwatzend",
    "aufschwatzendstes": "aufschwatzend",
    "aufschwatzest": "aufschwatzen",
    "aufschwatzet": "aufschwatzen",
    "aufschwatzt": "aufschwatzen",
    "aufschwatzte": "aufschwatzen",
    "aufschwatzten": "aufschwatzen",
    "aufschwatztest": "aufschwatzen",
    "aufschwatztet": "aufschwatzen",
    "aufschwemme": "aufschwemmen",
    "aufschwemmend": "aufschwemmen",
    "aufschwemmende": "aufschwemmend",
    "aufschwemmendem": "aufschwemmend",
    "aufschwemmenden": "aufschwemmend",
    "aufschwemmender": "aufschwemmend",
    "aufschwemmendes": "aufschwemmend",
    "aufschwemmest": "aufschwemmen",
    "aufschwemmet": "aufschwemmen",
    "aufschwemmst": "aufschwemmen",
    "aufschwemmt": "aufschwemmen",
    "aufschwemmte": "aufschwemmen",
    "aufschwemmten": "aufschwemmen",
    "aufschwemmtest": "aufschwemmen",
    "aufschwemmtet": "aufschwemmen",
    "aufschwinge": "aufschwingen",
    "aufschwingend": "aufschwingen",
    "aufschwingende": "aufschwingend",
    "aufschwingendem": "aufschwingend",
    "aufschwingenden": "aufschwingend",
    "aufschwingender": "aufschwingend",
    "aufschwingendes": "aufschwingend",
    "aufschwingest": "aufschwingen",
    "aufschwinget": "aufschwingen",
    "aufschwingst": "aufschwingen",
    "aufschwingt": "aufschwingen",
    "aufschwänge": "aufschwingen",
    "aufschwängen": "aufschwingen",
    "aufschwängest": "aufschwingen",
    "aufschwänget": "aufschwingen",
    "aufschöbe": "aufschieben",
    "aufschöben": "aufschieben",
    "aufschöbest": "aufschieben",
    "aufschöbet": "aufschieben",
    "aufschösse": "aufschießen",
    "aufschössen": "aufschießen",
    "aufschössest": "aufschießen",
    "aufschösset": "aufschießen",
    "aufschürfe": "aufschürfen",
    "aufschürfend": "aufschürfen",
    "aufschürfende": "aufschürfend",
    "aufschürfendem": "aufschürfend",
    "aufschürfenden": "aufschürfend",
    "aufschürfender": "aufschürfend",
    "aufschürfendere": "aufschürfend",
    "aufschürfenderem": "aufschürfend",
    "aufschürfenderen": "aufschürfend",
    "aufschürfenderer": "aufschürfend",
    "aufschürfenderes": "aufschürfend",
    "aufschürfendes": "aufschürfend",
    "aufschürfendste": "aufschürfend",
    "aufschürfendstem": "aufschürfend",
    "aufschürfendsten": "aufschürfend",
    "aufschürfendster": "aufschürfend",
    "aufschürfendstes": "aufschürfend",
    "aufschürfest": "aufschürfen",
    "aufschürfet": "aufschürfen",
    "aufschürfst": "aufschürfen",
    "aufschürft": "aufschürfen",
    "aufschürfte": "aufschürfen",
    "aufschürften": "aufschürfen",
    "aufschürftest": "aufschürfen",
    "aufschürftet": "aufschürfen",
    "aufschütte": "aufschütten",
    "aufschüttele": "aufschütteln",
    "aufschüttelnd": "aufschütteln",
    "aufschüttelnde": "aufschüttelnd",
    "aufschüttelndem": "aufschüttelnd",
    "aufschüttelnden": "aufschüttelnd",
    "aufschüttelnder": "aufschüttelnd",
    "aufschüttelndere": "aufschüttelnd",
    "aufschüttelnderem": "aufschüttelnd",
    "aufschüttelnderen": "aufschüttelnd",
    "aufschüttelnderer": "aufschüttelnd",
    "aufschüttelnderes": "aufschüttelnd",
    "aufschüttelndes": "aufschüttelnd",
    "aufschüttelndste": "aufschüttelnd",
    "aufschüttelndstem": "aufschüttelnd",
    "aufschüttelndsten": "aufschüttelnd",
    "aufschüttelndster": "aufschüttelnd",
    "aufschüttelndstes": "aufschüttelnd",
    "aufschüttelst": "aufschütteln",
    "aufschüttelt": "aufschütteln",
    "aufschüttelte": "aufschütteln",
    "aufschüttelten": "aufschütteln",
    "aufschütteltest": "aufschütteln",
    "aufschütteltet": "aufschütteln",
    "aufschüttend": "aufschütten",
    "aufschüttende": "aufschüttend",
    "aufschüttendem": "aufschüttend",
    "aufschüttenden": "aufschüttend",
    "aufschüttender": "aufschüttend",
    "aufschüttendes": "aufschüttend",
    "aufschüttest": "aufschütten",
    "aufschüttet": "aufschütten",
    "aufschüttete": "aufschütten",
    "aufschütteten": "aufschütten",
    "aufschüttetest": "aufschütten",
    "aufschüttetet": "aufschütten",
    "aufschüttle": "aufschütteln",
    "aufsehe": "aufsehen",
    "aufsehend": "aufsehen",
    "aufsehende": "aufsehend",
    "aufsehendem": "aufsehend",
    "aufsehenden": "aufsehend",
    "aufsehender": "aufsehend",
    "aufsehendes": "aufsehend",
    "aufsehenerregende": "aufsehenerregend",
    "aufsehenerregendem": "aufsehenerregend",
    "aufsehenerregenden": "aufsehenerregend",
    "aufsehenerregender": "aufsehenerregend",
    "aufsehenerregendere": "aufsehenerregend",
    "aufsehenerregenderem": "aufsehenerregend",
    "aufsehenerregenderen": "aufsehenerregend",
    "aufsehenerregenderer": "aufsehenerregend",
    "aufsehenerregenderes": "aufsehenerregend",
    "aufsehenerregendes": "aufsehenerregend",
    "aufsehenerregendste": "aufsehenerregend",
    "aufsehenerregendstem": "aufsehenerregend",
    "aufsehenerregendsten": "aufsehenerregend",
    "aufsehenerregendster": "aufsehenerregend",
    "aufsehenerregendstes": "aufsehenerregend",
    "aufsehest": "aufsehen",
    "aufsehet": "aufsehen",
    "aufseht": "aufsehen",
    "aufsetze": "aufsetzen",
    "aufsetzend": "aufsetzen",
    "aufsetzende": "aufsetzend",
    "aufsetzendem": "aufsetzend",
    "aufsetzenden": "aufsetzend",
    "aufsetzender": "aufsetzend",
    "aufsetzendes": "aufsetzend",
    "aufsetzest": "aufsetzen",
    "aufsetzet": "aufsetzen",
    "aufsetzt": "aufsetzen",
    "aufsetzte": "aufsetzen",
    "aufsetzten": "aufsetzen",
    "aufsetztest": "aufsetzen",
    "aufsetztet": "aufsetzen",
    "aufseufze": "aufseufzen",
    "aufseufzend": "aufseufzen",
    "aufseufzende": "aufseufzend",
    "aufseufzendem": "aufseufzend",
    "aufseufzenden": "aufseufzend",
    "aufseufzender": "aufseufzend",
    "aufseufzendere": "aufseufzend",
    "aufseufzenderem": "aufseufzend",
    "aufseufzenderen": "aufseufzend",
    "aufseufzenderer": "aufseufzend",
    "aufseufzenderes": "aufseufzend",
    "aufseufzendes": "aufseufzend",
    "aufseufzendste": "aufseufzend",
    "aufseufzendstem": "aufseufzend",
    "aufseufzendsten": "aufseufzend",
    "aufseufzendster": "aufseufzend",
    "aufseufzendstes": "aufseufzend",
    "aufseufzest": "aufseufzen",
    "aufseufzet": "aufseufzen",
    "aufseufzt": "aufseufzen",
    "aufseufzte": "aufseufzen",
    "aufseufzten": "aufseufzen",
    "aufseufztest": "aufseufzen",
    "aufseufztet": "aufseufzen",
    "aufsiehst": "aufsehen",
    "aufsieht": "aufsehen",
    "aufsitze": "aufsitzen",
    "aufsitzend": "aufsitzen",
    "aufsitzende": "aufsitzend",
    "aufsitzendem": "aufsitzend",
    "aufsitzenden": "aufsitzend",
    "aufsitzender": "aufsitzend",
    "aufsitzendes": "aufsitzend",
    "aufsitzest": "aufsitzen",
    "aufsitzet": "aufsitzen",
    "aufsitzt": "aufsitzen",
    "aufsog": "aufsaugen",
    "aufsogen": "aufsaugen",
    "aufsogst": "aufsaugen",
    "aufsogt": "aufsaugen",
    "aufspalte": "aufspalten",
    "aufspaltend": "aufspalten",
    "aufspaltende": "aufspaltend",
    "aufspaltendem": "aufspaltend",
    "aufspaltenden": "aufspaltend",
    "aufspaltender": "aufspaltend",
    "aufspaltendere": "aufspaltend",
    "aufspaltenderem": "aufspaltend",
    "aufspaltenderen": "aufspaltend",
    "aufspaltenderer": "aufspaltend",
    "aufspaltenderes": "aufspaltend",
    "aufspaltendes": "aufspaltend",
    "aufspaltendste": "aufspaltend",
    "aufspaltendstem": "aufspaltend",
    "aufspaltendsten": "aufspaltend",
    "aufspaltendster": "aufspaltend",
    "aufspaltendstes": "aufspaltend",
    "aufspaltest": "aufspalten",
    "aufspaltet": "aufspalten",
    "aufspaltete": "aufspalten",
    "aufspalteten": "aufspalten",
    "aufspaltetest": "aufspalten",
    "aufspaltetet": "aufspalten",
    "aufspann": "aufspinnen",
    "aufspannen": "aufspinnen",
    "aufspannst": "aufspinnen",
    "aufspannt": "aufspinnen",
    "aufspare": "aufsparen",
    "aufsparend": "aufsparen",
    "aufsparende": "aufsparend",
    "aufsparendem": "aufsparend",
    "aufsparenden": "aufsparend",
    "aufsparender": "aufsparend",
    "aufsparendere": "aufsparend",
    "aufsparenderem": "aufsparend",
    "aufsparenderen": "aufsparend",
    "aufsparenderer": "aufsparend",
    "aufsparenderes": "aufsparend",
    "aufsparendes": "aufsparend",
    "aufsparendste": "aufsparend",
    "aufsparendstem": "aufsparend",
    "aufsparendsten": "aufsparend",
    "aufsparendster": "aufsparend",
    "aufsparendstes": "aufsparend",
    "aufsparest": "aufsparen",
    "aufsparet": "aufsparen",
    "aufsparst": "aufsparen",
    "aufspart": "aufsparen",
    "aufsparte": "aufsparen",
    "aufsparten": "aufsparen",
    "aufspartest": "aufsparen",
    "aufspartet": "aufsparen",
    "aufspeichere": "aufspeichern",
    "aufspeichernd": "aufspeichern",
    "aufspeichernde": "aufspeichernd",
    "aufspeicherndem": "aufspeichernd",
    "aufspeichernden": "aufspeichernd",
    "aufspeichernder": "aufspeichernd",
    "aufspeicherndes": "aufspeichernd",
    "aufspeicherst": "aufspeichern",
    "aufspeichert": "aufspeichern",
    "aufspeicherte": "aufspeichern",
    "aufspeicherten": "aufspeichern",
    "aufspeichertest": "aufspeichern",
    "aufspeichertet": "aufspeichern",
    "aufsperre": "aufsperren",
    "aufsperrend": "aufsperren",
    "aufsperrende": "aufsperrend",
    "aufsperrendem": "aufsperrend",
    "aufsperrenden": "aufsperrend",
    "aufsperrender": "aufsperrend",
    "aufsperrendes": "aufsperrend",
    "aufsperrest": "aufsperren",
    "aufsperret": "aufsperren",
    "aufsperrst": "aufsperren",
    "aufsperrt": "aufsperren",
    "aufsperrte": "aufsperren",
    "aufsperrten": "aufsperren",
    "aufsperrtest": "aufsperren",
    "aufsperrtet": "aufsperren",
    "aufspiele": "aufspielen",
    "aufspielend": "aufspielen",
    "aufspielende": "aufspielend",
    "aufspielendem": "aufspielend",
    "aufspielenden": "aufspielend",
    "aufspielender": "aufspielend",
    "aufspielendes": "aufspielend",
    "aufspielest": "aufspielen",
    "aufspielet": "aufspielen",
    "aufspielst": "aufspielen",
    "aufspielt": "aufspielen",
    "aufspielte": "aufspielen",
    "aufspielten": "aufspielen",
    "aufspieltest": "aufspielen",
    "aufspieltet": "aufspielen",
    "aufspieße": "aufspießen",
    "aufspießend": "aufspießen",
    "aufspießende": "aufspießend",
    "aufspießendem": "aufspießend",
    "aufspießenden": "aufspießend",
    "aufspießender": "aufspießend",
    "aufspießendes": "aufspießend",
    "aufspießest": "aufspießen",
    "aufspießet": "aufspießen",
    "aufspießt": "aufspießen",
    "aufspießte": "aufspießen",
    "aufspießten": "aufspießen",
    "aufspießtest": "aufspießen",
    "aufspießtet": "aufspießen",
    "aufspinne": "aufspinnen",
    "aufspinnend": "aufspinnen",
    "aufspinnende": "aufspinnend",
    "aufspinnendem": "aufspinnend",
    "aufspinnenden": "aufspinnend",
    "aufspinnender": "aufspinnend",
    "aufspinnendes": "aufspinnend",
    "aufspinnest": "aufspinnen",
    "aufspinnet": "aufspinnen",
    "aufspinnst": "aufspinnen",
    "aufspinnt": "aufspinnen",
    "aufsprang": "aufspringen",
    "aufsprangen": "aufspringen",
    "aufsprangst": "aufspringen",
    "aufsprangt": "aufspringen",
    "aufsprenge": "aufsprengen",
    "aufsprengend": "aufsprengen",
    "aufsprengende": "aufsprengend",
    "aufsprengendem": "aufsprengend",
    "aufsprengenden": "aufsprengend",
    "aufsprengender": "aufsprengend",
    "aufsprengendes": "aufsprengend",
    "aufsprengest": "aufsprengen",
    "aufsprenget": "aufsprengen",
    "aufsprengst": "aufsprengen",
    "aufsprengt": "aufsprengen",
    "aufsprengte": "aufsprengen",
    "aufsprengten": "aufsprengen",
    "aufsprengtest": "aufsprengen",
    "aufsprengtet": "aufsprengen",
    "aufspringe": "aufspringen",
    "aufspringend": "aufspringen",
    "aufspringende": "aufspringend",
    "aufspringendem": "aufspringend",
    "aufspringenden": "aufspringend",
    "aufspringender": "aufspringend",
    "aufspringendes": "aufspringend",
    "aufspringest": "aufspringen",
    "aufspringet": "aufspringen",
    "aufspringst": "aufspringen",
    "aufspringt": "aufspringen",
    "aufspritze": "aufspritzen",
    "aufspritzend": "aufspritzen",
    "aufspritzende": "aufspritzend",
    "aufspritzendem": "aufspritzend",
    "aufspritzenden": "aufspritzend",
    "aufspritzender": "aufspritzend",
    "aufspritzendes": "aufspritzend",
    "aufspritzest": "aufspritzen",
    "aufspritzet": "aufspritzen",
    "aufspritzt": "aufspritzen",
    "aufspritzte": "aufspritzen",
    "aufspritzten": "aufspritzen",
    "aufspritztest": "aufspritzen",
    "aufspritztet": "aufspritzen",
    "aufspränge": "aufspringen",
    "aufsprängen": "aufspringen",
    "aufsprängest": "aufspringen",
    "aufspränget": "aufspringen",
    "aufspule": "aufspulen",
    "aufspulend": "aufspulen",
    "aufspulende": "aufspulend",
    "aufspulendem": "aufspulend",
    "aufspulenden": "aufspulend",
    "aufspulender": "aufspulend",
    "aufspulendes": "aufspulend",
    "aufspulest": "aufspulen",
    "aufspulet": "aufspulen",
    "aufspulst": "aufspulen",
    "aufspult": "aufspulen",
    "aufspulte": "aufspulen",
    "aufspulten": "aufspulen",
    "aufspultest": "aufspulen",
    "aufspultet": "aufspulen",
    "aufspänne": "aufspinnen",
    "aufspännen": "aufspinnen",
    "aufspännest": "aufspinnen",
    "aufspännet": "aufspinnen",
    "aufspüre": "aufspüren",
    "aufspürend": "aufspüren",
    "aufspürende": "aufspürend",
    "aufspürendem": "aufspürend",
    "aufspürenden": "aufspürend",
    "aufspürender": "aufspürend",
    "aufspürendes": "aufspürend",
    "aufspürest": "aufspüren",
    "aufspüret": "aufspüren",
    "aufspürst": "aufspüren",
    "aufspürt": "aufspüren",
    "aufspürte": "aufspüren",
    "aufspürten": "aufspüren",
    "aufspürtest": "aufspüren",
    "aufspürtet": "aufspüren",
    "aufstach": "aufstechen",
    "aufstachele": "aufstacheln",
    "aufstachelnd": "aufstacheln",
    "aufstachelnde": "aufstachelnd",
    "aufstachelndem": "aufstachelnd",
    "aufstachelnden": "aufstachelnd",
    "aufstachelnder": "aufstachelnd",
    "aufstachelndes": "aufstachelnd",
    "aufstachelst": "aufstacheln",
    "aufstachelt": "aufstacheln",
    "aufstachelte": "aufstacheln",
    "aufstachelten": "aufstacheln",
    "aufstacheltest": "aufstacheln",
    "aufstacheltet": "aufstacheln",
    "aufstachen": "aufstechen",
    "aufstachle": "aufstacheln",
    "aufstachst": "aufstechen",
    "aufstacht": "aufstechen",
    "aufstampfe": "aufstampfen",
    "aufstampfend": "aufstampfen",
    "aufstampfende": "aufstampfend",
    "aufstampfendem": "aufstampfend",
    "aufstampfenden": "aufstampfend",
    "aufstampfender": "aufstampfend",
    "aufstampfendes": "aufstampfend",
    "aufstampfest": "aufstampfen",
    "aufstampfet": "aufstampfen",
    "aufstampfst": "aufstampfen",
    "aufstampft": "aufstampfen",
    "aufstampfte": "aufstampfen",
    "aufstampften": "aufstampfen",
    "aufstampftest": "aufstampfen",
    "aufstampftet": "aufstampfen",
    "aufstand": "aufstehen",
    "aufstanden": "aufstehen",
    "aufstandest": "aufstehen",
    "aufstandet": "aufstehen",
    "aufstapele": "aufstapeln",
    "aufstapelnd": "aufstapeln",
    "aufstapelnde": "aufstapelnd",
    "aufstapelndem": "aufstapelnd",
    "aufstapelnden": "aufstapelnd",
    "aufstapelnder": "aufstapelnd",
    "aufstapelndes": "aufstapelnd",
    "aufstapelst": "aufstapeln",
    "aufstapelt": "aufstapeln",
    "aufstapelte": "aufstapeln",
    "aufstapelten": "aufstapeln",
    "aufstapeltest": "aufstapeln",
    "aufstapeltet": "aufstapeln",
    "aufstaple": "aufstapeln",
    "aufstaue": "aufstauen",
    "aufstauend": "aufstauen",
    "aufstauende": "aufstauend",
    "aufstauendem": "aufstauend",
    "aufstauenden": "aufstauend",
    "aufstauender": "aufstauend",
    "aufstauendere": "aufstauend",
    "aufstauenderem": "aufstauend",
    "aufstauenderen": "aufstauend",
    "aufstauenderer": "aufstauend",
    "aufstauenderes": "aufstauend",
    "aufstauendes": "aufstauend",
    "aufstauendste": "aufstauend",
    "aufstauendstem": "aufstauend",
    "aufstauendsten": "aufstauend",
    "aufstauendster": "aufstauend",
    "aufstauendstes": "aufstauend",
    "aufstauest": "aufstauen",
    "aufstauet": "aufstauen",
    "aufstaust": "aufstauen",
    "aufstaut": "aufstauen",
    "aufstaute": "aufstauen",
    "aufstauten": "aufstauen",
    "aufstautest": "aufstauen",
    "aufstautet": "aufstauen",
    "aufsteche": "aufstechen",
    "aufstechend": "aufstechen",
    "aufstechende": "aufstechend",
    "aufstechendem": "aufstechend",
    "aufstechenden": "aufstechend",
    "aufstechender": "aufstechend",
    "aufstechendes": "aufstechend",
    "aufstechest": "aufstechen",
    "aufstechet": "aufstechen",
    "aufstecht": "aufstechen",
    "aufsteckbare": "aufsteckbar",
    "aufsteckbarem": "aufsteckbar",
    "aufsteckbaren": "aufsteckbar",
    "aufsteckbarer": "aufsteckbar",
    "aufsteckbares": "aufsteckbar",
    "aufstecke": "aufstecken",
    "aufsteckend": "aufstecken",
    "aufsteckende": "aufsteckend",
    "aufsteckendem": "aufsteckend",
    "aufsteckenden": "aufsteckend",
    "aufsteckender": "aufsteckend",
    "aufsteckendes": "aufsteckend",
    "aufsteckest": "aufstecken",
    "aufstecket": "aufstecken",
    "aufsteckst": "aufstecken",
    "aufsteckt": "aufstecken",
    "aufsteckte": "aufstecken",
    "aufsteckten": "aufstecken",
    "aufstecktest": "aufstecken",
    "aufstecktet": "aufstecken",
    "aufstehe": "aufstehen",
    "aufstehend": "aufstehen",
    "aufstehende": "aufstehend",
    "aufstehendem": "aufstehend",
    "aufstehenden": "aufstehend",
    "aufstehender": "aufstehend",
    "aufstehendes": "aufstehend",
    "aufstehest": "aufstehen",
    "aufstehet": "aufstehen",
    "aufstehst": "aufstehen",
    "aufsteht": "aufstehen",
    "aufsteige": "aufsteigen",
    "aufsteigend": "aufsteigen",
    "aufsteigende": "aufsteigend",
    "aufsteigendem": "aufsteigend",
    "aufsteigenden": "aufsteigend",
    "aufsteigender": "aufsteigend",
    "aufsteigendes": "aufsteigend",
    "aufsteigest": "aufsteigen",
    "aufsteiget": "aufsteigen",
    "aufsteigst": "aufsteigen",
    "aufsteigt": "aufsteigen",
    "aufstelle": "aufstellen",
    "aufstellend": "aufstellen",
    "aufstellende": "aufstellend",
    "aufstellendem": "aufstellend",
    "aufstellenden": "aufstellend",
    "aufstellender": "aufstellend",
    "aufstellendes": "aufstellend",
    "aufstellest": "aufstellen",
    "aufstellet": "aufstellen",
    "aufstellst": "aufstellen",
    "aufstellt": "aufstellen",
    "aufstellte": "aufstellen",
    "aufstellten": "aufstellen",
    "aufstelltest": "aufstellen",
    "aufstelltet": "aufstellen",
    "aufstemme": "aufstemmen",
    "aufstemmend": "aufstemmen",
    "aufstemmende": "aufstemmend",
    "aufstemmendem": "aufstemmend",
    "aufstemmenden": "aufstemmend",
    "aufstemmender": "aufstemmend",
    "aufstemmendes": "aufstemmend",
    "aufstemmest": "aufstemmen",
    "aufstemmet": "aufstemmen",
    "aufstemmst": "aufstemmen",
    "aufstemmt": "aufstemmen",
    "aufstemmte": "aufstemmen",
    "aufstemmten": "aufstemmen",
    "aufstemmtest": "aufstemmen",
    "aufstemmtet": "aufstemmen",
    "aufstichst": "aufstechen",
    "aufsticht": "aufstechen",
    "aufstieg": "aufsteigen",
    "aufstiege": "aufsteigen",
    "aufstiegen": "aufsteigen",
    "aufstiegest": "aufsteigen",
    "aufstieget": "aufsteigen",
    "aufstiegst": "aufsteigen",
    "aufstiegt": "aufsteigen",
    "aufstiele": "aufstielen",
    "aufstielend": "aufstielen",
    "aufstielende": "aufstielend",
    "aufstielendem": "aufstielend",
    "aufstielenden": "aufstielend",
    "aufstielender": "aufstielend",
    "aufstielendes": "aufstielend",
    "aufstielest": "aufstielen",
    "aufstielet": "aufstielen",
    "aufstielst": "aufstielen",
    "aufstielt": "aufstielen",
    "aufstielte": "aufstielen",
    "aufstielten": "aufstielen",
    "aufstieltest": "aufstielen",
    "aufstieltet": "aufstielen",
    "aufstieß": "aufstoßen",
    "aufstieße": "aufstoßen",
    "aufstießen": "aufstoßen",
    "aufstießest": "aufstoßen",
    "aufstießet": "aufstoßen",
    "aufstießt": "aufstoßen",
    "aufstifte": "aufstiften",
    "aufstiftend": "aufstiften",
    "aufstiftende": "aufstiftend",
    "aufstiftendem": "aufstiftend",
    "aufstiftenden": "aufstiftend",
    "aufstiftender": "aufstiftend",
    "aufstiftendes": "aufstiftend",
    "aufstiftest": "aufstiften",
    "aufstiftet": "aufstiften",
    "aufstiftete": "aufstiften",
    "aufstifteten": "aufstiften",
    "aufstiftetest": "aufstiften",
    "aufstiftetet": "aufstiften",
    "aufstocke": "aufstocken",
    "aufstockend": "aufstocken",
    "aufstockende": "aufstockend",
    "aufstockendem": "aufstockend",
    "aufstockenden": "aufstockend",
    "aufstockender": "aufstockend",
    "aufstockendes": "aufstockend",
    "aufstockest": "aufstocken",
    "aufstocket": "aufstocken",
    "aufstockst": "aufstocken",
    "aufstockt": "aufstocken",
    "aufstockte": "aufstocken",
    "aufstockten": "aufstocken",
    "aufstocktest": "aufstocken",
    "aufstocktet": "aufstocken",
    "aufstoße": "aufstoßen",
    "aufstoßend": "aufstoßen",
    "aufstoßende": "aufstoßend",
    "aufstoßendem": "aufstoßend",
    "aufstoßenden": "aufstoßend",
    "aufstoßender": "aufstoßend",
    "aufstoßendes": "aufstoßend",
    "aufstoßest": "aufstoßen",
    "aufstoßet": "aufstoßen",
    "aufstoßt": "aufstoßen",
    "aufstrebe": "aufstreben",
    "aufstrebend": "aufstreben",
    "aufstrebende": "aufstrebend",
    "aufstrebendem": "aufstrebend",
    "aufstrebenden": "aufstrebend",
    "aufstrebender": "aufstrebend",
    "aufstrebendere": "aufstrebend",
    "aufstrebenderem": "aufstrebend",
    "aufstrebenderen": "aufstrebend",
    "aufstrebenderer": "aufstrebend",
    "aufstrebenderes": "aufstrebend",
    "aufstrebendes": "aufstrebend",
    "aufstrebendste": "aufstrebend",
    "aufstrebendstem": "aufstrebend",
    "aufstrebendsten": "aufstrebend",
    "aufstrebendster": "aufstrebend",
    "aufstrebendstes": "aufstrebend",
    "aufstrebest": "aufstreben",
    "aufstrebet": "aufstreben",
    "aufstrebst": "aufstreben",
    "aufstrebt": "aufstreben",
    "aufstrebte": "aufstreben",
    "aufstrebten": "aufstreben",
    "aufstrebtest": "aufstreben",
    "aufstrebtet": "aufstreben",
    "aufstreiche": "aufstreichen",
    "aufstreichend": "aufstreichen",
    "aufstreichende": "aufstreichend",
    "aufstreichendem": "aufstreichend",
    "aufstreichenden": "aufstreichend",
    "aufstreichender": "aufstreichend",
    "aufstreichendes": "aufstreichend",
    "aufstreichest": "aufstreichen",
    "aufstreichet": "aufstreichen",
    "aufstreichst": "aufstreichen",
    "aufstreicht": "aufstreichen",
    "aufstrich": "aufstreichen",
    "aufstrichest": "aufstreichen",
    "aufstrichet": "aufstreichen",
    "aufstrichst": "aufstreichen",
    "aufstricht": "aufstreichen",
    "aufstäche": "aufstechen",
    "aufstächen": "aufstechen",
    "aufstächest": "aufstechen",
    "aufstächet": "aufstechen",
    "aufständische": "aufständisch",
    "aufständischem": "aufständisch",
    "aufständischen": "aufständisch",
    "aufständischer": "aufständisch",
    "aufständisches": "aufständisch",
    "aufstöbere": "aufstöbern",
    "aufstöbernd": "aufstöbern",
    "aufstöbernde": "aufstöbernd",
    "aufstöberndem": "aufstöbernd",
    "aufstöbernden": "aufstöbernd",
    "aufstöbernder": "aufstöbernd",
    "aufstöberndes": "aufstöbernd",
    "aufstöberst": "aufstöbern",
    "aufstöbert": "aufstöbern",
    "aufstöberte": "aufstöbern",
    "aufstöberten": "aufstöbern",
    "aufstöbertest": "aufstöbern",
    "aufstöbertet": "aufstöbern",
    "aufstößt": "aufstoßen",
    "aufstülpe": "aufstülpen",
    "aufstülpend": "aufstülpen",
    "aufstülpende": "aufstülpend",
    "aufstülpendem": "aufstülpend",
    "aufstülpenden": "aufstülpend",
    "aufstülpender": "aufstülpend",
    "aufstülpendes": "aufstülpend",
    "aufstülpest": "aufstülpen",
    "aufstülpet": "aufstülpen",
    "aufstülpst": "aufstülpen",
    "aufstülpt": "aufstülpen",
    "aufstülpte": "aufstülpen",
    "aufstülpten": "aufstülpen",
    "aufstülptest": "aufstülpen",
    "aufstülptet": "aufstülpen",
    "aufstünde": "aufstehen",
    "aufstünden": "aufstehen",
    "aufstündest": "aufstehen",
    "aufstündet": "aufstehen",
    "aufstütze": "aufstützen",
    "aufstützend": "aufstützen",
    "aufstützende": "aufstützend",
    "aufstützendem": "aufstützend",
    "aufstützenden": "aufstützend",
    "aufstützender": "aufstützend",
    "aufstützendes": "aufstützend",
    "aufstützest": "aufstützen",
    "aufstützet": "aufstützen",
    "aufstützt": "aufstützen",
    "aufstützte": "aufstützen",
    "aufstützten": "aufstützen",
    "aufstütztest": "aufstützen",
    "aufstütztet": "aufstützen",
    "aufsuche": "aufsuchen",
    "aufsuchend": "aufsuchen",
    "aufsuchende": "aufsuchend",
    "aufsuchendem": "aufsuchend",
    "aufsuchenden": "aufsuchend",
    "aufsuchender": "aufsuchend",
    "aufsuchendes": "aufsuchend",
    "aufsuchest": "aufsuchen",
    "aufsuchet": "aufsuchen",
    "aufsuchst": "aufsuchen",
    "aufsucht": "aufsuchen",
    "aufsuchte": "aufsuchen",
    "aufsuchten": "aufsuchen",
    "aufsuchtest": "aufsuchen",
    "aufsuchtet": "aufsuchen",
    "aufsähe": "aufsehen",
    "aufsähen": "aufsehen",
    "aufsähest": "aufsehen",
    "aufsähet": "aufsehen",
    "aufsässige": "aufsässig",
    "aufsässigem": "aufsässig",
    "aufsässigen": "aufsässig",
    "aufsässiger": "aufsässig",
    "aufsässigere": "aufsässig",
    "aufsässigerem": "aufsässig",
    "aufsässigeren": "aufsässig",
    "aufsässigerer": "aufsässig",
    "aufsässigeres": "aufsässig",
    "aufsässiges": "aufsässig",
    "aufsässigste": "aufsässig",
    "aufsässigstem": "aufsässig",
    "aufsässigsten": "aufsässig",
    "aufsässigster": "aufsässig",
    "aufsässigstes": "aufsässig",
    "aufsäße": "aufsitzen",
    "aufsäßen": "aufsitzen",
    "aufsäßest": "aufsitzen",
    "aufsäßet": "aufsitzen",
    "aufsöge": "aufsaugen",
    "aufsögen": "aufsaugen",
    "aufsögest": "aufsaugen",
    "aufsöget": "aufsaugen",
    "auftakele": "auftakeln",
    "auftakelnd": "auftakeln",
    "auftakelnde": "auftakelnd",
    "auftakelndem": "auftakelnd",
    "auftakelnden": "auftakelnd",
    "auftakelnder": "auftakelnd",
    "auftakelndere": "auftakelnd",
    "auftakelnderem": "auftakelnd",
    "auftakelnderen": "auftakelnd",
    "auftakelnderer": "auftakelnd",
    "auftakelnderes": "auftakelnd",
    "auftakelndes": "auftakelnd",
    "auftakelndste": "auftakelnd",
    "auftakelndstem": "auftakelnd",
    "auftakelndsten": "auftakelnd",
    "auftakelndster": "auftakelnd",
    "auftakelndstes": "auftakelnd",
    "auftakelst": "auftakeln",
    "auftakelt": "auftakeln",
    "auftakelte": "auftakeln",
    "auftakelten": "auftakeln",
    "auftakeltest": "auftakeln",
    "auftakeltet": "auftakeln",
    "auftakle": "auftakeln",
    "auftanke": "auftanken",
    "auftankend": "auftanken",
    "auftankende": "auftankend",
    "auftankendem": "auftankend",
    "auftankenden": "auftankend",
    "auftankender": "auftankend",
    "auftankendes": "auftankend",
    "auftankest": "auftanken",
    "auftanket": "auftanken",
    "auftankst": "auftanken",
    "auftankt": "auftanken",
    "auftankte": "auftanken",
    "auftankten": "auftanken",
    "auftanktest": "auftanken",
    "auftanktet": "auftanken",
    "auftauche": "auftauchen",
    "auftauchend": "auftauchen",
    "auftauchende": "auftauchend",
    "auftauchendem": "auftauchend",
    "auftauchenden": "auftauchend",
    "auftauchender": "auftauchend",
    "auftauchendes": "auftauchend",
    "auftauchest": "auftauchen",
    "auftauchet": "auftauchen",
    "auftauchst": "auftauchen",
    "auftaucht": "auftauchen",
    "auftauchte": "auftauchen",
    "auftauchten": "auftauchen",
    "auftauchtest": "auftauchen",
    "auftauchtet": "auftauchen",
    "auftaue": "auftauen",
    "auftauend": "auftauen",
    "auftauende": "auftauend",
    "auftauendem": "auftauend",
    "auftauenden": "auftauend",
    "auftauender": "auftauend",
    "auftauendes": "auftauend",
    "auftauest": "auftauen",
    "auftauet": "auftauen",
    "auftaust": "auftauen",
    "auftaut": "auftauen",
    "auftaute": "auftauen",
    "auftauten": "auftauen",
    "auftautest": "auftauen",
    "auftautet": "auftauen",
    "aufteile": "aufteilen",
    "aufteilend": "aufteilen",
    "aufteilende": "aufteilend",
    "aufteilendem": "aufteilend",
    "aufteilenden": "aufteilend",
    "aufteilender": "aufteilend",
    "aufteilendes": "aufteilend",
    "aufteilest": "aufteilen",
    "aufteilet": "aufteilen",
    "aufteilst": "aufteilen",
    "aufteilt": "aufteilen",
    "aufteilte": "aufteilen",
    "aufteilten": "aufteilen",
    "aufteiltest": "aufteilen",
    "aufteiltet": "aufteilen",
    "auftische": "auftischen",
    "auftischend": "auftischen",
    "auftischende": "auftischend",
    "auftischendem": "auftischend",
    "auftischenden": "auftischend",
    "auftischender": "auftischend",
    "auftischendes": "auftischend",
    "auftischest": "auftischen",
    "auftischet": "auftischen",
    "auftischst": "auftischen",
    "auftischt": "auftischen",
    "auftischte": "auftischen",
    "auftischten": "auftischen",
    "auftischtest": "auftischen",
    "auftischtet": "auftischen",
    "auftraf": "auftreffen",
    "auftrafen": "auftreffen",
    "auftrafst": "auftreffen",
    "auftraft": "auftreffen",
    "auftragend": "auftragen",
    "auftragende": "auftragend",
    "auftragendem": "auftragend",
    "auftragenden": "auftragend",
    "auftragender": "auftragend",
    "auftragendes": "auftragend",
    "auftragest": "auftragen",
    "auftraget": "auftragen",
    "auftragt": "auftragen",
    "auftrat": "auftreten",
    "auftraten": "auftreten",
    "auftratest": "auftreten",
    "auftratet": "auftreten",
    "auftreffe": "auftreffen",
    "auftreffend": "auftreffen",
    "auftreffende": "auftreffend",
    "auftreffendem": "auftreffend",
    "auftreffenden": "auftreffend",
    "auftreffender": "auftreffend",
    "auftreffendes": "auftreffend",
    "auftreffest": "auftreffen",
    "auftreffet": "auftreffen",
    "auftrefft": "auftreffen",
    "auftreibe": "auftreiben",
    "auftreibend": "auftreiben",
    "auftreibende": "auftreibend",
    "auftreibendem": "auftreibend",
    "auftreibenden": "auftreibend",
    "auftreibender": "auftreibend",
    "auftreibendes": "auftreibend",
    "auftreibest": "auftreiben",
    "auftreibet": "auftreiben",
    "auftreibst": "auftreiben",
    "auftreibt": "auftreiben",
    "auftrenne": "auftrennen",
    "auftrennend": "auftrennen",
    "auftrennende": "auftrennend",
    "auftrennendem": "auftrennend",
    "auftrennenden": "auftrennend",
    "auftrennender": "auftrennend",
    "auftrennendes": "auftrennend",
    "auftrennest": "auftrennen",
    "auftrennet": "auftrennen",
    "auftrennst": "auftrennen",
    "auftrennt": "auftrennen",
    "auftrennte": "auftrennen",
    "auftrennten": "auftrennen",
    "auftrenntest": "auftrennen",
    "auftrenntet": "auftrennen",
    "auftrete": "auftreten",
    "auftretend": "auftreten",
    "auftretende": "auftretend",
    "auftretendem": "auftretend",
    "auftretenden": "auftretend",
    "auftretender": "auftretend",
    "auftretendes": "auftretend",
    "auftretest": "auftreten",
    "auftretet": "auftreten",
    "auftrieb": "auftreiben",
    "auftriebe": "auftreiben",
    "auftrieben": "auftreiben",
    "auftriebest": "auftreiben",
    "auftriebet": "auftreiben",
    "auftriebst": "auftreiben",
    "auftriebt": "auftreiben",
    "auftriffst": "auftreffen",
    "auftrifft": "auftreffen",
    "auftritt": "auftreten",
    "auftrittst": "auftreten",
    "auftrug": "auftragen",
    "auftrugen": "auftragen",
    "auftrugst": "auftragen",
    "auftrugt": "auftragen",
    "auftrumpfe": "auftrumpfen",
    "auftrumpfend": "auftrumpfen",
    "auftrumpfende": "auftrumpfend",
    "auftrumpfendem": "auftrumpfend",
    "auftrumpfenden": "auftrumpfend",
    "auftrumpfender": "auftrumpfend",
    "auftrumpfendes": "auftrumpfend",
    "auftrumpfest": "auftrumpfen",
    "auftrumpfet": "auftrumpfen",
    "auftrumpfst": "auftrumpfen",
    "auftrumpft": "auftrumpfen",
    "auftrumpfte": "auftrumpfen",
    "auftrumpften": "auftrumpfen",
    "auftrumpftest": "auftrumpfen",
    "auftrumpftet": "auftrumpfen",
    "aufträfe": "auftreffen",
    "aufträfen": "auftreffen",
    "aufträfest": "auftreffen",
    "aufträfet": "auftreffen",
    "aufträgst": "auftragen",
    "aufträgt": "auftragen",
    "aufträte": "auftreten",
    "aufträten": "auftreten",
    "aufträtest": "auftreten",
    "aufträtet": "auftreten",
    "auftrüge": "auftragen",
    "auftrügen": "auftragen",
    "auftrügest": "auftragen",
    "auftrüget": "auftragen",
    "auftürme": "auftürmen",
    "auftürmend": "auftürmen",
    "auftürmende": "auftürmend",
    "auftürmendem": "auftürmend",
    "auftürmenden": "auftürmend",
    "auftürmender": "auftürmend",
    "auftürmendes": "auftürmend",
    "auftürmest": "auftürmen",
    "auftürmet": "auftürmen",
    "auftürmst": "auftürmen",
    "auftürmt": "auftürmen",
    "auftürmte": "auftürmen",
    "auftürmten": "auftürmen",
    "auftürmtest": "auftürmen",
    "auftürmtet": "auftürmen",
    "aufwache": "aufwachen",
    "aufwachend": "aufwachen",
    "aufwachende": "aufwachend",
    "aufwachendem": "aufwachend",
    "aufwachenden": "aufwachend",
    "aufwachender": "aufwachend",
    "aufwachendes": "aufwachend",
    "aufwachest": "aufwachen",
    "aufwachet": "aufwachen",
    "aufwachse": "aufwachsen",
    "aufwachsend": "aufwachsen",
    "aufwachsende": "aufwachsend",
    "aufwachsendem": "aufwachsend",
    "aufwachsenden": "aufwachsend",
    "aufwachsender": "aufwachsend",
    "aufwachsendes": "aufwachsend",
    "aufwachsest": "aufwachsen",
    "aufwachset": "aufwachsen",
    "aufwachst": "aufwachsen",
    "aufwachste": "aufwachsen",
    "aufwachsten": "aufwachsen",
    "aufwachstest": "aufwachsen",
    "aufwachstet": "aufwachsen",
    "aufwacht": "aufwachen",
    "aufwachte": "aufwachen",
    "aufwachten": "aufwachen",
    "aufwachtest": "aufwachen",
    "aufwachtet": "aufwachen",
    "aufwalle": "aufwallen",
    "aufwallend": "aufwallen",
    "aufwallende": "aufwallend",
    "aufwallendem": "aufwallend",
    "aufwallenden": "aufwallend",
    "aufwallender": "aufwallend",
    "aufwallendere": "aufwallend",
    "aufwallenderem": "aufwallend",
    "aufwallenderen": "aufwallend",
    "aufwallenderer": "aufwallend",
    "aufwallenderes": "aufwallend",
    "aufwallendes": "aufwallend",
    "aufwallendste": "aufwallend",
    "aufwallendstem": "aufwallend",
    "aufwallendsten": "aufwallend",
    "aufwallendster": "aufwallend",
    "aufwallendstes": "aufwallend",
    "aufwallest": "aufwallen",
    "aufwallet": "aufwallen",
    "aufwallst": "aufwallen",
    "aufwallt": "aufwallen",
    "aufwallte": "aufwallen",
    "aufwallten": "aufwallen",
    "aufwalltest": "aufwallen",
    "aufwalltet": "aufwallen",
    "aufwalze": "aufwalzen",
    "aufwalzend": "aufwalzen",
    "aufwalzende": "aufwalzend",
    "aufwalzendem": "aufwalzend",
    "aufwalzenden": "aufwalzend",
    "aufwalzender": "aufwalzend",
    "aufwalzendes": "aufwalzend",
    "aufwalzest": "aufwalzen",
    "aufwalzet": "aufwalzen",
    "aufwalzt": "aufwalzen",
    "aufwalzte": "aufwalzen",
    "aufwalzten": "aufwalzen",
    "aufwalztest": "aufwalzen",
    "aufwalztet": "aufwalzen",
    "aufwand": "aufwinden",
    "aufwanden": "aufwinden",
    "aufwandest": "aufwinden",
    "aufwandet": "aufwinden",
    "aufwandte": "aufwenden",
    "aufwandten": "aufwenden",
    "aufwandtest": "aufwenden",
    "aufwandtet": "aufwenden",
    "aufwarf": "aufwerfen",
    "aufwarfen": "aufwerfen",
    "aufwarfst": "aufwerfen",
    "aufwarft": "aufwerfen",
    "aufwarte": "aufwarten",
    "aufwartend": "aufwarten",
    "aufwartende": "aufwartend",
    "aufwartendem": "aufwartend",
    "aufwartenden": "aufwartend",
    "aufwartender": "aufwartend",
    "aufwartendes": "aufwartend",
    "aufwartest": "aufwarten",
    "aufwartet": "aufwarten",
    "aufwartete": "aufwarten",
    "aufwarteten": "aufwarten",
    "aufwartetest": "aufwarten",
    "aufwartetet": "aufwarten",
    "aufwasche": "aufwaschen",
    "aufwaschend": "aufwaschen",
    "aufwaschende": "aufwaschend",
    "aufwaschendem": "aufwaschend",
    "aufwaschenden": "aufwaschend",
    "aufwaschender": "aufwaschend",
    "aufwaschendes": "aufwaschend",
    "aufwaschest": "aufwaschen",
    "aufwaschet": "aufwaschen",
    "aufwascht": "aufwaschen",
    "aufwecke": "aufwecken",
    "aufweckend": "aufwecken",
    "aufweckende": "aufweckend",
    "aufweckendem": "aufweckend",
    "aufweckenden": "aufweckend",
    "aufweckender": "aufweckend",
    "aufweckendes": "aufweckend",
    "aufweckest": "aufwecken",
    "aufwecket": "aufwecken",
    "aufweckst": "aufwecken",
    "aufweckt": "aufwecken",
    "aufweckte": "aufwecken",
    "aufweckten": "aufwecken",
    "aufwecktest": "aufwecken",
    "aufwecktet": "aufwecken",
    "aufweiche": "aufweichen",
    "aufweichend": "aufweichen",
    "aufweichende": "aufweichend",
    "aufweichendem": "aufweichend",
    "aufweichenden": "aufweichend",
    "aufweichender": "aufweichend",
    "aufweichendere": "aufweichend",
    "aufweichenderem": "aufweichend",
    "aufweichenderen": "aufweichend",
    "aufweichenderer": "aufweichend",
    "aufweichenderes": "aufweichend",
    "aufweichendes": "aufweichend",
    "aufweichendste": "aufweichend",
    "aufweichendstem": "aufweichend",
    "aufweichendsten": "aufweichend",
    "aufweichendster": "aufweichend",
    "aufweichendstes": "aufweichend",
    "aufweichest": "aufweichen",
    "aufweichet": "aufweichen",
    "aufweichst": "aufweichen",
    "aufweicht": "aufweichen",
    "aufweichte": "aufweichen",
    "aufweichten": "aufweichen",
    "aufweichtest": "aufweichen",
    "aufweichtet": "aufweichen",
    "aufweise": "aufweisen",
    "aufweisend": "aufweisen",
    "aufweisende": "aufweisend",
    "aufweisendem": "aufweisend",
    "aufweisenden": "aufweisend",
    "aufweisender": "aufweisend",
    "aufweisendes": "aufweisend",
    "aufweisest": "aufweisen",
    "aufweiset": "aufweisen",
    "aufweist": "aufweisen",
    "aufwende": "aufwenden",
    "aufwendend": "aufwenden",
    "aufwendende": "aufwendend",
    "aufwendendem": "aufwendend",
    "aufwendenden": "aufwendend",
    "aufwendender": "aufwendend",
    "aufwendendes": "aufwendend",
    "aufwendest": "aufwenden",
    "aufwendet": "aufwenden",
    "aufwendete": "aufwenden",
    "aufwendeten": "aufwenden",
    "aufwendetest": "aufwenden",
    "aufwendetet": "aufwenden",
    "aufwendige": "aufwendig",
    "aufwendigem": "aufwendig",
    "aufwendigen": "aufwendig",
    "aufwendiger": "aufwendig",
    "aufwendigere": "aufwendig",
    "aufwendigerem": "aufwendig",
    "aufwendigeren": "aufwendig",
    "aufwendigerer": "aufwendig",
    "aufwendigeres": "aufwendig",
    "aufwendiges": "aufwendig",
    "aufwendigste": "aufwendig",
    "aufwendigstem": "aufwendig",
    "aufwendigsten": "aufwendig",
    "aufwendigster": "aufwendig",
    "aufwendigstes": "aufwendig",
    "aufwerfe": "aufwerfen",
    "aufwerfend": "aufwerfen",
    "aufwerfende": "aufwerfend",
    "aufwerfendem": "aufwerfend",
    "aufwerfenden": "aufwerfend",
    "aufwerfender": "aufwerfend",
    "aufwerfendes": "aufwerfend",
    "aufwerfest": "aufwerfen",
    "aufwerfet": "aufwerfen",
    "aufwerft": "aufwerfen",
    "aufwerte": "aufwerten",
    "aufwertend": "aufwerten",
    "aufwertende": "aufwertend",
    "aufwertendem": "aufwertend",
    "aufwertenden": "aufwertend",
    "aufwertender": "aufwertend",
    "aufwertendere": "aufwertend",
    "aufwertenderem": "aufwertend",
    "aufwertenderen": "aufwertend",
    "aufwertenderer": "aufwertend",
    "aufwertenderes": "aufwertend",
    "aufwertendes": "aufwertend",
    "aufwertendste": "aufwertend",
    "aufwertendstem": "aufwertend",
    "aufwertendsten": "aufwertend",
    "aufwertendster": "aufwertend",
    "aufwertendstes": "aufwertend",
    "aufwertest": "aufwerten",
    "aufwertet": "aufwerten",
    "aufwertete": "aufwerten",
    "aufwerteten": "aufwerten",
    "aufwertetest": "aufwerten",
    "aufwertetet": "aufwerten",
    "aufwich": "aufweichen",
    "aufwiche": "aufweichen",
    "aufwichen": "aufweichen",
    "aufwichest": "aufweichen",
    "aufwichet": "aufweichen",
    "aufwichst": "aufweichen",
    "aufwicht": "aufweichen",
    "aufwiege": "aufwiegen",
    "aufwiegele": "aufwiegeln",
    "aufwiegelnd": "aufwiegeln",
    "aufwiegelnde": "aufwiegelnd",
    "aufwiegelndem": "aufwiegelnd",
    "aufwiegelnden": "aufwiegelnd",
    "aufwiegelnder": "aufwiegelnd",
    "aufwiegelndere": "aufwiegelnd",
    "aufwiegelnderem": "aufwiegelnd",
    "aufwiegelnderen": "aufwiegelnd",
    "aufwiegelnderer": "aufwiegelnd",
    "aufwiegelnderes": "aufwiegelnd",
    "aufwiegelndes": "aufwiegelnd",
    "aufwiegelndste": "aufwiegelnd",
    "aufwiegelndstem": "aufwiegelnd",
    "aufwiegelndsten": "aufwiegelnd",
    "aufwiegelndster": "aufwiegelnd",
    "aufwiegelndstes": "aufwiegelnd",
    "aufwiegelst": "aufwiegeln",
    "aufwiegelt": "aufwiegeln",
    "aufwiegelte": "aufwiegeln",
    "aufwiegelten": "aufwiegeln",
    "aufwiegeltest": "aufwiegeln",
    "aufwiegeltet": "aufwiegeln",
    "aufwiegend": "aufwiegen",
    "aufwiegende": "aufwiegend",
    "aufwiegendem": "aufwiegend",
    "aufwiegenden": "aufwiegend",
    "aufwiegender": "aufwiegend",
    "aufwiegendes": "aufwiegend",
    "aufwiegest": "aufwiegen",
    "aufwieget": "aufwiegen",
    "aufwiegle": "aufwiegeln",
    "aufwieglerische": "aufwieglerisch",
    "aufwieglerischem": "aufwieglerisch",
    "aufwieglerischen": "aufwieglerisch",
    "aufwieglerischer": "aufwieglerisch",
    "aufwieglerischere": "aufwieglerisch",
    "aufwieglerischerem": "aufwieglerisch",
    "aufwieglerischeren": "aufwieglerisch",
    "aufwieglerischerer": "aufwieglerisch",
    "aufwieglerischeres": "aufwieglerisch",
    "aufwieglerisches": "aufwieglerisch",
    "aufwieglerischste": "aufwieglerisch",
    "aufwieglerischstem": "aufwieglerisch",
    "aufwieglerischsten": "aufwieglerisch",
    "aufwieglerischster": "aufwieglerisch",
    "aufwieglerischstes": "aufwieglerisch",
    "aufwiegst": "aufwiegen",
    "aufwiegt": "aufwiegen",
    "aufwies": "aufweisen",
    "aufwiese": "aufweisen",
    "aufwiesen": "aufweisen",
    "aufwiesest": "aufweisen",
    "aufwieset": "aufweisen",
    "aufwiest": "aufweisen",
    "aufwindend": "aufwinden",
    "aufwindende": "aufwindend",
    "aufwindendem": "aufwindend",
    "aufwindenden": "aufwindend",
    "aufwindender": "aufwindend",
    "aufwindendes": "aufwindend",
    "aufwindest": "aufwinden",
    "aufwindet": "aufwinden",
    "aufwirbele": "aufwirbeln",
    "aufwirbelnd": "aufwirbeln",
    "aufwirbelnde": "aufwirbelnd",
    "aufwirbelndem": "aufwirbelnd",
    "aufwirbelnden": "aufwirbelnd",
    "aufwirbelnder": "aufwirbelnd",
    "aufwirbelndere": "aufwirbelnd",
    "aufwirbelnderem": "aufwirbelnd",
    "aufwirbelnderen": "aufwirbelnd",
    "aufwirbelnderer": "aufwirbelnd",
    "aufwirbelnderes": "aufwirbelnd",
    "aufwirbelndes": "aufwirbelnd",
    "aufwirbelndste": "aufwirbelnd",
    "aufwirbelndstem": "aufwirbelnd",
    "aufwirbelndsten": "aufwirbelnd",
    "aufwirbelndster": "aufwirbelnd",
    "aufwirbelndstes": "aufwirbelnd",
    "aufwirbelst": "aufwirbeln",
    "aufwirbelt": "aufwirbeln",
    "aufwirbelte": "aufwirbeln",
    "aufwirbelten": "aufwirbeln",
    "aufwirbeltest": "aufwirbeln",
    "aufwirbeltet": "aufwirbeln",
    "aufwirble": "aufwirbeln",
    "aufwirfst": "aufwerfen",
    "aufwirft": "aufwerfen",
    "aufwische": "aufwischen",
    "aufwischend": "aufwischen",
    "aufwischende": "aufwischend",
    "aufwischendem": "aufwischend",
    "aufwischenden": "aufwischend",
    "aufwischender": "aufwischend",
    "aufwischendes": "aufwischend",
    "aufwischest": "aufwischen",
    "aufwischet": "aufwischen",
    "aufwischst": "aufwischen",
    "aufwischt": "aufwischen",
    "aufwischte": "aufwischen",
    "aufwischten": "aufwischen",
    "aufwischtest": "aufwischen",
    "aufwischtet": "aufwischen",
    "aufwog": "aufwiegen",
    "aufwogen": "aufwiegen",
    "aufwogst": "aufwiegen",
    "aufwogt": "aufwiegen",
    "aufwuchs": "aufwachsen",
    "aufwuchsen": "aufwachsen",
    "aufwuchst": "aufwachsen",
    "aufwusch": "aufwaschen",
    "aufwuschen": "aufwaschen",
    "aufwuschst": "aufwaschen",
    "aufwuscht": "aufwaschen",
    "aufwächst": "aufwachsen",
    "aufwände": "aufwinden",
    "aufwänden": "aufwinden",
    "aufwändest": "aufwinden",
    "aufwändet": "aufwinden",
    "aufwändige": "aufwändig",
    "aufwändigem": "aufwändig",
    "aufwändigen": "aufwändig",
    "aufwändiger": "aufwändig",
    "aufwändigere": "aufwändig",
    "aufwändigerem": "aufwändig",
    "aufwändigeren": "aufwändig",
    "aufwändigerer": "aufwändig",
    "aufwändigeres": "aufwändig",
    "aufwändiges": "aufwändig",
    "aufwändigste": "aufwändig",
    "aufwändigstem": "aufwändig",
    "aufwändigsten": "aufwändig",
    "aufwändigster": "aufwändig",
    "aufwändigstes": "aufwändig",
    "aufwärfe": "aufwerfen",
    "aufwärfen": "aufwerfen",
    "aufwärfest": "aufwerfen",
    "aufwärfet": "aufwerfen",
    "aufwärme": "aufwärmen",
    "aufwärmend": "aufwärmen",
    "aufwärmende": "aufwärmend",
    "aufwärmendem": "aufwärmend",
    "aufwärmenden": "aufwärmend",
    "aufwärmender": "aufwärmend",
    "aufwärmendes": "aufwärmend",
    "aufwärmest": "aufwärmen",
    "aufwärmet": "aufwärmen",
    "aufwärmst": "aufwärmen",
    "aufwärmt": "aufwärmen",
    "aufwärmte": "aufwärmen",
    "aufwärmten": "aufwärmen",
    "aufwärmtest": "aufwärmen",
    "aufwärmtet": "aufwärmen",
    "aufwärtsgegangen": "aufwärtsgehen",
    "aufwärtsgegangene": "aufwärtsgegangen",
    "aufwärtsgegangenem": "aufwärtsgegangen",
    "aufwärtsgegangenen": "aufwärtsgegangen",
    "aufwärtsgegangener": "aufwärtsgegangen",
    "aufwärtsgegangenes": "aufwärtsgegangen",
    "aufwärtsgehe": "aufwärtsgehen",
    "aufwärtsgehend": "aufwärtsgehen",
    "aufwärtsgehende": "aufwärtsgehend",
    "aufwärtsgehendem": "aufwärtsgehend",
    "aufwärtsgehenden": "aufwärtsgehend",
    "aufwärtsgehender": "aufwärtsgehend",
    "aufwärtsgehendes": "aufwärtsgehend",
    "aufwärtsgehest": "aufwärtsgehen",
    "aufwärtsgehet": "aufwärtsgehen",
    "aufwärtsgehst": "aufwärtsgehen",
    "aufwärtsgeht": "aufwärtsgehen",
    "aufwärtsging": "aufwärtsgehen",
    "aufwärtsginge": "aufwärtsgehen",
    "aufwärtsgingen": "aufwärtsgehen",
    "aufwärtsgingest": "aufwärtsgehen",
    "aufwärtsginget": "aufwärtsgehen",
    "aufwärtsgingst": "aufwärtsgehen",
    "aufwärtsgingt": "aufwärtsgehen",
    "aufwärtszugehen": "aufwärtsgehen",
    "aufwäschst": "aufwaschen",
    "aufwäscht": "aufwaschen",
    "aufwöge": "aufwiegen",
    "aufwögen": "aufwiegen",
    "aufwögest": "aufwiegen",
    "aufwöget": "aufwiegen",
    "aufwüchse": "aufwachsen",
    "aufwüchsen": "aufwachsen",
    "aufwüchsest": "aufwachsen",
    "aufwüchset": "aufwachsen",
    "aufwühle": "aufwühlen",
    "aufwühlend": "aufwühlen",
    "aufwühlende": "aufwühlend",
    "aufwühlendem": "aufwühlend",
    "aufwühlenden": "aufwühlend",
    "aufwühlender": "aufwühlend",
    "aufwühlendere": "aufwühlend",
    "aufwühlenderem": "aufwühlend",
    "aufwühlenderen": "aufwühlend",
    "aufwühlenderer": "aufwühlend",
    "aufwühlenderes": "aufwühlend",
    "aufwühlendes": "aufwühlend",
    "aufwühlendste": "aufwühlend",
    "aufwühlendstem": "aufwühlend",
    "aufwühlendsten": "aufwühlend",
    "aufwühlendster": "aufwühlend",
    "aufwühlendstes": "aufwühlend",
    "aufwühlest": "aufwühlen",
    "aufwühlet": "aufwühlen",
    "aufwühlst": "aufwühlen",
    "aufwühlt": "aufwühlen",
    "aufwühlte": "aufwühlen",
    "aufwühlten": "aufwühlen",
    "aufwühltest": "aufwühlen",
    "aufwühltet": "aufwühlen",
    "aufwüsche": "aufwaschen",
    "aufwüschen": "aufwaschen",
    "aufwüschest": "aufwaschen",
    "aufwüschet": "aufwaschen",
    "aufzehre": "aufzehren",
    "aufzehrend": "aufzehren",
    "aufzehrende": "aufzehrend",
    "aufzehrendem": "aufzehrend",
    "aufzehrenden": "aufzehrend",
    "aufzehrender": "aufzehrend",
    "aufzehrendere": "aufzehrend",
    "aufzehrenderem": "aufzehrend",
    "aufzehrenderen": "aufzehrend",
    "aufzehrenderer": "aufzehrend",
    "aufzehrenderes": "aufzehrend",
    "aufzehrendes": "aufzehrend",
    "aufzehrendste": "aufzehrend",
    "aufzehrendstem": "aufzehrend",
    "aufzehrendsten": "aufzehrend",
    "aufzehrendster": "aufzehrend",
    "aufzehrendstes": "aufzehrend",
    "aufzehrest": "aufzehren",
    "aufzehret": "aufzehren",
    "aufzehrst": "aufzehren",
    "aufzehrt": "aufzehren",
    "aufzehrte": "aufzehren",
    "aufzehrten": "aufzehren",
    "aufzehrtest": "aufzehren",
    "aufzehrtet": "aufzehren",
    "aufzeichne": "aufzeichnen",
    "aufzeichnend": "aufzeichnen",
    "aufzeichnende": "aufzeichnend",
    "aufzeichnendem": "aufzeichnend",
    "aufzeichnenden": "aufzeichnend",
    "aufzeichnender": "aufzeichnend",
    "aufzeichnendes": "aufzeichnend",
    "aufzeichnest": "aufzeichnen",
    "aufzeichnet": "aufzeichnen",
    "aufzeichnete": "aufzeichnen",
    "aufzeichneten": "aufzeichnen",
    "aufzeichnetest": "aufzeichnen",
    "aufzeichnetet": "aufzeichnen",
    "aufzeige": "aufzeigen",
    "aufzeigend": "aufzeigen",
    "aufzeigende": "aufzeigend",
    "aufzeigendem": "aufzeigend",
    "aufzeigenden": "aufzeigend",
    "aufzeigender": "aufzeigend",
    "aufzeigendes": "aufzeigend",
    "aufzeigest": "aufzeigen",
    "aufzeiget": "aufzeigen",
    "aufzeigst": "aufzeigen",
    "aufzeigt": "aufzeigen",
    "aufzeigte": "aufzeigen",
    "aufzeigten": "aufzeigen",
    "aufzeigtest": "aufzeigen",
    "aufzeigtet": "aufzeigen",
    "aufziehe": "aufziehen",
    "aufziehend": "aufziehen",
    "aufziehende": "aufziehend",
    "aufziehendem": "aufziehend",
    "aufziehenden": "aufziehend",
    "aufziehender": "aufziehend",
    "aufziehendes": "aufziehend",
    "aufziehest": "aufziehen",
    "aufziehet": "aufziehen",
    "aufziehst": "aufziehen",
    "aufzieht": "aufziehen",
    "aufzog": "aufziehen",
    "aufzogen": "aufziehen",
    "aufzogst": "aufziehen",
    "aufzogt": "aufziehen",
    "aufzuarbeiten": "aufarbeiten",
    "aufzuatmen": "aufatmen",
    "aufzubacken": "aufbacken",
    "aufzubahren": "aufbahren",
    "aufzubauen": "aufbauen",
    "aufzubauschen": "aufbauschen",
    "aufzubegehren": "aufbegehren",
    "aufzubehalten": "aufbehalten",
    "aufzubeißen": "aufbeißen",
    "aufzubekommen": "aufbekommen",
    "aufzubereiten": "aufbereiten",
    "aufzubeschwören": "aufbeschwören",
    "aufzubessern": "aufbessern",
    "aufzubetten": "aufbetten",
    "aufzubewahren": "aufbewahren",
    "aufzubiegen": "aufbiegen",
    "aufzubieten": "aufbieten",
    "aufzubinden": "aufbinden",
    "aufzublasen": "aufblasen",
    "aufzubleiben": "aufbleiben",
    "aufzublenden": "aufblenden",
    "aufzublitzen": "aufblitzen",
    "aufzublähen": "aufblähen",
    "aufzublättern": "aufblättern",
    "aufzublühen": "aufblühen",
    "aufzubraten": "aufbraten",
    "aufzubrauchen": "aufbrauchen",
    "aufzubrausen": "aufbrausen",
    "aufzubrechen": "aufbrechen",
    "aufzubrennen": "aufbrennen",
    "aufzubringen": "aufbringen",
    "aufzubrummen": "aufbrummen",
    "aufzubrühen": "aufbrühen",
    "aufzubäumen": "aufbäumen",
    "aufzubügeln": "aufbügeln",
    "aufzubürden": "aufbürden",
    "aufzudampfen": "aufdampfen",
    "aufzudecken": "aufdecken",
    "aufzudonnern": "aufdonnern",
    "aufzudrehen": "aufdrehen",
    "aufzudrängen": "aufdrängen",
    "aufzudröseln": "aufdröseln",
    "aufzudrücken": "aufdrücken",
    "aufzudämmen": "aufdämmen",
    "aufzuerlegen": "auferlegen",
    "aufzuerstehen": "auferstehen",
    "aufzuessen": "aufessen",
    "aufzufahren": "auffahren",
    "aufzufallen": "auffallen",
    "aufzufangen": "auffangen",
    "aufzufassen": "auffassen",
    "aufzufinden": "auffinden",
    "aufzufischen": "auffischen",
    "aufzuflammen": "aufflammen",
    "aufzufliegen": "auffliegen",
    "aufzufordern": "auffordern",
    "aufzuforsten": "aufforsten",
    "aufzufressen": "auffressen",
    "aufzufrischen": "auffrischen",
    "aufzufädeln": "auffädeln",
    "aufzufärben": "auffärben",
    "aufzuführen": "aufführen",
    "aufzufüllen": "auffüllen",
    "aufzugabeln": "aufgabeln",
    "aufzugaloppieren": "aufgaloppieren",
    "aufzugeben": "aufgeben",
    "aufzugehen": "aufgehen",
    "aufzugeilen": "aufgeilen",
    "aufzugießen": "aufgießen",
    "aufzugleisen": "aufgleisen",
    "aufzugliedern": "aufgliedern",
    "aufzuglimmen": "aufglimmen",
    "aufzuglühen": "aufglühen",
    "aufzugreifen": "aufgreifen",
    "aufzuhaken": "aufhaken",
    "aufzuhalsen": "aufhalsen",
    "aufzuhalten": "aufhalten",
    "aufzuhauen": "aufhauen",
    "aufzuheben": "aufheben",
    "aufzuheitern": "aufheitern",
    "aufzuhellen": "aufhellen",
    "aufzuhetzen": "aufhetzen",
    "aufzuholen": "aufholen",
    "aufzuhorchen": "aufhorchen",
    "aufzuhängen": "aufhängen",
    "aufzuhärten": "aufhärten",
    "aufzuhören": "aufhören",
    "aufzujagen": "aufjagen",
    "aufzujauchzen": "aufjauchzen",
    "aufzukaufen": "aufkaufen",
    "aufzukeimen": "aufkeimen",
    "aufzuklappen": "aufklappen",
    "aufzuklaren": "aufklaren",
    "aufzuklauben": "aufklauben",
    "aufzukleben": "aufkleben",
    "aufzuklingeln": "aufklingeln",
    "aufzuklinken": "aufklinken",
    "aufzuklären": "aufklären",
    "aufzuknoten": "aufknoten",
    "aufzuknöpfen": "aufknöpfen",
    "aufzuknüpfen": "aufknüpfen",
    "aufzukochen": "aufkochen",
    "aufzukommen": "aufkommen",
    "aufzukratzen": "aufkratzen",
    "aufzukrempeln": "aufkrempeln",
    "aufzukreuzen": "aufkreuzen",
    "aufzukriegen": "aufkriegen",
    "aufzukämmen": "aufkämmen",
    "aufzukündigen": "aufkündigen",
    "aufzulachen": "auflachen",
    "aufzuladen": "aufladen",
    "aufzulassen": "auflassen",
    "aufzulasten": "auflasten",
    "aufzulauern": "auflauern",
    "aufzulaufen": "auflaufen",
    "aufzuleben": "aufleben",
    "aufzulegen": "auflegen",
    "aufzulehnen": "auflehnen",
    "aufzuleimen": "aufleimen",
    "aufzulesen": "auflesen",
    "aufzuleuchten": "aufleuchten",
    "aufzulichten": "auflichten",
    "aufzuliefern": "aufliefern",
    "aufzuliegen": "aufliegen",
    "aufzulisten": "auflisten",
    "aufzulockern": "auflockern",
    "aufzulodern": "auflodern",
    "aufzulösen": "auflösen",
    "aufzumachen": "aufmachen",
    "aufzumarschieren": "aufmarschieren",
    "aufzumeißeln": "aufmeißeln",
    "aufzumerken": "aufmerken",
    "aufzumotzen": "aufmotzen",
    "aufzumuntern": "aufmuntern",
    "aufzumöbeln": "aufmöbeln",
    "aufzunageln": "aufnageln",
    "aufzunehmen": "aufnehmen",
    "aufzunähen": "aufnähen",
    "aufzuopfern": "aufopfern",
    "aufzupassen": "aufpassen",
    "aufzupflanzen": "aufpflanzen",
    "aufzupfropfen": "aufpfropfen",
    "aufzuplatzen": "aufplatzen",
    "aufzuplustern": "aufplustern",
    "aufzupolieren": "aufpolieren",
    "aufzupolstern": "aufpolstern",
    "aufzupoppen": "aufpoppen",
    "aufzuprallen": "aufprallen",
    "aufzuprobieren": "aufprobieren",
    "aufzuprägen": "aufprägen",
    "aufzupumpen": "aufpumpen",
    "aufzuputschen": "aufputschen",
    "aufzuputzen": "aufputzen",
    "aufzupäppeln": "aufpäppeln",
    "aufzuquellen": "aufquellen",
    "aufzuraffen": "aufraffen",
    "aufzuragen": "aufragen",
    "aufzurappeln": "aufrappeln",
    "aufzurauchen": "aufrauchen",
    "aufzurauen": "aufrauen",
    "aufzurauhen": "aufrauhen",
    "aufzurechnen": "aufrechnen",
    "aufzuregen": "aufregen",
    "aufzureiben": "aufreiben",
    "aufzureihen": "aufreihen",
    "aufzureiten": "aufreiten",
    "aufzureizen": "aufreizen",
    "aufzureißen": "aufreißen",
    "aufzuribbeln": "aufribbeln",
    "aufzurichten": "aufrichten",
    "aufzurollen": "aufrollen",
    "aufzurufen": "aufrufen",
    "aufzurunden": "aufrunden",
    "aufzuräumen": "aufräumen",
    "aufzurühren": "aufrühren",
    "aufzurüsten": "aufrüsten",
    "aufzurütteln": "aufrütteln",
    "aufzusagen": "aufsagen",
    "aufzusammeln": "aufsammeln",
    "aufzusaugen": "aufsaugen",
    "aufzuschauen": "aufschauen",
    "aufzuschaukeln": "aufschaukeln",
    "aufzuscheinen": "aufscheinen",
    "aufzuscheuchen": "aufscheuchen",
    "aufzuscheuern": "aufscheuern",
    "aufzuschichten": "aufschichten",
    "aufzuschieben": "aufschieben",
    "aufzuschießen": "aufschießen",
    "aufzuschinden": "aufschinden",
    "aufzuschlagen": "aufschlagen",
    "aufzuschließen": "aufschließen",
    "aufzuschlitzen": "aufschlitzen",
    "aufzuschluchzen": "aufschluchzen",
    "aufzuschlämmen": "aufschlämmen",
    "aufzuschlüsseln": "aufschlüsseln",
    "aufzuschmeißen": "aufschmeißen",
    "aufzuschnallen": "aufschnallen",
    "aufzuschnappen": "aufschnappen",
    "aufzuschneiden": "aufschneiden",
    "aufzuschnellen": "aufschnellen",
    "aufzuschnüren": "aufschnüren",
    "aufzuschrauben": "aufschrauben",
    "aufzuschrecken": "aufschrecken",
    "aufzuschreiben": "aufschreiben",
    "aufzuschreien": "aufschreien",
    "aufzuschrumpfen": "aufschrumpfen",
    "aufzuschwatzen": "aufschwatzen",
    "aufzuschwemmen": "aufschwemmen",
    "aufzuschwingen": "aufschwingen",
    "aufzuschürfen": "aufschürfen",
    "aufzuschütteln": "aufschütteln",
    "aufzuschütten": "aufschütten",
    "aufzusehen": "aufsehen",
    "aufzusetzen": "aufsetzen",
    "aufzuseufzen": "aufseufzen",
    "aufzusitzen": "aufsitzen",
    "aufzuspalten": "aufspalten",
    "aufzusparen": "aufsparen",
    "aufzuspeichern": "aufspeichern",
    "aufzusperren": "aufsperren",
    "aufzuspielen": "aufspielen",
    "aufzuspießen": "aufspießen",
    "aufzuspinnen": "aufspinnen",
    "aufzusprengen": "aufsprengen",
    "aufzuspringen": "aufspringen",
    "aufzuspritzen": "aufspritzen",
    "aufzuspulen": "aufspulen",
    "aufzuspüren": "aufspüren",
    "aufzustacheln": "aufstacheln",
    "aufzustampfen": "aufstampfen",
    "aufzustapeln": "aufstapeln",
    "aufzustauen": "aufstauen",
    "aufzustechen": "aufstechen",
    "aufzustecken": "aufstecken",
    "aufzustehen": "aufstehen",
    "aufzusteigen": "aufsteigen",
    "aufzustellen": "aufstellen",
    "aufzustemmen": "aufstemmen",
    "aufzustielen": "aufstielen",
    "aufzustiften": "aufstiften",
    "aufzustocken": "aufstocken",
    "aufzustoßen": "aufstoßen",
    "aufzustreben": "aufstreben",
    "aufzustreichen": "aufstreichen",
    "aufzustöbern": "aufstöbern",
    "aufzustülpen": "aufstülpen",
    "aufzustützen": "aufstützen",
    "aufzusuchen": "aufsuchen",
    "aufzutakeln": "auftakeln",
    "aufzutanken": "auftanken",
    "aufzutauchen": "auftauchen",
    "aufzutauen": "auftauen",
    "aufzuteilen": "aufteilen",
    "aufzutischen": "auftischen",
    "aufzutragen": "auftragen",
    "aufzutreffen": "auftreffen",
    "aufzutreiben": "auftreiben",
    "aufzutrennen": "auftrennen",
    "aufzutreten": "auftreten",
    "aufzutrumpfen": "auftrumpfen",
    "aufzutürmen": "auftürmen",
    "aufzuwachen": "aufwachen",
    "aufzuwachsen": "aufwachsen",
    "aufzuwallen": "aufwallen",
    "aufzuwalzen": "aufwalzen",
    "aufzuwarten": "aufwarten",
    "aufzuwaschen": "aufwaschen",
    "aufzuwecken": "aufwecken",
    "aufzuweichen": "aufweichen",
    "aufzuweisen": "aufweisen",
    "aufzuwenden": "aufwenden",
    "aufzuwerfen": "aufwerfen",
    "aufzuwerten": "aufwerten",
    "aufzuwiegeln": "aufwiegeln",
    "aufzuwiegen": "aufwiegen",
    "aufzuwinden": "aufwinden",
    "aufzuwirbeln": "aufwirbeln",
    "aufzuwischen": "aufwischen",
    "aufzuwärmen": "aufwärmen",
    "aufzuwühlen": "aufwühlen",
    "aufzuzehren": "aufzehren",
    "aufzuzeichnen": "aufzeichnen",
    "aufzuzeigen": "aufzeigen",
    "aufzuziehen": "aufziehen",
    "aufzuzwingen": "aufzwingen",
    "aufzuzwirbeln": "aufzwirbeln",
    "aufzuzählen": "aufzählen",
    "aufzuzäumen": "aufzäumen",
    "aufzwang": "aufzwingen",
    "aufzwangen": "aufzwingen",
    "aufzwangst": "aufzwingen",
    "aufzwangt": "aufzwingen",
    "aufzwinge": "aufzwingen",
    "aufzwingend": "aufzwingen",
    "aufzwingende": "aufzwingend",
    "aufzwingendem": "aufzwingend",
    "aufzwingenden": "aufzwingend",
    "aufzwingender": "aufzwingend",
    "aufzwingendes": "aufzwingend",
    "aufzwingest": "aufzwingen",
    "aufzwinget": "aufzwingen",
    "aufzwingst": "aufzwingen",
    "aufzwingt": "aufzwingen",
    "aufzwirbele": "aufzwirbeln",
    "aufzwirbelnd": "aufzwirbeln",
    "aufzwirbelnde": "aufzwirbelnd",
    "aufzwirbelndem": "aufzwirbelnd",
    "aufzwirbelnden": "aufzwirbelnd",
    "aufzwirbelnder": "aufzwirbelnd",
    "aufzwirbelndere": "aufzwirbelnd",
    "aufzwirbelnderem": "aufzwirbelnd",
    "aufzwirbelnderen": "aufzwirbelnd",
    "aufzwirbelnderer": "aufzwirbelnd",
    "aufzwirbelnderes": "aufzwirbelnd",
    "aufzwirbelndes": "aufzwirbelnd",
    "aufzwirbelndste": "aufzwirbelnd",
    "aufzwirbelndstem": "aufzwirbelnd",
    "aufzwirbelndsten": "aufzwirbelnd",
    "aufzwirbelndster": "aufzwirbelnd",
    "aufzwirbelndstes": "aufzwirbelnd",
    "aufzwirbelst": "aufzwirbeln",
    "aufzwirbelt": "aufzwirbeln",
    "aufzwirbelte": "aufzwirbeln",
    "aufzwirbelten": "aufzwirbeln",
    "aufzwirbeltest": "aufzwirbeln",
    "aufzwirbeltet": "aufzwirbeln",
    "aufzwirble": "aufzwirbeln",
    "aufzwänge": "aufzwingen",
    "aufzwängen": "aufzwingen",
    "aufzwängest": "aufzwingen",
    "aufzwänget": "aufzwingen",
    "aufzähle": "aufzählen",
    "aufzählend": "aufzählen",
    "aufzählende": "aufzählend",
    "aufzählendem": "aufzählend",
    "aufzählenden": "aufzählend",
    "aufzählender": "aufzählend",
    "aufzählendes": "aufzählend",
    "aufzählest": "aufzählen",
    "aufzählet": "aufzählen",
    "aufzählst": "aufzählen",
    "aufzählt": "aufzählen",
    "aufzählte": "aufzählen",
    "aufzählten": "aufzählen",
    "aufzähltest": "aufzählen",
    "aufzähltet": "aufzählen",
    "aufzäume": "aufzäumen",
    "aufzäumend": "aufzäumen",
    "aufzäumende": "aufzäumend",
    "aufzäumendem": "aufzäumend",
    "aufzäumenden": "aufzäumend",
    "aufzäumender": "aufzäumend",
    "aufzäumendere": "aufzäumend",
    "aufzäumenderem": "aufzäumend",
    "aufzäumenderen": "aufzäumend",
    "aufzäumenderer": "aufzäumend",
    "aufzäumenderes": "aufzäumend",
    "aufzäumendes": "aufzäumend",
    "aufzäumendste": "aufzäumend",
    "aufzäumendstem": "aufzäumend",
    "aufzäumendsten": "aufzäumend",
    "aufzäumendster": "aufzäumend",
    "aufzäumendstes": "aufzäumend",
    "aufzäumest": "aufzäumen",
    "aufzäumet": "aufzäumen",
    "aufzäumst": "aufzäumen",
    "aufzäumt": "aufzäumen",
    "aufzäumte": "aufzäumen",
    "aufzäumten": "aufzäumen",
    "aufzäumtest": "aufzäumen",
    "aufzäumtet": "aufzäumen",
    "aufzöge": "aufziehen",
    "aufzögen": "aufziehen",
    "aufzögest": "aufziehen",
    "aufzöget": "aufziehen",
    "aufäße": "aufessen",
    "aufäßen": "aufessen",
    "aufäßest": "aufessen",
    "aufäßet": "aufessen",
    "augenblicklichem": "augenblicklich",
    "augenblicklichen": "augenblicklich",
    "augenblicklicher": "augenblicklich",
    "augenblickliches": "augenblicklich",
    "augenfälligem": "augenfällig",
    "augenfälligen": "augenfällig",
    "augenfälliger": "augenfällig",
    "augenfälligere": "augenfällig",
    "augenfälligerem": "augenfällig",
    "augenfälligeren": "augenfällig",
    "augenfälligerer": "augenfällig",
    "augenfälligeres": "augenfällig",
    "augenfälliges": "augenfällig",
    "augenfälligste": "augenfällig",
    "augenfälligstem": "augenfällig",
    "augenfälligsten": "augenfällig",
    "augenfälligster": "augenfällig",
    "augenfälligstes": "augenfällig",
    "augenscheinlichem": "augenscheinlich",
    "augenscheinlichen": "augenscheinlich",
    "augenscheinlicher": "augenscheinlich",
    "augenscheinliches": "augenscheinlich",
    "augenzwinkernde": "augenzwinkernd",
    "augenzwinkerndem": "augenzwinkernd",
    "augenzwinkernden": "augenzwinkernd",
    "augenzwinkernder": "augenzwinkernd",
    "augenzwinkerndes": "augenzwinkernd",
    "auktioniere": "auktionieren",
    "auktionierend": "auktionieren",
    "auktionierende": "auktionierend",
    "auktionierendem": "auktionierend",
    "auktionierenden": "auktionierend",
    "auktionierender": "auktionierend",
    "auktionierendes": "auktionierend",
    "auktionierest": "auktionieren",
    "auktionieret": "auktionieren",
    "auktionierst": "auktionieren",
    "auktioniert": "auktionieren",
    "auktionierte": "auktionieren",
    "auktioniertem": "auktioniert",
    "auktionierten": "auktionieren",
    "auktionierter": "auktioniert",
    "auktioniertes": "auktioniert",
    "auktioniertest": "auktionieren",
    "auktioniertet": "auktionieren",
    "ausarbeite": "ausarbeiten",
    "ausarbeitend": "ausarbeiten",
    "ausarbeitende": "ausarbeitend",
    "ausarbeitendem": "ausarbeitend",
    "ausarbeitenden": "ausarbeitend",
    "ausarbeitender": "ausarbeitend",
    "ausarbeitendes": "ausarbeitend",
    "ausarbeitest": "ausarbeiten",
    "ausarbeitet": "ausarbeiten",
    "ausarbeitete": "ausarbeiten",
    "ausarbeiteten": "ausarbeiten",
    "ausarbeitetest": "ausarbeiten",
    "ausarbeitetet": "ausarbeiten",
    "ausarte": "ausarten",
    "ausartend": "ausarten",
    "ausartende": "ausartend",
    "ausartendem": "ausartend",
    "ausartenden": "ausartend",
    "ausartender": "ausartend",
    "ausartendere": "ausartend",
    "ausartenderem": "ausartend",
    "ausartenderen": "ausartend",
    "ausartenderer": "ausartend",
    "ausartenderes": "ausartend",
    "ausartendes": "ausartend",
    "ausartendste": "ausartend",
    "ausartendstem": "ausartend",
    "ausartendsten": "ausartend",
    "ausartendster": "ausartend",
    "ausartendstes": "ausartend",
    "ausartest": "ausarten",
    "ausartet": "ausarten",
    "ausartete": "ausarten",
    "ausarteten": "ausarten",
    "ausartetest": "ausarten",
    "ausartetet": "ausarten",
    "ausatme": "ausatmen",
    "ausatmend": "ausatmen",
    "ausatmende": "ausatmend",
    "ausatmendem": "ausatmend",
    "ausatmenden": "ausatmend",
    "ausatmender": "ausatmend",
    "ausatmendes": "ausatmend",
    "ausatmest": "ausatmen",
    "ausatmet": "ausatmen",
    "ausatmete": "ausatmen",
    "ausatmeten": "ausatmen",
    "ausatmetest": "ausatmen",
    "ausatmetet": "ausatmen",
    "ausaß": "ausessen",
    "ausaßen": "ausessen",
    "ausaßt": "ausessen",
    "ausbade": "ausbaden",
    "ausbadend": "ausbaden",
    "ausbadende": "ausbadend",
    "ausbadendem": "ausbadend",
    "ausbadenden": "ausbadend",
    "ausbadender": "ausbadend",
    "ausbadendes": "ausbadend",
    "ausbadest": "ausbaden",
    "ausbadet": "ausbaden",
    "ausbadete": "ausbaden",
    "ausbadeten": "ausbaden",
    "ausbadetest": "ausbaden",
    "ausbadetet": "ausbaden",
    "ausbaggere": "ausbaggern",
    "ausbaggernd": "ausbaggern",
    "ausbaggernde": "ausbaggernd",
    "ausbaggerndem": "ausbaggernd",
    "ausbaggernden": "ausbaggernd",
    "ausbaggernder": "ausbaggernd",
    "ausbaggerndes": "ausbaggernd",
    "ausbaggerst": "ausbaggern",
    "ausbaggert": "ausbaggern",
    "ausbaggerte": "ausbaggern",
    "ausbaggerten": "ausbaggern",
    "ausbaggertest": "ausbaggern",
    "ausbaggertet": "ausbaggern",
    "ausbaldowere": "ausbaldowern",
    "ausbaldowernd": "ausbaldowern",
    "ausbaldowernde": "ausbaldowernd",
    "ausbaldowerndem": "ausbaldowernd",
    "ausbaldowernden": "ausbaldowernd",
    "ausbaldowernder": "ausbaldowernd",
    "ausbaldowerndes": "ausbaldowernd",
    "ausbaldowerst": "ausbaldowern",
    "ausbaldowert": "ausbaldowern",
    "ausbaldowerte": "ausbaldowern",
    "ausbaldowertem": "ausbaldowert",
    "ausbaldowerten": "ausbaldowern",
    "ausbaldowerter": "ausbaldowert",
    "ausbaldowertes": "ausbaldowert",
    "ausbaldowertest": "ausbaldowern",
    "ausbaldowertet": "ausbaldowern",
    "ausbat": "ausbitten",
    "ausbaten": "ausbitten",
    "ausbatest": "ausbitten",
    "ausbatet": "ausbitten",
    "ausbauche": "ausbauchen",
    "ausbauchend": "ausbauchen",
    "ausbauchende": "ausbauchend",
    "ausbauchendem": "ausbauchend",
    "ausbauchenden": "ausbauchend",
    "ausbauchender": "ausbauchend",
    "ausbauchendere": "ausbauchend",
    "ausbauchenderem": "ausbauchend",
    "ausbauchenderen": "ausbauchend",
    "ausbauchenderer": "ausbauchend",
    "ausbauchenderes": "ausbauchend",
    "ausbauchendes": "ausbauchend",
    "ausbauchendste": "ausbauchend",
    "ausbauchendstem": "ausbauchend",
    "ausbauchendsten": "ausbauchend",
    "ausbauchendster": "ausbauchend",
    "ausbauchendstes": "ausbauchend",
    "ausbauchest": "ausbauchen",
    "ausbauchet": "ausbauchen",
    "ausbauchst": "ausbauchen",
    "ausbaucht": "ausbauchen",
    "ausbauchte": "ausbauchen",
    "ausbauchten": "ausbauchen",
    "ausbauchtest": "ausbauchen",
    "ausbauchtet": "ausbauchen",
    "ausbaue": "ausbauen",
    "ausbauend": "ausbauen",
    "ausbauende": "ausbauend",
    "ausbauendem": "ausbauend",
    "ausbauenden": "ausbauend",
    "ausbauender": "ausbauend",
    "ausbauendes": "ausbauend",
    "ausbauest": "ausbauen",
    "ausbauet": "ausbauen",
    "ausbaufähige": "ausbaufähig",
    "ausbaufähigem": "ausbaufähig",
    "ausbaufähigen": "ausbaufähig",
    "ausbaufähiger": "ausbaufähig",
    "ausbaufähigere": "ausbaufähig",
    "ausbaufähigerem": "ausbaufähig",
    "ausbaufähigeren": "ausbaufähig",
    "ausbaufähigerer": "ausbaufähig",
    "ausbaufähigeres": "ausbaufähig",
    "ausbaufähiges": "ausbaufähig",
    "ausbaufähigste": "ausbaufähig",
    "ausbaufähigstem": "ausbaufähig",
    "ausbaufähigsten": "ausbaufähig",
    "ausbaufähigster": "ausbaufähig",
    "ausbaufähigstes": "ausbaufähig",
    "ausbaust": "ausbauen",
    "ausbaut": "ausbauen",
    "ausbaute": "ausbauen",
    "ausbautest": "ausbauen",
    "ausbautet": "ausbauen",
    "ausbeiße": "ausbeißen",
    "ausbeißend": "ausbeißen",
    "ausbeißende": "ausbeißend",
    "ausbeißendem": "ausbeißend",
    "ausbeißenden": "ausbeißend",
    "ausbeißender": "ausbeißend",
    "ausbeißendes": "ausbeißend",
    "ausbeißest": "ausbeißen",
    "ausbeißet": "ausbeißen",
    "ausbeißt": "ausbeißen",
    "ausbessere": "ausbessern",
    "ausbessernd": "ausbessern",
    "ausbessernde": "ausbessernd",
    "ausbesserndem": "ausbessernd",
    "ausbessernden": "ausbessernd",
    "ausbessernder": "ausbessernd",
    "ausbesserndere": "ausbessernd",
    "ausbessernderem": "ausbessernd",
    "ausbessernderen": "ausbessernd",
    "ausbessernderer": "ausbessernd",
    "ausbessernderes": "ausbessernd",
    "ausbesserndes": "ausbessernd",
    "ausbesserndste": "ausbessernd",
    "ausbesserndstem": "ausbessernd",
    "ausbesserndsten": "ausbessernd",
    "ausbesserndster": "ausbessernd",
    "ausbesserndstes": "ausbessernd",
    "ausbesserst": "ausbessern",
    "ausbessert": "ausbessern",
    "ausbesserte": "ausbessern",
    "ausbesserten": "ausbessern",
    "ausbessertest": "ausbessern",
    "ausbessertet": "ausbessern",
    "ausbetoniere": "ausbetonieren",
    "ausbetonierend": "ausbetonieren",
    "ausbetonierende": "ausbetonierend",
    "ausbetonierendem": "ausbetonierend",
    "ausbetonierenden": "ausbetonierend",
    "ausbetonierender": "ausbetonierend",
    "ausbetonierendes": "ausbetonierend",
    "ausbetonierest": "ausbetonieren",
    "ausbetonieret": "ausbetonieren",
    "ausbetonierst": "ausbetonieren",
    "ausbetoniert": "ausbetonieren",
    "ausbetonierte": "ausbetonieren",
    "ausbetoniertem": "ausbetoniert",
    "ausbetonierten": "ausbetonieren",
    "ausbetonierter": "ausbetoniert",
    "ausbetoniertes": "ausbetoniert",
    "ausbetoniertest": "ausbetonieren",
    "ausbetoniertet": "ausbetonieren",
    "ausbeule": "ausbeulen",
    "ausbeulend": "ausbeulen",
    "ausbeulende": "ausbeulend",
    "ausbeulendem": "ausbeulend",
    "ausbeulenden": "ausbeulend",
    "ausbeulender": "ausbeulend",
    "ausbeulendes": "ausbeulend",
    "ausbeulest": "ausbeulen",
    "ausbeulet": "ausbeulen",
    "ausbeulst": "ausbeulen",
    "ausbeult": "ausbeulen",
    "ausbeulte": "ausbeulen",
    "ausbeulten": "ausbeulen",
    "ausbeultest": "ausbeulen",
    "ausbeultet": "ausbeulen",
    "ausbeute": "ausbeuten",
    "ausbeutele": "ausbeuteln",
    "ausbeutelnd": "ausbeuteln",
    "ausbeutelnde": "ausbeutelnd",
    "ausbeutelndem": "ausbeutelnd",
    "ausbeutelnden": "ausbeutelnd",
    "ausbeutelnder": "ausbeutelnd",
    "ausbeutelndes": "ausbeutelnd",
    "ausbeutelst": "ausbeuteln",
    "ausbeutelt": "ausbeuteln",
    "ausbeutelte": "ausbeuteln",
    "ausbeutelten": "ausbeuteln",
    "ausbeuteltest": "ausbeuteln",
    "ausbeuteltet": "ausbeuteln",
    "ausbeutend": "ausbeuten",
    "ausbeutende": "ausbeutend",
    "ausbeutendem": "ausbeutend",
    "ausbeutenden": "ausbeutend",
    "ausbeutender": "ausbeutend",
    "ausbeutendere": "ausbeutend",
    "ausbeutenderem": "ausbeutend",
    "ausbeutenderen": "ausbeutend",
    "ausbeutenderer": "ausbeutend",
    "ausbeutenderes": "ausbeutend",
    "ausbeutendes": "ausbeutend",
    "ausbeutendste": "ausbeutend",
    "ausbeutendstem": "ausbeutend",
    "ausbeutendsten": "ausbeutend",
    "ausbeutendster": "ausbeutend",
    "ausbeutendstes": "ausbeutend",
    "ausbeutest": "ausbeuten",
    "ausbeutet": "ausbeuten",
    "ausbeutete": "ausbeuten",
    "ausbeuteten": "ausbeuten",
    "ausbeutetest": "ausbeuten",
    "ausbeutetet": "ausbeuten",
    "ausbeutle": "ausbeuteln",
    "ausbezahle": "ausbezahlen",
    "ausbezahlend": "ausbezahlen",
    "ausbezahlende": "ausbezahlend",
    "ausbezahlendem": "ausbezahlend",
    "ausbezahlenden": "ausbezahlend",
    "ausbezahlender": "ausbezahlend",
    "ausbezahlendes": "ausbezahlend",
    "ausbezahlest": "ausbezahlen",
    "ausbezahlet": "ausbezahlen",
    "ausbezahlst": "ausbezahlen",
    "ausbezahlt": "ausbezahlen",
    "ausbezahlte": "ausbezahlen",
    "ausbezahltem": "ausbezahlt",
    "ausbezahlten": "ausbezahlen",
    "ausbezahlter": "ausbezahlt",
    "ausbezahltes": "ausbezahlt",
    "ausbezahltest": "ausbezahlen",
    "ausbezahltet": "ausbezahlen",
    "ausbiege": "ausbiegen",
    "ausbiegend": "ausbiegen",
    "ausbiegende": "ausbiegend",
    "ausbiegendem": "ausbiegend",
    "ausbiegenden": "ausbiegend",
    "ausbiegender": "ausbiegend",
    "ausbiegendere": "ausbiegend",
    "ausbiegenderem": "ausbiegend",
    "ausbiegenderen": "ausbiegend",
    "ausbiegenderer": "ausbiegend",
    "ausbiegenderes": "ausbiegend",
    "ausbiegendes": "ausbiegend",
    "ausbiegendste": "ausbiegend",
    "ausbiegendstem": "ausbiegend",
    "ausbiegendsten": "ausbiegend",
    "ausbiegendster": "ausbiegend",
    "ausbiegendstes": "ausbiegend",
    "ausbiegest": "ausbiegen",
    "ausbieget": "ausbiegen",
    "ausbiegst": "ausbiegen",
    "ausbiegt": "ausbiegen",
    "ausbiete": "ausbieten",
    "ausbietend": "ausbieten",
    "ausbietende": "ausbietend",
    "ausbietendem": "ausbietend",
    "ausbietenden": "ausbietend",
    "ausbietender": "ausbietend",
    "ausbietendes": "ausbietend",
    "ausbietest": "ausbieten",
    "ausbietet": "ausbieten",
    "ausbilde": "ausbilden",
    "ausbildend": "ausbilden",
    "ausbildende": "ausbildend",
    "ausbildendem": "ausbildend",
    "ausbildenden": "ausbildend",
    "ausbildender": "ausbildend",
    "ausbildendes": "ausbildend",
    "ausbildest": "ausbilden",
    "ausbildet": "ausbilden",
    "ausbildete": "ausbilden",
    "ausbildeten": "ausbilden",
    "ausbildetest": "ausbilden",
    "ausbildetet": "ausbilden",
    "ausbisse": "ausbeißen",
    "ausbissen": "ausbeißen",
    "ausbissest": "ausbeißen",
    "ausbisset": "ausbeißen",
    "ausbitte": "ausbitten",
    "ausbittend": "ausbitten",
    "ausbittende": "ausbittend",
    "ausbittendem": "ausbittend",
    "ausbittenden": "ausbittend",
    "ausbittender": "ausbittend",
    "ausbittendes": "ausbittend",
    "ausbittest": "ausbitten",
    "ausbittet": "ausbitten",
    "ausbiß": "ausbeißen",
    "ausbißt": "ausbeißen",
    "ausblase": "ausblasen",
    "ausblasend": "ausblasen",
    "ausblasende": "ausblasend",
    "ausblasendem": "ausblasend",
    "ausblasenden": "ausblasend",
    "ausblasender": "ausblasend",
    "ausblasendes": "ausblasend",
    "ausblasest": "ausblasen",
    "ausblaset": "ausblasen",
    "ausblast": "ausblasen",
    "ausbleibe": "ausbleiben",
    "ausbleibend": "ausbleiben",
    "ausbleibende": "ausbleibend",
    "ausbleibendem": "ausbleibend",
    "ausbleibenden": "ausbleibend",
    "ausbleibender": "ausbleibend",
    "ausbleibendes": "ausbleibend",
    "ausbleibest": "ausbleiben",
    "ausbleibet": "ausbleiben",
    "ausbleibst": "ausbleiben",
    "ausbleibt": "ausbleiben",
    "ausbleiche": "ausbleichen",
    "ausbleichend": "ausbleichen",
    "ausbleichende": "ausbleichend",
    "ausbleichendem": "ausbleichend",
    "ausbleichenden": "ausbleichend",
    "ausbleichender": "ausbleichend",
    "ausbleichendere": "ausbleichend",
    "ausbleichenderem": "ausbleichend",
    "ausbleichenderen": "ausbleichend",
    "ausbleichenderer": "ausbleichend",
    "ausbleichenderes": "ausbleichend",
    "ausbleichendes": "ausbleichend",
    "ausbleichendste": "ausbleichend",
    "ausbleichendstem": "ausbleichend",
    "ausbleichendsten": "ausbleichend",
    "ausbleichendster": "ausbleichend",
    "ausbleichendstes": "ausbleichend",
    "ausbleichest": "ausbleichen",
    "ausbleichet": "ausbleichen",
    "ausbleichst": "ausbleichen",
    "ausbleicht": "ausbleichen",
    "ausblende": "ausblenden",
    "ausblendend": "ausblenden",
    "ausblendende": "ausblendend",
    "ausblendendem": "ausblendend",
    "ausblendenden": "ausblendend",
    "ausblendender": "ausblendend",
    "ausblendendes": "ausblendend",
    "ausblendest": "ausblenden",
    "ausblendet": "ausblenden",
    "ausblendete": "ausblenden",
    "ausblendeten": "ausblenden",
    "ausblendetest": "ausblenden",
    "ausblendetet": "ausblenden",
    "ausblich": "ausbleichen",
    "ausbliche": "ausbleichen",
    "ausblichen": "ausbleichen",
    "ausblichest": "ausbleichen",
    "ausblichet": "ausbleichen",
    "ausblichst": "ausbleichen",
    "ausblicht": "ausbleichen",
    "ausblieb": "ausbleiben",
    "ausbliebe": "ausbleiben",
    "ausblieben": "ausbleiben",
    "ausbliebest": "ausbleiben",
    "ausbliebet": "ausbleiben",
    "ausbliebst": "ausbleiben",
    "ausbliebt": "ausbleiben",
    "ausblies": "ausblasen",
    "ausbliese": "ausblasen",
    "ausbliesen": "ausblasen",
    "ausbliesest": "ausblasen",
    "ausblieset": "ausblasen",
    "ausbliest": "ausblasen",
    "ausblute": "ausbluten",
    "ausblutend": "ausbluten",
    "ausblutende": "ausblutend",
    "ausblutendem": "ausblutend",
    "ausblutenden": "ausblutend",
    "ausblutender": "ausblutend",
    "ausblutendere": "ausblutend",
    "ausblutenderem": "ausblutend",
    "ausblutenderen": "ausblutend",
    "ausblutenderer": "ausblutend",
    "ausblutenderes": "ausblutend",
    "ausblutendes": "ausblutend",
    "ausblutendste": "ausblutend",
    "ausblutendstem": "ausblutend",
    "ausblutendsten": "ausblutend",
    "ausblutendster": "ausblutend",
    "ausblutendstes": "ausblutend",
    "ausblutest": "ausbluten",
    "ausblutet": "ausbluten",
    "ausblutete": "ausbluten",
    "ausbluteten": "ausbluten",
    "ausblutetest": "ausbluten",
    "ausblutetet": "ausbluten",
    "ausbläst": "ausblasen",
    "ausbog": "ausbiegen",
    "ausbogen": "ausbiegen",
    "ausbogst": "ausbiegen",
    "ausbogt": "ausbiegen",
    "ausbohre": "ausbohren",
    "ausbohrend": "ausbohren",
    "ausbohrende": "ausbohrend",
    "ausbohrendem": "ausbohrend",
    "ausbohrenden": "ausbohrend",
    "ausbohrender": "ausbohrend",
    "ausbohrendere": "ausbohrend",
    "ausbohrenderem": "ausbohrend",
    "ausbohrenderen": "ausbohrend",
    "ausbohrenderer": "ausbohrend",
    "ausbohrenderes": "ausbohrend",
    "ausbohrendes": "ausbohrend",
    "ausbohrendste": "ausbohrend",
    "ausbohrendstem": "ausbohrend",
    "ausbohrendsten": "ausbohrend",
    "ausbohrendster": "ausbohrend",
    "ausbohrendstes": "ausbohrend",
    "ausbohrest": "ausbohren",
    "ausbohret": "ausbohren",
    "ausbohrst": "ausbohren",
    "ausbohrt": "ausbohren",
    "ausbohrte": "ausbohren",
    "ausbohrten": "ausbohren",
    "ausbohrtest": "ausbohren",
    "ausbohrtet": "ausbohren",
    "ausbombe": "ausbomben",
    "ausbombend": "ausbomben",
    "ausbombende": "ausbombend",
    "ausbombendem": "ausbombend",
    "ausbombenden": "ausbombend",
    "ausbombender": "ausbombend",
    "ausbombendere": "ausbombend",
    "ausbombenderem": "ausbombend",
    "ausbombenderen": "ausbombend",
    "ausbombenderer": "ausbombend",
    "ausbombenderes": "ausbombend",
    "ausbombendes": "ausbombend",
    "ausbombendste": "ausbombend",
    "ausbombendstem": "ausbombend",
    "ausbombendsten": "ausbombend",
    "ausbombendster": "ausbombend",
    "ausbombendstes": "ausbombend",
    "ausbombest": "ausbomben",
    "ausbombet": "ausbomben",
    "ausbombst": "ausbomben",
    "ausbombt": "ausbomben",
    "ausbombte": "ausbomben",
    "ausbombten": "ausbomben",
    "ausbombtest": "ausbomben",
    "ausbombtet": "ausbomben",
    "ausboote": "ausbooten",
    "ausbootend": "ausbooten",
    "ausbootende": "ausbootend",
    "ausbootendem": "ausbootend",
    "ausbootenden": "ausbootend",
    "ausbootender": "ausbootend",
    "ausbootendere": "ausbootend",
    "ausbootenderem": "ausbootend",
    "ausbootenderen": "ausbootend",
    "ausbootenderer": "ausbootend",
    "ausbootenderes": "ausbootend",
    "ausbootendes": "ausbootend",
    "ausbootendste": "ausbootend",
    "ausbootendstem": "ausbootend",
    "ausbootendsten": "ausbootend",
    "ausbootendster": "ausbootend",
    "ausbootendstes": "ausbootend",
    "ausbootest": "ausbooten",
    "ausbootet": "ausbooten",
    "ausbootete": "ausbooten",
    "ausbooteten": "ausbooten",
    "ausbootetest": "ausbooten",
    "ausbootetet": "ausbooten",
    "ausborge": "ausborgen",
    "ausborgend": "ausborgen",
    "ausborgende": "ausborgend",
    "ausborgendem": "ausborgend",
    "ausborgenden": "ausborgend",
    "ausborgender": "ausborgend",
    "ausborgendes": "ausborgend",
    "ausborgest": "ausborgen",
    "ausborget": "ausborgen",
    "ausborgst": "ausborgen",
    "ausborgt": "ausborgen",
    "ausborgte": "ausborgen",
    "ausborgten": "ausborgen",
    "ausborgtest": "ausborgen",
    "ausborgtet": "ausborgen",
    "ausbot": "ausbieten",
    "ausboten": "ausbieten",
    "ausbotest": "ausbieten",
    "ausbotet": "ausbieten",
    "ausbrach": "ausbrechen",
    "ausbrachen": "ausbrechen",
    "ausbrachst": "ausbrechen",
    "ausbracht": "ausbrechen",
    "ausbrachte": "ausbringen",
    "ausbrachten": "ausbringen",
    "ausbrachtest": "ausbringen",
    "ausbrachtet": "ausbringen",
    "ausbrannte": "ausbrennen",
    "ausbrannten": "ausbrennen",
    "ausbranntest": "ausbrennen",
    "ausbranntet": "ausbrennen",
    "ausbrate": "ausbraten",
    "ausbratend": "ausbraten",
    "ausbratende": "ausbratend",
    "ausbratendem": "ausbratend",
    "ausbratenden": "ausbratend",
    "ausbratender": "ausbratend",
    "ausbratendes": "ausbratend",
    "ausbratest": "ausbraten",
    "ausbratet": "ausbraten",
    "ausbreche": "ausbrechen",
    "ausbrechend": "ausbrechen",
    "ausbrechende": "ausbrechend",
    "ausbrechendem": "ausbrechend",
    "ausbrechenden": "ausbrechend",
    "ausbrechender": "ausbrechend",
    "ausbrechendes": "ausbrechend",
    "ausbrechest": "ausbrechen",
    "ausbrechet": "ausbrechen",
    "ausbrecht": "ausbrechen",
    "ausbreite": "ausbreiten",
    "ausbreitend": "ausbreiten",
    "ausbreitende": "ausbreitend",
    "ausbreitendem": "ausbreitend",
    "ausbreitenden": "ausbreitend",
    "ausbreitender": "ausbreitend",
    "ausbreitendere": "ausbreitend",
    "ausbreitenderem": "ausbreitend",
    "ausbreitenderen": "ausbreitend",
    "ausbreitenderer": "ausbreitend",
    "ausbreitenderes": "ausbreitend",
    "ausbreitendes": "ausbreitend",
    "ausbreitendste": "ausbreitend",
    "ausbreitendstem": "ausbreitend",
    "ausbreitendsten": "ausbreitend",
    "ausbreitendster": "ausbreitend",
    "ausbreitendstes": "ausbreitend",
    "ausbreitest": "ausbreiten",
    "ausbreitet": "ausbreiten",
    "ausbreitete": "ausbreiten",
    "ausbreiteten": "ausbreiten",
    "ausbreitetest": "ausbreiten",
    "ausbreitetet": "ausbreiten",
    "ausbremse": "ausbremsen",
    "ausbremsend": "ausbremsen",
    "ausbremsende": "ausbremsend",
    "ausbremsendem": "ausbremsend",
    "ausbremsenden": "ausbremsend",
    "ausbremsender": "ausbremsend",
    "ausbremsendes": "ausbremsend",
    "ausbremsest": "ausbremsen",
    "ausbremset": "ausbremsen",
    "ausbremst": "ausbremsen",
    "ausbremste": "ausbremsen",
    "ausbremsten": "ausbremsen",
    "ausbremstest": "ausbremsen",
    "ausbremstet": "ausbremsen",
    "ausbrenne": "ausbrennen",
    "ausbrennend": "ausbrennen",
    "ausbrennende": "ausbrennend",
    "ausbrennendem": "ausbrennend",
    "ausbrennenden": "ausbrennend",
    "ausbrennender": "ausbrennend",
    "ausbrennendes": "ausbrennend",
    "ausbrennest": "ausbrennen",
    "ausbrennet": "ausbrennen",
    "ausbrennst": "ausbrennen",
    "ausbrennt": "ausbrennen",
    "ausbrichst": "ausbrechen",
    "ausbricht": "ausbrechen",
    "ausbriet": "ausbraten",
    "ausbriete": "ausbraten",
    "ausbrieten": "ausbraten",
    "ausbrietest": "ausbraten",
    "ausbrietet": "ausbraten",
    "ausbringe": "ausbringen",
    "ausbringend": "ausbringen",
    "ausbringende": "ausbringend",
    "ausbringendem": "ausbringend",
    "ausbringenden": "ausbringend",
    "ausbringender": "ausbringend",
    "ausbringendes": "ausbringend",
    "ausbringest": "ausbringen",
    "ausbringet": "ausbringen",
    "ausbringst": "ausbringen",
    "ausbringt": "ausbringen",
    "ausbräche": "ausbrechen",
    "ausbrächen": "ausbrechen",
    "ausbrächest": "ausbrechen",
    "ausbrächet": "ausbrechen",
    "ausbrächte": "ausbringen",
    "ausbrächten": "ausbringen",
    "ausbrächtest": "ausbringen",
    "ausbrächtet": "ausbringen",
    "ausbrät": "ausbraten",
    "ausbrätst": "ausbraten",
    "ausbrüte": "ausbrüten",
    "ausbrütend": "ausbrüten",
    "ausbrütende": "ausbrütend",
    "ausbrütendem": "ausbrütend",
    "ausbrütenden": "ausbrütend",
    "ausbrütender": "ausbrütend",
    "ausbrütendes": "ausbrütend",
    "ausbrütest": "ausbrüten",
    "ausbrütet": "ausbrüten",
    "ausbrütete": "ausbrüten",
    "ausbrüteten": "ausbrüten",
    "ausbrütetest": "ausbrüten",
    "ausbrütetet": "ausbrüten",
    "ausbuche": "ausbuchen",
    "ausbuchend": "ausbuchen",
    "ausbuchende": "ausbuchend",
    "ausbuchendem": "ausbuchend",
    "ausbuchenden": "ausbuchend",
    "ausbuchender": "ausbuchend",
    "ausbuchendes": "ausbuchend",
    "ausbuchest": "ausbuchen",
    "ausbuchet": "ausbuchen",
    "ausbuchst": "ausbuchen",
    "ausbucht": "ausbuchen",
    "ausbuchte": "ausbuchten",
    "ausbuchten": "ausbuchen",
    "ausbuchtend": "ausbuchten",
    "ausbuchtende": "ausbuchtend",
    "ausbuchtendem": "ausbuchtend",
    "ausbuchtenden": "ausbuchtend",
    "ausbuchtender": "ausbuchtend",
    "ausbuchtendes": "ausbuchtend",
    "ausbuchtest": "ausbuchten",
    "ausbuchtet": "ausbuchten",
    "ausbuchtete": "ausbuchten",
    "ausbuchteten": "ausbuchten",
    "ausbuchtetest": "ausbuchten",
    "ausbuchtetet": "ausbuchten",
    "ausbuddele": "ausbuddeln",
    "ausbuddelnd": "ausbuddeln",
    "ausbuddelnde": "ausbuddelnd",
    "ausbuddelndem": "ausbuddelnd",
    "ausbuddelnden": "ausbuddelnd",
    "ausbuddelnder": "ausbuddelnd",
    "ausbuddelndes": "ausbuddelnd",
    "ausbuddelst": "ausbuddeln",
    "ausbuddelt": "ausbuddeln",
    "ausbuddelte": "ausbuddeln",
    "ausbuddelten": "ausbuddeln",
    "ausbuddeltest": "ausbuddeln",
    "ausbuddeltet": "ausbuddeln",
    "ausbuddle": "ausbuddeln",
    "ausbäte": "ausbitten",
    "ausbäten": "ausbitten",
    "ausbätest": "ausbitten",
    "ausbätet": "ausbitten",
    "ausböge": "ausbiegen",
    "ausbögen": "ausbiegen",
    "ausbögest": "ausbiegen",
    "ausböget": "ausbiegen",
    "ausböte": "ausbieten",
    "ausböten": "ausbieten",
    "ausbötest": "ausbieten",
    "ausbötet": "ausbieten",
    "ausbügele": "ausbügeln",
    "ausbügelnd": "ausbügeln",
    "ausbügelnde": "ausbügelnd",
    "ausbügelndem": "ausbügelnd",
    "ausbügelnden": "ausbügelnd",
    "ausbügelnder": "ausbügelnd",
    "ausbügelndes": "ausbügelnd",
    "ausbügelst": "ausbügeln",
    "ausbügelt": "ausbügeln",
    "ausbügelte": "ausbügeln",
    "ausbügelten": "ausbügeln",
    "ausbügeltest": "ausbügeln",
    "ausbügeltet": "ausbügeln",
    "ausbügle": "ausbügeln",
    "ausbürgere": "ausbürgern",
    "ausbürgernd": "ausbürgern",
    "ausbürgernde": "ausbürgernd",
    "ausbürgerndem": "ausbürgernd",
    "ausbürgernden": "ausbürgernd",
    "ausbürgernder": "ausbürgernd",
    "ausbürgerndes": "ausbürgernd",
    "ausbürgerst": "ausbürgern",
    "ausbürgert": "ausbürgern",
    "ausbürgerte": "ausbürgern",
    "ausbürgerten": "ausbürgern",
    "ausbürgertest": "ausbürgern",
    "ausbürgertet": "ausbürgern",
    "ausbürste": "ausbürsten",
    "ausbürstend": "ausbürsten",
    "ausbürstende": "ausbürstend",
    "ausbürstendem": "ausbürstend",
    "ausbürstenden": "ausbürstend",
    "ausbürstender": "ausbürstend",
    "ausbürstendes": "ausbürstend",
    "ausbürstest": "ausbürsten",
    "ausbürstet": "ausbürsten",
    "ausbürstete": "ausbürsten",
    "ausbürsteten": "ausbürsten",
    "ausbürstetest": "ausbürsten",
    "ausbürstetet": "ausbürsten",
    "ausbüxe": "ausbüxen",
    "ausbüxend": "ausbüxen",
    "ausbüxende": "ausbüxend",
    "ausbüxendem": "ausbüxend",
    "ausbüxenden": "ausbüxend",
    "ausbüxender": "ausbüxend",
    "ausbüxendes": "ausbüxend",
    "ausbüxest": "ausbüxen",
    "ausbüxet": "ausbüxen",
    "ausbüxt": "ausbüxen",
    "ausbüxte": "ausbüxen",
    "ausbüxten": "ausbüxen",
    "ausbüxtest": "ausbüxen",
    "ausbüxtet": "ausbüxen",
    "auschecke": "auschecken",
    "auscheckend": "auschecken",
    "auscheckende": "auscheckend",
    "auscheckendem": "auscheckend",
    "auscheckenden": "auscheckend",
    "auscheckender": "auscheckend",
    "auscheckendes": "auscheckend",
    "auscheckest": "auschecken",
    "auschecket": "auschecken",
    "auscheckst": "auschecken",
    "auscheckt": "auschecken",
    "auscheckte": "auschecken",
    "auscheckten": "auschecken",
    "auschecktest": "auschecken",
    "auschecktet": "auschecken",
    "ausdachte": "ausdenken",
    "ausdachten": "ausdenken",
    "ausdachtest": "ausdenken",
    "ausdachtet": "ausdenken",
    "ausdauere": "ausdauern",
    "ausdauernd": "ausdauern",
    "ausdauernde": "ausdauernd",
    "ausdauerndem": "ausdauernd",
    "ausdauernden": "ausdauernd",
    "ausdauernder": "ausdauernd",
    "ausdauerndere": "ausdauernd",
    "ausdauernderem": "ausdauernd",
    "ausdauernderen": "ausdauernd",
    "ausdauernderer": "ausdauernd",
    "ausdauernderes": "ausdauernd",
    "ausdauerndes": "ausdauernd",
    "ausdauerndste": "ausdauernd",
    "ausdauerndstem": "ausdauernd",
    "ausdauerndsten": "ausdauernd",
    "ausdauerndster": "ausdauernd",
    "ausdauerndstes": "ausdauernd",
    "ausdauerst": "ausdauern",
    "ausdauert": "ausdauern",
    "ausdauerte": "ausdauern",
    "ausdauerten": "ausdauern",
    "ausdauertest": "ausdauern",
    "ausdauertet": "ausdauern",
    "ausdehne": "ausdehnen",
    "ausdehnend": "ausdehnen",
    "ausdehnende": "ausdehnend",
    "ausdehnendem": "ausdehnend",
    "ausdehnenden": "ausdehnend",
    "ausdehnender": "ausdehnend",
    "ausdehnendere": "ausdehnend",
    "ausdehnenderem": "ausdehnend",
    "ausdehnenderen": "ausdehnend",
    "ausdehnenderer": "ausdehnend",
    "ausdehnenderes": "ausdehnend",
    "ausdehnendes": "ausdehnend",
    "ausdehnendste": "ausdehnend",
    "ausdehnendstem": "ausdehnend",
    "ausdehnendsten": "ausdehnend",
    "ausdehnendster": "ausdehnend",
    "ausdehnendstes": "ausdehnend",
    "ausdehnest": "ausdehnen",
    "ausdehnet": "ausdehnen",
    "ausdehnst": "ausdehnen",
    "ausdehnt": "ausdehnen",
    "ausdehnte": "ausdehnen",
    "ausdehnten": "ausdehnen",
    "ausdehntest": "ausdehnen",
    "ausdehntet": "ausdehnen",
    "ausdenke": "ausdenken",
    "ausdenkend": "ausdenken",
    "ausdenkende": "ausdenkend",
    "ausdenkendem": "ausdenkend",
    "ausdenkenden": "ausdenkend",
    "ausdenkender": "ausdenkend",
    "ausdenkendes": "ausdenkend",
    "ausdenkest": "ausdenken",
    "ausdenket": "ausdenken",
    "ausdenkst": "ausdenken",
    "ausdenkt": "ausdenken",
    "ausdeute": "ausdeuten",
    "ausdeutend": "ausdeuten",
    "ausdeutende": "ausdeutend",
    "ausdeutendem": "ausdeutend",
    "ausdeutenden": "ausdeutend",
    "ausdeutender": "ausdeutend",
    "ausdeutendes": "ausdeutend",
    "ausdeutest": "ausdeuten",
    "ausdeutet": "ausdeuten",
    "ausdeutete": "ausdeuten",
    "ausdeuteten": "ausdeuten",
    "ausdeutetest": "ausdeuten",
    "ausdeutetet": "ausdeuten",
    "ausdiene": "ausdienen",
    "ausdienend": "ausdienen",
    "ausdienende": "ausdienend",
    "ausdienendem": "ausdienend",
    "ausdienenden": "ausdienend",
    "ausdienender": "ausdienend",
    "ausdienendes": "ausdienend",
    "ausdienest": "ausdienen",
    "ausdienet": "ausdienen",
    "ausdienst": "ausdienen",
    "ausdient": "ausdienen",
    "ausdiente": "ausdienen",
    "ausdienten": "ausdienen",
    "ausdientest": "ausdienen",
    "ausdientet": "ausdienen",
    "ausdifferenziere": "ausdifferenzieren",
    "ausdifferenzierend": "ausdifferenzieren",
    "ausdifferenzierende": "ausdifferenzierend",
    "ausdifferenzierendem": "ausdifferenzierend",
    "ausdifferenzierenden": "ausdifferenzierend",
    "ausdifferenzierender": "ausdifferenzierend",
    "ausdifferenzierendere": "ausdifferenzierend",
    "ausdifferenzierenderem": "ausdifferenzierend",
    "ausdifferenzierenderen": "ausdifferenzierend",
    "ausdifferenzierenderer": "ausdifferenzierend",
    "ausdifferenzierenderes": "ausdifferenzierend",
    "ausdifferenzierendes": "ausdifferenzierend",
    "ausdifferenzierendste": "ausdifferenzierend",
    "ausdifferenzierendstem": "ausdifferenzierend",
    "ausdifferenzierendsten": "ausdifferenzierend",
    "ausdifferenzierendster": "ausdifferenzierend",
    "ausdifferenzierendstes": "ausdifferenzierend",
    "ausdifferenzierest": "ausdifferenzieren",
    "ausdifferenzieret": "ausdifferenzieren",
    "ausdifferenzierst": "ausdifferenzieren",
    "ausdifferenziert": "ausdifferenzieren",
    "ausdifferenzierte": "ausdifferenzieren",
    "ausdifferenziertem": "ausdifferenziert",
    "ausdifferenzierten": "ausdifferenzieren",
    "ausdifferenzierter": "ausdifferenziert",
    "ausdifferenziertere": "ausdifferenziert",
    "ausdifferenzierterem": "ausdifferenziert",
    "ausdifferenzierteren": "ausdifferenziert",
    "ausdifferenzierterer": "ausdifferenziert",
    "ausdifferenzierteres": "ausdifferenziert",
    "ausdifferenziertes": "ausdifferenziert",
    "ausdifferenziertest": "ausdifferenzieren",
    "ausdifferenzierteste": "ausdifferenziert",
    "ausdifferenziertestem": "ausdifferenziert",
    "ausdifferenziertesten": "ausdifferenziert",
    "ausdifferenziertester": "ausdifferenziert",
    "ausdifferenziertestes": "ausdifferenziert",
    "ausdifferenziertet": "ausdifferenzieren",
    "ausdiskutiere": "ausdiskutieren",
    "ausdiskutierend": "ausdiskutieren",
    "ausdiskutierende": "ausdiskutierend",
    "ausdiskutierendem": "ausdiskutierend",
    "ausdiskutierenden": "ausdiskutierend",
    "ausdiskutierender": "ausdiskutierend",
    "ausdiskutierendes": "ausdiskutierend",
    "ausdiskutierest": "ausdiskutieren",
    "ausdiskutieret": "ausdiskutieren",
    "ausdiskutierst": "ausdiskutieren",
    "ausdiskutiert": "ausdiskutieren",
    "ausdiskutierte": "ausdiskutieren",
    "ausdiskutiertem": "ausdiskutiert",
    "ausdiskutierten": "ausdiskutieren",
    "ausdiskutierter": "ausdiskutiert",
    "ausdiskutiertere": "ausdiskutiert",
    "ausdiskutierterem": "ausdiskutiert",
    "ausdiskutierteren": "ausdiskutiert",
    "ausdiskutierterer": "ausdiskutiert",
    "ausdiskutierteres": "ausdiskutiert",
    "ausdiskutiertes": "ausdiskutiert",
    "ausdiskutiertest": "ausdiskutieren",
    "ausdiskutiertestem": "ausdiskutiert",
    "ausdiskutiertesten": "ausdiskutiert",
    "ausdiskutiertester": "ausdiskutiert",
    "ausdiskutiertestes": "ausdiskutiert",
    "ausdiskutiertet": "ausdiskutieren",
    "ausdrang": "ausdringen",
    "ausdrangen": "ausdringen",
    "ausdrangst": "ausdringen",
    "ausdrangt": "ausdringen",
    "ausdrehe": "ausdrehen",
    "ausdrehend": "ausdrehen",
    "ausdrehende": "ausdrehend",
    "ausdrehendem": "ausdrehend",
    "ausdrehenden": "ausdrehend",
    "ausdrehender": "ausdrehend",
    "ausdrehendes": "ausdrehend",
    "ausdrehest": "ausdrehen",
    "ausdrehet": "ausdrehen",
    "ausdrehst": "ausdrehen",
    "ausdreht": "ausdrehen",
    "ausdrehte": "ausdrehen",
    "ausdrehten": "ausdrehen",
    "ausdrehtest": "ausdrehen",
    "ausdrehtet": "ausdrehen",
    "ausdresche": "ausdreschen",
    "ausdreschend": "ausdreschen",
    "ausdreschende": "ausdreschend",
    "ausdreschendem": "ausdreschend",
    "ausdreschenden": "ausdreschend",
    "ausdreschender": "ausdreschend",
    "ausdreschendes": "ausdreschend",
    "ausdreschest": "ausdreschen",
    "ausdreschet": "ausdreschen",
    "ausdrescht": "ausdreschen",
    "ausdringe": "ausdringen",
    "ausdringend": "ausdringen",
    "ausdringende": "ausdringend",
    "ausdringendem": "ausdringend",
    "ausdringenden": "ausdringend",
    "ausdringender": "ausdringend",
    "ausdringendes": "ausdringend",
    "ausdringest": "ausdringen",
    "ausdringet": "ausdringen",
    "ausdringst": "ausdringen",
    "ausdringt": "ausdringen",
    "ausdrischst": "ausdreschen",
    "ausdrischt": "ausdreschen",
    "ausdrosch": "ausdreschen",
    "ausdroschen": "ausdreschen",
    "ausdroschst": "ausdreschen",
    "ausdroscht": "ausdreschen",
    "ausdruckend": "ausdrucken",
    "ausdruckende": "ausdruckend",
    "ausdruckendem": "ausdruckend",
    "ausdruckenden": "ausdruckend",
    "ausdruckender": "ausdruckend",
    "ausdruckendes": "ausdruckend",
    "ausdruckest": "ausdrucken",
    "ausdrucket": "ausdrucken",
    "ausdruckslosem": "ausdruckslos",
    "ausdruckslosen": "ausdruckslos",
    "ausdrucksloser": "ausdruckslos",
    "ausdruckslosere": "ausdruckslos",
    "ausdrucksloserem": "ausdruckslos",
    "ausdrucksloseren": "ausdruckslos",
    "ausdrucksloserer": "ausdruckslos",
    "ausdrucksloseres": "ausdruckslos",
    "ausdrucksloses": "ausdruckslos",
    "ausdrucksloseste": "ausdruckslos",
    "ausdruckslosestem": "ausdruckslos",
    "ausdruckslosesten": "ausdruckslos",
    "ausdruckslosester": "ausdruckslos",
    "ausdruckslosestes": "ausdruckslos",
    "ausdruckst": "ausdrucken",
    "ausdrucksvolle": "ausdrucksvoll",
    "ausdrucksvollem": "ausdrucksvoll",
    "ausdrucksvollen": "ausdrucksvoll",
    "ausdrucksvoller": "ausdrucksvoll",
    "ausdrucksvollere": "ausdrucksvoll",
    "ausdrucksvollerem": "ausdrucksvoll",
    "ausdrucksvolleren": "ausdrucksvoll",
    "ausdrucksvollerer": "ausdrucksvoll",
    "ausdrucksvolleres": "ausdrucksvoll",
    "ausdrucksvolles": "ausdrucksvoll",
    "ausdrucksvollste": "ausdrucksvoll",
    "ausdrucksvollstem": "ausdrucksvoll",
    "ausdrucksvollsten": "ausdrucksvoll",
    "ausdrucksvollster": "ausdrucksvoll",
    "ausdrucksvollstes": "ausdrucksvoll",
    "ausdruckt": "ausdrucken",
    "ausdruckte": "ausdrucken",
    "ausdruckten": "ausdrucken",
    "ausdrucktest": "ausdrucken",
    "ausdrucktet": "ausdrucken",
    "ausdränge": "ausdringen",
    "ausdrängen": "ausdringen",
    "ausdrängest": "ausdringen",
    "ausdränget": "ausdringen",
    "ausdrösche": "ausdreschen",
    "ausdröschen": "ausdreschen",
    "ausdröschest": "ausdreschen",
    "ausdröschet": "ausdreschen",
    "ausdrücke": "ausdrücken",
    "ausdrückend": "ausdrücken",
    "ausdrückendem": "ausdrückend",
    "ausdrückender": "ausdrückend",
    "ausdrückendes": "ausdrückend",
    "ausdrückest": "ausdrücken",
    "ausdrücket": "ausdrücken",
    "ausdrückliche": "ausdrücklich",
    "ausdrücklichem": "ausdrücklich",
    "ausdrücklichen": "ausdrücklich",
    "ausdrücklicher": "ausdrücklich",
    "ausdrückliches": "ausdrücklich",
    "ausdrückst": "ausdrücken",
    "ausdrückt": "ausdrücken",
    "ausdrückte": "ausdrücken",
    "ausdrückten": "ausdrücken",
    "ausdrücktest": "ausdrücken",
    "ausdrücktet": "ausdrücken",
    "ausdunste": "ausdunsten",
    "ausdunstend": "ausdunsten",
    "ausdunstende": "ausdunstend",
    "ausdunstendem": "ausdunstend",
    "ausdunstenden": "ausdunstend",
    "ausdunstender": "ausdunstend",
    "ausdunstendere": "ausdunstend",
    "ausdunstenderem": "ausdunstend",
    "ausdunstenderen": "ausdunstend",
    "ausdunstenderer": "ausdunstend",
    "ausdunstenderes": "ausdunstend",
    "ausdunstendes": "ausdunstend",
    "ausdunstendste": "ausdunstend",
    "ausdunstendstem": "ausdunstend",
    "ausdunstendsten": "ausdunstend",
    "ausdunstendster": "ausdunstend",
    "ausdunstendstes": "ausdunstend",
    "ausdunstest": "ausdunsten",
    "ausdunstet": "ausdunsten",
    "ausdunstete": "ausdunsten",
    "ausdunsteten": "ausdunsten",
    "ausdunstetest": "ausdunsten",
    "ausdunstetet": "ausdunsten",
    "ausdächte": "ausdenken",
    "ausdächten": "ausdenken",
    "ausdächtest": "ausdenken",
    "ausdächtet": "ausdenken",
    "ausdörre": "ausdörren",
    "ausdörrend": "ausdörren",
    "ausdörrende": "ausdörrend",
    "ausdörrendem": "ausdörrend",
    "ausdörrenden": "ausdörrend",
    "ausdörrender": "ausdörrend",
    "ausdörrendere": "ausdörrend",
    "ausdörrenderem": "ausdörrend",
    "ausdörrenderen": "ausdörrend",
    "ausdörrenderer": "ausdörrend",
    "ausdörrenderes": "ausdörrend",
    "ausdörrendes": "ausdörrend",
    "ausdörrendste": "ausdörrend",
    "ausdörrendstem": "ausdörrend",
    "ausdörrendsten": "ausdörrend",
    "ausdörrendster": "ausdörrend",
    "ausdörrendstes": "ausdörrend",
    "ausdörrest": "ausdörren",
    "ausdörret": "ausdörren",
    "ausdörrst": "ausdörren",
    "ausdörrt": "ausdörren",
    "ausdörrte": "ausdörren",
    "ausdörrten": "ausdörren",
    "ausdörrtest": "ausdörren",
    "ausdörrtet": "ausdörren",
    "auserkiese": "auserkiesen",
    "auserkiesend": "auserkiesen",
    "auserkiesende": "auserkiesend",
    "auserkiesendem": "auserkiesend",
    "auserkiesenden": "auserkiesend",
    "auserkiesender": "auserkiesend",
    "auserkiesendes": "auserkiesend",
    "auserkiesest": "auserkiesen",
    "auserkieset": "auserkiesen",
    "auserkiest": "auserkiesen",
    "auserkor": "auserkiesen",
    "auserkoren": "auserkiesen",
    "auserkorene": "auserkoren",
    "auserkorenem": "auserkoren",
    "auserkorenen": "auserkoren",
    "auserkorener": "auserkoren",
    "auserkorenere": "auserkoren",
    "auserkorenerem": "auserkoren",
    "auserkoreneren": "auserkoren",
    "auserkorenerer": "auserkoren",
    "auserkoreneres": "auserkoren",
    "auserkorenes": "auserkoren",
    "auserkorenste": "auserkoren",
    "auserkorenstem": "auserkoren",
    "auserkorensten": "auserkoren",
    "auserkorenster": "auserkoren",
    "auserkorenstes": "auserkoren",
    "auserkorst": "auserkiesen",
    "auserkort": "auserkiesen",
    "auserköre": "auserkiesen",
    "auserkören": "auserkiesen",
    "auserkörest": "auserkiesen",
    "auserköret": "auserkiesen",
    "auserlesene": "auserlesen",
    "auserlesenem": "auserlesen",
    "auserlesenen": "auserlesen",
    "auserlesener": "auserlesen",
    "auserlesenes": "auserlesen",
    "ausersah": "ausersehen",
    "ausersahen": "ausersehen",
    "ausersahst": "ausersehen",
    "ausersaht": "ausersehen",
    "ausersehe": "ausersehen",
    "ausersehend": "ausersehen",
    "ausersehende": "ausersehend",
    "ausersehendem": "ausersehend",
    "ausersehenden": "ausersehend",
    "ausersehender": "ausersehend",
    "ausersehendes": "ausersehend",
    "ausersehene": "ausersehen",
    "ausersehenem": "ausersehen",
    "ausersehenen": "ausersehen",
    "ausersehener": "ausersehen",
    "ausersehenes": "ausersehen",
    "ausersehest": "ausersehen",
    "ausersehet": "ausersehen",
    "auserseht": "ausersehen",
    "ausersiehst": "ausersehen",
    "ausersieht": "ausersehen",
    "ausersähe": "ausersehen",
    "ausersähen": "ausersehen",
    "ausersähest": "ausersehen",
    "ausersähet": "ausersehen",
    "auserwähle": "auserwählen",
    "auserwählend": "auserwählen",
    "auserwählende": "auserwählend",
    "auserwählendem": "auserwählend",
    "auserwählenden": "auserwählend",
    "auserwählender": "auserwählend",
    "auserwählendes": "auserwählend",
    "auserwählest": "auserwählen",
    "auserwählet": "auserwählen",
    "auserwählst": "auserwählen",
    "auserwählt": "auserwählen",
    "auserwählte": "auserwählen",
    "auserwähltem": "auserwählt",
    "auserwählten": "auserwählen",
    "auserwählter": "auserwählt",
    "auserwähltes": "auserwählt",
    "auserwähltest": "auserwählen",
    "auserwähltet": "auserwählen",
    "ausesse": "ausessen",
    "ausessend": "ausessen",
    "ausessende": "ausessend",
    "ausessendem": "ausessend",
    "ausessenden": "ausessend",
    "ausessender": "ausessend",
    "ausessendes": "ausessend",
    "ausessest": "ausessen",
    "ausesset": "ausessen",
    "auseßt": "ausessen",
    "ausfahre": "ausfahren",
    "ausfahrend": "ausfahren",
    "ausfahrende": "ausfahrend",
    "ausfahrendem": "ausfahrend",
    "ausfahrenden": "ausfahrend",
    "ausfahrender": "ausfahrend",
    "ausfahrendes": "ausfahrend",
    "ausfahrest": "ausfahren",
    "ausfahret": "ausfahren",
    "ausfahrt": "ausfahren",
    "ausfallend": "ausfallen",
    "ausfallende": "ausfallend",
    "ausfallendem": "ausfallend",
    "ausfallenden": "ausfallend",
    "ausfallender": "ausfallend",
    "ausfallendes": "ausfallend",
    "ausfallest": "ausfallen",
    "ausfallet": "ausfallen",
    "ausfallt": "ausfallen",
    "ausfasere": "ausfasern",
    "ausfasernd": "ausfasern",
    "ausfasernde": "ausfasernd",
    "ausfaserndem": "ausfasernd",
    "ausfasernden": "ausfasernd",
    "ausfasernder": "ausfasernd",
    "ausfaserndere": "ausfasernd",
    "ausfasernderem": "ausfasernd",
    "ausfasernderen": "ausfasernd",
    "ausfasernderer": "ausfasernd",
    "ausfasernderes": "ausfasernd",
    "ausfaserndes": "ausfasernd",
    "ausfaserndste": "ausfasernd",
    "ausfaserndstem": "ausfasernd",
    "ausfaserndsten": "ausfasernd",
    "ausfaserndster": "ausfasernd",
    "ausfaserndstes": "ausfasernd",
    "ausfaserst": "ausfasern",
    "ausfasert": "ausfasern",
    "ausfaserte": "ausfasern",
    "ausfaserten": "ausfasern",
    "ausfasertest": "ausfasern",
    "ausfasertet": "ausfasern",
    "ausfechte": "ausfechten",
    "ausfechtend": "ausfechten",
    "ausfechtende": "ausfechtend",
    "ausfechtendem": "ausfechtend",
    "ausfechtenden": "ausfechtend",
    "ausfechtender": "ausfechtend",
    "ausfechtendes": "ausfechtend",
    "ausfechtest": "ausfechten",
    "ausfechtet": "ausfechten",
    "ausfege": "ausfegen",
    "ausfegend": "ausfegen",
    "ausfegende": "ausfegend",
    "ausfegendem": "ausfegend",
    "ausfegenden": "ausfegend",
    "ausfegender": "ausfegend",
    "ausfegendere": "ausfegend",
    "ausfegenderem": "ausfegend",
    "ausfegenderen": "ausfegend",
    "ausfegenderer": "ausfegend",
    "ausfegenderes": "ausfegend",
    "ausfegendes": "ausfegend",
    "ausfegendste": "ausfegend",
    "ausfegendstem": "ausfegend",
    "ausfegendsten": "ausfegend",
    "ausfegendster": "ausfegend",
    "ausfegendstes": "ausfegend",
    "ausfegest": "ausfegen",
    "ausfeget": "ausfegen",
    "ausfegst": "ausfegen",
    "ausfegt": "ausfegen",
    "ausfegte": "ausfegen",
    "ausfegten": "ausfegen",
    "ausfegtest": "ausfegen",
    "ausfegtet": "ausfegen",
    "ausfeile": "ausfeilen",
    "ausfeilend": "ausfeilen",
    "ausfeilende": "ausfeilend",
    "ausfeilendem": "ausfeilend",
    "ausfeilenden": "ausfeilend",
    "ausfeilender": "ausfeilend",
    "ausfeilendere": "ausfeilend",
    "ausfeilenderem": "ausfeilend",
    "ausfeilenderen": "ausfeilend",
    "ausfeilenderer": "ausfeilend",
    "ausfeilenderes": "ausfeilend",
    "ausfeilendes": "ausfeilend",
    "ausfeilendste": "ausfeilend",
    "ausfeilendstem": "ausfeilend",
    "ausfeilendsten": "ausfeilend",
    "ausfeilendster": "ausfeilend",
    "ausfeilendstes": "ausfeilend",
    "ausfeilest": "ausfeilen",
    "ausfeilet": "ausfeilen",
    "ausfeilst": "ausfeilen",
    "ausfeilt": "ausfeilen",
    "ausfeilte": "ausfeilen",
    "ausfeilten": "ausfeilen",
    "ausfeiltest": "ausfeilen",
    "ausfeiltet": "ausfeilen",
    "ausfertige": "ausfertigen",
    "ausfertigend": "ausfertigen",
    "ausfertigende": "ausfertigend",
    "ausfertigendem": "ausfertigend",
    "ausfertigenden": "ausfertigend",
    "ausfertigender": "ausfertigend",
    "ausfertigendes": "ausfertigend",
    "ausfertigest": "ausfertigen",
    "ausfertiget": "ausfertigen",
    "ausfertigst": "ausfertigen",
    "ausfertigt": "ausfertigen",
    "ausfertigte": "ausfertigen",
    "ausfertigten": "ausfertigen",
    "ausfertigtest": "ausfertigen",
    "ausfertigtet": "ausfertigen",
    "ausficht": "ausfechten",
    "ausfichtst": "ausfechten",
    "ausfiel": "ausfallen",
    "ausfiele": "ausfallen",
    "ausfielen": "ausfallen",
    "ausfielest": "ausfallen",
    "ausfielet": "ausfallen",
    "ausfielst": "ausfallen",
    "ausfielt": "ausfallen",
    "ausfiltere": "ausfiltern",
    "ausfilternd": "ausfiltern",
    "ausfilternde": "ausfilternd",
    "ausfilterndem": "ausfilternd",
    "ausfilternden": "ausfilternd",
    "ausfilternder": "ausfilternd",
    "ausfilterndere": "ausfilternd",
    "ausfilternderem": "ausfilternd",
    "ausfilternderen": "ausfilternd",
    "ausfilternderer": "ausfilternd",
    "ausfilternderes": "ausfilternd",
    "ausfilterndes": "ausfilternd",
    "ausfilterndste": "ausfilternd",
    "ausfilterndstem": "ausfilternd",
    "ausfilterndsten": "ausfilternd",
    "ausfilterndster": "ausfilternd",
    "ausfilterndstes": "ausfilternd",
    "ausfilterst": "ausfiltern",
    "ausfiltert": "ausfiltern",
    "ausfilterte": "ausfiltern",
    "ausfilterten": "ausfiltern",
    "ausfiltertest": "ausfiltern",
    "ausfiltertet": "ausfiltern",
    "ausfische": "ausfischen",
    "ausfischend": "ausfischen",
    "ausfischende": "ausfischend",
    "ausfischendem": "ausfischend",
    "ausfischenden": "ausfischend",
    "ausfischender": "ausfischend",
    "ausfischendes": "ausfischend",
    "ausfischest": "ausfischen",
    "ausfischet": "ausfischen",
    "ausfischst": "ausfischen",
    "ausfischt": "ausfischen",
    "ausfischte": "ausfischen",
    "ausfischten": "ausfischen",
    "ausfischtest": "ausfischen",
    "ausfischtet": "ausfischen",
    "ausflagge": "ausflaggen",
    "ausflaggend": "ausflaggen",
    "ausflaggende": "ausflaggend",
    "ausflaggendem": "ausflaggend",
    "ausflaggenden": "ausflaggend",
    "ausflaggender": "ausflaggend",
    "ausflaggendere": "ausflaggend",
    "ausflaggenderem": "ausflaggend",
    "ausflaggenderen": "ausflaggend",
    "ausflaggenderer": "ausflaggend",
    "ausflaggenderes": "ausflaggend",
    "ausflaggendes": "ausflaggend",
    "ausflaggendste": "ausflaggend",
    "ausflaggendstem": "ausflaggend",
    "ausflaggendsten": "ausflaggend",
    "ausflaggendster": "ausflaggend",
    "ausflaggendstes": "ausflaggend",
    "ausflaggest": "ausflaggen",
    "ausflagget": "ausflaggen",
    "ausflaggst": "ausflaggen",
    "ausflaggt": "ausflaggen",
    "ausflaggte": "ausflaggen",
    "ausflaggten": "ausflaggen",
    "ausflaggtest": "ausflaggen",
    "ausflaggtet": "ausflaggen",
    "ausfliege": "ausfliegen",
    "ausfliegend": "ausfliegen",
    "ausfliegende": "ausfliegend",
    "ausfliegendem": "ausfliegend",
    "ausfliegenden": "ausfliegend",
    "ausfliegender": "ausfliegend",
    "ausfliegendes": "ausfliegend",
    "ausfliegest": "ausfliegen",
    "ausflieget": "ausfliegen",
    "ausfliegst": "ausfliegen",
    "ausfliegt": "ausfliegen",
    "ausfließe": "ausfließen",
    "ausfließend": "ausfließen",
    "ausfließende": "ausfließend",
    "ausfließendem": "ausfließend",
    "ausfließenden": "ausfließend",
    "ausfließender": "ausfließend",
    "ausfließendes": "ausfließend",
    "ausfließest": "ausfließen",
    "ausfließet": "ausfließen",
    "ausfließt": "ausfließen",
    "ausflippe": "ausflippen",
    "ausflippend": "ausflippen",
    "ausflippende": "ausflippend",
    "ausflippendem": "ausflippend",
    "ausflippenden": "ausflippend",
    "ausflippender": "ausflippend",
    "ausflippendere": "ausflippend",
    "ausflippenderem": "ausflippend",
    "ausflippenderen": "ausflippend",
    "ausflippenderer": "ausflippend",
    "ausflippenderes": "ausflippend",
    "ausflippendes": "ausflippend",
    "ausflippendste": "ausflippend",
    "ausflippendstem": "ausflippend",
    "ausflippendsten": "ausflippend",
    "ausflippendster": "ausflippend",
    "ausflippendstes": "ausflippend",
    "ausflippest": "ausflippen",
    "ausflippet": "ausflippen",
    "ausflippst": "ausflippen",
    "ausflippt": "ausflippen",
    "ausflippte": "ausflippen",
    "ausflippten": "ausflippen",
    "ausflipptest": "ausflippen",
    "ausflipptet": "ausflippen",
    "ausflocke": "ausflocken",
    "ausflockend": "ausflocken",
    "ausflockende": "ausflockend",
    "ausflockendem": "ausflockend",
    "ausflockenden": "ausflockend",
    "ausflockender": "ausflockend",
    "ausflockendes": "ausflockend",
    "ausflockest": "ausflocken",
    "ausflocket": "ausflocken",
    "ausflockst": "ausflocken",
    "ausflockt": "ausflocken",
    "ausflockte": "ausflocken",
    "ausflockten": "ausflocken",
    "ausflocktest": "ausflocken",
    "ausflocktet": "ausflocken",
    "ausflog": "ausfliegen",
    "ausflogen": "ausfliegen",
    "ausflogst": "ausfliegen",
    "ausflogt": "ausfliegen",
    "ausflossen": "ausfließen",
    "ausfloß": "ausfließen",
    "ausfloßt": "ausfließen",
    "ausflöge": "ausfliegen",
    "ausflögen": "ausfliegen",
    "ausflögest": "ausfliegen",
    "ausflöget": "ausfliegen",
    "ausflösse": "ausfließen",
    "ausflössen": "ausfließen",
    "ausflössest": "ausfließen",
    "ausflösset": "ausfließen",
    "ausfocht": "ausfechten",
    "ausfochten": "ausfechten",
    "ausfochtest": "ausfechten",
    "ausfochtet": "ausfechten",
    "ausfolge": "ausfolgen",
    "ausfolgend": "ausfolgen",
    "ausfolgende": "ausfolgend",
    "ausfolgendem": "ausfolgend",
    "ausfolgenden": "ausfolgend",
    "ausfolgender": "ausfolgend",
    "ausfolgendes": "ausfolgend",
    "ausfolgest": "ausfolgen",
    "ausfolget": "ausfolgen",
    "ausfolgst": "ausfolgen",
    "ausfolgt": "ausfolgen",
    "ausfolgte": "ausfolgen",
    "ausfolgten": "ausfolgen",
    "ausfolgtest": "ausfolgen",
    "ausfolgtet": "ausfolgen",
    "ausformuliere": "ausformulieren",
    "ausformulierend": "ausformulieren",
    "ausformulierende": "ausformulierend",
    "ausformulierendem": "ausformulierend",
    "ausformulierenden": "ausformulierend",
    "ausformulierender": "ausformulierend",
    "ausformulierendes": "ausformulierend",
    "ausformulierest": "ausformulieren",
    "ausformulieret": "ausformulieren",
    "ausformulierst": "ausformulieren",
    "ausformuliert": "ausformulieren",
    "ausformulierte": "ausformulieren",
    "ausformuliertem": "ausformuliert",
    "ausformulierten": "ausformulieren",
    "ausformulierter": "ausformuliert",
    "ausformuliertere": "ausformuliert",
    "ausformulierterem": "ausformuliert",
    "ausformulierteren": "ausformuliert",
    "ausformulierterer": "ausformuliert",
    "ausformulierteres": "ausformuliert",
    "ausformuliertes": "ausformuliert",
    "ausformuliertest": "ausformulieren",
    "ausformuliertestem": "ausformuliert",
    "ausformuliertesten": "ausformuliert",
    "ausformuliertester": "ausformuliert",
    "ausformuliertestes": "ausformuliert",
    "ausformuliertet": "ausformulieren",
    "ausforsche": "ausforschen",
    "ausforschend": "ausforschen",
    "ausforschende": "ausforschend",
    "ausforschendem": "ausforschend",
    "ausforschenden": "ausforschend",
    "ausforschender": "ausforschend",
    "ausforschendes": "ausforschend",
    "ausforschest": "ausforschen",
    "ausforschet": "ausforschen",
    "ausforschst": "ausforschen",
    "ausforscht": "ausforschen",
    "ausforschte": "ausforschen",
    "ausforschten": "ausforschen",
    "ausforschtest": "ausforschen",
    "ausforschtet": "ausforschen",
    "ausfrage": "ausfragen",
    "ausfragend": "ausfragen",
    "ausfragende": "ausfragend",
    "ausfragendem": "ausfragend",
    "ausfragenden": "ausfragend",
    "ausfragender": "ausfragend",
    "ausfragendes": "ausfragend",
    "ausfragest": "ausfragen",
    "ausfraget": "ausfragen",
    "ausfragst": "ausfragen",
    "ausfragt": "ausfragen",
    "ausfragte": "ausfragen",
    "ausfragten": "ausfragen",
    "ausfragtest": "ausfragen",
    "ausfragtet": "ausfragen",
    "ausfranse": "ausfransen",
    "ausfransend": "ausfransen",
    "ausfransende": "ausfransend",
    "ausfransendem": "ausfransend",
    "ausfransenden": "ausfransend",
    "ausfransender": "ausfransend",
    "ausfransendere": "ausfransend",
    "ausfransenderem": "ausfransend",
    "ausfransenderen": "ausfransend",
    "ausfransenderer": "ausfransend",
    "ausfransenderes": "ausfransend",
    "ausfransendes": "ausfransend",
    "ausfransendste": "ausfransend",
    "ausfransendstem": "ausfransend",
    "ausfransendsten": "ausfransend",
    "ausfransendster": "ausfransend",
    "ausfransendstes": "ausfransend",
    "ausfransest": "ausfransen",
    "ausfranset": "ausfransen",
    "ausfranst": "ausfransen",
    "ausfranste": "ausfransen",
    "ausfransten": "ausfransen",
    "ausfranstest": "ausfransen",
    "ausfranstet": "ausfransen",
    "ausfraß": "ausfressen",
    "ausfraßen": "ausfressen",
    "ausfraßt": "ausfressen",
    "ausfresse": "ausfressen",
    "ausfressend": "ausfressen",
    "ausfressende": "ausfressend",
    "ausfressendem": "ausfressend",
    "ausfressenden": "ausfressend",
    "ausfressender": "ausfressend",
    "ausfressendes": "ausfressend",
    "ausfressest": "ausfressen",
    "ausfresset": "ausfressen",
    "ausfreßt": "ausfressen",
    "ausfriere": "ausfrieren",
    "ausfrierend": "ausfrieren",
    "ausfrierende": "ausfrierend",
    "ausfrierendem": "ausfrierend",
    "ausfrierenden": "ausfrierend",
    "ausfrierender": "ausfrierend",
    "ausfrierendes": "ausfrierend",
    "ausfrierest": "ausfrieren",
    "ausfrieret": "ausfrieren",
    "ausfrierst": "ausfrieren",
    "ausfriert": "ausfrieren",
    "ausfrißt": "ausfressen",
    "ausfror": "ausfrieren",
    "ausfroren": "ausfrieren",
    "ausfrorst": "ausfrieren",
    "ausfrort": "ausfrieren",
    "ausfräße": "ausfressen",
    "ausfräßen": "ausfressen",
    "ausfräßest": "ausfressen",
    "ausfräßet": "ausfressen",
    "ausfröre": "ausfrieren",
    "ausfrören": "ausfrieren",
    "ausfrörest": "ausfrieren",
    "ausfröret": "ausfrieren",
    "ausfuge": "ausfugen",
    "ausfugend": "ausfugen",
    "ausfugende": "ausfugend",
    "ausfugendem": "ausfugend",
    "ausfugenden": "ausfugend",
    "ausfugender": "ausfugend",
    "ausfugendere": "ausfugend",
    "ausfugenderem": "ausfugend",
    "ausfugenderen": "ausfugend",
    "ausfugenderer": "ausfugend",
    "ausfugenderes": "ausfugend",
    "ausfugendes": "ausfugend",
    "ausfugendste": "ausfugend",
    "ausfugendstem": "ausfugend",
    "ausfugendsten": "ausfugend",
    "ausfugendster": "ausfugend",
    "ausfugendstes": "ausfugend",
    "ausfugest": "ausfugen",
    "ausfuget": "ausfugen",
    "ausfugst": "ausfugen",
    "ausfugt": "ausfugen",
    "ausfugte": "ausfugen",
    "ausfugten": "ausfugen",
    "ausfugtest": "ausfugen",
    "ausfugtet": "ausfugen",
    "ausfuhr": "ausfahren",
    "ausfuhren": "ausfahren",
    "ausfuhrst": "ausfahren",
    "ausfuhrt": "ausfahren",
    "ausfädele": "ausfädeln",
    "ausfädelnd": "ausfädeln",
    "ausfädelnde": "ausfädelnd",
    "ausfädelndem": "ausfädelnd",
    "ausfädelnden": "ausfädelnd",
    "ausfädelnder": "ausfädelnd",
    "ausfädelndes": "ausfädelnd",
    "ausfädelst": "ausfädeln",
    "ausfädelt": "ausfädeln",
    "ausfädelte": "ausfädeln",
    "ausfädelten": "ausfädeln",
    "ausfädeltest": "ausfädeln",
    "ausfädeltet": "ausfädeln",
    "ausfädle": "ausfädeln",
    "ausfährst": "ausfahren",
    "ausfährt": "ausfahren",
    "ausfällend": "ausfällen",
    "ausfällendem": "ausfällend",
    "ausfällender": "ausfällend",
    "ausfällendes": "ausfällend",
    "ausfällest": "ausfällen",
    "ausfället": "ausfällen",
    "ausfällige": "ausfällig",
    "ausfälligem": "ausfällig",
    "ausfälligen": "ausfällig",
    "ausfälliger": "ausfällig",
    "ausfälligere": "ausfällig",
    "ausfälligerem": "ausfällig",
    "ausfälligeren": "ausfällig",
    "ausfälligerer": "ausfällig",
    "ausfälligeres": "ausfällig",
    "ausfälliges": "ausfällig",
    "ausfälligste": "ausfällig",
    "ausfälligstem": "ausfällig",
    "ausfälligsten": "ausfällig",
    "ausfälligster": "ausfällig",
    "ausfälligstes": "ausfällig",
    "ausfällst": "ausfällen",
    "ausfällt": "ausfällen",
    "ausfällte": "ausfällen",
    "ausfällten": "ausfällen",
    "ausfälltest": "ausfällen",
    "ausfälltet": "ausfällen",
    "ausföchte": "ausfechten",
    "ausföchten": "ausfechten",
    "ausföchtest": "ausfechten",
    "ausföchtet": "ausfechten",
    "ausführbarem": "ausführbar",
    "ausführbaren": "ausführbar",
    "ausführbarer": "ausführbar",
    "ausführbares": "ausführbar",
    "ausführe": "ausführen",
    "ausführen": "ausfahren",
    "ausführend": "ausführen",
    "ausführende": "ausführend",
    "ausführendem": "ausführend",
    "ausführenden": "ausführend",
    "ausführender": "ausführend",
    "ausführendes": "ausführend",
    "ausführest": "ausführen",
    "ausführet": "ausführen",
    "ausführlichem": "ausführlich",
    "ausführlichen": "ausführlich",
    "ausführlicher": "ausführlich",
    "ausführlichere": "ausführlich",
    "ausführlicherem": "ausführlich",
    "ausführlicheren": "ausführlich",
    "ausführlicherer": "ausführlich",
    "ausführlicheres": "ausführlich",
    "ausführliches": "ausführlich",
    "ausführlichste": "ausführlich",
    "ausführlichstem": "ausführlich",
    "ausführlichsten": "ausführlich",
    "ausführlichster": "ausführlich",
    "ausführlichstes": "ausführlich",
    "ausführst": "ausführen",
    "ausführt": "ausführen",
    "ausführte": "ausführen",
    "ausführten": "ausführen",
    "ausführtest": "ausführen",
    "ausführtet": "ausführen",
    "ausfülle": "ausfüllen",
    "ausfüllend": "ausfüllen",
    "ausfüllende": "ausfüllend",
    "ausfüllendem": "ausfüllend",
    "ausfüllenden": "ausfüllend",
    "ausfüllender": "ausfüllend",
    "ausfüllendes": "ausfüllend",
    "ausfüllest": "ausfüllen",
    "ausfüllet": "ausfüllen",
    "ausfüllst": "ausfüllen",
    "ausfüllt": "ausfüllen",
    "ausfüllte": "ausfüllen",
    "ausfüllten": "ausfüllen",
    "ausfülltest": "ausfüllen",
    "ausfülltet": "ausfüllen",
    "ausfüttere": "ausfüttern",
    "ausfütternd": "ausfüttern",
    "ausfütternde": "ausfütternd",
    "ausfütterndem": "ausfütternd",
    "ausfütternden": "ausfütternd",
    "ausfütternder": "ausfütternd",
    "ausfütterndes": "ausfütternd",
    "ausfütterst": "ausfüttern",
    "ausfüttert": "ausfüttern",
    "ausfütterte": "ausfüttern",
    "ausfütterten": "ausfüttern",
    "ausfüttertest": "ausfüttern",
    "ausfüttertet": "ausfüttern",
    "ausgab": "ausgeben",
    "ausgabst": "ausgeben",
    "ausgabt": "ausgeben",
    "ausgearbeitet": "ausarbeiten",
    "ausgearbeitete": "ausgearbeitet",
    "ausgearbeitetem": "ausgearbeitet",
    "ausgearbeiteten": "ausgearbeitet",
    "ausgearbeiteter": "ausgearbeitet",
    "ausgearbeitetere": "ausgearbeitet",
    "ausgearbeiteterem": "ausgearbeitet",
    "ausgearbeiteteren": "ausgearbeitet",
    "ausgearbeiteterer": "ausgearbeitet",
    "ausgearbeiteteres": "ausgearbeitet",
    "ausgearbeitetes": "ausgearbeitet",
    "ausgearbeiteteste": "ausgearbeitet",
    "ausgearbeitetestem": "ausgearbeitet",
    "ausgearbeitetesten": "ausgearbeitet",
    "ausgearbeitetester": "ausgearbeitet",
    "ausgearbeitetestes": "ausgearbeitet",
    "ausgeartet": "ausarten",
    "ausgeartete": "ausgeartet",
    "ausgeartetem": "ausgeartet",
    "ausgearteten": "ausgeartet",
    "ausgearteter": "ausgeartet",
    "ausgeartetere": "ausgeartet",
    "ausgearteterem": "ausgeartet",
    "ausgearteteren": "ausgeartet",
    "ausgearteterer": "ausgeartet",
    "ausgearteteres": "ausgeartet",
    "ausgeartetes": "ausgeartet",
    "ausgearteteste": "ausgeartet",
    "ausgeartetestem": "ausgeartet",
    "ausgeartetesten": "ausgeartet",
    "ausgeartetester": "ausgeartet",
    "ausgeartetestes": "ausgeartet",
    "ausgeatmet": "ausatmen",
    "ausgeatmete": "ausgeatmet",
    "ausgeatmetem": "ausgeatmet",
    "ausgeatmeten": "ausgeatmet",
    "ausgeatmeter": "ausgeatmet",
    "ausgeatmetes": "ausgeatmet",
    "ausgebadet": "ausbaden",
    "ausgebadete": "ausgebadet",
    "ausgebadetem": "ausgebadet",
    "ausgebadeten": "ausgebadet",
    "ausgebadeter": "ausgebadet",
    "ausgebadetes": "ausgebadet",
    "ausgebaggert": "ausbaggern",
    "ausgebaggerte": "ausgebaggert",
    "ausgebaggertem": "ausgebaggert",
    "ausgebaggerten": "ausgebaggert",
    "ausgebaggerter": "ausgebaggert",
    "ausgebaggertes": "ausgebaggert",
    "ausgebaucht": "ausbauchen",
    "ausgebauchte": "ausgebaucht",
    "ausgebauchtem": "ausgebaucht",
    "ausgebauchten": "ausgebaucht",
    "ausgebauchter": "ausgebaucht",
    "ausgebauchtere": "ausgebaucht",
    "ausgebauchterem": "ausgebaucht",
    "ausgebauchteren": "ausgebaucht",
    "ausgebauchterer": "ausgebaucht",
    "ausgebauchteres": "ausgebaucht",
    "ausgebauchtes": "ausgebaucht",
    "ausgebauchteste": "ausgebaucht",
    "ausgebauchtestem": "ausgebaucht",
    "ausgebauchtesten": "ausgebaucht",
    "ausgebauchtester": "ausgebaucht",
    "ausgebauchtestes": "ausgebaucht",
    "ausgebaut": "ausbauen",
    "ausgebaute": "ausgebaut",
    "ausgebautem": "ausgebaut",
    "ausgebauten": "ausgebaut",
    "ausgebauter": "ausgebaut",
    "ausgebautere": "ausgebaut",
    "ausgebauterem": "ausgebaut",
    "ausgebauteren": "ausgebaut",
    "ausgebauterer": "ausgebaut",
    "ausgebauteres": "ausgebaut",
    "ausgebautes": "ausgebaut",
    "ausgebauteste": "ausgebaut",
    "ausgebautestem": "ausgebaut",
    "ausgebautesten": "ausgebaut",
    "ausgebautester": "ausgebaut",
    "ausgebautestes": "ausgebaut",
    "ausgebe": "ausgeben",
    "ausgebend": "ausgeben",
    "ausgebende": "ausgebend",
    "ausgebendem": "ausgebend",
    "ausgebenden": "ausgebend",
    "ausgebender": "ausgebend",
    "ausgebendes": "ausgebend",
    "ausgebessert": "ausbessern",
    "ausgebesserte": "ausgebessert",
    "ausgebessertem": "ausgebessert",
    "ausgebesserten": "ausgebessert",
    "ausgebesserter": "ausgebessert",
    "ausgebessertere": "ausgebessert",
    "ausgebesserterem": "ausgebessert",
    "ausgebesserteren": "ausgebessert",
    "ausgebesserterer": "ausgebessert",
    "ausgebesserteres": "ausgebessert",
    "ausgebessertes": "ausgebessert",
    "ausgebesserteste": "ausgebessert",
    "ausgebessertestem": "ausgebessert",
    "ausgebessertesten": "ausgebessert",
    "ausgebessertester": "ausgebessert",
    "ausgebessertestes": "ausgebessert",
    "ausgebest": "ausgeben",
    "ausgebet": "ausgeben",
    "ausgebeten": "ausbitten",
    "ausgebetene": "ausgebeten",
    "ausgebetenem": "ausgebeten",
    "ausgebetenen": "ausgebeten",
    "ausgebetener": "ausgebeten",
    "ausgebetenes": "ausgebeten",
    "ausgebeult": "ausbeulen",
    "ausgebeulte": "ausgebeult",
    "ausgebeultem": "ausgebeult",
    "ausgebeulten": "ausgebeult",
    "ausgebeulter": "ausgebeult",
    "ausgebeultes": "ausgebeult",
    "ausgebeutelt": "ausbeuteln",
    "ausgebeutelte": "ausgebeutelt",
    "ausgebeuteltem": "ausgebeutelt",
    "ausgebeutelten": "ausgebeutelt",
    "ausgebeutelter": "ausgebeutelt",
    "ausgebeuteltes": "ausgebeutelt",
    "ausgebeutet": "ausbeuten",
    "ausgebeutete": "ausgebeutet",
    "ausgebeutetem": "ausgebeutet",
    "ausgebeuteten": "ausgebeutet",
    "ausgebeuteter": "ausgebeutet",
    "ausgebeutetere": "ausgebeutet",
    "ausgebeuteterem": "ausgebeutet",
    "ausgebeuteteren": "ausgebeutet",
    "ausgebeuteterer": "ausgebeutet",
    "ausgebeuteteres": "ausgebeutet",
    "ausgebeutetes": "ausgebeutet",
    "ausgebeuteteste": "ausgebeutet",
    "ausgebeutetestem": "ausgebeutet",
    "ausgebeutetesten": "ausgebeutet",
    "ausgebeutetester": "ausgebeutet",
    "ausgebeutetestes": "ausgebeutet",
    "ausgebildet": "ausbilden",
    "ausgebildete": "ausgebildet",
    "ausgebildetem": "ausgebildet",
    "ausgebildeten": "ausgebildet",
    "ausgebildeter": "ausgebildet",
    "ausgebildetere": "ausgebildet",
    "ausgebildeterem": "ausgebildet",
    "ausgebildeteren": "ausgebildet",
    "ausgebildeterer": "ausgebildet",
    "ausgebildeteres": "ausgebildet",
    "ausgebildetes": "ausgebildet",
    "ausgebildeteste": "ausgebildet",
    "ausgebildetestem": "ausgebildet",
    "ausgebildetesten": "ausgebildet",
    "ausgebildetester": "ausgebildet",
    "ausgebildetestes": "ausgebildet",
    "ausgebissen": "ausbeißen",
    "ausgebissene": "ausgebissen",
    "ausgebissenem": "ausgebissen",
    "ausgebissenen": "ausgebissen",
    "ausgebissener": "ausgebissen",
    "ausgebissenes": "ausgebissen",
    "ausgeblasen": "ausblasen",
    "ausgeblasene": "ausgeblasen",
    "ausgeblasenem": "ausgeblasen",
    "ausgeblasenen": "ausgeblasen",
    "ausgeblasener": "ausgeblasen",
    "ausgeblasenes": "ausgeblasen",
    "ausgeblendet": "ausblenden",
    "ausgeblendete": "ausgeblendet",
    "ausgeblendetem": "ausgeblendet",
    "ausgeblendeten": "ausgeblendet",
    "ausgeblendeter": "ausgeblendet",
    "ausgeblendetes": "ausgeblendet",
    "ausgeblichen": "ausbleichen",
    "ausgeblichene": "ausgeblichen",
    "ausgeblichenem": "ausgeblichen",
    "ausgeblichenen": "ausgeblichen",
    "ausgeblichener": "ausgeblichen",
    "ausgeblichenere": "ausgeblichen",
    "ausgeblichenerem": "ausgeblichen",
    "ausgeblicheneren": "ausgeblichen",
    "ausgeblichenerer": "ausgeblichen",
    "ausgeblicheneres": "ausgeblichen",
    "ausgeblichenes": "ausgeblichen",
    "ausgeblichenste": "ausgeblichen",
    "ausgeblichenstem": "ausgeblichen",
    "ausgeblichensten": "ausgeblichen",
    "ausgeblichenster": "ausgeblichen",
    "ausgeblichenstes": "ausgeblichen",
    "ausgeblieben": "ausbleiben",
    "ausgebliebene": "ausgeblieben",
    "ausgebliebenem": "ausgeblieben",
    "ausgebliebenen": "ausgeblieben",
    "ausgebliebener": "ausgeblieben",
    "ausgebliebenes": "ausgeblieben",
    "ausgeblutet": "ausbluten",
    "ausgeblutete": "ausgeblutet",
    "ausgeblutetem": "ausgeblutet",
    "ausgebluteten": "ausgeblutet",
    "ausgebluteter": "ausgeblutet",
    "ausgeblutetere": "ausgeblutet",
    "ausgebluteterem": "ausgeblutet",
    "ausgebluteteren": "ausgeblutet",
    "ausgebluteterer": "ausgeblutet",
    "ausgebluteteres": "ausgeblutet",
    "ausgeblutetes": "ausgeblutet",
    "ausgebluteteste": "ausgeblutet",
    "ausgeblutetestem": "ausgeblutet",
    "ausgeblutetesten": "ausgeblutet",
    "ausgeblutetester": "ausgeblutet",
    "ausgeblutetestes": "ausgeblutet",
    "ausgebogen": "ausbiegen",
    "ausgebogene": "ausgebogen",
    "ausgebogenem": "ausgebogen",
    "ausgebogenen": "ausgebogen",
    "ausgebogener": "ausgebogen",
    "ausgebogenere": "ausgebogen",
    "ausgebogenerem": "ausgebogen",
    "ausgebogeneren": "ausgebogen",
    "ausgebogenerer": "ausgebogen",
    "ausgebogeneres": "ausgebogen",
    "ausgebogenes": "ausgebogen",
    "ausgebogenste": "ausgebogen",
    "ausgebogenstem": "ausgebogen",
    "ausgebogensten": "ausgebogen",
    "ausgebogenster": "ausgebogen",
    "ausgebogenstes": "ausgebogen",
    "ausgebohrt": "ausbohren",
    "ausgebohrte": "ausgebohrt",
    "ausgebohrtem": "ausgebohrt",
    "ausgebohrten": "ausgebohrt",
    "ausgebohrter": "ausgebohrt",
    "ausgebohrtere": "ausgebohrt",
    "ausgebohrterem": "ausgebohrt",
    "ausgebohrteren": "ausgebohrt",
    "ausgebohrterer": "ausgebohrt",
    "ausgebohrteres": "ausgebohrt",
    "ausgebohrtes": "ausgebohrt",
    "ausgebohrteste": "ausgebohrt",
    "ausgebohrtestem": "ausgebohrt",
    "ausgebohrtesten": "ausgebohrt",
    "ausgebohrtester": "ausgebohrt",
    "ausgebohrtestes": "ausgebohrt",
    "ausgebombt": "ausbomben",
    "ausgebombte": "ausgebombt",
    "ausgebombtem": "ausgebombt",
    "ausgebombten": "ausgebombt",
    "ausgebombter": "ausgebombt",
    "ausgebombtere": "ausgebombt",
    "ausgebombterem": "ausgebombt",
    "ausgebombteren": "ausgebombt",
    "ausgebombterer": "ausgebombt",
    "ausgebombteres": "ausgebombt",
    "ausgebombtes": "ausgebombt",
    "ausgebombteste": "ausgebombt",
    "ausgebombtestem": "ausgebombt",
    "ausgebombtesten": "ausgebombt",
    "ausgebombtester": "ausgebombt",
    "ausgebombtestes": "ausgebombt",
    "ausgebootet": "ausbooten",
    "ausgebootete": "ausgebootet",
    "ausgebootetem": "ausgebootet",
    "ausgebooteten": "ausgebootet",
    "ausgebooteter": "ausgebootet",
    "ausgebootetere": "ausgebootet",
    "ausgebooteterem": "ausgebootet",
    "ausgebooteteren": "ausgebootet",
    "ausgebooteterer": "ausgebootet",
    "ausgebooteteres": "ausgebootet",
    "ausgebootetes": "ausgebootet",
    "ausgebooteteste": "ausgebootet",
    "ausgebootetestem": "ausgebootet",
    "ausgebootetesten": "ausgebootet",
    "ausgebootetester": "ausgebootet",
    "ausgebootetestes": "ausgebootet",
    "ausgeborgt": "ausborgen",
    "ausgeborgte": "ausgeborgt",
    "ausgeborgtem": "ausgeborgt",
    "ausgeborgten": "ausgeborgt",
    "ausgeborgter": "ausgeborgt",
    "ausgeborgtes": "ausgeborgt",
    "ausgeboten": "ausbieten",
    "ausgebotene": "ausgeboten",
    "ausgebotenem": "ausgeboten",
    "ausgebotenen": "ausgeboten",
    "ausgebotener": "ausgeboten",
    "ausgebotenes": "ausgeboten",
    "ausgebracht": "ausbringen",
    "ausgebrachte": "ausgebracht",
    "ausgebrachtem": "ausgebracht",
    "ausgebrachten": "ausgebracht",
    "ausgebrachter": "ausgebracht",
    "ausgebrachtes": "ausgebracht",
    "ausgebrannt": "ausbrennen",
    "ausgebrannte": "ausgebrannt",
    "ausgebranntem": "ausgebrannt",
    "ausgebrannten": "ausgebrannt",
    "ausgebrannter": "ausgebrannt",
    "ausgebranntere": "ausgebrannt",
    "ausgebrannterem": "ausgebrannt",
    "ausgebrannteren": "ausgebrannt",
    "ausgebrannterer": "ausgebrannt",
    "ausgebrannteres": "ausgebrannt",
    "ausgebranntes": "ausgebrannt",
    "ausgebrannteste": "ausgebrannt",
    "ausgebranntestem": "ausgebrannt",
    "ausgebranntesten": "ausgebrannt",
    "ausgebranntester": "ausgebrannt",
    "ausgebranntestes": "ausgebrannt",
    "ausgebraten": "ausbraten",
    "ausgebratene": "ausgebraten",
    "ausgebratenem": "ausgebraten",
    "ausgebratenen": "ausgebraten",
    "ausgebratener": "ausgebraten",
    "ausgebratenes": "ausgebraten",
    "ausgebreitet": "ausbreiten",
    "ausgebreitete": "ausgebreitet",
    "ausgebreitetem": "ausgebreitet",
    "ausgebreiteten": "ausgebreitet",
    "ausgebreiteter": "ausgebreitet",
    "ausgebreitetere": "ausgebreitet",
    "ausgebreiteterem": "ausgebreitet",
    "ausgebreiteteren": "ausgebreitet",
    "ausgebreiteterer": "ausgebreitet",
    "ausgebreiteteres": "ausgebreitet",
    "ausgebreitetes": "ausgebreitet",
    "ausgebreiteteste": "ausgebreitet",
    "ausgebreitetestem": "ausgebreitet",
    "ausgebreitetesten": "ausgebreitet",
    "ausgebreitetester": "ausgebreitet",
    "ausgebreitetestes": "ausgebreitet",
    "ausgebremst": "ausbremsen",
    "ausgebremste": "ausgebremst",
    "ausgebremstem": "ausgebremst",
    "ausgebremsten": "ausgebremst",
    "ausgebremster": "ausgebremst",
    "ausgebremstes": "ausgebremst",
    "ausgebrochen": "ausbrechen",
    "ausgebrochene": "ausgebrochen",
    "ausgebrochenem": "ausgebrochen",
    "ausgebrochenen": "ausgebrochen",
    "ausgebrochener": "ausgebrochen",
    "ausgebrochenere": "ausgebrochen",
    "ausgebrochenerem": "ausgebrochen",
    "ausgebrocheneren": "ausgebrochen",
    "ausgebrochenerer": "ausgebrochen",
    "ausgebrocheneres": "ausgebrochen",
    "ausgebrochenes": "ausgebrochen",
    "ausgebrochenste": "ausgebrochen",
    "ausgebrochenstem": "ausgebrochen",
    "ausgebrochensten": "ausgebrochen",
    "ausgebrochenster": "ausgebrochen",
    "ausgebrochenstes": "ausgebrochen",
    "ausgebrütet": "ausbrüten",
    "ausgebrütete": "ausgebrütet",
    "ausgebrütetem": "ausgebrütet",
    "ausgebrüteten": "ausgebrütet",
    "ausgebrüteter": "ausgebrütet",
    "ausgebrütetes": "ausgebrütet",
    "ausgebt": "ausgeben",
    "ausgebucht": "ausbuchen",
    "ausgebuchte": "ausgebucht",
    "ausgebuchtem": "ausgebucht",
    "ausgebuchten": "ausgebucht",
    "ausgebuchter": "ausgebucht",
    "ausgebuchtes": "ausgebucht",
    "ausgebuchtet": "ausbuchten",
    "ausgebuchtete": "ausgebuchtet",
    "ausgebuchtetem": "ausgebuchtet",
    "ausgebuchteten": "ausgebuchtet",
    "ausgebuchteter": "ausgebuchtet",
    "ausgebuchtetes": "ausgebuchtet",
    "ausgebuddelt": "ausbuddeln",
    "ausgebuddelte": "ausgebuddelt",
    "ausgebuddeltem": "ausgebuddelt",
    "ausgebuddelten": "ausgebuddelt",
    "ausgebuddelter": "ausgebuddelt",
    "ausgebuddeltes": "ausgebuddelt",
    "ausgebuffte": "ausgebufft",
    "ausgebufftem": "ausgebufft",
    "ausgebufften": "ausgebufft",
    "ausgebuffter": "ausgebufft",
    "ausgebufftere": "ausgebufft",
    "ausgebuffterem": "ausgebufft",
    "ausgebuffteren": "ausgebufft",
    "ausgebuffterer": "ausgebufft",
    "ausgebuffteres": "ausgebufft",
    "ausgebufftes": "ausgebufft",
    "ausgebuffteste": "ausgebufft",
    "ausgebufftestem": "ausgebufft",
    "ausgebufftesten": "ausgebufft",
    "ausgebufftester": "ausgebufft",
    "ausgebufftestes": "ausgebufft",
    "ausgebügelt": "ausbügeln",
    "ausgebügelte": "ausgebügelt",
    "ausgebügeltem": "ausgebügelt",
    "ausgebügelten": "ausgebügelt",
    "ausgebügelter": "ausgebügelt",
    "ausgebügeltes": "ausgebügelt",
    "ausgebürgert": "ausbürgern",
    "ausgebürgerte": "ausgebürgert",
    "ausgebürgertem": "ausgebürgert",
    "ausgebürgerten": "ausgebürgert",
    "ausgebürgerter": "ausgebürgert",
    "ausgebürgertes": "ausgebürgert",
    "ausgebürstet": "ausbürsten",
    "ausgebürstete": "ausgebürstet",
    "ausgebürstetem": "ausgebürstet",
    "ausgebürsteten": "ausgebürstet",
    "ausgebürsteter": "ausgebürstet",
    "ausgebürstetes": "ausgebürstet",
    "ausgebüxt": "ausbüxen",
    "ausgebüxte": "ausgebüxt",
    "ausgebüxtem": "ausgebüxt",
    "ausgebüxten": "ausgebüxt",
    "ausgebüxter": "ausgebüxt",
    "ausgebüxtes": "ausgebüxt",
    "ausgecheckt": "auschecken",
    "ausgecheckte": "ausgecheckt",
    "ausgechecktem": "ausgecheckt",
    "ausgecheckten": "ausgecheckt",
    "ausgecheckter": "ausgecheckt",
    "ausgechecktes": "ausgecheckt",
    "ausgedacht": "ausdenken",
    "ausgedachte": "ausgedacht",
    "ausgedachtem": "ausgedacht",
    "ausgedachten": "ausgedacht",
    "ausgedachter": "ausgedacht",
    "ausgedachtes": "ausgedacht",
    "ausgedauert": "ausdauern",
    "ausgedauerte": "ausgedauert",
    "ausgedauertem": "ausgedauert",
    "ausgedauerten": "ausgedauert",
    "ausgedauerter": "ausgedauert",
    "ausgedauertere": "ausgedauert",
    "ausgedauerterem": "ausgedauert",
    "ausgedauerteren": "ausgedauert",
    "ausgedauerterer": "ausgedauert",
    "ausgedauerteres": "ausgedauert",
    "ausgedauertes": "ausgedauert",
    "ausgedauerteste": "ausgedauert",
    "ausgedauertestem": "ausgedauert",
    "ausgedauertesten": "ausgedauert",
    "ausgedauertester": "ausgedauert",
    "ausgedauertestes": "ausgedauert",
    "ausgedehnt": "ausdehnen",
    "ausgedehnte": "ausgedehnt",
    "ausgedehntem": "ausgedehnt",
    "ausgedehnten": "ausgedehnt",
    "ausgedehnter": "ausgedehnt",
    "ausgedehntere": "ausgedehnt",
    "ausgedehnterem": "ausgedehnt",
    "ausgedehnteren": "ausgedehnt",
    "ausgedehnterer": "ausgedehnt",
    "ausgedehnteres": "ausgedehnt",
    "ausgedehntes": "ausgedehnt",
    "ausgedehnteste": "ausgedehnt",
    "ausgedehntestem": "ausgedehnt",
    "ausgedehntesten": "ausgedehnt",
    "ausgedehntester": "ausgedehnt",
    "ausgedehntestes": "ausgedehnt",
    "ausgedeutet": "ausdeuten",
    "ausgedeutete": "ausgedeutet",
    "ausgedeutetem": "ausgedeutet",
    "ausgedeuteten": "ausgedeutet",
    "ausgedeuteter": "ausgedeutet",
    "ausgedeutetes": "ausgedeutet",
    "ausgedient": "ausdienen",
    "ausgediente": "ausgedient",
    "ausgedientem": "ausgedient",
    "ausgedienten": "ausgedient",
    "ausgedienter": "ausgedient",
    "ausgedientes": "ausgedient",
    "ausgedreht": "ausdrehen",
    "ausgedrehte": "ausgedreht",
    "ausgedrehtem": "ausgedreht",
    "ausgedrehten": "ausgedreht",
    "ausgedrehter": "ausgedreht",
    "ausgedrehtes": "ausgedreht",
    "ausgedroschen": "ausdreschen",
    "ausgedroschene": "ausgedroschen",
    "ausgedroschenem": "ausgedroschen",
    "ausgedroschenen": "ausgedroschen",
    "ausgedroschener": "ausgedroschen",
    "ausgedroschenere": "ausgedroschen",
    "ausgedroschenerem": "ausgedroschen",
    "ausgedroscheneren": "ausgedroschen",
    "ausgedroschenerer": "ausgedroschen",
    "ausgedroscheneres": "ausgedroschen",
    "ausgedroschenes": "ausgedroschen",
    "ausgedroschenste": "ausgedroschen",
    "ausgedroschenstem": "ausgedroschen",
    "ausgedroschensten": "ausgedroschen",
    "ausgedroschenster": "ausgedroschen",
    "ausgedroschenstes": "ausgedroschen",
    "ausgedruckt": "ausdrucken",
    "ausgedruckte": "ausgedruckt",
    "ausgedrucktem": "ausgedruckt",
    "ausgedruckten": "ausgedruckt",
    "ausgedruckter": "ausgedruckt",
    "ausgedrucktes": "ausgedruckt",
    "ausgedrungen": "ausdringen",
    "ausgedrungene": "ausgedrungen",
    "ausgedrungenem": "ausgedrungen",
    "ausgedrungenen": "ausgedrungen",
    "ausgedrungener": "ausgedrungen",
    "ausgedrungenere": "ausgedrungen",
    "ausgedrungenerem": "ausgedrungen",
    "ausgedrungeneren": "ausgedrungen",
    "ausgedrungenerer": "ausgedrungen",
    "ausgedrungeneres": "ausgedrungen",
    "ausgedrungenes": "ausgedrungen",
    "ausgedrungenste": "ausgedrungen",
    "ausgedrungenstem": "ausgedrungen",
    "ausgedrungensten": "ausgedrungen",
    "ausgedrungenster": "ausgedrungen",
    "ausgedrungenstes": "ausgedrungen",
    "ausgedrückt": "ausdrücken",
    "ausgedrücktem": "ausgedrückt",
    "ausgedrückter": "ausgedrückt",
    "ausgedrücktes": "ausgedrückt",
    "ausgedunstet": "ausdunsten",
    "ausgedunstete": "ausgedunstet",
    "ausgedunstetem": "ausgedunstet",
    "ausgedunsteten": "ausgedunstet",
    "ausgedunsteter": "ausgedunstet",
    "ausgedunstetere": "ausgedunstet",
    "ausgedunsteterem": "ausgedunstet",
    "ausgedunsteteren": "ausgedunstet",
    "ausgedunsteterer": "ausgedunstet",
    "ausgedunsteteres": "ausgedunstet",
    "ausgedunstetes": "ausgedunstet",
    "ausgedunsteteste": "ausgedunstet",
    "ausgedunstetestem": "ausgedunstet",
    "ausgedunstetesten": "ausgedunstet",
    "ausgedunstetester": "ausgedunstet",
    "ausgedunstetestes": "ausgedunstet",
    "ausgedörrt": "ausdörren",
    "ausgedörrte": "ausgedörrt",
    "ausgedörrtem": "ausgedörrt",
    "ausgedörrten": "ausgedörrt",
    "ausgedörrter": "ausgedörrt",
    "ausgedörrtere": "ausgedörrt",
    "ausgedörrterem": "ausgedörrt",
    "ausgedörrteren": "ausgedörrt",
    "ausgedörrterer": "ausgedörrt",
    "ausgedörrteres": "ausgedörrt",
    "ausgedörrtes": "ausgedörrt",
    "ausgedörrteste": "ausgedörrt",
    "ausgedörrtestem": "ausgedörrt",
    "ausgedörrtesten": "ausgedörrt",
    "ausgedörrtester": "ausgedörrt",
    "ausgedörrtestes": "ausgedörrt",
    "ausgefahren": "ausfahren",
    "ausgefahrene": "ausgefahren",
    "ausgefahrenem": "ausgefahren",
    "ausgefahrenen": "ausgefahren",
    "ausgefahrener": "ausgefahren",
    "ausgefahrenes": "ausgefahren",
    "ausgefallen": "ausfallen",
    "ausgefallene": "ausgefallen",
    "ausgefallenem": "ausgefallen",
    "ausgefallenen": "ausgefallen",
    "ausgefallener": "ausgefallen",
    "ausgefallenere": "ausgefallen",
    "ausgefallenerem": "ausgefallen",
    "ausgefalleneren": "ausgefallen",
    "ausgefallenerer": "ausgefallen",
    "ausgefalleneres": "ausgefallen",
    "ausgefallenes": "ausgefallen",
    "ausgefallenste": "ausgefallen",
    "ausgefallenstem": "ausgefallen",
    "ausgefallensten": "ausgefallen",
    "ausgefallenster": "ausgefallen",
    "ausgefallenstes": "ausgefallen",
    "ausgefasert": "ausfasern",
    "ausgefaserte": "ausgefasert",
    "ausgefasertem": "ausgefasert",
    "ausgefaserten": "ausgefasert",
    "ausgefaserter": "ausgefasert",
    "ausgefasertere": "ausgefasert",
    "ausgefaserterem": "ausgefasert",
    "ausgefaserteren": "ausgefasert",
    "ausgefaserterer": "ausgefasert",
    "ausgefaserteres": "ausgefasert",
    "ausgefasertes": "ausgefasert",
    "ausgefaserteste": "ausgefasert",
    "ausgefasertestem": "ausgefasert",
    "ausgefasertesten": "ausgefasert",
    "ausgefasertester": "ausgefasert",
    "ausgefasertestes": "ausgefasert",
    "ausgefegt": "ausfegen",
    "ausgefegte": "ausgefegt",
    "ausgefegtem": "ausgefegt",
    "ausgefegten": "ausgefegt",
    "ausgefegter": "ausgefegt",
    "ausgefegtere": "ausgefegt",
    "ausgefegterem": "ausgefegt",
    "ausgefegteren": "ausgefegt",
    "ausgefegterer": "ausgefegt",
    "ausgefegteres": "ausgefegt",
    "ausgefegtes": "ausgefegt",
    "ausgefegteste": "ausgefegt",
    "ausgefegtestem": "ausgefegt",
    "ausgefegtesten": "ausgefegt",
    "ausgefegtester": "ausgefegt",
    "ausgefegtestes": "ausgefegt",
    "ausgefeilt": "ausfeilen",
    "ausgefeilte": "ausgefeilt",
    "ausgefeiltem": "ausgefeilt",
    "ausgefeilten": "ausgefeilt",
    "ausgefeilter": "ausgefeilt",
    "ausgefeiltere": "ausgefeilt",
    "ausgefeilterem": "ausgefeilt",
    "ausgefeilteren": "ausgefeilt",
    "ausgefeilterer": "ausgefeilt",
    "ausgefeilteres": "ausgefeilt",
    "ausgefeiltes": "ausgefeilt",
    "ausgefeilteste": "ausgefeilt",
    "ausgefeiltestem": "ausgefeilt",
    "ausgefeiltesten": "ausgefeilt",
    "ausgefeiltester": "ausgefeilt",
    "ausgefeiltestes": "ausgefeilt",
    "ausgefertigt": "ausfertigen",
    "ausgefertigte": "ausgefertigt",
    "ausgefertigtem": "ausgefertigt",
    "ausgefertigten": "ausgefertigt",
    "ausgefertigter": "ausgefertigt",
    "ausgefertigtes": "ausgefertigt",
    "ausgefiltert": "ausfiltern",
    "ausgefilterte": "ausgefiltert",
    "ausgefiltertem": "ausgefiltert",
    "ausgefilterten": "ausgefiltert",
    "ausgefilterter": "ausgefiltert",
    "ausgefiltertere": "ausgefiltert",
    "ausgefilterterem": "ausgefiltert",
    "ausgefilterteren": "ausgefiltert",
    "ausgefilterterer": "ausgefiltert",
    "ausgefilterteres": "ausgefiltert",
    "ausgefiltertes": "ausgefiltert",
    "ausgefilterteste": "ausgefiltert",
    "ausgefiltertestem": "ausgefiltert",
    "ausgefiltertesten": "ausgefiltert",
    "ausgefiltertester": "ausgefiltert",
    "ausgefiltertestes": "ausgefiltert",
    "ausgefischt": "ausfischen",
    "ausgefischte": "ausgefischt",
    "ausgefischtem": "ausgefischt",
    "ausgefischten": "ausgefischt",
    "ausgefischter": "ausgefischt",
    "ausgefischtes": "ausgefischt",
    "ausgeflaggt": "ausflaggen",
    "ausgeflaggte": "ausgeflaggt",
    "ausgeflaggtem": "ausgeflaggt",
    "ausgeflaggten": "ausgeflaggt",
    "ausgeflaggter": "ausgeflaggt",
    "ausgeflaggtere": "ausgeflaggt",
    "ausgeflaggterem": "ausgeflaggt",
    "ausgeflaggteren": "ausgeflaggt",
    "ausgeflaggterer": "ausgeflaggt",
    "ausgeflaggteres": "ausgeflaggt",
    "ausgeflaggtes": "ausgeflaggt",
    "ausgeflaggteste": "ausgeflaggt",
    "ausgeflaggtestem": "ausgeflaggt",
    "ausgeflaggtesten": "ausgeflaggt",
    "ausgeflaggtester": "ausgeflaggt",
    "ausgeflaggtestes": "ausgeflaggt",
    "ausgeflippt": "ausflippen",
    "ausgeflippte": "ausgeflippt",
    "ausgeflipptem": "ausgeflippt",
    "ausgeflippten": "ausgeflippt",
    "ausgeflippter": "ausgeflippt",
    "ausgeflipptere": "ausgeflippt",
    "ausgeflippterem": "ausgeflippt",
    "ausgeflippteren": "ausgeflippt",
    "ausgeflippterer": "ausgeflippt",
    "ausgeflippteres": "ausgeflippt",
    "ausgeflipptes": "ausgeflippt",
    "ausgeflippteste": "ausgeflippt",
    "ausgeflipptestem": "ausgeflippt",
    "ausgeflipptesten": "ausgeflippt",
    "ausgeflipptester": "ausgeflippt",
    "ausgeflipptestes": "ausgeflippt",
    "ausgeflockt": "ausflocken",
    "ausgeflockte": "ausgeflockt",
    "ausgeflocktem": "ausgeflockt",
    "ausgeflockten": "ausgeflockt",
    "ausgeflockter": "ausgeflockt",
    "ausgeflocktes": "ausgeflockt",
    "ausgeflogen": "ausfliegen",
    "ausgeflogene": "ausgeflogen",
    "ausgeflogenem": "ausgeflogen",
    "ausgeflogenen": "ausgeflogen",
    "ausgeflogener": "ausgeflogen",
    "ausgeflogenes": "ausgeflogen",
    "ausgeflossen": "ausfließen",
    "ausgeflossene": "ausgeflossen",
    "ausgeflossenem": "ausgeflossen",
    "ausgeflossenen": "ausgeflossen",
    "ausgeflossener": "ausgeflossen",
    "ausgeflossenes": "ausgeflossen",
    "ausgefochten": "ausfechten",
    "ausgefochtene": "ausgefochten",
    "ausgefochtenem": "ausgefochten",
    "ausgefochtenen": "ausgefochten",
    "ausgefochtener": "ausgefochten",
    "ausgefochtenere": "ausgefochten",
    "ausgefochtenerem": "ausgefochten",
    "ausgefochteneren": "ausgefochten",
    "ausgefochtenerer": "ausgefochten",
    "ausgefochteneres": "ausgefochten",
    "ausgefochtenes": "ausgefochten",
    "ausgefochtenste": "ausgefochten",
    "ausgefochtenstem": "ausgefochten",
    "ausgefochtensten": "ausgefochten",
    "ausgefochtenster": "ausgefochten",
    "ausgefochtenstes": "ausgefochten",
    "ausgefolgt": "ausfolgen",
    "ausgefolgte": "ausgefolgt",
    "ausgefolgtem": "ausgefolgt",
    "ausgefolgten": "ausgefolgt",
    "ausgefolgter": "ausgefolgt",
    "ausgefolgtes": "ausgefolgt",
    "ausgeforscht": "ausforschen",
    "ausgeforschte": "ausgeforscht",
    "ausgeforschtem": "ausgeforscht",
    "ausgeforschten": "ausgeforscht",
    "ausgeforschter": "ausgeforscht",
    "ausgeforschtes": "ausgeforscht",
    "ausgefragt": "ausfragen",
    "ausgefragte": "ausgefragt",
    "ausgefragtem": "ausgefragt",
    "ausgefragten": "ausgefragt",
    "ausgefragter": "ausgefragt",
    "ausgefragtere": "ausgefragt",
    "ausgefragterem": "ausgefragt",
    "ausgefragteren": "ausgefragt",
    "ausgefragterer": "ausgefragt",
    "ausgefragteres": "ausgefragt",
    "ausgefragtes": "ausgefragt",
    "ausgefragteste": "ausgefragt",
    "ausgefragtestem": "ausgefragt",
    "ausgefragtesten": "ausgefragt",
    "ausgefragtester": "ausgefragt",
    "ausgefragtestes": "ausgefragt",
    "ausgefranst": "ausfransen",
    "ausgefranste": "ausgefranst",
    "ausgefranstem": "ausgefranst",
    "ausgefransten": "ausgefranst",
    "ausgefranster": "ausgefranst",
    "ausgefranstere": "ausgefranst",
    "ausgefransterem": "ausgefranst",
    "ausgefransteren": "ausgefranst",
    "ausgefransterer": "ausgefranst",
    "ausgefransteres": "ausgefranst",
    "ausgefranstes": "ausgefranst",
    "ausgefransteste": "ausgefranst",
    "ausgefranstestem": "ausgefranst",
    "ausgefranstesten": "ausgefranst",
    "ausgefranstester": "ausgefranst",
    "ausgefranstestes": "ausgefranst",
    "ausgefressen": "ausfressen",
    "ausgefressene": "ausgefressen",
    "ausgefressenem": "ausgefressen",
    "ausgefressenen": "ausgefressen",
    "ausgefressener": "ausgefressen",
    "ausgefressenes": "ausgefressen",
    "ausgefroren": "ausfrieren",
    "ausgefrorene": "ausgefroren",
    "ausgefrorenem": "ausgefroren",
    "ausgefrorenen": "ausgefroren",
    "ausgefrorener": "ausgefroren",
    "ausgefrorenes": "ausgefroren",
    "ausgefugt": "ausfugen",
    "ausgefugte": "ausgefugt",
    "ausgefugtem": "ausgefugt",
    "ausgefugten": "ausgefugt",
    "ausgefugter": "ausgefugt",
    "ausgefugtere": "ausgefugt",
    "ausgefugterem": "ausgefugt",
    "ausgefugteren": "ausgefugt",
    "ausgefugterer": "ausgefugt",
    "ausgefugteres": "ausgefugt",
    "ausgefugtes": "ausgefugt",
    "ausgefugteste": "ausgefugt",
    "ausgefugtestem": "ausgefugt",
    "ausgefugtesten": "ausgefugt",
    "ausgefugtester": "ausgefugt",
    "ausgefugtestes": "ausgefugt",
    "ausgefädelt": "ausfädeln",
    "ausgefädelte": "ausgefädelt",
    "ausgefädeltem": "ausgefädelt",
    "ausgefädelten": "ausgefädelt",
    "ausgefädelter": "ausgefädelt",
    "ausgefädeltes": "ausgefädelt",
    "ausgefällt": "ausfällen",
    "ausgefällte": "ausgefällt",
    "ausgefälltem": "ausgefällt",
    "ausgefällten": "ausgefällt",
    "ausgefällter": "ausgefällt",
    "ausgefälltes": "ausgefällt",
    "ausgeführt": "ausführen",
    "ausgeführte": "ausgeführt",
    "ausgeführtem": "ausgeführt",
    "ausgeführten": "ausgeführt",
    "ausgeführter": "ausgeführt",
    "ausgeführtes": "ausgeführt",
    "ausgefüllt": "ausfüllen",
    "ausgefüllte": "ausgefüllt",
    "ausgefülltem": "ausgefüllt",
    "ausgefüllten": "ausgefüllt",
    "ausgefüllter": "ausgefüllt",
    "ausgefülltes": "ausgefüllt",
    "ausgefüttert": "ausfüttern",
    "ausgefütterte": "ausgefüttert",
    "ausgefüttertem": "ausgefüttert",
    "ausgefütterten": "ausgefüttert",
    "ausgefütterter": "ausgefüttert",
    "ausgefüttertes": "ausgefüttert",
    "ausgegangen": "ausgehen",
    "ausgegangene": "ausgegangen",
    "ausgegangenem": "ausgegangen",
    "ausgegangenen": "ausgegangen",
    "ausgegangener": "ausgegangen",
    "ausgegangenes": "ausgegangen",
    "ausgegeben": "ausgeben",
    "ausgegebene": "ausgegeben",
    "ausgegebenem": "ausgegeben",
    "ausgegebenen": "ausgegeben",
    "ausgegebener": "ausgegeben",
    "ausgegebenes": "ausgegeben",
    "ausgegeizt": "ausgeizen",
    "ausgegeizte": "ausgegeizt",
    "ausgegeiztem": "ausgegeizt",
    "ausgegeizten": "ausgegeizt",
    "ausgegeizter": "ausgegeizt",
    "ausgegeiztes": "ausgegeizt",
    "ausgegessen": "ausessen",
    "ausgegessene": "ausgegessen",
    "ausgegessenem": "ausgegessen",
    "ausgegessenen": "ausgegessen",
    "ausgegessener": "ausgegessen",
    "ausgegessenes": "ausgegessen",
    "ausgeglichen": "ausgleichen",
    "ausgeglichene": "ausgeglichen",
    "ausgeglichenem": "ausgeglichen",
    "ausgeglichenen": "ausgeglichen",
    "ausgeglichener": "ausgeglichen",
    "ausgeglichenere": "ausgeglichen",
    "ausgeglichenerem": "ausgeglichen",
    "ausgeglicheneren": "ausgeglichen",
    "ausgeglichenerer": "ausgeglichen",
    "ausgeglicheneres": "ausgeglichen",
    "ausgeglichenes": "ausgeglichen",
    "ausgeglichenste": "ausgeglichen",
    "ausgeglichenstem": "ausgeglichen",
    "ausgeglichensten": "ausgeglichen",
    "ausgeglichenster": "ausgeglichen",
    "ausgeglichenstes": "ausgeglichen",
    "ausgegliedert": "ausgliedern",
    "ausgegliederte": "ausgegliedert",
    "ausgegliedertem": "ausgegliedert",
    "ausgegliederten": "ausgegliedert",
    "ausgegliederter": "ausgegliedert",
    "ausgegliedertes": "ausgegliedert",
    "ausgeglitscht": "ausglitschen",
    "ausgeglitschte": "ausgeglitscht",
    "ausgeglitschtem": "ausgeglitscht",
    "ausgeglitschten": "ausgeglitscht",
    "ausgeglitschter": "ausgeglitscht",
    "ausgeglitschtes": "ausgeglitscht",
    "ausgeglitten": "ausgleiten",
    "ausgeglittene": "ausgeglitten",
    "ausgeglittenem": "ausgeglitten",
    "ausgeglittenen": "ausgeglitten",
    "ausgeglittener": "ausgeglitten",
    "ausgeglittenes": "ausgeglitten",
    "ausgeglommen": "ausglimmen",
    "ausgeglommene": "ausgeglommen",
    "ausgeglommenem": "ausgeglommen",
    "ausgeglommenen": "ausgeglommen",
    "ausgeglommener": "ausgeglommen",
    "ausgeglommenere": "ausgeglommen",
    "ausgeglommenerem": "ausgeglommen",
    "ausgeglommeneren": "ausgeglommen",
    "ausgeglommenerer": "ausgeglommen",
    "ausgeglommeneres": "ausgeglommen",
    "ausgeglommenes": "ausgeglommen",
    "ausgeglommenste": "ausgeglommen",
    "ausgeglommenstem": "ausgeglommen",
    "ausgeglommensten": "ausgeglommen",
    "ausgeglommenster": "ausgeglommen",
    "ausgeglommenstes": "ausgeglommen",
    "ausgeglüht": "ausglühen",
    "ausgeglühte": "ausgeglüht",
    "ausgeglühtem": "ausgeglüht",
    "ausgeglühten": "ausgeglüht",
    "ausgeglühter": "ausgeglüht",
    "ausgeglühtere": "ausgeglüht",
    "ausgeglühterem": "ausgeglüht",
    "ausgeglühteren": "ausgeglüht",
    "ausgeglühterer": "ausgeglüht",
    "ausgeglühteres": "ausgeglüht",
    "ausgeglühtes": "ausgeglüht",
    "ausgeglühteste": "ausgeglüht",
    "ausgeglühtestem": "ausgeglüht",
    "ausgeglühtesten": "ausgeglüht",
    "ausgeglühtester": "ausgeglüht",
    "ausgeglühtestes": "ausgeglüht",
    "ausgegossen": "ausgießen",
    "ausgegossene": "ausgegossen",
    "ausgegossenem": "ausgegossen",
    "ausgegossenen": "ausgegossen",
    "ausgegossener": "ausgegossen",
    "ausgegossenes": "ausgegossen",
    "ausgegraben": "ausgraben",
    "ausgegrabene": "ausgegraben",
    "ausgegrabenem": "ausgegraben",
    "ausgegrabenen": "ausgegraben",
    "ausgegrabener": "ausgegraben",
    "ausgegrabenes": "ausgegraben",
    "ausgegrenzt": "ausgrenzen",
    "ausgegrenzte": "ausgegrenzt",
    "ausgegrenztem": "ausgegrenzt",
    "ausgegrenzten": "ausgegrenzt",
    "ausgegrenzter": "ausgegrenzt",
    "ausgegrenztere": "ausgegrenzt",
    "ausgegrenzterem": "ausgegrenzt",
    "ausgegrenzteren": "ausgegrenzt",
    "ausgegrenzterer": "ausgegrenzt",
    "ausgegrenzteres": "ausgegrenzt",
    "ausgegrenztes": "ausgegrenzt",
    "ausgegrenzteste": "ausgegrenzt",
    "ausgegrenztestem": "ausgegrenzt",
    "ausgegrenztesten": "ausgegrenzt",
    "ausgegrenztester": "ausgegrenzt",
    "ausgegrenztestes": "ausgegrenzt",
    "ausgegriffen": "ausgreifen",
    "ausgegriffene": "ausgegriffen",
    "ausgegriffenem": "ausgegriffen",
    "ausgegriffenen": "ausgegriffen",
    "ausgegriffener": "ausgegriffen",
    "ausgegriffenes": "ausgegriffen",
    "ausgehakt": "aushaken",
    "ausgehakte": "ausgehakt",
    "ausgehaktem": "ausgehakt",
    "ausgehakten": "ausgehakt",
    "ausgehakter": "ausgehakt",
    "ausgehaktes": "ausgehakt",
    "ausgehalten": "aushalten",
    "ausgehaltene": "ausgehalten",
    "ausgehaltenem": "ausgehalten",
    "ausgehaltenen": "ausgehalten",
    "ausgehaltener": "ausgehalten",
    "ausgehaltenes": "ausgehalten",
    "ausgehandelt": "aushandeln",
    "ausgehandelte": "ausgehandelt",
    "ausgehandeltem": "ausgehandelt",
    "ausgehandelten": "ausgehandelt",
    "ausgehandelter": "ausgehandelt",
    "ausgehandeltes": "ausgehandelt",
    "ausgehangen": "aushängen",
    "ausgehangene": "ausgehangen",
    "ausgehangenem": "ausgehangen",
    "ausgehangenen": "ausgehangen",
    "ausgehangener": "ausgehangen",
    "ausgehangenes": "ausgehangen",
    "ausgeharrte": "ausgeharrt",
    "ausgeharrtem": "ausgeharrt",
    "ausgeharrten": "ausgeharrt",
    "ausgeharrter": "ausgeharrt",
    "ausgeharrtes": "ausgeharrt",
    "ausgehaucht": "aushauchen",
    "ausgehauchte": "ausgehaucht",
    "ausgehauchtem": "ausgehaucht",
    "ausgehauchten": "ausgehaucht",
    "ausgehauchter": "ausgehaucht",
    "ausgehauchtes": "ausgehaucht",
    "ausgehauen": "aushauen",
    "ausgehauene": "ausgehauen",
    "ausgehauenem": "ausgehauen",
    "ausgehauenen": "ausgehauen",
    "ausgehauener": "ausgehauen",
    "ausgehauenes": "ausgehauen",
    "ausgehe": "ausgehen",
    "ausgeheilt": "ausheilen",
    "ausgeheilte": "ausgeheilt",
    "ausgeheiltem": "ausgeheilt",
    "ausgeheilten": "ausgeheilt",
    "ausgeheilter": "ausgeheilt",
    "ausgeheiltere": "ausgeheilt",
    "ausgeheilterem": "ausgeheilt",
    "ausgeheilteren": "ausgeheilt",
    "ausgeheilterer": "ausgeheilt",
    "ausgeheilteres": "ausgeheilt",
    "ausgeheiltes": "ausgeheilt",
    "ausgeheilteste": "ausgeheilt",
    "ausgeheiltestem": "ausgeheilt",
    "ausgeheiltesten": "ausgeheilt",
    "ausgeheiltester": "ausgeheilt",
    "ausgeheiltestes": "ausgeheilt",
    "ausgehend": "ausgehen",
    "ausgehende": "ausgehend",
    "ausgehendem": "ausgehend",
    "ausgehenden": "ausgehend",
    "ausgehender": "ausgehend",
    "ausgehendes": "ausgehend",
    "ausgehest": "ausgehen",
    "ausgehet": "ausgehen",
    "ausgehoben": "ausheben",
    "ausgehobene": "ausgehoben",
    "ausgehobenem": "ausgehoben",
    "ausgehobenen": "ausgehoben",
    "ausgehobener": "ausgehoben",
    "ausgehobenes": "ausgehoben",
    "ausgeholfen": "aushelfen",
    "ausgeholfene": "ausgeholfen",
    "ausgeholfenem": "ausgeholfen",
    "ausgeholfenen": "ausgeholfen",
    "ausgeholfener": "ausgeholfen",
    "ausgeholfenes": "ausgeholfen",
    "ausgeholt": "ausholen",
    "ausgeholte": "ausgeholt",
    "ausgeholtem": "ausgeholt",
    "ausgeholten": "ausgeholt",
    "ausgeholter": "ausgeholt",
    "ausgeholtes": "ausgeholt",
    "ausgeholzt": "ausholzen",
    "ausgeholzte": "ausgeholzt",
    "ausgeholztem": "ausgeholzt",
    "ausgeholzten": "ausgeholzt",
    "ausgeholzter": "ausgeholzt",
    "ausgeholztes": "ausgeholzt",
    "ausgehorcht": "aushorchen",
    "ausgehorchte": "ausgehorcht",
    "ausgehorchtem": "ausgehorcht",
    "ausgehorchten": "ausgehorcht",
    "ausgehorchter": "ausgehorcht",
    "ausgehorchtere": "ausgehorcht",
    "ausgehorchterem": "ausgehorcht",
    "ausgehorchteren": "ausgehorcht",
    "ausgehorchterer": "ausgehorcht",
    "ausgehorchteres": "ausgehorcht",
    "ausgehorchtes": "ausgehorcht",
    "ausgehorchteste": "ausgehorcht",
    "ausgehorchtestem": "ausgehorcht",
    "ausgehorchtesten": "ausgehorcht",
    "ausgehorchtester": "ausgehorcht",
    "ausgehorchtestes": "ausgehorcht",
    "ausgehst": "ausgehen",
    "ausgeht": "ausgehen",
    "ausgehungert": "aushungern",
    "ausgehungerte": "ausgehungert",
    "ausgehungertem": "ausgehungert",
    "ausgehungerten": "ausgehungert",
    "ausgehungerter": "ausgehungert",
    "ausgehungertere": "ausgehungert",
    "ausgehungerterem": "ausgehungert",
    "ausgehungerteren": "ausgehungert",
    "ausgehungerterer": "ausgehungert",
    "ausgehungerteres": "ausgehungert",
    "ausgehungertes": "ausgehungert",
    "ausgehungerteste": "ausgehungert",
    "ausgehungertestem": "ausgehungert",
    "ausgehungertesten": "ausgehungert",
    "ausgehungertester": "ausgehungert",
    "ausgehungertestes": "ausgehungert",
    "ausgehustet": "aushusten",
    "ausgehustete": "ausgehustet",
    "ausgehustetem": "ausgehustet",
    "ausgehusteten": "ausgehustet",
    "ausgehusteter": "ausgehustet",
    "ausgehustetes": "ausgehustet",
    "ausgehändigt": "aushändigen",
    "ausgehändigte": "ausgehändigt",
    "ausgehändigtem": "ausgehändigt",
    "ausgehändigten": "ausgehändigt",
    "ausgehändigter": "ausgehändigt",
    "ausgehändigtes": "ausgehändigt",
    "ausgehängt": "aushängen",
    "ausgehängte": "ausgehängt",
    "ausgehängtem": "ausgehängt",
    "ausgehängten": "ausgehängt",
    "ausgehängter": "ausgehängt",
    "ausgehängtere": "ausgehängt",
    "ausgehängterem": "ausgehängt",
    "ausgehängteren": "ausgehängt",
    "ausgehängterer": "ausgehängt",
    "ausgehängteres": "ausgehängt",
    "ausgehängtes": "ausgehängt",
    "ausgehängteste": "ausgehängt",
    "ausgehängtestem": "ausgehängt",
    "ausgehängtesten": "ausgehängt",
    "ausgehängtester": "ausgehängt",
    "ausgehängtestes": "ausgehängt",
    "ausgehärtet": "aushärten",
    "ausgehärtete": "ausgehärtet",
    "ausgehärtetem": "ausgehärtet",
    "ausgehärteten": "ausgehärtet",
    "ausgehärteter": "ausgehärtet",
    "ausgehärtetere": "ausgehärtet",
    "ausgehärteterem": "ausgehärtet",
    "ausgehärteteren": "ausgehärtet",
    "ausgehärteterer": "ausgehärtet",
    "ausgehärteteres": "ausgehärtet",
    "ausgehärtetes": "ausgehärtet",
    "ausgehärteteste": "ausgehärtet",
    "ausgehärtetestem": "ausgehärtet",
    "ausgehärtetesten": "ausgehärtet",
    "ausgehärtetester": "ausgehärtet",
    "ausgehärtetestes": "ausgehärtet",
    "ausgehöhlt": "aushöhlen",
    "ausgehöhlte": "ausgehöhlt",
    "ausgehöhltem": "ausgehöhlt",
    "ausgehöhlten": "ausgehöhlt",
    "ausgehöhlter": "ausgehöhlt",
    "ausgehöhltere": "ausgehöhlt",
    "ausgehöhlterem": "ausgehöhlt",
    "ausgehöhlteren": "ausgehöhlt",
    "ausgehöhlterer": "ausgehöhlt",
    "ausgehöhlteres": "ausgehöhlt",
    "ausgehöhltes": "ausgehöhlt",
    "ausgehöhlteste": "ausgehöhlt",
    "ausgehöhltestem": "ausgehöhlt",
    "ausgehöhltesten": "ausgehöhlt",
    "ausgehöhltester": "ausgehöhlt",
    "ausgehöhltestes": "ausgehöhlt",
    "ausgehülst": "aushülsen",
    "ausgehülste": "ausgehülst",
    "ausgehülstem": "ausgehülst",
    "ausgehülsten": "ausgehülst",
    "ausgehülster": "ausgehülst",
    "ausgehülstere": "ausgehülst",
    "ausgehülsterem": "ausgehülst",
    "ausgehülsteren": "ausgehülst",
    "ausgehülsterer": "ausgehülst",
    "ausgehülsteres": "ausgehülst",
    "ausgehülstes": "ausgehülst",
    "ausgehülsteste": "ausgehülst",
    "ausgehülstestem": "ausgehülst",
    "ausgehülstesten": "ausgehülst",
    "ausgehülstester": "ausgehülst",
    "ausgehülstestes": "ausgehülst",
    "ausgeize": "ausgeizen",
    "ausgeizend": "ausgeizen",
    "ausgeizende": "ausgeizend",
    "ausgeizendem": "ausgeizend",
    "ausgeizenden": "ausgeizend",
    "ausgeizender": "ausgeizend",
    "ausgeizendes": "ausgeizend",
    "ausgeizest": "ausgeizen",
    "ausgeizet": "ausgeizen",
    "ausgeizt": "ausgeizen",
    "ausgeizte": "ausgeizen",
    "ausgeizten": "ausgeizen",
    "ausgeiztest": "ausgeizen",
    "ausgeiztet": "ausgeizen",
    "ausgekannt": "auskennen",
    "ausgekannte": "ausgekannt",
    "ausgekanntem": "ausgekannt",
    "ausgekannten": "ausgekannt",
    "ausgekannter": "ausgekannt",
    "ausgekanntes": "ausgekannt",
    "ausgekegelt": "auskegeln",
    "ausgekegelte": "ausgekegelt",
    "ausgekegeltem": "ausgekegelt",
    "ausgekegelten": "ausgekegelt",
    "ausgekegelter": "ausgekegelt",
    "ausgekegeltes": "ausgekegelt",
    "ausgekehrt": "auskehren",
    "ausgekehrte": "ausgekehrt",
    "ausgekehrtem": "ausgekehrt",
    "ausgekehrten": "ausgekehrt",
    "ausgekehrter": "ausgekehrt",
    "ausgekehrtes": "ausgekehrt",
    "ausgekeilt": "auskeilen",
    "ausgekeilte": "ausgekeilt",
    "ausgekeiltem": "ausgekeilt",
    "ausgekeilten": "ausgekeilt",
    "ausgekeilter": "ausgekeilt",
    "ausgekeiltere": "ausgekeilt",
    "ausgekeilterem": "ausgekeilt",
    "ausgekeilteren": "ausgekeilt",
    "ausgekeilterer": "ausgekeilt",
    "ausgekeilteres": "ausgekeilt",
    "ausgekeiltes": "ausgekeilt",
    "ausgekeilteste": "ausgekeilt",
    "ausgekeiltestem": "ausgekeilt",
    "ausgekeiltesten": "ausgekeilt",
    "ausgekeiltester": "ausgekeilt",
    "ausgekeiltestes": "ausgekeilt",
    "ausgekeimt": "auskeimen",
    "ausgekeimte": "ausgekeimt",
    "ausgekeimtem": "ausgekeimt",
    "ausgekeimten": "ausgekeimt",
    "ausgekeimter": "ausgekeimt",
    "ausgekeimtere": "ausgekeimt",
    "ausgekeimterem": "ausgekeimt",
    "ausgekeimteren": "ausgekeimt",
    "ausgekeimterer": "ausgekeimt",
    "ausgekeimteres": "ausgekeimt",
    "ausgekeimtes": "ausgekeimt",
    "ausgekeimteste": "ausgekeimt",
    "ausgekeimtestem": "ausgekeimt",
    "ausgekeimtesten": "ausgekeimt",
    "ausgekeimtester": "ausgekeimt",
    "ausgekeimtestes": "ausgekeimt",
    "ausgekeltert": "auskeltern",
    "ausgekelterte": "ausgekeltert",
    "ausgekeltertem": "ausgekeltert",
    "ausgekelterten": "ausgekeltert",
    "ausgekelterter": "ausgekeltert",
    "ausgekeltertere": "ausgekeltert",
    "ausgekelterterem": "ausgekeltert",
    "ausgekelterteren": "ausgekeltert",
    "ausgekelterterer": "ausgekeltert",
    "ausgekelterteres": "ausgekeltert",
    "ausgekeltertes": "ausgekeltert",
    "ausgekelterteste": "ausgekeltert",
    "ausgekeltertestem": "ausgekeltert",
    "ausgekeltertesten": "ausgekeltert",
    "ausgekeltertester": "ausgekeltert",
    "ausgekeltertestes": "ausgekeltert",
    "ausgekernt": "auskernen",
    "ausgekernte": "ausgekernt",
    "ausgekerntem": "ausgekernt",
    "ausgekernten": "ausgekernt",
    "ausgekernter": "ausgekernt",
    "ausgekerntere": "ausgekernt",
    "ausgekernterem": "ausgekernt",
    "ausgekernteren": "ausgekernt",
    "ausgekernterer": "ausgekernt",
    "ausgekernteres": "ausgekernt",
    "ausgekerntes": "ausgekernt",
    "ausgekernteste": "ausgekernt",
    "ausgekerntestem": "ausgekernt",
    "ausgekerntesten": "ausgekernt",
    "ausgekerntester": "ausgekernt",
    "ausgekerntestes": "ausgekernt",
    "ausgeklammert": "ausklammern",
    "ausgeklammerte": "ausgeklammert",
    "ausgeklammertem": "ausgeklammert",
    "ausgeklammerten": "ausgeklammert",
    "ausgeklammerter": "ausgeklammert",
    "ausgeklammertes": "ausgeklammert",
    "ausgeklebt": "auskleben",
    "ausgeklebte": "ausgeklebt",
    "ausgeklebtem": "ausgeklebt",
    "ausgeklebten": "ausgeklebt",
    "ausgeklebter": "ausgeklebt",
    "ausgeklebtes": "ausgeklebt",
    "ausgekleidet": "auskleiden",
    "ausgekleidete": "ausgekleidet",
    "ausgekleidetem": "ausgekleidet",
    "ausgekleideten": "ausgekleidet",
    "ausgekleideter": "ausgekleidet",
    "ausgekleidetes": "ausgekleidet",
    "ausgeklinkt": "ausklinken",
    "ausgeklinkte": "ausgeklinkt",
    "ausgeklinktem": "ausgeklinkt",
    "ausgeklinkten": "ausgeklinkt",
    "ausgeklinkter": "ausgeklinkt",
    "ausgeklinktes": "ausgeklinkt",
    "ausgeklopft": "ausklopfen",
    "ausgeklopfte": "ausgeklopft",
    "ausgeklopftem": "ausgeklopft",
    "ausgeklopften": "ausgeklopft",
    "ausgeklopfter": "ausgeklopft",
    "ausgeklopftes": "ausgeklopft",
    "ausgeklungen": "ausklingen",
    "ausgeklungene": "ausgeklungen",
    "ausgeklungenem": "ausgeklungen",
    "ausgeklungenen": "ausgeklungen",
    "ausgeklungener": "ausgeklungen",
    "ausgeklungenes": "ausgeklungen",
    "ausgeklügelt": "ausklügeln",
    "ausgeklügelte": "ausgeklügelt",
    "ausgeklügeltem": "ausgeklügelt",
    "ausgeklügelten": "ausgeklügelt",
    "ausgeklügelter": "ausgeklügelt",
    "ausgeklügeltere": "ausgeklügelt",
    "ausgeklügelterem": "ausgeklügelt",
    "ausgeklügelteren": "ausgeklügelt",
    "ausgeklügelterer": "ausgeklügelt",
    "ausgeklügelteres": "ausgeklügelt",
    "ausgeklügeltes": "ausgeklügelt",
    "ausgeklügelteste": "ausgeklügelt",
    "ausgeklügeltestem": "ausgeklügelt",
    "ausgeklügeltesten": "ausgeklügelt",
    "ausgeklügeltester": "ausgeklügelt",
    "ausgeklügeltestes": "ausgeklügelt",
    "ausgekniffen": "auskneifen",
    "ausgekniffene": "ausgekniffen",
    "ausgekniffenem": "ausgekniffen",
    "ausgekniffenen": "ausgekniffen",
    "ausgekniffener": "ausgekniffen",
    "ausgekniffenere": "ausgekniffen",
    "ausgekniffenerem": "ausgekniffen",
    "ausgekniffeneren": "ausgekniffen",
    "ausgekniffenerer": "ausgekniffen",
    "ausgekniffeneres": "ausgekniffen",
    "ausgekniffenes": "ausgekniffen",
    "ausgekniffenste": "ausgekniffen",
    "ausgekniffenstem": "ausgekniffen",
    "ausgekniffensten": "ausgekniffen",
    "ausgekniffenster": "ausgekniffen",
    "ausgekniffenstes": "ausgekniffen",
    "ausgeknipst": "ausknipsen",
    "ausgeknipste": "ausgeknipst",
    "ausgeknipstem": "ausgeknipst",
    "ausgeknipsten": "ausgeknipst",
    "ausgeknipster": "ausgeknipst",
    "ausgeknipstes": "ausgeknipst",
    "ausgeknobelt": "ausknobeln",
    "ausgeknobelte": "ausgeknobelt",
    "ausgeknobeltem": "ausgeknobelt",
    "ausgeknobelten": "ausgeknobelt",
    "ausgeknobelter": "ausgeknobelt",
    "ausgeknobeltere": "ausgeknobelt",
    "ausgeknobelterem": "ausgeknobelt",
    "ausgeknobelteren": "ausgeknobelt",
    "ausgeknobelterer": "ausgeknobelt",
    "ausgeknobelteres": "ausgeknobelt",
    "ausgeknobeltes": "ausgeknobelt",
    "ausgeknobelteste": "ausgeknobelt",
    "ausgeknobeltestem": "ausgeknobelt",
    "ausgeknobeltesten": "ausgeknobelt",
    "ausgeknobeltester": "ausgeknobelt",
    "ausgeknobeltestes": "ausgeknobelt",
    "ausgekocht": "auskochen",
    "ausgekochte": "ausgekocht",
    "ausgekochtem": "ausgekocht",
    "ausgekochten": "ausgekocht",
    "ausgekochter": "ausgekocht",
    "ausgekochtere": "ausgekocht",
    "ausgekochterem": "ausgekocht",
    "ausgekochteren": "ausgekocht",
    "ausgekochterer": "ausgekocht",
    "ausgekochteres": "ausgekocht",
    "ausgekochtes": "ausgekocht",
    "ausgekochteste": "ausgekocht",
    "ausgekochtestem": "ausgekocht",
    "ausgekochtesten": "ausgekocht",
    "ausgekochtester": "ausgekocht",
    "ausgekochtestes": "ausgekocht",
    "ausgekommen": "auskommen",
    "ausgekommene": "ausgekommen",
    "ausgekommenem": "ausgekommen",
    "ausgekommenen": "ausgekommen",
    "ausgekommener": "ausgekommen",
    "ausgekommenes": "ausgekommen",
    "ausgekostet": "auskosten",
    "ausgekostete": "ausgekostet",
    "ausgekostetem": "ausgekostet",
    "ausgekosteten": "ausgekostet",
    "ausgekosteter": "ausgekostet",
    "ausgekostetere": "ausgekostet",
    "ausgekosteterem": "ausgekostet",
    "ausgekosteteren": "ausgekostet",
    "ausgekosteterer": "ausgekostet",
    "ausgekosteteres": "ausgekostet",
    "ausgekostetes": "ausgekostet",
    "ausgekosteteste": "ausgekostet",
    "ausgekostetestem": "ausgekostet",
    "ausgekostetesten": "ausgekostet",
    "ausgekostetester": "ausgekostet",
    "ausgekostetestes": "ausgekostet",
    "ausgekramt": "auskramen",
    "ausgekramte": "ausgekramt",
    "ausgekramtem": "ausgekramt",
    "ausgekramten": "ausgekramt",
    "ausgekramter": "ausgekramt",
    "ausgekramtes": "ausgekramt",
    "ausgekratzt": "auskratzen",
    "ausgekratzte": "ausgekratzt",
    "ausgekratztem": "ausgekratzt",
    "ausgekratzten": "ausgekratzt",
    "ausgekratzter": "ausgekratzt",
    "ausgekratztere": "ausgekratzt",
    "ausgekratzterem": "ausgekratzt",
    "ausgekratzteren": "ausgekratzt",
    "ausgekratzterer": "ausgekratzt",
    "ausgekratzteres": "ausgekratzt",
    "ausgekratztes": "ausgekratzt",
    "ausgekratzteste": "ausgekratzt",
    "ausgekratztestem": "ausgekratzt",
    "ausgekratztesten": "ausgekratzt",
    "ausgekratztester": "ausgekratzt",
    "ausgekratztestes": "ausgekratzt",
    "ausgekrochen": "auskriechen",
    "ausgekrochene": "ausgekrochen",
    "ausgekrochenem": "ausgekrochen",
    "ausgekrochenen": "ausgekrochen",
    "ausgekrochener": "ausgekrochen",
    "ausgekrochenes": "ausgekrochen",
    "ausgekugelt": "auskugeln",
    "ausgekugelte": "ausgekugelt",
    "ausgekugeltem": "ausgekugelt",
    "ausgekugelten": "ausgekugelt",
    "ausgekugelter": "ausgekugelt",
    "ausgekugeltes": "ausgekugelt",
    "ausgekundschaftet": "auskundschaften",
    "ausgekundschaftete": "ausgekundschaftet",
    "ausgekundschaftetem": "ausgekundschaftet",
    "ausgekundschafteten": "ausgekundschaftet",
    "ausgekundschafteter": "ausgekundschaftet",
    "ausgekundschaftetes": "ausgekundschaftet",
    "ausgekuppelt": "auskuppeln",
    "ausgekuppelte": "ausgekuppelt",
    "ausgekuppeltem": "ausgekuppelt",
    "ausgekuppelten": "ausgekuppelt",
    "ausgekuppelter": "ausgekuppelt",
    "ausgekuppeltes": "ausgekuppelt",
    "ausgekämmt": "auskämmen",
    "ausgekämmte": "ausgekämmt",
    "ausgekämmtem": "ausgekämmt",
    "ausgekämmten": "ausgekämmt",
    "ausgekämmter": "ausgekämmt",
    "ausgekämmtes": "ausgekämmt",
    "ausgekämpft": "auskämpfen",
    "ausgekämpfte": "ausgekämpft",
    "ausgekämpftem": "ausgekämpft",
    "ausgekämpften": "ausgekämpft",
    "ausgekämpfter": "ausgekämpft",
    "ausgekämpftes": "ausgekämpft",
    "ausgekühlt": "auskühlen",
    "ausgekühlte": "ausgekühlt",
    "ausgekühltem": "ausgekühlt",
    "ausgekühlten": "ausgekühlt",
    "ausgekühlter": "ausgekühlt",
    "ausgekühltere": "ausgekühlt",
    "ausgekühlterem": "ausgekühlt",
    "ausgekühlteren": "ausgekühlt",
    "ausgekühlterer": "ausgekühlt",
    "ausgekühlteres": "ausgekühlt",
    "ausgekühltes": "ausgekühlt",
    "ausgekühlteste": "ausgekühlt",
    "ausgekühltestem": "ausgekühlt",
    "ausgekühltesten": "ausgekühlt",
    "ausgekühltester": "ausgekühlt",
    "ausgekühltestes": "ausgekühlt",
    "ausgelacht": "auslachen",
    "ausgelachte": "ausgelacht",
    "ausgelachtem": "ausgelacht",
    "ausgelachten": "ausgelacht",
    "ausgelachter": "ausgelacht",
    "ausgelachtes": "ausgelacht",
    "ausgeladen": "ausladen",
    "ausgeladene": "ausgeladen",
    "ausgeladenem": "ausgeladen",
    "ausgeladenen": "ausgeladen",
    "ausgeladener": "ausgeladen",
    "ausgeladenes": "ausgeladen",
    "ausgelagert": "auslagern",
    "ausgelagerte": "ausgelagert",
    "ausgelagertem": "ausgelagert",
    "ausgelagerten": "ausgelagert",
    "ausgelagerter": "ausgelagert",
    "ausgelagertes": "ausgelagert",
    "ausgelangt": "auslangen",
    "ausgelangte": "ausgelangt",
    "ausgelangtem": "ausgelangt",
    "ausgelangten": "ausgelangt",
    "ausgelangter": "ausgelangt",
    "ausgelangtes": "ausgelangt",
    "ausgelassen": "auslassen",
    "ausgelassene": "ausgelassen",
    "ausgelassenem": "ausgelassen",
    "ausgelassenen": "ausgelassen",
    "ausgelassener": "ausgelassen",
    "ausgelassenere": "ausgelassen",
    "ausgelassenerem": "ausgelassen",
    "ausgelasseneren": "ausgelassen",
    "ausgelassenerer": "ausgelassen",
    "ausgelasseneres": "ausgelassen",
    "ausgelassenes": "ausgelassen",
    "ausgelassenste": "ausgelassen",
    "ausgelassenstem": "ausgelassen",
    "ausgelassensten": "ausgelassen",
    "ausgelassenster": "ausgelassen",
    "ausgelassenstes": "ausgelassen",
    "ausgelastet": "auslasten",
    "ausgelastete": "ausgelastet",
    "ausgelastetem": "ausgelastet",
    "ausgelasteten": "ausgelastet",
    "ausgelasteter": "ausgelastet",
    "ausgelastetere": "ausgelastet",
    "ausgelasteterem": "ausgelastet",
    "ausgelasteteren": "ausgelastet",
    "ausgelasteterer": "ausgelastet",
    "ausgelasteteres": "ausgelastet",
    "ausgelastetes": "ausgelastet",
    "ausgelasteteste": "ausgelastet",
    "ausgelastetestem": "ausgelastet",
    "ausgelastetesten": "ausgelastet",
    "ausgelastetester": "ausgelastet",
    "ausgelastetestes": "ausgelastet",
    "ausgelatscht": "auslatschen",
    "ausgelatschte": "ausgelatscht",
    "ausgelatschtem": "ausgelatscht",
    "ausgelatschten": "ausgelatscht",
    "ausgelatschter": "ausgelatscht",
    "ausgelatschtere": "ausgelatscht",
    "ausgelatschterem": "ausgelatscht",
    "ausgelatschteren": "ausgelatscht",
    "ausgelatschterer": "ausgelatscht",
    "ausgelatschteres": "ausgelatscht",
    "ausgelatschtes": "ausgelatscht",
    "ausgelatschteste": "ausgelatscht",
    "ausgelatschtestem": "ausgelatscht",
    "ausgelatschtesten": "ausgelatscht",
    "ausgelatschtester": "ausgelatscht",
    "ausgelatschtestes": "ausgelatscht",
    "ausgelaufen": "auslaufen",
    "ausgelaufene": "ausgelaufen",
    "ausgelaufenem": "ausgelaufen",
    "ausgelaufenen": "ausgelaufen",
    "ausgelaufener": "ausgelaufen",
    "ausgelaufenere": "ausgelaufen",
    "ausgelaufenerem": "ausgelaufen",
    "ausgelaufeneren": "ausgelaufen",
    "ausgelaufenerer": "ausgelaufen",
    "ausgelaufeneres": "ausgelaufen",
    "ausgelaufenes": "ausgelaufen",
    "ausgelaufenste": "ausgelaufen",
    "ausgelaufenstem": "ausgelaufen",
    "ausgelaufensten": "ausgelaufen",
    "ausgelaufenster": "ausgelaufen",
    "ausgelaufenstes": "ausgelaufen",
    "ausgelaugt": "auslaugen",
    "ausgelaugte": "ausgelaugt",
    "ausgelaugtem": "ausgelaugt",
    "ausgelaugten": "ausgelaugt",
    "ausgelaugter": "ausgelaugt",
    "ausgelaugtere": "ausgelaugt",
    "ausgelaugterem": "ausgelaugt",
    "ausgelaugteren": "ausgelaugt",
    "ausgelaugterer": "ausgelaugt",
    "ausgelaugteres": "ausgelaugt",
    "ausgelaugtes": "ausgelaugt",
    "ausgelaugteste": "ausgelaugt",
    "ausgelaugtestem": "ausgelaugt",
    "ausgelaugtesten": "ausgelaugt",
    "ausgelaugtester": "ausgelaugt",
    "ausgelaugtestes": "ausgelaugt",
    "ausgelautet": "auslauten",
    "ausgelautete": "ausgelautet",
    "ausgelautetem": "ausgelautet",
    "ausgelauteten": "ausgelautet",
    "ausgelauteter": "ausgelautet",
    "ausgelautetes": "ausgelautet",
    "ausgelebt": "ausleben",
    "ausgelebte": "ausgelebt",
    "ausgelebtem": "ausgelebt",
    "ausgelebten": "ausgelebt",
    "ausgelebter": "ausgelebt",
    "ausgelebtes": "ausgelebt",
    "ausgeleert": "ausleeren",
    "ausgeleerte": "ausgeleert",
    "ausgeleertem": "ausgeleert",
    "ausgeleerten": "ausgeleert",
    "ausgeleerter": "ausgeleert",
    "ausgeleertes": "ausgeleert",
    "ausgelegt": "auslegen",
    "ausgelegte": "ausgelegt",
    "ausgelegtem": "ausgelegt",
    "ausgelegten": "ausgelegt",
    "ausgelegter": "ausgelegt",
    "ausgelegtes": "ausgelegt",
    "ausgeleiert": "ausleiern",
    "ausgeleierte": "ausgeleiert",
    "ausgeleiertem": "ausgeleiert",
    "ausgeleierten": "ausgeleiert",
    "ausgeleierter": "ausgeleiert",
    "ausgeleiertere": "ausgeleiert",
    "ausgeleierterem": "ausgeleiert",
    "ausgeleierteren": "ausgeleiert",
    "ausgeleierterer": "ausgeleiert",
    "ausgeleierteres": "ausgeleiert",
    "ausgeleiertes": "ausgeleiert",
    "ausgeleierteste": "ausgeleiert",
    "ausgeleiertestem": "ausgeleiert",
    "ausgeleiertesten": "ausgeleiert",
    "ausgeleiertester": "ausgeleiert",
    "ausgeleiertestes": "ausgeleiert",
    "ausgelernt": "auslernen",
    "ausgelernte": "ausgelernt",
    "ausgelerntem": "ausgelernt",
    "ausgelernten": "ausgelernt",
    "ausgelernter": "ausgelernt",
    "ausgelerntes": "ausgelernt",
    "ausgelesen": "auslesen",
    "ausgelesene": "ausgelesen",
    "ausgelesenem": "ausgelesen",
    "ausgelesenen": "ausgelesen",
    "ausgelesener": "ausgelesen",
    "ausgelesenes": "ausgelesen",
    "ausgeleuchtet": "ausleuchten",
    "ausgeleuchtete": "ausgeleuchtet",
    "ausgeleuchtetem": "ausgeleuchtet",
    "ausgeleuchteten": "ausgeleuchtet",
    "ausgeleuchteter": "ausgeleuchtet",
    "ausgeleuchtetere": "ausgeleuchtet",
    "ausgeleuchteterem": "ausgeleuchtet",
    "ausgeleuchteteren": "ausgeleuchtet",
    "ausgeleuchteterer": "ausgeleuchtet",
    "ausgeleuchteteres": "ausgeleuchtet",
    "ausgeleuchtetes": "ausgeleuchtet",
    "ausgeleuchteteste": "ausgeleuchtet",
    "ausgeleuchtetestem": "ausgeleuchtet",
    "ausgeleuchtetesten": "ausgeleuchtet",
    "ausgeleuchtetester": "ausgeleuchtet",
    "ausgeleuchtetestes": "ausgeleuchtet",
    "ausgelichtet": "auslichten",
    "ausgelichtete": "ausgelichtet",
    "ausgelichtetem": "ausgelichtet",
    "ausgelichteten": "ausgelichtet",
    "ausgelichteter": "ausgelichtet",
    "ausgelichtetes": "ausgelichtet",
    "ausgeliefert": "ausliefern",
    "ausgelieferte": "ausgeliefert",
    "ausgeliefertem": "ausgeliefert",
    "ausgelieferten": "ausgeliefert",
    "ausgelieferter": "ausgeliefert",
    "ausgeliefertes": "ausgeliefert",
    "ausgeliehen": "ausleihen",
    "ausgeliehene": "ausgeliehen",
    "ausgeliehenem": "ausgeliehen",
    "ausgeliehenen": "ausgeliehen",
    "ausgeliehener": "ausgeliehen",
    "ausgeliehenes": "ausgeliehen",
    "ausgelitten": "ausleiden",
    "ausgelittene": "ausgelitten",
    "ausgelittenem": "ausgelitten",
    "ausgelittenen": "ausgelitten",
    "ausgelittener": "ausgelitten",
    "ausgelittenere": "ausgelitten",
    "ausgelittenerem": "ausgelitten",
    "ausgelitteneren": "ausgelitten",
    "ausgelittenerer": "ausgelitten",
    "ausgelitteneres": "ausgelitten",
    "ausgelittenes": "ausgelitten",
    "ausgelittenste": "ausgelitten",
    "ausgelittenstem": "ausgelitten",
    "ausgelittensten": "ausgelitten",
    "ausgelittenster": "ausgelitten",
    "ausgelittenstes": "ausgelitten",
    "ausgeloschen": "auslöschen",
    "ausgeloschene": "ausgeloschen",
    "ausgeloschenem": "ausgeloschen",
    "ausgeloschenen": "ausgeloschen",
    "ausgeloschener": "ausgeloschen",
    "ausgeloschenes": "ausgeloschen",
    "ausgelost": "auslosen",
    "ausgeloste": "ausgelost",
    "ausgelostem": "ausgelost",
    "ausgelosten": "ausgelost",
    "ausgeloster": "ausgelost",
    "ausgelostes": "ausgelost",
    "ausgelotet": "ausloten",
    "ausgelotete": "ausgelotet",
    "ausgelotetem": "ausgelotet",
    "ausgeloteten": "ausgelotet",
    "ausgeloteter": "ausgelotet",
    "ausgelotetes": "ausgelotet",
    "ausgeläutet": "ausläuten",
    "ausgeläutetem": "ausgeläutet",
    "ausgeläuteter": "ausgeläutet",
    "ausgeläutetes": "ausgeläutet",
    "ausgelöffelt": "auslöffeln",
    "ausgelöffelte": "ausgelöffelt",
    "ausgelöffeltem": "ausgelöffelt",
    "ausgelöffelten": "ausgelöffelt",
    "ausgelöffelter": "ausgelöffelt",
    "ausgelöffeltes": "ausgelöffelt",
    "ausgelöscht": "auslöschen",
    "ausgelöschte": "ausgelöscht",
    "ausgelöschtem": "ausgelöscht",
    "ausgelöschten": "ausgelöscht",
    "ausgelöschter": "ausgelöscht",
    "ausgelöschtes": "ausgelöscht",
    "ausgelöst": "auslösen",
    "ausgelöstem": "ausgelöst",
    "ausgelöster": "ausgelöst",
    "ausgelöstes": "ausgelöst",
    "ausgelüftet": "auslüften",
    "ausgelüftete": "ausgelüftet",
    "ausgelüftetem": "ausgelüftet",
    "ausgelüfteten": "ausgelüftet",
    "ausgelüfteter": "ausgelüftet",
    "ausgelüftetere": "ausgelüftet",
    "ausgelüfteterem": "ausgelüftet",
    "ausgelüfteteren": "ausgelüftet",
    "ausgelüfteterer": "ausgelüftet",
    "ausgelüfteteres": "ausgelüftet",
    "ausgelüftetes": "ausgelüftet",
    "ausgelüfteteste": "ausgelüftet",
    "ausgelüftetestem": "ausgelüftet",
    "ausgelüftetesten": "ausgelüftet",
    "ausgelüftetester": "ausgelüftet",
    "ausgelüftetestes": "ausgelüftet",
    "ausgemacht": "ausmachen",
    "ausgemachte": "ausgemacht",
    "ausgemachtem": "ausgemacht",
    "ausgemachten": "ausgemacht",
    "ausgemachter": "ausgemacht",
    "ausgemachtes": "ausgemacht",
    "ausgemahlen": "ausmahlen",
    "ausgemahlene": "ausgemahlen",
    "ausgemahlenem": "ausgemahlen",
    "ausgemahlenen": "ausgemahlen",
    "ausgemahlener": "ausgemahlen",
    "ausgemahlenere": "ausgemahlen",
    "ausgemahlenerem": "ausgemahlen",
    "ausgemahleneren": "ausgemahlen",
    "ausgemahlenerer": "ausgemahlen",
    "ausgemahleneres": "ausgemahlen",
    "ausgemahlenes": "ausgemahlen",
    "ausgemahlenste": "ausgemahlen",
    "ausgemahlenstem": "ausgemahlen",
    "ausgemahlensten": "ausgemahlen",
    "ausgemahlenster": "ausgemahlen",
    "ausgemahlenstes": "ausgemahlen",
    "ausgemalt": "ausmalen",
    "ausgemalte": "ausgemalt",
    "ausgemaltem": "ausgemalt",
    "ausgemalten": "ausgemalt",
    "ausgemalter": "ausgemalt",
    "ausgemaltere": "ausgemalt",
    "ausgemalterem": "ausgemalt",
    "ausgemalteren": "ausgemalt",
    "ausgemalterer": "ausgemalt",
    "ausgemalteres": "ausgemalt",
    "ausgemaltes": "ausgemalt",
    "ausgemalteste": "ausgemalt",
    "ausgemaltestem": "ausgemalt",
    "ausgemaltesten": "ausgemalt",
    "ausgemaltester": "ausgemalt",
    "ausgemaltestes": "ausgemalt",
    "ausgemeißelt": "ausmeißeln",
    "ausgemeißelte": "ausgemeißelt",
    "ausgemeißeltem": "ausgemeißelt",
    "ausgemeißelten": "ausgemeißelt",
    "ausgemeißelter": "ausgemeißelt",
    "ausgemeißeltes": "ausgemeißelt",
    "ausgemelkt": "ausmelken",
    "ausgemelkte": "ausgemelkt",
    "ausgemelktem": "ausgemelkt",
    "ausgemelkten": "ausgemelkt",
    "ausgemelkter": "ausgemelkt",
    "ausgemelktes": "ausgemelkt",
    "ausgemerzt": "ausmerzen",
    "ausgemerzte": "ausgemerzt",
    "ausgemerztem": "ausgemerzt",
    "ausgemerzten": "ausgemerzt",
    "ausgemerzter": "ausgemerzt",
    "ausgemerztere": "ausgemerzt",
    "ausgemerzterem": "ausgemerzt",
    "ausgemerzteren": "ausgemerzt",
    "ausgemerzterer": "ausgemerzt",
    "ausgemerzteres": "ausgemerzt",
    "ausgemerztes": "ausgemerzt",
    "ausgemerzteste": "ausgemerzt",
    "ausgemerztestem": "ausgemerzt",
    "ausgemerztesten": "ausgemerzt",
    "ausgemerztester": "ausgemerzt",
    "ausgemerztestes": "ausgemerzt",
    "ausgemessen": "ausmessen",
    "ausgemessene": "ausgemessen",
    "ausgemessenem": "ausgemessen",
    "ausgemessenen": "ausgemessen",
    "ausgemessener": "ausgemessen",
    "ausgemessenes": "ausgemessen",
    "ausgemistet": "ausmisten",
    "ausgemistete": "ausgemistet",
    "ausgemistetem": "ausgemistet",
    "ausgemisteten": "ausgemistet",
    "ausgemisteter": "ausgemistet",
    "ausgemistetes": "ausgemistet",
    "ausgemolken": "ausmelken",
    "ausgemolkene": "ausgemolken",
    "ausgemolkenem": "ausgemolken",
    "ausgemolkenen": "ausgemolken",
    "ausgemolkener": "ausgemolken",
    "ausgemolkenes": "ausgemolken",
    "ausgemustert": "ausmustern",
    "ausgemusterte": "ausgemustert",
    "ausgemustertem": "ausgemustert",
    "ausgemusterten": "ausgemustert",
    "ausgemusterter": "ausgemustert",
    "ausgemustertes": "ausgemustert",
    "ausgemündet": "ausmünden",
    "ausgemündete": "ausgemündet",
    "ausgemündetem": "ausgemündet",
    "ausgemündeten": "ausgemündet",
    "ausgemündeter": "ausgemündet",
    "ausgemündetes": "ausgemündet",
    "ausgenommen": "ausnehmen",
    "ausgenommene": "ausgenommen",
    "ausgenommenem": "ausgenommen",
    "ausgenommenen": "ausgenommen",
    "ausgenommener": "ausgenommen",
    "ausgenommenere": "ausgenommen",
    "ausgenommenerem": "ausgenommen",
    "ausgenommeneren": "ausgenommen",
    "ausgenommenerer": "ausgenommen",
    "ausgenommeneres": "ausgenommen",
    "ausgenommenes": "ausgenommen",
    "ausgenommenste": "ausgenommen",
    "ausgenommenstem": "ausgenommen",
    "ausgenommensten": "ausgenommen",
    "ausgenommenster": "ausgenommen",
    "ausgenommenstes": "ausgenommen",
    "ausgenutzt": "ausnutzen",
    "ausgenutzte": "ausgenutzt",
    "ausgenutztem": "ausgenutzt",
    "ausgenutzten": "ausgenutzt",
    "ausgenutzter": "ausgenutzt",
    "ausgenutztere": "ausgenutzt",
    "ausgenutzterem": "ausgenutzt",
    "ausgenutzteren": "ausgenutzt",
    "ausgenutzterer": "ausgenutzt",
    "ausgenutzteres": "ausgenutzt",
    "ausgenutztes": "ausgenutzt",
    "ausgenutzteste": "ausgenutzt",
    "ausgenutztestem": "ausgenutzt",
    "ausgenutztesten": "ausgenutzt",
    "ausgenutztester": "ausgenutzt",
    "ausgenutztestes": "ausgenutzt",
    "ausgepackt": "auspacken",
    "ausgepackte": "ausgepackt",
    "ausgepacktem": "ausgepackt",
    "ausgepackten": "ausgepackt",
    "ausgepackter": "ausgepackt",
    "ausgepacktes": "ausgepackt",
    "ausgeparkt": "ausparken",
    "ausgeparkte": "ausgeparkt",
    "ausgeparktem": "ausgeparkt",
    "ausgeparkten": "ausgeparkt",
    "ausgeparkter": "ausgeparkt",
    "ausgeparktes": "ausgeparkt",
    "ausgepeitscht": "auspeitschen",
    "ausgepeitschte": "ausgepeitscht",
    "ausgepeitschtem": "ausgepeitscht",
    "ausgepeitschten": "ausgepeitscht",
    "ausgepeitschter": "ausgepeitscht",
    "ausgepeitschtere": "ausgepeitscht",
    "ausgepeitschterem": "ausgepeitscht",
    "ausgepeitschteren": "ausgepeitscht",
    "ausgepeitschterer": "ausgepeitscht",
    "ausgepeitschteres": "ausgepeitscht",
    "ausgepeitschtes": "ausgepeitscht",
    "ausgepeitschteste": "ausgepeitscht",
    "ausgepeitschtestem": "ausgepeitscht",
    "ausgepeitschtesten": "ausgepeitscht",
    "ausgepeitschtester": "ausgepeitscht",
    "ausgepeitschtestes": "ausgepeitscht",
    "ausgependelt": "auspendeln",
    "ausgependelte": "ausgependelt",
    "ausgependeltem": "ausgependelt",
    "ausgependelten": "ausgependelt",
    "ausgependelter": "ausgependelt",
    "ausgependeltere": "ausgependelt",
    "ausgependelterem": "ausgependelt",
    "ausgependelteren": "ausgependelt",
    "ausgependelterer": "ausgependelt",
    "ausgependelteres": "ausgependelt",
    "ausgependeltes": "ausgependelt",
    "ausgependelteste": "ausgependelt",
    "ausgependeltestem": "ausgependelt",
    "ausgependeltesten": "ausgependelt",
    "ausgependeltester": "ausgependelt",
    "ausgependeltestes": "ausgependelt",
    "ausgepfiffen": "auspfeifen",
    "ausgepfiffene": "ausgepfiffen",
    "ausgepfiffenem": "ausgepfiffen",
    "ausgepfiffenen": "ausgepfiffen",
    "ausgepfiffener": "ausgepfiffen",
    "ausgepfiffenere": "ausgepfiffen",
    "ausgepfiffenerem": "ausgepfiffen",
    "ausgepfiffeneren": "ausgepfiffen",
    "ausgepfiffenerer": "ausgepfiffen",
    "ausgepfiffeneres": "ausgepfiffen",
    "ausgepfiffenes": "ausgepfiffen",
    "ausgepfiffenste": "ausgepfiffen",
    "ausgepfiffenstem": "ausgepfiffen",
    "ausgepfiffensten": "ausgepfiffen",
    "ausgepfiffenster": "ausgepfiffen",
    "ausgepfiffenstes": "ausgepfiffen",
    "ausgepflanzt": "auspflanzen",
    "ausgepflanzte": "ausgepflanzt",
    "ausgepflanztem": "ausgepflanzt",
    "ausgepflanzten": "ausgepflanzt",
    "ausgepflanzter": "ausgepflanzt",
    "ausgepflanztes": "ausgepflanzt",
    "ausgeplappert": "ausplappern",
    "ausgeplapperte": "ausgeplappert",
    "ausgeplappertem": "ausgeplappert",
    "ausgeplapperten": "ausgeplappert",
    "ausgeplapperter": "ausgeplappert",
    "ausgeplappertes": "ausgeplappert",
    "ausgeplaudert": "ausplaudern",
    "ausgeplauderte": "ausgeplaudert",
    "ausgeplaudertem": "ausgeplaudert",
    "ausgeplauderten": "ausgeplaudert",
    "ausgeplauderter": "ausgeplaudert",
    "ausgeplaudertes": "ausgeplaudert",
    "ausgeplündert": "ausplündern",
    "ausgeplünderte": "ausgeplündert",
    "ausgeplündertem": "ausgeplündert",
    "ausgeplünderten": "ausgeplündert",
    "ausgeplünderter": "ausgeplündert",
    "ausgeplündertere": "ausgeplündert",
    "ausgeplünderterem": "ausgeplündert",
    "ausgeplünderteren": "ausgeplündert",
    "ausgeplünderterer": "ausgeplündert",
    "ausgeplünderteres": "ausgeplündert",
    "ausgeplündertes": "ausgeplündert",
    "ausgeplünderteste": "ausgeplündert",
    "ausgeplündertestem": "ausgeplündert",
    "ausgeplündertesten": "ausgeplündert",
    "ausgeplündertester": "ausgeplündert",
    "ausgeplündertestes": "ausgeplündert",
    "ausgepolstert": "auspolstern",
    "ausgepolsterte": "ausgepolstert",
    "ausgepolstertem": "ausgepolstert",
    "ausgepolsterten": "ausgepolstert",
    "ausgepolsterter": "ausgepolstert",
    "ausgepolstertere": "ausgepolstert",
    "ausgepolsterterem": "ausgepolstert",
    "ausgepolsterteren": "ausgepolstert",
    "ausgepolsterterer": "ausgepolstert",
    "ausgepolsterteres": "ausgepolstert",
    "ausgepolstertes": "ausgepolstert",
    "ausgepolsterteste": "ausgepolstert",
    "ausgepolstertestem": "ausgepolstert",
    "ausgepolstertesten": "ausgepolstert",
    "ausgepolstertester": "ausgepolstert",
    "ausgepolstertestes": "ausgepolstert",
    "ausgepowert": "auspowern",
    "ausgepowerte": "ausgepowert",
    "ausgepowertem": "ausgepowert",
    "ausgepowerten": "ausgepowert",
    "ausgepowerter": "ausgepowert",
    "ausgepowertere": "ausgepowert",
    "ausgepowerterem": "ausgepowert",
    "ausgepowerteren": "ausgepowert",
    "ausgepowerterer": "ausgepowert",
    "ausgepowerteres": "ausgepowert",
    "ausgepowertes": "ausgepowert",
    "ausgepowerteste": "ausgepowert",
    "ausgepowertestem": "ausgepowert",
    "ausgepowertesten": "ausgepowert",
    "ausgepowertester": "ausgepowert",
    "ausgepowertestes": "ausgepowert",
    "ausgepreßt": "auspressen",
    "ausgepreßte": "ausgepreßt",
    "ausgepreßtem": "ausgepreßt",
    "ausgepreßten": "ausgepreßt",
    "ausgepreßter": "ausgepreßt",
    "ausgepreßtere": "ausgepreßt",
    "ausgepreßterem": "ausgepreßt",
    "ausgepreßteren": "ausgepreßt",
    "ausgepreßterer": "ausgepreßt",
    "ausgepreßteres": "ausgepreßt",
    "ausgepreßtes": "ausgepreßt",
    "ausgepreßteste": "ausgepreßt",
    "ausgepreßtestem": "ausgepreßt",
    "ausgepreßtesten": "ausgepreßt",
    "ausgepreßtester": "ausgepreßt",
    "ausgepreßtestes": "ausgepreßt",
    "ausgeprägt": "ausprägen",
    "ausgeprägte": "ausgeprägt",
    "ausgeprägtem": "ausgeprägt",
    "ausgeprägten": "ausgeprägt",
    "ausgeprägter": "ausgeprägt",
    "ausgeprägtere": "ausgeprägt",
    "ausgeprägterem": "ausgeprägt",
    "ausgeprägteren": "ausgeprägt",
    "ausgeprägterer": "ausgeprägt",
    "ausgeprägteres": "ausgeprägt",
    "ausgeprägtes": "ausgeprägt",
    "ausgeprägteste": "ausgeprägt",
    "ausgeprägtestem": "ausgeprägt",
    "ausgeprägtesten": "ausgeprägt",
    "ausgeprägtester": "ausgeprägt",
    "ausgeprägtestes": "ausgeprägt",
    "ausgepumpt": "auspumpen",
    "ausgepumpte": "ausgepumpt",
    "ausgepumptem": "ausgepumpt",
    "ausgepumpten": "ausgepumpt",
    "ausgepumpter": "ausgepumpt",
    "ausgepumptere": "ausgepumpt",
    "ausgepumpterem": "ausgepumpt",
    "ausgepumpteren": "ausgepumpt",
    "ausgepumpterer": "ausgepumpt",
    "ausgepumpteres": "ausgepumpt",
    "ausgepumptes": "ausgepumpt",
    "ausgepumpteste": "ausgepumpt",
    "ausgepumptestem": "ausgepumpt",
    "ausgepumptesten": "ausgepumpt",
    "ausgepumptester": "ausgepumpt",
    "ausgepumptestes": "ausgepumpt",
    "ausgepustet": "auspusten",
    "ausgepustete": "ausgepustet",
    "ausgepustetem": "ausgepustet",
    "ausgepusteten": "ausgepustet",
    "ausgepusteter": "ausgepustet",
    "ausgepustetes": "ausgepustet",
    "ausgeputzt": "ausputzen",
    "ausgeputzte": "ausgeputzt",
    "ausgeputztem": "ausgeputzt",
    "ausgeputzten": "ausgeputzt",
    "ausgeputzter": "ausgeputzt",
    "ausgeputztes": "ausgeputzt",
    "ausgequatscht": "ausquatschen",
    "ausgequatschte": "ausgequatscht",
    "ausgequatschtem": "ausgequatscht",
    "ausgequatschten": "ausgequatscht",
    "ausgequatschter": "ausgequatscht",
    "ausgequatschtere": "ausgequatscht",
    "ausgequatschterem": "ausgequatscht",
    "ausgequatschteren": "ausgequatscht",
    "ausgequatschterer": "ausgequatscht",
    "ausgequatschteres": "ausgequatscht",
    "ausgequatschtes": "ausgequatscht",
    "ausgequatschteste": "ausgequatscht",
    "ausgequatschtestem": "ausgequatscht",
    "ausgequatschtesten": "ausgequatscht",
    "ausgequatschtester": "ausgequatscht",
    "ausgequatschtestes": "ausgequatscht",
    "ausgequetscht": "ausquetschen",
    "ausgequetschte": "ausgequetscht",
    "ausgequetschtem": "ausgequetscht",
    "ausgequetschten": "ausgequetscht",
    "ausgequetschter": "ausgequetscht",
    "ausgequetschtere": "ausgequetscht",
    "ausgequetschterem": "ausgequetscht",
    "ausgequetschteren": "ausgequetscht",
    "ausgequetschterer": "ausgequetscht",
    "ausgequetschteres": "ausgequetscht",
    "ausgequetschtes": "ausgequetscht",
    "ausgequetschteste": "ausgequetscht",
    "ausgequetschtestem": "ausgequetscht",
    "ausgequetschtesten": "ausgequetscht",
    "ausgequetschtester": "ausgequetscht",
    "ausgequetschtestes": "ausgequetscht",
    "ausgerastet": "ausrasten",
    "ausgerastete": "ausgerastet",
    "ausgerastetem": "ausgerastet",
    "ausgerasteten": "ausgerastet",
    "ausgerasteter": "ausgerastet",
    "ausgerastetere": "ausgerastet",
    "ausgerasteterem": "ausgerastet",
    "ausgerasteteren": "ausgerastet",
    "ausgerasteterer": "ausgerastet",
    "ausgerasteteres": "ausgerastet",
    "ausgerastetes": "ausgerastet",
    "ausgerasteteste": "ausgerastet",
    "ausgerastetestem": "ausgerastet",
    "ausgerastetesten": "ausgerastet",
    "ausgerastetester": "ausgerastet",
    "ausgerastetestes": "ausgerastet",
    "ausgeraubt": "ausrauben",
    "ausgeraubte": "ausgeraubt",
    "ausgeraubtem": "ausgeraubt",
    "ausgeraubten": "ausgeraubt",
    "ausgeraubter": "ausgeraubt",
    "ausgeraubtes": "ausgeraubt",
    "ausgeraucht": "ausrauchen",
    "ausgerauchte": "ausgeraucht",
    "ausgerauchtem": "ausgeraucht",
    "ausgerauchten": "ausgeraucht",
    "ausgerauchter": "ausgeraucht",
    "ausgerauchtes": "ausgeraucht",
    "ausgerechnet": "ausrechnen",
    "ausgerechnete": "ausgerechnet",
    "ausgerechnetem": "ausgerechnet",
    "ausgerechneten": "ausgerechnet",
    "ausgerechneter": "ausgerechnet",
    "ausgerechnetes": "ausgerechnet",
    "ausgeredet": "ausreden",
    "ausgeredete": "ausgeredet",
    "ausgeredetem": "ausgeredet",
    "ausgeredeten": "ausgeredet",
    "ausgeredeter": "ausgeredet",
    "ausgeredetes": "ausgeredet",
    "ausgeregnet": "ausregnen",
    "ausgeregnete": "ausgeregnet",
    "ausgeregnetem": "ausgeregnet",
    "ausgeregneten": "ausgeregnet",
    "ausgeregneter": "ausgeregnet",
    "ausgeregnetes": "ausgeregnet",
    "ausgereicht": "ausreichen",
    "ausgereichte": "ausgereicht",
    "ausgereichtem": "ausgereicht",
    "ausgereichten": "ausgereicht",
    "ausgereichter": "ausgereicht",
    "ausgereichtes": "ausgereicht",
    "ausgereift": "ausreifen",
    "ausgereifte": "ausgereift",
    "ausgereiftem": "ausgereift",
    "ausgereiften": "ausgereift",
    "ausgereifter": "ausgereift",
    "ausgereiftere": "ausgereift",
    "ausgereifterem": "ausgereift",
    "ausgereifteren": "ausgereift",
    "ausgereifterer": "ausgereift",
    "ausgereifteres": "ausgereift",
    "ausgereiftes": "ausgereift",
    "ausgereifteste": "ausgereift",
    "ausgereiftestem": "ausgereift",
    "ausgereiftesten": "ausgereift",
    "ausgereiftester": "ausgereift",
    "ausgereiftestes": "ausgereift",
    "ausgereist": "ausreisen",
    "ausgereiste": "ausgereist",
    "ausgereistem": "ausgereist",
    "ausgereisten": "ausgereist",
    "ausgereister": "ausgereist",
    "ausgereistes": "ausgereist",
    "ausgereizt": "ausreizen",
    "ausgereizte": "ausgereizt",
    "ausgereiztem": "ausgereizt",
    "ausgereizten": "ausgereizt",
    "ausgereizter": "ausgereizt",
    "ausgereiztere": "ausgereizt",
    "ausgereizterem": "ausgereizt",
    "ausgereizteren": "ausgereizt",
    "ausgereizterer": "ausgereizt",
    "ausgereizteres": "ausgereizt",
    "ausgereiztes": "ausgereizt",
    "ausgereizteste": "ausgereizt",
    "ausgereiztestem": "ausgereizt",
    "ausgereiztesten": "ausgereizt",
    "ausgereiztester": "ausgereizt",
    "ausgereiztestes": "ausgereizt",
    "ausgerenkt": "ausrenken",
    "ausgerenkte": "ausgerenkt",
    "ausgerenktem": "ausgerenkt",
    "ausgerenkten": "ausgerenkt",
    "ausgerenkter": "ausgerenkt",
    "ausgerenktes": "ausgerenkt",
    "ausgerichtet": "ausrichten",
    "ausgerichtete": "ausgerichtet",
    "ausgerichtetem": "ausgerichtet",
    "ausgerichteten": "ausgerichtet",
    "ausgerichteter": "ausgerichtet",
    "ausgerichtetes": "ausgerichtet",
    "ausgerieben": "ausreiben",
    "ausgeriebene": "ausgerieben",
    "ausgeriebenem": "ausgerieben",
    "ausgeriebenen": "ausgerieben",
    "ausgeriebener": "ausgerieben",
    "ausgeriebenes": "ausgerieben",
    "ausgerissen": "ausreißen",
    "ausgerissene": "ausgerissen",
    "ausgerissenem": "ausgerissen",
    "ausgerissenen": "ausgerissen",
    "ausgerissener": "ausgerissen",
    "ausgerissenere": "ausgerissen",
    "ausgerissenerem": "ausgerissen",
    "ausgerisseneren": "ausgerissen",
    "ausgerissenerer": "ausgerissen",
    "ausgerisseneres": "ausgerissen",
    "ausgerissenes": "ausgerissen",
    "ausgerissenste": "ausgerissen",
    "ausgerissenstem": "ausgerissen",
    "ausgerissensten": "ausgerissen",
    "ausgerissenster": "ausgerissen",
    "ausgerissenstes": "ausgerissen",
    "ausgeritten": "ausreiten",
    "ausgerittene": "ausgeritten",
    "ausgerittenem": "ausgeritten",
    "ausgerittenen": "ausgeritten",
    "ausgerittener": "ausgeritten",
    "ausgerittenes": "ausgeritten",
    "ausgerodet": "ausroden",
    "ausgerodete": "ausgerodet",
    "ausgerodetem": "ausgerodet",
    "ausgerodeten": "ausgerodet",
    "ausgerodeter": "ausgerodet",
    "ausgerodetere": "ausgerodet",
    "ausgerodeterem": "ausgerodet",
    "ausgerodeteren": "ausgerodet",
    "ausgerodeterer": "ausgerodet",
    "ausgerodeteres": "ausgerodet",
    "ausgerodetes": "ausgerodet",
    "ausgerodeteste": "ausgerodet",
    "ausgerodetestem": "ausgerodet",
    "ausgerodetesten": "ausgerodet",
    "ausgerodetester": "ausgerodet",
    "ausgerodetestes": "ausgerodet",
    "ausgerollt": "ausrollen",
    "ausgerollte": "ausgerollt",
    "ausgerolltem": "ausgerollt",
    "ausgerollten": "ausgerollt",
    "ausgerollter": "ausgerollt",
    "ausgerolltere": "ausgerollt",
    "ausgerollterem": "ausgerollt",
    "ausgerollteren": "ausgerollt",
    "ausgerollterer": "ausgerollt",
    "ausgerollteres": "ausgerollt",
    "ausgerolltes": "ausgerollt",
    "ausgerollteste": "ausgerollt",
    "ausgerolltestem": "ausgerollt",
    "ausgerolltesten": "ausgerollt",
    "ausgerolltester": "ausgerollt",
    "ausgerolltestes": "ausgerollt",
    "ausgerottet": "ausrotten",
    "ausgerottete": "ausgerottet",
    "ausgerottetem": "ausgerottet",
    "ausgerotteten": "ausgerottet",
    "ausgerotteter": "ausgerottet",
    "ausgerottetes": "ausgerottet",
    "ausgerufen": "ausrufen",
    "ausgerufene": "ausgerufen",
    "ausgerufenem": "ausgerufen",
    "ausgerufenen": "ausgerufen",
    "ausgerufener": "ausgerufen",
    "ausgerufenes": "ausgerufen",
    "ausgeruht": "ausruhen",
    "ausgeruhte": "ausgeruht",
    "ausgeruhtem": "ausgeruht",
    "ausgeruhten": "ausgeruht",
    "ausgeruhter": "ausgeruht",
    "ausgeruhtere": "ausgeruht",
    "ausgeruhterem": "ausgeruht",
    "ausgeruhteren": "ausgeruht",
    "ausgeruhterer": "ausgeruht",
    "ausgeruhteres": "ausgeruht",
    "ausgeruhtes": "ausgeruht",
    "ausgeruhteste": "ausgeruht",
    "ausgeruhtestem": "ausgeruht",
    "ausgeruhtesten": "ausgeruht",
    "ausgeruhtester": "ausgeruht",
    "ausgeruhtestes": "ausgeruht",
    "ausgerupft": "ausrupfen",
    "ausgerupfte": "ausgerupft",
    "ausgerupftem": "ausgerupft",
    "ausgerupften": "ausgerupft",
    "ausgerupfter": "ausgerupft",
    "ausgerupftere": "ausgerupft",
    "ausgerupfterem": "ausgerupft",
    "ausgerupfteren": "ausgerupft",
    "ausgerupfterer": "ausgerupft",
    "ausgerupfteres": "ausgerupft",
    "ausgerupftes": "ausgerupft",
    "ausgerupfteste": "ausgerupft",
    "ausgerupftestem": "ausgerupft",
    "ausgerupftesten": "ausgerupft",
    "ausgerupftester": "ausgerupft",
    "ausgerupftestes": "ausgerupft",
    "ausgerutscht": "ausrutschen",
    "ausgerutschte": "ausgerutscht",
    "ausgerutschtem": "ausgerutscht",
    "ausgerutschten": "ausgerutscht",
    "ausgerutschter": "ausgerutscht",
    "ausgerutschtes": "ausgerutscht",
    "ausgeräuchert": "ausräuchern",
    "ausgeräucherte": "ausgeräuchert",
    "ausgeräuchertem": "ausgeräuchert",
    "ausgeräucherten": "ausgeräuchert",
    "ausgeräucherter": "ausgeräuchert",
    "ausgeräuchertere": "ausgeräuchert",
    "ausgeräucherterem": "ausgeräuchert",
    "ausgeräucherteren": "ausgeräuchert",
    "ausgeräucherterer": "ausgeräuchert",
    "ausgeräucherteres": "ausgeräuchert",
    "ausgeräuchertes": "ausgeräuchert",
    "ausgeräucherteste": "ausgeräuchert",
    "ausgeräuchertestem": "ausgeräuchert",
    "ausgeräuchertesten": "ausgeräuchert",
    "ausgeräuchertester": "ausgeräuchert",
    "ausgeräuchertestes": "ausgeräuchert",
    "ausgeräumt": "ausräumen",
    "ausgeräumte": "ausgeräumt",
    "ausgeräumtem": "ausgeräumt",
    "ausgeräumten": "ausgeräumt",
    "ausgeräumter": "ausgeräumt",
    "ausgeräumtes": "ausgeräumt",
    "ausgerückt": "ausrücken",
    "ausgerückte": "ausgerückt",
    "ausgerücktem": "ausgerückt",
    "ausgerückten": "ausgerückt",
    "ausgerückter": "ausgerückt",
    "ausgerücktes": "ausgerückt",
    "ausgerüstet": "ausrüsten",
    "ausgerüstete": "ausgerüstet",
    "ausgerüstetem": "ausgerüstet",
    "ausgerüsteten": "ausgerüstet",
    "ausgerüsteter": "ausgerüstet",
    "ausgerüstetes": "ausgerüstet",
    "ausgesagt": "aussagen",
    "ausgesagte": "ausgesagt",
    "ausgesagtem": "ausgesagt",
    "ausgesagten": "ausgesagt",
    "ausgesagter": "ausgesagt",
    "ausgesagtes": "ausgesagt",
    "ausgesalzen": "aussalzen",
    "ausgesalzene": "ausgesalzen",
    "ausgesalzenem": "ausgesalzen",
    "ausgesalzenen": "ausgesalzen",
    "ausgesalzener": "ausgesalzen",
    "ausgesalzenere": "ausgesalzen",
    "ausgesalzenerem": "ausgesalzen",
    "ausgesalzeneren": "ausgesalzen",
    "ausgesalzenerer": "ausgesalzen",
    "ausgesalzeneres": "ausgesalzen",
    "ausgesalzenes": "ausgesalzen",
    "ausgesalzenste": "ausgesalzen",
    "ausgesalzenstem": "ausgesalzen",
    "ausgesalzensten": "ausgesalzen",
    "ausgesalzenster": "ausgesalzen",
    "ausgesalzenstes": "ausgesalzen",
    "ausgesandt": "aussenden",
    "ausgesandte": "ausgesandt",
    "ausgesandtem": "ausgesandt",
    "ausgesandten": "ausgesandt",
    "ausgesandter": "ausgesandt",
    "ausgesandtes": "ausgesandt",
    "ausgesaugt": "aussaugen",
    "ausgesaugte": "ausgesaugt",
    "ausgesaugtem": "ausgesaugt",
    "ausgesaugten": "ausgesaugt",
    "ausgesaugter": "ausgesaugt",
    "ausgesaugtere": "ausgesaugt",
    "ausgesaugterem": "ausgesaugt",
    "ausgesaugteren": "ausgesaugt",
    "ausgesaugterer": "ausgesaugt",
    "ausgesaugteres": "ausgesaugt",
    "ausgesaugtes": "ausgesaugt",
    "ausgesaugteste": "ausgesaugt",
    "ausgesaugtestem": "ausgesaugt",
    "ausgesaugtesten": "ausgesaugt",
    "ausgesaugtester": "ausgesaugt",
    "ausgesaugtestes": "ausgesaugt",
    "ausgeschabt": "ausschaben",
    "ausgeschabte": "ausgeschabt",
    "ausgeschabtem": "ausgeschabt",
    "ausgeschabten": "ausgeschabt",
    "ausgeschabter": "ausgeschabt",
    "ausgeschabtere": "ausgeschabt",
    "ausgeschabterem": "ausgeschabt",
    "ausgeschabteren": "ausgeschabt",
    "ausgeschabterer": "ausgeschabt",
    "ausgeschabteres": "ausgeschabt",
    "ausgeschabtes": "ausgeschabt",
    "ausgeschabteste": "ausgeschabt",
    "ausgeschabtestem": "ausgeschabt",
    "ausgeschabtesten": "ausgeschabt",
    "ausgeschabtester": "ausgeschabt",
    "ausgeschabtestes": "ausgeschabt",
    "ausgeschachtelt": "ausschachteln",
    "ausgeschachtelte": "ausgeschachtelt",
    "ausgeschachteltem": "ausgeschachtelt",
    "ausgeschachtelten": "ausgeschachtelt",
    "ausgeschachtelter": "ausgeschachtelt",
    "ausgeschachteltere": "ausgeschachtelt",
    "ausgeschachtelterem": "ausgeschachtelt",
    "ausgeschachtelteren": "ausgeschachtelt",
    "ausgeschachtelterer": "ausgeschachtelt",
    "ausgeschachtelteres": "ausgeschachtelt",
    "ausgeschachteltes": "ausgeschachtelt",
    "ausgeschachtelteste": "ausgeschachtelt",
    "ausgeschachteltestem": "ausgeschachtelt",
    "ausgeschachteltesten": "ausgeschachtelt",
    "ausgeschachteltester": "ausgeschachtelt",
    "ausgeschachteltestes": "ausgeschachtelt",
    "ausgeschalt": "ausschalen",
    "ausgeschalte": "ausgeschalt",
    "ausgeschaltem": "ausgeschalt",
    "ausgeschalten": "ausgeschalt",
    "ausgeschalter": "ausgeschalt",
    "ausgeschaltere": "ausgeschalt",
    "ausgeschalterem": "ausgeschalt",
    "ausgeschalteren": "ausgeschalt",
    "ausgeschalterer": "ausgeschalt",
    "ausgeschalteres": "ausgeschalt",
    "ausgeschaltes": "ausgeschalt",
    "ausgeschalteste": "ausgeschalt",
    "ausgeschaltestem": "ausgeschalt",
    "ausgeschaltesten": "ausgeschalt",
    "ausgeschaltester": "ausgeschalt",
    "ausgeschaltestes": "ausgeschalt",
    "ausgeschaltet": "ausschalten",
    "ausgeschaltete": "ausgeschaltet",
    "ausgeschaltetem": "ausgeschaltet",
    "ausgeschalteten": "ausgeschaltet",
    "ausgeschalteter": "ausgeschaltet",
    "ausgeschaltetes": "ausgeschaltet",
    "ausgescharrt": "ausscharren",
    "ausgescharrte": "ausgescharrt",
    "ausgescharrtem": "ausgescharrt",
    "ausgescharrten": "ausgescharrt",
    "ausgescharrter": "ausgescharrt",
    "ausgescharrtes": "ausgescharrt",
    "ausgeschaufelt": "ausschaufeln",
    "ausgeschaufelte": "ausgeschaufelt",
    "ausgeschaufeltem": "ausgeschaufelt",
    "ausgeschaufelten": "ausgeschaufelt",
    "ausgeschaufelter": "ausgeschaufelt",
    "ausgeschaufeltes": "ausgeschaufelt",
    "ausgeschaut": "ausschauen",
    "ausgeschaute": "ausgeschaut",
    "ausgeschautem": "ausgeschaut",
    "ausgeschauten": "ausgeschaut",
    "ausgeschauter": "ausgeschaut",
    "ausgeschautes": "ausgeschaut",
    "ausgeschenkt": "ausschenken",
    "ausgeschenkte": "ausgeschenkt",
    "ausgeschenktem": "ausgeschenkt",
    "ausgeschenkten": "ausgeschenkt",
    "ausgeschenkter": "ausgeschenkt",
    "ausgeschenktes": "ausgeschenkt",
    "ausgeschert": "ausscheren",
    "ausgescherte": "ausgeschert",
    "ausgeschertem": "ausgeschert",
    "ausgescherten": "ausgeschert",
    "ausgescherter": "ausgeschert",
    "ausgeschertere": "ausgeschert",
    "ausgescherterem": "ausgeschert",
    "ausgescherteren": "ausgeschert",
    "ausgescherterer": "ausgeschert",
    "ausgescherteres": "ausgeschert",
    "ausgeschertes": "ausgeschert",
    "ausgescherteste": "ausgeschert",
    "ausgeschertestem": "ausgeschert",
    "ausgeschertesten": "ausgeschert",
    "ausgeschertester": "ausgeschert",
    "ausgeschertestes": "ausgeschert",
    "ausgeschieden": "ausscheiden",
    "ausgeschiedene": "ausgeschieden",
    "ausgeschiedenem": "ausgeschieden",
    "ausgeschiedenen": "ausgeschieden",
    "ausgeschiedener": "ausgeschieden",
    "ausgeschiedenes": "ausgeschieden",
    "ausgeschifft": "ausschiffen",
    "ausgeschiffte": "ausgeschifft",
    "ausgeschifftem": "ausgeschifft",
    "ausgeschifften": "ausgeschifft",
    "ausgeschiffter": "ausgeschifft",
    "ausgeschifftes": "ausgeschifft",
    "ausgeschildert": "ausschildern",
    "ausgeschilderte": "ausgeschildert",
    "ausgeschildertem": "ausgeschildert",
    "ausgeschilderten": "ausgeschildert",
    "ausgeschilderter": "ausgeschildert",
    "ausgeschildertes": "ausgeschildert",
    "ausgeschimpft": "ausschimpfen",
    "ausgeschimpfte": "ausgeschimpft",
    "ausgeschimpftem": "ausgeschimpft",
    "ausgeschimpften": "ausgeschimpft",
    "ausgeschimpfter": "ausgeschimpft",
    "ausgeschimpftere": "ausgeschimpft",
    "ausgeschimpfterem": "ausgeschimpft",
    "ausgeschimpfteren": "ausgeschimpft",
    "ausgeschimpfterer": "ausgeschimpft",
    "ausgeschimpfteres": "ausgeschimpft",
    "ausgeschimpftes": "ausgeschimpft",
    "ausgeschimpfteste": "ausgeschimpft",
    "ausgeschimpftestem": "ausgeschimpft",
    "ausgeschimpftesten": "ausgeschimpft",
    "ausgeschimpftester": "ausgeschimpft",
    "ausgeschimpftestes": "ausgeschimpft",
    "ausgeschirrt": "ausschirren",
    "ausgeschirrte": "ausgeschirrt",
    "ausgeschirrtem": "ausgeschirrt",
    "ausgeschirrten": "ausgeschirrt",
    "ausgeschirrter": "ausgeschirrt",
    "ausgeschirrtes": "ausgeschirrt",
    "ausgeschlachtet": "ausschlachten",
    "ausgeschlachtete": "ausgeschlachtet",
    "ausgeschlachtetem": "ausgeschlachtet",
    "ausgeschlachteten": "ausgeschlachtet",
    "ausgeschlachteter": "ausgeschlachtet",
    "ausgeschlachtetere": "ausgeschlachtet",
    "ausgeschlachteterem": "ausgeschlachtet",
    "ausgeschlachteteren": "ausgeschlachtet",
    "ausgeschlachteterer": "ausgeschlachtet",
    "ausgeschlachteteres": "ausgeschlachtet",
    "ausgeschlachtetes": "ausgeschlachtet",
    "ausgeschlachteteste": "ausgeschlachtet",
    "ausgeschlachtetestem": "ausgeschlachtet",
    "ausgeschlachtetesten": "ausgeschlachtet",
    "ausgeschlachtetester": "ausgeschlachtet",
    "ausgeschlachtetestes": "ausgeschlachtet",
    "ausgeschlafen": "ausschlafen",
    "ausgeschlafene": "ausgeschlafen",
    "ausgeschlafenem": "ausgeschlafen",
    "ausgeschlafenen": "ausgeschlafen",
    "ausgeschlafener": "ausgeschlafen",
    "ausgeschlafenere": "ausgeschlafen",
    "ausgeschlafenerem": "ausgeschlafen",
    "ausgeschlafeneren": "ausgeschlafen",
    "ausgeschlafenerer": "ausgeschlafen",
    "ausgeschlafeneres": "ausgeschlafen",
    "ausgeschlafenes": "ausgeschlafen",
    "ausgeschlafenste": "ausgeschlafen",
    "ausgeschlafenstem": "ausgeschlafen",
    "ausgeschlafensten": "ausgeschlafen",
    "ausgeschlafenster": "ausgeschlafen",
    "ausgeschlafenstes": "ausgeschlafen",
    "ausgeschlagen": "ausschlagen",
    "ausgeschlagene": "ausgeschlagen",
    "ausgeschlagenem": "ausgeschlagen",
    "ausgeschlagenen": "ausgeschlagen",
    "ausgeschlagener": "ausgeschlagen",
    "ausgeschlagenes": "ausgeschlagen",
    "ausgeschleimt": "ausschleimen",
    "ausgeschleimte": "ausgeschleimt",
    "ausgeschleimtem": "ausgeschleimt",
    "ausgeschleimten": "ausgeschleimt",
    "ausgeschleimter": "ausgeschleimt",
    "ausgeschleimtere": "ausgeschleimt",
    "ausgeschleimterem": "ausgeschleimt",
    "ausgeschleimteren": "ausgeschleimt",
    "ausgeschleimterer": "ausgeschleimt",
    "ausgeschleimteres": "ausgeschleimt",
    "ausgeschleimtes": "ausgeschleimt",
    "ausgeschleimteste": "ausgeschleimt",
    "ausgeschleimtestem": "ausgeschleimt",
    "ausgeschleimtesten": "ausgeschleimt",
    "ausgeschleimtester": "ausgeschleimt",
    "ausgeschleimtestes": "ausgeschleimt",
    "ausgeschlossen": "ausschließen",
    "ausgeschlossene": "ausgeschlossen",
    "ausgeschlossenem": "ausgeschlossen",
    "ausgeschlossenen": "ausgeschlossen",
    "ausgeschlossener": "ausgeschlossen",
    "ausgeschlossenes": "ausgeschlossen",
    "ausgeschlämmt": "ausschlämmen",
    "ausgeschlämmte": "ausgeschlämmt",
    "ausgeschlämmtem": "ausgeschlämmt",
    "ausgeschlämmten": "ausgeschlämmt",
    "ausgeschlämmter": "ausgeschlämmt",
    "ausgeschlämmtes": "ausgeschlämmt",
    "ausgeschlüpft": "ausschlüpfen",
    "ausgeschlüpfte": "ausgeschlüpft",
    "ausgeschlüpftem": "ausgeschlüpft",
    "ausgeschlüpften": "ausgeschlüpft",
    "ausgeschlüpfter": "ausgeschlüpft",
    "ausgeschlüpftes": "ausgeschlüpft",
    "ausgeschlürft": "ausschlürfen",
    "ausgeschlürfte": "ausgeschlürft",
    "ausgeschlürftem": "ausgeschlürft",
    "ausgeschlürften": "ausgeschlürft",
    "ausgeschlürfter": "ausgeschlürft",
    "ausgeschlürftes": "ausgeschlürft",
    "ausgeschmiert": "ausschmieren",
    "ausgeschmierte": "ausgeschmiert",
    "ausgeschmiertem": "ausgeschmiert",
    "ausgeschmierten": "ausgeschmiert",
    "ausgeschmierter": "ausgeschmiert",
    "ausgeschmiertes": "ausgeschmiert",
    "ausgeschmolzen": "ausschmelzen",
    "ausgeschmolzene": "ausgeschmolzen",
    "ausgeschmolzenem": "ausgeschmolzen",
    "ausgeschmolzenen": "ausgeschmolzen",
    "ausgeschmolzener": "ausgeschmolzen",
    "ausgeschmolzenes": "ausgeschmolzen",
    "ausgeschnappt": "ausschnappen",
    "ausgeschnappte": "ausgeschnappt",
    "ausgeschnapptem": "ausgeschnappt",
    "ausgeschnappten": "ausgeschnappt",
    "ausgeschnappter": "ausgeschnappt",
    "ausgeschnapptes": "ausgeschnappt",
    "ausgeschnaubt": "ausschnauben",
    "ausgeschnaubte": "ausgeschnaubt",
    "ausgeschnaubtem": "ausgeschnaubt",
    "ausgeschnaubten": "ausgeschnaubt",
    "ausgeschnaubter": "ausgeschnaubt",
    "ausgeschnaubtere": "ausgeschnaubt",
    "ausgeschnaubterem": "ausgeschnaubt",
    "ausgeschnaubteren": "ausgeschnaubt",
    "ausgeschnaubterer": "ausgeschnaubt",
    "ausgeschnaubteres": "ausgeschnaubt",
    "ausgeschnaubtes": "ausgeschnaubt",
    "ausgeschnaubteste": "ausgeschnaubt",
    "ausgeschnaubtestem": "ausgeschnaubt",
    "ausgeschnaubtesten": "ausgeschnaubt",
    "ausgeschnaubtester": "ausgeschnaubt",
    "ausgeschnaubtestes": "ausgeschnaubt",
    "ausgeschnauft": "ausschnaufen",
    "ausgeschnaufte": "ausgeschnauft",
    "ausgeschnauftem": "ausgeschnauft",
    "ausgeschnauften": "ausgeschnauft",
    "ausgeschnaufter": "ausgeschnauft",
    "ausgeschnauftere": "ausgeschnauft",
    "ausgeschnaufterem": "ausgeschnauft",
    "ausgeschnaufteren": "ausgeschnauft",
    "ausgeschnaufterer": "ausgeschnauft",
    "ausgeschnaufteres": "ausgeschnauft",
    "ausgeschnauftes": "ausgeschnauft",
    "ausgeschnaufteste": "ausgeschnauft",
    "ausgeschnauftestem": "ausgeschnauft",
    "ausgeschnauftesten": "ausgeschnauft",
    "ausgeschnauftester": "ausgeschnauft",
    "ausgeschnauftestes": "ausgeschnauft",
    "ausgeschneuzt": "ausschneuzen",
    "ausgeschneuzte": "ausgeschneuzt",
    "ausgeschneuztem": "ausgeschneuzt",
    "ausgeschneuzten": "ausgeschneuzt",
    "ausgeschneuzter": "ausgeschneuzt",
    "ausgeschneuztes": "ausgeschneuzt",
    "ausgeschnitten": "ausschneiden",
    "ausgeschnittene": "ausgeschnitten",
    "ausgeschnittenem": "ausgeschnitten",
    "ausgeschnittenen": "ausgeschnitten",
    "ausgeschnittener": "ausgeschnitten",
    "ausgeschnittenes": "ausgeschnitten",
    "ausgeschnäuzt": "ausschnäuzen",
    "ausgeschnäuzte": "ausgeschnäuzt",
    "ausgeschnäuztem": "ausgeschnäuzt",
    "ausgeschnäuzten": "ausgeschnäuzt",
    "ausgeschnäuzter": "ausgeschnäuzt",
    "ausgeschnäuztes": "ausgeschnäuzt",
    "ausgescholten": "ausschelten",
    "ausgescholtene": "ausgescholten",
    "ausgescholtenem": "ausgescholten",
    "ausgescholtenen": "ausgescholten",
    "ausgescholtener": "ausgescholten",
    "ausgescholtenere": "ausgescholten",
    "ausgescholtenerem": "ausgescholten",
    "ausgescholteneren": "ausgescholten",
    "ausgescholtenerer": "ausgescholten",
    "ausgescholteneres": "ausgescholten",
    "ausgescholtenes": "ausgescholten",
    "ausgescholtenste": "ausgescholten",
    "ausgescholtenstem": "ausgescholten",
    "ausgescholtensten": "ausgescholten",
    "ausgescholtenster": "ausgescholten",
    "ausgescholtenstes": "ausgescholten",
    "ausgeschoren": "ausscheren",
    "ausgeschorene": "ausgeschoren",
    "ausgeschorenem": "ausgeschoren",
    "ausgeschorenen": "ausgeschoren",
    "ausgeschorener": "ausgeschoren",
    "ausgeschorenere": "ausgeschoren",
    "ausgeschorenerem": "ausgeschoren",
    "ausgeschoreneren": "ausgeschoren",
    "ausgeschorenerer": "ausgeschoren",
    "ausgeschoreneres": "ausgeschoren",
    "ausgeschorenes": "ausgeschoren",
    "ausgeschorenste": "ausgeschoren",
    "ausgeschorenstem": "ausgeschoren",
    "ausgeschorensten": "ausgeschoren",
    "ausgeschorenster": "ausgeschoren",
    "ausgeschorenstes": "ausgeschoren",
    "ausgeschossen": "ausschießen",
    "ausgeschossene": "ausgeschossen",
    "ausgeschossenem": "ausgeschossen",
    "ausgeschossenen": "ausgeschossen",
    "ausgeschossener": "ausgeschossen",
    "ausgeschossenes": "ausgeschossen",
    "ausgeschraubt": "ausschrauben",
    "ausgeschraubte": "ausgeschraubt",
    "ausgeschraubtem": "ausgeschraubt",
    "ausgeschraubten": "ausgeschraubt",
    "ausgeschraubter": "ausgeschraubt",
    "ausgeschraubtes": "ausgeschraubt",
    "ausgeschrieben": "ausschreiben",
    "ausgeschriebene": "ausgeschrieben",
    "ausgeschriebenem": "ausgeschrieben",
    "ausgeschriebenen": "ausgeschrieben",
    "ausgeschriebener": "ausgeschrieben",
    "ausgeschriebenes": "ausgeschrieben",
    "ausgeschrien": "ausschreien",
    "ausgeschriene": "ausgeschrien",
    "ausgeschrienem": "ausgeschrien",
    "ausgeschrienen": "ausgeschrien",
    "ausgeschriener": "ausgeschrien",
    "ausgeschrienere": "ausgeschrien",
    "ausgeschrienerem": "ausgeschrien",
    "ausgeschrieneren": "ausgeschrien",
    "ausgeschrienerer": "ausgeschrien",
    "ausgeschrieneres": "ausgeschrien",
    "ausgeschrienes": "ausgeschrien",
    "ausgeschrienste": "ausgeschrien",
    "ausgeschrienstem": "ausgeschrien",
    "ausgeschriensten": "ausgeschrien",
    "ausgeschrienster": "ausgeschrien",
    "ausgeschrienstes": "ausgeschrien",
    "ausgeschritten": "ausschreiten",
    "ausgeschrittene": "ausgeschritten",
    "ausgeschrittenem": "ausgeschritten",
    "ausgeschrittenen": "ausgeschritten",
    "ausgeschrittener": "ausgeschritten",
    "ausgeschrittenes": "ausgeschritten",
    "ausgeschult": "ausschulen",
    "ausgeschulte": "ausgeschult",
    "ausgeschultem": "ausgeschult",
    "ausgeschulten": "ausgeschult",
    "ausgeschulter": "ausgeschult",
    "ausgeschultes": "ausgeschult",
    "ausgeschwefelt": "ausschwefeln",
    "ausgeschwefelte": "ausgeschwefelt",
    "ausgeschwefeltem": "ausgeschwefelt",
    "ausgeschwefelten": "ausgeschwefelt",
    "ausgeschwefelter": "ausgeschwefelt",
    "ausgeschwefeltere": "ausgeschwefelt",
    "ausgeschwefelterem": "ausgeschwefelt",
    "ausgeschwefelteren": "ausgeschwefelt",
    "ausgeschwefelterer": "ausgeschwefelt",
    "ausgeschwefelteres": "ausgeschwefelt",
    "ausgeschwefeltes": "ausgeschwefelt",
    "ausgeschwefelteste": "ausgeschwefelt",
    "ausgeschwefeltestem": "ausgeschwefelt",
    "ausgeschwefeltesten": "ausgeschwefelt",
    "ausgeschwefeltester": "ausgeschwefelt",
    "ausgeschwefeltestes": "ausgeschwefelt",
    "ausgeschweift": "ausschweifen",
    "ausgeschweifte": "ausgeschweift",
    "ausgeschweiftem": "ausgeschweift",
    "ausgeschweiften": "ausgeschweift",
    "ausgeschweifter": "ausgeschweift",
    "ausgeschweiftere": "ausgeschweift",
    "ausgeschweifterem": "ausgeschweift",
    "ausgeschweifteren": "ausgeschweift",
    "ausgeschweifterer": "ausgeschweift",
    "ausgeschweifteres": "ausgeschweift",
    "ausgeschweiftes": "ausgeschweift",
    "ausgeschweifteste": "ausgeschweift",
    "ausgeschweiftestem": "ausgeschweift",
    "ausgeschweiftesten": "ausgeschweift",
    "ausgeschweiftester": "ausgeschweift",
    "ausgeschweiftestes": "ausgeschweift",
    "ausgeschwemmt": "ausschwemmen",
    "ausgeschwemmte": "ausgeschwemmt",
    "ausgeschwemmtem": "ausgeschwemmt",
    "ausgeschwemmten": "ausgeschwemmt",
    "ausgeschwemmter": "ausgeschwemmt",
    "ausgeschwemmtere": "ausgeschwemmt",
    "ausgeschwemmterem": "ausgeschwemmt",
    "ausgeschwemmteren": "ausgeschwemmt",
    "ausgeschwemmterer": "ausgeschwemmt",
    "ausgeschwemmteres": "ausgeschwemmt",
    "ausgeschwemmtes": "ausgeschwemmt",
    "ausgeschwemmteste": "ausgeschwemmt",
    "ausgeschwemmtestem": "ausgeschwemmt",
    "ausgeschwemmtesten": "ausgeschwemmt",
    "ausgeschwemmtester": "ausgeschwemmt",
    "ausgeschwemmtestes": "ausgeschwemmt",
    "ausgeschwenkt": "ausschwenken",
    "ausgeschwenkte": "ausgeschwenkt",
    "ausgeschwenktem": "ausgeschwenkt",
    "ausgeschwenkten": "ausgeschwenkt",
    "ausgeschwenkter": "ausgeschwenkt",
    "ausgeschwenktes": "ausgeschwenkt",
    "ausgeschwiegen": "ausschweigen",
    "ausgeschwiegene": "ausgeschwiegen",
    "ausgeschwiegenem": "ausgeschwiegen",
    "ausgeschwiegenen": "ausgeschwiegen",
    "ausgeschwiegener": "ausgeschwiegen",
    "ausgeschwiegenere": "ausgeschwiegen",
    "ausgeschwiegenerem": "ausgeschwiegen",
    "ausgeschwiegeneren": "ausgeschwiegen",
    "ausgeschwiegenerer": "ausgeschwiegen",
    "ausgeschwiegeneres": "ausgeschwiegen",
    "ausgeschwiegenes": "ausgeschwiegen",
    "ausgeschwiegenste": "ausgeschwiegen",
    "ausgeschwiegenstem": "ausgeschwiegen",
    "ausgeschwiegensten": "ausgeschwiegen",
    "ausgeschwiegenster": "ausgeschwiegen",
    "ausgeschwiegenstes": "ausgeschwiegen",
    "ausgeschwitzt": "ausschwitzen",
    "ausgeschwitzte": "ausgeschwitzt",
    "ausgeschwitztem": "ausgeschwitzt",
    "ausgeschwitzten": "ausgeschwitzt",
    "ausgeschwitzter": "ausgeschwitzt",
    "ausgeschwitztere": "ausgeschwitzt",
    "ausgeschwitzterem": "ausgeschwitzt",
    "ausgeschwitzteren": "ausgeschwitzt",
    "ausgeschwitzterer": "ausgeschwitzt",
    "ausgeschwitzteres": "ausgeschwitzt",
    "ausgeschwitztes": "ausgeschwitzt",
    "ausgeschwitzteste": "ausgeschwitzt",
    "ausgeschwitztestem": "ausgeschwitzt",
    "ausgeschwitztesten": "ausgeschwitzt",
    "ausgeschwitztester": "ausgeschwitzt",
    "ausgeschwitztestes": "ausgeschwitzt",
    "ausgeschwungen": "ausschwingen",
    "ausgeschwungene": "ausgeschwungen",
    "ausgeschwungenem": "ausgeschwungen",
    "ausgeschwungenen": "ausgeschwungen",
    "ausgeschwungener": "ausgeschwungen",
    "ausgeschwungenes": "ausgeschwungen",
    "ausgeschwärmt": "ausschwärmen",
    "ausgeschwärmte": "ausgeschwärmt",
    "ausgeschwärmtem": "ausgeschwärmt",
    "ausgeschwärmten": "ausgeschwärmt",
    "ausgeschwärmter": "ausgeschwärmt",
    "ausgeschwärmtes": "ausgeschwärmt",
    "ausgeschält": "ausschälen",
    "ausgeschältem": "ausgeschält",
    "ausgeschälter": "ausgeschält",
    "ausgeschältes": "ausgeschält",
    "ausgeschöpft": "ausschöpfen",
    "ausgeschöpfte": "ausgeschöpft",
    "ausgeschöpftem": "ausgeschöpft",
    "ausgeschöpften": "ausgeschöpft",
    "ausgeschöpfter": "ausgeschöpft",
    "ausgeschöpftere": "ausgeschöpft",
    "ausgeschöpfterem": "ausgeschöpft",
    "ausgeschöpfteren": "ausgeschöpft",
    "ausgeschöpfterer": "ausgeschöpft",
    "ausgeschöpfteres": "ausgeschöpft",
    "ausgeschöpftes": "ausgeschöpft",
    "ausgeschöpfteste": "ausgeschöpft",
    "ausgeschöpftestem": "ausgeschöpft",
    "ausgeschöpftesten": "ausgeschöpft",
    "ausgeschöpftester": "ausgeschöpft",
    "ausgeschöpftestes": "ausgeschöpft",
    "ausgeschüttelt": "ausschütteln",
    "ausgeschüttelte": "ausgeschüttelt",
    "ausgeschütteltem": "ausgeschüttelt",
    "ausgeschüttelten": "ausgeschüttelt",
    "ausgeschüttelter": "ausgeschüttelt",
    "ausgeschütteltere": "ausgeschüttelt",
    "ausgeschüttelterem": "ausgeschüttelt",
    "ausgeschüttelteren": "ausgeschüttelt",
    "ausgeschüttelterer": "ausgeschüttelt",
    "ausgeschüttelteres": "ausgeschüttelt",
    "ausgeschütteltes": "ausgeschüttelt",
    "ausgeschüttelteste": "ausgeschüttelt",
    "ausgeschütteltestem": "ausgeschüttelt",
    "ausgeschütteltesten": "ausgeschüttelt",
    "ausgeschütteltester": "ausgeschüttelt",
    "ausgeschütteltestes": "ausgeschüttelt",
    "ausgeschüttet": "ausschütten",
    "ausgeschüttete": "ausgeschüttet",
    "ausgeschüttetem": "ausgeschüttet",
    "ausgeschütteten": "ausgeschüttet",
    "ausgeschütteter": "ausgeschüttet",
    "ausgeschüttetes": "ausgeschüttet",
    "ausgesehen": "aussehen",
    "ausgesehene": "ausgesehen",
    "ausgesehenem": "ausgesehen",
    "ausgesehenen": "ausgesehen",
    "ausgesehener": "ausgesehen",
    "ausgesehenes": "ausgesehen",
    "ausgesendet": "aussenden",
    "ausgesendete": "ausgesendet",
    "ausgesendetem": "ausgesendet",
    "ausgesendeten": "ausgesendet",
    "ausgesendeter": "ausgesendet",
    "ausgesendetes": "ausgesendet",
    "ausgesessen": "aussitzen",
    "ausgesessene": "ausgesessen",
    "ausgesessenem": "ausgesessen",
    "ausgesessenen": "ausgesessen",
    "ausgesessener": "ausgesessen",
    "ausgesessenes": "ausgesessen",
    "ausgesetzt": "aussetzen",
    "ausgesetzte": "ausgesetzt",
    "ausgesetztem": "ausgesetzt",
    "ausgesetzten": "ausgesetzt",
    "ausgesetzter": "ausgesetzt",
    "ausgesetztes": "ausgesetzt",
    "ausgesiebt": "aussieben",
    "ausgesiebte": "ausgesiebt",
    "ausgesiebtem": "ausgesiebt",
    "ausgesiebten": "ausgesiebt",
    "ausgesiebter": "ausgesiebt",
    "ausgesiebtere": "ausgesiebt",
    "ausgesiebterem": "ausgesiebt",
    "ausgesiebteren": "ausgesiebt",
    "ausgesiebterer": "ausgesiebt",
    "ausgesiebteres": "ausgesiebt",
    "ausgesiebtes": "ausgesiebt",
    "ausgesiebteste": "ausgesiebt",
    "ausgesiebtestem": "ausgesiebt",
    "ausgesiebtesten": "ausgesiebt",
    "ausgesiebtester": "ausgesiebt",
    "ausgesiebtestes": "ausgesiebt",
    "ausgesiedelt": "aussiedeln",
    "ausgesiedelte": "ausgesiedelt",
    "ausgesiedeltem": "ausgesiedelt",
    "ausgesiedelten": "ausgesiedelt",
    "ausgesiedelter": "ausgesiedelt",
    "ausgesiedeltes": "ausgesiedelt",
    "ausgesoffen": "aussaufen",
    "ausgesoffene": "ausgesoffen",
    "ausgesoffenem": "ausgesoffen",
    "ausgesoffenen": "ausgesoffen",
    "ausgesoffener": "ausgesoffen",
    "ausgesoffenere": "ausgesoffen",
    "ausgesoffenerem": "ausgesoffen",
    "ausgesoffeneren": "ausgesoffen",
    "ausgesoffenerer": "ausgesoffen",
    "ausgesoffeneres": "ausgesoffen",
    "ausgesoffenes": "ausgesoffen",
    "ausgesoffenste": "ausgesoffen",
    "ausgesoffenstem": "ausgesoffen",
    "ausgesoffensten": "ausgesoffen",
    "ausgesoffenster": "ausgesoffen",
    "ausgesoffenstes": "ausgesoffen",
    "ausgesogen": "aussaugen",
    "ausgesogene": "ausgesogen",
    "ausgesogenem": "ausgesogen",
    "ausgesogenen": "ausgesogen",
    "ausgesogener": "ausgesogen",
    "ausgesogenes": "ausgesogen",
    "ausgesondert": "aussondern",
    "ausgesonderte": "ausgesondert",
    "ausgesondertem": "ausgesondert",
    "ausgesonderten": "ausgesondert",
    "ausgesonderter": "ausgesondert",
    "ausgesondertes": "ausgesondert",
    "ausgespannt": "ausspannen",
    "ausgespannte": "ausgespannt",
    "ausgespanntem": "ausgespannt",
    "ausgespannten": "ausgespannt",
    "ausgespannter": "ausgespannt",
    "ausgespanntes": "ausgespannt",
    "ausgespart": "aussparen",
    "ausgesparte": "ausgespart",
    "ausgespartem": "ausgespart",
    "ausgesparten": "ausgespart",
    "ausgesparter": "ausgespart",
    "ausgespartes": "ausgespart",
    "ausgesperrt": "aussperren",
    "ausgesperrte": "ausgesperrt",
    "ausgesperrtem": "ausgesperrt",
    "ausgesperrten": "ausgesperrt",
    "ausgesperrter": "ausgesperrt",
    "ausgesperrtes": "ausgesperrt",
    "ausgespielt": "ausspielen",
    "ausgespielte": "ausgespielt",
    "ausgespieltem": "ausgespielt",
    "ausgespielten": "ausgespielt",
    "ausgespielter": "ausgespielt",
    "ausgespieltes": "ausgespielt",
    "ausgespien": "ausspeien",
    "ausgespiene": "ausgespien",
    "ausgespienem": "ausgespien",
    "ausgespienen": "ausgespien",
    "ausgespiener": "ausgespien",
    "ausgespienes": "ausgespien",
    "ausgesprengt": "aussprengen",
    "ausgesprengte": "ausgesprengt",
    "ausgesprengtem": "ausgesprengt",
    "ausgesprengten": "ausgesprengt",
    "ausgesprengter": "ausgesprengt",
    "ausgesprengtes": "ausgesprengt",
    "ausgespritzt": "ausspritzen",
    "ausgespritzte": "ausgespritzt",
    "ausgespritztem": "ausgespritzt",
    "ausgespritzten": "ausgespritzt",
    "ausgespritzter": "ausgespritzt",
    "ausgespritztes": "ausgespritzt",
    "ausgesprochen": "aussprechen",
    "ausgesprochene": "ausgesprochen",
    "ausgesprochenem": "ausgesprochen",
    "ausgesprochenen": "ausgesprochen",
    "ausgesprochener": "ausgesprochen",
    "ausgesprochenes": "ausgesprochen",
    "ausgesprüht": "aussprühen",
    "ausgesprühte": "ausgesprüht",
    "ausgesprühtem": "ausgesprüht",
    "ausgesprühten": "ausgesprüht",
    "ausgesprühter": "ausgesprüht",
    "ausgesprühtes": "ausgesprüht",
    "ausgespuckt": "ausspucken",
    "ausgespuckte": "ausgespuckt",
    "ausgespucktem": "ausgespuckt",
    "ausgespuckten": "ausgespuckt",
    "ausgespuckter": "ausgespuckt",
    "ausgespucktes": "ausgespuckt",
    "ausgespäht": "ausspähen",
    "ausgespähte": "ausgespäht",
    "ausgespähtem": "ausgespäht",
    "ausgespähten": "ausgespäht",
    "ausgespähter": "ausgespäht",
    "ausgespähtere": "ausgespäht",
    "ausgespähterem": "ausgespäht",
    "ausgespähteren": "ausgespäht",
    "ausgespähterer": "ausgespäht",
    "ausgespähteres": "ausgespäht",
    "ausgespähtes": "ausgespäht",
    "ausgespähteste": "ausgespäht",
    "ausgespähtestem": "ausgespäht",
    "ausgespähtesten": "ausgespäht",
    "ausgespähtester": "ausgespäht",
    "ausgespähtestes": "ausgespäht",
    "ausgespült": "ausspülen",
    "ausgespülte": "ausgespült",
    "ausgespültem": "ausgespült",
    "ausgespülten": "ausgespült",
    "ausgespülter": "ausgespült",
    "ausgespültes": "ausgespült",
    "ausgestalte": "ausgestalten",
    "ausgestaltend": "ausgestalten",
    "ausgestaltende": "ausgestaltend",
    "ausgestaltendem": "ausgestaltend",
    "ausgestaltenden": "ausgestaltend",
    "ausgestaltender": "ausgestaltend",
    "ausgestaltendes": "ausgestaltend",
    "ausgestaltest": "ausgestalten",
    "ausgestaltet": "ausgestalten",
    "ausgestaltete": "ausgestalten",
    "ausgestaltetem": "ausgestaltet",
    "ausgestalteten": "ausgestalten",
    "ausgestalteter": "ausgestaltet",
    "ausgestaltetere": "ausgestaltet",
    "ausgestalteterem": "ausgestaltet",
    "ausgestalteteren": "ausgestaltet",
    "ausgestalteterer": "ausgestaltet",
    "ausgestalteteres": "ausgestaltet",
    "ausgestaltetes": "ausgestaltet",
    "ausgestaltetest": "ausgestalten",
    "ausgestalteteste": "ausgestaltet",
    "ausgestaltetestem": "ausgestaltet",
    "ausgestaltetesten": "ausgestaltet",
    "ausgestaltetester": "ausgestaltet",
    "ausgestaltetestes": "ausgestaltet",
    "ausgestaltetet": "ausgestalten",
    "ausgestanden": "ausstehen",
    "ausgestandene": "ausgestanden",
    "ausgestandenem": "ausgestanden",
    "ausgestandenen": "ausgestanden",
    "ausgestandener": "ausgestanden",
    "ausgestandenes": "ausgestanden",
    "ausgestanzt": "ausstanzen",
    "ausgestanzte": "ausgestanzt",
    "ausgestanztem": "ausgestanzt",
    "ausgestanzten": "ausgestanzt",
    "ausgestanzter": "ausgestanzt",
    "ausgestanztes": "ausgestanzt",
    "ausgestattet": "ausstatten",
    "ausgestattete": "ausgestattet",
    "ausgestattetem": "ausgestattet",
    "ausgestatteten": "ausgestattet",
    "ausgestatteter": "ausgestattet",
    "ausgestattetere": "ausgestattet",
    "ausgestatteterem": "ausgestattet",
    "ausgestatteteren": "ausgestattet",
    "ausgestatteterer": "ausgestattet",
    "ausgestatteteres": "ausgestattet",
    "ausgestattetes": "ausgestattet",
    "ausgestatteteste": "ausgestattet",
    "ausgestattetestem": "ausgestattet",
    "ausgestattetesten": "ausgestattet",
    "ausgestattetester": "ausgestattet",
    "ausgestattetestes": "ausgestattet",
    "ausgesteift": "aussteifen",
    "ausgesteifte": "ausgesteift",
    "ausgesteiftem": "ausgesteift",
    "ausgesteiften": "ausgesteift",
    "ausgesteifter": "ausgesteift",
    "ausgesteiftere": "ausgesteift",
    "ausgesteifterem": "ausgesteift",
    "ausgesteifteren": "ausgesteift",
    "ausgesteifterer": "ausgesteift",
    "ausgesteifteres": "ausgesteift",
    "ausgesteiftes": "ausgesteift",
    "ausgesteifteste": "ausgesteift",
    "ausgesteiftestem": "ausgesteift",
    "ausgesteiftesten": "ausgesteift",
    "ausgesteiftester": "ausgesteift",
    "ausgesteiftestes": "ausgesteift",
    "ausgestellt": "ausstellen",
    "ausgestellte": "ausgestellt",
    "ausgestelltem": "ausgestellt",
    "ausgestellten": "ausgestellt",
    "ausgestellter": "ausgestellt",
    "ausgestelltes": "ausgestellt",
    "ausgesteuert": "aussteuern",
    "ausgesteuerte": "ausgesteuert",
    "ausgesteuertem": "ausgesteuert",
    "ausgesteuerten": "ausgesteuert",
    "ausgesteuerter": "ausgesteuert",
    "ausgesteuertes": "ausgesteuert",
    "ausgestiegen": "aussteigen",
    "ausgestiegene": "ausgestiegen",
    "ausgestiegenem": "ausgestiegen",
    "ausgestiegenen": "ausgestiegen",
    "ausgestiegener": "ausgestiegen",
    "ausgestiegenes": "ausgestiegen",
    "ausgestochen": "ausstechen",
    "ausgestochene": "ausgestochen",
    "ausgestochenem": "ausgestochen",
    "ausgestochenen": "ausgestochen",
    "ausgestochener": "ausgestochen",
    "ausgestochenes": "ausgestochen",
    "ausgestopft": "ausstopfen",
    "ausgestopfte": "ausgestopft",
    "ausgestopftem": "ausgestopft",
    "ausgestopften": "ausgestopft",
    "ausgestopfter": "ausgestopft",
    "ausgestopftere": "ausgestopft",
    "ausgestopfterem": "ausgestopft",
    "ausgestopfteren": "ausgestopft",
    "ausgestopfterer": "ausgestopft",
    "ausgestopfteres": "ausgestopft",
    "ausgestopftes": "ausgestopft",
    "ausgestopfteste": "ausgestopft",
    "ausgestopftestem": "ausgestopft",
    "ausgestopftesten": "ausgestopft",
    "ausgestopftester": "ausgestopft",
    "ausgestopftestes": "ausgestopft",
    "ausgestorben": "aussterben",
    "ausgestorbene": "ausgestorben",
    "ausgestorbenem": "ausgestorben",
    "ausgestorbenen": "ausgestorben",
    "ausgestorbener": "ausgestorben",
    "ausgestorbenere": "ausgestorben",
    "ausgestorbenerem": "ausgestorben",
    "ausgestorbeneren": "ausgestorben",
    "ausgestorbenerer": "ausgestorben",
    "ausgestorbeneres": "ausgestorben",
    "ausgestorbenes": "ausgestorben",
    "ausgestorbenste": "ausgestorben",
    "ausgestorbenstem": "ausgestorben",
    "ausgestorbensten": "ausgestorben",
    "ausgestorbenster": "ausgestorben",
    "ausgestorbenstes": "ausgestorben",
    "ausgestoßen": "ausstoßen",
    "ausgestoßene": "ausgestoßen",
    "ausgestoßenem": "ausgestoßen",
    "ausgestoßenen": "ausgestoßen",
    "ausgestoßener": "ausgestoßen",
    "ausgestoßenes": "ausgestoßen",
    "ausgestrahlt": "ausstrahlen",
    "ausgestrahlte": "ausgestrahlt",
    "ausgestrahltem": "ausgestrahlt",
    "ausgestrahlten": "ausgestrahlt",
    "ausgestrahlter": "ausgestrahlt",
    "ausgestrahltes": "ausgestrahlt",
    "ausgestreut": "ausstreuen",
    "ausgestreute": "ausgestreut",
    "ausgestreutem": "ausgestreut",
    "ausgestreuten": "ausgestreut",
    "ausgestreuter": "ausgestreut",
    "ausgestreutes": "ausgestreut",
    "ausgestrichen": "ausstreichen",
    "ausgestrichene": "ausgestrichen",
    "ausgestrichenem": "ausgestrichen",
    "ausgestrichenen": "ausgestrichen",
    "ausgestrichener": "ausgestrichen",
    "ausgestrichenes": "ausgestrichen",
    "ausgeströmt": "ausströmen",
    "ausgeströmte": "ausgeströmt",
    "ausgeströmtem": "ausgeströmt",
    "ausgeströmten": "ausgeströmt",
    "ausgeströmter": "ausgeströmt",
    "ausgeströmtes": "ausgeströmt",
    "ausgestülpt": "ausstülpen",
    "ausgestülpte": "ausgestülpt",
    "ausgestülptem": "ausgestülpt",
    "ausgestülpten": "ausgestülpt",
    "ausgestülpter": "ausgestülpt",
    "ausgestülptes": "ausgestülpt",
    "ausgesucht": "aussuchen",
    "ausgesuchte": "ausgesucht",
    "ausgesuchtem": "ausgesucht",
    "ausgesuchten": "ausgesucht",
    "ausgesuchter": "ausgesucht",
    "ausgesuchtere": "ausgesucht",
    "ausgesuchterem": "ausgesucht",
    "ausgesuchteren": "ausgesucht",
    "ausgesuchterer": "ausgesucht",
    "ausgesuchteres": "ausgesucht",
    "ausgesuchtes": "ausgesucht",
    "ausgesuchteste": "ausgesucht",
    "ausgesuchtestem": "ausgesucht",
    "ausgesuchtesten": "ausgesucht",
    "ausgesuchtester": "ausgesucht",
    "ausgesuchtestes": "ausgesucht",
    "ausgesägt": "aussägen",
    "ausgesägtem": "ausgesägt",
    "ausgesägter": "ausgesägt",
    "ausgesägtes": "ausgesägt",
    "ausgesät": "aussäen",
    "ausgesäte": "ausgesät",
    "ausgesätem": "ausgesät",
    "ausgesäten": "ausgesät",
    "ausgesäter": "ausgesät",
    "ausgesätes": "ausgesät",
    "ausgesöhnt": "aussöhnen",
    "ausgesöhnte": "ausgesöhnt",
    "ausgesöhntem": "ausgesöhnt",
    "ausgesöhnten": "ausgesöhnt",
    "ausgesöhnter": "ausgesöhnt",
    "ausgesöhntes": "ausgesöhnt",
    "ausgetauscht": "austauschen",
    "ausgetauschte": "ausgetauscht",
    "ausgetauschtem": "ausgetauscht",
    "ausgetauschten": "ausgetauscht",
    "ausgetauschter": "ausgetauscht",
    "ausgetauschtes": "ausgetauscht",
    "ausgeteilt": "austeilen",
    "ausgeteilte": "ausgeteilt",
    "ausgeteiltem": "ausgeteilt",
    "ausgeteilten": "ausgeteilt",
    "ausgeteilter": "ausgeteilt",
    "ausgeteiltes": "ausgeteilt",
    "ausgetilgt": "austilgen",
    "ausgetilgte": "ausgetilgt",
    "ausgetilgtem": "ausgetilgt",
    "ausgetilgten": "ausgetilgt",
    "ausgetilgter": "ausgetilgt",
    "ausgetilgtes": "ausgetilgt",
    "ausgetobt": "austoben",
    "ausgetobte": "ausgetobt",
    "ausgetobtem": "ausgetobt",
    "ausgetobten": "ausgetobt",
    "ausgetobter": "ausgetobt",
    "ausgetobtere": "ausgetobt",
    "ausgetobterem": "ausgetobt",
    "ausgetobteren": "ausgetobt",
    "ausgetobterer": "ausgetobt",
    "ausgetobteres": "ausgetobt",
    "ausgetobtes": "ausgetobt",
    "ausgetobteste": "ausgetobt",
    "ausgetobtestem": "ausgetobt",
    "ausgetobtesten": "ausgetobt",
    "ausgetobtester": "ausgetobt",
    "ausgetobtestes": "ausgetobt",
    "ausgetragen": "austragen",
    "ausgetragene": "ausgetragen",
    "ausgetragenem": "ausgetragen",
    "ausgetragenen": "ausgetragen",
    "ausgetragener": "ausgetragen",
    "ausgetragenes": "ausgetragen",
    "ausgetreten": "austreten",
    "ausgetretene": "ausgetreten",
    "ausgetretenem": "ausgetreten",
    "ausgetretenen": "ausgetreten",
    "ausgetretener": "ausgetreten",
    "ausgetretenes": "ausgetreten",
    "ausgetrickst": "austricksen",
    "ausgetrickste": "ausgetrickst",
    "ausgetrickstem": "ausgetrickst",
    "ausgetricksten": "ausgetrickst",
    "ausgetrickster": "ausgetrickst",
    "ausgetrickstere": "ausgetrickst",
    "ausgetricksterem": "ausgetrickst",
    "ausgetricksteren": "ausgetrickst",
    "ausgetricksterer": "ausgetrickst",
    "ausgetricksteres": "ausgetrickst",
    "ausgetrickstes": "ausgetrickst",
    "ausgetricksteste": "ausgetrickst",
    "ausgetrickstestem": "ausgetrickst",
    "ausgetrickstesten": "ausgetrickst",
    "ausgetrickstester": "ausgetrickst",
    "ausgetrickstestes": "ausgetrickst",
    "ausgetrieben": "austreiben",
    "ausgetriebene": "ausgetrieben",
    "ausgetriebenem": "ausgetrieben",
    "ausgetriebenen": "ausgetrieben",
    "ausgetriebener": "ausgetrieben",
    "ausgetriebenes": "ausgetrieben",
    "ausgetrocknet": "austrocknen",
    "ausgetrocknete": "ausgetrocknet",
    "ausgetrocknetem": "ausgetrocknet",
    "ausgetrockneten": "ausgetrocknet",
    "ausgetrockneter": "ausgetrocknet",
    "ausgetrocknetere": "ausgetrocknet",
    "ausgetrockneterem": "ausgetrocknet",
    "ausgetrockneteren": "ausgetrocknet",
    "ausgetrockneterer": "ausgetrocknet",
    "ausgetrockneteres": "ausgetrocknet",
    "ausgetrocknetes": "ausgetrocknet",
    "ausgetrockneteste": "ausgetrocknet",
    "ausgetrocknetestem": "ausgetrocknet",
    "ausgetrocknetesten": "ausgetrocknet",
    "ausgetrocknetester": "ausgetrocknet",
    "ausgetrocknetestes": "ausgetrocknet",
    "ausgetrunken": "austrinken",
    "ausgetrunkene": "ausgetrunken",
    "ausgetrunkenem": "ausgetrunken",
    "ausgetrunkenen": "ausgetrunken",
    "ausgetrunkener": "ausgetrunken",
    "ausgetrunkenere": "ausgetrunken",
    "ausgetrunkenerem": "ausgetrunken",
    "ausgetrunkeneren": "ausgetrunken",
    "ausgetrunkenerer": "ausgetrunken",
    "ausgetrunkeneres": "ausgetrunken",
    "ausgetrunkenes": "ausgetrunken",
    "ausgetrunkenste": "ausgetrunken",
    "ausgetrunkenstem": "ausgetrunken",
    "ausgetrunkensten": "ausgetrunken",
    "ausgetrunkenster": "ausgetrunken",
    "ausgetrunkenstes": "ausgetrunken",
    "ausgeträumt": "austräumen",
    "ausgeträumte": "ausgeträumt",
    "ausgeträumtem": "ausgeträumt",
    "ausgeträumten": "ausgeträumt",
    "ausgeträumter": "ausgeträumt",
    "ausgeträumtes": "ausgeträumt",
    "ausgetupft": "austupfen",
    "ausgetupfte": "ausgetupft",
    "ausgetupftem": "ausgetupft",
    "ausgetupften": "ausgetupft",
    "ausgetupfter": "ausgetupft",
    "ausgetupftes": "ausgetupft",
    "ausgetüftelt": "austüfteln",
    "ausgetüftelte": "ausgetüftelt",
    "ausgetüfteltem": "ausgetüftelt",
    "ausgetüftelten": "ausgetüftelt",
    "ausgetüftelter": "ausgetüftelt",
    "ausgetüfteltere": "ausgetüftelt",
    "ausgetüftelterem": "ausgetüftelt",
    "ausgetüftelteren": "ausgetüftelt",
    "ausgetüftelterer": "ausgetüftelt",
    "ausgetüftelteres": "ausgetüftelt",
    "ausgetüfteltes": "ausgetüftelt",
    "ausgetüftelteste": "ausgetüftelt",
    "ausgetüfteltestem": "ausgetüftelt",
    "ausgetüfteltesten": "ausgetüftelt",
    "ausgetüfteltester": "ausgetüftelt",
    "ausgetüfteltestes": "ausgetüftelt",
    "ausgeufert": "ausufern",
    "ausgeuferte": "ausgeufert",
    "ausgeufertem": "ausgeufert",
    "ausgeuferten": "ausgeufert",
    "ausgeuferter": "ausgeufert",
    "ausgeufertere": "ausgeufert",
    "ausgeuferterem": "ausgeufert",
    "ausgeuferteren": "ausgeufert",
    "ausgeuferterer": "ausgeufert",
    "ausgeuferteres": "ausgeufert",
    "ausgeufertes": "ausgeufert",
    "ausgeuferteste": "ausgeufert",
    "ausgeufertestem": "ausgeufert",
    "ausgeufertesten": "ausgeufert",
    "ausgeufertester": "ausgeufert",
    "ausgeufertestes": "ausgeufert",
    "ausgewachsen": "auswachsen",
    "ausgewachsene": "ausgewachsen",
    "ausgewachsenem": "ausgewachsen",
    "ausgewachsenen": "ausgewachsen",
    "ausgewachsener": "ausgewachsen",
    "ausgewachsenere": "ausgewachsen",
    "ausgewachsenerem": "ausgewachsen",
    "ausgewachseneren": "ausgewachsen",
    "ausgewachsenerer": "ausgewachsen",
    "ausgewachseneres": "ausgewachsen",
    "ausgewachsenes": "ausgewachsen",
    "ausgewachsenste": "ausgewachsen",
    "ausgewachsenstem": "ausgewachsen",
    "ausgewachsensten": "ausgewachsen",
    "ausgewachsenster": "ausgewachsen",
    "ausgewachsenstes": "ausgewachsen",
    "ausgewachst": "auswachsen",
    "ausgewachste": "ausgewachst",
    "ausgewachstem": "ausgewachst",
    "ausgewachsten": "ausgewachst",
    "ausgewachster": "ausgewachst",
    "ausgewachstere": "ausgewachst",
    "ausgewachsterem": "ausgewachst",
    "ausgewachsteren": "ausgewachst",
    "ausgewachsterer": "ausgewachst",
    "ausgewachsteres": "ausgewachst",
    "ausgewachstes": "ausgewachst",
    "ausgewachsteste": "ausgewachst",
    "ausgewachstestem": "ausgewachst",
    "ausgewachstesten": "ausgewachst",
    "ausgewachstester": "ausgewachst",
    "ausgewachstestes": "ausgewachst",
    "ausgewalzt": "auswalzen",
    "ausgewalzte": "ausgewalzt",
    "ausgewalztem": "ausgewalzt",
    "ausgewalzten": "ausgewalzt",
    "ausgewalzter": "ausgewalzt",
    "ausgewalztes": "ausgewalzt",
    "ausgewandert": "auswandern",
    "ausgewanderte": "ausgewandert",
    "ausgewandertem": "ausgewandert",
    "ausgewanderten": "ausgewandert",
    "ausgewanderter": "ausgewandert",
    "ausgewandertes": "ausgewandert",
    "ausgewaschen": "auswaschen",
    "ausgewaschene": "ausgewaschen",
    "ausgewaschenem": "ausgewaschen",
    "ausgewaschenen": "ausgewaschen",
    "ausgewaschener": "ausgewaschen",
    "ausgewaschenes": "ausgewaschen",
    "ausgewechselt": "auswechseln",
    "ausgewechselte": "ausgewechselt",
    "ausgewechseltem": "ausgewechselt",
    "ausgewechselten": "ausgewechselt",
    "ausgewechselter": "ausgewechselt",
    "ausgewechseltes": "ausgewechselt",
    "ausgeweicht": "ausweichen",
    "ausgeweichte": "ausgeweicht",
    "ausgeweichtem": "ausgeweicht",
    "ausgeweichten": "ausgeweicht",
    "ausgeweichter": "ausgeweicht",
    "ausgeweichtes": "ausgeweicht",
    "ausgeweidet": "ausweiden",
    "ausgeweidete": "ausgeweidet",
    "ausgeweidetem": "ausgeweidet",
    "ausgeweideten": "ausgeweidet",
    "ausgeweideter": "ausgeweidet",
    "ausgeweidetes": "ausgeweidet",
    "ausgeweint": "ausweinen",
    "ausgeweinte": "ausgeweint",
    "ausgeweintem": "ausgeweint",
    "ausgeweinten": "ausgeweint",
    "ausgeweinter": "ausgeweint",
    "ausgeweintes": "ausgeweint",
    "ausgeweitet": "ausweiten",
    "ausgeweitete": "ausgeweitet",
    "ausgeweitetem": "ausgeweitet",
    "ausgeweiteten": "ausgeweitet",
    "ausgeweiteter": "ausgeweitet",
    "ausgeweitetere": "ausgeweitet",
    "ausgeweiteterem": "ausgeweitet",
    "ausgeweiteteren": "ausgeweitet",
    "ausgeweiteterer": "ausgeweitet",
    "ausgeweiteteres": "ausgeweitet",
    "ausgeweitetes": "ausgeweitet",
    "ausgeweiteteste": "ausgeweitet",
    "ausgeweitetestem": "ausgeweitet",
    "ausgeweitetesten": "ausgeweitet",
    "ausgeweitetester": "ausgeweitet",
    "ausgeweitetestes": "ausgeweitet",
    "ausgewertet": "auswerten",
    "ausgewertete": "ausgewertet",
    "ausgewertetem": "ausgewertet",
    "ausgewerteten": "ausgewertet",
    "ausgewerteter": "ausgewertet",
    "ausgewertetes": "ausgewertet",
    "ausgewetzt": "auswetzen",
    "ausgewetzte": "ausgewetzt",
    "ausgewetztem": "ausgewetzt",
    "ausgewetzten": "ausgewetzt",
    "ausgewetzter": "ausgewetzt",
    "ausgewetztere": "ausgewetzt",
    "ausgewetzterem": "ausgewetzt",
    "ausgewetzteren": "ausgewetzt",
    "ausgewetzterer": "ausgewetzt",
    "ausgewetzteres": "ausgewetzt",
    "ausgewetztes": "ausgewetzt",
    "ausgewetzteste": "ausgewetzt",
    "ausgewetztestem": "ausgewetzt",
    "ausgewetztesten": "ausgewetzt",
    "ausgewetztester": "ausgewetzt",
    "ausgewetztestes": "ausgewetzt",
    "ausgewichen": "ausweichen",
    "ausgewichene": "ausgewichen",
    "ausgewichenem": "ausgewichen",
    "ausgewichenen": "ausgewichen",
    "ausgewichener": "ausgewichen",
    "ausgewichenes": "ausgewichen",
    "ausgewickelt": "auswickeln",
    "ausgewickelte": "ausgewickelt",
    "ausgewickeltem": "ausgewickelt",
    "ausgewickelten": "ausgewickelt",
    "ausgewickelter": "ausgewickelt",
    "ausgewickeltere": "ausgewickelt",
    "ausgewickelterem": "ausgewickelt",
    "ausgewickelteren": "ausgewickelt",
    "ausgewickelterer": "ausgewickelt",
    "ausgewickelteres": "ausgewickelt",
    "ausgewickeltes": "ausgewickelt",
    "ausgewickelteste": "ausgewickelt",
    "ausgewickeltestem": "ausgewickelt",
    "ausgewickeltesten": "ausgewickelt",
    "ausgewickeltester": "ausgewickelt",
    "ausgewickeltestes": "ausgewickelt",
    "ausgewiesen": "ausweisen",
    "ausgewiesene": "ausgewiesen",
    "ausgewiesenem": "ausgewiesen",
    "ausgewiesenen": "ausgewiesen",
    "ausgewiesener": "ausgewiesen",
    "ausgewiesenere": "ausgewiesen",
    "ausgewiesenerem": "ausgewiesen",
    "ausgewieseneren": "ausgewiesen",
    "ausgewiesenerer": "ausgewiesen",
    "ausgewieseneres": "ausgewiesen",
    "ausgewiesenes": "ausgewiesen",
    "ausgewiesenste": "ausgewiesen",
    "ausgewiesenstem": "ausgewiesen",
    "ausgewiesensten": "ausgewiesen",
    "ausgewiesenster": "ausgewiesen",
    "ausgewiesenstes": "ausgewiesen",
    "ausgewirkt": "auswirken",
    "ausgewirkte": "ausgewirkt",
    "ausgewirktem": "ausgewirkt",
    "ausgewirkten": "ausgewirkt",
    "ausgewirkter": "ausgewirkt",
    "ausgewirktes": "ausgewirkt",
    "ausgewischt": "auswischen",
    "ausgewischte": "ausgewischt",
    "ausgewischtem": "ausgewischt",
    "ausgewischten": "ausgewischt",
    "ausgewischter": "ausgewischt",
    "ausgewischtes": "ausgewischt",
    "ausgewogen": "auswiegen",
    "ausgewogene": "ausgewogen",
    "ausgewogenem": "ausgewogen",
    "ausgewogenen": "ausgewogen",
    "ausgewogener": "ausgewogen",
    "ausgewogenere": "ausgewogen",
    "ausgewogenerem": "ausgewogen",
    "ausgewogeneren": "ausgewogen",
    "ausgewogenerer": "ausgewogen",
    "ausgewogeneres": "ausgewogen",
    "ausgewogenes": "ausgewogen",
    "ausgewogenste": "ausgewogen",
    "ausgewogenstem": "ausgewogen",
    "ausgewogensten": "ausgewogen",
    "ausgewogenster": "ausgewogen",
    "ausgewogenstes": "ausgewogen",
    "ausgeworfen": "auswerfen",
    "ausgeworfene": "ausgeworfen",
    "ausgeworfenem": "ausgeworfen",
    "ausgeworfenen": "ausgeworfen",
    "ausgeworfener": "ausgeworfen",
    "ausgeworfenes": "ausgeworfen",
    "ausgewrungen": "auswringen",
    "ausgewrungene": "ausgewrungen",
    "ausgewrungenem": "ausgewrungen",
    "ausgewrungenen": "ausgewrungen",
    "ausgewrungener": "ausgewrungen",
    "ausgewrungenere": "ausgewrungen",
    "ausgewrungenerem": "ausgewrungen",
    "ausgewrungeneren": "ausgewrungen",
    "ausgewrungenerer": "ausgewrungen",
    "ausgewrungeneres": "ausgewrungen",
    "ausgewrungenes": "ausgewrungen",
    "ausgewrungenste": "ausgewrungen",
    "ausgewrungenstem": "ausgewrungen",
    "ausgewrungensten": "ausgewrungen",
    "ausgewrungenster": "ausgewrungen",
    "ausgewrungenstes": "ausgewrungen",
    "ausgewuchtet": "auswuchten",
    "ausgewuchtete": "ausgewuchtet",
    "ausgewuchtetem": "ausgewuchtet",
    "ausgewuchteten": "ausgewuchtet",
    "ausgewuchteter": "ausgewuchtet",
    "ausgewuchtetere": "ausgewuchtet",
    "ausgewuchteterem": "ausgewuchtet",
    "ausgewuchteteren": "ausgewuchtet",
    "ausgewuchteterer": "ausgewuchtet",
    "ausgewuchteteres": "ausgewuchtet",
    "ausgewuchtetes": "ausgewuchtet",
    "ausgewuchteteste": "ausgewuchtet",
    "ausgewuchtetestem": "ausgewuchtet",
    "ausgewuchtetesten": "ausgewuchtet",
    "ausgewuchtetester": "ausgewuchtet",
    "ausgewuchtetestes": "ausgewuchtet",
    "ausgewunden": "auswinden",
    "ausgewundene": "ausgewunden",
    "ausgewundenem": "ausgewunden",
    "ausgewundenen": "ausgewunden",
    "ausgewundener": "ausgewunden",
    "ausgewundenes": "ausgewunden",
    "ausgewählt": "auswählen",
    "ausgewählte": "ausgewählt",
    "ausgewähltem": "ausgewählt",
    "ausgewählten": "ausgewählt",
    "ausgewählter": "ausgewählt",
    "ausgewähltes": "ausgewählt",
    "ausgewärmt": "auswärmen",
    "ausgewärmte": "ausgewärmt",
    "ausgewärmtem": "ausgewärmt",
    "ausgewärmten": "ausgewärmt",
    "ausgewärmter": "ausgewärmt",
    "ausgewärmtes": "ausgewärmt",
    "ausgezahlt": "auszahlen",
    "ausgezahlte": "ausgezahlt",
    "ausgezahltem": "ausgezahlt",
    "ausgezahlten": "ausgezahlt",
    "ausgezahlter": "ausgezahlt",
    "ausgezahltes": "ausgezahlt",
    "ausgezahnt": "auszahnen",
    "ausgezahnte": "ausgezahnt",
    "ausgezahntem": "ausgezahnt",
    "ausgezahnten": "ausgezahnt",
    "ausgezahnter": "ausgezahnt",
    "ausgezahntere": "ausgezahnt",
    "ausgezahnterem": "ausgezahnt",
    "ausgezahnteren": "ausgezahnt",
    "ausgezahnterer": "ausgezahnt",
    "ausgezahnteres": "ausgezahnt",
    "ausgezahntes": "ausgezahnt",
    "ausgezahnteste": "ausgezahnt",
    "ausgezahntestem": "ausgezahnt",
    "ausgezahntesten": "ausgezahnt",
    "ausgezahntester": "ausgezahnt",
    "ausgezahntestes": "ausgezahnt",
    "ausgezankt": "auszanken",
    "ausgezankte": "ausgezankt",
    "ausgezanktem": "ausgezankt",
    "ausgezankten": "ausgezankt",
    "ausgezankter": "ausgezankt",
    "ausgezanktere": "ausgezankt",
    "ausgezankterem": "ausgezankt",
    "ausgezankteren": "ausgezankt",
    "ausgezankterer": "ausgezankt",
    "ausgezankteres": "ausgezankt",
    "ausgezanktes": "ausgezankt",
    "ausgezankteste": "ausgezankt",
    "ausgezanktestem": "ausgezankt",
    "ausgezanktesten": "ausgezankt",
    "ausgezanktester": "ausgezankt",
    "ausgezanktestes": "ausgezankt",
    "ausgezeichnet": "auszeichnen",
    "ausgezeichnete": "ausgezeichnet",
    "ausgezeichnetem": "ausgezeichnet",
    "ausgezeichneten": "ausgezeichnet",
    "ausgezeichneter": "ausgezeichnet",
    "ausgezeichnetere": "ausgezeichnet",
    "ausgezeichneterem": "ausgezeichnet",
    "ausgezeichneteren": "ausgezeichnet",
    "ausgezeichneterer": "ausgezeichnet",
    "ausgezeichneteres": "ausgezeichnet",
    "ausgezeichnetes": "ausgezeichnet",
    "ausgezeichneteste": "ausgezeichnet",
    "ausgezeichnetestem": "ausgezeichnet",
    "ausgezeichnetesten": "ausgezeichnet",
    "ausgezeichnetester": "ausgezeichnet",
    "ausgezeichnetestes": "ausgezeichnet",
    "ausgeziert": "auszieren",
    "ausgezierte": "ausgeziert",
    "ausgeziertem": "ausgeziert",
    "ausgezierten": "ausgeziert",
    "ausgezierter": "ausgeziert",
    "ausgeziertere": "ausgeziert",
    "ausgezierterem": "ausgeziert",
    "ausgezierteren": "ausgeziert",
    "ausgezierterer": "ausgeziert",
    "ausgezierteres": "ausgeziert",
    "ausgeziertes": "ausgeziert",
    "ausgezierteste": "ausgeziert",
    "ausgeziertestem": "ausgeziert",
    "ausgeziertesten": "ausgeziert",
    "ausgeziertester": "ausgeziert",
    "ausgeziertestes": "ausgeziert",
    "ausgezirkelt": "auszirkeln",
    "ausgezirkelte": "ausgezirkelt",
    "ausgezirkeltem": "ausgezirkelt",
    "ausgezirkelten": "ausgezirkelt",
    "ausgezirkelter": "ausgezirkelt",
    "ausgezirkeltes": "ausgezirkelt",
    "ausgezischt": "auszischen",
    "ausgezischte": "ausgezischt",
    "ausgezischtem": "ausgezischt",
    "ausgezischten": "ausgezischt",
    "ausgezischter": "ausgezischt",
    "ausgezischtes": "ausgezischt",
    "ausgezogen": "ausziehen",
    "ausgezogene": "ausgezogen",
    "ausgezogenem": "ausgezogen",
    "ausgezogenen": "ausgezogen",
    "ausgezogener": "ausgezogen",
    "ausgezogenere": "ausgezogen",
    "ausgezogenerem": "ausgezogen",
    "ausgezogeneren": "ausgezogen",
    "ausgezogenerer": "ausgezogen",
    "ausgezogeneres": "ausgezogen",
    "ausgezogenes": "ausgezogen",
    "ausgezogenste": "ausgezogen",
    "ausgezogenstem": "ausgezogen",
    "ausgezogensten": "ausgezogen",
    "ausgezogenster": "ausgezogen",
    "ausgezogenstes": "ausgezogen",
    "ausgezupft": "auszupfen",
    "ausgezupfte": "ausgezupft",
    "ausgezupftem": "ausgezupft",
    "ausgezupften": "ausgezupft",
    "ausgezupfter": "ausgezupft",
    "ausgezupftes": "ausgezupft",
    "ausgezählt": "auszählen",
    "ausgezähltem": "ausgezählt",
    "ausgezählter": "ausgezählt",
    "ausgezähltes": "ausgezählt",
    "ausgeübt": "ausüben",
    "ausgeübte": "ausgeübt",
    "ausgeübtem": "ausgeübt",
    "ausgeübten": "ausgeübt",
    "ausgeübter": "ausgeübt",
    "ausgeübtes": "ausgeübt",
    "ausgibst": "ausgeben",
    "ausgibt": "ausgeben",
    "ausgiebige": "ausgiebig",
    "ausgiebigem": "ausgiebig",
    "ausgiebigen": "ausgiebig",
    "ausgiebiger": "ausgiebig",
    "ausgiebiges": "ausgiebig",
    "ausgieße": "ausgießen",
    "ausgießend": "ausgießen",
    "ausgießende": "ausgießend",
    "ausgießendem": "ausgießend",
    "ausgießenden": "ausgießend",
    "ausgießender": "ausgießend",
    "ausgießendes": "ausgießend",
    "ausgießest": "ausgießen",
    "ausgießet": "ausgießen",
    "ausgießt": "ausgießen",
    "ausging": "ausgehen",
    "ausginge": "ausgehen",
    "ausgingen": "ausgehen",
    "ausgingest": "ausgehen",
    "ausginget": "ausgehen",
    "ausgingst": "ausgehen",
    "ausgingt": "ausgehen",
    "ausgleichbare": "ausgleichbar",
    "ausgleichbarem": "ausgleichbar",
    "ausgleichbaren": "ausgleichbar",
    "ausgleichbarer": "ausgleichbar",
    "ausgleichbares": "ausgleichbar",
    "ausgleiche": "ausgleichen",
    "ausgleichend": "ausgleichen",
    "ausgleichende": "ausgleichend",
    "ausgleichendem": "ausgleichend",
    "ausgleichenden": "ausgleichend",
    "ausgleichender": "ausgleichend",
    "ausgleichendes": "ausgleichend",
    "ausgleichest": "ausgleichen",
    "ausgleichet": "ausgleichen",
    "ausgleichst": "ausgleichen",
    "ausgleicht": "ausgleichen",
    "ausgleite": "ausgleiten",
    "ausgleitend": "ausgleiten",
    "ausgleitende": "ausgleitend",
    "ausgleitendem": "ausgleitend",
    "ausgleitenden": "ausgleitend",
    "ausgleitender": "ausgleitend",
    "ausgleitendes": "ausgleitend",
    "ausgleitest": "ausgleiten",
    "ausgleitet": "ausgleiten",
    "ausglich": "ausgleichen",
    "ausgliche": "ausgleichen",
    "ausglichen": "ausgleichen",
    "ausglichest": "ausgleichen",
    "ausglichet": "ausgleichen",
    "ausglichst": "ausgleichen",
    "ausglicht": "ausgleichen",
    "ausgliedere": "ausgliedern",
    "ausgliedernd": "ausgliedern",
    "ausgliedernde": "ausgliedernd",
    "ausgliederndem": "ausgliedernd",
    "ausgliedernden": "ausgliedernd",
    "ausgliedernder": "ausgliedernd",
    "ausgliederndes": "ausgliedernd",
    "ausgliederst": "ausgliedern",
    "ausgliedert": "ausgliedern",
    "ausgliederte": "ausgliedern",
    "ausgliederten": "ausgliedern",
    "ausgliedertest": "ausgliedern",
    "ausgliedertet": "ausgliedern",
    "ausglimme": "ausglimmen",
    "ausglimmend": "ausglimmen",
    "ausglimmende": "ausglimmend",
    "ausglimmendem": "ausglimmend",
    "ausglimmenden": "ausglimmend",
    "ausglimmender": "ausglimmend",
    "ausglimmendere": "ausglimmend",
    "ausglimmenderem": "ausglimmend",
    "ausglimmenderen": "ausglimmend",
    "ausglimmenderer": "ausglimmend",
    "ausglimmenderes": "ausglimmend",
    "ausglimmendes": "ausglimmend",
    "ausglimmendste": "ausglimmend",
    "ausglimmendstem": "ausglimmend",
    "ausglimmendsten": "ausglimmend",
    "ausglimmendster": "ausglimmend",
    "ausglimmendstes": "ausglimmend",
    "ausglimmest": "ausglimmen",
    "ausglimmet": "ausglimmen",
    "ausglimmst": "ausglimmen",
    "ausglimmt": "ausglimmen",
    "ausglitsche": "ausglitschen",
    "ausglitschend": "ausglitschen",
    "ausglitschende": "ausglitschend",
    "ausglitschendem": "ausglitschend",
    "ausglitschenden": "ausglitschend",
    "ausglitschender": "ausglitschend",
    "ausglitschendes": "ausglitschend",
    "ausglitschest": "ausglitschen",
    "ausglitschet": "ausglitschen",
    "ausglitschst": "ausglitschen",
    "ausglitscht": "ausglitschen",
    "ausglitschte": "ausglitschen",
    "ausglitschten": "ausglitschen",
    "ausglitschtest": "ausglitschen",
    "ausglitschtet": "ausglitschen",
    "ausglitt": "ausgleiten",
    "ausglitte": "ausgleiten",
    "ausglitten": "ausgleiten",
    "ausglittest": "ausgleiten",
    "ausglittet": "ausgleiten",
    "ausglomm": "ausglimmen",
    "ausglommen": "ausglimmen",
    "ausglommst": "ausglimmen",
    "ausglommt": "ausglimmen",
    "ausglömme": "ausglimmen",
    "ausglömmen": "ausglimmen",
    "ausglömmest": "ausglimmen",
    "ausglömmet": "ausglimmen",
    "ausglühe": "ausglühen",
    "ausglühend": "ausglühen",
    "ausglühende": "ausglühend",
    "ausglühendem": "ausglühend",
    "ausglühenden": "ausglühend",
    "ausglühender": "ausglühend",
    "ausglühendere": "ausglühend",
    "ausglühenderem": "ausglühend",
    "ausglühenderen": "ausglühend",
    "ausglühenderer": "ausglühend",
    "ausglühenderes": "ausglühend",
    "ausglühendes": "ausglühend",
    "ausglühendste": "ausglühend",
    "ausglühendstem": "ausglühend",
    "ausglühendsten": "ausglühend",
    "ausglühendster": "ausglühend",
    "ausglühendstes": "ausglühend",
    "ausglühest": "ausglühen",
    "ausglühet": "ausglühen",
    "ausglühst": "ausglühen",
    "ausglüht": "ausglühen",
    "ausglühte": "ausglühen",
    "ausglühten": "ausglühen",
    "ausglühtest": "ausglühen",
    "ausglühtet": "ausglühen",
    "ausgossen": "ausgießen",
    "ausgoß": "ausgießen",
    "ausgoßt": "ausgießen",
    "ausgrabe": "ausgraben",
    "ausgrabend": "ausgraben",
    "ausgrabende": "ausgrabend",
    "ausgrabendem": "ausgrabend",
    "ausgrabenden": "ausgrabend",
    "ausgrabender": "ausgrabend",
    "ausgrabendes": "ausgrabend",
    "ausgrabest": "ausgraben",
    "ausgrabet": "ausgraben",
    "ausgrabt": "ausgraben",
    "ausgreife": "ausgreifen",
    "ausgreifend": "ausgreifen",
    "ausgreifende": "ausgreifend",
    "ausgreifendem": "ausgreifend",
    "ausgreifenden": "ausgreifend",
    "ausgreifender": "ausgreifend",
    "ausgreifendes": "ausgreifend",
    "ausgreifest": "ausgreifen",
    "ausgreifet": "ausgreifen",
    "ausgreifst": "ausgreifen",
    "ausgreift": "ausgreifen",
    "ausgrenze": "ausgrenzen",
    "ausgrenzend": "ausgrenzen",
    "ausgrenzende": "ausgrenzend",
    "ausgrenzendem": "ausgrenzend",
    "ausgrenzenden": "ausgrenzend",
    "ausgrenzender": "ausgrenzend",
    "ausgrenzendere": "ausgrenzend",
    "ausgrenzenderem": "ausgrenzend",
    "ausgrenzenderen": "ausgrenzend",
    "ausgrenzenderer": "ausgrenzend",
    "ausgrenzenderes": "ausgrenzend",
    "ausgrenzendes": "ausgrenzend",
    "ausgrenzendste": "ausgrenzend",
    "ausgrenzendstem": "ausgrenzend",
    "ausgrenzendsten": "ausgrenzend",
    "ausgrenzendster": "ausgrenzend",
    "ausgrenzendstes": "ausgrenzend",
    "ausgrenzest": "ausgrenzen",
    "ausgrenzet": "ausgrenzen",
    "ausgrenzt": "ausgrenzen",
    "ausgrenzte": "ausgrenzen",
    "ausgrenzten": "ausgrenzen",
    "ausgrenztest": "ausgrenzen",
    "ausgrenztet": "ausgrenzen",
    "ausgriff": "ausgreifen",
    "ausgriffe": "ausgreifen",
    "ausgriffen": "ausgreifen",
    "ausgriffest": "ausgreifen",
    "ausgriffet": "ausgreifen",
    "ausgriffst": "ausgreifen",
    "ausgrifft": "ausgreifen",
    "ausgrub": "ausgraben",
    "ausgruben": "ausgraben",
    "ausgrubst": "ausgraben",
    "ausgrubt": "ausgraben",
    "ausgräbst": "ausgraben",
    "ausgräbt": "ausgraben",
    "ausgrübe": "ausgraben",
    "ausgrüben": "ausgraben",
    "ausgrübest": "ausgraben",
    "ausgrübet": "ausgraben",
    "ausgäbe": "ausgeben",
    "ausgäben": "ausgeben",
    "ausgäbest": "ausgeben",
    "ausgäbet": "ausgeben",
    "ausgösse": "ausgießen",
    "ausgössen": "ausgießen",
    "ausgössest": "ausgießen",
    "ausgösset": "ausgießen",
    "aushake": "aushaken",
    "aushakend": "aushaken",
    "aushakende": "aushakend",
    "aushakendem": "aushakend",
    "aushakenden": "aushakend",
    "aushakender": "aushakend",
    "aushakendes": "aushakend",
    "aushakest": "aushaken",
    "aushaket": "aushaken",
    "aushakst": "aushaken",
    "aushakt": "aushaken",
    "aushakte": "aushaken",
    "aushakten": "aushaken",
    "aushaktest": "aushaken",
    "aushaktet": "aushaken",
    "aushalf": "aushelfen",
    "aushalfen": "aushelfen",
    "aushalfst": "aushelfen",
    "aushalft": "aushelfen",
    "aushalte": "aushalten",
    "aushaltend": "aushalten",
    "aushaltende": "aushaltend",
    "aushaltendem": "aushaltend",
    "aushaltenden": "aushaltend",
    "aushaltender": "aushaltend",
    "aushaltendes": "aushaltend",
    "aushaltest": "aushalten",
    "aushaltet": "aushalten",
    "aushandele": "aushandeln",
    "aushandelnd": "aushandeln",
    "aushandelnde": "aushandelnd",
    "aushandelndem": "aushandelnd",
    "aushandelnden": "aushandelnd",
    "aushandelnder": "aushandelnd",
    "aushandelndes": "aushandelnd",
    "aushandelst": "aushandeln",
    "aushandelt": "aushandeln",
    "aushandelte": "aushandeln",
    "aushandelten": "aushandeln",
    "aushandeltest": "aushandeln",
    "aushandeltet": "aushandeln",
    "aushandle": "aushandeln",
    "ausharrende": "ausharrend",
    "ausharrendem": "ausharrend",
    "ausharrenden": "ausharrend",
    "ausharrender": "ausharrend",
    "ausharrendere": "ausharrend",
    "ausharrenderem": "ausharrend",
    "ausharrenderen": "ausharrend",
    "ausharrenderer": "ausharrend",
    "ausharrenderes": "ausharrend",
    "ausharrendes": "ausharrend",
    "ausharrendste": "ausharrend",
    "ausharrendstem": "ausharrend",
    "ausharrendsten": "ausharrend",
    "ausharrendster": "ausharrend",
    "ausharrendstes": "ausharrend",
    "aushauche": "aushauchen",
    "aushauchend": "aushauchen",
    "aushauchende": "aushauchend",
    "aushauchendem": "aushauchend",
    "aushauchenden": "aushauchend",
    "aushauchender": "aushauchend",
    "aushauchendes": "aushauchend",
    "aushauchest": "aushauchen",
    "aushauchet": "aushauchen",
    "aushauchst": "aushauchen",
    "aushaucht": "aushauchen",
    "aushauchte": "aushauchen",
    "aushauchten": "aushauchen",
    "aushauchtest": "aushauchen",
    "aushauchtet": "aushauchen",
    "aushaue": "aushauen",
    "aushauend": "aushauen",
    "aushauende": "aushauend",
    "aushauendem": "aushauend",
    "aushauenden": "aushauend",
    "aushauender": "aushauend",
    "aushauendes": "aushauend",
    "aushauest": "aushauen",
    "aushauet": "aushauen",
    "aushaust": "aushauen",
    "aushaut": "aushauen",
    "aushaute": "aushauen",
    "aushauten": "aushauen",
    "aushautest": "aushauen",
    "aushautet": "aushauen",
    "aushebe": "ausheben",
    "aushebend": "ausheben",
    "aushebende": "aushebend",
    "aushebendem": "aushebend",
    "aushebenden": "aushebend",
    "aushebender": "aushebend",
    "aushebendes": "aushebend",
    "aushebest": "ausheben",
    "aushebet": "ausheben",
    "aushebst": "ausheben",
    "aushebt": "ausheben",
    "ausheile": "ausheilen",
    "ausheilend": "ausheilen",
    "ausheilende": "ausheilend",
    "ausheilendem": "ausheilend",
    "ausheilenden": "ausheilend",
    "ausheilender": "ausheilend",
    "ausheilendere": "ausheilend",
    "ausheilenderem": "ausheilend",
    "ausheilenderen": "ausheilend",
    "ausheilenderer": "ausheilend",
    "ausheilenderes": "ausheilend",
    "ausheilendes": "ausheilend",
    "ausheilendste": "ausheilend",
    "ausheilendstem": "ausheilend",
    "ausheilendsten": "ausheilend",
    "ausheilendster": "ausheilend",
    "ausheilendstes": "ausheilend",
    "ausheilest": "ausheilen",
    "ausheilet": "ausheilen",
    "ausheilst": "ausheilen",
    "ausheilt": "ausheilen",
    "ausheilte": "ausheilen",
    "ausheilten": "ausheilen",
    "ausheiltest": "ausheilen",
    "ausheiltet": "ausheilen",
    "aushelfe": "aushelfen",
    "aushelfend": "aushelfen",
    "aushelfende": "aushelfend",
    "aushelfendem": "aushelfend",
    "aushelfenden": "aushelfend",
    "aushelfender": "aushelfend",
    "aushelfendes": "aushelfend",
    "aushelfest": "aushelfen",
    "aushelfet": "aushelfen",
    "aushelft": "aushelfen",
    "aushielt": "aushalten",
    "aushielte": "aushalten",
    "aushielten": "aushalten",
    "aushieltest": "aushalten",
    "aushieltet": "aushalten",
    "aushilfst": "aushelfen",
    "aushilft": "aushelfen",
    "aushing": "aushängen",
    "aushinge": "aushängen",
    "aushingen": "aushängen",
    "aushingest": "aushängen",
    "aushinget": "aushängen",
    "aushingst": "aushängen",
    "aushingt": "aushängen",
    "aushob": "ausheben",
    "aushoben": "ausheben",
    "aushobst": "ausheben",
    "aushobt": "ausheben",
    "aushole": "ausholen",
    "ausholend": "ausholen",
    "ausholende": "ausholend",
    "ausholendem": "ausholend",
    "ausholenden": "ausholend",
    "ausholender": "ausholend",
    "ausholendes": "ausholend",
    "ausholest": "ausholen",
    "ausholet": "ausholen",
    "ausholst": "ausholen",
    "ausholt": "ausholen",
    "ausholte": "ausholen",
    "ausholten": "ausholen",
    "ausholtest": "ausholen",
    "ausholtet": "ausholen",
    "ausholze": "ausholzen",
    "ausholzend": "ausholzen",
    "ausholzende": "ausholzend",
    "ausholzendem": "ausholzend",
    "ausholzenden": "ausholzend",
    "ausholzender": "ausholzend",
    "ausholzendes": "ausholzend",
    "ausholzest": "ausholzen",
    "ausholzet": "ausholzen",
    "ausholzt": "ausholzen",
    "ausholzte": "ausholzen",
    "ausholzten": "ausholzen",
    "ausholztest": "ausholzen",
    "ausholztet": "ausholzen",
    "aushorche": "aushorchen",
    "aushorchend": "aushorchen",
    "aushorchende": "aushorchend",
    "aushorchendem": "aushorchend",
    "aushorchenden": "aushorchend",
    "aushorchender": "aushorchend",
    "aushorchendere": "aushorchend",
    "aushorchenderem": "aushorchend",
    "aushorchenderen": "aushorchend",
    "aushorchenderer": "aushorchend",
    "aushorchenderes": "aushorchend",
    "aushorchendes": "aushorchend",
    "aushorchendste": "aushorchend",
    "aushorchendstem": "aushorchend",
    "aushorchendsten": "aushorchend",
    "aushorchendster": "aushorchend",
    "aushorchendstes": "aushorchend",
    "aushorchest": "aushorchen",
    "aushorchet": "aushorchen",
    "aushorchst": "aushorchen",
    "aushorcht": "aushorchen",
    "aushorchte": "aushorchen",
    "aushorchten": "aushorchen",
    "aushorchtest": "aushorchen",
    "aushorchtet": "aushorchen",
    "aushungere": "aushungern",
    "aushungernd": "aushungern",
    "aushungernde": "aushungernd",
    "aushungerndem": "aushungernd",
    "aushungernden": "aushungernd",
    "aushungernder": "aushungernd",
    "aushungerndere": "aushungernd",
    "aushungernderem": "aushungernd",
    "aushungernderen": "aushungernd",
    "aushungernderer": "aushungernd",
    "aushungernderes": "aushungernd",
    "aushungerndes": "aushungernd",
    "aushungerndste": "aushungernd",
    "aushungerndstem": "aushungernd",
    "aushungerndsten": "aushungernd",
    "aushungerndster": "aushungernd",
    "aushungerndstes": "aushungernd",
    "aushungerst": "aushungern",
    "aushungert": "aushungern",
    "aushungerte": "aushungern",
    "aushungerten": "aushungern",
    "aushungertest": "aushungern",
    "aushungertet": "aushungern",
    "aushuste": "aushusten",
    "aushustend": "aushusten",
    "aushustende": "aushustend",
    "aushustendem": "aushustend",
    "aushustenden": "aushustend",
    "aushustender": "aushustend",
    "aushustendes": "aushustend",
    "aushustest": "aushusten",
    "aushustet": "aushusten",
    "aushustete": "aushusten",
    "aushusteten": "aushusten",
    "aushustetest": "aushusten",
    "aushustetet": "aushusten",
    "aushälfe": "aushelfen",
    "aushälfen": "aushelfen",
    "aushälfest": "aushelfen",
    "aushälfet": "aushelfen",
    "aushält": "aushalten",
    "aushältst": "aushalten",
    "aushändige": "aushändigen",
    "aushändigend": "aushändigen",
    "aushändigende": "aushändigend",
    "aushändigendem": "aushändigend",
    "aushändigenden": "aushändigend",
    "aushändigender": "aushändigend",
    "aushändigendes": "aushändigend",
    "aushändigest": "aushändigen",
    "aushändiget": "aushändigen",
    "aushändigst": "aushändigen",
    "aushändigt": "aushändigen",
    "aushändigte": "aushändigen",
    "aushändigten": "aushändigen",
    "aushändigtest": "aushändigen",
    "aushändigtet": "aushändigen",
    "aushängend": "aushängen",
    "aushängende": "aushängend",
    "aushängendem": "aushängend",
    "aushängenden": "aushängend",
    "aushängender": "aushängend",
    "aushängendere": "aushängend",
    "aushängenderem": "aushängend",
    "aushängenderen": "aushängend",
    "aushängenderer": "aushängend",
    "aushängenderes": "aushängend",
    "aushängendes": "aushängend",
    "aushängendste": "aushängend",
    "aushängendstem": "aushängend",
    "aushängendsten": "aushängend",
    "aushängendster": "aushängend",
    "aushängendstes": "aushängend",
    "aushängest": "aushängen",
    "aushänget": "aushängen",
    "aushängst": "aushängen",
    "aushängt": "aushängen",
    "aushängte": "aushängen",
    "aushängten": "aushängen",
    "aushängtest": "aushängen",
    "aushängtet": "aushängen",
    "aushärte": "aushärten",
    "aushärtend": "aushärten",
    "aushärtende": "aushärtend",
    "aushärtendem": "aushärtend",
    "aushärtenden": "aushärtend",
    "aushärtender": "aushärtend",
    "aushärtendere": "aushärtend",
    "aushärtenderem": "aushärtend",
    "aushärtenderen": "aushärtend",
    "aushärtenderer": "aushärtend",
    "aushärtenderes": "aushärtend",
    "aushärtendes": "aushärtend",
    "aushärtendste": "aushärtend",
    "aushärtendstem": "aushärtend",
    "aushärtendsten": "aushärtend",
    "aushärtendster": "aushärtend",
    "aushärtendstes": "aushärtend",
    "aushärtest": "aushärten",
    "aushärtet": "aushärten",
    "aushärtete": "aushärten",
    "aushärteten": "aushärten",
    "aushärtetest": "aushärten",
    "aushärtetet": "aushärten",
    "aushäusige": "aushäusig",
    "aushäusigem": "aushäusig",
    "aushäusigen": "aushäusig",
    "aushäusiger": "aushäusig",
    "aushäusiges": "aushäusig",
    "aushöbe": "ausheben",
    "aushöben": "ausheben",
    "aushöbest": "ausheben",
    "aushöbet": "ausheben",
    "aushöhle": "aushöhlen",
    "aushöhlend": "aushöhlen",
    "aushöhlende": "aushöhlend",
    "aushöhlendem": "aushöhlend",
    "aushöhlenden": "aushöhlend",
    "aushöhlender": "aushöhlend",
    "aushöhlendere": "aushöhlend",
    "aushöhlenderem": "aushöhlend",
    "aushöhlenderen": "aushöhlend",
    "aushöhlenderer": "aushöhlend",
    "aushöhlenderes": "aushöhlend",
    "aushöhlendes": "aushöhlend",
    "aushöhlendste": "aushöhlend",
    "aushöhlendstem": "aushöhlend",
    "aushöhlendsten": "aushöhlend",
    "aushöhlendster": "aushöhlend",
    "aushöhlendstes": "aushöhlend",
    "aushöhlest": "aushöhlen",
    "aushöhlet": "aushöhlen",
    "aushöhlst": "aushöhlen",
    "aushöhlt": "aushöhlen",
    "aushöhlte": "aushöhlen",
    "aushöhlten": "aushöhlen",
    "aushöhltest": "aushöhlen",
    "aushöhltet": "aushöhlen",
    "aushülse": "aushülsen",
    "aushülsend": "aushülsen",
    "aushülsende": "aushülsend",
    "aushülsendem": "aushülsend",
    "aushülsenden": "aushülsend",
    "aushülsender": "aushülsend",
    "aushülsendere": "aushülsend",
    "aushülsenderem": "aushülsend",
    "aushülsenderen": "aushülsend",
    "aushülsenderer": "aushülsend",
    "aushülsenderes": "aushülsend",
    "aushülsendes": "aushülsend",
    "aushülsendste": "aushülsend",
    "aushülsendstem": "aushülsend",
    "aushülsendsten": "aushülsend",
    "aushülsendster": "aushülsend",
    "aushülsendstes": "aushülsend",
    "aushülsest": "aushülsen",
    "aushülset": "aushülsen",
    "aushülst": "aushülsen",
    "aushülste": "aushülsen",
    "aushülsten": "aushülsen",
    "aushülstest": "aushülsen",
    "aushülstet": "aushülsen",
    "ausißt": "ausessen",
    "auskam": "auskommen",
    "auskamen": "auskommen",
    "auskamst": "auskommen",
    "auskamt": "auskommen",
    "auskannte": "auskennen",
    "auskannten": "auskennen",
    "auskanntest": "auskennen",
    "auskanntet": "auskennen",
    "auskegele": "auskegeln",
    "auskegelnd": "auskegeln",
    "auskegelnde": "auskegelnd",
    "auskegelndem": "auskegelnd",
    "auskegelnden": "auskegelnd",
    "auskegelnder": "auskegelnd",
    "auskegelndes": "auskegelnd",
    "auskegelst": "auskegeln",
    "auskegelt": "auskegeln",
    "auskegelte": "auskegeln",
    "auskegelten": "auskegeln",
    "auskegeltest": "auskegeln",
    "auskegeltet": "auskegeln",
    "auskegle": "auskegeln",
    "auskehre": "auskehren",
    "auskehrend": "auskehren",
    "auskehrende": "auskehrend",
    "auskehrendem": "auskehrend",
    "auskehrenden": "auskehrend",
    "auskehrender": "auskehrend",
    "auskehrendes": "auskehrend",
    "auskehrest": "auskehren",
    "auskehret": "auskehren",
    "auskehrst": "auskehren",
    "auskehrt": "auskehren",
    "auskehrte": "auskehren",
    "auskehrten": "auskehren",
    "auskehrtest": "auskehren",
    "auskehrtet": "auskehren",
    "auskeile": "auskeilen",
    "auskeilend": "auskeilen",
    "auskeilende": "auskeilend",
    "auskeilendem": "auskeilend",
    "auskeilenden": "auskeilend",
    "auskeilender": "auskeilend",
    "auskeilendere": "auskeilend",
    "auskeilenderem": "auskeilend",
    "auskeilenderen": "auskeilend",
    "auskeilenderer": "auskeilend",
    "auskeilenderes": "auskeilend",
    "auskeilendes": "auskeilend",
    "auskeilendste": "auskeilend",
    "auskeilendstem": "auskeilend",
    "auskeilendsten": "auskeilend",
    "auskeilendster": "auskeilend",
    "auskeilendstes": "auskeilend",
    "auskeilest": "auskeilen",
    "auskeilet": "auskeilen",
    "auskeilst": "auskeilen",
    "auskeilt": "auskeilen",
    "auskeilte": "auskeilen",
    "auskeilten": "auskeilen",
    "auskeiltest": "auskeilen",
    "auskeiltet": "auskeilen",
    "auskeime": "auskeimen",
    "auskeimend": "auskeimen",
    "auskeimende": "auskeimend",
    "auskeimendem": "auskeimend",
    "auskeimenden": "auskeimend",
    "auskeimender": "auskeimend",
    "auskeimendere": "auskeimend",
    "auskeimenderem": "auskeimend",
    "auskeimenderen": "auskeimend",
    "auskeimenderer": "auskeimend",
    "auskeimenderes": "auskeimend",
    "auskeimendes": "auskeimend",
    "auskeimendste": "auskeimend",
    "auskeimendstem": "auskeimend",
    "auskeimendsten": "auskeimend",
    "auskeimendster": "auskeimend",
    "auskeimendstes": "auskeimend",
    "auskeimest": "auskeimen",
    "auskeimet": "auskeimen",
    "auskeimst": "auskeimen",
    "auskeimt": "auskeimen",
    "auskeimte": "auskeimen",
    "auskeimten": "auskeimen",
    "auskeimtest": "auskeimen",
    "auskeimtet": "auskeimen",
    "auskeltere": "auskeltern",
    "auskelternd": "auskeltern",
    "auskelternde": "auskelternd",
    "auskelterndem": "auskelternd",
    "auskelternden": "auskelternd",
    "auskelternder": "auskelternd",
    "auskelterndere": "auskelternd",
    "auskelternderem": "auskelternd",
    "auskelternderen": "auskelternd",
    "auskelternderer": "auskelternd",
    "auskelternderes": "auskelternd",
    "auskelterndes": "auskelternd",
    "auskelterndste": "auskelternd",
    "auskelterndstem": "auskelternd",
    "auskelterndsten": "auskelternd",
    "auskelterndster": "auskelternd",
    "auskelterndstes": "auskelternd",
    "auskelterst": "auskeltern",
    "auskeltert": "auskeltern",
    "auskelterte": "auskeltern",
    "auskelterten": "auskeltern",
    "auskeltertest": "auskeltern",
    "auskeltertet": "auskeltern",
    "auskenne": "auskennen",
    "auskennend": "auskennen",
    "auskennende": "auskennend",
    "auskennendem": "auskennend",
    "auskennenden": "auskennend",
    "auskennender": "auskennend",
    "auskennendes": "auskennend",
    "auskennest": "auskennen",
    "auskennet": "auskennen",
    "auskennst": "auskennen",
    "auskennt": "auskennen",
    "auskerne": "auskernen",
    "auskernend": "auskernen",
    "auskernende": "auskernend",
    "auskernendem": "auskernend",
    "auskernenden": "auskernend",
    "auskernender": "auskernend",
    "auskernendere": "auskernend",
    "auskernenderem": "auskernend",
    "auskernenderen": "auskernend",
    "auskernenderer": "auskernend",
    "auskernenderes": "auskernend",
    "auskernendes": "auskernend",
    "auskernendste": "auskernend",
    "auskernendstem": "auskernend",
    "auskernendsten": "auskernend",
    "auskernendster": "auskernend",
    "auskernendstes": "auskernend",
    "auskernest": "auskernen",
    "auskernet": "auskernen",
    "auskernst": "auskernen",
    "auskernt": "auskernen",
    "auskernte": "auskernen",
    "auskernten": "auskernen",
    "auskerntest": "auskernen",
    "auskerntet": "auskernen",
    "ausklammere": "ausklammern",
    "ausklammernd": "ausklammern",
    "ausklammernde": "ausklammernd",
    "ausklammerndem": "ausklammernd",
    "ausklammernden": "ausklammernd",
    "ausklammernder": "ausklammernd",
    "ausklammerndes": "ausklammernd",
    "ausklammerst": "ausklammern",
    "ausklammert": "ausklammern",
    "ausklammerte": "ausklammern",
    "ausklammerten": "ausklammern",
    "ausklammertest": "ausklammern",
    "ausklammertet": "ausklammern",
    "ausklamüsere": "ausklamüsern",
    "ausklamüsernd": "ausklamüsern",
    "ausklamüsernde": "ausklamüsernd",
    "ausklamüserndem": "ausklamüsernd",
    "ausklamüsernden": "ausklamüsernd",
    "ausklamüsernder": "ausklamüsernd",
    "ausklamüserndere": "ausklamüsernd",
    "ausklamüsernderem": "ausklamüsernd",
    "ausklamüsernderen": "ausklamüsernd",
    "ausklamüsernderer": "ausklamüsernd",
    "ausklamüsernderes": "ausklamüsernd",
    "ausklamüserndes": "ausklamüsernd",
    "ausklamüserndste": "ausklamüsernd",
    "ausklamüserndstem": "ausklamüsernd",
    "ausklamüserndsten": "ausklamüsernd",
    "ausklamüserndster": "ausklamüsernd",
    "ausklamüserndstes": "ausklamüsernd",
    "ausklamüserst": "ausklamüsern",
    "ausklamüsert": "ausklamüsern",
    "ausklamüserte": "ausklamüsern",
    "ausklamüsertem": "ausklamüsert",
    "ausklamüserten": "ausklamüsern",
    "ausklamüserter": "ausklamüsert",
    "ausklamüsertere": "ausklamüsert",
    "ausklamüserterem": "ausklamüsert",
    "ausklamüserteren": "ausklamüsert",
    "ausklamüserterer": "ausklamüsert",
    "ausklamüserteres": "ausklamüsert",
    "ausklamüsertes": "ausklamüsert",
    "ausklamüsertest": "ausklamüsern",
    "ausklamüserteste": "ausklamüsert",
    "ausklamüsertestem": "ausklamüsert",
    "ausklamüsertesten": "ausklamüsert",
    "ausklamüsertester": "ausklamüsert",
    "ausklamüsertestes": "ausklamüsert",
    "ausklamüsertet": "ausklamüsern",
    "ausklang": "ausklingen",
    "ausklangen": "ausklingen",
    "ausklangst": "ausklingen",
    "ausklangt": "ausklingen",
    "ausklebe": "auskleben",
    "ausklebend": "auskleben",
    "ausklebende": "ausklebend",
    "ausklebendem": "ausklebend",
    "ausklebenden": "ausklebend",
    "ausklebender": "ausklebend",
    "ausklebendes": "ausklebend",
    "ausklebest": "auskleben",
    "ausklebet": "auskleben",
    "ausklebst": "auskleben",
    "ausklebt": "auskleben",
    "ausklebte": "auskleben",
    "ausklebten": "auskleben",
    "ausklebtest": "auskleben",
    "ausklebtet": "auskleben",
    "auskleide": "auskleiden",
    "auskleidend": "auskleiden",
    "auskleidende": "auskleidend",
    "auskleidendem": "auskleidend",
    "auskleidenden": "auskleidend",
    "auskleidender": "auskleidend",
    "auskleidendes": "auskleidend",
    "auskleidest": "auskleiden",
    "auskleidet": "auskleiden",
    "auskleidete": "auskleiden",
    "auskleideten": "auskleiden",
    "auskleidetest": "auskleiden",
    "auskleidetet": "auskleiden",
    "ausklinge": "ausklingen",
    "ausklingend": "ausklingen",
    "ausklingende": "ausklingend",
    "ausklingendem": "ausklingend",
    "ausklingenden": "ausklingend",
    "ausklingender": "ausklingend",
    "ausklingendes": "ausklingend",
    "ausklingest": "ausklingen",
    "ausklinget": "ausklingen",
    "ausklingst": "ausklingen",
    "ausklingt": "ausklingen",
    "ausklinke": "ausklinken",
    "ausklinkend": "ausklinken",
    "ausklinkende": "ausklinkend",
    "ausklinkendem": "ausklinkend",
    "ausklinkenden": "ausklinkend",
    "ausklinkender": "ausklinkend",
    "ausklinkendes": "ausklinkend",
    "ausklinkest": "ausklinken",
    "ausklinket": "ausklinken",
    "ausklinkst": "ausklinken",
    "ausklinkt": "ausklinken",
    "ausklinkte": "ausklinken",
    "ausklinkten": "ausklinken",
    "ausklinktest": "ausklinken",
    "ausklinktet": "ausklinken",
    "ausklopfe": "ausklopfen",
    "ausklopfend": "ausklopfen",
    "ausklopfende": "ausklopfend",
    "ausklopfendem": "ausklopfend",
    "ausklopfenden": "ausklopfend",
    "ausklopfender": "ausklopfend",
    "ausklopfendes": "ausklopfend",
    "ausklopfest": "ausklopfen",
    "ausklopfet": "ausklopfen",
    "ausklopfst": "ausklopfen",
    "ausklopft": "ausklopfen",
    "ausklopfte": "ausklopfen",
    "ausklopften": "ausklopfen",
    "ausklopftest": "ausklopfen",
    "ausklopftet": "ausklopfen",
    "ausklängest": "ausklingen",
    "ausklänget": "ausklingen",
    "ausklügele": "ausklügeln",
    "ausklügelnd": "ausklügeln",
    "ausklügelnde": "ausklügelnd",
    "ausklügelndem": "ausklügelnd",
    "ausklügelnden": "ausklügelnd",
    "ausklügelnder": "ausklügelnd",
    "ausklügelndere": "ausklügelnd",
    "ausklügelnderem": "ausklügelnd",
    "ausklügelnderen": "ausklügelnd",
    "ausklügelnderer": "ausklügelnd",
    "ausklügelnderes": "ausklügelnd",
    "ausklügelndes": "ausklügelnd",
    "ausklügelndste": "ausklügelnd",
    "ausklügelndstem": "ausklügelnd",
    "ausklügelndsten": "ausklügelnd",
    "ausklügelndster": "ausklügelnd",
    "ausklügelndstes": "ausklügelnd",
    "ausklügelst": "ausklügeln",
    "ausklügelt": "ausklügeln",
    "ausklügelte": "ausklügeln",
    "ausklügelten": "ausklügeln",
    "ausklügeltest": "ausklügeln",
    "ausklügeltet": "ausklügeln",
    "ausklügle": "ausklügeln",
    "auskneife": "auskneifen",
    "auskneifend": "auskneifen",
    "auskneifende": "auskneifend",
    "auskneifendem": "auskneifend",
    "auskneifenden": "auskneifend",
    "auskneifender": "auskneifend",
    "auskneifendere": "auskneifend",
    "auskneifenderem": "auskneifend",
    "auskneifenderen": "auskneifend",
    "auskneifenderer": "auskneifend",
    "auskneifenderes": "auskneifend",
    "auskneifendes": "auskneifend",
    "auskneifendste": "auskneifend",
    "auskneifendstem": "auskneifend",
    "auskneifendsten": "auskneifend",
    "auskneifendster": "auskneifend",
    "auskneifendstes": "auskneifend",
    "auskneifest": "auskneifen",
    "auskneifet": "auskneifen",
    "auskneifst": "auskneifen",
    "auskneift": "auskneifen",
    "auskniff": "auskneifen",
    "auskniffe": "auskneifen",
    "auskniffen": "auskneifen",
    "auskniffest": "auskneifen",
    "auskniffet": "auskneifen",
    "auskniffst": "auskneifen",
    "ausknifft": "auskneifen",
    "ausknipse": "ausknipsen",
    "ausknipsend": "ausknipsen",
    "ausknipsende": "ausknipsend",
    "ausknipsendem": "ausknipsend",
    "ausknipsenden": "ausknipsend",
    "ausknipsender": "ausknipsend",
    "ausknipsendes": "ausknipsend",
    "ausknipsest": "ausknipsen",
    "ausknipset": "ausknipsen",
    "ausknipst": "ausknipsen",
    "ausknipste": "ausknipsen",
    "ausknipsten": "ausknipsen",
    "ausknipstest": "ausknipsen",
    "ausknipstet": "ausknipsen",
    "ausknobele": "ausknobeln",
    "ausknobelnd": "ausknobeln",
    "ausknobelnde": "ausknobelnd",
    "ausknobelndem": "ausknobelnd",
    "ausknobelnden": "ausknobelnd",
    "ausknobelnder": "ausknobelnd",
    "ausknobelndere": "ausknobelnd",
    "ausknobelnderem": "ausknobelnd",
    "ausknobelnderen": "ausknobelnd",
    "ausknobelnderer": "ausknobelnd",
    "ausknobelnderes": "ausknobelnd",
    "ausknobelndes": "ausknobelnd",
    "ausknobelndste": "ausknobelnd",
    "ausknobelndstem": "ausknobelnd",
    "ausknobelndsten": "ausknobelnd",
    "ausknobelndster": "ausknobelnd",
    "ausknobelndstes": "ausknobelnd",
    "ausknobelst": "ausknobeln",
    "ausknobelt": "ausknobeln",
    "ausknobelte": "ausknobeln",
    "ausknobelten": "ausknobeln",
    "ausknobeltest": "ausknobeln",
    "ausknobeltet": "ausknobeln",
    "ausknoble": "ausknobeln",
    "auskoche": "auskochen",
    "auskochend": "auskochen",
    "auskochende": "auskochend",
    "auskochendem": "auskochend",
    "auskochenden": "auskochend",
    "auskochender": "auskochend",
    "auskochendere": "auskochend",
    "auskochenderem": "auskochend",
    "auskochenderen": "auskochend",
    "auskochenderer": "auskochend",
    "auskochenderes": "auskochend",
    "auskochendes": "auskochend",
    "auskochendste": "auskochend",
    "auskochendstem": "auskochend",
    "auskochendsten": "auskochend",
    "auskochendster": "auskochend",
    "auskochendstes": "auskochend",
    "auskochest": "auskochen",
    "auskochet": "auskochen",
    "auskochst": "auskochen",
    "auskocht": "auskochen",
    "auskochte": "auskochen",
    "auskochten": "auskochen",
    "auskochtest": "auskochen",
    "auskochtet": "auskochen",
    "auskomme": "auskommen",
    "auskommend": "auskommen",
    "auskommende": "auskommend",
    "auskommendem": "auskommend",
    "auskommenden": "auskommend",
    "auskommender": "auskommend",
    "auskommendes": "auskommend",
    "auskommest": "auskommen",
    "auskommet": "auskommen",
    "auskommst": "auskommen",
    "auskommt": "auskommen",
    "auskoste": "auskosten",
    "auskostend": "auskosten",
    "auskostende": "auskostend",
    "auskostendem": "auskostend",
    "auskostenden": "auskostend",
    "auskostender": "auskostend",
    "auskostendere": "auskostend",
    "auskostenderem": "auskostend",
    "auskostenderen": "auskostend",
    "auskostenderer": "auskostend",
    "auskostenderes": "auskostend",
    "auskostendes": "auskostend",
    "auskostendste": "auskostend",
    "auskostendstem": "auskostend",
    "auskostendsten": "auskostend",
    "auskostendster": "auskostend",
    "auskostendstes": "auskostend",
    "auskostest": "auskosten",
    "auskostet": "auskosten",
    "auskostete": "auskosten",
    "auskosteten": "auskosten",
    "auskostetest": "auskosten",
    "auskostetet": "auskosten",
    "auskrame": "auskramen",
    "auskramend": "auskramen",
    "auskramende": "auskramend",
    "auskramendem": "auskramend",
    "auskramenden": "auskramend",
    "auskramender": "auskramend",
    "auskramendes": "auskramend",
    "auskramest": "auskramen",
    "auskramet": "auskramen",
    "auskramst": "auskramen",
    "auskramt": "auskramen",
    "auskramte": "auskramen",
    "auskramten": "auskramen",
    "auskramtest": "auskramen",
    "auskramtet": "auskramen",
    "auskratze": "auskratzen",
    "auskratzend": "auskratzen",
    "auskratzende": "auskratzend",
    "auskratzendem": "auskratzend",
    "auskratzenden": "auskratzend",
    "auskratzender": "auskratzend",
    "auskratzendere": "auskratzend",
    "auskratzenderem": "auskratzend",
    "auskratzenderen": "auskratzend",
    "auskratzenderer": "auskratzend",
    "auskratzenderes": "auskratzend",
    "auskratzendes": "auskratzend",
    "auskratzendste": "auskratzend",
    "auskratzendstem": "auskratzend",
    "auskratzendsten": "auskratzend",
    "auskratzendster": "auskratzend",
    "auskratzendstes": "auskratzend",
    "auskratzest": "auskratzen",
    "auskratzet": "auskratzen",
    "auskratzt": "auskratzen",
    "auskratzte": "auskratzen",
    "auskratzten": "auskratzen",
    "auskratztest": "auskratzen",
    "auskratztet": "auskratzen",
    "auskrieche": "auskriechen",
    "auskriechend": "auskriechen",
    "auskriechende": "auskriechend",
    "auskriechendem": "auskriechend",
    "auskriechenden": "auskriechend",
    "auskriechender": "auskriechend",
    "auskriechendes": "auskriechend",
    "auskriechest": "auskriechen",
    "auskriechet": "auskriechen",
    "auskriechst": "auskriechen",
    "auskriecht": "auskriechen",
    "auskristallisieren": "auskristallisiere",
    "auskristallisierend": "auskristallisiere",
    "auskristallisierende": "auskristallisierend",
    "auskristallisierendem": "auskristallisierend",
    "auskristallisierenden": "auskristallisierend",
    "auskristallisierender": "auskristallisierend",
    "auskristallisierendes": "auskristallisierend",
    "auskristallisierest": "auskristallisiere",
    "auskristallisieret": "auskristallisiere",
    "auskristallisierst": "auskristallisiere",
    "auskristallisiert": "auskristallisiere",
    "auskristallisierte": "auskristallisiere",
    "auskristallisiertem": "auskristallisiert",
    "auskristallisierten": "auskristallisiere",
    "auskristallisierter": "auskristallisiert",
    "auskristallisiertes": "auskristallisiert",
    "auskristallisiertest": "auskristallisiere",
    "auskristallisiertet": "auskristallisiere",
    "auskroch": "auskriechen",
    "auskrochen": "auskriechen",
    "auskrochst": "auskriechen",
    "auskrocht": "auskriechen",
    "auskröche": "auskriechen",
    "auskröchen": "auskriechen",
    "auskröchest": "auskriechen",
    "auskröchet": "auskriechen",
    "auskugele": "auskugeln",
    "auskugelnd": "auskugeln",
    "auskugelnde": "auskugelnd",
    "auskugelndem": "auskugelnd",
    "auskugelnden": "auskugelnd",
    "auskugelnder": "auskugelnd",
    "auskugelndes": "auskugelnd",
    "auskugelst": "auskugeln",
    "auskugelt": "auskugeln",
    "auskugelte": "auskugeln",
    "auskugelten": "auskugeln",
    "auskugeltest": "auskugeln",
    "auskugeltet": "auskugeln",
    "auskugle": "auskugeln",
    "auskundschafte": "auskundschaften",
    "auskundschaftend": "auskundschaften",
    "auskundschaftende": "auskundschaftend",
    "auskundschaftendem": "auskundschaftend",
    "auskundschaftenden": "auskundschaftend",
    "auskundschaftender": "auskundschaftend",
    "auskundschaftendes": "auskundschaftend",
    "auskundschaftest": "auskundschaften",
    "auskundschaftet": "auskundschaften",
    "auskundschaftete": "auskundschaften",
    "auskundschafteten": "auskundschaften",
    "auskundschaftetest": "auskundschaften",
    "auskundschaftetet": "auskundschaften",
    "auskuppele": "auskuppeln",
    "auskuppelnd": "auskuppeln",
    "auskuppelnde": "auskuppelnd",
    "auskuppelndem": "auskuppelnd",
    "auskuppelnden": "auskuppelnd",
    "auskuppelnder": "auskuppelnd",
    "auskuppelndes": "auskuppelnd",
    "auskuppelst": "auskuppeln",
    "auskuppelt": "auskuppeln",
    "auskuppelte": "auskuppeln",
    "auskuppelten": "auskuppeln",
    "auskuppeltest": "auskuppeln",
    "auskuppeltet": "auskuppeln",
    "auskupple": "auskuppeln",
    "auskuriere": "auskurieren",
    "auskurierend": "auskurieren",
    "auskurierende": "auskurierend",
    "auskurierendem": "auskurierend",
    "auskurierenden": "auskurierend",
    "auskurierender": "auskurierend",
    "auskurierendes": "auskurierend",
    "auskurierest": "auskurieren",
    "auskurieret": "auskurieren",
    "auskurierst": "auskurieren",
    "auskuriert": "auskurieren",
    "auskurierte": "auskurieren",
    "auskuriertem": "auskuriert",
    "auskurierten": "auskurieren",
    "auskurierter": "auskuriert",
    "auskuriertes": "auskuriert",
    "auskuriertest": "auskurieren",
    "auskuriertet": "auskurieren",
    "auskäme": "auskommen",
    "auskämen": "auskommen",
    "auskämest": "auskommen",
    "auskämet": "auskommen",
    "auskämme": "auskämmen",
    "auskämmend": "auskämmen",
    "auskämmende": "auskämmend",
    "auskämmendem": "auskämmend",
    "auskämmenden": "auskämmend",
    "auskämmender": "auskämmend",
    "auskämmendes": "auskämmend",
    "auskämmest": "auskämmen",
    "auskämmet": "auskämmen",
    "auskämmst": "auskämmen",
    "auskämmt": "auskämmen",
    "auskämmte": "auskämmen",
    "auskämmten": "auskämmen",
    "auskämmtest": "auskämmen",
    "auskämmtet": "auskämmen",
    "auskämpfe": "auskämpfen",
    "auskämpfend": "auskämpfen",
    "auskämpfende": "auskämpfend",
    "auskämpfendem": "auskämpfend",
    "auskämpfenden": "auskämpfend",
    "auskämpfender": "auskämpfend",
    "auskämpfendes": "auskämpfend",
    "auskämpfest": "auskämpfen",
    "auskämpfet": "auskämpfen",
    "auskämpfst": "auskämpfen",
    "auskämpft": "auskämpfen",
    "auskämpfte": "auskämpfen",
    "auskämpften": "auskämpfen",
    "auskämpftest": "auskämpfen",
    "auskämpftet": "auskämpfen",
    "auskühle": "auskühlen",
    "auskühlend": "auskühlen",
    "auskühlende": "auskühlend",
    "auskühlendem": "auskühlend",
    "auskühlenden": "auskühlend",
    "auskühlender": "auskühlend",
    "auskühlendere": "auskühlend",
    "auskühlenderem": "auskühlend",
    "auskühlenderen": "auskühlend",
    "auskühlenderer": "auskühlend",
    "auskühlenderes": "auskühlend",
    "auskühlendes": "auskühlend",
    "auskühlendste": "auskühlend",
    "auskühlendstem": "auskühlend",
    "auskühlendsten": "auskühlend",
    "auskühlendster": "auskühlend",
    "auskühlendstes": "auskühlend",
    "auskühlest": "auskühlen",
    "auskühlet": "auskühlen",
    "auskühlst": "auskühlen",
    "auskühlt": "auskühlen",
    "auskühlte": "auskühlen",
    "auskühlten": "auskühlen",
    "auskühltest": "auskühlen",
    "auskühltet": "auskühlen",
    "auslache": "auslachen",
    "auslachend": "auslachen",
    "auslachende": "auslachend",
    "auslachendem": "auslachend",
    "auslachenden": "auslachend",
    "auslachender": "auslachend",
    "auslachendes": "auslachend",
    "auslachest": "auslachen",
    "auslachet": "auslachen",
    "auslachst": "auslachen",
    "auslacht": "auslachen",
    "auslachte": "auslachen",
    "auslachten": "auslachen",
    "auslachtest": "auslachen",
    "auslachtet": "auslachen",
    "auslade": "ausladen",
    "ausladend": "ausladen",
    "ausladende": "ausladend",
    "ausladendem": "ausladend",
    "ausladenden": "ausladend",
    "ausladender": "ausladend",
    "ausladendere": "ausladend",
    "ausladenderem": "ausladend",
    "ausladenderen": "ausladend",
    "ausladenderer": "ausladend",
    "ausladenderes": "ausladend",
    "ausladendes": "ausladend",
    "ausladendste": "ausladend",
    "ausladendstem": "ausladend",
    "ausladendsten": "ausladend",
    "ausladendster": "ausladend",
    "ausladendstes": "ausladend",
    "ausladest": "ausladen",
    "ausladet": "ausladen",
    "auslagere": "auslagern",
    "auslagernd": "auslagern",
    "auslagernde": "auslagernd",
    "auslagerndem": "auslagernd",
    "auslagernden": "auslagernd",
    "auslagernder": "auslagernd",
    "auslagerndes": "auslagernd",
    "auslagerst": "auslagern",
    "auslagert": "auslagern",
    "auslagerte": "auslagern",
    "auslagerten": "auslagern",
    "auslagertest": "auslagern",
    "auslagertet": "auslagern",
    "auslandsdeutschem": "auslandsdeutsch",
    "auslandsdeutschen": "auslandsdeutsch",
    "auslandsdeutscher": "auslandsdeutsch",
    "auslandsdeutsches": "auslandsdeutsch",
    "auslange": "auslangen",
    "auslangend": "auslangen",
    "auslangende": "auslangend",
    "auslangendem": "auslangend",
    "auslangenden": "auslangend",
    "auslangender": "auslangend",
    "auslangendes": "auslangend",
    "auslangest": "auslangen",
    "auslanget": "auslangen",
    "auslangst": "auslangen",
    "auslangt": "auslangen",
    "auslangte": "auslangen",
    "auslangten": "auslangen",
    "auslangtest": "auslangen",
    "auslangtet": "auslangen",
    "auslas": "auslesen",
    "auslasen": "auslesen",
    "auslasse": "auslassen",
    "auslassend": "auslassen",
    "auslassende": "auslassend",
    "auslassendem": "auslassend",
    "auslassenden": "auslassend",
    "auslassender": "auslassend",
    "auslassendere": "auslassend",
    "auslassenderem": "auslassend",
    "auslassenderen": "auslassend",
    "auslassenderer": "auslassend",
    "auslassenderes": "auslassend",
    "auslassendes": "auslassend",
    "auslassendste": "auslassend",
    "auslassendstem": "auslassend",
    "auslassendsten": "auslassend",
    "auslassendster": "auslassend",
    "auslassendstes": "auslassend",
    "auslassest": "auslassen",
    "auslasset": "auslassen",
    "auslast": "auslesen",
    "auslaste": "auslasten",
    "auslastend": "auslasten",
    "auslastende": "auslastend",
    "auslastendem": "auslastend",
    "auslastenden": "auslastend",
    "auslastender": "auslastend",
    "auslastendere": "auslastend",
    "auslastenderem": "auslastend",
    "auslastenderen": "auslastend",
    "auslastenderer": "auslastend",
    "auslastenderes": "auslastend",
    "auslastendes": "auslastend",
    "auslastendste": "auslastend",
    "auslastendstem": "auslastend",
    "auslastendsten": "auslastend",
    "auslastendster": "auslastend",
    "auslastendstes": "auslastend",
    "auslastest": "auslasten",
    "auslastet": "auslasten",
    "auslastete": "auslasten",
    "auslasteten": "auslasten",
    "auslastetest": "auslasten",
    "auslastetet": "auslasten",
    "auslatsche": "auslatschen",
    "auslatschend": "auslatschen",
    "auslatschende": "auslatschend",
    "auslatschendem": "auslatschend",
    "auslatschenden": "auslatschend",
    "auslatschender": "auslatschend",
    "auslatschendere": "auslatschend",
    "auslatschenderem": "auslatschend",
    "auslatschenderen": "auslatschend",
    "auslatschenderer": "auslatschend",
    "auslatschenderes": "auslatschend",
    "auslatschendes": "auslatschend",
    "auslatschendste": "auslatschend",
    "auslatschendstem": "auslatschend",
    "auslatschendsten": "auslatschend",
    "auslatschendster": "auslatschend",
    "auslatschendstes": "auslatschend",
    "auslatschest": "auslatschen",
    "auslatschet": "auslatschen",
    "auslatschst": "auslatschen",
    "auslatscht": "auslatschen",
    "auslatschte": "auslatschen",
    "auslatschten": "auslatschen",
    "auslatschtest": "auslatschen",
    "auslatschtet": "auslatschen",
    "auslaufend": "auslaufen",
    "auslaufende": "auslaufend",
    "auslaufendem": "auslaufend",
    "auslaufenden": "auslaufend",
    "auslaufender": "auslaufend",
    "auslaufendere": "auslaufend",
    "auslaufenderem": "auslaufend",
    "auslaufenderen": "auslaufend",
    "auslaufenderer": "auslaufend",
    "auslaufenderes": "auslaufend",
    "auslaufendes": "auslaufend",
    "auslaufendste": "auslaufend",
    "auslaufendstem": "auslaufend",
    "auslaufendsten": "auslaufend",
    "auslaufendster": "auslaufend",
    "auslaufendstes": "auslaufend",
    "auslaufest": "auslaufen",
    "auslaufet": "auslaufen",
    "auslauft": "auslaufen",
    "auslauge": "auslaugen",
    "auslaugend": "auslaugen",
    "auslaugende": "auslaugend",
    "auslaugendem": "auslaugend",
    "auslaugenden": "auslaugend",
    "auslaugender": "auslaugend",
    "auslaugendere": "auslaugend",
    "auslaugenderem": "auslaugend",
    "auslaugenderen": "auslaugend",
    "auslaugenderer": "auslaugend",
    "auslaugenderes": "auslaugend",
    "auslaugendes": "auslaugend",
    "auslaugendste": "auslaugend",
    "auslaugendstem": "auslaugend",
    "auslaugendsten": "auslaugend",
    "auslaugendster": "auslaugend",
    "auslaugendstes": "auslaugend",
    "auslaugest": "auslaugen",
    "auslauget": "auslaugen",
    "auslaugst": "auslaugen",
    "auslaugt": "auslaugen",
    "auslaugte": "auslaugen",
    "auslaugten": "auslaugen",
    "auslaugtest": "auslaugen",
    "auslaugtet": "auslaugen",
    "auslaute": "auslauten",
    "auslautend": "auslauten",
    "auslautende": "auslautend",
    "auslautendem": "auslautend",
    "auslautenden": "auslautend",
    "auslautender": "auslautend",
    "auslautendes": "auslautend",
    "auslautest": "auslauten",
    "auslautet": "auslauten",
    "auslautete": "auslauten",
    "auslauteten": "auslauten",
    "auslautetest": "auslauten",
    "auslautetet": "auslauten",
    "auslaßt": "auslassen",
    "auslebe": "ausleben",
    "auslebend": "ausleben",
    "auslebende": "auslebend",
    "auslebendem": "auslebend",
    "auslebenden": "auslebend",
    "auslebender": "auslebend",
    "auslebendere": "auslebend",
    "auslebenderem": "auslebend",
    "auslebenderen": "auslebend",
    "auslebenderer": "auslebend",
    "auslebenderes": "auslebend",
    "auslebendes": "auslebend",
    "auslebendste": "auslebend",
    "auslebendstem": "auslebend",
    "auslebendsten": "auslebend",
    "auslebendster": "auslebend",
    "auslebendstes": "auslebend",
    "auslebest": "ausleben",
    "auslebet": "ausleben",
    "auslebst": "ausleben",
    "auslebt": "ausleben",
    "auslebte": "ausleben",
    "auslebten": "ausleben",
    "auslebtest": "ausleben",
    "auslebtet": "ausleben",
    "ausleere": "ausleeren",
    "ausleerend": "ausleeren",
    "ausleerende": "ausleerend",
    "ausleerendem": "ausleerend",
    "ausleerenden": "ausleerend",
    "ausleerender": "ausleerend",
    "ausleerendes": "ausleerend",
    "ausleerest": "ausleeren",
    "ausleeret": "ausleeren",
    "ausleerst": "ausleeren",
    "ausleert": "ausleeren",
    "ausleerte": "ausleeren",
    "ausleerten": "ausleeren",
    "ausleertest": "ausleeren",
    "ausleertet": "ausleeren",
    "auslege": "auslegen",
    "auslegend": "auslegen",
    "auslegende": "auslegend",
    "auslegendem": "auslegend",
    "auslegenden": "auslegend",
    "auslegender": "auslegend",
    "auslegendes": "auslegend",
    "auslegest": "auslegen",
    "ausleget": "auslegen",
    "auslegst": "auslegen",
    "auslegt": "auslegen",
    "auslegte": "auslegen",
    "auslegten": "auslegen",
    "auslegtest": "auslegen",
    "auslegtet": "auslegen",
    "ausleide": "ausleiden",
    "ausleidend": "ausleiden",
    "ausleidende": "ausleidend",
    "ausleidendem": "ausleidend",
    "ausleidenden": "ausleidend",
    "ausleidender": "ausleidend",
    "ausleidendere": "ausleidend",
    "ausleidenderem": "ausleidend",
    "ausleidenderen": "ausleidend",
    "ausleidenderer": "ausleidend",
    "ausleidenderes": "ausleidend",
    "ausleidendes": "ausleidend",
    "ausleidendste": "ausleidend",
    "ausleidendstem": "ausleidend",
    "ausleidendsten": "ausleidend",
    "ausleidendster": "ausleidend",
    "ausleidendstes": "ausleidend",
    "ausleidest": "ausleiden",
    "ausleidet": "ausleiden",
    "ausleiere": "ausleiern",
    "ausleiernd": "ausleiern",
    "ausleiernde": "ausleiernd",
    "ausleierndem": "ausleiernd",
    "ausleiernden": "ausleiernd",
    "ausleiernder": "ausleiernd",
    "ausleierndere": "ausleiernd",
    "ausleiernderem": "ausleiernd",
    "ausleiernderen": "ausleiernd",
    "ausleiernderer": "ausleiernd",
    "ausleiernderes": "ausleiernd",
    "ausleierndes": "ausleiernd",
    "ausleierndste": "ausleiernd",
    "ausleierndstem": "ausleiernd",
    "ausleierndsten": "ausleiernd",
    "ausleierndster": "ausleiernd",
    "ausleierndstes": "ausleiernd",
    "ausleierst": "ausleiern",
    "ausleiert": "ausleiern",
    "ausleierte": "ausleiern",
    "ausleierten": "ausleiern",
    "ausleiertest": "ausleiern",
    "ausleiertet": "ausleiern",
    "ausleihe": "ausleihen",
    "ausleihend": "ausleihen",
    "ausleihende": "ausleihend",
    "ausleihendem": "ausleihend",
    "ausleihenden": "ausleihend",
    "ausleihender": "ausleihend",
    "ausleihendes": "ausleihend",
    "ausleihest": "ausleihen",
    "ausleihet": "ausleihen",
    "ausleihst": "ausleihen",
    "ausleiht": "ausleihen",
    "auslerne": "auslernen",
    "auslernend": "auslernen",
    "auslernende": "auslernend",
    "auslernendem": "auslernend",
    "auslernenden": "auslernend",
    "auslernender": "auslernend",
    "auslernendes": "auslernend",
    "auslernest": "auslernen",
    "auslernet": "auslernen",
    "auslernst": "auslernen",
    "auslernt": "auslernen",
    "auslernte": "auslernen",
    "auslernten": "auslernen",
    "auslerntest": "auslernen",
    "auslerntet": "auslernen",
    "auslese": "auslesen",
    "auslesend": "auslesen",
    "auslesende": "auslesend",
    "auslesendem": "auslesend",
    "auslesenden": "auslesend",
    "auslesender": "auslesend",
    "auslesendes": "auslesend",
    "auslesest": "auslesen",
    "ausleset": "auslesen",
    "auslest": "auslesen",
    "ausleuchte": "ausleuchten",
    "ausleuchtend": "ausleuchten",
    "ausleuchtende": "ausleuchtend",
    "ausleuchtendem": "ausleuchtend",
    "ausleuchtenden": "ausleuchtend",
    "ausleuchtender": "ausleuchtend",
    "ausleuchtendere": "ausleuchtend",
    "ausleuchtenderem": "ausleuchtend",
    "ausleuchtenderen": "ausleuchtend",
    "ausleuchtenderer": "ausleuchtend",
    "ausleuchtenderes": "ausleuchtend",
    "ausleuchtendes": "ausleuchtend",
    "ausleuchtendste": "ausleuchtend",
    "ausleuchtendstem": "ausleuchtend",
    "ausleuchtendsten": "ausleuchtend",
    "ausleuchtendster": "ausleuchtend",
    "ausleuchtendstes": "ausleuchtend",
    "ausleuchtest": "ausleuchten",
    "ausleuchtet": "ausleuchten",
    "ausleuchtete": "ausleuchten",
    "ausleuchteten": "ausleuchten",
    "ausleuchtetest": "ausleuchten",
    "ausleuchtetet": "ausleuchten",
    "auslichte": "auslichten",
    "auslichtend": "auslichten",
    "auslichtende": "auslichtend",
    "auslichtendem": "auslichtend",
    "auslichtenden": "auslichtend",
    "auslichtender": "auslichtend",
    "auslichtendes": "auslichtend",
    "auslichtest": "auslichten",
    "auslichtet": "auslichten",
    "auslichtete": "auslichten",
    "auslichteten": "auslichten",
    "auslichtetest": "auslichten",
    "auslichtetet": "auslichten",
    "auslief": "auslaufen",
    "ausliefe": "auslaufen",
    "ausliefen": "auslaufen",
    "ausliefere": "ausliefern",
    "ausliefernd": "ausliefern",
    "ausliefernde": "ausliefernd",
    "auslieferndem": "ausliefernd",
    "ausliefernden": "ausliefernd",
    "ausliefernder": "ausliefernd",
    "auslieferndes": "ausliefernd",
    "auslieferst": "ausliefern",
    "ausliefert": "ausliefern",
    "auslieferte": "ausliefern",
    "auslieferten": "ausliefern",
    "ausliefertest": "ausliefern",
    "ausliefertet": "ausliefern",
    "ausliefest": "auslaufen",
    "ausliefet": "auslaufen",
    "ausliefst": "auslaufen",
    "auslieft": "auslaufen",
    "auslieh": "ausleihen",
    "ausliehe": "ausleihen",
    "ausliehen": "ausleihen",
    "ausliehest": "ausleihen",
    "ausliehet": "ausleihen",
    "ausliehst": "ausleihen",
    "auslieht": "ausleihen",
    "ausliest": "auslesen",
    "ausließ": "auslassen",
    "ausließe": "auslassen",
    "ausließen": "auslassen",
    "ausließest": "auslassen",
    "ausließet": "auslassen",
    "ausließt": "auslassen",
    "auslischst": "auslöschen",
    "auslischt": "auslöschen",
    "auslitt": "ausleiden",
    "auslitte": "ausleiden",
    "auslitten": "ausleiden",
    "auslittest": "ausleiden",
    "auslittet": "ausleiden",
    "auslosch": "auslöschen",
    "ausloschen": "auslöschen",
    "ausloschst": "auslöschen",
    "ausloscht": "auslöschen",
    "auslose": "auslosen",
    "auslosend": "auslosen",
    "auslosende": "auslosend",
    "auslosendem": "auslosend",
    "auslosenden": "auslosend",
    "auslosender": "auslosend",
    "auslosendes": "auslosend",
    "auslosest": "auslosen",
    "ausloset": "auslosen",
    "auslost": "auslosen",
    "ausloste": "auslosen",
    "auslosten": "auslosen",
    "auslostest": "auslosen",
    "auslostet": "auslosen",
    "auslote": "ausloten",
    "auslotend": "ausloten",
    "auslotende": "auslotend",
    "auslotendem": "auslotend",
    "auslotenden": "auslotend",
    "auslotender": "auslotend",
    "auslotendes": "auslotend",
    "auslotest": "ausloten",
    "auslotet": "ausloten",
    "auslotete": "ausloten",
    "ausloteten": "ausloten",
    "auslotetest": "ausloten",
    "auslotetet": "ausloten",
    "auslud": "ausladen",
    "ausluden": "ausladen",
    "ausludest": "ausladen",
    "ausludet": "ausladen",
    "auslädst": "ausladen",
    "auslädt": "ausladen",
    "ausländerfeindliche": "ausländerfeindlich",
    "ausländerfeindlichem": "ausländerfeindlich",
    "ausländerfeindlichen": "ausländerfeindlich",
    "ausländerfeindlicher": "ausländerfeindlich",
    "ausländerfeindlichere": "ausländerfeindlich",
    "ausländerfeindlicherem": "ausländerfeindlich",
    "ausländerfeindlicheren": "ausländerfeindlich",
    "ausländerfeindlicherer": "ausländerfeindlich",
    "ausländerfeindlicheres": "ausländerfeindlich",
    "ausländerfeindliches": "ausländerfeindlich",
    "ausländerfeindlichste": "ausländerfeindlich",
    "ausländerfeindlichstem": "ausländerfeindlich",
    "ausländerfeindlichsten": "ausländerfeindlich",
    "ausländerfeindlichster": "ausländerfeindlich",
    "ausländerfeindlichstes": "ausländerfeindlich",
    "ausländischem": "ausländisch",
    "ausländischen": "ausländisch",
    "ausländischer": "ausländisch",
    "ausländisches": "ausländisch",
    "ausläse": "auslesen",
    "ausläsen": "auslesen",
    "ausläsest": "auslesen",
    "ausläset": "auslesen",
    "ausläufst": "auslaufen",
    "ausläuft": "auslaufen",
    "ausläute": "ausläuten",
    "ausläutend": "ausläuten",
    "ausläutendem": "ausläutend",
    "ausläutender": "ausläutend",
    "ausläutendes": "ausläutend",
    "ausläutest": "ausläuten",
    "ausläutet": "ausläuten",
    "ausläutete": "ausläuten",
    "ausläuteten": "ausläuten",
    "ausläutetest": "ausläuten",
    "ausläutetet": "ausläuten",
    "ausläßt": "auslassen",
    "auslöffele": "auslöffeln",
    "auslöffelnd": "auslöffeln",
    "auslöffelnde": "auslöffelnd",
    "auslöffelndem": "auslöffelnd",
    "auslöffelnden": "auslöffelnd",
    "auslöffelnder": "auslöffelnd",
    "auslöffelndes": "auslöffelnd",
    "auslöffelst": "auslöffeln",
    "auslöffelt": "auslöffeln",
    "auslöffelte": "auslöffeln",
    "auslöffelten": "auslöffeln",
    "auslöffeltest": "auslöffeln",
    "auslöffeltet": "auslöffeln",
    "auslöffle": "auslöffeln",
    "auslösche": "auslöschen",
    "auslöschend": "auslöschen",
    "auslöschende": "auslöschend",
    "auslöschendem": "auslöschend",
    "auslöschenden": "auslöschend",
    "auslöschender": "auslöschend",
    "auslöschendes": "auslöschend",
    "auslöschest": "auslöschen",
    "auslöschet": "auslöschen",
    "auslöschst": "auslöschen",
    "auslöscht": "auslöschen",
    "auslöschte": "auslöschen",
    "auslöschten": "auslöschen",
    "auslöschtest": "auslöschen",
    "auslöschtet": "auslöschen",
    "auslöse": "auslösen",
    "auslösend": "auslösen",
    "auslösendem": "auslösend",
    "auslösender": "auslösend",
    "auslösendes": "auslösend",
    "auslösest": "auslösen",
    "auslöset": "auslösen",
    "auslöst": "auslösen",
    "auslöste": "auslösen",
    "auslösten": "auslösen",
    "auslöstest": "auslösen",
    "auslöstet": "auslösen",
    "auslüde": "ausladen",
    "auslüden": "ausladen",
    "auslüdest": "ausladen",
    "auslüdet": "ausladen",
    "auslüfte": "auslüften",
    "auslüftend": "auslüften",
    "auslüftende": "auslüftend",
    "auslüftendem": "auslüftend",
    "auslüftenden": "auslüftend",
    "auslüftender": "auslüftend",
    "auslüftendere": "auslüftend",
    "auslüftenderem": "auslüftend",
    "auslüftenderen": "auslüftend",
    "auslüftenderer": "auslüftend",
    "auslüftenderes": "auslüftend",
    "auslüftendes": "auslüftend",
    "auslüftendste": "auslüftend",
    "auslüftendstem": "auslüftend",
    "auslüftendsten": "auslüftend",
    "auslüftendster": "auslüftend",
    "auslüftendstes": "auslüftend",
    "auslüftest": "auslüften",
    "auslüftet": "auslüften",
    "auslüftete": "auslüften",
    "auslüfteten": "auslüften",
    "auslüftetest": "auslüften",
    "auslüftetet": "auslüften",
    "ausmache": "ausmachen",
    "ausmachend": "ausmachen",
    "ausmachende": "ausmachend",
    "ausmachendem": "ausmachend",
    "ausmachenden": "ausmachend",
    "ausmachender": "ausmachend",
    "ausmachendes": "ausmachend",
    "ausmachest": "ausmachen",
    "ausmachet": "ausmachen",
    "ausmachst": "ausmachen",
    "ausmacht": "ausmachen",
    "ausmachte": "ausmachen",
    "ausmachten": "ausmachen",
    "ausmachtest": "ausmachen",
    "ausmachtet": "ausmachen",
    "ausmahle": "ausmahlen",
    "ausmahlend": "ausmahlen",
    "ausmahlende": "ausmahlend",
    "ausmahlendem": "ausmahlend",
    "ausmahlenden": "ausmahlend",
    "ausmahlender": "ausmahlend",
    "ausmahlendere": "ausmahlend",
    "ausmahlenderem": "ausmahlend",
    "ausmahlenderen": "ausmahlend",
    "ausmahlenderer": "ausmahlend",
    "ausmahlenderes": "ausmahlend",
    "ausmahlendes": "ausmahlend",
    "ausmahlendste": "ausmahlend",
    "ausmahlendstem": "ausmahlend",
    "ausmahlendsten": "ausmahlend",
    "ausmahlendster": "ausmahlend",
    "ausmahlendstes": "ausmahlend",
    "ausmahlest": "ausmahlen",
    "ausmahlet": "ausmahlen",
    "ausmahlst": "ausmahlen",
    "ausmahlt": "ausmahlen",
    "ausmahlte": "ausmahlen",
    "ausmahlten": "ausmahlen",
    "ausmahltest": "ausmahlen",
    "ausmahltet": "ausmahlen",
    "ausmale": "ausmalen",
    "ausmalend": "ausmalen",
    "ausmalende": "ausmalend",
    "ausmalendem": "ausmalend",
    "ausmalenden": "ausmalend",
    "ausmalender": "ausmalend",
    "ausmalendere": "ausmalend",
    "ausmalenderem": "ausmalend",
    "ausmalenderen": "ausmalend",
    "ausmalenderer": "ausmalend",
    "ausmalenderes": "ausmalend",
    "ausmalendes": "ausmalend",
    "ausmalendste": "ausmalend",
    "ausmalendstem": "ausmalend",
    "ausmalendsten": "ausmalend",
    "ausmalendster": "ausmalend",
    "ausmalendstes": "ausmalend",
    "ausmalest": "ausmalen",
    "ausmalet": "ausmalen",
    "ausmalst": "ausmalen",
    "ausmalt": "ausmalen",
    "ausmalte": "ausmalen",
    "ausmalten": "ausmalen",
    "ausmaltest": "ausmalen",
    "ausmaltet": "ausmalen",
    "ausmaß": "ausmessen",
    "ausmaßt": "ausmessen",
    "ausmeißele": "ausmeißeln",
    "ausmeißelnd": "ausmeißeln",
    "ausmeißelnde": "ausmeißelnd",
    "ausmeißelndem": "ausmeißelnd",
    "ausmeißelnden": "ausmeißelnd",
    "ausmeißelnder": "ausmeißelnd",
    "ausmeißelndes": "ausmeißelnd",
    "ausmeißelst": "ausmeißeln",
    "ausmeißelt": "ausmeißeln",
    "ausmeißelte": "ausmeißeln",
    "ausmeißelten": "ausmeißeln",
    "ausmeißeltest": "ausmeißeln",
    "ausmeißeltet": "ausmeißeln",
    "ausmeißle": "ausmeißeln",
    "ausmelke": "ausmelken",
    "ausmelkend": "ausmelken",
    "ausmelkende": "ausmelkend",
    "ausmelkendem": "ausmelkend",
    "ausmelkenden": "ausmelkend",
    "ausmelkender": "ausmelkend",
    "ausmelkendes": "ausmelkend",
    "ausmelkest": "ausmelken",
    "ausmelket": "ausmelken",
    "ausmelkst": "ausmelken",
    "ausmelkt": "ausmelken",
    "ausmelkte": "ausmelken",
    "ausmelkten": "ausmelken",
    "ausmelktest": "ausmelken",
    "ausmelktet": "ausmelken",
    "ausmerze": "ausmerzen",
    "ausmerzend": "ausmerzen",
    "ausmerzende": "ausmerzend",
    "ausmerzendem": "ausmerzend",
    "ausmerzenden": "ausmerzend",
    "ausmerzender": "ausmerzend",
    "ausmerzendere": "ausmerzend",
    "ausmerzenderem": "ausmerzend",
    "ausmerzenderen": "ausmerzend",
    "ausmerzenderer": "ausmerzend",
    "ausmerzenderes": "ausmerzend",
    "ausmerzendes": "ausmerzend",
    "ausmerzendste": "ausmerzend",
    "ausmerzendstem": "ausmerzend",
    "ausmerzendsten": "ausmerzend",
    "ausmerzendster": "ausmerzend",
    "ausmerzendstes": "ausmerzend",
    "ausmerzest": "ausmerzen",
    "ausmerzet": "ausmerzen",
    "ausmerzt": "ausmerzen",
    "ausmerzte": "ausmerzen",
    "ausmerzten": "ausmerzen",
    "ausmerztest": "ausmerzen",
    "ausmerztet": "ausmerzen",
    "ausmesse": "ausmessen",
    "ausmessend": "ausmessen",
    "ausmessende": "ausmessend",
    "ausmessendem": "ausmessend",
    "ausmessenden": "ausmessend",
    "ausmessender": "ausmessend",
    "ausmessendes": "ausmessend",
    "ausmessest": "ausmessen",
    "ausmesset": "ausmessen",
    "ausmeßt": "ausmessen",
    "ausmilkst": "ausmelken",
    "ausmilkt": "ausmelken",
    "ausmiste": "ausmisten",
    "ausmistend": "ausmisten",
    "ausmistende": "ausmistend",
    "ausmistendem": "ausmistend",
    "ausmistenden": "ausmistend",
    "ausmistender": "ausmistend",
    "ausmistendes": "ausmistend",
    "ausmistest": "ausmisten",
    "ausmistet": "ausmisten",
    "ausmistete": "ausmisten",
    "ausmisteten": "ausmisten",
    "ausmistetest": "ausmisten",
    "ausmistetet": "ausmisten",
    "ausmißt": "ausmessen",
    "ausmolk": "ausmelken",
    "ausmolken": "ausmelken",
    "ausmolkst": "ausmelken",
    "ausmolkt": "ausmelken",
    "ausmustere": "ausmustern",
    "ausmusternd": "ausmustern",
    "ausmusternde": "ausmusternd",
    "ausmusterndem": "ausmusternd",
    "ausmusternden": "ausmusternd",
    "ausmusternder": "ausmusternd",
    "ausmusterndes": "ausmusternd",
    "ausmusterst": "ausmustern",
    "ausmustert": "ausmustern",
    "ausmusterte": "ausmustern",
    "ausmusterten": "ausmustern",
    "ausmustertest": "ausmustern",
    "ausmustertet": "ausmustern",
    "ausmäße": "ausmessen",
    "ausmäßen": "ausmessen",
    "ausmäßest": "ausmessen",
    "ausmäßet": "ausmessen",
    "ausmölke": "ausmelken",
    "ausmölken": "ausmelken",
    "ausmölkest": "ausmelken",
    "ausmölket": "ausmelken",
    "ausmünde": "ausmünden",
    "ausmündend": "ausmünden",
    "ausmündende": "ausmündend",
    "ausmündendem": "ausmündend",
    "ausmündenden": "ausmündend",
    "ausmündender": "ausmündend",
    "ausmündendes": "ausmündend",
    "ausmündest": "ausmünden",
    "ausmündet": "ausmünden",
    "ausmündete": "ausmünden",
    "ausmündeten": "ausmünden",
    "ausmündetest": "ausmünden",
    "ausmündetet": "ausmünden",
    "ausnahm": "ausnehmen",
    "ausnahmslose": "ausnahmslos",
    "ausnahmslosem": "ausnahmslos",
    "ausnahmslosen": "ausnahmslos",
    "ausnahmsloser": "ausnahmslos",
    "ausnahmsloses": "ausnahmslos",
    "ausnahmst": "ausnehmen",
    "ausnahmt": "ausnehmen",
    "ausnehme": "ausnehmen",
    "ausnehmend": "ausnehmen",
    "ausnehmende": "ausnehmend",
    "ausnehmendem": "ausnehmend",
    "ausnehmenden": "ausnehmend",
    "ausnehmender": "ausnehmend",
    "ausnehmendere": "ausnehmend",
    "ausnehmenderem": "ausnehmend",
    "ausnehmenderen": "ausnehmend",
    "ausnehmenderer": "ausnehmend",
    "ausnehmenderes": "ausnehmend",
    "ausnehmendes": "ausnehmend",
    "ausnehmendste": "ausnehmend",
    "ausnehmendstem": "ausnehmend",
    "ausnehmendsten": "ausnehmend",
    "ausnehmendster": "ausnehmend",
    "ausnehmendstes": "ausnehmend",
    "ausnehmest": "ausnehmen",
    "ausnehmet": "ausnehmen",
    "ausnehmt": "ausnehmen",
    "ausnimmst": "ausnehmen",
    "ausnimmt": "ausnehmen",
    "ausnutze": "ausnutzen",
    "ausnutzend": "ausnutzen",
    "ausnutzende": "ausnutzend",
    "ausnutzendem": "ausnutzend",
    "ausnutzenden": "ausnutzend",
    "ausnutzender": "ausnutzend",
    "ausnutzendere": "ausnutzend",
    "ausnutzenderem": "ausnutzend",
    "ausnutzenderen": "ausnutzend",
    "ausnutzenderer": "ausnutzend",
    "ausnutzenderes": "ausnutzend",
    "ausnutzendes": "ausnutzend",
    "ausnutzendste": "ausnutzend",
    "ausnutzendstem": "ausnutzend",
    "ausnutzendsten": "ausnutzend",
    "ausnutzendster": "ausnutzend",
    "ausnutzendstes": "ausnutzend",
    "ausnutzest": "ausnutzen",
    "ausnutzet": "ausnutzen",
    "ausnutzt": "ausnutzen",
    "ausnutzte": "ausnutzen",
    "ausnutzten": "ausnutzen",
    "ausnutztest": "ausnutzen",
    "ausnutztet": "ausnutzen",
    "ausnähme": "ausnehmen",
    "ausnähmen": "ausnehmen",
    "ausnähmest": "ausnehmen",
    "ausnähmet": "ausnehmen",
    "auspacke": "auspacken",
    "auspackend": "auspacken",
    "auspackende": "auspackend",
    "auspackendem": "auspackend",
    "auspackenden": "auspackend",
    "auspackender": "auspackend",
    "auspackendes": "auspackend",
    "auspackest": "auspacken",
    "auspacket": "auspacken",
    "auspackst": "auspacken",
    "auspackt": "auspacken",
    "auspackte": "auspacken",
    "auspackten": "auspacken",
    "auspacktest": "auspacken",
    "auspacktet": "auspacken",
    "ausparke": "ausparken",
    "ausparkend": "ausparken",
    "ausparkende": "ausparkend",
    "ausparkendem": "ausparkend",
    "ausparkenden": "ausparkend",
    "ausparkender": "ausparkend",
    "ausparkendes": "ausparkend",
    "ausparkest": "ausparken",
    "ausparket": "ausparken",
    "ausparkst": "ausparken",
    "ausparkt": "ausparken",
    "ausparkte": "ausparken",
    "ausparkten": "ausparken",
    "ausparktest": "ausparken",
    "ausparktet": "ausparken",
    "auspeitsche": "auspeitschen",
    "auspeitschend": "auspeitschen",
    "auspeitschende": "auspeitschend",
    "auspeitschendem": "auspeitschend",
    "auspeitschenden": "auspeitschend",
    "auspeitschender": "auspeitschend",
    "auspeitschendere": "auspeitschend",
    "auspeitschenderem": "auspeitschend",
    "auspeitschenderen": "auspeitschend",
    "auspeitschenderer": "auspeitschend",
    "auspeitschenderes": "auspeitschend",
    "auspeitschendes": "auspeitschend",
    "auspeitschendste": "auspeitschend",
    "auspeitschendstem": "auspeitschend",
    "auspeitschendsten": "auspeitschend",
    "auspeitschendster": "auspeitschend",
    "auspeitschendstes": "auspeitschend",
    "auspeitschest": "auspeitschen",
    "auspeitschet": "auspeitschen",
    "auspeitschst": "auspeitschen",
    "auspeitscht": "auspeitschen",
    "auspeitschte": "auspeitschen",
    "auspeitschten": "auspeitschen",
    "auspeitschtest": "auspeitschen",
    "auspeitschtet": "auspeitschen",
    "auspendele": "auspendeln",
    "auspendelnd": "auspendeln",
    "auspendelnde": "auspendelnd",
    "auspendelndem": "auspendelnd",
    "auspendelnden": "auspendelnd",
    "auspendelnder": "auspendelnd",
    "auspendelndere": "auspendelnd",
    "auspendelnderem": "auspendelnd",
    "auspendelnderen": "auspendelnd",
    "auspendelnderer": "auspendelnd",
    "auspendelnderes": "auspendelnd",
    "auspendelndes": "auspendelnd",
    "auspendelndste": "auspendelnd",
    "auspendelndstem": "auspendelnd",
    "auspendelndsten": "auspendelnd",
    "auspendelndster": "auspendelnd",
    "auspendelndstes": "auspendelnd",
    "auspendelst": "auspendeln",
    "auspendelt": "auspendeln",
    "auspendelte": "auspendeln",
    "auspendelten": "auspendeln",
    "auspendeltest": "auspendeln",
    "auspendeltet": "auspendeln",
    "auspendle": "auspendeln",
    "auspfeife": "auspfeifen",
    "auspfeifend": "auspfeifen",
    "auspfeifende": "auspfeifend",
    "auspfeifendem": "auspfeifend",
    "auspfeifenden": "auspfeifend",
    "auspfeifender": "auspfeifend",
    "auspfeifendere": "auspfeifend",
    "auspfeifenderem": "auspfeifend",
    "auspfeifenderen": "auspfeifend",
    "auspfeifenderer": "auspfeifend",
    "auspfeifenderes": "auspfeifend",
    "auspfeifendes": "auspfeifend",
    "auspfeifendste": "auspfeifend",
    "auspfeifendstem": "auspfeifend",
    "auspfeifendsten": "auspfeifend",
    "auspfeifendster": "auspfeifend",
    "auspfeifendstes": "auspfeifend",
    "auspfeifest": "auspfeifen",
    "auspfeifet": "auspfeifen",
    "auspfeifst": "auspfeifen",
    "auspfeift": "auspfeifen",
    "auspfiff": "auspfeifen",
    "auspfiffe": "auspfeifen",
    "auspfiffen": "auspfeifen",
    "auspfiffest": "auspfeifen",
    "auspfiffet": "auspfeifen",
    "auspfiffst": "auspfeifen",
    "auspfifft": "auspfeifen",
    "auspflanze": "auspflanzen",
    "auspflanzend": "auspflanzen",
    "auspflanzende": "auspflanzend",
    "auspflanzendem": "auspflanzend",
    "auspflanzenden": "auspflanzend",
    "auspflanzender": "auspflanzend",
    "auspflanzendes": "auspflanzend",
    "auspflanzest": "auspflanzen",
    "auspflanzet": "auspflanzen",
    "auspflanzt": "auspflanzen",
    "auspflanzte": "auspflanzen",
    "auspflanzten": "auspflanzen",
    "auspflanztest": "auspflanzen",
    "auspflanztet": "auspflanzen",
    "ausplappere": "ausplappern",
    "ausplappernd": "ausplappern",
    "ausplappernde": "ausplappernd",
    "ausplapperndem": "ausplappernd",
    "ausplappernden": "ausplappernd",
    "ausplappernder": "ausplappernd",
    "ausplapperndes": "ausplappernd",
    "ausplapperst": "ausplappern",
    "ausplappert": "ausplappern",
    "ausplapperte": "ausplappern",
    "ausplapperten": "ausplappern",
    "ausplappertest": "ausplappern",
    "ausplappertet": "ausplappern",
    "ausplaudere": "ausplaudern",
    "ausplaudernd": "ausplaudern",
    "ausplaudernde": "ausplaudernd",
    "ausplauderndem": "ausplaudernd",
    "ausplaudernden": "ausplaudernd",
    "ausplaudernder": "ausplaudernd",
    "ausplauderndes": "ausplaudernd",
    "ausplauderst": "ausplaudern",
    "ausplaudert": "ausplaudern",
    "ausplauderte": "ausplaudern",
    "ausplauderten": "ausplaudern",
    "ausplaudertest": "ausplaudern",
    "ausplaudertet": "ausplaudern",
    "ausplündere": "ausplündern",
    "ausplündernd": "ausplündern",
    "ausplündernde": "ausplündernd",
    "ausplünderndem": "ausplündernd",
    "ausplündernden": "ausplündernd",
    "ausplündernder": "ausplündernd",
    "ausplünderndere": "ausplündernd",
    "ausplündernderem": "ausplündernd",
    "ausplündernderen": "ausplündernd",
    "ausplündernderer": "ausplündernd",
    "ausplündernderes": "ausplündernd",
    "ausplünderndes": "ausplündernd",
    "ausplünderndste": "ausplündernd",
    "ausplünderndstem": "ausplündernd",
    "ausplünderndsten": "ausplündernd",
    "ausplünderndster": "ausplündernd",
    "ausplünderndstes": "ausplündernd",
    "ausplünderst": "ausplündern",
    "ausplündert": "ausplündern",
    "ausplünderte": "ausplündern",
    "ausplünderten": "ausplündern",
    "ausplündertest": "ausplündern",
    "ausplündertet": "ausplündern",
    "auspolstere": "auspolstern",
    "auspolsternd": "auspolstern",
    "auspolsternde": "auspolsternd",
    "auspolsterndem": "auspolsternd",
    "auspolsternden": "auspolsternd",
    "auspolsternder": "auspolsternd",
    "auspolsterndere": "auspolsternd",
    "auspolsternderem": "auspolsternd",
    "auspolsternderen": "auspolsternd",
    "auspolsternderer": "auspolsternd",
    "auspolsternderes": "auspolsternd",
    "auspolsterndes": "auspolsternd",
    "auspolsterndste": "auspolsternd",
    "auspolsterndstem": "auspolsternd",
    "auspolsterndsten": "auspolsternd",
    "auspolsterndster": "auspolsternd",
    "auspolsterndstes": "auspolsternd",
    "auspolsterst": "auspolstern",
    "auspolstert": "auspolstern",
    "auspolsterte": "auspolstern",
    "auspolsterten": "auspolstern",
    "auspolstertest": "auspolstern",
    "auspolstertet": "auspolstern",
    "ausposaune": "ausposaunen",
    "ausposaunend": "ausposaunen",
    "ausposaunende": "ausposaunend",
    "ausposaunendem": "ausposaunend",
    "ausposaunenden": "ausposaunend",
    "ausposaunender": "ausposaunend",
    "ausposaunendes": "ausposaunend",
    "ausposaunest": "ausposaunen",
    "ausposaunet": "ausposaunen",
    "ausposaunst": "ausposaunen",
    "ausposaunt": "ausposaunen",
    "ausposaunte": "ausposaunen",
    "ausposauntem": "ausposaunt",
    "ausposaunten": "ausposaunen",
    "ausposaunter": "ausposaunt",
    "ausposauntes": "ausposaunt",
    "ausposauntest": "ausposaunen",
    "ausposauntet": "ausposaunen",
    "auspowere": "auspowern",
    "auspowernd": "auspowern",
    "auspowernde": "auspowernd",
    "auspowerndem": "auspowernd",
    "auspowernden": "auspowernd",
    "auspowernder": "auspowernd",
    "auspowerndere": "auspowernd",
    "auspowernderem": "auspowernd",
    "auspowernderen": "auspowernd",
    "auspowernderer": "auspowernd",
    "auspowernderes": "auspowernd",
    "auspowerndes": "auspowernd",
    "auspowerndste": "auspowernd",
    "auspowerndstem": "auspowernd",
    "auspowerndsten": "auspowernd",
    "auspowerndster": "auspowernd",
    "auspowerndstes": "auspowernd",
    "auspowerst": "auspowern",
    "auspowert": "auspowern",
    "auspowerte": "auspowern",
    "auspowerten": "auspowern",
    "auspowertest": "auspowern",
    "auspowertet": "auspowern",
    "auspresse": "auspressen",
    "auspressend": "auspressen",
    "auspressende": "auspressend",
    "auspressendem": "auspressend",
    "auspressenden": "auspressend",
    "auspressender": "auspressend",
    "auspressendere": "auspressend",
    "auspressenderem": "auspressend",
    "auspressenderen": "auspressend",
    "auspressenderer": "auspressend",
    "auspressenderes": "auspressend",
    "auspressendes": "auspressend",
    "auspressendste": "auspressend",
    "auspressendstem": "auspressend",
    "auspressendsten": "auspressend",
    "auspressendster": "auspressend",
    "auspressendstes": "auspressend",
    "auspressest": "auspressen",
    "auspresset": "auspressen",
    "auspreßt": "auspressen",
    "auspreßte": "auspressen",
    "auspreßten": "auspressen",
    "auspreßtest": "auspressen",
    "auspreßtet": "auspressen",
    "ausprobiere": "ausprobieren",
    "ausprobierend": "ausprobieren",
    "ausprobierende": "ausprobierend",
    "ausprobierendem": "ausprobierend",
    "ausprobierenden": "ausprobierend",
    "ausprobierender": "ausprobierend",
    "ausprobierendes": "ausprobierend",
    "ausprobierest": "ausprobieren",
    "ausprobieret": "ausprobieren",
    "ausprobierst": "ausprobieren",
    "ausprobiert": "ausprobieren",
    "ausprobierte": "ausprobieren",
    "ausprobiertem": "ausprobiert",
    "ausprobierten": "ausprobieren",
    "ausprobierter": "ausprobiert",
    "ausprobiertes": "ausprobiert",
    "ausprobiertest": "ausprobieren",
    "ausprobiertet": "ausprobieren",
    "auspräge": "ausprägen",
    "ausprägend": "ausprägen",
    "ausprägende": "ausprägend",
    "ausprägendem": "ausprägend",
    "ausprägenden": "ausprägend",
    "ausprägender": "ausprägend",
    "ausprägendere": "ausprägend",
    "ausprägenderem": "ausprägend",
    "ausprägenderen": "ausprägend",
    "ausprägenderer": "ausprägend",
    "ausprägenderes": "ausprägend",
    "ausprägendes": "ausprägend",
    "ausprägendste": "ausprägend",
    "ausprägendstem": "ausprägend",
    "ausprägendsten": "ausprägend",
    "ausprägendster": "ausprägend",
    "ausprägendstes": "ausprägend",
    "ausprägest": "ausprägen",
    "auspräget": "ausprägen",
    "ausprägst": "ausprägen",
    "ausprägt": "ausprägen",
    "ausprägte": "ausprägen",
    "ausprägten": "ausprägen",
    "ausprägtest": "ausprägen",
    "ausprägtet": "ausprägen",
    "auspumpe": "auspumpen",
    "auspumpend": "auspumpen",
    "auspumpende": "auspumpend",
    "auspumpendem": "auspumpend",
    "auspumpenden": "auspumpend",
    "auspumpender": "auspumpend",
    "auspumpendere": "auspumpend",
    "auspumpenderem": "auspumpend",
    "auspumpenderen": "auspumpend",
    "auspumpenderer": "auspumpend",
    "auspumpenderes": "auspumpend",
    "auspumpendes": "auspumpend",
    "auspumpendste": "auspumpend",
    "auspumpendstem": "auspumpend",
    "auspumpendsten": "auspumpend",
    "auspumpendster": "auspumpend",
    "auspumpendstes": "auspumpend",
    "auspumpest": "auspumpen",
    "auspumpet": "auspumpen",
    "auspumpst": "auspumpen",
    "auspumpt": "auspumpen",
    "auspumpte": "auspumpen",
    "auspumpten": "auspumpen",
    "auspumptest": "auspumpen",
    "auspumptet": "auspumpen",
    "auspuste": "auspusten",
    "auspustend": "auspusten",
    "auspustende": "auspustend",
    "auspustendem": "auspustend",
    "auspustenden": "auspustend",
    "auspustender": "auspustend",
    "auspustendes": "auspustend",
    "auspustest": "auspusten",
    "auspustet": "auspusten",
    "auspustete": "auspusten",
    "auspusteten": "auspusten",
    "auspustetest": "auspusten",
    "auspustetet": "auspusten",
    "ausputze": "ausputzen",
    "ausputzend": "ausputzen",
    "ausputzende": "ausputzend",
    "ausputzendem": "ausputzend",
    "ausputzenden": "ausputzend",
    "ausputzender": "ausputzend",
    "ausputzendes": "ausputzend",
    "ausputzest": "ausputzen",
    "ausputzet": "ausputzen",
    "ausputzt": "ausputzen",
    "ausputzte": "ausputzen",
    "ausputzten": "ausputzen",
    "ausputztest": "ausputzen",
    "ausputztet": "ausputzen",
    "ausquartiere": "ausquartieren",
    "ausquartierend": "ausquartieren",
    "ausquartierende": "ausquartierend",
    "ausquartierendem": "ausquartierend",
    "ausquartierenden": "ausquartierend",
    "ausquartierender": "ausquartierend",
    "ausquartierendes": "ausquartierend",
    "ausquartierest": "ausquartieren",
    "ausquartieret": "ausquartieren",
    "ausquartierst": "ausquartieren",
    "ausquartiert": "ausquartieren",
    "ausquartierte": "ausquartieren",
    "ausquartiertem": "ausquartiert",
    "ausquartierten": "ausquartieren",
    "ausquartierter": "ausquartiert",
    "ausquartiertes": "ausquartiert",
    "ausquartiertest": "ausquartieren",
    "ausquartiertet": "ausquartieren",
    "ausquatsche": "ausquatschen",
    "ausquatschend": "ausquatschen",
    "ausquatschende": "ausquatschend",
    "ausquatschendem": "ausquatschend",
    "ausquatschenden": "ausquatschend",
    "ausquatschender": "ausquatschend",
    "ausquatschendere": "ausquatschend",
    "ausquatschenderem": "ausquatschend",
    "ausquatschenderen": "ausquatschend",
    "ausquatschenderer": "ausquatschend",
    "ausquatschenderes": "ausquatschend",
    "ausquatschendes": "ausquatschend",
    "ausquatschendste": "ausquatschend",
    "ausquatschendstem": "ausquatschend",
    "ausquatschendsten": "ausquatschend",
    "ausquatschendster": "ausquatschend",
    "ausquatschendstes": "ausquatschend",
    "ausquatschest": "ausquatschen",
    "ausquatschet": "ausquatschen",
    "ausquatschst": "ausquatschen",
    "ausquatscht": "ausquatschen",
    "ausquatschte": "ausquatschen",
    "ausquatschten": "ausquatschen",
    "ausquatschtest": "ausquatschen",
    "ausquatschtet": "ausquatschen",
    "ausquetsche": "ausquetschen",
    "ausquetschend": "ausquetschen",
    "ausquetschende": "ausquetschend",
    "ausquetschendem": "ausquetschend",
    "ausquetschenden": "ausquetschend",
    "ausquetschender": "ausquetschend",
    "ausquetschendere": "ausquetschend",
    "ausquetschenderem": "ausquetschend",
    "ausquetschenderen": "ausquetschend",
    "ausquetschenderer": "ausquetschend",
    "ausquetschenderes": "ausquetschend",
    "ausquetschendes": "ausquetschend",
    "ausquetschendste": "ausquetschend",
    "ausquetschendstem": "ausquetschend",
    "ausquetschendsten": "ausquetschend",
    "ausquetschendster": "ausquetschend",
    "ausquetschendstes": "ausquetschend",
    "ausquetschest": "ausquetschen",
    "ausquetschet": "ausquetschen",
    "ausquetschst": "ausquetschen",
    "ausquetscht": "ausquetschen",
    "ausquetschte": "ausquetschen",
    "ausquetschten": "ausquetschen",
    "ausquetschtest": "ausquetschen",
    "ausquetschtet": "ausquetschen",
    "ausradiere": "ausradieren",
    "ausradierend": "ausradieren",
    "ausradierende": "ausradierend",
    "ausradierendem": "ausradierend",
    "ausradierenden": "ausradierend",
    "ausradierender": "ausradierend",
    "ausradierendes": "ausradierend",
    "ausradierest": "ausradieren",
    "ausradieret": "ausradieren",
    "ausradierst": "ausradieren",
    "ausradiert": "ausradieren",
    "ausradierte": "ausradieren",
    "ausradiertem": "ausradiert",
    "ausradierten": "ausradieren",
    "ausradierter": "ausradiert",
    "ausradiertes": "ausradiert",
    "ausradiertest": "ausradieren",
    "ausradiertet": "ausradieren",
    "ausrangiere": "ausrangieren",
    "ausrangierend": "ausrangieren",
    "ausrangierende": "ausrangierend",
    "ausrangierendem": "ausrangierend",
    "ausrangierenden": "ausrangierend",
    "ausrangierender": "ausrangierend",
    "ausrangierendes": "ausrangierend",
    "ausrangierest": "ausrangieren",
    "ausrangieret": "ausrangieren",
    "ausrangierst": "ausrangieren",
    "ausrangiert": "ausrangieren",
    "ausrangierte": "ausrangieren",
    "ausrangiertem": "ausrangiert",
    "ausrangierten": "ausrangieren",
    "ausrangierter": "ausrangiert",
    "ausrangiertes": "ausrangiert",
    "ausrangiertest": "ausrangieren",
    "ausrangiertet": "ausrangieren",
    "ausrasiere": "ausrasieren",
    "ausrasierend": "ausrasieren",
    "ausrasierende": "ausrasierend",
    "ausrasierendem": "ausrasierend",
    "ausrasierenden": "ausrasierend",
    "ausrasierender": "ausrasierend",
    "ausrasierendes": "ausrasierend",
    "ausrasierest": "ausrasieren",
    "ausrasieret": "ausrasieren",
    "ausrasierst": "ausrasieren",
    "ausrasiert": "ausrasieren",
    "ausrasierte": "ausrasieren",
    "ausrasiertem": "ausrasiert",
    "ausrasierten": "ausrasieren",
    "ausrasierter": "ausrasiert",
    "ausrasiertes": "ausrasiert",
    "ausrasiertest": "ausrasieren",
    "ausrasiertet": "ausrasieren",
    "ausraste": "ausrasten",
    "ausrastend": "ausrasten",
    "ausrastende": "ausrastend",
    "ausrastendem": "ausrastend",
    "ausrastenden": "ausrastend",
    "ausrastender": "ausrastend",
    "ausrastendere": "ausrastend",
    "ausrastenderem": "ausrastend",
    "ausrastenderen": "ausrastend",
    "ausrastenderer": "ausrastend",
    "ausrastenderes": "ausrastend",
    "ausrastendes": "ausrastend",
    "ausrastendste": "ausrastend",
    "ausrastendstem": "ausrastend",
    "ausrastendsten": "ausrastend",
    "ausrastendster": "ausrastend",
    "ausrastendstes": "ausrastend",
    "ausrastest": "ausrasten",
    "ausrastet": "ausrasten",
    "ausrastete": "ausrasten",
    "ausrasteten": "ausrasten",
    "ausrastetest": "ausrasten",
    "ausrastetet": "ausrasten",
    "ausraube": "ausrauben",
    "ausraubend": "ausrauben",
    "ausraubende": "ausraubend",
    "ausraubendem": "ausraubend",
    "ausraubenden": "ausraubend",
    "ausraubender": "ausraubend",
    "ausraubendes": "ausraubend",
    "ausraubest": "ausrauben",
    "ausraubet": "ausrauben",
    "ausraubst": "ausrauben",
    "ausraubt": "ausrauben",
    "ausraubte": "ausrauben",
    "ausraubten": "ausrauben",
    "ausraubtest": "ausrauben",
    "ausraubtet": "ausrauben",
    "ausrauche": "ausrauchen",
    "ausrauchend": "ausrauchen",
    "ausrauchende": "ausrauchend",
    "ausrauchendem": "ausrauchend",
    "ausrauchenden": "ausrauchend",
    "ausrauchender": "ausrauchend",
    "ausrauchendes": "ausrauchend",
    "ausrauchest": "ausrauchen",
    "ausrauchet": "ausrauchen",
    "ausrauchst": "ausrauchen",
    "ausraucht": "ausrauchen",
    "ausrauchte": "ausrauchen",
    "ausrauchten": "ausrauchen",
    "ausrauchtest": "ausrauchen",
    "ausrauchtet": "ausrauchen",
    "ausrechne": "ausrechnen",
    "ausrechnend": "ausrechnen",
    "ausrechnende": "ausrechnend",
    "ausrechnendem": "ausrechnend",
    "ausrechnenden": "ausrechnend",
    "ausrechnender": "ausrechnend",
    "ausrechnendes": "ausrechnend",
    "ausrechnest": "ausrechnen",
    "ausrechnet": "ausrechnen",
    "ausrechnete": "ausrechnen",
    "ausrechneten": "ausrechnen",
    "ausrechnetest": "ausrechnen",
    "ausrechnetet": "ausrechnen",
    "ausrede": "ausreden",
    "ausredend": "ausreden",
    "ausredende": "ausredend",
    "ausredendem": "ausredend",
    "ausredenden": "ausredend",
    "ausredender": "ausredend",
    "ausredendes": "ausredend",
    "ausredest": "ausreden",
    "ausredet": "ausreden",
    "ausredete": "ausreden",
    "ausredeten": "ausreden",
    "ausredetest": "ausreden",
    "ausredetet": "ausreden",
    "ausregne": "ausregnen",
    "ausregnend": "ausregnen",
    "ausregnende": "ausregnend",
    "ausregnendem": "ausregnend",
    "ausregnenden": "ausregnend",
    "ausregnender": "ausregnend",
    "ausregnendes": "ausregnend",
    "ausregnest": "ausregnen",
    "ausregnet": "ausregnen",
    "ausregnete": "ausregnen",
    "ausregneten": "ausregnen",
    "ausregnetest": "ausregnen",
    "ausregnetet": "ausregnen",
    "ausreibe": "ausreiben",
    "ausreibend": "ausreiben",
    "ausreibende": "ausreibend",
    "ausreibendem": "ausreibend",
    "ausreibenden": "ausreibend",
    "ausreibender": "ausreibend",
    "ausreibendes": "ausreibend",
    "ausreibest": "ausreiben",
    "ausreibet": "ausreiben",
    "ausreibst": "ausreiben",
    "ausreibt": "ausreiben",
    "ausreiche": "ausreichen",
    "ausreichend": "ausreichen",
    "ausreichende": "ausreichend",
    "ausreichendem": "ausreichend",
    "ausreichenden": "ausreichend",
    "ausreichender": "ausreichend",
    "ausreichendes": "ausreichend",
    "ausreichest": "ausreichen",
    "ausreichet": "ausreichen",
    "ausreichst": "ausreichen",
    "ausreicht": "ausreichen",
    "ausreichte": "ausreichen",
    "ausreichten": "ausreichen",
    "ausreichtest": "ausreichen",
    "ausreichtet": "ausreichen",
    "ausreife": "ausreifen",
    "ausreifend": "ausreifen",
    "ausreifende": "ausreifend",
    "ausreifendem": "ausreifend",
    "ausreifenden": "ausreifend",
    "ausreifender": "ausreifend",
    "ausreifendes": "ausreifend",
    "ausreifest": "ausreifen",
    "ausreifet": "ausreifen",
    "ausreifst": "ausreifen",
    "ausreift": "ausreifen",
    "ausreifte": "ausreifen",
    "ausreiften": "ausreifen",
    "ausreiftest": "ausreifen",
    "ausreiftet": "ausreifen",
    "ausreise": "ausreisen",
    "ausreisend": "ausreisen",
    "ausreisende": "ausreisend",
    "ausreisendem": "ausreisend",
    "ausreisenden": "ausreisend",
    "ausreisender": "ausreisend",
    "ausreisendes": "ausreisend",
    "ausreisest": "ausreisen",
    "ausreiset": "ausreisen",
    "ausreist": "ausreisen",
    "ausreiste": "ausreisen",
    "ausreisten": "ausreisen",
    "ausreistest": "ausreisen",
    "ausreistet": "ausreisen",
    "ausreite": "ausreiten",
    "ausreitend": "ausreiten",
    "ausreitende": "ausreitend",
    "ausreitendem": "ausreitend",
    "ausreitenden": "ausreitend",
    "ausreitender": "ausreitend",
    "ausreitendes": "ausreitend",
    "ausreitest": "ausreiten",
    "ausreitet": "ausreiten",
    "ausreize": "ausreizen",
    "ausreizend": "ausreizen",
    "ausreizende": "ausreizend",
    "ausreizendem": "ausreizend",
    "ausreizenden": "ausreizend",
    "ausreizender": "ausreizend",
    "ausreizendere": "ausreizend",
    "ausreizenderem": "ausreizend",
    "ausreizenderen": "ausreizend",
    "ausreizenderer": "ausreizend",
    "ausreizenderes": "ausreizend",
    "ausreizendes": "ausreizend",
    "ausreizendste": "ausreizend",
    "ausreizendstem": "ausreizend",
    "ausreizendsten": "ausreizend",
    "ausreizendster": "ausreizend",
    "ausreizendstes": "ausreizend",
    "ausreizest": "ausreizen",
    "ausreizet": "ausreizen",
    "ausreizt": "ausreizen",
    "ausreizte": "ausreizen",
    "ausreizten": "ausreizen",
    "ausreiztest": "ausreizen",
    "ausreiztet": "ausreizen",
    "ausreiße": "ausreißen",
    "ausreißend": "ausreißen",
    "ausreißende": "ausreißend",
    "ausreißendem": "ausreißend",
    "ausreißenden": "ausreißend",
    "ausreißender": "ausreißend",
    "ausreißendere": "ausreißend",
    "ausreißenderem": "ausreißend",
    "ausreißenderen": "ausreißend",
    "ausreißenderer": "ausreißend",
    "ausreißenderes": "ausreißend",
    "ausreißendes": "ausreißend",
    "ausreißendste": "ausreißend",
    "ausreißendstem": "ausreißend",
    "ausreißendsten": "ausreißend",
    "ausreißendster": "ausreißend",
    "ausreißendstes": "ausreißend",
    "ausreißest": "ausreißen",
    "ausreißet": "ausreißen",
    "ausreißt": "ausreißen",
    "ausrenke": "ausrenken",
    "ausrenkend": "ausrenken",
    "ausrenkende": "ausrenkend",
    "ausrenkendem": "ausrenkend",
    "ausrenkenden": "ausrenkend",
    "ausrenkender": "ausrenkend",
    "ausrenkendes": "ausrenkend",
    "ausrenkest": "ausrenken",
    "ausrenket": "ausrenken",
    "ausrenkst": "ausrenken",
    "ausrenkt": "ausrenken",
    "ausrenkte": "ausrenken",
    "ausrenkten": "ausrenken",
    "ausrenktest": "ausrenken",
    "ausrenktet": "ausrenken",
    "ausrichte": "ausrichten",
    "ausrichtend": "ausrichten",
    "ausrichtende": "ausrichtend",
    "ausrichtendem": "ausrichtend",
    "ausrichtenden": "ausrichtend",
    "ausrichtender": "ausrichtend",
    "ausrichtendes": "ausrichtend",
    "ausrichtest": "ausrichten",
    "ausrichtet": "ausrichten",
    "ausrichtete": "ausrichten",
    "ausrichteten": "ausrichten",
    "ausrichtetest": "ausrichten",
    "ausrichtetet": "ausrichten",
    "ausrieb": "ausreiben",
    "ausriebe": "ausreiben",
    "ausrieben": "ausreiben",
    "ausriebest": "ausreiben",
    "ausriebet": "ausreiben",
    "ausriebst": "ausreiben",
    "ausriebt": "ausreiben",
    "ausrief": "ausrufen",
    "ausriefe": "ausrufen",
    "ausriefen": "ausrufen",
    "ausriefest": "ausrufen",
    "ausriefet": "ausrufen",
    "ausriefst": "ausrufen",
    "ausrieft": "ausrufen",
    "ausrisse": "ausreißen",
    "ausrissen": "ausreißen",
    "ausrissest": "ausreißen",
    "ausrisset": "ausreißen",
    "ausritt": "ausreiten",
    "ausrittest": "ausreiten",
    "ausrittet": "ausreiten",
    "ausriß": "ausreißen",
    "ausrißt": "ausreißen",
    "ausrode": "ausroden",
    "ausrodend": "ausroden",
    "ausrodende": "ausrodend",
    "ausrodendem": "ausrodend",
    "ausrodenden": "ausrodend",
    "ausrodender": "ausrodend",
    "ausrodendere": "ausrodend",
    "ausrodenderem": "ausrodend",
    "ausrodenderen": "ausrodend",
    "ausrodenderer": "ausrodend",
    "ausrodenderes": "ausrodend",
    "ausrodendes": "ausrodend",
    "ausrodendste": "ausrodend",
    "ausrodendstem": "ausrodend",
    "ausrodendsten": "ausrodend",
    "ausrodendster": "ausrodend",
    "ausrodendstes": "ausrodend",
    "ausrodest": "ausroden",
    "ausrodet": "ausroden",
    "ausrodete": "ausroden",
    "ausrodeten": "ausroden",
    "ausrodetest": "ausroden",
    "ausrodetet": "ausroden",
    "ausrolle": "ausrollen",
    "ausrollend": "ausrollen",
    "ausrollende": "ausrollend",
    "ausrollendem": "ausrollend",
    "ausrollenden": "ausrollend",
    "ausrollender": "ausrollend",
    "ausrollendere": "ausrollend",
    "ausrollenderem": "ausrollend",
    "ausrollenderen": "ausrollend",
    "ausrollenderer": "ausrollend",
    "ausrollenderes": "ausrollend",
    "ausrollendes": "ausrollend",
    "ausrollendste": "ausrollend",
    "ausrollendstem": "ausrollend",
    "ausrollendsten": "ausrollend",
    "ausrollendster": "ausrollend",
    "ausrollendstes": "ausrollend",
    "ausrollest": "ausrollen",
    "ausrollet": "ausrollen",
    "ausrollst": "ausrollen",
    "ausrollt": "ausrollen",
    "ausrollte": "ausrollen",
    "ausrollten": "ausrollen",
    "ausrolltest": "ausrollen",
    "ausrolltet": "ausrollen",
    "ausrotte": "ausrotten",
    "ausrottend": "ausrotten",
    "ausrottende": "ausrottend",
    "ausrottendem": "ausrottend",
    "ausrottenden": "ausrottend",
    "ausrottender": "ausrottend",
    "ausrottendes": "ausrottend",
    "ausrottest": "ausrotten",
    "ausrottet": "ausrotten",
    "ausrottete": "ausrotten",
    "ausrotteten": "ausrotten",
    "ausrottetest": "ausrotten",
    "ausrottetet": "ausrotten",
    "ausrufend": "ausrufen",
    "ausrufende": "ausrufend",
    "ausrufendem": "ausrufend",
    "ausrufenden": "ausrufend",
    "ausrufender": "ausrufend",
    "ausrufendes": "ausrufend",
    "ausrufest": "ausrufen",
    "ausrufet": "ausrufen",
    "ausrufst": "ausrufen",
    "ausruft": "ausrufen",
    "ausruhe": "ausruhen",
    "ausruhend": "ausruhen",
    "ausruhende": "ausruhend",
    "ausruhendem": "ausruhend",
    "ausruhenden": "ausruhend",
    "ausruhender": "ausruhend",
    "ausruhendere": "ausruhend",
    "ausruhenderem": "ausruhend",
    "ausruhenderen": "ausruhend",
    "ausruhenderer": "ausruhend",
    "ausruhenderes": "ausruhend",
    "ausruhendes": "ausruhend",
    "ausruhendste": "ausruhend",
    "ausruhendstem": "ausruhend",
    "ausruhendsten": "ausruhend",
    "ausruhendster": "ausruhend",
    "ausruhendstes": "ausruhend",
    "ausruhest": "ausruhen",
    "ausruhet": "ausruhen",
    "ausruhst": "ausruhen",
    "ausruht": "ausruhen",
    "ausruhte": "ausruhen",
    "ausruhten": "ausruhen",
    "ausruhtest": "ausruhen",
    "ausruhtet": "ausruhen",
    "ausrupfe": "ausrupfen",
    "ausrupfend": "ausrupfen",
    "ausrupfende": "ausrupfend",
    "ausrupfendem": "ausrupfend",
    "ausrupfenden": "ausrupfend",
    "ausrupfender": "ausrupfend",
    "ausrupfendere": "ausrupfend",
    "ausrupfenderem": "ausrupfend",
    "ausrupfenderen": "ausrupfend",
    "ausrupfenderer": "ausrupfend",
    "ausrupfenderes": "ausrupfend",
    "ausrupfendes": "ausrupfend",
    "ausrupfendste": "ausrupfend",
    "ausrupfendstem": "ausrupfend",
    "ausrupfendsten": "ausrupfend",
    "ausrupfendster": "ausrupfend",
    "ausrupfendstes": "ausrupfend",
    "ausrupfest": "ausrupfen",
    "ausrupfet": "ausrupfen",
    "ausrupfst": "ausrupfen",
    "ausrupft": "ausrupfen",
    "ausrupfte": "ausrupfen",
    "ausrupften": "ausrupfen",
    "ausrupftest": "ausrupfen",
    "ausrupftet": "ausrupfen",
    "ausrutsche": "ausrutschen",
    "ausrutschend": "ausrutschen",
    "ausrutschende": "ausrutschend",
    "ausrutschendem": "ausrutschend",
    "ausrutschenden": "ausrutschend",
    "ausrutschender": "ausrutschend",
    "ausrutschendes": "ausrutschend",
    "ausrutschest": "ausrutschen",
    "ausrutschet": "ausrutschen",
    "ausrutschst": "ausrutschen",
    "ausrutscht": "ausrutschen",
    "ausrutschte": "ausrutschen",
    "ausrutschten": "ausrutschen",
    "ausrutschtest": "ausrutschen",
    "ausrutschtet": "ausrutschen",
    "ausräuchere": "ausräuchern",
    "ausräuchernd": "ausräuchern",
    "ausräuchernde": "ausräuchernd",
    "ausräucherndem": "ausräuchernd",
    "ausräuchernden": "ausräuchernd",
    "ausräuchernder": "ausräuchernd",
    "ausräucherndere": "ausräuchernd",
    "ausräuchernderem": "ausräuchernd",
    "ausräuchernderen": "ausräuchernd",
    "ausräuchernderer": "ausräuchernd",
    "ausräuchernderes": "ausräuchernd",
    "ausräucherndes": "ausräuchernd",
    "ausräucherndste": "ausräuchernd",
    "ausräucherndstem": "ausräuchernd",
    "ausräucherndsten": "ausräuchernd",
    "ausräucherndster": "ausräuchernd",
    "ausräucherndstes": "ausräuchernd",
    "ausräucherst": "ausräuchern",
    "ausräuchert": "ausräuchern",
    "ausräucherte": "ausräuchern",
    "ausräucherten": "ausräuchern",
    "ausräuchertest": "ausräuchern",
    "ausräuchertet": "ausräuchern",
    "ausräume": "ausräumen",
    "ausräumend": "ausräumen",
    "ausräumende": "ausräumend",
    "ausräumendem": "ausräumend",
    "ausräumenden": "ausräumend",
    "ausräumender": "ausräumend",
    "ausräumendes": "ausräumend",
    "ausräumest": "ausräumen",
    "ausräumet": "ausräumen",
    "ausräumst": "ausräumen",
    "ausräumt": "ausräumen",
    "ausräumte": "ausräumen",
    "ausräumten": "ausräumen",
    "ausräumtest": "ausräumen",
    "ausräumtet": "ausräumen",
    "ausrücke": "ausrücken",
    "ausrückend": "ausrücken",
    "ausrückende": "ausrückend",
    "ausrückendem": "ausrückend",
    "ausrückenden": "ausrückend",
    "ausrückender": "ausrückend",
    "ausrückendes": "ausrückend",
    "ausrückest": "ausrücken",
    "ausrücket": "ausrücken",
    "ausrückst": "ausrücken",
    "ausrückt": "ausrücken",
    "ausrückte": "ausrücken",
    "ausrückten": "ausrücken",
    "ausrücktest": "ausrücken",
    "ausrücktet": "ausrücken",
    "ausrüste": "ausrüsten",
    "ausrüstend": "ausrüsten",
    "ausrüstende": "ausrüstend",
    "ausrüstendem": "ausrüstend",
    "ausrüstenden": "ausrüstend",
    "ausrüstender": "ausrüstend",
    "ausrüstendes": "ausrüstend",
    "ausrüstest": "ausrüsten",
    "ausrüstet": "ausrüsten",
    "ausrüstete": "ausrüsten",
    "ausrüsteten": "ausrüsten",
    "ausrüstetest": "ausrüsten",
    "ausrüstetet": "ausrüsten",
    "aussage": "aussagen",
    "aussagend": "aussagen",
    "aussagende": "aussagend",
    "aussagendem": "aussagend",
    "aussagenden": "aussagend",
    "aussagender": "aussagend",
    "aussagendes": "aussagend",
    "aussagest": "aussagen",
    "aussaget": "aussagen",
    "aussagst": "aussagen",
    "aussagt": "aussagen",
    "aussagte": "aussagen",
    "aussagten": "aussagen",
    "aussagtest": "aussagen",
    "aussagtet": "aussagen",
    "aussah": "aussehen",
    "aussahen": "aussehen",
    "aussahst": "aussehen",
    "aussaht": "aussehen",
    "aussalze": "aussalzen",
    "aussalzend": "aussalzen",
    "aussalzende": "aussalzend",
    "aussalzendem": "aussalzend",
    "aussalzenden": "aussalzend",
    "aussalzender": "aussalzend",
    "aussalzendere": "aussalzend",
    "aussalzenderem": "aussalzend",
    "aussalzenderen": "aussalzend",
    "aussalzenderer": "aussalzend",
    "aussalzenderes": "aussalzend",
    "aussalzendes": "aussalzend",
    "aussalzendste": "aussalzend",
    "aussalzendstem": "aussalzend",
    "aussalzendsten": "aussalzend",
    "aussalzendster": "aussalzend",
    "aussalzendstes": "aussalzend",
    "aussalzest": "aussalzen",
    "aussalzet": "aussalzen",
    "aussalzt": "aussalzen",
    "aussalzte": "aussalzen",
    "aussalzten": "aussalzen",
    "aussalztest": "aussalzen",
    "aussalztet": "aussalzen",
    "aussandte": "aussenden",
    "aussandten": "aussenden",
    "aussandtest": "aussenden",
    "aussandtet": "aussenden",
    "aussaufe": "aussaufen",
    "aussaufend": "aussaufen",
    "aussaufende": "aussaufend",
    "aussaufendem": "aussaufend",
    "aussaufenden": "aussaufend",
    "aussaufender": "aussaufend",
    "aussaufendes": "aussaufend",
    "aussaufest": "aussaufen",
    "aussaufet": "aussaufen",
    "aussauft": "aussaufen",
    "aussauge": "aussaugen",
    "aussaugend": "aussaugen",
    "aussaugende": "aussaugend",
    "aussaugendem": "aussaugend",
    "aussaugenden": "aussaugend",
    "aussaugender": "aussaugend",
    "aussaugendes": "aussaugend",
    "aussaugest": "aussaugen",
    "aussauget": "aussaugen",
    "aussaugst": "aussaugen",
    "aussaugt": "aussaugen",
    "aussaugte": "aussaugen",
    "aussaugten": "aussaugen",
    "aussaugtest": "aussaugen",
    "aussaugtet": "aussaugen",
    "aussaß": "aussitzen",
    "aussaßen": "aussitzen",
    "aussaßt": "aussitzen",
    "ausschabe": "ausschaben",
    "ausschabend": "ausschaben",
    "ausschabende": "ausschabend",
    "ausschabendem": "ausschabend",
    "ausschabenden": "ausschabend",
    "ausschabender": "ausschabend",
    "ausschabendere": "ausschabend",
    "ausschabenderem": "ausschabend",
    "ausschabenderen": "ausschabend",
    "ausschabenderer": "ausschabend",
    "ausschabenderes": "ausschabend",
    "ausschabendes": "ausschabend",
    "ausschabendste": "ausschabend",
    "ausschabendstem": "ausschabend",
    "ausschabendsten": "ausschabend",
    "ausschabendster": "ausschabend",
    "ausschabendstes": "ausschabend",
    "ausschabest": "ausschaben",
    "ausschabet": "ausschaben",
    "ausschabst": "ausschaben",
    "ausschabt": "ausschaben",
    "ausschabte": "ausschaben",
    "ausschabten": "ausschaben",
    "ausschabtest": "ausschaben",
    "ausschabtet": "ausschaben",
    "ausschachtele": "ausschachteln",
    "ausschachtelnd": "ausschachteln",
    "ausschachtelnde": "ausschachtelnd",
    "ausschachtelndem": "ausschachtelnd",
    "ausschachtelnden": "ausschachtelnd",
    "ausschachtelnder": "ausschachtelnd",
    "ausschachtelndere": "ausschachtelnd",
    "ausschachtelnderem": "ausschachtelnd",
    "ausschachtelnderen": "ausschachtelnd",
    "ausschachtelnderer": "ausschachtelnd",
    "ausschachtelnderes": "ausschachtelnd",
    "ausschachtelndes": "ausschachtelnd",
    "ausschachtelndste": "ausschachtelnd",
    "ausschachtelndstem": "ausschachtelnd",
    "ausschachtelndsten": "ausschachtelnd",
    "ausschachtelndster": "ausschachtelnd",
    "ausschachtelndstes": "ausschachtelnd",
    "ausschachtelst": "ausschachteln",
    "ausschachtelt": "ausschachteln",
    "ausschachtelte": "ausschachteln",
    "ausschachtelten": "ausschachteln",
    "ausschachteltest": "ausschachteln",
    "ausschachteltet": "ausschachteln",
    "ausschachtle": "ausschachteln",
    "ausschale": "ausschalen",
    "ausschalend": "ausschalen",
    "ausschalende": "ausschalend",
    "ausschalendem": "ausschalend",
    "ausschalenden": "ausschalend",
    "ausschalender": "ausschalend",
    "ausschalendere": "ausschalend",
    "ausschalenderem": "ausschalend",
    "ausschalenderen": "ausschalend",
    "ausschalenderer": "ausschalend",
    "ausschalenderes": "ausschalend",
    "ausschalendes": "ausschalend",
    "ausschalendste": "ausschalend",
    "ausschalendstem": "ausschalend",
    "ausschalendsten": "ausschalend",
    "ausschalendster": "ausschalend",
    "ausschalendstes": "ausschalend",
    "ausschalest": "ausschalen",
    "ausschalet": "ausschalen",
    "ausschalst": "ausschalen",
    "ausschalt": "ausschelten",
    "ausschalte": "ausschalten",
    "ausschalten": "ausschalen",
    "ausschaltend": "ausschalten",
    "ausschaltende": "ausschaltend",
    "ausschaltendem": "ausschaltend",
    "ausschaltenden": "ausschaltend",
    "ausschaltender": "ausschaltend",
    "ausschaltendes": "ausschaltend",
    "ausschaltest": "ausschelten",
    "ausschaltet": "ausschelten",
    "ausschaltete": "ausschalten",
    "ausschalteten": "ausschalten",
    "ausschaltetest": "ausschalten",
    "ausschaltetet": "ausschalten",
    "ausscharre": "ausscharren",
    "ausscharrend": "ausscharren",
    "ausscharrende": "ausscharrend",
    "ausscharrendem": "ausscharrend",
    "ausscharrenden": "ausscharrend",
    "ausscharrender": "ausscharrend",
    "ausscharrendes": "ausscharrend",
    "ausscharrest": "ausscharren",
    "ausscharret": "ausscharren",
    "ausscharrst": "ausscharren",
    "ausscharrt": "ausscharren",
    "ausscharrte": "ausscharren",
    "ausscharrten": "ausscharren",
    "ausscharrtest": "ausscharren",
    "ausscharrtet": "ausscharren",
    "ausschaue": "ausschauen",
    "ausschauend": "ausschauen",
    "ausschauende": "ausschauend",
    "ausschauendem": "ausschauend",
    "ausschauenden": "ausschauend",
    "ausschauender": "ausschauend",
    "ausschauendes": "ausschauend",
    "ausschauest": "ausschauen",
    "ausschauet": "ausschauen",
    "ausschaufele": "ausschaufeln",
    "ausschaufelnd": "ausschaufeln",
    "ausschaufelnde": "ausschaufelnd",
    "ausschaufelndem": "ausschaufelnd",
    "ausschaufelnden": "ausschaufelnd",
    "ausschaufelnder": "ausschaufelnd",
    "ausschaufelndes": "ausschaufelnd",
    "ausschaufelst": "ausschaufeln",
    "ausschaufelt": "ausschaufeln",
    "ausschaufelte": "ausschaufeln",
    "ausschaufelten": "ausschaufeln",
    "ausschaufeltest": "ausschaufeln",
    "ausschaufeltet": "ausschaufeln",
    "ausschaufle": "ausschaufeln",
    "ausschaust": "ausschauen",
    "ausschaut": "ausschauen",
    "ausschaute": "ausschauen",
    "ausschauten": "ausschauen",
    "ausschautest": "ausschauen",
    "ausschautet": "ausschauen",
    "ausscheide": "ausscheiden",
    "ausscheidend": "ausscheiden",
    "ausscheidende": "ausscheidend",
    "ausscheidendem": "ausscheidend",
    "ausscheidenden": "ausscheidend",
    "ausscheidender": "ausscheidend",
    "ausscheidendes": "ausscheidend",
    "ausscheidest": "ausscheiden",
    "ausscheidet": "ausscheiden",
    "ausschelte": "ausschelten",
    "ausscheltend": "ausschelten",
    "ausscheltende": "ausscheltend",
    "ausscheltendem": "ausscheltend",
    "ausscheltenden": "ausscheltend",
    "ausscheltender": "ausscheltend",
    "ausscheltendere": "ausscheltend",
    "ausscheltenderem": "ausscheltend",
    "ausscheltenderen": "ausscheltend",
    "ausscheltenderer": "ausscheltend",
    "ausscheltenderes": "ausscheltend",
    "ausscheltendes": "ausscheltend",
    "ausscheltendste": "ausscheltend",
    "ausscheltendstem": "ausscheltend",
    "ausscheltendsten": "ausscheltend",
    "ausscheltendster": "ausscheltend",
    "ausscheltendstes": "ausscheltend",
    "ausscheltest": "ausschelten",
    "ausscheltet": "ausschelten",
    "ausschenke": "ausschenken",
    "ausschenkend": "ausschenken",
    "ausschenkende": "ausschenkend",
    "ausschenkendem": "ausschenkend",
    "ausschenkenden": "ausschenkend",
    "ausschenkender": "ausschenkend",
    "ausschenkendes": "ausschenkend",
    "ausschenkest": "ausschenken",
    "ausschenket": "ausschenken",
    "ausschenkst": "ausschenken",
    "ausschenkt": "ausschenken",
    "ausschenkte": "ausschenken",
    "ausschenkten": "ausschenken",
    "ausschenktest": "ausschenken",
    "ausschenktet": "ausschenken",
    "ausschere": "ausscheren",
    "ausscherend": "ausscheren",
    "ausscherende": "ausscherend",
    "ausscherendem": "ausscherend",
    "ausscherenden": "ausscherend",
    "ausscherender": "ausscherend",
    "ausscherendere": "ausscherend",
    "ausscherenderem": "ausscherend",
    "ausscherenderen": "ausscherend",
    "ausscherenderer": "ausscherend",
    "ausscherenderes": "ausscherend",
    "ausscherendes": "ausscherend",
    "ausscherendste": "ausscherend",
    "ausscherendstem": "ausscherend",
    "ausscherendsten": "ausscherend",
    "ausscherendster": "ausscherend",
    "ausscherendstes": "ausscherend",
    "ausscherest": "ausscheren",
    "ausscheret": "ausscheren",
    "ausscherst": "ausscheren",
    "ausschert": "ausscheren",
    "ausscherte": "ausscheren",
    "ausscherten": "ausscheren",
    "ausschertest": "ausscheren",
    "ausschertet": "ausscheren",
    "ausschied": "ausscheiden",
    "ausschiede": "ausscheiden",
    "ausschieden": "ausscheiden",
    "ausschiedest": "ausscheiden",
    "ausschiedet": "ausscheiden",
    "ausschieße": "ausschießen",
    "ausschießend": "ausschießen",
    "ausschießende": "ausschießend",
    "ausschießendem": "ausschießend",
    "ausschießenden": "ausschießend",
    "ausschießender": "ausschießend",
    "ausschießendes": "ausschießend",
    "ausschießest": "ausschießen",
    "ausschießet": "ausschießen",
    "ausschießt": "ausschießen",
    "ausschiffe": "ausschiffen",
    "ausschiffend": "ausschiffen",
    "ausschiffende": "ausschiffend",
    "ausschiffendem": "ausschiffend",
    "ausschiffenden": "ausschiffend",
    "ausschiffender": "ausschiffend",
    "ausschiffendes": "ausschiffend",
    "ausschiffest": "ausschiffen",
    "ausschiffet": "ausschiffen",
    "ausschiffst": "ausschiffen",
    "ausschifft": "ausschiffen",
    "ausschiffte": "ausschiffen",
    "ausschifften": "ausschiffen",
    "ausschifftest": "ausschiffen",
    "ausschifftet": "ausschiffen",
    "ausschildere": "ausschildern",
    "ausschildernd": "ausschildern",
    "ausschildernde": "ausschildernd",
    "ausschilderndem": "ausschildernd",
    "ausschildernden": "ausschildernd",
    "ausschildernder": "ausschildernd",
    "ausschilderndes": "ausschildernd",
    "ausschilderst": "ausschildern",
    "ausschildert": "ausschildern",
    "ausschilderte": "ausschildern",
    "ausschilderten": "ausschildern",
    "ausschildertest": "ausschildern",
    "ausschildertet": "ausschildern",
    "ausschilt": "ausschelten",
    "ausschiltst": "ausschelten",
    "ausschimpfe": "ausschimpfen",
    "ausschimpfend": "ausschimpfen",
    "ausschimpfende": "ausschimpfend",
    "ausschimpfendem": "ausschimpfend",
    "ausschimpfenden": "ausschimpfend",
    "ausschimpfender": "ausschimpfend",
    "ausschimpfendere": "ausschimpfend",
    "ausschimpfenderem": "ausschimpfend",
    "ausschimpfenderen": "ausschimpfend",
    "ausschimpfenderer": "ausschimpfend",
    "ausschimpfenderes": "ausschimpfend",
    "ausschimpfendes": "ausschimpfend",
    "ausschimpfendste": "ausschimpfend",
    "ausschimpfendstem": "ausschimpfend",
    "ausschimpfendsten": "ausschimpfend",
    "ausschimpfendster": "ausschimpfend",
    "ausschimpfendstes": "ausschimpfend",
    "ausschimpfest": "ausschimpfen",
    "ausschimpfet": "ausschimpfen",
    "ausschimpfst": "ausschimpfen",
    "ausschimpft": "ausschimpfen",
    "ausschimpfte": "ausschimpfen",
    "ausschimpften": "ausschimpfen",
    "ausschimpftest": "ausschimpfen",
    "ausschimpftet": "ausschimpfen",
    "ausschirre": "ausschirren",
    "ausschirrend": "ausschirren",
    "ausschirrende": "ausschirrend",
    "ausschirrendem": "ausschirrend",
    "ausschirrenden": "ausschirrend",
    "ausschirrender": "ausschirrend",
    "ausschirrendes": "ausschirrend",
    "ausschirrest": "ausschirren",
    "ausschirret": "ausschirren",
    "ausschirrst": "ausschirren",
    "ausschirrt": "ausschirren",
    "ausschirrte": "ausschirren",
    "ausschirrten": "ausschirren",
    "ausschirrtest": "ausschirren",
    "ausschirrtet": "ausschirren",
    "ausschlachte": "ausschlachten",
    "ausschlachtend": "ausschlachten",
    "ausschlachtende": "ausschlachtend",
    "ausschlachtendem": "ausschlachtend",
    "ausschlachtenden": "ausschlachtend",
    "ausschlachtender": "ausschlachtend",
    "ausschlachtendere": "ausschlachtend",
    "ausschlachtenderem": "ausschlachtend",
    "ausschlachtenderen": "ausschlachtend",
    "ausschlachtenderer": "ausschlachtend",
    "ausschlachtenderes": "ausschlachtend",
    "ausschlachtendes": "ausschlachtend",
    "ausschlachtendste": "ausschlachtend",
    "ausschlachtendstem": "ausschlachtend",
    "ausschlachtendsten": "ausschlachtend",
    "ausschlachtendster": "ausschlachtend",
    "ausschlachtendstes": "ausschlachtend",
    "ausschlachtest": "ausschlachten",
    "ausschlachtet": "ausschlachten",
    "ausschlachtete": "ausschlachten",
    "ausschlachteten": "ausschlachten",
    "ausschlachtetest": "ausschlachten",
    "ausschlachtetet": "ausschlachten",
    "ausschlafe": "ausschlafen",
    "ausschlafend": "ausschlafen",
    "ausschlafende": "ausschlafend",
    "ausschlafendem": "ausschlafend",
    "ausschlafenden": "ausschlafend",
    "ausschlafender": "ausschlafend",
    "ausschlafendes": "ausschlafend",
    "ausschlafest": "ausschlafen",
    "ausschlafet": "ausschlafen",
    "ausschlaft": "ausschlafen",
    "ausschlagend": "ausschlagen",
    "ausschlagende": "ausschlagend",
    "ausschlagendem": "ausschlagend",
    "ausschlagenden": "ausschlagend",
    "ausschlagender": "ausschlagend",
    "ausschlagendes": "ausschlagend",
    "ausschlagest": "ausschlagen",
    "ausschlaget": "ausschlagen",
    "ausschlaggebende": "ausschlaggebend",
    "ausschlaggebendem": "ausschlaggebend",
    "ausschlaggebenden": "ausschlaggebend",
    "ausschlaggebender": "ausschlaggebend",
    "ausschlaggebendes": "ausschlaggebend",
    "ausschlagt": "ausschlagen",
    "ausschleime": "ausschleimen",
    "ausschleimend": "ausschleimen",
    "ausschleimende": "ausschleimend",
    "ausschleimendem": "ausschleimend",
    "ausschleimenden": "ausschleimend",
    "ausschleimender": "ausschleimend",
    "ausschleimendere": "ausschleimend",
    "ausschleimenderem": "ausschleimend",
    "ausschleimenderen": "ausschleimend",
    "ausschleimenderer": "ausschleimend",
    "ausschleimenderes": "ausschleimend",
    "ausschleimendes": "ausschleimend",
    "ausschleimendste": "ausschleimend",
    "ausschleimendstem": "ausschleimend",
    "ausschleimendsten": "ausschleimend",
    "ausschleimendster": "ausschleimend",
    "ausschleimendstes": "ausschleimend",
    "ausschleimest": "ausschleimen",
    "ausschleimet": "ausschleimen",
    "ausschleimst": "ausschleimen",
    "ausschleimt": "ausschleimen",
    "ausschleimte": "ausschleimen",
    "ausschleimten": "ausschleimen",
    "ausschleimtest": "ausschleimen",
    "ausschleimtet": "ausschleimen",
    "ausschlief": "ausschlafen",
    "ausschliefe": "ausschlafen",
    "ausschliefen": "ausschlafen",
    "ausschliefest": "ausschlafen",
    "ausschliefet": "ausschlafen",
    "ausschliefst": "ausschlafen",
    "ausschlieft": "ausschlafen",
    "ausschließe": "ausschließen",
    "ausschließend": "ausschließen",
    "ausschließende": "ausschließend",
    "ausschließendem": "ausschließend",
    "ausschließenden": "ausschließend",
    "ausschließender": "ausschließend",
    "ausschließendes": "ausschließend",
    "ausschließest": "ausschließen",
    "ausschließet": "ausschließen",
    "ausschließliche": "ausschließlich",
    "ausschließlichem": "ausschließlich",
    "ausschließlichen": "ausschließlich",
    "ausschließlicher": "ausschließlich",
    "ausschließliches": "ausschließlich",
    "ausschließt": "ausschließen",
    "ausschlossen": "ausschließen",
    "ausschloß": "ausschließen",
    "ausschloßt": "ausschließen",
    "ausschlug": "ausschlagen",
    "ausschlugen": "ausschlagen",
    "ausschlugst": "ausschlagen",
    "ausschlugt": "ausschlagen",
    "ausschläfst": "ausschlafen",
    "ausschläft": "ausschlafen",
    "ausschlägst": "ausschlagen",
    "ausschlägt": "ausschlagen",
    "ausschlämme": "ausschlämmen",
    "ausschlämmend": "ausschlämmen",
    "ausschlämmende": "ausschlämmend",
    "ausschlämmendem": "ausschlämmend",
    "ausschlämmenden": "ausschlämmend",
    "ausschlämmender": "ausschlämmend",
    "ausschlämmendes": "ausschlämmend",
    "ausschlämmest": "ausschlämmen",
    "ausschlämmet": "ausschlämmen",
    "ausschlämmst": "ausschlämmen",
    "ausschlämmt": "ausschlämmen",
    "ausschlämmte": "ausschlämmen",
    "ausschlämmten": "ausschlämmen",
    "ausschlämmtest": "ausschlämmen",
    "ausschlämmtet": "ausschlämmen",
    "ausschlösse": "ausschließen",
    "ausschlössen": "ausschließen",
    "ausschlössest": "ausschließen",
    "ausschlösset": "ausschließen",
    "ausschlüge": "ausschlagen",
    "ausschlügen": "ausschlagen",
    "ausschlügest": "ausschlagen",
    "ausschlüget": "ausschlagen",
    "ausschlüpfend": "ausschlüpfen",
    "ausschlüpfende": "ausschlüpfend",
    "ausschlüpfendem": "ausschlüpfend",
    "ausschlüpfenden": "ausschlüpfend",
    "ausschlüpfender": "ausschlüpfend",
    "ausschlüpfendes": "ausschlüpfend",
    "ausschlüpfest": "ausschlüpfen",
    "ausschlüpfet": "ausschlüpfen",
    "ausschlüpfst": "ausschlüpfen",
    "ausschlüpft": "ausschlüpfen",
    "ausschlüpfte": "ausschlüpfen",
    "ausschlüpften": "ausschlüpfen",
    "ausschlüpftest": "ausschlüpfen",
    "ausschlüpftet": "ausschlüpfen",
    "ausschlürfe": "ausschlürfen",
    "ausschlürfend": "ausschlürfen",
    "ausschlürfende": "ausschlürfend",
    "ausschlürfendem": "ausschlürfend",
    "ausschlürfenden": "ausschlürfend",
    "ausschlürfender": "ausschlürfend",
    "ausschlürfendes": "ausschlürfend",
    "ausschlürfest": "ausschlürfen",
    "ausschlürfet": "ausschlürfen",
    "ausschlürfst": "ausschlürfen",
    "ausschlürft": "ausschlürfen",
    "ausschlürfte": "ausschlürfen",
    "ausschlürften": "ausschlürfen",
    "ausschlürftest": "ausschlürfen",
    "ausschlürftet": "ausschlürfen",
    "ausschmelze": "ausschmelzen",
    "ausschmelzend": "ausschmelzen",
    "ausschmelzende": "ausschmelzend",
    "ausschmelzendem": "ausschmelzend",
    "ausschmelzenden": "ausschmelzend",
    "ausschmelzender": "ausschmelzend",
    "ausschmelzendes": "ausschmelzend",
    "ausschmelzest": "ausschmelzen",
    "ausschmelzet": "ausschmelzen",
    "ausschmelzt": "ausschmelzen",
    "ausschmiere": "ausschmieren",
    "ausschmierend": "ausschmieren",
    "ausschmierende": "ausschmierend",
    "ausschmierendem": "ausschmierend",
    "ausschmierenden": "ausschmierend",
    "ausschmierender": "ausschmierend",
    "ausschmierendes": "ausschmierend",
    "ausschmierest": "ausschmieren",
    "ausschmieret": "ausschmieren",
    "ausschmierst": "ausschmieren",
    "ausschmiert": "ausschmieren",
    "ausschmierte": "ausschmieren",
    "ausschmierten": "ausschmieren",
    "ausschmiertest": "ausschmieren",
    "ausschmiertet": "ausschmieren",
    "ausschmilzt": "ausschmelzen",
    "ausschmolz": "ausschmelzen",
    "ausschmolzen": "ausschmelzen",
    "ausschmolzst": "ausschmelzen",
    "ausschmolzt": "ausschmelzen",
    "ausschmölze": "ausschmelzen",
    "ausschmölzen": "ausschmelzen",
    "ausschmölzest": "ausschmelzen",
    "ausschmölzet": "ausschmelzen",
    "ausschnappe": "ausschnappen",
    "ausschnappend": "ausschnappen",
    "ausschnappende": "ausschnappend",
    "ausschnappendem": "ausschnappend",
    "ausschnappenden": "ausschnappend",
    "ausschnappender": "ausschnappend",
    "ausschnappendes": "ausschnappend",
    "ausschnappest": "ausschnappen",
    "ausschnappet": "ausschnappen",
    "ausschnappst": "ausschnappen",
    "ausschnappt": "ausschnappen",
    "ausschnappte": "ausschnappen",
    "ausschnappten": "ausschnappen",
    "ausschnapptest": "ausschnappen",
    "ausschnapptet": "ausschnappen",
    "ausschnaube": "ausschnauben",
    "ausschnaubend": "ausschnauben",
    "ausschnaubende": "ausschnaubend",
    "ausschnaubendem": "ausschnaubend",
    "ausschnaubenden": "ausschnaubend",
    "ausschnaubender": "ausschnaubend",
    "ausschnaubendere": "ausschnaubend",
    "ausschnaubenderem": "ausschnaubend",
    "ausschnaubenderen": "ausschnaubend",
    "ausschnaubenderer": "ausschnaubend",
    "ausschnaubenderes": "ausschnaubend",
    "ausschnaubendes": "ausschnaubend",
    "ausschnaubendste": "ausschnaubend",
    "ausschnaubendstem": "ausschnaubend",
    "ausschnaubendsten": "ausschnaubend",
    "ausschnaubendster": "ausschnaubend",
    "ausschnaubendstes": "ausschnaubend",
    "ausschnaubest": "ausschnauben",
    "ausschnaubet": "ausschnauben",
    "ausschnaubst": "ausschnauben",
    "ausschnaubt": "ausschnauben",
    "ausschnaubte": "ausschnauben",
    "ausschnaubten": "ausschnauben",
    "ausschnaubtest": "ausschnauben",
    "ausschnaubtet": "ausschnauben",
    "ausschnaufe": "ausschnaufen",
    "ausschnaufend": "ausschnaufen",
    "ausschnaufende": "ausschnaufend",
    "ausschnaufendem": "ausschnaufend",
    "ausschnaufenden": "ausschnaufend",
    "ausschnaufender": "ausschnaufend",
    "ausschnaufendere": "ausschnaufend",
    "ausschnaufenderem": "ausschnaufend",
    "ausschnaufenderen": "ausschnaufend",
    "ausschnaufenderer": "ausschnaufend",
    "ausschnaufenderes": "ausschnaufend",
    "ausschnaufendes": "ausschnaufend",
    "ausschnaufendste": "ausschnaufend",
    "ausschnaufendstem": "ausschnaufend",
    "ausschnaufendsten": "ausschnaufend",
    "ausschnaufendster": "ausschnaufend",
    "ausschnaufendstes": "ausschnaufend",
    "ausschnaufest": "ausschnaufen",
    "ausschnaufet": "ausschnaufen",
    "ausschnaufst": "ausschnaufen",
    "ausschnauft": "ausschnaufen",
    "ausschnaufte": "ausschnaufen",
    "ausschnauften": "ausschnaufen",
    "ausschnauftest": "ausschnaufen",
    "ausschnauftet": "ausschnaufen",
    "ausschneide": "ausschneiden",
    "ausschneidend": "ausschneiden",
    "ausschneidende": "ausschneidend",
    "ausschneidendem": "ausschneidend",
    "ausschneidenden": "ausschneidend",
    "ausschneidender": "ausschneidend",
    "ausschneidendes": "ausschneidend",
    "ausschneidest": "ausschneiden",
    "ausschneidet": "ausschneiden",
    "ausschneuze": "ausschneuzen",
    "ausschneuzend": "ausschneuzen",
    "ausschneuzende": "ausschneuzend",
    "ausschneuzendem": "ausschneuzend",
    "ausschneuzenden": "ausschneuzend",
    "ausschneuzender": "ausschneuzend",
    "ausschneuzendes": "ausschneuzend",
    "ausschneuzest": "ausschneuzen",
    "ausschneuzet": "ausschneuzen",
    "ausschneuzt": "ausschneuzen",
    "ausschneuzte": "ausschneuzen",
    "ausschneuzten": "ausschneuzen",
    "ausschneuztest": "ausschneuzen",
    "ausschneuztet": "ausschneuzen",
    "ausschnitt": "ausschneiden",
    "ausschnittest": "ausschneiden",
    "ausschnittet": "ausschneiden",
    "ausschnäuze": "ausschnäuzen",
    "ausschnäuzend": "ausschnäuzen",
    "ausschnäuzende": "ausschnäuzend",
    "ausschnäuzendem": "ausschnäuzend",
    "ausschnäuzenden": "ausschnäuzend",
    "ausschnäuzender": "ausschnäuzend",
    "ausschnäuzendes": "ausschnäuzend",
    "ausschnäuzest": "ausschnäuzen",
    "ausschnäuzet": "ausschnäuzen",
    "ausschnäuzt": "ausschnäuzen",
    "ausschnäuzte": "ausschnäuzen",
    "ausschnäuzten": "ausschnäuzen",
    "ausschnäuztest": "ausschnäuzen",
    "ausschnäuztet": "ausschnäuzen",
    "ausschor": "ausscheren",
    "ausschoren": "ausscheren",
    "ausschorst": "ausscheren",
    "ausschort": "ausscheren",
    "ausschossen": "ausschießen",
    "ausschoß": "ausschießen",
    "ausschoßt": "ausschießen",
    "ausschraube": "ausschrauben",
    "ausschraubend": "ausschrauben",
    "ausschraubende": "ausschraubend",
    "ausschraubendem": "ausschraubend",
    "ausschraubenden": "ausschraubend",
    "ausschraubender": "ausschraubend",
    "ausschraubendes": "ausschraubend",
    "ausschraubest": "ausschrauben",
    "ausschraubet": "ausschrauben",
    "ausschraubst": "ausschrauben",
    "ausschraubt": "ausschrauben",
    "ausschraubte": "ausschrauben",
    "ausschraubten": "ausschrauben",
    "ausschraubtest": "ausschrauben",
    "ausschraubtet": "ausschrauben",
    "ausschreibe": "ausschreiben",
    "ausschreibend": "ausschreiben",
    "ausschreibende": "ausschreibend",
    "ausschreibendem": "ausschreibend",
    "ausschreibenden": "ausschreibend",
    "ausschreibender": "ausschreibend",
    "ausschreibendes": "ausschreibend",
    "ausschreibest": "ausschreiben",
    "ausschreibet": "ausschreiben",
    "ausschreibst": "ausschreiben",
    "ausschreibt": "ausschreiben",
    "ausschreie": "ausschreien",
    "ausschreiend": "ausschreien",
    "ausschreiende": "ausschreiend",
    "ausschreiendem": "ausschreiend",
    "ausschreienden": "ausschreiend",
    "ausschreiender": "ausschreiend",
    "ausschreiendere": "ausschreiend",
    "ausschreienderem": "ausschreiend",
    "ausschreienderen": "ausschreiend",
    "ausschreienderer": "ausschreiend",
    "ausschreienderes": "ausschreiend",
    "ausschreiendes": "ausschreiend",
    "ausschreiendste": "ausschreiend",
    "ausschreiendstem": "ausschreiend",
    "ausschreiendsten": "ausschreiend",
    "ausschreiendster": "ausschreiend",
    "ausschreiendstes": "ausschreiend",
    "ausschreiest": "ausschreien",
    "ausschreiet": "ausschreien",
    "ausschreist": "ausschreien",
    "ausschreit": "ausschreien",
    "ausschreitend": "ausschreiten",
    "ausschreitende": "ausschreitend",
    "ausschreitendem": "ausschreitend",
    "ausschreitenden": "ausschreitend",
    "ausschreitender": "ausschreitend",
    "ausschreitendes": "ausschreitend",
    "ausschrie": "ausschreien",
    "ausschrieb": "ausschreiben",
    "ausschriebe": "ausschreiben",
    "ausschrieben": "ausschreiben",
    "ausschriebest": "ausschreiben",
    "ausschriebet": "ausschreiben",
    "ausschriebst": "ausschreiben",
    "ausschriebt": "ausschreiben",
    "ausschriee": "ausschreien",
    "ausschrieen": "ausschreien",
    "ausschrieest": "ausschreien",
    "ausschrieet": "ausschreien",
    "ausschrien": "ausschreien",
    "ausschriest": "ausschreien",
    "ausschriet": "ausschreien",
    "ausschule": "ausschulen",
    "ausschulend": "ausschulen",
    "ausschulende": "ausschulend",
    "ausschulendem": "ausschulend",
    "ausschulenden": "ausschulend",
    "ausschulender": "ausschulend",
    "ausschulendes": "ausschulend",
    "ausschulest": "ausschulen",
    "ausschulet": "ausschulen",
    "ausschulst": "ausschulen",
    "ausschult": "ausschulen",
    "ausschulte": "ausschulen",
    "ausschulten": "ausschulen",
    "ausschultest": "ausschulen",
    "ausschultet": "ausschulen",
    "ausschwang": "ausschwingen",
    "ausschwangen": "ausschwingen",
    "ausschwangst": "ausschwingen",
    "ausschwangt": "ausschwingen",
    "ausschwefele": "ausschwefeln",
    "ausschwefelnd": "ausschwefeln",
    "ausschwefelnde": "ausschwefelnd",
    "ausschwefelndem": "ausschwefelnd",
    "ausschwefelnden": "ausschwefelnd",
    "ausschwefelnder": "ausschwefelnd",
    "ausschwefelndere": "ausschwefelnd",
    "ausschwefelnderem": "ausschwefelnd",
    "ausschwefelnderen": "ausschwefelnd",
    "ausschwefelnderer": "ausschwefelnd",
    "ausschwefelnderes": "ausschwefelnd",
    "ausschwefelndes": "ausschwefelnd",
    "ausschwefelndste": "ausschwefelnd",
    "ausschwefelndstem": "ausschwefelnd",
    "ausschwefelndsten": "ausschwefelnd",
    "ausschwefelndster": "ausschwefelnd",
    "ausschwefelndstes": "ausschwefelnd",
    "ausschwefelst": "ausschwefeln",
    "ausschwefelt": "ausschwefeln",
    "ausschwefelte": "ausschwefeln",
    "ausschwefelten": "ausschwefeln",
    "ausschwefeltest": "ausschwefeln",
    "ausschwefeltet": "ausschwefeln",
    "ausschwefle": "ausschwefeln",
    "ausschweife": "ausschweifen",
    "ausschweifend": "ausschweifen",
    "ausschweifende": "ausschweifend",
    "ausschweifendem": "ausschweifend",
    "ausschweifenden": "ausschweifend",
    "ausschweifender": "ausschweifend",
    "ausschweifendere": "ausschweifend",
    "ausschweifenderem": "ausschweifend",
    "ausschweifenderen": "ausschweifend",
    "ausschweifenderer": "ausschweifend",
    "ausschweifenderes": "ausschweifend",
    "ausschweifendes": "ausschweifend",
    "ausschweifendste": "ausschweifend",
    "ausschweifendstem": "ausschweifend",
    "ausschweifendsten": "ausschweifend",
    "ausschweifendster": "ausschweifend",
    "ausschweifendstes": "ausschweifend",
    "ausschweifest": "ausschweifen",
    "ausschweifet": "ausschweifen",
    "ausschweifst": "ausschweifen",
    "ausschweift": "ausschweifen",
    "ausschweifte": "ausschweifen",
    "ausschweiften": "ausschweifen",
    "ausschweiftest": "ausschweifen",
    "ausschweiftet": "ausschweifen",
    "ausschweige": "ausschweigen",
    "ausschweigend": "ausschweigen",
    "ausschweigende": "ausschweigend",
    "ausschweigendem": "ausschweigend",
    "ausschweigenden": "ausschweigend",
    "ausschweigender": "ausschweigend",
    "ausschweigendere": "ausschweigend",
    "ausschweigenderem": "ausschweigend",
    "ausschweigenderen": "ausschweigend",
    "ausschweigenderer": "ausschweigend",
    "ausschweigenderes": "ausschweigend",
    "ausschweigendes": "ausschweigend",
    "ausschweigendste": "ausschweigend",
    "ausschweigendstem": "ausschweigend",
    "ausschweigendsten": "ausschweigend",
    "ausschweigendster": "ausschweigend",
    "ausschweigendstes": "ausschweigend",
    "ausschweigest": "ausschweigen",
    "ausschweiget": "ausschweigen",
    "ausschweigst": "ausschweigen",
    "ausschweigt": "ausschweigen",
    "ausschwemme": "ausschwemmen",
    "ausschwemmend": "ausschwemmen",
    "ausschwemmende": "ausschwemmend",
    "ausschwemmendem": "ausschwemmend",
    "ausschwemmenden": "ausschwemmend",
    "ausschwemmender": "ausschwemmend",
    "ausschwemmendere": "ausschwemmend",
    "ausschwemmenderem": "ausschwemmend",
    "ausschwemmenderen": "ausschwemmend",
    "ausschwemmenderer": "ausschwemmend",
    "ausschwemmenderes": "ausschwemmend",
    "ausschwemmendes": "ausschwemmend",
    "ausschwemmendste": "ausschwemmend",
    "ausschwemmendstem": "ausschwemmend",
    "ausschwemmendsten": "ausschwemmend",
    "ausschwemmendster": "ausschwemmend",
    "ausschwemmendstes": "ausschwemmend",
    "ausschwemmest": "ausschwemmen",
    "ausschwemmet": "ausschwemmen",
    "ausschwemmst": "ausschwemmen",
    "ausschwemmt": "ausschwemmen",
    "ausschwemmte": "ausschwemmen",
    "ausschwemmten": "ausschwemmen",
    "ausschwemmtest": "ausschwemmen",
    "ausschwemmtet": "ausschwemmen",
    "ausschwenke": "ausschwenken",
    "ausschwenkend": "ausschwenken",
    "ausschwenkende": "ausschwenkend",
    "ausschwenkendem": "ausschwenkend",
    "ausschwenkenden": "ausschwenkend",
    "ausschwenkender": "ausschwenkend",
    "ausschwenkendes": "ausschwenkend",
    "ausschwenkest": "ausschwenken",
    "ausschwenket": "ausschwenken",
    "ausschwenkst": "ausschwenken",
    "ausschwenkt": "ausschwenken",
    "ausschwenkte": "ausschwenken",
    "ausschwenkten": "ausschwenken",
    "ausschwenktest": "ausschwenken",
    "ausschwenktet": "ausschwenken",
    "ausschwieg": "ausschweigen",
    "ausschwiege": "ausschweigen",
    "ausschwiegen": "ausschweigen",
    "ausschwiegest": "ausschweigen",
    "ausschwieget": "ausschweigen",
    "ausschwiegst": "ausschweigen",
    "ausschwiegt": "ausschweigen",
    "ausschwinge": "ausschwingen",
    "ausschwingend": "ausschwingen",
    "ausschwingende": "ausschwingend",
    "ausschwingendem": "ausschwingend",
    "ausschwingenden": "ausschwingend",
    "ausschwingender": "ausschwingend",
    "ausschwingendes": "ausschwingend",
    "ausschwingest": "ausschwingen",
    "ausschwinget": "ausschwingen",
    "ausschwingst": "ausschwingen",
    "ausschwingt": "ausschwingen",
    "ausschwitze": "ausschwitzen",
    "ausschwitzend": "ausschwitzen",
    "ausschwitzende": "ausschwitzend",
    "ausschwitzendem": "ausschwitzend",
    "ausschwitzenden": "ausschwitzend",
    "ausschwitzender": "ausschwitzend",
    "ausschwitzendere": "ausschwitzend",
    "ausschwitzenderem": "ausschwitzend",
    "ausschwitzenderen": "ausschwitzend",
    "ausschwitzenderer": "ausschwitzend",
    "ausschwitzenderes": "ausschwitzend",
    "ausschwitzendes": "ausschwitzend",
    "ausschwitzendste": "ausschwitzend",
    "ausschwitzendstem": "ausschwitzend",
    "ausschwitzendsten": "ausschwitzend",
    "ausschwitzendster": "ausschwitzend",
    "ausschwitzendstes": "ausschwitzend",
    "ausschwitzest": "ausschwitzen",
    "ausschwitzet": "ausschwitzen",
    "ausschwitzt": "ausschwitzen",
    "ausschwitzte": "ausschwitzen",
    "ausschwitzten": "ausschwitzen",
    "ausschwitztest": "ausschwitzen",
    "ausschwitztet": "ausschwitzen",
    "ausschwänge": "ausschwingen",
    "ausschwängen": "ausschwingen",
    "ausschwängest": "ausschwingen",
    "ausschwänget": "ausschwingen",
    "ausschwärme": "ausschwärmen",
    "ausschwärmend": "ausschwärmen",
    "ausschwärmende": "ausschwärmend",
    "ausschwärmendem": "ausschwärmend",
    "ausschwärmenden": "ausschwärmend",
    "ausschwärmender": "ausschwärmend",
    "ausschwärmendes": "ausschwärmend",
    "ausschwärmest": "ausschwärmen",
    "ausschwärmet": "ausschwärmen",
    "ausschwärmst": "ausschwärmen",
    "ausschwärmt": "ausschwärmen",
    "ausschwärmte": "ausschwärmen",
    "ausschwärmten": "ausschwärmen",
    "ausschwärmtest": "ausschwärmen",
    "ausschwärmtet": "ausschwärmen",
    "ausschäle": "ausschälen",
    "ausschälend": "ausschälen",
    "ausschälendem": "ausschälend",
    "ausschälender": "ausschälend",
    "ausschälendes": "ausschälend",
    "ausschälest": "ausschälen",
    "ausschälet": "ausschälen",
    "ausschälst": "ausschälen",
    "ausschält": "ausschälen",
    "ausschälte": "ausschälen",
    "ausschälten": "ausschälen",
    "ausschältest": "ausschälen",
    "ausschältet": "ausschälen",
    "ausschölte": "ausschelten",
    "ausschölten": "ausschelten",
    "ausschöltest": "ausschelten",
    "ausschöltet": "ausschelten",
    "ausschöpfe": "ausschöpfen",
    "ausschöpfend": "ausschöpfen",
    "ausschöpfende": "ausschöpfend",
    "ausschöpfendem": "ausschöpfend",
    "ausschöpfenden": "ausschöpfend",
    "ausschöpfender": "ausschöpfend",
    "ausschöpfendere": "ausschöpfend",
    "ausschöpfenderem": "ausschöpfend",
    "ausschöpfenderen": "ausschöpfend",
    "ausschöpfenderer": "ausschöpfend",
    "ausschöpfenderes": "ausschöpfend",
    "ausschöpfendes": "ausschöpfend",
    "ausschöpfendste": "ausschöpfend",
    "ausschöpfendstem": "ausschöpfend",
    "ausschöpfendsten": "ausschöpfend",
    "ausschöpfendster": "ausschöpfend",
    "ausschöpfendstes": "ausschöpfend",
    "ausschöpfest": "ausschöpfen",
    "ausschöpfet": "ausschöpfen",
    "ausschöpfst": "ausschöpfen",
    "ausschöpft": "ausschöpfen",
    "ausschöpfte": "ausschöpfen",
    "ausschöpften": "ausschöpfen",
    "ausschöpftest": "ausschöpfen",
    "ausschöpftet": "ausschöpfen",
    "ausschöre": "ausscheren",
    "ausschören": "ausscheren",
    "ausschörest": "ausscheren",
    "ausschöret": "ausscheren",
    "ausschösse": "ausschießen",
    "ausschössen": "ausschießen",
    "ausschössest": "ausschießen",
    "ausschösset": "ausschießen",
    "ausschütte": "ausschütten",
    "ausschüttele": "ausschütteln",
    "ausschüttelnd": "ausschütteln",
    "ausschüttelnde": "ausschüttelnd",
    "ausschüttelndem": "ausschüttelnd",
    "ausschüttelnden": "ausschüttelnd",
    "ausschüttelnder": "ausschüttelnd",
    "ausschüttelndere": "ausschüttelnd",
    "ausschüttelnderem": "ausschüttelnd",
    "ausschüttelnderen": "ausschüttelnd",
    "ausschüttelnderer": "ausschüttelnd",
    "ausschüttelnderes": "ausschüttelnd",
    "ausschüttelndes": "ausschüttelnd",
    "ausschüttelndste": "ausschüttelnd",
    "ausschüttelndstem": "ausschüttelnd",
    "ausschüttelndsten": "ausschüttelnd",
    "ausschüttelndster": "ausschüttelnd",
    "ausschüttelndstes": "ausschüttelnd",
    "ausschüttelst": "ausschütteln",
    "ausschüttelt": "ausschütteln",
    "ausschüttelte": "ausschütteln",
    "ausschüttelten": "ausschütteln",
    "ausschütteltest": "ausschütteln",
    "ausschütteltet": "ausschütteln",
    "ausschüttend": "ausschütten",
    "ausschüttende": "ausschüttend",
    "ausschüttendem": "ausschüttend",
    "ausschüttenden": "ausschüttend",
    "ausschüttender": "ausschüttend",
    "ausschüttendes": "ausschüttend",
    "ausschüttest": "ausschütten",
    "ausschüttet": "ausschütten",
    "ausschüttete": "ausschütten",
    "ausschütteten": "ausschütten",
    "ausschüttetest": "ausschütten",
    "ausschüttetet": "ausschütten",
    "ausschüttle": "ausschütteln",
    "aussehe": "aussehen",
    "aussehend": "aussehen",
    "aussehende": "aussehend",
    "aussehendem": "aussehend",
    "aussehenden": "aussehend",
    "aussehender": "aussehend",
    "aussehendes": "aussehend",
    "aussehest": "aussehen",
    "aussehet": "aussehen",
    "ausseht": "aussehen",
    "aussende": "aussenden",
    "aussendend": "aussenden",
    "aussendende": "aussendend",
    "aussendendem": "aussendend",
    "aussendenden": "aussendend",
    "aussendender": "aussendend",
    "aussendendes": "aussendend",
    "aussendest": "aussenden",
    "aussendet": "aussenden",
    "aussendete": "aussenden",
    "aussendeten": "aussenden",
    "aussendetest": "aussenden",
    "aussendetet": "aussenden",
    "aussetze": "aussetzen",
    "aussetzend": "aussetzen",
    "aussetzende": "aussetzend",
    "aussetzendem": "aussetzend",
    "aussetzenden": "aussetzend",
    "aussetzender": "aussetzend",
    "aussetzendes": "aussetzend",
    "aussetzest": "aussetzen",
    "aussetzet": "aussetzen",
    "aussetzt": "aussetzen",
    "aussetzte": "aussetzen",
    "aussetzten": "aussetzen",
    "aussetztest": "aussetzen",
    "aussetztet": "aussetzen",
    "aussichtslosem": "aussichtslos",
    "aussichtslosen": "aussichtslos",
    "aussichtsloser": "aussichtslos",
    "aussichtslosere": "aussichtslos",
    "aussichtsloserem": "aussichtslos",
    "aussichtsloseren": "aussichtslos",
    "aussichtsloserer": "aussichtslos",
    "aussichtsloseres": "aussichtslos",
    "aussichtsloses": "aussichtslos",
    "aussichtsloseste": "aussichtslos",
    "aussichtslosestem": "aussichtslos",
    "aussichtslosesten": "aussichtslos",
    "aussichtslosester": "aussichtslos",
    "aussichtslosestes": "aussichtslos",
    "aussichtsreiche": "aussichtsreich",
    "aussichtsreichem": "aussichtsreich",
    "aussichtsreichen": "aussichtsreich",
    "aussichtsreicher": "aussichtsreich",
    "aussichtsreichere": "aussichtsreich",
    "aussichtsreicherem": "aussichtsreich",
    "aussichtsreicheren": "aussichtsreich",
    "aussichtsreicherer": "aussichtsreich",
    "aussichtsreicheres": "aussichtsreich",
    "aussichtsreiches": "aussichtsreich",
    "aussichtsreichste": "aussichtsreich",
    "aussichtsreichstem": "aussichtsreich",
    "aussichtsreichsten": "aussichtsreich",
    "aussichtsreichster": "aussichtsreich",
    "aussichtsreichstes": "aussichtsreich",
    "aussiebe": "aussieben",
    "aussiebend": "aussieben",
    "aussiebende": "aussiebend",
    "aussiebendem": "aussiebend",
    "aussiebenden": "aussiebend",
    "aussiebender": "aussiebend",
    "aussiebendere": "aussiebend",
    "aussiebenderem": "aussiebend",
    "aussiebenderen": "aussiebend",
    "aussiebenderer": "aussiebend",
    "aussiebenderes": "aussiebend",
    "aussiebendes": "aussiebend",
    "aussiebendste": "aussiebend",
    "aussiebendstem": "aussiebend",
    "aussiebendsten": "aussiebend",
    "aussiebendster": "aussiebend",
    "aussiebendstes": "aussiebend",
    "aussiebest": "aussieben",
    "aussiebet": "aussieben",
    "aussiebst": "aussieben",
    "aussiebt": "aussieben",
    "aussiebte": "aussieben",
    "aussiebten": "aussieben",
    "aussiebtest": "aussieben",
    "aussiebtet": "aussieben",
    "aussiedele": "aussiedeln",
    "aussiedelnd": "aussiedeln",
    "aussiedelnde": "aussiedelnd",
    "aussiedelndem": "aussiedelnd",
    "aussiedelnden": "aussiedelnd",
    "aussiedelnder": "aussiedelnd",
    "aussiedelndes": "aussiedelnd",
    "aussiedelst": "aussiedeln",
    "aussiedelt": "aussiedeln",
    "aussiedelte": "aussiedeln",
    "aussiedelten": "aussiedeln",
    "aussiedeltest": "aussiedeln",
    "aussiedeltet": "aussiedeln",
    "aussiedle": "aussiedeln",
    "aussiehst": "aussehen",
    "aussieht": "aussehen",
    "aussitze": "aussitzen",
    "aussitzend": "aussitzen",
    "aussitzende": "aussitzend",
    "aussitzendem": "aussitzend",
    "aussitzenden": "aussitzend",
    "aussitzender": "aussitzend",
    "aussitzendes": "aussitzend",
    "aussitzest": "aussitzen",
    "aussitzet": "aussitzen",
    "aussitzt": "aussitzen",
    "aussoff": "aussaufen",
    "aussoffen": "aussaufen",
    "aussoffst": "aussaufen",
    "aussofft": "aussaufen",
    "aussog": "aussaugen",
    "aussogen": "aussaugen",
    "aussogst": "aussaugen",
    "aussogt": "aussaugen",
    "aussondere": "aussondern",
    "aussondernd": "aussondern",
    "aussondernde": "aussondernd",
    "aussonderndem": "aussondernd",
    "aussondernden": "aussondernd",
    "aussondernder": "aussondernd",
    "aussonderndes": "aussondernd",
    "aussonderst": "aussondern",
    "aussondert": "aussondern",
    "aussonderte": "aussondern",
    "aussonderten": "aussondern",
    "aussondertest": "aussondern",
    "aussondertet": "aussondern",
    "aussortiere": "aussortieren",
    "aussortierend": "aussortieren",
    "aussortierende": "aussortierend",
    "aussortierendem": "aussortierend",
    "aussortierenden": "aussortierend",
    "aussortierender": "aussortierend",
    "aussortierendere": "aussortierend",
    "aussortierenderem": "aussortierend",
    "aussortierenderen": "aussortierend",
    "aussortierenderer": "aussortierend",
    "aussortierenderes": "aussortierend",
    "aussortierendes": "aussortierend",
    "aussortierendste": "aussortierend",
    "aussortierendstem": "aussortierend",
    "aussortierendsten": "aussortierend",
    "aussortierendster": "aussortierend",
    "aussortierendstes": "aussortierend",
    "aussortierest": "aussortieren",
    "aussortieret": "aussortieren",
    "aussortierst": "aussortieren",
    "aussortiert": "aussortieren",
    "aussortierte": "aussortieren",
    "aussortiertem": "aussortiert",
    "aussortierten": "aussortieren",
    "aussortierter": "aussortiert",
    "aussortiertere": "aussortiert",
    "aussortierterem": "aussortiert",
    "aussortierteren": "aussortiert",
    "aussortierterer": "aussortiert",
    "aussortierteres": "aussortiert",
    "aussortiertes": "aussortiert",
    "aussortiertest": "aussortieren",
    "aussortierteste": "aussortiert",
    "aussortiertestem": "aussortiert",
    "aussortiertesten": "aussortiert",
    "aussortiertester": "aussortiert",
    "aussortiertestes": "aussortiert",
    "aussortiertet": "aussortieren",
    "ausspanne": "ausspannen",
    "ausspannend": "ausspannen",
    "ausspannende": "ausspannend",
    "ausspannendem": "ausspannend",
    "ausspannenden": "ausspannend",
    "ausspannender": "ausspannend",
    "ausspannendes": "ausspannend",
    "ausspannest": "ausspannen",
    "ausspannet": "ausspannen",
    "ausspannst": "ausspannen",
    "ausspannt": "ausspannen",
    "ausspannte": "ausspannen",
    "ausspannten": "ausspannen",
    "ausspanntest": "ausspannen",
    "ausspanntet": "ausspannen",
    "ausspare": "aussparen",
    "aussparend": "aussparen",
    "aussparende": "aussparend",
    "aussparendem": "aussparend",
    "aussparenden": "aussparend",
    "aussparender": "aussparend",
    "aussparendes": "aussparend",
    "aussparest": "aussparen",
    "aussparet": "aussparen",
    "aussparst": "aussparen",
    "ausspart": "aussparen",
    "aussparte": "aussparen",
    "aussparten": "aussparen",
    "ausspartest": "aussparen",
    "ausspartet": "aussparen",
    "ausspeie": "ausspeien",
    "ausspeiend": "ausspeien",
    "ausspeiende": "ausspeiend",
    "ausspeiendem": "ausspeiend",
    "ausspeienden": "ausspeiend",
    "ausspeiender": "ausspeiend",
    "ausspeiendes": "ausspeiend",
    "ausspeiest": "ausspeien",
    "ausspeiet": "ausspeien",
    "ausspeist": "ausspeien",
    "ausspeit": "ausspeien",
    "aussperre": "aussperren",
    "aussperrend": "aussperren",
    "aussperrende": "aussperrend",
    "aussperrendem": "aussperrend",
    "aussperrenden": "aussperrend",
    "aussperrender": "aussperrend",
    "aussperrendes": "aussperrend",
    "aussperrest": "aussperren",
    "aussperret": "aussperren",
    "aussperrst": "aussperren",
    "aussperrt": "aussperren",
    "aussperrte": "aussperren",
    "aussperrten": "aussperren",
    "aussperrtest": "aussperren",
    "aussperrtet": "aussperren",
    "ausspie": "ausspeien",
    "ausspiee": "ausspeien",
    "ausspieen": "ausspeien",
    "ausspieest": "ausspeien",
    "ausspieet": "ausspeien",
    "ausspiele": "ausspielen",
    "ausspielend": "ausspielen",
    "ausspielende": "ausspielend",
    "ausspielendem": "ausspielend",
    "ausspielenden": "ausspielend",
    "ausspielender": "ausspielend",
    "ausspielendes": "ausspielend",
    "ausspielest": "ausspielen",
    "ausspielet": "ausspielen",
    "ausspielst": "ausspielen",
    "ausspielt": "ausspielen",
    "ausspielte": "ausspielen",
    "ausspielten": "ausspielen",
    "ausspieltest": "ausspielen",
    "ausspieltet": "ausspielen",
    "ausspien": "ausspeien",
    "ausspiest": "ausspeien",
    "ausspiet": "ausspeien",
    "ausspioniere": "ausspionieren",
    "ausspionierend": "ausspionieren",
    "ausspionierende": "ausspionierend",
    "ausspionierendem": "ausspionierend",
    "ausspionierenden": "ausspionierend",
    "ausspionierender": "ausspionierend",
    "ausspionierendere": "ausspionierend",
    "ausspionierenderem": "ausspionierend",
    "ausspionierenderen": "ausspionierend",
    "ausspionierenderer": "ausspionierend",
    "ausspionierenderes": "ausspionierend",
    "ausspionierendes": "ausspionierend",
    "ausspionierendste": "ausspionierend",
    "ausspionierendstem": "ausspionierend",
    "ausspionierendsten": "ausspionierend",
    "ausspionierendster": "ausspionierend",
    "ausspionierendstes": "ausspionierend",
    "ausspionierest": "ausspionieren",
    "ausspionieret": "ausspionieren",
    "ausspionierst": "ausspionieren",
    "ausspioniert": "ausspionieren",
    "ausspionierte": "ausspionieren",
    "ausspioniertem": "ausspioniert",
    "ausspionierten": "ausspionieren",
    "ausspionierter": "ausspioniert",
    "ausspioniertere": "ausspioniert",
    "ausspionierterem": "ausspioniert",
    "ausspionierteren": "ausspioniert",
    "ausspionierterer": "ausspioniert",
    "ausspionierteres": "ausspioniert",
    "ausspioniertes": "ausspioniert",
    "ausspioniertest": "ausspionieren",
    "ausspionierteste": "ausspioniert",
    "ausspioniertestem": "ausspioniert",
    "ausspioniertesten": "ausspioniert",
    "ausspioniertester": "ausspioniert",
    "ausspioniertestes": "ausspioniert",
    "ausspioniertet": "ausspionieren",
    "aussprach": "aussprechen",
    "aussprachst": "aussprechen",
    "ausspracht": "aussprechen",
    "aussprechbare": "aussprechbar",
    "aussprechbarem": "aussprechbar",
    "aussprechbaren": "aussprechbar",
    "aussprechbarer": "aussprechbar",
    "aussprechbares": "aussprechbar",
    "ausspreche": "aussprechen",
    "aussprechend": "aussprechen",
    "aussprechende": "aussprechend",
    "aussprechendem": "aussprechend",
    "aussprechenden": "aussprechend",
    "aussprechender": "aussprechend",
    "aussprechendes": "aussprechend",
    "aussprechest": "aussprechen",
    "aussprechet": "aussprechen",
    "aussprecht": "aussprechen",
    "aussprenge": "aussprengen",
    "aussprengend": "aussprengen",
    "aussprengende": "aussprengend",
    "aussprengendem": "aussprengend",
    "aussprengenden": "aussprengend",
    "aussprengender": "aussprengend",
    "aussprengendes": "aussprengend",
    "aussprengest": "aussprengen",
    "aussprenget": "aussprengen",
    "aussprengst": "aussprengen",
    "aussprengt": "aussprengen",
    "aussprengte": "aussprengen",
    "aussprengten": "aussprengen",
    "aussprengtest": "aussprengen",
    "aussprengtet": "aussprengen",
    "aussprichst": "aussprechen",
    "ausspricht": "aussprechen",
    "ausspritze": "ausspritzen",
    "ausspritzend": "ausspritzen",
    "ausspritzende": "ausspritzend",
    "ausspritzendem": "ausspritzend",
    "ausspritzenden": "ausspritzend",
    "ausspritzender": "ausspritzend",
    "ausspritzendes": "ausspritzend",
    "ausspritzest": "ausspritzen",
    "ausspritzet": "ausspritzen",
    "ausspritzt": "ausspritzen",
    "ausspritzte": "ausspritzen",
    "ausspritzten": "ausspritzen",
    "ausspritztest": "ausspritzen",
    "ausspritztet": "ausspritzen",
    "ausspräche": "aussprechen",
    "aussprächen": "aussprechen",
    "aussprächest": "aussprechen",
    "aussprächet": "aussprechen",
    "aussprühe": "aussprühen",
    "aussprühend": "aussprühen",
    "aussprühende": "aussprühend",
    "aussprühendem": "aussprühend",
    "aussprühenden": "aussprühend",
    "aussprühender": "aussprühend",
    "aussprühendes": "aussprühend",
    "aussprühest": "aussprühen",
    "aussprühet": "aussprühen",
    "aussprühst": "aussprühen",
    "aussprüht": "aussprühen",
    "aussprühte": "aussprühen",
    "aussprühten": "aussprühen",
    "aussprühtest": "aussprühen",
    "aussprühtet": "aussprühen",
    "ausspucke": "ausspucken",
    "ausspuckend": "ausspucken",
    "ausspuckende": "ausspuckend",
    "ausspuckendem": "ausspuckend",
    "ausspuckenden": "ausspuckend",
    "ausspuckender": "ausspuckend",
    "ausspuckendes": "ausspuckend",
    "ausspuckest": "ausspucken",
    "ausspucket": "ausspucken",
    "ausspuckst": "ausspucken",
    "ausspuckt": "ausspucken",
    "ausspuckte": "ausspucken",
    "ausspuckten": "ausspucken",
    "ausspucktest": "ausspucken",
    "ausspucktet": "ausspucken",
    "ausspähe": "ausspähen",
    "ausspähend": "ausspähen",
    "ausspähende": "ausspähend",
    "ausspähendem": "ausspähend",
    "ausspähenden": "ausspähend",
    "ausspähender": "ausspähend",
    "ausspähendere": "ausspähend",
    "ausspähenderem": "ausspähend",
    "ausspähenderen": "ausspähend",
    "ausspähenderer": "ausspähend",
    "ausspähenderes": "ausspähend",
    "ausspähendes": "ausspähend",
    "ausspähendste": "ausspähend",
    "ausspähendstem": "ausspähend",
    "ausspähendsten": "ausspähend",
    "ausspähendster": "ausspähend",
    "ausspähendstes": "ausspähend",
    "ausspähest": "ausspähen",
    "ausspähet": "ausspähen",
    "ausspähst": "ausspähen",
    "ausspäht": "ausspähen",
    "ausspähte": "ausspähen",
    "ausspähten": "ausspähen",
    "ausspähtest": "ausspähen",
    "ausspähtet": "ausspähen",
    "ausspüle": "ausspülen",
    "ausspülend": "ausspülen",
    "ausspülende": "ausspülend",
    "ausspülendem": "ausspülend",
    "ausspülenden": "ausspülend",
    "ausspülender": "ausspülend",
    "ausspülendes": "ausspülend",
    "ausspülest": "ausspülen",
    "ausspület": "ausspülen",
    "ausspülst": "ausspülen",
    "ausspült": "ausspülen",
    "ausspülte": "ausspülen",
    "ausspülten": "ausspülen",
    "ausspültest": "ausspülen",
    "ausspültet": "ausspülen",
    "ausstach": "ausstechen",
    "ausstachen": "ausstechen",
    "ausstachst": "ausstechen",
    "ausstacht": "ausstechen",
    "ausstaffiere": "ausstaffieren",
    "ausstaffierend": "ausstaffieren",
    "ausstaffierende": "ausstaffierend",
    "ausstaffierendem": "ausstaffierend",
    "ausstaffierenden": "ausstaffierend",
    "ausstaffierender": "ausstaffierend",
    "ausstaffierendere": "ausstaffierend",
    "ausstaffierenderem": "ausstaffierend",
    "ausstaffierenderen": "ausstaffierend",
    "ausstaffierenderer": "ausstaffierend",
    "ausstaffierenderes": "ausstaffierend",
    "ausstaffierendes": "ausstaffierend",
    "ausstaffierendste": "ausstaffierend",
    "ausstaffierendstem": "ausstaffierend",
    "ausstaffierendsten": "ausstaffierend",
    "ausstaffierendster": "ausstaffierend",
    "ausstaffierendstes": "ausstaffierend",
    "ausstaffierest": "ausstaffieren",
    "ausstaffieret": "ausstaffieren",
    "ausstaffierst": "ausstaffieren",
    "ausstaffiert": "ausstaffieren",
    "ausstaffierte": "ausstaffieren",
    "ausstaffiertem": "ausstaffiert",
    "ausstaffierten": "ausstaffieren",
    "ausstaffierter": "ausstaffiert",
    "ausstaffiertere": "ausstaffiert",
    "ausstaffierterem": "ausstaffiert",
    "ausstaffierteren": "ausstaffiert",
    "ausstaffierterer": "ausstaffiert",
    "ausstaffierteres": "ausstaffiert",
    "ausstaffiertes": "ausstaffiert",
    "ausstaffiertest": "ausstaffieren",
    "ausstaffierteste": "ausstaffiert",
    "ausstaffiertestem": "ausstaffiert",
    "ausstaffiertesten": "ausstaffiert",
    "ausstaffiertester": "ausstaffiert",
    "ausstaffiertestes": "ausstaffiert",
    "ausstaffiertet": "ausstaffieren",
    "ausstand": "ausstehen",
    "ausstanden": "ausstehen",
    "ausstandest": "ausstehen",
    "ausstandet": "ausstehen",
    "ausstanze": "ausstanzen",
    "ausstanzend": "ausstanzen",
    "ausstanzende": "ausstanzend",
    "ausstanzendem": "ausstanzend",
    "ausstanzenden": "ausstanzend",
    "ausstanzender": "ausstanzend",
    "ausstanzendes": "ausstanzend",
    "ausstanzest": "ausstanzen",
    "ausstanzet": "ausstanzen",
    "ausstanzt": "ausstanzen",
    "ausstanzte": "ausstanzen",
    "ausstanzten": "ausstanzen",
    "ausstanztest": "ausstanzen",
    "ausstanztet": "ausstanzen",
    "ausstarb": "aussterben",
    "ausstarben": "aussterben",
    "ausstarbst": "aussterben",
    "ausstarbt": "aussterben",
    "ausstatte": "ausstatten",
    "ausstattend": "ausstatten",
    "ausstattende": "ausstattend",
    "ausstattendem": "ausstattend",
    "ausstattenden": "ausstattend",
    "ausstattender": "ausstattend",
    "ausstattendes": "ausstattend",
    "ausstattest": "ausstatten",
    "ausstattet": "ausstatten",
    "ausstattete": "ausstatten",
    "ausstatteten": "ausstatten",
    "ausstattetest": "ausstatten",
    "ausstattetet": "ausstatten",
    "aussteche": "ausstechen",
    "ausstechend": "ausstechen",
    "ausstechende": "ausstechend",
    "ausstechendem": "ausstechend",
    "ausstechenden": "ausstechend",
    "ausstechender": "ausstechend",
    "ausstechendes": "ausstechend",
    "ausstechest": "ausstechen",
    "ausstechet": "ausstechen",
    "ausstecht": "ausstechen",
    "ausstehe": "ausstehen",
    "ausstehend": "ausstehen",
    "ausstehende": "ausstehend",
    "ausstehendem": "ausstehend",
    "ausstehenden": "ausstehend",
    "ausstehender": "ausstehend",
    "ausstehendes": "ausstehend",
    "ausstehest": "ausstehen",
    "ausstehet": "ausstehen",
    "ausstehst": "ausstehen",
    "aussteht": "ausstehen",
    "aussteife": "aussteifen",
    "aussteifend": "aussteifen",
    "aussteifende": "aussteifend",
    "aussteifendem": "aussteifend",
    "aussteifenden": "aussteifend",
    "aussteifender": "aussteifend",
    "aussteifendere": "aussteifend",
    "aussteifenderem": "aussteifend",
    "aussteifenderen": "aussteifend",
    "aussteifenderer": "aussteifend",
    "aussteifenderes": "aussteifend",
    "aussteifendes": "aussteifend",
    "aussteifendste": "aussteifend",
    "aussteifendstem": "aussteifend",
    "aussteifendsten": "aussteifend",
    "aussteifendster": "aussteifend",
    "aussteifendstes": "aussteifend",
    "aussteifest": "aussteifen",
    "aussteifet": "aussteifen",
    "aussteifst": "aussteifen",
    "aussteift": "aussteifen",
    "aussteifte": "aussteifen",
    "aussteiften": "aussteifen",
    "aussteiftest": "aussteifen",
    "aussteiftet": "aussteifen",
    "aussteige": "aussteigen",
    "aussteigend": "aussteigen",
    "aussteigende": "aussteigend",
    "aussteigendem": "aussteigend",
    "aussteigenden": "aussteigend",
    "aussteigender": "aussteigend",
    "aussteigendes": "aussteigend",
    "aussteigest": "aussteigen",
    "aussteiget": "aussteigen",
    "aussteigst": "aussteigen",
    "aussteigt": "aussteigen",
    "ausstelle": "ausstellen",
    "ausstellend": "ausstellen",
    "ausstellende": "ausstellend",
    "ausstellendem": "ausstellend",
    "ausstellenden": "ausstellend",
    "ausstellender": "ausstellend",
    "ausstellendes": "ausstellend",
    "ausstellest": "ausstellen",
    "ausstellet": "ausstellen",
    "ausstellst": "ausstellen",
    "ausstellt": "ausstellen",
    "ausstellte": "ausstellen",
    "ausstellten": "ausstellen",
    "ausstelltest": "ausstellen",
    "ausstelltet": "ausstellen",
    "aussterbe": "aussterben",
    "aussterbend": "aussterben",
    "aussterbende": "aussterbend",
    "aussterbendem": "aussterbend",
    "aussterbenden": "aussterbend",
    "aussterbender": "aussterbend",
    "aussterbendere": "aussterbend",
    "aussterbenderem": "aussterbend",
    "aussterbenderen": "aussterbend",
    "aussterbenderer": "aussterbend",
    "aussterbenderes": "aussterbend",
    "aussterbendes": "aussterbend",
    "aussterbendste": "aussterbend",
    "aussterbendstem": "aussterbend",
    "aussterbendsten": "aussterbend",
    "aussterbendster": "aussterbend",
    "aussterbendstes": "aussterbend",
    "aussterbest": "aussterben",
    "aussterbet": "aussterben",
    "aussterbt": "aussterben",
    "aussteuere": "aussteuern",
    "aussteuernd": "aussteuern",
    "aussteuernde": "aussteuernd",
    "aussteuerndem": "aussteuernd",
    "aussteuernden": "aussteuernd",
    "aussteuernder": "aussteuernd",
    "aussteuerndes": "aussteuernd",
    "aussteuerst": "aussteuern",
    "aussteuert": "aussteuern",
    "aussteuerte": "aussteuern",
    "aussteuerten": "aussteuern",
    "aussteuertest": "aussteuern",
    "aussteuertet": "aussteuern",
    "ausstichst": "ausstechen",
    "aussticht": "ausstechen",
    "ausstieg": "aussteigen",
    "ausstiegest": "aussteigen",
    "ausstieget": "aussteigen",
    "ausstiegst": "aussteigen",
    "ausstiegt": "aussteigen",
    "ausstieß": "ausstoßen",
    "ausstieße": "ausstoßen",
    "ausstießen": "ausstoßen",
    "ausstießest": "ausstoßen",
    "ausstießet": "ausstoßen",
    "ausstießt": "ausstoßen",
    "ausstirbst": "aussterben",
    "ausstirbt": "aussterben",
    "ausstopfe": "ausstopfen",
    "ausstopfend": "ausstopfen",
    "ausstopfende": "ausstopfend",
    "ausstopfendem": "ausstopfend",
    "ausstopfenden": "ausstopfend",
    "ausstopfender": "ausstopfend",
    "ausstopfendere": "ausstopfend",
    "ausstopfenderem": "ausstopfend",
    "ausstopfenderen": "ausstopfend",
    "ausstopfenderer": "ausstopfend",
    "ausstopfenderes": "ausstopfend",
    "ausstopfendes": "ausstopfend",
    "ausstopfendste": "ausstopfend",
    "ausstopfendstem": "ausstopfend",
    "ausstopfendsten": "ausstopfend",
    "ausstopfendster": "ausstopfend",
    "ausstopfendstes": "ausstopfend",
    "ausstopfest": "ausstopfen",
    "ausstopfet": "ausstopfen",
    "ausstopfst": "ausstopfen",
    "ausstopft": "ausstopfen",
    "ausstopfte": "ausstopfen",
    "ausstopften": "ausstopfen",
    "ausstopftest": "ausstopfen",
    "ausstopftet": "ausstopfen",
    "ausstoße": "ausstoßen",
    "ausstoßend": "ausstoßen",
    "ausstoßende": "ausstoßend",
    "ausstoßendem": "ausstoßend",
    "ausstoßenden": "ausstoßend",
    "ausstoßender": "ausstoßend",
    "ausstoßendes": "ausstoßend",
    "ausstoßest": "ausstoßen",
    "ausstoßet": "ausstoßen",
    "ausstoßt": "ausstoßen",
    "ausstrahle": "ausstrahlen",
    "ausstrahlend": "ausstrahlen",
    "ausstrahlende": "ausstrahlend",
    "ausstrahlendem": "ausstrahlend",
    "ausstrahlenden": "ausstrahlend",
    "ausstrahlender": "ausstrahlend",
    "ausstrahlendere": "ausstrahlend",
    "ausstrahlenderem": "ausstrahlend",
    "ausstrahlenderen": "ausstrahlend",
    "ausstrahlenderer": "ausstrahlend",
    "ausstrahlenderes": "ausstrahlend",
    "ausstrahlendes": "ausstrahlend",
    "ausstrahlendste": "ausstrahlend",
    "ausstrahlendstem": "ausstrahlend",
    "ausstrahlendsten": "ausstrahlend",
    "ausstrahlendster": "ausstrahlend",
    "ausstrahlendstes": "ausstrahlend",
    "ausstrahlest": "ausstrahlen",
    "ausstrahlet": "ausstrahlen",
    "ausstrahlst": "ausstrahlen",
    "ausstrahlt": "ausstrahlen",
    "ausstrahlte": "ausstrahlen",
    "ausstrahlten": "ausstrahlen",
    "ausstrahltest": "ausstrahlen",
    "ausstrahltet": "ausstrahlen",
    "ausstreiche": "ausstreichen",
    "ausstreichend": "ausstreichen",
    "ausstreichende": "ausstreichend",
    "ausstreichendem": "ausstreichend",
    "ausstreichenden": "ausstreichend",
    "ausstreichender": "ausstreichend",
    "ausstreichendes": "ausstreichend",
    "ausstreichest": "ausstreichen",
    "ausstreichet": "ausstreichen",
    "ausstreichst": "ausstreichen",
    "ausstreicht": "ausstreichen",
    "ausstreue": "ausstreuen",
    "ausstreuend": "ausstreuen",
    "ausstreuende": "ausstreuend",
    "ausstreuendem": "ausstreuend",
    "ausstreuenden": "ausstreuend",
    "ausstreuender": "ausstreuend",
    "ausstreuendes": "ausstreuend",
    "ausstreuest": "ausstreuen",
    "ausstreuet": "ausstreuen",
    "ausstreust": "ausstreuen",
    "ausstreut": "ausstreuen",
    "ausstreute": "ausstreuen",
    "ausstreuten": "ausstreuen",
    "ausstreutest": "ausstreuen",
    "ausstreutet": "ausstreuen",
    "ausstrich": "ausstreichen",
    "ausstriche": "ausstreichen",
    "ausstrichen": "ausstreichen",
    "ausstrichest": "ausstreichen",
    "ausstrichet": "ausstreichen",
    "ausstrichst": "ausstreichen",
    "ausstricht": "ausstreichen",
    "ausströme": "ausströmen",
    "ausströmend": "ausströmen",
    "ausströmende": "ausströmend",
    "ausströmendem": "ausströmend",
    "ausströmenden": "ausströmend",
    "ausströmender": "ausströmend",
    "ausströmendes": "ausströmend",
    "ausströmest": "ausströmen",
    "ausströmet": "ausströmen",
    "ausströmst": "ausströmen",
    "ausströmt": "ausströmen",
    "ausströmte": "ausströmen",
    "ausströmten": "ausströmen",
    "ausströmtest": "ausströmen",
    "ausströmtet": "ausströmen",
    "ausstäche": "ausstechen",
    "ausstächen": "ausstechen",
    "ausstächest": "ausstechen",
    "ausstächet": "ausstechen",
    "ausstärbe": "aussterben",
    "ausstärben": "aussterben",
    "ausstärbest": "aussterben",
    "ausstärbet": "aussterben",
    "ausstößt": "ausstoßen",
    "ausstülpe": "ausstülpen",
    "ausstülpend": "ausstülpen",
    "ausstülpende": "ausstülpend",
    "ausstülpendem": "ausstülpend",
    "ausstülpenden": "ausstülpend",
    "ausstülpender": "ausstülpend",
    "ausstülpendes": "ausstülpend",
    "ausstülpest": "ausstülpen",
    "ausstülpet": "ausstülpen",
    "ausstülpst": "ausstülpen",
    "ausstülpt": "ausstülpen",
    "ausstülpte": "ausstülpen",
    "ausstülpten": "ausstülpen",
    "ausstülptest": "ausstülpen",
    "ausstülptet": "ausstülpen",
    "ausstünde": "ausstehen",
    "ausstünden": "ausstehen",
    "ausstündest": "ausstehen",
    "ausstündet": "ausstehen",
    "aussuche": "aussuchen",
    "aussuchend": "aussuchen",
    "aussuchende": "aussuchend",
    "aussuchendem": "aussuchend",
    "aussuchenden": "aussuchend",
    "aussuchender": "aussuchend",
    "aussuchendes": "aussuchend",
    "aussuchest": "aussuchen",
    "aussuchet": "aussuchen",
    "aussuchst": "aussuchen",
    "aussucht": "aussuchen",
    "aussuchte": "aussuchen",
    "aussuchten": "aussuchen",
    "aussuchtest": "aussuchen",
    "aussuchtet": "aussuchen",
    "aussäe": "aussäen",
    "aussäend": "aussäen",
    "aussäende": "aussäend",
    "aussäendem": "aussäend",
    "aussäenden": "aussäend",
    "aussäender": "aussäend",
    "aussäendes": "aussäend",
    "aussäest": "aussäen",
    "aussäet": "aussäen",
    "aussäge": "aussägen",
    "aussägend": "aussägen",
    "aussägendem": "aussägend",
    "aussägender": "aussägend",
    "aussägendes": "aussägend",
    "aussägest": "aussägen",
    "aussäget": "aussägen",
    "aussägst": "aussägen",
    "aussägt": "aussägen",
    "aussägte": "aussägen",
    "aussägten": "aussägen",
    "aussägtest": "aussägen",
    "aussägtet": "aussägen",
    "aussähe": "aussehen",
    "aussähen": "aussehen",
    "aussähest": "aussehen",
    "aussähet": "aussehen",
    "aussäst": "aussäen",
    "aussät": "aussäen",
    "aussäte": "aussäen",
    "aussäten": "aussäen",
    "aussätest": "aussäen",
    "aussätet": "aussäen",
    "aussätzige": "aussätzig",
    "aussätzigem": "aussätzig",
    "aussätzigen": "aussätzig",
    "aussätziger": "aussätzig",
    "aussätziges": "aussätzig",
    "aussäufst": "aussaufen",
    "aussäuft": "aussaufen",
    "aussäße": "aussitzen",
    "aussäßen": "aussitzen",
    "aussäßest": "aussitzen",
    "aussäßet": "aussitzen",
    "aussöffe": "aussaufen",
    "aussöffen": "aussaufen",
    "aussöffest": "aussaufen",
    "aussöffet": "aussaufen",
    "aussöge": "aussaugen",
    "aussögen": "aussaugen",
    "aussögest": "aussaugen",
    "aussöget": "aussaugen",
    "aussöhne": "aussöhnen",
    "aussöhnend": "aussöhnen",
    "aussöhnende": "aussöhnend",
    "aussöhnendem": "aussöhnend",
    "aussöhnenden": "aussöhnend",
    "aussöhnender": "aussöhnend",
    "aussöhnendes": "aussöhnend",
    "aussöhnest": "aussöhnen",
    "aussöhnet": "aussöhnen",
    "aussöhnst": "aussöhnen",
    "aussöhnt": "aussöhnen",
    "aussöhnte": "aussöhnen",
    "aussöhnten": "aussöhnen",
    "aussöhntest": "aussöhnen",
    "aussöhntet": "aussöhnen",
    "austariere": "austarieren",
    "austarierend": "austarieren",
    "austarierende": "austarierend",
    "austarierendem": "austarierend",
    "austarierenden": "austarierend",
    "austarierender": "austarierend",
    "austarierendes": "austarierend",
    "austarierest": "austarieren",
    "austarieret": "austarieren",
    "austarierst": "austarieren",
    "austariert": "austarieren",
    "austarierte": "austarieren",
    "austariertem": "austariert",
    "austarierten": "austarieren",
    "austarierter": "austariert",
    "austariertes": "austariert",
    "austariertest": "austarieren",
    "austariertet": "austarieren",
    "austauschbare": "austauschbar",
    "austauschbarem": "austauschbar",
    "austauschbaren": "austauschbar",
    "austauschbarer": "austauschbar",
    "austauschbares": "austauschbar",
    "austauschend": "austauschen",
    "austauschende": "austauschend",
    "austauschendem": "austauschend",
    "austauschenden": "austauschend",
    "austauschender": "austauschend",
    "austauschendes": "austauschend",
    "austauschest": "austauschen",
    "austauschet": "austauschen",
    "austauschst": "austauschen",
    "austauscht": "austauschen",
    "austauschte": "austauschen",
    "austauschten": "austauschen",
    "austauschtest": "austauschen",
    "austauschtet": "austauschen",
    "austeile": "austeilen",
    "austeilend": "austeilen",
    "austeilende": "austeilend",
    "austeilendem": "austeilend",
    "austeilenden": "austeilend",
    "austeilender": "austeilend",
    "austeilendes": "austeilend",
    "austeilest": "austeilen",
    "austeilet": "austeilen",
    "austeilst": "austeilen",
    "austeilt": "austeilen",
    "austeilte": "austeilen",
    "austeilten": "austeilen",
    "austeiltest": "austeilen",
    "austeiltet": "austeilen",
    "austilge": "austilgen",
    "austilgend": "austilgen",
    "austilgende": "austilgend",
    "austilgendem": "austilgend",
    "austilgenden": "austilgend",
    "austilgender": "austilgend",
    "austilgendes": "austilgend",
    "austilgest": "austilgen",
    "austilget": "austilgen",
    "austilgst": "austilgen",
    "austilgt": "austilgen",
    "austilgte": "austilgen",
    "austilgten": "austilgen",
    "austilgtest": "austilgen",
    "austilgtet": "austilgen",
    "austobe": "austoben",
    "austobend": "austoben",
    "austobende": "austobend",
    "austobendem": "austobend",
    "austobenden": "austobend",
    "austobender": "austobend",
    "austobendere": "austobend",
    "austobenderem": "austobend",
    "austobenderen": "austobend",
    "austobenderer": "austobend",
    "austobenderes": "austobend",
    "austobendes": "austobend",
    "austobendste": "austobend",
    "austobendstem": "austobend",
    "austobendsten": "austobend",
    "austobendster": "austobend",
    "austobendstes": "austobend",
    "austobest": "austoben",
    "austobet": "austoben",
    "austobst": "austoben",
    "austobt": "austoben",
    "austobte": "austoben",
    "austobten": "austoben",
    "austobtest": "austoben",
    "austobtet": "austoben",
    "austrage": "austragen",
    "austragend": "austragen",
    "austragende": "austragend",
    "austragendem": "austragend",
    "austragenden": "austragend",
    "austragender": "austragend",
    "austragendes": "austragend",
    "austragest": "austragen",
    "austraget": "austragen",
    "austragt": "austragen",
    "australischem": "australisch",
    "australischen": "australisch",
    "australischer": "australisch",
    "australisches": "australisch",
    "austrank": "austrinken",
    "austranken": "austrinken",
    "austrankst": "austrinken",
    "austrankt": "austrinken",
    "austrat": "austreten",
    "austraten": "austreten",
    "austratest": "austreten",
    "austratet": "austreten",
    "austreibe": "austreiben",
    "austreibend": "austreiben",
    "austreibende": "austreibend",
    "austreibendem": "austreibend",
    "austreibenden": "austreibend",
    "austreibender": "austreibend",
    "austreibendes": "austreibend",
    "austreibest": "austreiben",
    "austreibet": "austreiben",
    "austreibst": "austreiben",
    "austreibt": "austreiben",
    "austrete": "austreten",
    "austretend": "austreten",
    "austretende": "austretend",
    "austretendem": "austretend",
    "austretenden": "austretend",
    "austretender": "austretend",
    "austretendes": "austretend",
    "austretest": "austreten",
    "austretet": "austreten",
    "austrickse": "austricksen",
    "austricksend": "austricksen",
    "austricksende": "austricksend",
    "austricksendem": "austricksend",
    "austricksenden": "austricksend",
    "austricksender": "austricksend",
    "austricksendere": "austricksend",
    "austricksenderem": "austricksend",
    "austricksenderen": "austricksend",
    "austricksenderer": "austricksend",
    "austricksenderes": "austricksend",
    "austricksendes": "austricksend",
    "austricksendste": "austricksend",
    "austricksendstem": "austricksend",
    "austricksendsten": "austricksend",
    "austricksendster": "austricksend",
    "austricksendstes": "austricksend",
    "austricksest": "austricksen",
    "austrickset": "austricksen",
    "austrickst": "austricksen",
    "austrickste": "austricksen",
    "austricksten": "austricksen",
    "austrickstest": "austricksen",
    "austrickstet": "austricksen",
    "austrieb": "austreiben",
    "austriebe": "austreiben",
    "austrieben": "austreiben",
    "austriebest": "austreiben",
    "austriebet": "austreiben",
    "austriebst": "austreiben",
    "austriebt": "austreiben",
    "austrinke": "austrinken",
    "austrinkend": "austrinken",
    "austrinkende": "austrinkend",
    "austrinkendem": "austrinkend",
    "austrinkenden": "austrinkend",
    "austrinkender": "austrinkend",
    "austrinkendere": "austrinkend",
    "austrinkenderem": "austrinkend",
    "austrinkenderen": "austrinkend",
    "austrinkenderer": "austrinkend",
    "austrinkenderes": "austrinkend",
    "austrinkendes": "austrinkend",
    "austrinkendste": "austrinkend",
    "austrinkendstem": "austrinkend",
    "austrinkendsten": "austrinkend",
    "austrinkendster": "austrinkend",
    "austrinkendstes": "austrinkend",
    "austrinkest": "austrinken",
    "austrinket": "austrinken",
    "austrinkst": "austrinken",
    "austrinkt": "austrinken",
    "austritt": "austreten",
    "austrittst": "austreten",
    "austrockne": "austrocknen",
    "austrocknend": "austrocknen",
    "austrocknende": "austrocknend",
    "austrocknendem": "austrocknend",
    "austrocknenden": "austrocknend",
    "austrocknender": "austrocknend",
    "austrocknendere": "austrocknend",
    "austrocknenderem": "austrocknend",
    "austrocknenderen": "austrocknend",
    "austrocknenderer": "austrocknend",
    "austrocknenderes": "austrocknend",
    "austrocknendes": "austrocknend",
    "austrocknendste": "austrocknend",
    "austrocknendstem": "austrocknend",
    "austrocknendsten": "austrocknend",
    "austrocknendster": "austrocknend",
    "austrocknendstes": "austrocknend",
    "austrocknest": "austrocknen",
    "austrocknet": "austrocknen",
    "austrocknete": "austrocknen",
    "austrockneten": "austrocknen",
    "austrocknetest": "austrocknen",
    "austrocknetet": "austrocknen",
    "austrompete": "austrompeten",
    "austrompetend": "austrompeten",
    "austrompetende": "austrompetend",
    "austrompetendem": "austrompetend",
    "austrompetenden": "austrompetend",
    "austrompetender": "austrompetend",
    "austrompetendes": "austrompetend",
    "austrompetest": "austrompeten",
    "austrompetet": "austrompeten",
    "austrompetete": "austrompeten",
    "austrompetetem": "austrompetet",
    "austrompeteten": "austrompeten",
    "austrompeteter": "austrompetet",
    "austrompetetes": "austrompetet",
    "austrompetetest": "austrompeten",
    "austrompetetet": "austrompeten",
    "austrug": "austragen",
    "austrugen": "austragen",
    "austrugst": "austragen",
    "austrugt": "austragen",
    "austrägst": "austragen",
    "austrägt": "austragen",
    "austränke": "austrinken",
    "austränken": "austrinken",
    "austränkest": "austrinken",
    "austränket": "austrinken",
    "austräte": "austreten",
    "austräten": "austreten",
    "austrätest": "austreten",
    "austrätet": "austreten",
    "austräume": "austräumen",
    "austräumend": "austräumen",
    "austräumende": "austräumend",
    "austräumendem": "austräumend",
    "austräumenden": "austräumend",
    "austräumender": "austräumend",
    "austräumendes": "austräumend",
    "austräumest": "austräumen",
    "austräumet": "austräumen",
    "austräumst": "austräumen",
    "austräumt": "austräumen",
    "austräumte": "austräumen",
    "austräumten": "austräumen",
    "austräumtest": "austräumen",
    "austräumtet": "austräumen",
    "austrüge": "austragen",
    "austrügen": "austragen",
    "austrügest": "austragen",
    "austrüget": "austragen",
    "austupfe": "austupfen",
    "austupfend": "austupfen",
    "austupfende": "austupfend",
    "austupfendem": "austupfend",
    "austupfenden": "austupfend",
    "austupfender": "austupfend",
    "austupfendes": "austupfend",
    "austupfest": "austupfen",
    "austupfet": "austupfen",
    "austupfst": "austupfen",
    "austupft": "austupfen",
    "austupfte": "austupfen",
    "austupften": "austupfen",
    "austupftest": "austupfen",
    "austupftet": "austupfen",
    "austüftele": "austüfteln",
    "austüftelnd": "austüfteln",
    "austüftelnde": "austüftelnd",
    "austüftelndem": "austüftelnd",
    "austüftelnden": "austüftelnd",
    "austüftelnder": "austüftelnd",
    "austüftelndere": "austüftelnd",
    "austüftelnderem": "austüftelnd",
    "austüftelnderen": "austüftelnd",
    "austüftelnderer": "austüftelnd",
    "austüftelnderes": "austüftelnd",
    "austüftelndes": "austüftelnd",
    "austüftelndste": "austüftelnd",
    "austüftelndstem": "austüftelnd",
    "austüftelndsten": "austüftelnd",
    "austüftelndster": "austüftelnd",
    "austüftelndstes": "austüftelnd",
    "austüftelst": "austüfteln",
    "austüftelt": "austüfteln",
    "austüftelte": "austüfteln",
    "austüftelten": "austüfteln",
    "austüfteltest": "austüfteln",
    "austüfteltet": "austüfteln",
    "austüftle": "austüfteln",
    "ausufere": "ausufern",
    "ausufernd": "ausufern",
    "ausufernde": "ausufernd",
    "ausuferndem": "ausufernd",
    "ausufernden": "ausufernd",
    "ausufernder": "ausufernd",
    "ausuferndere": "ausufernd",
    "ausufernderem": "ausufernd",
    "ausufernderen": "ausufernd",
    "ausufernderer": "ausufernd",
    "ausufernderes": "ausufernd",
    "ausuferndes": "ausufernd",
    "ausuferndste": "ausufernd",
    "ausuferndstem": "ausufernd",
    "ausuferndsten": "ausufernd",
    "ausuferndster": "ausufernd",
    "ausuferndstes": "ausufernd",
    "ausuferst": "ausufern",
    "ausufert": "ausufern",
    "ausuferte": "ausufern",
    "ausuferten": "ausufern",
    "ausufertest": "ausufern",
    "ausufertet": "ausufern",
    "ausverkaufend": "ausverkaufen",
    "ausverkaufende": "ausverkaufend",
    "ausverkaufendem": "ausverkaufend",
    "ausverkaufenden": "ausverkaufend",
    "ausverkaufender": "ausverkaufend",
    "ausverkaufendes": "ausverkaufend",
    "ausverkaufest": "ausverkaufen",
    "ausverkaufet": "ausverkaufen",
    "ausverkaufst": "ausverkaufen",
    "ausverkauft": "ausverkaufen",
    "ausverkaufte": "ausverkaufen",
    "ausverkauftem": "ausverkauft",
    "ausverkauften": "ausverkaufen",
    "ausverkaufter": "ausverkauft",
    "ausverkauftes": "ausverkauft",
    "ausverkauftest": "ausverkaufen",
    "ausverkauftet": "ausverkaufen",
    "auswachse": "auswachsen",
    "auswachsend": "auswachsen",
    "auswachsende": "auswachsend",
    "auswachsendem": "auswachsend",
    "auswachsenden": "auswachsend",
    "auswachsender": "auswachsend",
    "auswachsendere": "auswachsend",
    "auswachsenderem": "auswachsend",
    "auswachsenderen": "auswachsend",
    "auswachsenderer": "auswachsend",
    "auswachsenderes": "auswachsend",
    "auswachsendes": "auswachsend",
    "auswachsendste": "auswachsend",
    "auswachsendstem": "auswachsend",
    "auswachsendsten": "auswachsend",
    "auswachsendster": "auswachsend",
    "auswachsendstes": "auswachsend",
    "auswachsest": "auswachsen",
    "auswachset": "auswachsen",
    "auswachst": "auswachsen",
    "auswachste": "auswachsen",
    "auswachsten": "auswachsen",
    "auswachstest": "auswachsen",
    "auswachstet": "auswachsen",
    "auswalze": "auswalzen",
    "auswalzend": "auswalzen",
    "auswalzende": "auswalzend",
    "auswalzendem": "auswalzend",
    "auswalzenden": "auswalzend",
    "auswalzender": "auswalzend",
    "auswalzendes": "auswalzend",
    "auswalzest": "auswalzen",
    "auswalzet": "auswalzen",
    "auswalzt": "auswalzen",
    "auswalzte": "auswalzen",
    "auswalzten": "auswalzen",
    "auswalztest": "auswalzen",
    "auswalztet": "auswalzen",
    "auswand": "auswinden",
    "auswanden": "auswinden",
    "auswandere": "auswandern",
    "auswandernd": "auswandern",
    "auswandernde": "auswandernd",
    "auswanderndem": "auswandernd",
    "auswandernden": "auswandernd",
    "auswandernder": "auswandernd",
    "auswanderndes": "auswandernd",
    "auswanderst": "auswandern",
    "auswandert": "auswandern",
    "auswanderte": "auswandern",
    "auswanderten": "auswandern",
    "auswandertest": "auswandern",
    "auswandertet": "auswandern",
    "auswandest": "auswinden",
    "auswandet": "auswinden",
    "auswarf": "auswerfen",
    "auswarfen": "auswerfen",
    "auswarfst": "auswerfen",
    "auswarft": "auswerfen",
    "auswasche": "auswaschen",
    "auswaschend": "auswaschen",
    "auswaschende": "auswaschend",
    "auswaschendem": "auswaschend",
    "auswaschenden": "auswaschend",
    "auswaschender": "auswaschend",
    "auswaschendes": "auswaschend",
    "auswaschest": "auswaschen",
    "auswaschet": "auswaschen",
    "auswascht": "auswaschen",
    "auswechselbare": "auswechselbar",
    "auswechselbarem": "auswechselbar",
    "auswechselbaren": "auswechselbar",
    "auswechselbarer": "auswechselbar",
    "auswechselbares": "auswechselbar",
    "auswechsele": "auswechseln",
    "auswechselnd": "auswechseln",
    "auswechselnde": "auswechselnd",
    "auswechselndem": "auswechselnd",
    "auswechselnden": "auswechselnd",
    "auswechselnder": "auswechselnd",
    "auswechselndes": "auswechselnd",
    "auswechselst": "auswechseln",
    "auswechselt": "auswechseln",
    "auswechselte": "auswechseln",
    "auswechselten": "auswechseln",
    "auswechseltest": "auswechseln",
    "auswechseltet": "auswechseln",
    "auswechsle": "auswechseln",
    "ausweglosem": "ausweglos",
    "ausweglosen": "ausweglos",
    "auswegloser": "ausweglos",
    "ausweglosere": "ausweglos",
    "auswegloserem": "ausweglos",
    "auswegloseren": "ausweglos",
    "auswegloserer": "ausweglos",
    "auswegloseres": "ausweglos",
    "auswegloses": "ausweglos",
    "auswegloseste": "ausweglos",
    "ausweglosestem": "ausweglos",
    "ausweglosesten": "ausweglos",
    "ausweglosester": "ausweglos",
    "ausweglosestes": "ausweglos",
    "ausweichend": "ausweichen",
    "ausweichende": "ausweichend",
    "ausweichendem": "ausweichend",
    "ausweichenden": "ausweichend",
    "ausweichender": "ausweichend",
    "ausweichendes": "ausweichend",
    "ausweichest": "ausweichen",
    "ausweichet": "ausweichen",
    "ausweichst": "ausweichen",
    "ausweicht": "ausweichen",
    "ausweichte": "ausweichen",
    "ausweichten": "ausweichen",
    "ausweichtest": "ausweichen",
    "ausweichtet": "ausweichen",
    "ausweide": "ausweiden",
    "ausweidend": "ausweiden",
    "ausweidende": "ausweidend",
    "ausweidendem": "ausweidend",
    "ausweidenden": "ausweidend",
    "ausweidender": "ausweidend",
    "ausweidendes": "ausweidend",
    "ausweidest": "ausweiden",
    "ausweidet": "ausweiden",
    "ausweidete": "ausweiden",
    "ausweideten": "ausweiden",
    "ausweidetest": "ausweiden",
    "ausweidetet": "ausweiden",
    "ausweine": "ausweinen",
    "ausweinend": "ausweinen",
    "ausweinende": "ausweinend",
    "ausweinendem": "ausweinend",
    "ausweinenden": "ausweinend",
    "ausweinender": "ausweinend",
    "ausweinendes": "ausweinend",
    "ausweinest": "ausweinen",
    "ausweinet": "ausweinen",
    "ausweinst": "ausweinen",
    "ausweint": "ausweinen",
    "ausweinte": "ausweinen",
    "ausweinten": "ausweinen",
    "ausweintest": "ausweinen",
    "ausweintet": "ausweinen",
    "ausweisend": "ausweisen",
    "ausweisende": "ausweisend",
    "ausweisendem": "ausweisend",
    "ausweisenden": "ausweisend",
    "ausweisender": "ausweisend",
    "ausweisendere": "ausweisend",
    "ausweisenderem": "ausweisend",
    "ausweisenderen": "ausweisend",
    "ausweisenderer": "ausweisend",
    "ausweisenderes": "ausweisend",
    "ausweisendes": "ausweisend",
    "ausweisendste": "ausweisend",
    "ausweisendstem": "ausweisend",
    "ausweisendsten": "ausweisend",
    "ausweisendster": "ausweisend",
    "ausweisendstes": "ausweisend",
    "ausweisest": "ausweisen",
    "ausweiset": "ausweisen",
    "ausweist": "ausweisen",
    "ausweite": "ausweiten",
    "ausweitend": "ausweiten",
    "ausweitende": "ausweitend",
    "ausweitendem": "ausweitend",
    "ausweitenden": "ausweitend",
    "ausweitender": "ausweitend",
    "ausweitendere": "ausweitend",
    "ausweitenderem": "ausweitend",
    "ausweitenderen": "ausweitend",
    "ausweitenderer": "ausweitend",
    "ausweitenderes": "ausweitend",
    "ausweitendes": "ausweitend",
    "ausweitendste": "ausweitend",
    "ausweitendstem": "ausweitend",
    "ausweitendsten": "ausweitend",
    "ausweitendster": "ausweitend",
    "ausweitendstes": "ausweitend",
    "ausweitest": "ausweiten",
    "ausweitet": "ausweiten",
    "ausweitete": "ausweiten",
    "ausweiteten": "ausweiten",
    "ausweitetest": "ausweiten",
    "ausweitetet": "ausweiten",
    "auswendigem": "auswendig",
    "auswendigen": "auswendig",
    "auswendiger": "auswendig",
    "auswendiges": "auswendig",
    "auswerfe": "auswerfen",
    "auswerfend": "auswerfen",
    "auswerfende": "auswerfend",
    "auswerfendem": "auswerfend",
    "auswerfenden": "auswerfend",
    "auswerfender": "auswerfend",
    "auswerfendes": "auswerfend",
    "auswerfest": "auswerfen",
    "auswerfet": "auswerfen",
    "auswerft": "auswerfen",
    "auswerte": "auswerten",
    "auswertend": "auswerten",
    "auswertende": "auswertend",
    "auswertendem": "auswertend",
    "auswertenden": "auswertend",
    "auswertender": "auswertend",
    "auswertendes": "auswertend",
    "auswertest": "auswerten",
    "auswertet": "auswerten",
    "auswertete": "auswerten",
    "auswerteten": "auswerten",
    "auswertetest": "auswerten",
    "auswertetet": "auswerten",
    "auswetze": "auswetzen",
    "auswetzend": "auswetzen",
    "auswetzende": "auswetzend",
    "auswetzendem": "auswetzend",
    "auswetzenden": "auswetzend",
    "auswetzender": "auswetzend",
    "auswetzendere": "auswetzend",
    "auswetzenderem": "auswetzend",
    "auswetzenderen": "auswetzend",
    "auswetzenderer": "auswetzend",
    "auswetzenderes": "auswetzend",
    "auswetzendes": "auswetzend",
    "auswetzendste": "auswetzend",
    "auswetzendstem": "auswetzend",
    "auswetzendsten": "auswetzend",
    "auswetzendster": "auswetzend",
    "auswetzendstes": "auswetzend",
    "auswetzest": "auswetzen",
    "auswetzet": "auswetzen",
    "auswetzt": "auswetzen",
    "auswetzte": "auswetzen",
    "auswetzten": "auswetzen",
    "auswetztest": "auswetzen",
    "auswetztet": "auswetzen",
    "auswich": "ausweichen",
    "auswiche": "ausweichen",
    "auswichen": "ausweichen",
    "auswichest": "ausweichen",
    "auswichet": "ausweichen",
    "auswichst": "ausweichen",
    "auswicht": "ausweichen",
    "auswickele": "auswickeln",
    "auswickelnd": "auswickeln",
    "auswickelnde": "auswickelnd",
    "auswickelndem": "auswickelnd",
    "auswickelnden": "auswickelnd",
    "auswickelnder": "auswickelnd",
    "auswickelndes": "auswickelnd",
    "auswickelst": "auswickeln",
    "auswickelt": "auswickeln",
    "auswickelte": "auswickeln",
    "auswickelten": "auswickeln",
    "auswickeltest": "auswickeln",
    "auswickeltet": "auswickeln",
    "auswickle": "auswickeln",
    "auswiege": "auswiegen",
    "auswiegend": "auswiegen",
    "auswiegende": "auswiegend",
    "auswiegendem": "auswiegend",
    "auswiegenden": "auswiegend",
    "auswiegender": "auswiegend",
    "auswiegendes": "auswiegend",
    "auswiegest": "auswiegen",
    "auswieget": "auswiegen",
    "auswiegst": "auswiegen",
    "auswiegt": "auswiegen",
    "auswies": "ausweisen",
    "auswiese": "ausweisen",
    "auswiesen": "ausweisen",
    "auswiesest": "ausweisen",
    "auswieset": "ausweisen",
    "auswiest": "ausweisen",
    "auswinde": "auswinden",
    "auswindend": "auswinden",
    "auswindende": "auswindend",
    "auswindendem": "auswindend",
    "auswindenden": "auswindend",
    "auswindender": "auswindend",
    "auswindendes": "auswindend",
    "auswindest": "auswinden",
    "auswindet": "auswinden",
    "auswirfst": "auswerfen",
    "auswirft": "auswerfen",
    "auswirke": "auswirken",
    "auswirkend": "auswirken",
    "auswirkende": "auswirkend",
    "auswirkendem": "auswirkend",
    "auswirkenden": "auswirkend",
    "auswirkender": "auswirkend",
    "auswirkendes": "auswirkend",
    "auswirkest": "auswirken",
    "auswirket": "auswirken",
    "auswirkst": "auswirken",
    "auswirkt": "auswirken",
    "auswirkte": "auswirken",
    "auswirkten": "auswirken",
    "auswirktest": "auswirken",
    "auswirktet": "auswirken",
    "auswische": "auswischen",
    "auswischend": "auswischen",
    "auswischende": "auswischend",
    "auswischendem": "auswischend",
    "auswischenden": "auswischend",
    "auswischender": "auswischend",
    "auswischendes": "auswischend",
    "auswischest": "auswischen",
    "auswischet": "auswischen",
    "auswischst": "auswischen",
    "auswischt": "auswischen",
    "auswischte": "auswischen",
    "auswischten": "auswischen",
    "auswischtest": "auswischen",
    "auswischtet": "auswischen",
    "auswog": "auswiegen",
    "auswogen": "auswiegen",
    "auswogst": "auswiegen",
    "auswogt": "auswiegen",
    "auswrang": "auswringen",
    "auswrangen": "auswringen",
    "auswrangst": "auswringen",
    "auswrangt": "auswringen",
    "auswringe": "auswringen",
    "auswringend": "auswringen",
    "auswringende": "auswringend",
    "auswringendem": "auswringend",
    "auswringenden": "auswringend",
    "auswringender": "auswringend",
    "auswringendes": "auswringend",
    "auswringest": "auswringen",
    "auswringet": "auswringen",
    "auswringst": "auswringen",
    "auswringt": "auswringen",
    "auswränge": "auswringen",
    "auswrängen": "auswringen",
    "auswrängest": "auswringen",
    "auswränget": "auswringen",
    "auswuchs": "auswachsen",
    "auswuchsen": "auswachsen",
    "auswuchst": "auswachsen",
    "auswuchte": "auswuchten",
    "auswuchtend": "auswuchten",
    "auswuchtende": "auswuchtend",
    "auswuchtendem": "auswuchtend",
    "auswuchtenden": "auswuchtend",
    "auswuchtender": "auswuchtend",
    "auswuchtendere": "auswuchtend",
    "auswuchtenderem": "auswuchtend",
    "auswuchtenderen": "auswuchtend",
    "auswuchtenderer": "auswuchtend",
    "auswuchtenderes": "auswuchtend",
    "auswuchtendes": "auswuchtend",
    "auswuchtendste": "auswuchtend",
    "auswuchtendstem": "auswuchtend",
    "auswuchtendsten": "auswuchtend",
    "auswuchtendster": "auswuchtend",
    "auswuchtendstes": "auswuchtend",
    "auswuchtest": "auswuchten",
    "auswuchtet": "auswuchten",
    "auswuchtete": "auswuchten",
    "auswuchteten": "auswuchten",
    "auswuchtetest": "auswuchten",
    "auswuchtetet": "auswuchten",
    "auswusch": "auswaschen",
    "auswuschen": "auswaschen",
    "auswuschst": "auswaschen",
    "auswuscht": "auswaschen",
    "auswächst": "auswachsen",
    "auswähle": "auswählen",
    "auswählend": "auswählen",
    "auswählende": "auswählend",
    "auswählendem": "auswählend",
    "auswählenden": "auswählend",
    "auswählender": "auswählend",
    "auswählendes": "auswählend",
    "auswählest": "auswählen",
    "auswählet": "auswählen",
    "auswählst": "auswählen",
    "auswählt": "auswählen",
    "auswählte": "auswählen",
    "auswählten": "auswählen",
    "auswähltest": "auswählen",
    "auswähltet": "auswählen",
    "auswände": "auswinden",
    "auswänden": "auswinden",
    "auswändest": "auswinden",
    "auswändet": "auswinden",
    "auswärfe": "auswerfen",
    "auswärfen": "auswerfen",
    "auswärfest": "auswerfen",
    "auswärfet": "auswerfen",
    "auswärme": "auswärmen",
    "auswärmend": "auswärmen",
    "auswärmende": "auswärmend",
    "auswärmendem": "auswärmend",
    "auswärmenden": "auswärmend",
    "auswärmender": "auswärmend",
    "auswärmendes": "auswärmend",
    "auswärmest": "auswärmen",
    "auswärmet": "auswärmen",
    "auswärmst": "auswärmen",
    "auswärmt": "auswärmen",
    "auswärmte": "auswärmen",
    "auswärmten": "auswärmen",
    "auswärmtest": "auswärmen",
    "auswärmtet": "auswärmen",
    "auswärtige": "auswärtig",
    "auswärtigem": "auswärtig",
    "auswärtigen": "auswärtig",
    "auswärtiger": "auswärtig",
    "auswärtiges": "auswärtig",
    "auswäschst": "auswaschen",
    "auswäscht": "auswaschen",
    "auswöge": "auswiegen",
    "auswögen": "auswiegen",
    "auswögest": "auswiegen",
    "auswöget": "auswiegen",
    "auswüchse": "auswachsen",
    "auswüchsen": "auswachsen",
    "auswüchsest": "auswachsen",
    "auswüchset": "auswachsen",
    "auswüsche": "auswaschen",
    "auswüschen": "auswaschen",
    "auswüschest": "auswaschen",
    "auswüschet": "auswaschen",
    "auszahle": "auszahlen",
    "auszahlend": "auszahlen",
    "auszahlende": "auszahlend",
    "auszahlendem": "auszahlend",
    "auszahlenden": "auszahlend",
    "auszahlender": "auszahlend",
    "auszahlendes": "auszahlend",
    "auszahlest": "auszahlen",
    "auszahlet": "auszahlen",
    "auszahlst": "auszahlen",
    "auszahlt": "auszahlen",
    "auszahlte": "auszahlen",
    "auszahlten": "auszahlen",
    "auszahltest": "auszahlen",
    "auszahltet": "auszahlen",
    "auszahne": "auszahnen",
    "auszahnend": "auszahnen",
    "auszahnende": "auszahnend",
    "auszahnendem": "auszahnend",
    "auszahnenden": "auszahnend",
    "auszahnender": "auszahnend",
    "auszahnendere": "auszahnend",
    "auszahnenderem": "auszahnend",
    "auszahnenderen": "auszahnend",
    "auszahnenderer": "auszahnend",
    "auszahnenderes": "auszahnend",
    "auszahnendes": "auszahnend",
    "auszahnendste": "auszahnend",
    "auszahnendstem": "auszahnend",
    "auszahnendsten": "auszahnend",
    "auszahnendster": "auszahnend",
    "auszahnendstes": "auszahnend",
    "auszahnest": "auszahnen",
    "auszahnet": "auszahnen",
    "auszahnst": "auszahnen",
    "auszahnt": "auszahnen",
    "auszahnte": "auszahnen",
    "auszahnten": "auszahnen",
    "auszahntest": "auszahnen",
    "auszahntet": "auszahnen",
    "auszanke": "auszanken",
    "auszankend": "auszanken",
    "auszankende": "auszankend",
    "auszankendem": "auszankend",
    "auszankenden": "auszankend",
    "auszankender": "auszankend",
    "auszankendere": "auszankend",
    "auszankenderem": "auszankend",
    "auszankenderen": "auszankend",
    "auszankenderer": "auszankend",
    "auszankenderes": "auszankend",
    "auszankendes": "auszankend",
    "auszankendste": "auszankend",
    "auszankendstem": "auszankend",
    "auszankendsten": "auszankend",
    "auszankendster": "auszankend",
    "auszankendstes": "auszankend",
    "auszankest": "auszanken",
    "auszanket": "auszanken",
    "auszankst": "auszanken",
    "auszankt": "auszanken",
    "auszankte": "auszanken",
    "auszankten": "auszanken",
    "auszanktest": "auszanken",
    "auszanktet": "auszanken",
    "auszeichne": "auszeichnen",
    "auszeichnend": "auszeichnen",
    "auszeichnende": "auszeichnend",
    "auszeichnendem": "auszeichnend",
    "auszeichnenden": "auszeichnend",
    "auszeichnender": "auszeichnend",
    "auszeichnendes": "auszeichnend",
    "auszeichnest": "auszeichnen",
    "auszeichnet": "auszeichnen",
    "auszeichnete": "auszeichnen",
    "auszeichneten": "auszeichnen",
    "auszeichnetest": "auszeichnen",
    "auszeichnetet": "auszeichnen",
    "ausziehe": "ausziehen",
    "ausziehend": "ausziehen",
    "ausziehende": "ausziehend",
    "ausziehendem": "ausziehend",
    "ausziehenden": "ausziehend",
    "ausziehender": "ausziehend",
    "ausziehendes": "ausziehend",
    "ausziehest": "ausziehen",
    "ausziehet": "ausziehen",
    "ausziehst": "ausziehen",
    "auszieht": "ausziehen",
    "ausziere": "auszieren",
    "auszierend": "auszieren",
    "auszierende": "auszierend",
    "auszierendem": "auszierend",
    "auszierenden": "auszierend",
    "auszierender": "auszierend",
    "auszierendere": "auszierend",
    "auszierenderem": "auszierend",
    "auszierenderen": "auszierend",
    "auszierenderer": "auszierend",
    "auszierenderes": "auszierend",
    "auszierendes": "auszierend",
    "auszierendste": "auszierend",
    "auszierendstem": "auszierend",
    "auszierendsten": "auszierend",
    "auszierendster": "auszierend",
    "auszierendstes": "auszierend",
    "auszierest": "auszieren",
    "auszieret": "auszieren",
    "auszierst": "auszieren",
    "ausziert": "auszieren",
    "auszierte": "auszieren",
    "auszierten": "auszieren",
    "ausziertest": "auszieren",
    "ausziertet": "auszieren",
    "auszirkele": "auszirkeln",
    "auszirkelnd": "auszirkeln",
    "auszirkelnde": "auszirkelnd",
    "auszirkelndem": "auszirkelnd",
    "auszirkelnden": "auszirkelnd",
    "auszirkelnder": "auszirkelnd",
    "auszirkelndes": "auszirkelnd",
    "auszirkelst": "auszirkeln",
    "auszirkelt": "auszirkeln",
    "auszirkelte": "auszirkeln",
    "auszirkelten": "auszirkeln",
    "auszirkeltest": "auszirkeln",
    "auszirkeltet": "auszirkeln",
    "auszirkle": "auszirkeln",
    "auszische": "auszischen",
    "auszischend": "auszischen",
    "auszischende": "auszischend",
    "auszischendem": "auszischend",
    "auszischenden": "auszischend",
    "auszischender": "auszischend",
    "auszischendes": "auszischend",
    "auszischest": "auszischen",
    "auszischet": "auszischen",
    "auszischst": "auszischen",
    "auszischt": "auszischen",
    "auszischte": "auszischen",
    "auszischten": "auszischen",
    "auszischtest": "auszischen",
    "auszischtet": "auszischen",
    "auszog": "ausziehen",
    "auszogen": "ausziehen",
    "auszogst": "ausziehen",
    "auszogt": "ausziehen",
    "auszuarbeiten": "ausarbeiten",
    "auszuarten": "ausarten",
    "auszuatmen": "ausatmen",
    "auszubaden": "ausbaden",
    "auszubaggern": "ausbaggern",
    "auszubaldowern": "ausbaldowern",
    "auszubauchen": "ausbauchen",
    "auszubauen": "ausbauen",
    "auszubeißen": "ausbeißen",
    "auszubessern": "ausbessern",
    "auszubetonieren": "ausbetonieren",
    "auszubeulen": "ausbeulen",
    "auszubeuteln": "ausbeuteln",
    "auszubeuten": "ausbeuten",
    "auszubezahlen": "ausbezahlen",
    "auszubiegen": "ausbiegen",
    "auszubieten": "ausbieten",
    "auszubilden": "ausbilden",
    "auszubitten": "ausbitten",
    "auszublasen": "ausblasen",
    "auszubleiben": "ausbleiben",
    "auszubleichen": "ausbleichen",
    "auszublenden": "ausblenden",
    "auszubluten": "ausbluten",
    "auszubohren": "ausbohren",
    "auszubomben": "ausbomben",
    "auszubooten": "ausbooten",
    "auszuborgen": "ausborgen",
    "auszubraten": "ausbraten",
    "auszubrechen": "ausbrechen",
    "auszubreiten": "ausbreiten",
    "auszubremsen": "ausbremsen",
    "auszubrennen": "ausbrennen",
    "auszubringen": "ausbringen",
    "auszubrüten": "ausbrüten",
    "auszubuchen": "ausbuchen",
    "auszubuchten": "ausbuchten",
    "auszubuddeln": "ausbuddeln",
    "auszubügeln": "ausbügeln",
    "auszubürgern": "ausbürgern",
    "auszubürsten": "ausbürsten",
    "auszubüxen": "ausbüxen",
    "auszuchecken": "auschecken",
    "auszudauern": "ausdauern",
    "auszudehnen": "ausdehnen",
    "auszudenken": "ausdenken",
    "auszudeuten": "ausdeuten",
    "auszudienen": "ausdienen",
    "auszudifferenzieren": "ausdifferenzieren",
    "auszudiskutieren": "ausdiskutieren",
    "auszudrehen": "ausdrehen",
    "auszudreschen": "ausdreschen",
    "auszudringen": "ausdringen",
    "auszudrucken": "ausdrucken",
    "auszudrücken": "ausdrücken",
    "auszudunsten": "ausdunsten",
    "auszudörren": "ausdörren",
    "auszuerkiesen": "auserkiesen",
    "auszuersehen": "ausersehen",
    "auszuerwählen": "auserwählen",
    "auszuessen": "ausessen",
    "auszufahren": "ausfahren",
    "auszufallen": "ausfallen",
    "auszufasern": "ausfasern",
    "auszufechten": "ausfechten",
    "auszufegen": "ausfegen",
    "auszufeilen": "ausfeilen",
    "auszufertigen": "ausfertigen",
    "auszufiltern": "ausfiltern",
    "auszufischen": "ausfischen",
    "auszuflaggen": "ausflaggen",
    "auszufliegen": "ausfliegen",
    "auszufließen": "ausfließen",
    "auszuflippen": "ausflippen",
    "auszuflocken": "ausflocken",
    "auszufolgen": "ausfolgen",
    "auszuformulieren": "ausformulieren",
    "auszuforschen": "ausforschen",
    "auszufragen": "ausfragen",
    "auszufransen": "ausfransen",
    "auszufressen": "ausfressen",
    "auszufrieren": "ausfrieren",
    "auszufugen": "ausfugen",
    "auszufädeln": "ausfädeln",
    "auszufällen": "ausfällen",
    "auszuführen": "ausführen",
    "auszufüllen": "ausfüllen",
    "auszufüttern": "ausfüttern",
    "auszugeben": "ausgeben",
    "auszugehen": "ausgehen",
    "auszugeizen": "ausgeizen",
    "auszugestalten": "ausgestalten",
    "auszugießen": "ausgießen",
    "auszugleichen": "ausgleichen",
    "auszugleiten": "ausgleiten",
    "auszugliedern": "ausgliedern",
    "auszuglimmen": "ausglimmen",
    "auszuglitschen": "ausglitschen",
    "auszuglühen": "ausglühen",
    "auszugraben": "ausgraben",
    "auszugreifen": "ausgreifen",
    "auszugrenzen": "ausgrenzen",
    "auszuhaken": "aushaken",
    "auszuhalten": "aushalten",
    "auszuhandeln": "aushandeln",
    "auszuhauchen": "aushauchen",
    "auszuhauen": "aushauen",
    "auszuheben": "ausheben",
    "auszuheilen": "ausheilen",
    "auszuhelfen": "aushelfen",
    "auszuholen": "ausholen",
    "auszuholzen": "ausholzen",
    "auszuhorchen": "aushorchen",
    "auszuhungern": "aushungern",
    "auszuhusten": "aushusten",
    "auszuhändigen": "aushändigen",
    "auszuhängen": "aushängen",
    "auszuhärten": "aushärten",
    "auszuhöhlen": "aushöhlen",
    "auszuhülsen": "aushülsen",
    "auszukegeln": "auskegeln",
    "auszukehren": "auskehren",
    "auszukeilen": "auskeilen",
    "auszukeimen": "auskeimen",
    "auszukeltern": "auskeltern",
    "auszukennen": "auskennen",
    "auszukernen": "auskernen",
    "auszuklammern": "ausklammern",
    "auszuklamüsern": "ausklamüsern",
    "auszukleben": "auskleben",
    "auszukleiden": "auskleiden",
    "auszuklingen": "ausklingen",
    "auszuklinken": "ausklinken",
    "auszuklopfen": "ausklopfen",
    "auszuklügeln": "ausklügeln",
    "auszukneifen": "auskneifen",
    "auszuknipsen": "ausknipsen",
    "auszuknobeln": "ausknobeln",
    "auszukochen": "auskochen",
    "auszukommen": "auskommen",
    "auszukosten": "auskosten",
    "auszukramen": "auskramen",
    "auszukratzen": "auskratzen",
    "auszukriechen": "auskriechen",
    "auszukristallisieren": "auskristallisiere",
    "auszukugeln": "auskugeln",
    "auszukundschaften": "auskundschaften",
    "auszukuppeln": "auskuppeln",
    "auszukurieren": "auskurieren",
    "auszukämmen": "auskämmen",
    "auszukämpfen": "auskämpfen",
    "auszukühlen": "auskühlen",
    "auszulachen": "auslachen",
    "auszuladen": "ausladen",
    "auszulagern": "auslagern",
    "auszulangen": "auslangen",
    "auszulassen": "auslassen",
    "auszulasten": "auslasten",
    "auszulatschen": "auslatschen",
    "auszulaufen": "auslaufen",
    "auszulaugen": "auslaugen",
    "auszulauten": "auslauten",
    "auszuleben": "ausleben",
    "auszuleeren": "ausleeren",
    "auszulegen": "auslegen",
    "auszuleiden": "ausleiden",
    "auszuleiern": "ausleiern",
    "auszuleihen": "ausleihen",
    "auszulernen": "auslernen",
    "auszulesen": "auslesen",
    "auszuleuchten": "ausleuchten",
    "auszulichten": "auslichten",
    "auszuliefern": "ausliefern",
    "auszulosen": "auslosen",
    "auszuloten": "ausloten",
    "auszuläuten": "ausläuten",
    "auszulöffeln": "auslöffeln",
    "auszulöschen": "auslöschen",
    "auszulösen": "auslösen",
    "auszulüften": "auslüften",
    "auszumachen": "ausmachen",
    "auszumahlen": "ausmahlen",
    "auszumalen": "ausmalen",
    "auszumeißeln": "ausmeißeln",
    "auszumelken": "ausmelken",
    "auszumerzen": "ausmerzen",
    "auszumessen": "ausmessen",
    "auszumisten": "ausmisten",
    "auszumustern": "ausmustern",
    "auszumünden": "ausmünden",
    "auszunehmen": "ausnehmen",
    "auszunutzen": "ausnutzen",
    "auszupacken": "auspacken",
    "auszuparken": "ausparken",
    "auszupeitschen": "auspeitschen",
    "auszupendeln": "auspendeln",
    "auszupfe": "auszupfen",
    "auszupfeifen": "auspfeifen",
    "auszupfend": "auszupfen",
    "auszupfende": "auszupfend",
    "auszupfendem": "auszupfend",
    "auszupfenden": "auszupfend",
    "auszupfender": "auszupfend",
    "auszupfendes": "auszupfend",
    "auszupfest": "auszupfen",
    "auszupfet": "auszupfen",
    "auszupflanzen": "auspflanzen",
    "auszupfst": "auszupfen",
    "auszupft": "auszupfen",
    "auszupfte": "auszupfen",
    "auszupften": "auszupfen",
    "auszupftest": "auszupfen",
    "auszupftet": "auszupfen",
    "auszuplappern": "ausplappern",
    "auszuplaudern": "ausplaudern",
    "auszuplündern": "ausplündern",
    "auszupolstern": "auspolstern",
    "auszuposaunen": "ausposaunen",
    "auszupowern": "auspowern",
    "auszupressen": "auspressen",
    "auszuprobieren": "ausprobieren",
    "auszuprägen": "ausprägen",
    "auszupumpen": "auspumpen",
    "auszupusten": "auspusten",
    "auszuputzen": "ausputzen",
    "auszuquartieren": "ausquartieren",
    "auszuquatschen": "ausquatschen",
    "auszuquetschen": "ausquetschen",
    "auszuradieren": "ausradieren",
    "auszurangieren": "ausrangieren",
    "auszurasieren": "ausrasieren",
    "auszurasten": "ausrasten",
    "auszurauben": "ausrauben",
    "auszurauchen": "ausrauchen",
    "auszurechnen": "ausrechnen",
    "auszureden": "ausreden",
    "auszuregnen": "ausregnen",
    "auszureiben": "ausreiben",
    "auszureichen": "ausreichen",
    "auszureifen": "ausreifen",
    "auszureisen": "ausreisen",
    "auszureiten": "ausreiten",
    "auszureizen": "ausreizen",
    "auszureißen": "ausreißen",
    "auszurenken": "ausrenken",
    "auszurichten": "ausrichten",
    "auszuroden": "ausroden",
    "auszurollen": "ausrollen",
    "auszurotten": "ausrotten",
    "auszurufen": "ausrufen",
    "auszuruhen": "ausruhen",
    "auszurupfen": "ausrupfen",
    "auszurutschen": "ausrutschen",
    "auszuräuchern": "ausräuchern",
    "auszuräumen": "ausräumen",
    "auszurücken": "ausrücken",
    "auszurüsten": "ausrüsten",
    "auszusagen": "aussagen",
    "auszusalzen": "aussalzen",
    "auszusaufen": "aussaufen",
    "auszusaugen": "aussaugen",
    "auszuschaben": "ausschaben",
    "auszuschachteln": "ausschachteln",
    "auszuschalen": "ausschalen",
    "auszuschalten": "ausschalten",
    "auszuscharren": "ausscharren",
    "auszuschauen": "ausschauen",
    "auszuschaufeln": "ausschaufeln",
    "auszuscheiden": "ausscheiden",
    "auszuschelten": "ausschelten",
    "auszuschenken": "ausschenken",
    "auszuscheren": "ausscheren",
    "auszuschießen": "ausschießen",
    "auszuschiffen": "ausschiffen",
    "auszuschildern": "ausschildern",
    "auszuschimpfen": "ausschimpfen",
    "auszuschirren": "ausschirren",
    "auszuschlachten": "ausschlachten",
    "auszuschlafen": "ausschlafen",
    "auszuschlagen": "ausschlagen",
    "auszuschleimen": "ausschleimen",
    "auszuschließen": "ausschließen",
    "auszuschlämmen": "ausschlämmen",
    "auszuschlüpfen": "ausschlüpfen",
    "auszuschlürfen": "ausschlürfen",
    "auszuschmelzen": "ausschmelzen",
    "auszuschmieren": "ausschmieren",
    "auszuschnappen": "ausschnappen",
    "auszuschnauben": "ausschnauben",
    "auszuschnaufen": "ausschnaufen",
    "auszuschneiden": "ausschneiden",
    "auszuschneuzen": "ausschneuzen",
    "auszuschnäuzen": "ausschnäuzen",
    "auszuschrauben": "ausschrauben",
    "auszuschreiben": "ausschreiben",
    "auszuschreien": "ausschreien",
    "auszuschulen": "ausschulen",
    "auszuschwefeln": "ausschwefeln",
    "auszuschweifen": "ausschweifen",
    "auszuschweigen": "ausschweigen",
    "auszuschwemmen": "ausschwemmen",
    "auszuschwenken": "ausschwenken",
    "auszuschwingen": "ausschwingen",
    "auszuschwitzen": "ausschwitzen",
    "auszuschwärmen": "ausschwärmen",
    "auszuschälen": "ausschälen",
    "auszuschöpfen": "ausschöpfen",
    "auszuschütteln": "ausschütteln",
    "auszuschütten": "ausschütten",
    "auszusehen": "aussehen",
    "auszusenden": "aussenden",
    "auszusetzen": "aussetzen",
    "auszusieben": "aussieben",
    "auszusiedeln": "aussiedeln",
    "auszusitzen": "aussitzen",
    "auszusondern": "aussondern",
    "auszusortieren": "aussortieren",
    "auszuspannen": "ausspannen",
    "auszusparen": "aussparen",
    "auszuspeien": "ausspeien",
    "auszusperren": "aussperren",
    "auszuspielen": "ausspielen",
    "auszuspionieren": "ausspionieren",
    "auszusprechen": "aussprechen",
    "auszusprengen": "aussprengen",
    "auszuspritzen": "ausspritzen",
    "auszusprühen": "aussprühen",
    "auszuspucken": "ausspucken",
    "auszuspähen": "ausspähen",
    "auszuspülen": "ausspülen",
    "auszustaffieren": "ausstaffieren",
    "auszustanzen": "ausstanzen",
    "auszustatten": "ausstatten",
    "auszustechen": "ausstechen",
    "auszustehen": "ausstehen",
    "auszusteifen": "aussteifen",
    "auszusteigen": "aussteigen",
    "auszustellen": "ausstellen",
    "auszusterben": "aussterben",
    "auszusteuern": "aussteuern",
    "auszustopfen": "ausstopfen",
    "auszustoßen": "ausstoßen",
    "auszustrahlen": "ausstrahlen",
    "auszustreichen": "ausstreichen",
    "auszustreuen": "ausstreuen",
    "auszuströmen": "ausströmen",
    "auszustülpen": "ausstülpen",
    "auszusuchen": "aussuchen",
    "auszusäen": "aussäen",
    "auszusägen": "aussägen",
    "auszusöhnen": "aussöhnen",
    "auszutarieren": "austarieren",
    "auszutauschen": "austauschen",
    "auszuteilen": "austeilen",
    "auszutilgen": "austilgen",
    "auszutoben": "austoben",
    "auszutragen": "austragen",
    "auszutreiben": "austreiben",
    "auszutreten": "austreten",
    "auszutricksen": "austricksen",
    "auszutrinken": "austrinken",
    "auszutrocknen": "austrocknen",
    "auszutrompeten": "austrompeten",
    "auszuträumen": "austräumen",
    "auszutupfen": "austupfen",
    "auszutüfteln": "austüfteln",
    "auszuufern": "ausufern",
    "auszuverkaufen": "ausverkaufen",
    "auszuwachsen": "auswachsen",
    "auszuwalzen": "auswalzen",
    "auszuwandern": "auswandern",
    "auszuwaschen": "auswaschen",
    "auszuwechseln": "auswechseln",
    "auszuweichen": "ausweichen",
    "auszuweiden": "ausweiden",
    "auszuweinen": "ausweinen",
    "auszuweisen": "ausweisen",
    "auszuweiten": "ausweiten",
    "auszuwerfen": "auswerfen",
    "auszuwerten": "auswerten",
    "auszuwetzen": "auswetzen",
    "auszuwickeln": "auswickeln",
    "auszuwiegen": "auswiegen",
    "auszuwinden": "auswinden",
    "auszuwirken": "auswirken",
    "auszuwischen": "auswischen",
    "auszuwringen": "auswringen",
    "auszuwuchten": "auswuchten",
    "auszuwählen": "auswählen",
    "auszuwärmen": "auswärmen",
    "auszuzahlen": "auszahlen",
    "auszuzahnen": "auszahnen",
    "auszuzanken": "auszanken",
    "auszuzeichnen": "auszeichnen",
    "auszuziehen": "ausziehen",
    "auszuzieren": "auszieren",
    "auszuzirkeln": "auszirkeln",
    "auszuzischen": "auszischen",
    "auszuzupfen": "auszupfen",
    "auszuzählen": "auszählen",
    "auszuüben": "ausüben",
    "auszähle": "auszählen",
    "auszählend": "auszählen",
    "auszählendem": "auszählend",
    "auszählender": "auszählend",
    "auszählendes": "auszählend",
    "auszählest": "auszählen",
    "auszählet": "auszählen",
    "auszählst": "auszählen",
    "auszählt": "auszählen",
    "auszählte": "auszählen",
    "auszählten": "auszählen",
    "auszähltest": "auszählen",
    "auszähltet": "auszählen",
    "auszöge": "ausziehen",
    "auszögen": "ausziehen",
    "auszögest": "ausziehen",
    "auszöget": "ausziehen",
    "ausäße": "ausessen",
    "ausäßen": "ausessen",
    "ausäßest": "ausessen",
    "ausäßet": "ausessen",
    "ausübe": "ausüben",
    "ausübend": "ausüben",
    "ausübende": "ausübend",
    "ausübendem": "ausübend",
    "ausübenden": "ausübend",
    "ausübender": "ausübend",
    "ausübendes": "ausübend",
    "ausübest": "ausüben",
    "ausübet": "ausüben",
    "ausübst": "ausüben",
    "ausübt": "ausüben",
    "ausübte": "ausüben",
    "ausübten": "ausüben",
    "ausübtest": "ausüben",
    "ausübtet": "ausüben",
    "authentifiziere": "authentifizieren",
    "authentifizierend": "authentifizieren",
    "authentifizierende": "authentifizierend",
    "authentifizierendem": "authentifizierend",
    "authentifizierenden": "authentifizierend",
    "authentifizierender": "authentifizierend",
    "authentifizierendere": "authentifizierend",
    "authentifizierenderem": "authentifizierend",
    "authentifizierenderen": "authentifizierend",
    "authentifizierenderer": "authentifizierend",
    "authentifizierenderes": "authentifizierend",
    "authentifizierendes": "authentifizierend",
    "authentifizierendste": "authentifizierend",
    "authentifizierendstem": "authentifizierend",
    "authentifizierendsten": "authentifizierend",
    "authentifizierendster": "authentifizierend",
    "authentifizierendstes": "authentifizierend",
    "authentifizierest": "authentifizieren",
    "authentifizieret": "authentifizieren",
    "authentifizierst": "authentifizieren",
    "authentifiziert": "authentifizieren",
    "authentifizierte": "authentifizieren",
    "authentifiziertem": "authentifiziert",
    "authentifizierten": "authentifizieren",
    "authentifizierter": "authentifiziert",
    "authentifiziertes": "authentifiziert",
    "authentifiziertest": "authentifizieren",
    "authentifiziertet": "authentifizieren",
    "authentische": "authentisch",
    "authentischem": "authentisch",
    "authentischen": "authentisch",
    "authentischer": "authentisch",
    "authentischere": "authentisch",
    "authentischerem": "authentisch",
    "authentischeren": "authentisch",
    "authentischerer": "authentisch",
    "authentischeres": "authentisch",
    "authentisches": "authentisch",
    "authentischste": "authentisch",
    "authentischstem": "authentisch",
    "authentischsten": "authentisch",
    "authentischster": "authentisch",
    "authentischstes": "authentisch",
    "authentisiere": "authentisieren",
    "authentisierend": "authentisieren",
    "authentisierende": "authentisierend",
    "authentisierendem": "authentisierend",
    "authentisierenden": "authentisierend",
    "authentisierender": "authentisierend",
    "authentisierendere": "authentisierend",
    "authentisierenderem": "authentisierend",
    "authentisierenderen": "authentisierend",
    "authentisierenderer": "authentisierend",
    "authentisierenderes": "authentisierend",
    "authentisierendes": "authentisierend",
    "authentisierendste": "authentisierend",
    "authentisierendstem": "authentisierend",
    "authentisierendsten": "authentisierend",
    "authentisierendster": "authentisierend",
    "authentisierendstes": "authentisierend",
    "authentisierest": "authentisieren",
    "authentisieret": "authentisieren",
    "authentisierst": "authentisieren",
    "authentisiert": "authentisieren",
    "authentisierte": "authentisieren",
    "authentisiertem": "authentisiert",
    "authentisierten": "authentisieren",
    "authentisierter": "authentisiert",
    "authentisiertes": "authentisiert",
    "authentisiertest": "authentisieren",
    "authentisiertet": "authentisieren",
    "autistischem": "autistisch",
    "autistischen": "autistisch",
    "autistischer": "autistisch",
    "autistisches": "autistisch",
    "autobiographischem": "autobiographisch",
    "autobiographischen": "autobiographisch",
    "autobiographischer": "autobiographisch",
    "autobiographisches": "autobiographisch",
    "autodidaktischem": "autodidaktisch",
    "autodidaktischen": "autodidaktisch",
    "autodidaktischer": "autodidaktisch",
    "autodidaktisches": "autodidaktisch",
    "autofreiem": "autofrei",
    "autofreien": "autofrei",
    "autofreier": "autofrei",
    "autofreies": "autofrei",
    "autogene": "autogen",
    "autogenem": "autogen",
    "autogenen": "autogen",
    "autogener": "autogen",
    "autogenes": "autogen",
    "autographischem": "autographisch",
    "autographischen": "autographisch",
    "autographischer": "autographisch",
    "autographisches": "autographisch",
    "autokratischem": "autokratisch",
    "autokratischen": "autokratisch",
    "autokratischer": "autokratisch",
    "autokratisches": "autokratisch",
    "automatischem": "automatisch",
    "automatischen": "automatisch",
    "automatischer": "automatisch",
    "automatischere": "automatisch",
    "automatischerem": "automatisch",
    "automatischeren": "automatisch",
    "automatischerer": "automatisch",
    "automatischeres": "automatisch",
    "automatisches": "automatisch",
    "automatischste": "automatisch",
    "automatischstem": "automatisch",
    "automatischsten": "automatisch",
    "automatischster": "automatisch",
    "automatischstes": "automatisch",
    "automatisiere": "automatisieren",
    "automatisierend": "automatisieren",
    "automatisierende": "automatisierend",
    "automatisierendem": "automatisierend",
    "automatisierenden": "automatisierend",
    "automatisierender": "automatisierend",
    "automatisierendere": "automatisierend",
    "automatisierenderem": "automatisierend",
    "automatisierenderen": "automatisierend",
    "automatisierenderer": "automatisierend",
    "automatisierenderes": "automatisierend",
    "automatisierendes": "automatisierend",
    "automatisierendste": "automatisierend",
    "automatisierendstem": "automatisierend",
    "automatisierendsten": "automatisierend",
    "automatisierendster": "automatisierend",
    "automatisierendstes": "automatisierend",
    "automatisierest": "automatisieren",
    "automatisieret": "automatisieren",
    "automatisierst": "automatisieren",
    "automatisiert": "automatisieren",
    "automatisierte": "automatisieren",
    "automatisiertem": "automatisiert",
    "automatisierten": "automatisieren",
    "automatisierter": "automatisiert",
    "automatisiertere": "automatisiert",
    "automatisierterem": "automatisiert",
    "automatisierteren": "automatisiert",
    "automatisierterer": "automatisiert",
    "automatisierteres": "automatisiert",
    "automatisiertes": "automatisiert",
    "automatisiertest": "automatisieren",
    "automatisiertestem": "automatisiert",
    "automatisiertesten": "automatisiert",
    "automatisiertester": "automatisiert",
    "automatisiertestes": "automatisiert",
    "automatisiertet": "automatisieren",
    "autonomem": "autonom",
    "autonomen": "autonom",
    "autonomer": "autonom",
    "autonomere": "autonom",
    "autonomerem": "autonom",
    "autonomeren": "autonom",
    "autonomerer": "autonom",
    "autonomeres": "autonom",
    "autonomes": "autonom",
    "autonomstem": "autonom",
    "autonomsten": "autonom",
    "autonomster": "autonom",
    "autonomstes": "autonom",
    "autorisiere": "autorisieren",
    "autorisierend": "autorisieren",
    "autorisierende": "autorisierend",
    "autorisierendem": "autorisierend",
    "autorisierenden": "autorisierend",
    "autorisierender": "autorisierend",
    "autorisierendes": "autorisierend",
    "autorisierest": "autorisieren",
    "autorisieret": "autorisieren",
    "autorisierst": "autorisieren",
    "autorisiert": "autorisieren",
    "autorisierte": "autorisieren",
    "autorisiertem": "autorisiert",
    "autorisierten": "autorisieren",
    "autorisierter": "autorisiert",
    "autorisiertes": "autorisiert",
    "autorisiertest": "autorisieren",
    "autorisiertet": "autorisieren",
    "autoritativem": "autoritativ",
    "autoritativen": "autoritativ",
    "autoritativer": "autoritativ",
    "autoritativere": "autoritativ",
    "autoritativerem": "autoritativ",
    "autoritativeren": "autoritativ",
    "autoritativerer": "autoritativ",
    "autoritativeres": "autoritativ",
    "autoritatives": "autoritativ",
    "autoritativste": "autoritativ",
    "autoritativstem": "autoritativ",
    "autoritativsten": "autoritativ",
    "autoritativster": "autoritativ",
    "autoritativstes": "autoritativ",
    "autoritäre": "autoritär",
    "autoritärem": "autoritär",
    "autoritären": "autoritär",
    "autoritärer": "autoritär",
    "autoritärere": "autoritär",
    "autoritärerem": "autoritär",
    "autoritäreren": "autoritär",
    "autoritärerer": "autoritär",
    "autoritäreres": "autoritär",
    "autoritäres": "autoritär",
    "autoritärste": "autoritär",
    "autoritärstem": "autoritär",
    "autoritärsten": "autoritär",
    "autoritärster": "autoritär",
    "autoritärstes": "autoritär",
    "autosuggestivem": "autosuggestiv",
    "autosuggestiven": "autosuggestiv",
    "autosuggestiver": "autosuggestiv",
    "autosuggestivere": "autosuggestiv",
    "autosuggestiverem": "autosuggestiv",
    "autosuggestiveren": "autosuggestiv",
    "autosuggestiverer": "autosuggestiv",
    "autosuggestiveres": "autosuggestiv",
    "autosuggestives": "autosuggestiv",
    "autosuggestivste": "autosuggestiv",
    "autosuggestivstem": "autosuggestiv",
    "autosuggestivsten": "autosuggestiv",
    "autosuggestivster": "autosuggestiv",
    "autosuggestivstes": "autosuggestiv",
    "außenpolitischem": "außenpolitisch",
    "außenpolitischen": "außenpolitisch",
    "außenpolitischer": "außenpolitisch",
    "außenpolitischere": "außenpolitisch",
    "außenpolitischerem": "außenpolitisch",
    "außenpolitischeren": "außenpolitisch",
    "außenpolitischerer": "außenpolitisch",
    "außenpolitischeres": "außenpolitisch",
    "außenpolitisches": "außenpolitisch",
    "außenpolitischste": "außenpolitisch",
    "außenpolitischstem": "außenpolitisch",
    "außenpolitischsten": "außenpolitisch",
    "außenpolitischster": "außenpolitisch",
    "außenpolitischstes": "außenpolitisch",
    "außeramtlichem": "außeramtlich",
    "außeramtlichen": "außeramtlich",
    "außeramtlicher": "außeramtlich",
    "außeramtliches": "außeramtlich",
    "außerdeutsche": "außerdeutsch",
    "außerdeutschem": "außerdeutsch",
    "außerdeutschen": "außerdeutsch",
    "außerdeutscher": "außerdeutsch",
    "außerdeutsches": "außerdeutsch",
    "außerdienstliche": "außerdienstlich",
    "außerdienstlichem": "außerdienstlich",
    "außerdienstlichen": "außerdienstlich",
    "außerdienstlicher": "außerdienstlich",
    "außerdienstliches": "außerdienstlich",
    "außereheliche": "außerehelich",
    "außerehelichem": "außerehelich",
    "außerehelichen": "außerehelich",
    "außerehelicher": "außerehelich",
    "außereheliches": "außerehelich",
    "außereuropäische": "außereuropäisch",
    "außereuropäischem": "außereuropäisch",
    "außereuropäischen": "außereuropäisch",
    "außereuropäischer": "außereuropäisch",
    "außereuropäisches": "außereuropäisch",
    "außergalaktische": "außergalaktisch",
    "außergalaktischem": "außergalaktisch",
    "außergalaktischen": "außergalaktisch",
    "außergalaktischer": "außergalaktisch",
    "außergalaktisches": "außergalaktisch",
    "außergerichtliche": "außergerichtlich",
    "außergerichtlichem": "außergerichtlich",
    "außergerichtlichen": "außergerichtlich",
    "außergerichtlicher": "außergerichtlich",
    "außergerichtliches": "außergerichtlich",
    "außergewöhnliche": "außergewöhnlich",
    "außergewöhnlichem": "außergewöhnlich",
    "außergewöhnlichen": "außergewöhnlich",
    "außergewöhnlicher": "außergewöhnlich",
    "außergewöhnlichere": "außergewöhnlich",
    "außergewöhnlicherem": "außergewöhnlich",
    "außergewöhnlicheren": "außergewöhnlich",
    "außergewöhnlicherer": "außergewöhnlich",
    "außergewöhnlicheres": "außergewöhnlich",
    "außergewöhnliches": "außergewöhnlich",
    "außergewöhnlichste": "außergewöhnlich",
    "außergewöhnlichstem": "außergewöhnlich",
    "außergewöhnlichsten": "außergewöhnlich",
    "außergewöhnlichster": "außergewöhnlich",
    "außergewöhnlichstes": "außergewöhnlich",
    "außerirdische": "außerirdisch",
    "außerirdischem": "außerirdisch",
    "außerirdischen": "außerirdisch",
    "außerirdischer": "außerirdisch",
    "außerirdisches": "außerirdisch",
    "außerkirchliche": "außerkirchlich",
    "außerkirchlichem": "außerkirchlich",
    "außerkirchlichen": "außerkirchlich",
    "außerkirchlicher": "außerkirchlich",
    "außerkirchliches": "außerkirchlich",
    "außerordentliche": "außerordentlich",
    "außerordentlichem": "außerordentlich",
    "außerordentlichen": "außerordentlich",
    "außerordentlicher": "außerordentlich",
    "außerordentlichere": "außerordentlich",
    "außerordentlicherem": "außerordentlich",
    "außerordentlicheren": "außerordentlich",
    "außerordentlicherer": "außerordentlich",
    "außerordentlicheres": "außerordentlich",
    "außerordentliches": "außerordentlich",
    "außerordentlichste": "außerordentlich",
    "außerordentlichstem": "außerordentlich",
    "außerordentlichsten": "außerordentlich",
    "außerordentlichster": "außerordentlich",
    "außerordentlichstes": "außerordentlich",
    "außerparlamentarische": "außerparlamentarisch",
    "außerparlamentarischem": "außerparlamentarisch",
    "außerparlamentarischen": "außerparlamentarisch",
    "außerparlamentarischer": "außerparlamentarisch",
    "außerparlamentarisches": "außerparlamentarisch",
    "außerplanmäßige": "außerplanmäßig",
    "außerplanmäßigem": "außerplanmäßig",
    "außerplanmäßigen": "außerplanmäßig",
    "außerplanmäßiger": "außerplanmäßig",
    "außerplanmäßiges": "außerplanmäßig",
    "avanciere": "avancieren",
    "avancierend": "avancieren",
    "avancierende": "avancierend",
    "avancierendem": "avancierend",
    "avancierenden": "avancierend",
    "avancierender": "avancierend",
    "avancierendere": "avancierend",
    "avancierenderem": "avancierend",
    "avancierenderen": "avancierend",
    "avancierenderer": "avancierend",
    "avancierenderes": "avancierend",
    "avancierendes": "avancierend",
    "avancierendste": "avancierend",
    "avancierendstem": "avancierend",
    "avancierendsten": "avancierend",
    "avancierendster": "avancierend",
    "avancierendstes": "avancierend",
    "avancierest": "avancieren",
    "avancieret": "avancieren",
    "avancierst": "avancieren",
    "avanciert": "avancieren",
    "avancierte": "avancieren",
    "avanciertem": "avanciert",
    "avancierten": "avancieren",
    "avancierter": "avanciert",
    "avanciertere": "avanciert",
    "avancierterem": "avanciert",
    "avancierteren": "avanciert",
    "avancierterer": "avanciert",
    "avancierteres": "avanciert",
    "avanciertes": "avanciert",
    "avanciertest": "avancieren",
    "avancierteste": "avanciert",
    "avanciertestem": "avanciert",
    "avanciertesten": "avanciert",
    "avanciertester": "avanciert",
    "avanciertestes": "avanciert",
    "avanciertet": "avancieren",
    "avisiere": "avisieren",
    "avisierend": "avisieren",
    "avisierende": "avisierend",
    "avisierendem": "avisierend",
    "avisierenden": "avisierend",
    "avisierender": "avisierend",
    "avisierendes": "avisierend",
    "avisierest": "avisieren",
    "avisieret": "avisieren",
    "avisierst": "avisieren",
    "avisiert": "avisieren",
    "avisierte": "avisieren",
    "avisiertem": "avisiert",
    "avisierten": "avisieren",
    "avisierter": "avisiert",
    "avisiertes": "avisiert",
    "avisiertest": "avisieren",
    "avisiertet": "avisieren",
    "axiomatischem": "axiomatisch",
    "axiomatischen": "axiomatisch",
    "axiomatischer": "axiomatisch",
    "axiomatisches": "axiomatisch",
    "axiomatisiere": "axiomatisieren",
    "axiomatisierend": "axiomatisieren",
    "axiomatisierende": "axiomatisierend",
    "axiomatisierendem": "axiomatisierend",
    "axiomatisierenden": "axiomatisierend",
    "axiomatisierender": "axiomatisierend",
    "axiomatisierendere": "axiomatisierend",
    "axiomatisierenderem": "axiomatisierend",
    "axiomatisierenderen": "axiomatisierend",
    "axiomatisierenderer": "axiomatisierend",
    "axiomatisierenderes": "axiomatisierend",
    "axiomatisierendes": "axiomatisierend",
    "axiomatisierendste": "axiomatisierend",
    "axiomatisierendstem": "axiomatisierend",
    "axiomatisierendsten": "axiomatisierend",
    "axiomatisierendster": "axiomatisierend",
    "axiomatisierendstes": "axiomatisierend",
    "axiomatisierest": "axiomatisieren",
    "axiomatisieret": "axiomatisieren",
    "axiomatisierst": "axiomatisieren",
    "axiomatisiert": "axiomatisieren",
    "axiomatisierte": "axiomatisieren",
    "axiomatisiertem": "axiomatisiert",
    "axiomatisierten": "axiomatisieren",
    "axiomatisierter": "axiomatisiert",
    "axiomatisiertere": "axiomatisiert",
    "axiomatisierterem": "axiomatisiert",
    "axiomatisierteren": "axiomatisiert",
    "axiomatisierterer": "axiomatisiert",
    "axiomatisierteres": "axiomatisiert",
    "axiomatisiertes": "axiomatisiert",
    "axiomatisiertest": "axiomatisieren",
    "axiomatisiertestem": "axiomatisiert",
    "axiomatisiertesten": "axiomatisiert",
    "axiomatisiertester": "axiomatisiert",
    "axiomatisiertestes": "axiomatisiert",
    "axiomatisiertet": "axiomatisieren",
    "aztekischem": "aztekisch",
    "aztekischen": "aztekisch",
    "aztekischer": "aztekisch",
    "aztekisches": "aztekisch",
    "aß": "essen",
    "aßen": "essen",
    "aßt": "essen",
    "babylonischem": "babylonisch",
    "babylonischen": "babylonisch",
    "babylonischer": "babylonisch",
    "babylonisches": "babylonisch",
    "backend": "backen",
    "backende": "backend",
    "backendem": "backend",
    "backenden": "backend",
    "backender": "backend",
    "backendes": "backend",
    "backest": "backen",
    "backet": "backen",
    "backst": "backen",
    "backt": "backen",
    "backte": "backen",
    "backten": "backen",
    "backtest": "backen",
    "backtet": "backen",
    "badend": "baden",
    "badende": "badend",
    "badendem": "badend",
    "badenden": "badend",
    "badender": "badend",
    "badendes": "badend",
    "badest": "baden",
    "badet": "baden",
    "badete": "baden",
    "badeten": "baden",
    "badetest": "baden",
    "badetet": "baden",
    "badischem": "badisch",
    "badischen": "badisch",
    "badischer": "badisch",
    "badisches": "badisch",
    "bagatellisiere": "bagatellisieren",
    "bagatellisierend": "bagatellisieren",
    "bagatellisierende": "bagatellisierend",
    "bagatellisierendem": "bagatellisierend",
    "bagatellisierenden": "bagatellisierend",
    "bagatellisierender": "bagatellisierend",
    "bagatellisierendere": "bagatellisierend",
    "bagatellisierenderem": "bagatellisierend",
    "bagatellisierenderen": "bagatellisierend",
    "bagatellisierenderer": "bagatellisierend",
    "bagatellisierenderes": "bagatellisierend",
    "bagatellisierendes": "bagatellisierend",
    "bagatellisierendste": "bagatellisierend",
    "bagatellisierendstem": "bagatellisierend",
    "bagatellisierendsten": "bagatellisierend",
    "bagatellisierendster": "bagatellisierend",
    "bagatellisierendstes": "bagatellisierend",
    "bagatellisierest": "bagatellisieren",
    "bagatellisieret": "bagatellisieren",
    "bagatellisierst": "bagatellisieren",
    "bagatellisiert": "bagatellisieren",
    "bagatellisierte": "bagatellisieren",
    "bagatellisiertem": "bagatellisiert",
    "bagatellisierten": "bagatellisieren",
    "bagatellisierter": "bagatellisiert",
    "bagatellisiertere": "bagatellisiert",
    "bagatellisierterem": "bagatellisiert",
    "bagatellisierteren": "bagatellisiert",
    "bagatellisierterer": "bagatellisiert",
    "bagatellisierteres": "bagatellisiert",
    "bagatellisiertes": "bagatellisiert",
    "bagatellisiertest": "bagatellisieren",
    "bagatellisierteste": "bagatellisiert",
    "bagatellisiertestem": "bagatellisiert",
    "bagatellisiertesten": "bagatellisiert",
    "bagatellisiertester": "bagatellisiert",
    "bagatellisiertestes": "bagatellisiert",
    "bagatellisiertet": "bagatellisieren",
    "baggere": "baggern",
    "baggernd": "baggern",
    "baggernde": "baggernd",
    "baggerndem": "baggernd",
    "baggernden": "baggernd",
    "baggernder": "baggernd",
    "baggerndere": "baggernd",
    "baggernderem": "baggernd",
    "baggernderen": "baggernd",
    "baggernderer": "baggernd",
    "baggernderes": "baggernd",
    "baggerndes": "baggernd",
    "baggerndste": "baggernd",
    "baggerndstem": "baggernd",
    "baggerndsten": "baggernd",
    "baggerndster": "baggernd",
    "baggerndstes": "baggernd",
    "baggerst": "baggern",
    "baggert": "baggern",
    "baggerte": "baggern",
    "baggerten": "baggern",
    "baggertest": "baggern",
    "baggertet": "baggern",
    "bahnbrechendem": "bahnbrechend",
    "bahnbrechenden": "bahnbrechend",
    "bahnbrechender": "bahnbrechend",
    "bahnbrechendere": "bahnbrechend",
    "bahnbrechenderem": "bahnbrechend",
    "bahnbrechenderen": "bahnbrechend",
    "bahnbrechenderer": "bahnbrechend",
    "bahnbrechenderes": "bahnbrechend",
    "bahnbrechendes": "bahnbrechend",
    "bahnbrechendste": "bahnbrechend",
    "bahnbrechendstem": "bahnbrechend",
    "bahnbrechendsten": "bahnbrechend",
    "bahnbrechendster": "bahnbrechend",
    "bahnbrechendstes": "bahnbrechend",
    "bahne": "bahnen",
    "bahnend": "bahnen",
    "bahnende": "bahnend",
    "bahnendem": "bahnend",
    "bahnenden": "bahnend",
    "bahnender": "bahnend",
    "bahnendes": "bahnend",
    "bahnest": "bahnen",
    "bahnet": "bahnen",
    "bahnst": "bahnen",
    "bahnt": "bahnen",
    "bahnte": "bahnen",
    "bahnten": "bahnen",
    "bahntest": "bahnen",
    "bahntet": "bahnen",
    "bahre": "bahren",
    "bahrend": "bahren",
    "bahrende": "bahrend",
    "bahrendem": "bahrend",
    "bahrenden": "bahrend",
    "bahrender": "bahrend",
    "bahrendes": "bahrend",
    "bahrest": "bahren",
    "bahret": "bahren",
    "bahrst": "bahren",
    "bahrt": "bahren",
    "bahrte": "bahren",
    "bahrten": "bahren",
    "bahrtest": "bahren",
    "bahrtet": "bahren",
    "bairischem": "bairisch",
    "bairischen": "bairisch",
    "bairischer": "bairisch",
    "bairisches": "bairisch",
    "bajuwarischem": "bajuwarisch",
    "bajuwarischen": "bajuwarisch",
    "bajuwarischer": "bajuwarisch",
    "bajuwarisches": "bajuwarisch",
    "bakteriellem": "bakteriell",
    "bakteriellen": "bakteriell",
    "bakterieller": "bakteriell",
    "bakterielles": "bakteriell",
    "bakteriologischem": "bakteriologisch",
    "bakteriologischen": "bakteriologisch",
    "bakteriologischer": "bakteriologisch",
    "bakteriologisches": "bakteriologisch",
    "baldigem": "baldig",
    "baldigen": "baldig",
    "baldiger": "baldig",
    "baldiges": "baldig",
    "baldowere": "baldowern",
    "baldowernd": "baldowern",
    "baldowernde": "baldowernd",
    "baldowerndem": "baldowernd",
    "baldowernden": "baldowernd",
    "baldowernder": "baldowernd",
    "baldowerndes": "baldowernd",
    "baldowerst": "baldowern",
    "baldowert": "baldowern",
    "baldowerte": "baldowern",
    "baldowertem": "baldowert",
    "baldowerten": "baldowern",
    "baldowerter": "baldowert",
    "baldowertes": "baldowert",
    "baldowertest": "baldowern",
    "baldowertet": "baldowern",
    "balge": "balgen",
    "balgend": "balgen",
    "balgende": "balgend",
    "balgendem": "balgend",
    "balgenden": "balgend",
    "balgender": "balgend",
    "balgendere": "balgend",
    "balgenderem": "balgend",
    "balgenderen": "balgend",
    "balgenderer": "balgend",
    "balgenderes": "balgend",
    "balgendes": "balgend",
    "balgendste": "balgend",
    "balgendstem": "balgend",
    "balgendsten": "balgend",
    "balgendster": "balgend",
    "balgendstes": "balgend",
    "balgest": "balgen",
    "balget": "balgen",
    "balgst": "balgen",
    "balgt": "balgen",
    "balgte": "balgen",
    "balgten": "balgen",
    "balgtest": "balgen",
    "balgtet": "balgen",
    "balkanisiere": "balkanisieren",
    "balkanisierend": "balkanisieren",
    "balkanisierende": "balkanisierend",
    "balkanisierendem": "balkanisierend",
    "balkanisierenden": "balkanisierend",
    "balkanisierender": "balkanisierend",
    "balkanisierendere": "balkanisierend",
    "balkanisierenderem": "balkanisierend",
    "balkanisierenderen": "balkanisierend",
    "balkanisierenderer": "balkanisierend",
    "balkanisierenderes": "balkanisierend",
    "balkanisierendes": "balkanisierend",
    "balkanisierendste": "balkanisierend",
    "balkanisierendstem": "balkanisierend",
    "balkanisierendsten": "balkanisierend",
    "balkanisierendster": "balkanisierend",
    "balkanisierendstes": "balkanisierend",
    "balkanisierest": "balkanisieren",
    "balkanisieret": "balkanisieren",
    "balkanisierst": "balkanisieren",
    "balkanisiert": "balkanisieren",
    "balkanisierte": "balkanisieren",
    "balkanisiertem": "balkanisiert",
    "balkanisierten": "balkanisieren",
    "balkanisierter": "balkanisiert",
    "balkanisiertere": "balkanisiert",
    "balkanisierterem": "balkanisiert",
    "balkanisierteren": "balkanisiert",
    "balkanisierterer": "balkanisiert",
    "balkanisierteres": "balkanisiert",
    "balkanisiertes": "balkanisiert",
    "balkanisiertest": "balkanisieren",
    "balkanisierteste": "balkanisiert",
    "balkanisiertestem": "balkanisiert",
    "balkanisiertesten": "balkanisiert",
    "balkanisiertester": "balkanisiert",
    "balkanisiertestes": "balkanisiert",
    "balkanisiertet": "balkanisieren",
    "balladenhaftem": "balladenhaft",
    "balladenhaften": "balladenhaft",
    "balladenhafter": "balladenhaft",
    "balladenhaftere": "balladenhaft",
    "balladenhafterem": "balladenhaft",
    "balladenhafteren": "balladenhaft",
    "balladenhafterer": "balladenhaft",
    "balladenhafteres": "balladenhaft",
    "balladenhaftes": "balladenhaft",
    "balladenhafteste": "balladenhaft",
    "balladenhaftestem": "balladenhaft",
    "balladenhaftesten": "balladenhaft",
    "balladenhaftester": "balladenhaft",
    "balladenhaftestes": "balladenhaft",
    "ballend": "ballen",
    "ballende": "ballend",
    "ballendem": "ballend",
    "ballenden": "ballend",
    "ballender": "ballend",
    "ballendere": "ballend",
    "ballenderem": "ballend",
    "ballenderen": "ballend",
    "ballenderer": "ballend",
    "ballenderes": "ballend",
    "ballendes": "ballend",
    "ballendste": "ballend",
    "ballendstem": "ballend",
    "ballendsten": "ballend",
    "ballendster": "ballend",
    "ballendstes": "ballend",
    "ballere": "ballern",
    "ballernd": "ballern",
    "ballernde": "ballernd",
    "ballerndem": "ballernd",
    "ballernden": "ballernd",
    "ballernder": "ballernd",
    "ballerndere": "ballernd",
    "ballernderem": "ballernd",
    "ballernderen": "ballernd",
    "ballernderer": "ballernd",
    "ballernderes": "ballernd",
    "ballerndes": "ballernd",
    "ballerndste": "ballernd",
    "ballerndstem": "ballernd",
    "ballerndsten": "ballernd",
    "ballerndster": "ballernd",
    "ballerndstes": "ballernd",
    "ballerst": "ballern",
    "ballert": "ballern",
    "ballerte": "ballern",
    "ballerten": "ballern",
    "ballertest": "ballern",
    "ballertet": "ballern",
    "ballest": "ballen",
    "ballet": "ballen",
    "ballistischem": "ballistisch",
    "ballistischen": "ballistisch",
    "ballistischer": "ballistisch",
    "ballistisches": "ballistisch",
    "ballst": "ballen",
    "ballt": "ballen",
    "ballte": "ballen",
    "ballten": "ballen",
    "balltest": "ballen",
    "balltet": "ballen",
    "balsamiere": "balsamieren",
    "balsamierend": "balsamieren",
    "balsamierende": "balsamierend",
    "balsamierendem": "balsamierend",
    "balsamierenden": "balsamierend",
    "balsamierender": "balsamierend",
    "balsamierendere": "balsamierend",
    "balsamierenderem": "balsamierend",
    "balsamierenderen": "balsamierend",
    "balsamierenderer": "balsamierend",
    "balsamierenderes": "balsamierend",
    "balsamierendes": "balsamierend",
    "balsamierendste": "balsamierend",
    "balsamierendstem": "balsamierend",
    "balsamierendsten": "balsamierend",
    "balsamierendster": "balsamierend",
    "balsamierendstes": "balsamierend",
    "balsamierest": "balsamieren",
    "balsamieret": "balsamieren",
    "balsamierst": "balsamieren",
    "balsamiert": "balsamieren",
    "balsamierte": "balsamieren",
    "balsamiertem": "balsamiert",
    "balsamierten": "balsamieren",
    "balsamierter": "balsamiert",
    "balsamiertere": "balsamiert",
    "balsamierterem": "balsamiert",
    "balsamierteren": "balsamiert",
    "balsamierterer": "balsamiert",
    "balsamierteres": "balsamiert",
    "balsamiertes": "balsamiert",
    "balsamiertest": "balsamieren",
    "balsamierteste": "balsamiert",
    "balsamiertestem": "balsamiert",
    "balsamiertesten": "balsamiert",
    "balsamiertester": "balsamiert",
    "balsamiertestes": "balsamiert",
    "balsamiertet": "balsamieren",
    "baltischem": "baltisch",
    "baltischen": "baltisch",
    "baltischer": "baltisch",
    "baltisches": "baltisch",
    "balze": "balzen",
    "balzend": "balzen",
    "balzende": "balzend",
    "balzendem": "balzend",
    "balzenden": "balzend",
    "balzender": "balzend",
    "balzendere": "balzend",
    "balzenderem": "balzend",
    "balzenderen": "balzend",
    "balzenderer": "balzend",
    "balzenderes": "balzend",
    "balzendes": "balzend",
    "balzendste": "balzend",
    "balzendstem": "balzend",
    "balzendsten": "balzend",
    "balzendster": "balzend",
    "balzendstes": "balzend",
    "balzest": "balzen",
    "balzet": "balzen",
    "balzt": "balzen",
    "balzte": "balzen",
    "balzten": "balzen",
    "balztest": "balzen",
    "balztet": "balzen",
    "banalem": "banal",
    "banalen": "banal",
    "banaler": "banal",
    "banalere": "banal",
    "banalerem": "banal",
    "banaleren": "banal",
    "banalerer": "banal",
    "banaleres": "banal",
    "banales": "banal",
    "banalisiere": "banalisieren",
    "banalisierend": "banalisieren",
    "banalisierende": "banalisierend",
    "banalisierendem": "banalisierend",
    "banalisierenden": "banalisierend",
    "banalisierender": "banalisierend",
    "banalisierendere": "banalisierend",
    "banalisierenderem": "banalisierend",
    "banalisierenderen": "banalisierend",
    "banalisierenderer": "banalisierend",
    "banalisierenderes": "banalisierend",
    "banalisierendes": "banalisierend",
    "banalisierendste": "banalisierend",
    "banalisierendstem": "banalisierend",
    "banalisierendsten": "banalisierend",
    "banalisierendster": "banalisierend",
    "banalisierendstes": "banalisierend",
    "banalisierest": "banalisieren",
    "banalisieret": "banalisieren",
    "banalisierst": "banalisieren",
    "banalisiert": "banalisieren",
    "banalisierte": "banalisieren",
    "banalisiertem": "banalisiert",
    "banalisierten": "banalisieren",
    "banalisierter": "banalisiert",
    "banalisiertes": "banalisiert",
    "banalisiertest": "banalisieren",
    "banalisiertet": "banalisieren",
    "banalstem": "banal",
    "banalsten": "banal",
    "banalster": "banal",
    "banalstes": "banal",
    "bandele": "bandeln",
    "bandelnd": "bandeln",
    "bandelnde": "bandelnd",
    "bandelndem": "bandelnd",
    "bandelnden": "bandelnd",
    "bandelnder": "bandelnd",
    "bandelndes": "bandelnd",
    "bandelst": "bandeln",
    "bandelt": "bandeln",
    "bandelte": "bandeln",
    "bandelten": "bandeln",
    "bandeltest": "bandeln",
    "bandeltet": "bandeln",
    "bandest": "binden",
    "bandet": "binden",
    "bandle": "bandeln",
    "bangend": "bangen",
    "bangende": "bangend",
    "bangendem": "bangend",
    "bangenden": "bangend",
    "bangender": "bangend",
    "bangendes": "bangend",
    "bangest": "bangen",
    "banget": "bangen",
    "bangst": "bangen",
    "bangt": "bangen",
    "bangte": "bangen",
    "bangten": "bangen",
    "bangtest": "bangen",
    "bangtet": "bangen",
    "bannend": "bannen",
    "bannende": "bannend",
    "bannendem": "bannend",
    "bannenden": "bannend",
    "bannender": "bannend",
    "bannendere": "bannend",
    "bannenderem": "bannend",
    "bannenderen": "bannend",
    "bannenderer": "bannend",
    "bannenderes": "bannend",
    "bannendes": "bannend",
    "bannendste": "bannend",
    "bannendstem": "bannend",
    "bannendsten": "bannend",
    "bannendster": "bannend",
    "bannendstes": "bannend",
    "bannest": "bannen",
    "bannet": "bannen",
    "bannst": "bannen",
    "bannt": "bannen",
    "bannte": "bannen",
    "bannten": "bannen",
    "banntest": "bannen",
    "banntet": "bannen",
    "barbarischem": "barbarisch",
    "barbarischen": "barbarisch",
    "barbarischer": "barbarisch",
    "barbarisches": "barbarisch",
    "barbierend": "barbieren",
    "barbierende": "barbierend",
    "barbierendem": "barbierend",
    "barbierenden": "barbierend",
    "barbierender": "barbierend",
    "barbierendes": "barbierend",
    "barbierest": "barbieren",
    "barbieret": "barbieren",
    "barbierst": "barbieren",
    "barbiert": "barbieren",
    "barbierte": "barbieren",
    "barbiertem": "barbiert",
    "barbierten": "barbieren",
    "barbierter": "barbiert",
    "barbiertere": "barbiert",
    "barbierterem": "barbiert",
    "barbierteren": "barbiert",
    "barbierterer": "barbiert",
    "barbierteres": "barbiert",
    "barbiertes": "barbiert",
    "barbiertest": "barbieren",
    "barbierteste": "barbiert",
    "barbiertestem": "barbiert",
    "barbiertesten": "barbiert",
    "barbiertester": "barbiert",
    "barbiertestes": "barbiert",
    "barbiertet": "barbieren",
    "barbusigem": "barbusig",
    "barbusigen": "barbusig",
    "barbusiger": "barbusig",
    "barbusiges": "barbusig",
    "barem": "bar",
    "baren": "bar",
    "barer": "bar",
    "bares": "bar",
    "barfüßigem": "barfüßig",
    "barfüßigen": "barfüßig",
    "barfüßiger": "barfüßig",
    "barfüßigere": "barfüßig",
    "barfüßigerem": "barfüßig",
    "barfüßigeren": "barfüßig",
    "barfüßigerer": "barfüßig",
    "barfüßigeres": "barfüßig",
    "barfüßiges": "barfüßig",
    "barfüßigste": "barfüßig",
    "barfüßigstem": "barfüßig",
    "barfüßigsten": "barfüßig",
    "barfüßigster": "barfüßig",
    "barfüßigstes": "barfüßig",
    "barg": "bergen",
    "bargeldlosem": "bargeldlos",
    "bargeldlosen": "bargeldlos",
    "bargeldloser": "bargeldlos",
    "bargeldloses": "bargeldlos",
    "bargen": "bergen",
    "bargst": "bergen",
    "bargt": "bergen",
    "barmherzigem": "barmherzig",
    "barmherzigen": "barmherzig",
    "barmherziger": "barmherzig",
    "barmherzigere": "barmherzig",
    "barmherzigerem": "barmherzig",
    "barmherzigeren": "barmherzig",
    "barmherzigerer": "barmherzig",
    "barmherzigeres": "barmherzig",
    "barmherziges": "barmherzig",
    "barmherzigste": "barmherzig",
    "barmherzigstem": "barmherzig",
    "barmherzigsten": "barmherzig",
    "barmherzigster": "barmherzig",
    "barmherzigstes": "barmherzig",
    "barocke": "barock",
    "barockem": "barock",
    "barocken": "barock",
    "barocker": "barock",
    "barockes": "barock",
    "barrend": "barren",
    "barrende": "barrend",
    "barrendem": "barrend",
    "barrenden": "barrend",
    "barrender": "barrend",
    "barrendere": "barrend",
    "barrenderem": "barrend",
    "barrenderen": "barrend",
    "barrenderer": "barrend",
    "barrenderes": "barrend",
    "barrendes": "barrend",
    "barrendste": "barrend",
    "barrendstem": "barrend",
    "barrendsten": "barrend",
    "barrendster": "barrend",
    "barrendstes": "barrend",
    "barrest": "barren",
    "barret": "barren",
    "barrikadierend": "barrikadieren",
    "barrikadierende": "barrikadierend",
    "barrikadierendem": "barrikadierend",
    "barrikadierenden": "barrikadierend",
    "barrikadierender": "barrikadierend",
    "barrikadierendere": "barrikadierend",
    "barrikadierenderem": "barrikadierend",
    "barrikadierenderen": "barrikadierend",
    "barrikadierenderer": "barrikadierend",
    "barrikadierenderes": "barrikadierend",
    "barrikadierendes": "barrikadierend",
    "barrikadierendste": "barrikadierend",
    "barrikadierendstem": "barrikadierend",
    "barrikadierendsten": "barrikadierend",
    "barrikadierendster": "barrikadierend",
    "barrikadierendstes": "barrikadierend",
    "barrikadierest": "barrikadieren",
    "barrikadieret": "barrikadieren",
    "barrikadierst": "barrikadieren",
    "barrikadiert": "barrikadieren",
    "barrikadierte": "barrikadieren",
    "barrikadiertem": "barrikadiert",
    "barrikadierten": "barrikadieren",
    "barrikadierter": "barrikadiert",
    "barrikadiertere": "barrikadiert",
    "barrikadierterem": "barrikadiert",
    "barrikadierteren": "barrikadiert",
    "barrikadierterer": "barrikadiert",
    "barrikadierteres": "barrikadiert",
    "barrikadiertes": "barrikadiert",
    "barrikadiertest": "barrikadieren",
    "barrikadierteste": "barrikadiert",
    "barrikadiertestem": "barrikadiert",
    "barrikadiertesten": "barrikadiert",
    "barrikadiertester": "barrikadiert",
    "barrikadiertestes": "barrikadiert",
    "barrikadiertet": "barrikadieren",
    "barrst": "barren",
    "barrt": "barren",
    "barrte": "barren",
    "barrten": "barren",
    "barrtest": "barren",
    "barrtet": "barren",
    "barschem": "barsch",
    "barschen": "barsch",
    "barscher": "barsch",
    "barsches": "barsch",
    "barst": "bersten",
    "barsten": "bersten",
    "barstest": "bersten",
    "barstet": "bersten",
    "bartlose": "bartlos",
    "bartlosem": "bartlos",
    "bartlosen": "bartlos",
    "bartloser": "bartlos",
    "bartloses": "bartlos",
    "basiere": "basieren",
    "basierend": "basieren",
    "basierende": "basierend",
    "basierendem": "basierend",
    "basierenden": "basierend",
    "basierender": "basierend",
    "basierendes": "basierend",
    "basierest": "basieren",
    "basieret": "basieren",
    "basierst": "basieren",
    "basiert": "basieren",
    "basierte": "basieren",
    "basiertem": "basiert",
    "basierten": "basieren",
    "basierter": "basiert",
    "basiertes": "basiert",
    "basiertest": "basieren",
    "basiertet": "basieren",
    "basisdemokratischem": "basisdemokratisch",
    "basisdemokratischen": "basisdemokratisch",
    "basisdemokratischer": "basisdemokratisch",
    "basisdemokratisches": "basisdemokratisch",
    "baskischem": "baskisch",
    "baskischen": "baskisch",
    "baskischer": "baskisch",
    "baskisches": "baskisch",
    "bastele": "basteln",
    "bastelnd": "basteln",
    "bastelnde": "bastelnd",
    "bastelndem": "bastelnd",
    "bastelnden": "bastelnd",
    "bastelnder": "bastelnd",
    "bastelndes": "bastelnd",
    "bastelst": "basteln",
    "bastelt": "basteln",
    "bastelte": "basteln",
    "bastelten": "basteln",
    "basteltest": "basteln",
    "basteltet": "basteln",
    "bastle": "basteln",
    "bat": "bitten",
    "baten": "bitten",
    "batest": "bitten",
    "batet": "bitten",
    "bauchend": "bauchen",
    "bauchende": "bauchend",
    "bauchendem": "bauchend",
    "bauchenden": "bauchend",
    "bauchender": "bauchend",
    "bauchendere": "bauchend",
    "bauchenderem": "bauchend",
    "bauchenderen": "bauchend",
    "bauchenderer": "bauchend",
    "bauchenderes": "bauchend",
    "bauchendes": "bauchend",
    "bauchendste": "bauchend",
    "bauchendstem": "bauchend",
    "bauchendsten": "bauchend",
    "bauchendster": "bauchend",
    "bauchendstes": "bauchend",
    "bauchest": "bauchen",
    "bauchet": "bauchen",
    "bauchigem": "bauchig",
    "bauchigen": "bauchig",
    "bauchiger": "bauchig",
    "bauchiges": "bauchig",
    "bauchrede": "bauchreden",
    "bauchredend": "bauchreden",
    "bauchredende": "bauchredend",
    "bauchredendem": "bauchredend",
    "bauchredenden": "bauchredend",
    "bauchredender": "bauchredend",
    "bauchredendere": "bauchredend",
    "bauchredenderem": "bauchredend",
    "bauchredenderen": "bauchredend",
    "bauchredenderer": "bauchredend",
    "bauchredenderes": "bauchredend",
    "bauchredendes": "bauchredend",
    "bauchredendste": "bauchredend",
    "bauchredendstem": "bauchredend",
    "bauchredendsten": "bauchredend",
    "bauchredendster": "bauchredend",
    "bauchredendstes": "bauchredend",
    "bauchredest": "bauchreden",
    "bauchredet": "bauchreden",
    "bauchredete": "bauchreden",
    "bauchredeten": "bauchreden",
    "bauchredetest": "bauchreden",
    "bauchredetet": "bauchreden",
    "bauchst": "bauchen",
    "baucht": "bauchen",
    "bauchte": "bauchen",
    "bauchten": "bauchen",
    "bauchtest": "bauchen",
    "bauchtet": "bauchen",
    "baue": "bauen",
    "bauend": "bauen",
    "bauende": "bauend",
    "bauendem": "bauend",
    "bauenden": "bauend",
    "bauender": "bauend",
    "bauendes": "bauend",
    "bauest": "bauen",
    "bauet": "bauen",
    "baufällige": "baufällig",
    "baufälligem": "baufällig",
    "baufälligen": "baufällig",
    "baufälliger": "baufällig",
    "baufälligere": "baufällig",
    "baufälligerem": "baufällig",
    "baufälligeren": "baufällig",
    "baufälligerer": "baufällig",
    "baufälligeres": "baufällig",
    "baufälliges": "baufällig",
    "baufälligste": "baufällig",
    "baufälligstem": "baufällig",
    "baufälligsten": "baufällig",
    "baufälligster": "baufällig",
    "baufälligstes": "baufällig",
    "bauliche": "baulich",
    "baulichem": "baulich",
    "baulichen": "baulich",
    "baulicher": "baulich",
    "bauliches": "baulich",
    "baumele": "baumeln",
    "baumelnd": "baumeln",
    "baumelnde": "baumelnd",
    "baumelndem": "baumelnd",
    "baumelnden": "baumelnd",
    "baumelnder": "baumelnd",
    "baumelndere": "baumelnd",
    "baumelnderem": "baumelnd",
    "baumelnderen": "baumelnd",
    "baumelnderer": "baumelnd",
    "baumelnderes": "baumelnd",
    "baumelndes": "baumelnd",
    "baumelndste": "baumelnd",
    "baumelndstem": "baumelnd",
    "baumelndsten": "baumelnd",
    "baumelndster": "baumelnd",
    "baumelndstes": "baumelnd",
    "baumelst": "baumeln",
    "baumelt": "baumeln",
    "baumelte": "baumeln",
    "baumelten": "baumeln",
    "baumeltest": "baumeln",
    "baumeltet": "baumeln",
    "baumlangem": "baumlang",
    "baumlangen": "baumlang",
    "baumlanger": "baumlang",
    "baumlanges": "baumlang",
    "baumle": "baumeln",
    "baureifem": "baureif",
    "baureifen": "baureif",
    "baureifer": "baureif",
    "baureifere": "baureif",
    "baureiferem": "baureif",
    "baureiferen": "baureif",
    "baureiferer": "baureif",
    "baureiferes": "baureif",
    "baureifes": "baureif",
    "baureifste": "baureif",
    "baureifstem": "baureif",
    "baureifsten": "baureif",
    "baureifster": "baureif",
    "baureifstes": "baureif",
    "bauschend": "bauschen",
    "bauschende": "bauschend",
    "bauschendem": "bauschend",
    "bauschenden": "bauschend",
    "bauschender": "bauschend",
    "bauschendes": "bauschend",
    "bauschest": "bauschen",
    "bauschet": "bauschen",
    "bauschige": "bauschig",
    "bauschigem": "bauschig",
    "bauschigen": "bauschig",
    "bauschiger": "bauschig",
    "bauschigere": "bauschig",
    "bauschigerem": "bauschig",
    "bauschigeren": "bauschig",
    "bauschigerer": "bauschig",
    "bauschigeres": "bauschig",
    "bauschiges": "bauschig",
    "bauschigste": "bauschig",
    "bauschigstem": "bauschig",
    "bauschigsten": "bauschig",
    "bauschigster": "bauschig",
    "bauschigstes": "bauschig",
    "bauschst": "bauschen",
    "bauscht": "bauschen",
    "bauschte": "bauschen",
    "bauschten": "bauschen",
    "bauschtest": "bauschen",
    "bauschtet": "bauschen",
    "bauspare": "bausparen",
    "bausparend": "bausparen",
    "bausparende": "bausparend",
    "bausparendem": "bausparend",
    "bausparenden": "bausparend",
    "bausparender": "bausparend",
    "bausparendere": "bausparend",
    "bausparenderem": "bausparend",
    "bausparenderen": "bausparend",
    "bausparenderer": "bausparend",
    "bausparenderes": "bausparend",
    "bausparendes": "bausparend",
    "bausparendste": "bausparend",
    "bausparendstem": "bausparend",
    "bausparendsten": "bausparend",
    "bausparendster": "bausparend",
    "bausparendstes": "bausparend",
    "bausparest": "bausparen",
    "bausparet": "bausparen",
    "bausparst": "bausparen",
    "bauspart": "bausparen",
    "bausparte": "bausparen",
    "bausparten": "bausparen",
    "bauspartest": "bausparen",
    "bauspartet": "bausparen",
    "baust": "bauen",
    "baut": "bauen",
    "baute": "bauen",
    "bautest": "bauen",
    "bautet": "bauen",
    "bayerische": "bayerisch",
    "bayerischem": "bayerisch",
    "bayerischen": "bayerisch",
    "bayerischer": "bayerisch",
    "bayerischere": "bayerisch",
    "bayerischerem": "bayerisch",
    "bayerischeren": "bayerisch",
    "bayerischerer": "bayerisch",
    "bayerischeres": "bayerisch",
    "bayerisches": "bayerisch",
    "bayerischste": "bayerisch",
    "bayerischstem": "bayerisch",
    "bayerischsten": "bayerisch",
    "bayerischster": "bayerisch",
    "bayerischstes": "bayerisch",
    "bayrischem": "bayrisch",
    "bayrischen": "bayrisch",
    "bayrischer": "bayrisch",
    "bayrischere": "bayrisch",
    "bayrischerem": "bayrisch",
    "bayrischeren": "bayrisch",
    "bayrischerer": "bayrisch",
    "bayrischeres": "bayrisch",
    "bayrisches": "bayrisch",
    "bayrischste": "bayrisch",
    "bayrischstem": "bayrisch",
    "bayrischsten": "bayrisch",
    "bayrischster": "bayrisch",
    "bayrischstes": "bayrisch",
    "beabsichtige": "beabsichtigen",
    "beabsichtigend": "beabsichtigen",
    "beabsichtigende": "beabsichtigend",
    "beabsichtigendem": "beabsichtigend",
    "beabsichtigenden": "beabsichtigend",
    "beabsichtigender": "beabsichtigend",
    "beabsichtigendes": "beabsichtigend",
    "beabsichtigest": "beabsichtigen",
    "beabsichtiget": "beabsichtigen",
    "beabsichtigst": "beabsichtigen",
    "beabsichtigt": "beabsichtigen",
    "beabsichtigte": "beabsichtigen",
    "beabsichtigtem": "beabsichtigt",
    "beabsichtigten": "beabsichtigen",
    "beabsichtigter": "beabsichtigt",
    "beabsichtigtes": "beabsichtigt",
    "beabsichtigtest": "beabsichtigen",
    "beabsichtigtet": "beabsichtigen",
    "beachte": "beachten",
    "beachtend": "beachten",
    "beachtende": "beachtend",
    "beachtendem": "beachtend",
    "beachtenden": "beachtend",
    "beachtender": "beachtend",
    "beachtendere": "beachtend",
    "beachtenderem": "beachtend",
    "beachtenderen": "beachtend",
    "beachtenderer": "beachtend",
    "beachtenderes": "beachtend",
    "beachtendes": "beachtend",
    "beachtendste": "beachtend",
    "beachtendstem": "beachtend",
    "beachtendsten": "beachtend",
    "beachtendster": "beachtend",
    "beachtendstes": "beachtend",
    "beachtenswertem": "beachtenswert",
    "beachtenswerten": "beachtenswert",
    "beachtenswerter": "beachtenswert",
    "beachtenswertere": "beachtenswert",
    "beachtenswerterem": "beachtenswert",
    "beachtenswerteren": "beachtenswert",
    "beachtenswerterer": "beachtenswert",
    "beachtenswerteres": "beachtenswert",
    "beachtenswertes": "beachtenswert",
    "beachtenswerteste": "beachtenswert",
    "beachtenswertestem": "beachtenswert",
    "beachtenswertesten": "beachtenswert",
    "beachtenswertester": "beachtenswert",
    "beachtenswertestes": "beachtenswert",
    "beachtest": "beachten",
    "beachtet": "beachten",
    "beachtete": "beachten",
    "beachtetem": "beachtet",
    "beachteten": "beachten",
    "beachteter": "beachtet",
    "beachtetere": "beachtet",
    "beachteterem": "beachtet",
    "beachteteren": "beachtet",
    "beachteterer": "beachtet",
    "beachteteres": "beachtet",
    "beachtetes": "beachtet",
    "beachtetest": "beachten",
    "beachteteste": "beachtet",
    "beachtetestem": "beachtet",
    "beachtetesten": "beachtet",
    "beachtetester": "beachtet",
    "beachtetestes": "beachtet",
    "beachtetet": "beachten",
    "beachtliche": "beachtlich",
    "beachtlichem": "beachtlich",
    "beachtlichen": "beachtlich",
    "beachtlicher": "beachtlich",
    "beachtlichere": "beachtlich",
    "beachtlicherem": "beachtlich",
    "beachtlicheren": "beachtlich",
    "beachtlicherer": "beachtlich",
    "beachtlicheres": "beachtlich",
    "beachtliches": "beachtlich",
    "beachtlichste": "beachtlich",
    "beachtlichstem": "beachtlich",
    "beachtlichsten": "beachtlich",
    "beachtlichster": "beachtlich",
    "beachtlichstes": "beachtlich",
    "beanspruche": "beanspruchen",
    "beanspruchend": "beanspruchen",
    "beanspruchende": "beanspruchend",
    "beanspruchendem": "beanspruchend",
    "beanspruchenden": "beanspruchend",
    "beanspruchender": "beanspruchend",
    "beanspruchendes": "beanspruchend",
    "beanspruchest": "beanspruchen",
    "beanspruchet": "beanspruchen",
    "beanspruchst": "beanspruchen",
    "beansprucht": "beanspruchen",
    "beanspruchte": "beanspruchen",
    "beanspruchtem": "beansprucht",
    "beanspruchten": "beanspruchen",
    "beanspruchter": "beansprucht",
    "beanspruchtere": "beansprucht",
    "beanspruchterem": "beansprucht",
    "beanspruchteren": "beansprucht",
    "beanspruchterer": "beansprucht",
    "beanspruchteres": "beansprucht",
    "beanspruchtes": "beansprucht",
    "beanspruchtest": "beanspruchen",
    "beanspruchteste": "beansprucht",
    "beanspruchtestem": "beansprucht",
    "beanspruchtesten": "beansprucht",
    "beanspruchtester": "beansprucht",
    "beanspruchtestes": "beansprucht",
    "beanspruchtet": "beanspruchen",
    "beanstande": "beanstanden",
    "beanstandend": "beanstanden",
    "beanstandende": "beanstandend",
    "beanstandendem": "beanstandend",
    "beanstandenden": "beanstandend",
    "beanstandender": "beanstandend",
    "beanstandendere": "beanstandend",
    "beanstandenderem": "beanstandend",
    "beanstandenderen": "beanstandend",
    "beanstandenderer": "beanstandend",
    "beanstandenderes": "beanstandend",
    "beanstandendes": "beanstandend",
    "beanstandendste": "beanstandend",
    "beanstandendstem": "beanstandend",
    "beanstandendsten": "beanstandend",
    "beanstandendster": "beanstandend",
    "beanstandendstes": "beanstandend",
    "beanstandest": "beanstanden",
    "beanstandet": "beanstanden",
    "beanstandete": "beanstanden",
    "beanstandetem": "beanstandet",
    "beanstandeten": "beanstanden",
    "beanstandeter": "beanstandet",
    "beanstandetere": "beanstandet",
    "beanstandeterem": "beanstandet",
    "beanstandeteren": "beanstandet",
    "beanstandeterer": "beanstandet",
    "beanstandeteres": "beanstandet",
    "beanstandetes": "beanstandet",
    "beanstandetest": "beanstanden",
    "beanstandeteste": "beanstandet",
    "beanstandetestem": "beanstandet",
    "beanstandetesten": "beanstandet",
    "beanstandetester": "beanstandet",
    "beanstandetestes": "beanstandet",
    "beanstandetet": "beanstanden",
    "beantrage": "beantragen",
    "beantragend": "beantragen",
    "beantragende": "beantragend",
    "beantragendem": "beantragend",
    "beantragenden": "beantragend",
    "beantragender": "beantragend",
    "beantragendes": "beantragend",
    "beantragest": "beantragen",
    "beantraget": "beantragen",
    "beantragst": "beantragen",
    "beantragt": "beantragen",
    "beantragte": "beantragen",
    "beantragtem": "beantragt",
    "beantragten": "beantragen",
    "beantragter": "beantragt",
    "beantragtes": "beantragt",
    "beantragtest": "beantragen",
    "beantragtet": "beantragen",
    "beantworte": "beantworten",
    "beantwortend": "beantworten",
    "beantwortende": "beantwortend",
    "beantwortendem": "beantwortend",
    "beantwortenden": "beantwortend",
    "beantwortender": "beantwortend",
    "beantwortendes": "beantwortend",
    "beantwortest": "beantworten",
    "beantwortet": "beantworten",
    "beantwortete": "beantworten",
    "beantwortetem": "beantwortet",
    "beantworteten": "beantworten",
    "beantworteter": "beantwortet",
    "beantwortetes": "beantwortet",
    "beantwortetest": "beantworten",
    "beantwortetet": "beantworten",
    "bearbeite": "bearbeiten",
    "bearbeitend": "bearbeiten",
    "bearbeitende": "bearbeitend",
    "bearbeitendem": "bearbeitend",
    "bearbeitenden": "bearbeitend",
    "bearbeitender": "bearbeitend",
    "bearbeitendes": "bearbeitend",
    "bearbeitest": "bearbeiten",
    "bearbeitet": "bearbeiten",
    "bearbeitete": "bearbeiten",
    "bearbeitetem": "bearbeitet",
    "bearbeiteten": "bearbeiten",
    "bearbeiteter": "bearbeitet",
    "bearbeitetere": "bearbeitet",
    "bearbeiteterem": "bearbeitet",
    "bearbeiteteren": "bearbeitet",
    "bearbeiteterer": "bearbeitet",
    "bearbeiteteres": "bearbeitet",
    "bearbeitetes": "bearbeitet",
    "bearbeitetest": "bearbeiten",
    "bearbeiteteste": "bearbeitet",
    "bearbeitetestem": "bearbeitet",
    "bearbeitetesten": "bearbeitet",
    "bearbeitetester": "bearbeitet",
    "bearbeitetestes": "bearbeitet",
    "bearbeitetet": "bearbeiten",
    "beatme": "beatmen",
    "beatmend": "beatmen",
    "beatmende": "beatmend",
    "beatmendem": "beatmend",
    "beatmenden": "beatmend",
    "beatmender": "beatmend",
    "beatmendes": "beatmend",
    "beatmest": "beatmen",
    "beatmet": "beatmen",
    "beatmete": "beatmen",
    "beatmetem": "beatmet",
    "beatmeten": "beatmen",
    "beatmeter": "beatmet",
    "beatmetes": "beatmet",
    "beatmetest": "beatmen",
    "beatmetet": "beatmen",
    "beaufsichtige": "beaufsichtigen",
    "beaufsichtigend": "beaufsichtigen",
    "beaufsichtigende": "beaufsichtigend",
    "beaufsichtigendem": "beaufsichtigend",
    "beaufsichtigenden": "beaufsichtigend",
    "beaufsichtigender": "beaufsichtigend",
    "beaufsichtigendere": "beaufsichtigend",
    "beaufsichtigenderem": "beaufsichtigend",
    "beaufsichtigenderen": "beaufsichtigend",
    "beaufsichtigenderer": "beaufsichtigend",
    "beaufsichtigenderes": "beaufsichtigend",
    "beaufsichtigendes": "beaufsichtigend",
    "beaufsichtigendste": "beaufsichtigend",
    "beaufsichtigendstem": "beaufsichtigend",
    "beaufsichtigendsten": "beaufsichtigend",
    "beaufsichtigendster": "beaufsichtigend",
    "beaufsichtigendstes": "beaufsichtigend",
    "beaufsichtigest": "beaufsichtigen",
    "beaufsichtiget": "beaufsichtigen",
    "beaufsichtigst": "beaufsichtigen",
    "beaufsichtigt": "beaufsichtigen",
    "beaufsichtigte": "beaufsichtigen",
    "beaufsichtigtem": "beaufsichtigt",
    "beaufsichtigten": "beaufsichtigen",
    "beaufsichtigter": "beaufsichtigt",
    "beaufsichtigtere": "beaufsichtigt",
    "beaufsichtigterem": "beaufsichtigt",
    "beaufsichtigteren": "beaufsichtigt",
    "beaufsichtigterer": "beaufsichtigt",
    "beaufsichtigteres": "beaufsichtigt",
    "beaufsichtigtes": "beaufsichtigt",
    "beaufsichtigtest": "beaufsichtigen",
    "beaufsichtigtestem": "beaufsichtigt",
    "beaufsichtigtesten": "beaufsichtigt",
    "beaufsichtigtester": "beaufsichtigt",
    "beaufsichtigtestes": "beaufsichtigt",
    "beaufsichtigtet": "beaufsichtigen",
    "beauftrage": "beauftragen",
    "beauftragend": "beauftragen",
    "beauftragende": "beauftragend",
    "beauftragendem": "beauftragend",
    "beauftragenden": "beauftragend",
    "beauftragender": "beauftragend",
    "beauftragendes": "beauftragend",
    "beauftragest": "beauftragen",
    "beauftraget": "beauftragen",
    "beauftragst": "beauftragen",
    "beauftragt": "beauftragen",
    "beauftragte": "beauftragen",
    "beauftragtem": "beauftragt",
    "beauftragten": "beauftragen",
    "beauftragter": "beauftragt",
    "beauftragtes": "beauftragt",
    "beauftragtest": "beauftragen",
    "beauftragtet": "beauftragen",
    "bebaue": "bebauen",
    "bebauend": "bebauen",
    "bebauende": "bebauend",
    "bebauendem": "bebauend",
    "bebauenden": "bebauend",
    "bebauender": "bebauend",
    "bebauendes": "bebauend",
    "bebauest": "bebauen",
    "bebauet": "bebauen",
    "bebaust": "bebauen",
    "bebaut": "bebauen",
    "bebaute": "bebauen",
    "bebautem": "bebaut",
    "bebauten": "bebauen",
    "bebauter": "bebaut",
    "bebautere": "bebaut",
    "bebauterem": "bebaut",
    "bebauteren": "bebaut",
    "bebauterer": "bebaut",
    "bebauteres": "bebaut",
    "bebautes": "bebaut",
    "bebautest": "bebauen",
    "bebauteste": "bebaut",
    "bebautestem": "bebaut",
    "bebautesten": "bebaut",
    "bebautester": "bebaut",
    "bebautestes": "bebaut",
    "bebautet": "bebauen",
    "bebe": "beben",
    "bebend": "beben",
    "bebende": "bebend",
    "bebendem": "bebend",
    "bebenden": "bebend",
    "bebender": "bebend",
    "bebendere": "bebend",
    "bebenderem": "bebend",
    "bebenderen": "bebend",
    "bebenderer": "bebend",
    "bebenderes": "bebend",
    "bebendes": "bebend",
    "bebendste": "bebend",
    "bebendstem": "bebend",
    "bebendsten": "bebend",
    "bebendster": "bebend",
    "bebendstes": "bebend",
    "bebest": "beben",
    "bebet": "beben",
    "bebildere": "bebildern",
    "bebildernd": "bebildern",
    "bebildernde": "bebildernd",
    "bebilderndem": "bebildernd",
    "bebildernden": "bebildernd",
    "bebildernder": "bebildernd",
    "bebilderndes": "bebildernd",
    "bebilderst": "bebildern",
    "bebildert": "bebildern",
    "bebilderte": "bebildern",
    "bebildertem": "bebildert",
    "bebilderten": "bebildern",
    "bebilderter": "bebildert",
    "bebildertere": "bebildert",
    "bebilderterem": "bebildert",
    "bebilderteren": "bebildert",
    "bebilderterer": "bebildert",
    "bebilderteres": "bebildert",
    "bebildertes": "bebildert",
    "bebildertest": "bebildern",
    "bebilderteste": "bebildert",
    "bebildertestem": "bebildert",
    "bebildertesten": "bebildert",
    "bebildertester": "bebildert",
    "bebildertestes": "bebildert",
    "bebildertet": "bebildern",
    "bebst": "beben",
    "bebt": "beben",
    "bebte": "beben",
    "bebten": "beben",
    "bebtest": "beben",
    "bebtet": "beben",
    "bechere": "bechern",
    "bechernd": "bechern",
    "bechernde": "bechernd",
    "becherndem": "bechernd",
    "bechernden": "bechernd",
    "bechernder": "bechernd",
    "becherndere": "bechernd",
    "bechernderem": "bechernd",
    "bechernderen": "bechernd",
    "bechernderer": "bechernd",
    "bechernderes": "bechernd",
    "becherndes": "bechernd",
    "becherndste": "bechernd",
    "becherndstem": "bechernd",
    "becherndsten": "bechernd",
    "becherndster": "bechernd",
    "becherndstes": "bechernd",
    "becherst": "bechern",
    "bechert": "bechern",
    "becherte": "bechern",
    "becherten": "bechern",
    "bechertest": "bechern",
    "bechertet": "bechern",
    "becirce": "becircen",
    "becircend": "becircen",
    "becircende": "becircend",
    "becircendem": "becircend",
    "becircenden": "becircend",
    "becircender": "becircend",
    "becircendere": "becircend",
    "becircenderem": "becircend",
    "becircenderen": "becircend",
    "becircenderer": "becircend",
    "becircenderes": "becircend",
    "becircendes": "becircend",
    "becircendste": "becircend",
    "becircendstem": "becircend",
    "becircendsten": "becircend",
    "becircendster": "becircend",
    "becircendstes": "becircend",
    "becircest": "becircen",
    "becircet": "becircen",
    "becirct": "becircen",
    "becircte": "becircen",
    "becirctem": "becirct",
    "becircten": "becircen",
    "becircter": "becirct",
    "becirctere": "becirct",
    "becircterem": "becirct",
    "becircteren": "becirct",
    "becircterer": "becirct",
    "becircteres": "becirct",
    "becirctes": "becirct",
    "becirctest": "becircen",
    "becircteste": "becirct",
    "becirctestem": "becirct",
    "becirctesten": "becirct",
    "becirctester": "becirct",
    "becirctestes": "becirct",
    "becirctet": "becircen",
    "bedacht": "bedenken",
    "bedachte": "bedacht",
    "bedachtem": "bedacht",
    "bedachten": "bedacht",
    "bedachter": "bedacht",
    "bedachtes": "bedacht",
    "bedachtest": "bedenken",
    "bedachtet": "bedenken",
    "bedanke": "bedanken",
    "bedankend": "bedanken",
    "bedankende": "bedankend",
    "bedankendem": "bedankend",
    "bedankenden": "bedankend",
    "bedankender": "bedankend",
    "bedankendes": "bedankend",
    "bedankest": "bedanken",
    "bedanket": "bedanken",
    "bedankst": "bedanken",
    "bedankt": "bedanken",
    "bedankte": "bedanken",
    "bedanktem": "bedankt",
    "bedankten": "bedanken",
    "bedankter": "bedankt",
    "bedanktes": "bedankt",
    "bedanktest": "bedanken",
    "bedanktet": "bedanken",
    "bedarfsgerechtem": "bedarfsgerecht",
    "bedarfsgerechten": "bedarfsgerecht",
    "bedarfsgerechter": "bedarfsgerecht",
    "bedarfsgerechtes": "bedarfsgerecht",
    "bedauere": "bedauern",
    "bedauerliche": "bedauerlich",
    "bedauerlichem": "bedauerlich",
    "bedauerlichen": "bedauerlich",
    "bedauerlicher": "bedauerlich",
    "bedauerlichere": "bedauerlich",
    "bedauerlicherem": "bedauerlich",
    "bedauerlicheren": "bedauerlich",
    "bedauerlicherer": "bedauerlich",
    "bedauerlicheres": "bedauerlich",
    "bedauerliches": "bedauerlich",
    "bedauerlichste": "bedauerlich",
    "bedauerlichstem": "bedauerlich",
    "bedauerlichsten": "bedauerlich",
    "bedauerlichster": "bedauerlich",
    "bedauerlichstes": "bedauerlich",
    "bedauernd": "bedauern",
    "bedauernde": "bedauernd",
    "bedauerndem": "bedauernd",
    "bedauernden": "bedauernd",
    "bedauernder": "bedauernd",
    "bedauerndere": "bedauernd",
    "bedauernderem": "bedauernd",
    "bedauernderen": "bedauernd",
    "bedauernderer": "bedauernd",
    "bedauernderes": "bedauernd",
    "bedauerndes": "bedauernd",
    "bedauerndste": "bedauernd",
    "bedauerndstem": "bedauernd",
    "bedauerndsten": "bedauernd",
    "bedauerndster": "bedauernd",
    "bedauerndstes": "bedauernd",
    "bedauernswertem": "bedauernswert",
    "bedauernswerten": "bedauernswert",
    "bedauernswerter": "bedauernswert",
    "bedauernswertere": "bedauernswert",
    "bedauernswerterem": "bedauernswert",
    "bedauernswerteren": "bedauernswert",
    "bedauernswerterer": "bedauernswert",
    "bedauernswerteres": "bedauernswert",
    "bedauernswertes": "bedauernswert",
    "bedauernswerteste": "bedauernswert",
    "bedauernswertestem": "bedauernswert",
    "bedauernswertesten": "bedauernswert",
    "bedauernswertester": "bedauernswert",
    "bedauernswertestes": "bedauernswert",
    "bedauerst": "bedauern",
    "bedauert": "bedauern",
    "bedauerte": "bedauern",
    "bedauertem": "bedauert",
    "bedauerten": "bedauern",
    "bedauerter": "bedauert",
    "bedauertere": "bedauert",
    "bedauerterem": "bedauert",
    "bedauerteren": "bedauert",
    "bedauerterer": "bedauert",
    "bedauerteres": "bedauert",
    "bedauertes": "bedauert",
    "bedauertest": "bedauern",
    "bedauerteste": "bedauert",
    "bedauertestem": "bedauert",
    "bedauertesten": "bedauert",
    "bedauertester": "bedauert",
    "bedauertestes": "bedauert",
    "bedauertet": "bedauern",
    "bedecke": "bedecken",
    "bedeckend": "bedecken",
    "bedeckende": "bedeckend",
    "bedeckendem": "bedeckend",
    "bedeckenden": "bedeckend",
    "bedeckender": "bedeckend",
    "bedeckendere": "bedeckend",
    "bedeckenderem": "bedeckend",
    "bedeckenderen": "bedeckend",
    "bedeckenderer": "bedeckend",
    "bedeckenderes": "bedeckend",
    "bedeckendes": "bedeckend",
    "bedeckendste": "bedeckend",
    "bedeckendstem": "bedeckend",
    "bedeckendsten": "bedeckend",
    "bedeckendster": "bedeckend",
    "bedeckendstes": "bedeckend",
    "bedeckest": "bedecken",
    "bedecket": "bedecken",
    "bedeckst": "bedecken",
    "bedeckt": "bedecken",
    "bedeckte": "bedecken",
    "bedecktem": "bedeckt",
    "bedeckten": "bedecken",
    "bedeckter": "bedeckt",
    "bedecktere": "bedeckt",
    "bedeckterem": "bedeckt",
    "bedeckteren": "bedeckt",
    "bedeckterer": "bedeckt",
    "bedeckteres": "bedeckt",
    "bedecktes": "bedeckt",
    "bedecktest": "bedecken",
    "bedeckteste": "bedeckt",
    "bedecktestem": "bedeckt",
    "bedecktesten": "bedeckt",
    "bedecktester": "bedeckt",
    "bedecktestes": "bedeckt",
    "bedecktet": "bedecken",
    "bedenke": "bedenken",
    "bedenkend": "bedenken",
    "bedenkende": "bedenkend",
    "bedenkendem": "bedenkend",
    "bedenkenden": "bedenkend",
    "bedenkender": "bedenkend",
    "bedenkendere": "bedenkend",
    "bedenkenderem": "bedenkend",
    "bedenkenderen": "bedenkend",
    "bedenkenderer": "bedenkend",
    "bedenkenderes": "bedenkend",
    "bedenkendes": "bedenkend",
    "bedenkendste": "bedenkend",
    "bedenkendstem": "bedenkend",
    "bedenkendsten": "bedenkend",
    "bedenkendster": "bedenkend",
    "bedenkendstes": "bedenkend",
    "bedenkenlose": "bedenkenlos",
    "bedenkenlosem": "bedenkenlos",
    "bedenkenlosen": "bedenkenlos",
    "bedenkenloser": "bedenkenlos",
    "bedenkenloses": "bedenkenlos",
    "bedenkest": "bedenken",
    "bedenket": "bedenken",
    "bedenkliche": "bedenklich",
    "bedenklichem": "bedenklich",
    "bedenklichen": "bedenklich",
    "bedenklicher": "bedenklich",
    "bedenklichere": "bedenklich",
    "bedenklicherem": "bedenklich",
    "bedenklicheren": "bedenklich",
    "bedenklicherer": "bedenklich",
    "bedenklicheres": "bedenklich",
    "bedenkliches": "bedenklich",
    "bedenklichste": "bedenklich",
    "bedenklichstem": "bedenklich",
    "bedenklichsten": "bedenklich",
    "bedenklichster": "bedenklich",
    "bedenklichstes": "bedenklich",
    "bedenkst": "bedenken",
    "bedenkt": "bedenken",
    "bedeppertem": "bedeppert",
    "bedepperten": "bedeppert",
    "bedepperter": "bedeppert",
    "bedeppertere": "bedeppert",
    "bedepperterem": "bedeppert",
    "bedepperteren": "bedeppert",
    "bedepperterer": "bedeppert",
    "bedepperteres": "bedeppert",
    "bedeppertes": "bedeppert",
    "bedepperteste": "bedeppert",
    "bedeppertestem": "bedeppert",
    "bedeppertesten": "bedeppert",
    "bedeppertester": "bedeppert",
    "bedeppertestes": "bedeppert",
    "bedeute": "bedeuten",
    "bedeutend": "bedeuten",
    "bedeutende": "bedeutend",
    "bedeutendem": "bedeutend",
    "bedeutenden": "bedeutend",
    "bedeutender": "bedeutend",
    "bedeutendere": "bedeutend",
    "bedeutenderem": "bedeutend",
    "bedeutenderen": "bedeutend",
    "bedeutenderer": "bedeutend",
    "bedeutenderes": "bedeutend",
    "bedeutendes": "bedeutend",
    "bedeutendste": "bedeutend",
    "bedeutendstem": "bedeutend",
    "bedeutendsten": "bedeutend",
    "bedeutendster": "bedeutend",
    "bedeutendstes": "bedeutend",
    "bedeutest": "bedeuten",
    "bedeutet": "bedeuten",
    "bedeutete": "bedeuten",
    "bedeutetem": "bedeutet",
    "bedeuteten": "bedeuten",
    "bedeuteter": "bedeutet",
    "bedeutetes": "bedeutet",
    "bedeutetest": "bedeuten",
    "bedeutetet": "bedeuten",
    "bedeutsame": "bedeutsam",
    "bedeutsamem": "bedeutsam",
    "bedeutsamen": "bedeutsam",
    "bedeutsamer": "bedeutsam",
    "bedeutsamere": "bedeutsam",
    "bedeutsamerem": "bedeutsam",
    "bedeutsameren": "bedeutsam",
    "bedeutsamerer": "bedeutsam",
    "bedeutsameres": "bedeutsam",
    "bedeutsames": "bedeutsam",
    "bedeutsamste": "bedeutsam",
    "bedeutsamstem": "bedeutsam",
    "bedeutsamsten": "bedeutsam",
    "bedeutsamster": "bedeutsam",
    "bedeutsamstes": "bedeutsam",
    "bedeutungslosem": "bedeutungslos",
    "bedeutungslosen": "bedeutungslos",
    "bedeutungsloser": "bedeutungslos",
    "bedeutungslosere": "bedeutungslos",
    "bedeutungsloserem": "bedeutungslos",
    "bedeutungsloseren": "bedeutungslos",
    "bedeutungsloserer": "bedeutungslos",
    "bedeutungsloseres": "bedeutungslos",
    "bedeutungsloses": "bedeutungslos",
    "bedeutungsloseste": "bedeutungslos",
    "bedeutungslosestem": "bedeutungslos",
    "bedeutungslosesten": "bedeutungslos",
    "bedeutungslosester": "bedeutungslos",
    "bedeutungslosestes": "bedeutungslos",
    "bedeutungsvolle": "bedeutungsvoll",
    "bedeutungsvollem": "bedeutungsvoll",
    "bedeutungsvollen": "bedeutungsvoll",
    "bedeutungsvoller": "bedeutungsvoll",
    "bedeutungsvollere": "bedeutungsvoll",
    "bedeutungsvollerem": "bedeutungsvoll",
    "bedeutungsvolleren": "bedeutungsvoll",
    "bedeutungsvollerer": "bedeutungsvoll",
    "bedeutungsvolleres": "bedeutungsvoll",
    "bedeutungsvolles": "bedeutungsvoll",
    "bedeutungsvollste": "bedeutungsvoll",
    "bedeutungsvollstem": "bedeutungsvoll",
    "bedeutungsvollsten": "bedeutungsvoll",
    "bedeutungsvollster": "bedeutungsvoll",
    "bedeutungsvollstes": "bedeutungsvoll",
    "bediene": "bedienen",
    "bedienend": "bedienen",
    "bedienende": "bedienend",
    "bedienendem": "bedienend",
    "bedienenden": "bedienend",
    "bedienender": "bedienend",
    "bedienendes": "bedienend",
    "bedienest": "bedienen",
    "bedienet": "bedienen",
    "bedienst": "bedienen",
    "bedient": "bedienen",
    "bediente": "bedienen",
    "bedientem": "bedient",
    "bedienten": "bedienen",
    "bedienter": "bedient",
    "bedientere": "bedient",
    "bedienterem": "bedient",
    "bedienteren": "bedient",
    "bedienterer": "bedient",
    "bedienteres": "bedient",
    "bedientes": "bedient",
    "bedientest": "bedienen",
    "bedienteste": "bedient",
    "bedientestem": "bedient",
    "bedientesten": "bedient",
    "bedientester": "bedient",
    "bedientestes": "bedient",
    "bedientet": "bedienen",
    "bedingtem": "bedingt",
    "bedingten": "bedingt",
    "bedingter": "bedingt",
    "bedingtes": "bedingt",
    "bedingungslosem": "bedingungslos",
    "bedingungslosen": "bedingungslos",
    "bedingungsloser": "bedingungslos",
    "bedingungslosere": "bedingungslos",
    "bedingungsloserem": "bedingungslos",
    "bedingungsloseren": "bedingungslos",
    "bedingungsloserer": "bedingungslos",
    "bedingungsloseres": "bedingungslos",
    "bedingungsloses": "bedingungslos",
    "bedingungsloseste": "bedingungslos",
    "bedingungslosestem": "bedingungslos",
    "bedingungslosesten": "bedingungslos",
    "bedingungslosester": "bedingungslos",
    "bedingungslosestes": "bedingungslos",
    "bedrohe": "bedrohen",
    "bedrohend": "bedrohen",
    "bedrohende": "bedrohend",
    "bedrohendem": "bedrohend",
    "bedrohenden": "bedrohend",
    "bedrohender": "bedrohend",
    "bedrohendere": "bedrohend",
    "bedrohenderem": "bedrohend",
    "bedrohenderen": "bedrohend",
    "bedrohenderer": "bedrohend",
    "bedrohenderes": "bedrohend",
    "bedrohendes": "bedrohend",
    "bedrohendste": "bedrohend",
    "bedrohendstem": "bedrohend",
    "bedrohendsten": "bedrohend",
    "bedrohendster": "bedrohend",
    "bedrohendstes": "bedrohend",
    "bedrohest": "bedrohen",
    "bedrohet": "bedrohen",
    "bedrohliche": "bedrohlich",
    "bedrohlichem": "bedrohlich",
    "bedrohlichen": "bedrohlich",
    "bedrohlicher": "bedrohlich",
    "bedrohlichere": "bedrohlich",
    "bedrohlicherem": "bedrohlich",
    "bedrohlicheren": "bedrohlich",
    "bedrohlicherer": "bedrohlich",
    "bedrohlicheres": "bedrohlich",
    "bedrohliches": "bedrohlich",
    "bedrohlichste": "bedrohlich",
    "bedrohlichstem": "bedrohlich",
    "bedrohlichsten": "bedrohlich",
    "bedrohlichster": "bedrohlich",
    "bedrohlichstes": "bedrohlich",
    "bedrohst": "bedrohen",
    "bedroht": "bedrohen",
    "bedrohte": "bedrohen",
    "bedrohtem": "bedroht",
    "bedrohten": "bedrohen",
    "bedrohter": "bedroht",
    "bedrohtere": "bedroht",
    "bedrohterem": "bedroht",
    "bedrohteren": "bedroht",
    "bedrohterer": "bedroht",
    "bedrohteres": "bedroht",
    "bedrohtes": "bedroht",
    "bedrohtest": "bedrohen",
    "bedrohteste": "bedroht",
    "bedrohtestem": "bedroht",
    "bedrohtesten": "bedroht",
    "bedrohtester": "bedroht",
    "bedrohtestes": "bedroht",
    "bedrohtet": "bedrohen",
    "bedrucke": "bedrucken",
    "bedruckend": "bedrucken",
    "bedruckende": "bedruckend",
    "bedruckendem": "bedruckend",
    "bedruckenden": "bedruckend",
    "bedruckender": "bedruckend",
    "bedruckendes": "bedruckend",
    "bedruckest": "bedrucken",
    "bedrucket": "bedrucken",
    "bedruckst": "bedrucken",
    "bedruckt": "bedrucken",
    "bedruckte": "bedrucken",
    "bedrucktem": "bedruckt",
    "bedruckten": "bedrucken",
    "bedruckter": "bedruckt",
    "bedrucktere": "bedruckt",
    "bedruckterem": "bedruckt",
    "bedruckteren": "bedruckt",
    "bedruckterer": "bedruckt",
    "bedruckteres": "bedruckt",
    "bedrucktes": "bedruckt",
    "bedrucktest": "bedrucken",
    "bedruckteste": "bedruckt",
    "bedrucktestem": "bedruckt",
    "bedrucktesten": "bedruckt",
    "bedrucktester": "bedruckt",
    "bedrucktestes": "bedruckt",
    "bedrucktet": "bedrucken",
    "bedränge": "bedrängen",
    "bedrängend": "bedrängen",
    "bedrängende": "bedrängend",
    "bedrängendem": "bedrängend",
    "bedrängenden": "bedrängend",
    "bedrängender": "bedrängend",
    "bedrängendere": "bedrängend",
    "bedrängenderem": "bedrängend",
    "bedrängenderen": "bedrängend",
    "bedrängenderer": "bedrängend",
    "bedrängenderes": "bedrängend",
    "bedrängendes": "bedrängend",
    "bedrängendste": "bedrängend",
    "bedrängendstem": "bedrängend",
    "bedrängendsten": "bedrängend",
    "bedrängendster": "bedrängend",
    "bedrängendstes": "bedrängend",
    "bedrängest": "bedrängen",
    "bedränget": "bedrängen",
    "bedrängst": "bedrängen",
    "bedrängt": "bedrängen",
    "bedrängte": "bedrängen",
    "bedrängtem": "bedrängt",
    "bedrängten": "bedrängen",
    "bedrängter": "bedrängt",
    "bedrängtere": "bedrängt",
    "bedrängterem": "bedrängt",
    "bedrängteren": "bedrängt",
    "bedrängterer": "bedrängt",
    "bedrängteres": "bedrängt",
    "bedrängtes": "bedrängt",
    "bedrängtest": "bedrängen",
    "bedrängteste": "bedrängt",
    "bedrängtestem": "bedrängt",
    "bedrängtesten": "bedrängt",
    "bedrängtester": "bedrängt",
    "bedrängtestes": "bedrängt",
    "bedrängtet": "bedrängen",
    "bedrücke": "bedrücken",
    "bedrückend": "bedrücken",
    "bedrückendem": "bedrückend",
    "bedrückender": "bedrückend",
    "bedrückendere": "bedrückend",
    "bedrückenderem": "bedrückend",
    "bedrückenderen": "bedrückend",
    "bedrückenderer": "bedrückend",
    "bedrückenderes": "bedrückend",
    "bedrückendes": "bedrückend",
    "bedrückendste": "bedrückend",
    "bedrückendstem": "bedrückend",
    "bedrückendsten": "bedrückend",
    "bedrückendster": "bedrückend",
    "bedrückendstes": "bedrückend",
    "bedrückest": "bedrücken",
    "bedrücket": "bedrücken",
    "bedrückst": "bedrücken",
    "bedrückt": "bedrücken",
    "bedrückte": "bedrücken",
    "bedrücktem": "bedrückt",
    "bedrückten": "bedrückt",
    "bedrückter": "bedrückt",
    "bedrückterem": "bedrückt",
    "bedrückterer": "bedrückt",
    "bedrückteres": "bedrückt",
    "bedrücktes": "bedrückt",
    "bedrücktest": "bedrücken",
    "bedrücktestem": "bedrückt",
    "bedrücktester": "bedrückt",
    "bedrücktestes": "bedrückt",
    "bedrücktet": "bedrücken",
    "bedusele": "beduseln",
    "beduselnd": "beduseln",
    "beduselnde": "beduselnd",
    "beduselndem": "beduselnd",
    "beduselnden": "beduselnd",
    "beduselnder": "beduselnd",
    "beduselndere": "beduselnd",
    "beduselnderem": "beduselnd",
    "beduselnderen": "beduselnd",
    "beduselnderer": "beduselnd",
    "beduselnderes": "beduselnd",
    "beduselndes": "beduselnd",
    "beduselndste": "beduselnd",
    "beduselndstem": "beduselnd",
    "beduselndsten": "beduselnd",
    "beduselndster": "beduselnd",
    "beduselndstes": "beduselnd",
    "beduselst": "beduseln",
    "beduselt": "beduseln",
    "beduselte": "beduseln",
    "beduseltem": "beduselt",
    "beduselten": "beduseln",
    "beduselter": "beduselt",
    "beduseltere": "beduselt",
    "beduselterem": "beduselt",
    "beduselteren": "beduselt",
    "beduselterer": "beduselt",
    "beduselteres": "beduselt",
    "beduseltes": "beduselt",
    "beduseltest": "beduseln",
    "beduselteste": "beduselt",
    "beduseltestem": "beduselt",
    "beduseltesten": "beduselt",
    "beduseltester": "beduselt",
    "beduseltestes": "beduselt",
    "beduseltet": "beduseln",
    "bedusle": "beduseln",
    "bedächte": "bedenken",
    "bedächten": "bedenken",
    "bedächtest": "bedenken",
    "bedächtet": "bedenken",
    "bedächtige": "bedächtig",
    "bedächtigem": "bedächtig",
    "bedächtigen": "bedächtig",
    "bedächtiger": "bedächtig",
    "bedächtigere": "bedächtig",
    "bedächtigerem": "bedächtig",
    "bedächtigeren": "bedächtig",
    "bedächtigerer": "bedächtig",
    "bedächtigeres": "bedächtig",
    "bedächtiges": "bedächtig",
    "bedächtigste": "bedächtig",
    "bedächtigstem": "bedächtig",
    "bedächtigsten": "bedächtig",
    "bedächtigster": "bedächtig",
    "bedächtigstes": "bedächtig",
    "bedürfnislosem": "bedürfnislos",
    "bedürfnislosen": "bedürfnislos",
    "bedürfnisloser": "bedürfnislos",
    "bedürfnislosere": "bedürfnislos",
    "bedürfnisloserem": "bedürfnislos",
    "bedürfnisloseren": "bedürfnislos",
    "bedürfnisloserer": "bedürfnislos",
    "bedürfnisloseres": "bedürfnislos",
    "bedürfnisloses": "bedürfnislos",
    "bedürfnisloseste": "bedürfnislos",
    "bedürfnislosestem": "bedürfnislos",
    "bedürfnislosesten": "bedürfnislos",
    "bedürfnislosester": "bedürfnislos",
    "bedürfnislosestes": "bedürfnislos",
    "bedürftigem": "bedürftig",
    "bedürftigen": "bedürftig",
    "bedürftiger": "bedürftig",
    "bedürftigere": "bedürftig",
    "bedürftigerem": "bedürftig",
    "bedürftigeren": "bedürftig",
    "bedürftigerer": "bedürftig",
    "bedürftigeres": "bedürftig",
    "bedürftiges": "bedürftig",
    "bedürftigste": "bedürftig",
    "bedürftigstem": "bedürftig",
    "bedürftigsten": "bedürftig",
    "bedürftigster": "bedürftig",
    "bedürftigstes": "bedürftig",
    "beehre": "beehren",
    "beehrend": "beehren",
    "beehrende": "beehrend",
    "beehrendem": "beehrend",
    "beehrenden": "beehrend",
    "beehrender": "beehrend",
    "beehrendes": "beehrend",
    "beehrest": "beehren",
    "beehret": "beehren",
    "beehrst": "beehren",
    "beehrt": "beehren",
    "beehrte": "beehren",
    "beehrtem": "beehrt",
    "beehrten": "beehren",
    "beehrter": "beehrt",
    "beehrtes": "beehrt",
    "beehrtest": "beehren",
    "beehrtet": "beehren",
    "beeile": "beeilen",
    "beeilend": "beeilen",
    "beeilende": "beeilend",
    "beeilendem": "beeilend",
    "beeilenden": "beeilend",
    "beeilender": "beeilend",
    "beeilendere": "beeilend",
    "beeilenderem": "beeilend",
    "beeilenderen": "beeilend",
    "beeilenderer": "beeilend",
    "beeilenderes": "beeilend",
    "beeilendes": "beeilend",
    "beeilendste": "beeilend",
    "beeilendstem": "beeilend",
    "beeilendsten": "beeilend",
    "beeilendster": "beeilend",
    "beeilendstes": "beeilend",
    "beeilest": "beeilen",
    "beeilet": "beeilen",
    "beeilst": "beeilen",
    "beeilt": "beeilen",
    "beeilte": "beeilen",
    "beeiltem": "beeilt",
    "beeilten": "beeilen",
    "beeilter": "beeilt",
    "beeiltes": "beeilt",
    "beeiltest": "beeilen",
    "beeiltet": "beeilen",
    "beeindrucke": "beeindrucken",
    "beeindruckend": "beeindrucken",
    "beeindruckende": "beeindruckend",
    "beeindruckendem": "beeindruckend",
    "beeindruckenden": "beeindruckend",
    "beeindruckender": "beeindruckend",
    "beeindruckendere": "beeindruckend",
    "beeindruckenderem": "beeindruckend",
    "beeindruckenderen": "beeindruckend",
    "beeindruckenderer": "beeindruckend",
    "beeindruckenderes": "beeindruckend",
    "beeindruckendes": "beeindruckend",
    "beeindruckendste": "beeindruckend",
    "beeindruckendstem": "beeindruckend",
    "beeindruckendsten": "beeindruckend",
    "beeindruckendster": "beeindruckend",
    "beeindruckendstes": "beeindruckend",
    "beeindruckest": "beeindrucken",
    "beeindrucket": "beeindrucken",
    "beeindruckst": "beeindrucken",
    "beeindruckt": "beeindrucken",
    "beeindruckte": "beeindrucken",
    "beeindrucktem": "beeindruckt",
    "beeindruckten": "beeindrucken",
    "beeindruckter": "beeindruckt",
    "beeindrucktere": "beeindruckt",
    "beeindruckterem": "beeindruckt",
    "beeindruckteren": "beeindruckt",
    "beeindruckterer": "beeindruckt",
    "beeindruckteres": "beeindruckt",
    "beeindrucktes": "beeindruckt",
    "beeindrucktest": "beeindrucken",
    "beeindruckteste": "beeindruckt",
    "beeindrucktestem": "beeindruckt",
    "beeindrucktesten": "beeindruckt",
    "beeindrucktester": "beeindruckt",
    "beeindrucktestes": "beeindruckt",
    "beeindrucktet": "beeindrucken",
    "beeinflusse": "beeinflussen",
    "beeinflussend": "beeinflussen",
    "beeinflussende": "beeinflussend",
    "beeinflussendem": "beeinflussend",
    "beeinflussenden": "beeinflussend",
    "beeinflussender": "beeinflussend",
    "beeinflussendes": "beeinflussend",
    "beeinflussest": "beeinflussen",
    "beeinflusset": "beeinflussen",
    "beeinflußt": "beeinflussen",
    "beeinflußte": "beeinflussen",
    "beeinflußtem": "beeinflußt",
    "beeinflußten": "beeinflussen",
    "beeinflußter": "beeinflußt",
    "beeinflußtere": "beeinflußt",
    "beeinflußterem": "beeinflußt",
    "beeinflußteren": "beeinflußt",
    "beeinflußterer": "beeinflußt",
    "beeinflußteres": "beeinflußt",
    "beeinflußtes": "beeinflußt",
    "beeinflußtest": "beeinflussen",
    "beeinflußteste": "beeinflußt",
    "beeinflußtestem": "beeinflußt",
    "beeinflußtesten": "beeinflußt",
    "beeinflußtester": "beeinflußt",
    "beeinflußtestes": "beeinflußt",
    "beeinflußtet": "beeinflussen",
    "beeinträchtige": "beeinträchtigen",
    "beeinträchtigend": "beeinträchtigen",
    "beeinträchtigende": "beeinträchtigend",
    "beeinträchtigendem": "beeinträchtigend",
    "beeinträchtigenden": "beeinträchtigend",
    "beeinträchtigender": "beeinträchtigend",
    "beeinträchtigendere": "beeinträchtigend",
    "beeinträchtigenderem": "beeinträchtigend",
    "beeinträchtigenderen": "beeinträchtigend",
    "beeinträchtigenderer": "beeinträchtigend",
    "beeinträchtigenderes": "beeinträchtigend",
    "beeinträchtigendes": "beeinträchtigend",
    "beeinträchtigendste": "beeinträchtigend",
    "beeinträchtigendstem": "beeinträchtigend",
    "beeinträchtigendsten": "beeinträchtigend",
    "beeinträchtigendster": "beeinträchtigend",
    "beeinträchtigendstes": "beeinträchtigend",
    "beeinträchtigest": "beeinträchtigen",
    "beeinträchtiget": "beeinträchtigen",
    "beeinträchtigst": "beeinträchtigen",
    "beeinträchtigt": "beeinträchtigen",
    "beeinträchtigte": "beeinträchtigen",
    "beeinträchtigtem": "beeinträchtigt",
    "beeinträchtigten": "beeinträchtigen",
    "beeinträchtigter": "beeinträchtigt",
    "beeinträchtigtere": "beeinträchtigt",
    "beeinträchtigterem": "beeinträchtigt",
    "beeinträchtigteren": "beeinträchtigt",
    "beeinträchtigterer": "beeinträchtigt",
    "beeinträchtigteres": "beeinträchtigt",
    "beeinträchtigtes": "beeinträchtigt",
    "beeinträchtigtest": "beeinträchtigen",
    "beeinträchtigteste": "beeinträchtigt",
    "beeinträchtigtestem": "beeinträchtigt",
    "beeinträchtigtesten": "beeinträchtigt",
    "beeinträchtigtester": "beeinträchtigt",
    "beeinträchtigtestes": "beeinträchtigt",
    "beeinträchtigtet": "beeinträchtigen",
    "beende": "beenden",
    "beendend": "beenden",
    "beendende": "beendend",
    "beendendem": "beendend",
    "beendenden": "beendend",
    "beendender": "beendend",
    "beendendes": "beendend",
    "beendest": "beenden",
    "beendet": "beenden",
    "beendete": "beenden",
    "beendetem": "beendet",
    "beendeten": "beenden",
    "beendeter": "beendet",
    "beendetes": "beendet",
    "beendetest": "beenden",
    "beendetet": "beenden",
    "beerbe": "beerben",
    "beerbend": "beerben",
    "beerbende": "beerbend",
    "beerbendem": "beerbend",
    "beerbenden": "beerbend",
    "beerbender": "beerbend",
    "beerbendes": "beerbend",
    "beerbest": "beerben",
    "beerbet": "beerben",
    "beerbst": "beerben",
    "beerbt": "beerben",
    "beerbte": "beerben",
    "beerbtem": "beerbt",
    "beerbten": "beerben",
    "beerbter": "beerbt",
    "beerbtes": "beerbt",
    "beerbtest": "beerben",
    "beerbtet": "beerben",
    "beerdige": "beerdigen",
    "beerdigend": "beerdigen",
    "beerdigende": "beerdigend",
    "beerdigendem": "beerdigend",
    "beerdigenden": "beerdigend",
    "beerdigender": "beerdigend",
    "beerdigendes": "beerdigend",
    "beerdigest": "beerdigen",
    "beerdiget": "beerdigen",
    "beerdigst": "beerdigen",
    "beerdigt": "beerdigen",
    "beerdigte": "beerdigen",
    "beerdigtem": "beerdigt",
    "beerdigten": "beerdigen",
    "beerdigter": "beerdigt",
    "beerdigtes": "beerdigt",
    "beerdigtest": "beerdigen",
    "beerdigtet": "beerdigen",
    "befahl": "befehlen",
    "befahlen": "befehlen",
    "befahlst": "befehlen",
    "befahlt": "befehlen",
    "befahrbare": "befahrbar",
    "befahrbarem": "befahrbar",
    "befahrbaren": "befahrbar",
    "befahrbarer": "befahrbar",
    "befahrbarere": "befahrbar",
    "befahrbarerem": "befahrbar",
    "befahrbareren": "befahrbar",
    "befahrbarerer": "befahrbar",
    "befahrbareres": "befahrbar",
    "befahrbares": "befahrbar",
    "befahrbarste": "befahrbar",
    "befahrbarstem": "befahrbar",
    "befahrbarsten": "befahrbar",
    "befahrbarster": "befahrbar",
    "befahrbarstes": "befahrbar",
    "befahre": "befahren",
    "befahrend": "befahren",
    "befahrende": "befahrend",
    "befahrendem": "befahrend",
    "befahrenden": "befahrend",
    "befahrender": "befahrend",
    "befahrendes": "befahrend",
    "befahrene": "befahren",
    "befahrenem": "befahren",
    "befahrenen": "befahren",
    "befahrener": "befahren",
    "befahrenere": "befahren",
    "befahrenerem": "befahren",
    "befahreneren": "befahren",
    "befahrenerer": "befahren",
    "befahreneres": "befahren",
    "befahrenes": "befahren",
    "befahrenstem": "befahren",
    "befahrensten": "befahren",
    "befahrenster": "befahren",
    "befahrenstes": "befahren",
    "befahrest": "befahren",
    "befahret": "befahren",
    "befahrt": "befahren",
    "befalle": "befallen",
    "befallend": "befallen",
    "befallende": "befallend",
    "befallendem": "befallend",
    "befallenden": "befallend",
    "befallender": "befallend",
    "befallendes": "befallend",
    "befallene": "befallen",
    "befallenem": "befallen",
    "befallenen": "befallen",
    "befallener": "befallen",
    "befallenere": "befallen",
    "befallenerem": "befallen",
    "befalleneren": "befallen",
    "befallenerer": "befallen",
    "befalleneres": "befallen",
    "befallenes": "befallen",
    "befallenstem": "befallen",
    "befallensten": "befallen",
    "befallenster": "befallen",
    "befallenstes": "befallen",
    "befallest": "befallen",
    "befallet": "befallen",
    "befallt": "befallen",
    "befand": "befinden",
    "befanden": "befinden",
    "befandest": "befinden",
    "befandet": "befinden",
    "befangene": "befangen",
    "befangenem": "befangen",
    "befangenen": "befangen",
    "befangener": "befangen",
    "befangenere": "befangen",
    "befangenerem": "befangen",
    "befangeneren": "befangen",
    "befangenerer": "befangen",
    "befangeneres": "befangen",
    "befangenes": "befangen",
    "befangenste": "befangen",
    "befangenstem": "befangen",
    "befangensten": "befangen",
    "befangenster": "befangen",
    "befangenstes": "befangen",
    "befasse": "befassen",
    "befassend": "befassen",
    "befassende": "befassend",
    "befassendem": "befassend",
    "befassenden": "befassend",
    "befassender": "befassend",
    "befassendes": "befassend",
    "befassest": "befassen",
    "befasset": "befassen",
    "befaßt": "befassen",
    "befaßte": "befassen",
    "befaßtem": "befaßt",
    "befaßten": "befassen",
    "befaßter": "befaßt",
    "befaßtes": "befaßt",
    "befaßtest": "befassen",
    "befaßtet": "befassen",
    "befehlend": "befehlen",
    "befehlende": "befehlend",
    "befehlendem": "befehlend",
    "befehlenden": "befehlend",
    "befehlender": "befehlend",
    "befehlendere": "befehlend",
    "befehlenderem": "befehlend",
    "befehlenderen": "befehlend",
    "befehlenderer": "befehlend",
    "befehlenderes": "befehlend",
    "befehlendes": "befehlend",
    "befehlendste": "befehlend",
    "befehlendstem": "befehlend",
    "befehlendsten": "befehlend",
    "befehlendster": "befehlend",
    "befehlendstes": "befehlend",
    "befehlest": "befehlen",
    "befehlet": "befehlen",
    "befehlige": "befehligen",
    "befehligend": "befehligen",
    "befehligende": "befehligend",
    "befehligendem": "befehligend",
    "befehligenden": "befehligend",
    "befehligender": "befehligend",
    "befehligendes": "befehligend",
    "befehligest": "befehligen",
    "befehliget": "befehligen",
    "befehligst": "befehligen",
    "befehligt": "befehligen",
    "befehligte": "befehligen",
    "befehligtem": "befehligt",
    "befehligten": "befehligen",
    "befehligter": "befehligt",
    "befehligtes": "befehligt",
    "befehligtest": "befehligen",
    "befehligtet": "befehligen",
    "befehlt": "befehlen",
    "befestige": "befestigen",
    "befestigend": "befestigen",
    "befestigende": "befestigend",
    "befestigendem": "befestigend",
    "befestigenden": "befestigend",
    "befestigender": "befestigend",
    "befestigendere": "befestigend",
    "befestigenderem": "befestigend",
    "befestigenderen": "befestigend",
    "befestigenderer": "befestigend",
    "befestigenderes": "befestigend",
    "befestigendes": "befestigend",
    "befestigendste": "befestigend",
    "befestigendstem": "befestigend",
    "befestigendsten": "befestigend",
    "befestigendster": "befestigend",
    "befestigendstes": "befestigend",
    "befestigest": "befestigen",
    "befestiget": "befestigen",
    "befestigst": "befestigen",
    "befestigt": "befestigen",
    "befestigte": "befestigen",
    "befestigtem": "befestigt",
    "befestigten": "befestigen",
    "befestigter": "befestigt",
    "befestigtere": "befestigt",
    "befestigterem": "befestigt",
    "befestigteren": "befestigt",
    "befestigterer": "befestigt",
    "befestigteres": "befestigt",
    "befestigtes": "befestigt",
    "befestigtest": "befestigen",
    "befestigteste": "befestigt",
    "befestigtestem": "befestigt",
    "befestigtesten": "befestigt",
    "befestigtester": "befestigt",
    "befestigtestes": "befestigt",
    "befestigtet": "befestigen",
    "befeuchte": "befeuchten",
    "befeuchtend": "befeuchten",
    "befeuchtende": "befeuchtend",
    "befeuchtendem": "befeuchtend",
    "befeuchtenden": "befeuchtend",
    "befeuchtender": "befeuchtend",
    "befeuchtendere": "befeuchtend",
    "befeuchtenderem": "befeuchtend",
    "befeuchtenderen": "befeuchtend",
    "befeuchtenderer": "befeuchtend",
    "befeuchtenderes": "befeuchtend",
    "befeuchtendes": "befeuchtend",
    "befeuchtendste": "befeuchtend",
    "befeuchtendstem": "befeuchtend",
    "befeuchtendsten": "befeuchtend",
    "befeuchtendster": "befeuchtend",
    "befeuchtendstes": "befeuchtend",
    "befeuchtest": "befeuchten",
    "befeuchtet": "befeuchten",
    "befeuchtete": "befeuchten",
    "befeuchtetem": "befeuchtet",
    "befeuchteten": "befeuchten",
    "befeuchteter": "befeuchtet",
    "befeuchtetere": "befeuchtet",
    "befeuchteterem": "befeuchtet",
    "befeuchteteren": "befeuchtet",
    "befeuchteterer": "befeuchtet",
    "befeuchteteres": "befeuchtet",
    "befeuchtetes": "befeuchtet",
    "befeuchtetest": "befeuchten",
    "befeuchteteste": "befeuchtet",
    "befeuchtetestem": "befeuchtet",
    "befeuchtetesten": "befeuchtet",
    "befeuchtetester": "befeuchtet",
    "befeuchtetestes": "befeuchtet",
    "befeuchtetet": "befeuchten",
    "befeuere": "befeuern",
    "befeuernd": "befeuern",
    "befeuernde": "befeuernd",
    "befeuerndem": "befeuernd",
    "befeuernden": "befeuernd",
    "befeuernder": "befeuernd",
    "befeuerndere": "befeuernd",
    "befeuernderem": "befeuernd",
    "befeuernderen": "befeuernd",
    "befeuernderer": "befeuernd",
    "befeuernderes": "befeuernd",
    "befeuerndes": "befeuernd",
    "befeuerndste": "befeuernd",
    "befeuerndstem": "befeuernd",
    "befeuerndsten": "befeuernd",
    "befeuerndster": "befeuernd",
    "befeuerndstes": "befeuernd",
    "befeuerst": "befeuern",
    "befeuert": "befeuern",
    "befeuerte": "befeuern",
    "befeuertem": "befeuert",
    "befeuerten": "befeuern",
    "befeuerter": "befeuert",
    "befeuertere": "befeuert",
    "befeuerterem": "befeuert",
    "befeuerteren": "befeuert",
    "befeuerterer": "befeuert",
    "befeuerteres": "befeuert",
    "befeuertes": "befeuert",
    "befeuertest": "befeuern",
    "befeuerteste": "befeuert",
    "befeuertestem": "befeuert",
    "befeuertesten": "befeuert",
    "befeuertester": "befeuert",
    "befeuertestes": "befeuert",
    "befeuertet": "befeuern",
    "befiehl": "befehlen",
    "befiehlst": "befehlen",
    "befiehlt": "befehlen",
    "befiel": "befallen",
    "befiele": "befallen",
    "befielen": "befallen",
    "befielest": "befallen",
    "befielet": "befallen",
    "befielst": "befallen",
    "befielt": "befallen",
    "befinde": "befinden",
    "befindend": "befinden",
    "befindende": "befindend",
    "befindendem": "befindend",
    "befindenden": "befindend",
    "befindender": "befindend",
    "befindendes": "befindend",
    "befindest": "befinden",
    "befindet": "befinden",
    "befindlichem": "befindliche",
    "befindlichen": "befindliche",
    "befindlicher": "befindliche",
    "befindliches": "befindliche",
    "beflagge": "beflaggen",
    "beflaggend": "beflaggen",
    "beflaggende": "beflaggend",
    "beflaggendem": "beflaggend",
    "beflaggenden": "beflaggend",
    "beflaggender": "beflaggend",
    "beflaggendere": "beflaggend",
    "beflaggenderem": "beflaggend",
    "beflaggenderen": "beflaggend",
    "beflaggenderer": "beflaggend",
    "beflaggenderes": "beflaggend",
    "beflaggendes": "beflaggend",
    "beflaggendste": "beflaggend",
    "beflaggendstem": "beflaggend",
    "beflaggendsten": "beflaggend",
    "beflaggendster": "beflaggend",
    "beflaggendstes": "beflaggend",
    "beflaggest": "beflaggen",
    "beflagget": "beflaggen",
    "beflaggst": "beflaggen",
    "beflaggt": "beflaggen",
    "beflaggte": "beflaggen",
    "beflaggtem": "beflaggt",
    "beflaggten": "beflaggen",
    "beflaggter": "beflaggt",
    "beflaggtere": "beflaggt",
    "beflaggterem": "beflaggt",
    "beflaggteren": "beflaggt",
    "beflaggterer": "beflaggt",
    "beflaggteres": "beflaggt",
    "beflaggtes": "beflaggt",
    "beflaggtest": "beflaggen",
    "beflaggteste": "beflaggt",
    "beflaggtestem": "beflaggt",
    "beflaggtesten": "beflaggt",
    "beflaggtester": "beflaggt",
    "beflaggtestes": "beflaggt",
    "beflaggtet": "beflaggen",
    "beflecke": "beflecken",
    "befleckend": "beflecken",
    "befleckende": "befleckend",
    "befleckendem": "befleckend",
    "befleckenden": "befleckend",
    "befleckender": "befleckend",
    "befleckendes": "befleckend",
    "befleckest": "beflecken",
    "beflecket": "beflecken",
    "befleckst": "beflecken",
    "befleckt": "beflecken",
    "befleckte": "beflecken",
    "beflecktem": "befleckt",
    "befleckten": "beflecken",
    "befleckter": "befleckt",
    "beflecktere": "befleckt",
    "befleckterem": "befleckt",
    "befleckteren": "befleckt",
    "befleckterer": "befleckt",
    "befleckteres": "befleckt",
    "beflecktes": "befleckt",
    "beflecktest": "beflecken",
    "befleckteste": "befleckt",
    "beflecktestem": "befleckt",
    "beflecktesten": "befleckt",
    "beflecktester": "befleckt",
    "beflecktestes": "befleckt",
    "beflecktet": "beflecken",
    "befleiße": "befleißen",
    "befleißend": "befleißen",
    "befleißende": "befleißend",
    "befleißendem": "befleißend",
    "befleißenden": "befleißend",
    "befleißender": "befleißend",
    "befleißendere": "befleißend",
    "befleißenderem": "befleißend",
    "befleißenderen": "befleißend",
    "befleißenderer": "befleißend",
    "befleißenderes": "befleißend",
    "befleißendes": "befleißend",
    "befleißendste": "befleißend",
    "befleißendstem": "befleißend",
    "befleißendsten": "befleißend",
    "befleißendster": "befleißend",
    "befleißendstes": "befleißend",
    "befleißest": "befleißen",
    "befleißet": "befleißen",
    "befleißt": "befleißen",
    "beflisse": "befleißen",
    "beflissen": "befleißen",
    "beflissene": "beflissen",
    "beflissenem": "beflissen",
    "beflissenen": "beflissen",
    "beflissener": "beflissen",
    "beflissenere": "beflissen",
    "beflissenerem": "beflissen",
    "beflisseneren": "beflissen",
    "beflissenerer": "beflissen",
    "beflisseneres": "beflissen",
    "beflissenes": "beflissen",
    "beflissenste": "beflissen",
    "beflissenstem": "beflissen",
    "beflissensten": "beflissen",
    "beflissenster": "beflissen",
    "beflissenstes": "beflissen",
    "beflissest": "befleißen",
    "beflisset": "befleißen",
    "befliß": "befleißen",
    "beflißt": "befleißen",
    "beflügele": "beflügeln",
    "beflügelnd": "beflügeln",
    "beflügelnde": "beflügelnd",
    "beflügelndem": "beflügelnd",
    "beflügelnden": "beflügelnd",
    "beflügelnder": "beflügelnd",
    "beflügelndes": "beflügelnd",
    "beflügelst": "beflügeln",
    "beflügelt": "beflügeln",
    "beflügelte": "beflügeln",
    "beflügeltem": "beflügelt",
    "beflügelten": "beflügeln",
    "beflügelter": "beflügelt",
    "beflügeltes": "beflügelt",
    "beflügeltest": "beflügeln",
    "beflügeltet": "beflügeln",
    "beflügle": "beflügeln",
    "befohlen": "befehlen",
    "befohlene": "befohlen",
    "befohlenem": "befohlen",
    "befohlenen": "befohlen",
    "befohlener": "befohlen",
    "befohlenes": "befohlen",
    "befolge": "befolgen",
    "befolgend": "befolgen",
    "befolgende": "befolgend",
    "befolgendem": "befolgend",
    "befolgenden": "befolgend",
    "befolgender": "befolgend",
    "befolgendere": "befolgend",
    "befolgenderem": "befolgend",
    "befolgenderen": "befolgend",
    "befolgenderer": "befolgend",
    "befolgenderes": "befolgend",
    "befolgendes": "befolgend",
    "befolgendste": "befolgend",
    "befolgendstem": "befolgend",
    "befolgendsten": "befolgend",
    "befolgendster": "befolgend",
    "befolgendstes": "befolgend",
    "befolgest": "befolgen",
    "befolget": "befolgen",
    "befolgst": "befolgen",
    "befolgt": "befolgen",
    "befolgte": "befolgen",
    "befolgtem": "befolgt",
    "befolgten": "befolgen",
    "befolgter": "befolgt",
    "befolgtere": "befolgt",
    "befolgterem": "befolgt",
    "befolgteren": "befolgt",
    "befolgterer": "befolgt",
    "befolgteres": "befolgt",
    "befolgtes": "befolgt",
    "befolgtest": "befolgen",
    "befolgteste": "befolgt",
    "befolgtestem": "befolgt",
    "befolgtesten": "befolgt",
    "befolgtester": "befolgt",
    "befolgtestes": "befolgt",
    "befolgtet": "befolgen",
    "befrage": "befragen",
    "befragend": "befragen",
    "befragende": "befragend",
    "befragendem": "befragend",
    "befragenden": "befragend",
    "befragender": "befragend",
    "befragendes": "befragend",
    "befragest": "befragen",
    "befraget": "befragen",
    "befragst": "befragen",
    "befragt": "befragen",
    "befragte": "befragen",
    "befragtem": "befragt",
    "befragten": "befragen",
    "befragter": "befragt",
    "befragtere": "befragt",
    "befragterem": "befragt",
    "befragteren": "befragt",
    "befragterer": "befragt",
    "befragteres": "befragt",
    "befragtes": "befragt",
    "befragtest": "befragen",
    "befragteste": "befragt",
    "befragtestem": "befragt",
    "befragtesten": "befragt",
    "befragtester": "befragt",
    "befragtestes": "befragt",
    "befragtet": "befragen",
    "befreie": "befreien",
    "befreiend": "befreien",
    "befreiende": "befreiend",
    "befreiendem": "befreiend",
    "befreienden": "befreiend",
    "befreiender": "befreiend",
    "befreiendes": "befreiend",
    "befreiest": "befreien",
    "befreiet": "befreien",
    "befreist": "befreien",
    "befreit": "befreien",
    "befreite": "befreien",
    "befreitem": "befreit",
    "befreiten": "befreien",
    "befreiter": "befreit",
    "befreites": "befreit",
    "befreitest": "befreien",
    "befreitet": "befreien",
    "befremde": "befremden",
    "befremdend": "befremden",
    "befremdende": "befremdend",
    "befremdendem": "befremdend",
    "befremdenden": "befremdend",
    "befremdender": "befremdend",
    "befremdendere": "befremdend",
    "befremdenderem": "befremdend",
    "befremdenderen": "befremdend",
    "befremdenderer": "befremdend",
    "befremdenderes": "befremdend",
    "befremdendes": "befremdend",
    "befremdendste": "befremdend",
    "befremdendstem": "befremdend",
    "befremdendsten": "befremdend",
    "befremdendster": "befremdend",
    "befremdendstes": "befremdend",
    "befremdest": "befremden",
    "befremdet": "befremden",
    "befremdete": "befremden",
    "befremdetem": "befremdet",
    "befremdeten": "befremden",
    "befremdeter": "befremdet",
    "befremdetes": "befremdet",
    "befremdetest": "befremden",
    "befremdetet": "befremden",
    "befreundete": "befreundet",
    "befreundetem": "befreundet",
    "befreundeten": "befreundet",
    "befreundeter": "befreundet",
    "befreundetes": "befreundet",
    "befriedige": "befriedigen",
    "befriedigend": "befriedigen",
    "befriedigende": "befriedigend",
    "befriedigendem": "befriedigend",
    "befriedigenden": "befriedigend",
    "befriedigender": "befriedigend",
    "befriedigendere": "befriedigend",
    "befriedigenderem": "befriedigend",
    "befriedigenderen": "befriedigend",
    "befriedigenderer": "befriedigend",
    "befriedigenderes": "befriedigend",
    "befriedigendes": "befriedigend",
    "befriedigendste": "befriedigend",
    "befriedigendstem": "befriedigend",
    "befriedigendsten": "befriedigend",
    "befriedigendster": "befriedigend",
    "befriedigendstes": "befriedigend",
    "befriedigest": "befriedigen",
    "befriediget": "befriedigen",
    "befriedigst": "befriedigen",
    "befriedigt": "befriedigen",
    "befriedigte": "befriedigen",
    "befriedigtem": "befriedigt",
    "befriedigten": "befriedigen",
    "befriedigter": "befriedigt",
    "befriedigtere": "befriedigt",
    "befriedigterem": "befriedigt",
    "befriedigteren": "befriedigt",
    "befriedigterer": "befriedigt",
    "befriedigteres": "befriedigt",
    "befriedigtes": "befriedigt",
    "befriedigtest": "befriedigen",
    "befriedigteste": "befriedigt",
    "befriedigtestem": "befriedigt",
    "befriedigtesten": "befriedigt",
    "befriedigtester": "befriedigt",
    "befriedigtestes": "befriedigt",
    "befriedigtet": "befriedigen",
    "befriste": "befristen",
    "befristend": "befristen",
    "befristende": "befristend",
    "befristendem": "befristend",
    "befristenden": "befristend",
    "befristender": "befristend",
    "befristendes": "befristend",
    "befristest": "befristen",
    "befristet": "befristen",
    "befristete": "befristen",
    "befristetem": "befristet",
    "befristeten": "befristen",
    "befristeter": "befristet",
    "befristetes": "befristet",
    "befristetest": "befristen",
    "befristetet": "befristen",
    "befruchte": "befruchten",
    "befruchtend": "befruchten",
    "befruchtende": "befruchtend",
    "befruchtendem": "befruchtend",
    "befruchtenden": "befruchtend",
    "befruchtender": "befruchtend",
    "befruchtendere": "befruchtend",
    "befruchtenderem": "befruchtend",
    "befruchtenderen": "befruchtend",
    "befruchtenderer": "befruchtend",
    "befruchtenderes": "befruchtend",
    "befruchtendes": "befruchtend",
    "befruchtendste": "befruchtend",
    "befruchtendstem": "befruchtend",
    "befruchtendsten": "befruchtend",
    "befruchtendster": "befruchtend",
    "befruchtendstes": "befruchtend",
    "befruchtest": "befruchten",
    "befruchtet": "befruchten",
    "befruchtete": "befruchten",
    "befruchtetem": "befruchtet",
    "befruchteten": "befruchten",
    "befruchteter": "befruchtet",
    "befruchtetere": "befruchtet",
    "befruchteterem": "befruchtet",
    "befruchteteren": "befruchtet",
    "befruchteterer": "befruchtet",
    "befruchteteres": "befruchtet",
    "befruchtetes": "befruchtet",
    "befruchtetest": "befruchten",
    "befruchteteste": "befruchtet",
    "befruchtetestem": "befruchtet",
    "befruchtetesten": "befruchtet",
    "befruchtetester": "befruchtet",
    "befruchtetestes": "befruchtet",
    "befruchtetet": "befruchten",
    "befuhr": "befahren",
    "befuhren": "befahren",
    "befuhrst": "befahren",
    "befuhrt": "befahren",
    "befummele": "befummeln",
    "befummelnd": "befummeln",
    "befummelnde": "befummelnd",
    "befummelndem": "befummelnd",
    "befummelnden": "befummelnd",
    "befummelnder": "befummelnd",
    "befummelndere": "befummelnd",
    "befummelnderem": "befummelnd",
    "befummelnderen": "befummelnd",
    "befummelnderer": "befummelnd",
    "befummelnderes": "befummelnd",
    "befummelndes": "befummelnd",
    "befummelndste": "befummelnd",
    "befummelndstem": "befummelnd",
    "befummelndsten": "befummelnd",
    "befummelndster": "befummelnd",
    "befummelndstes": "befummelnd",
    "befummelst": "befummeln",
    "befummelt": "befummeln",
    "befummelte": "befummeln",
    "befummeltem": "befummelt",
    "befummelten": "befummeln",
    "befummelter": "befummelt",
    "befummeltere": "befummelt",
    "befummelterem": "befummelt",
    "befummelteren": "befummelt",
    "befummelterer": "befummelt",
    "befummelteres": "befummelt",
    "befummeltes": "befummelt",
    "befummeltest": "befummeln",
    "befummelteste": "befummelt",
    "befummeltestem": "befummelt",
    "befummeltesten": "befummelt",
    "befummeltester": "befummelt",
    "befummeltestes": "befummelt",
    "befummeltet": "befummeln",
    "befummle": "befummeln",
    "befundenem": "befunden",
    "befundenen": "befunden",
    "befundener": "befunden",
    "befundenes": "befunden",
    "befähige": "befähigen",
    "befähigend": "befähigen",
    "befähigende": "befähigend",
    "befähigendem": "befähigend",
    "befähigenden": "befähigend",
    "befähigender": "befähigend",
    "befähigendes": "befähigend",
    "befähigest": "befähigen",
    "befähiget": "befähigen",
    "befähigst": "befähigen",
    "befähigt": "befähigen",
    "befähigte": "befähigen",
    "befähigtem": "befähigt",
    "befähigten": "befähigen",
    "befähigter": "befähigt",
    "befähigtes": "befähigt",
    "befähigtest": "befähigen",
    "befähigtet": "befähigen",
    "befähle": "befehlen",
    "befählen": "befehlen",
    "befählest": "befehlen",
    "befählet": "befehlen",
    "befährst": "befahren",
    "befährt": "befahren",
    "befällst": "befallen",
    "befällt": "befallen",
    "befände": "befinden",
    "befänden": "befinden",
    "befändest": "befinden",
    "befändet": "befinden",
    "befördere": "befördern",
    "befördernd": "befördern",
    "befördernde": "befördernd",
    "beförderndem": "befördernd",
    "befördernden": "befördernd",
    "befördernder": "befördernd",
    "beförderndes": "befördernd",
    "beförderst": "befördern",
    "befördert": "befördern",
    "beförderte": "befördern",
    "befördertem": "befördert",
    "beförderten": "befördern",
    "beförderter": "befördert",
    "befördertes": "befördert",
    "befördertest": "befördern",
    "befördertet": "befördern",
    "beführe": "befahren",
    "beführen": "befahren",
    "beführest": "befahren",
    "beführet": "befahren",
    "befürchte": "befürchten",
    "befürchtend": "befürchten",
    "befürchtende": "befürchtend",
    "befürchtendem": "befürchtend",
    "befürchtenden": "befürchtend",
    "befürchtender": "befürchtend",
    "befürchtendes": "befürchtend",
    "befürchtest": "befürchten",
    "befürchtet": "befürchten",
    "befürchtete": "befürchten",
    "befürchtetem": "befürchtet",
    "befürchteten": "befürchten",
    "befürchteter": "befürchtet",
    "befürchtetes": "befürchtet",
    "befürchtetest": "befürchten",
    "befürchtetet": "befürchten",
    "befürsorge": "befürsorgen",
    "befürsorgend": "befürsorgen",
    "befürsorgende": "befürsorgend",
    "befürsorgendem": "befürsorgend",
    "befürsorgenden": "befürsorgend",
    "befürsorgender": "befürsorgend",
    "befürsorgendere": "befürsorgend",
    "befürsorgenderem": "befürsorgend",
    "befürsorgenderen": "befürsorgend",
    "befürsorgenderer": "befürsorgend",
    "befürsorgenderes": "befürsorgend",
    "befürsorgendes": "befürsorgend",
    "befürsorgendste": "befürsorgend",
    "befürsorgendstem": "befürsorgend",
    "befürsorgendsten": "befürsorgend",
    "befürsorgendster": "befürsorgend",
    "befürsorgendstes": "befürsorgend",
    "befürsorgest": "befürsorgen",
    "befürsorget": "befürsorgen",
    "befürsorgst": "befürsorgen",
    "befürsorgt": "befürsorgen",
    "befürsorgte": "befürsorgen",
    "befürsorgtem": "befürsorgt",
    "befürsorgten": "befürsorgen",
    "befürsorgter": "befürsorgt",
    "befürsorgtere": "befürsorgt",
    "befürsorgterem": "befürsorgt",
    "befürsorgteren": "befürsorgt",
    "befürsorgterer": "befürsorgt",
    "befürsorgteres": "befürsorgt",
    "befürsorgtes": "befürsorgt",
    "befürsorgtest": "befürsorgen",
    "befürsorgteste": "befürsorgt",
    "befürsorgtestem": "befürsorgt",
    "befürsorgtesten": "befürsorgt",
    "befürsorgtester": "befürsorgt",
    "befürsorgtestes": "befürsorgt",
    "befürsorgtet": "befürsorgen",
    "befürworte": "befürworten",
    "befürwortend": "befürworten",
    "befürwortende": "befürwortend",
    "befürwortendem": "befürwortend",
    "befürwortenden": "befürwortend",
    "befürwortender": "befürwortend",
    "befürwortendes": "befürwortend",
    "befürwortest": "befürworten",
    "befürwortet": "befürworten",
    "befürwortete": "befürworten",
    "befürwortetem": "befürwortet",
    "befürworteten": "befürworten",
    "befürworteter": "befürwortet",
    "befürwortetes": "befürwortet",
    "befürwortetest": "befürworten",
    "befürwortetet": "befürworten",
    "begab": "begeben",
    "begaben": "begeben",
    "begabst": "begeben",
    "begabt": "begeben",
    "begaffe": "begaffen",
    "begaffend": "begaffen",
    "begaffende": "begaffend",
    "begaffendem": "begaffend",
    "begaffenden": "begaffend",
    "begaffender": "begaffend",
    "begaffendere": "begaffend",
    "begaffenderem": "begaffend",
    "begaffenderen": "begaffend",
    "begaffenderer": "begaffend",
    "begaffenderes": "begaffend",
    "begaffendes": "begaffend",
    "begaffendste": "begaffend",
    "begaffendstem": "begaffend",
    "begaffendsten": "begaffend",
    "begaffendster": "begaffend",
    "begaffendstes": "begaffend",
    "begaffest": "begaffen",
    "begaffet": "begaffen",
    "begaffst": "begaffen",
    "begafft": "begaffen",
    "begaffte": "begaffen",
    "begafftem": "begafft",
    "begafften": "begaffen",
    "begaffter": "begafft",
    "begafftere": "begafft",
    "begaffterem": "begafft",
    "begaffteren": "begafft",
    "begaffterer": "begafft",
    "begaffteres": "begafft",
    "begafftes": "begafft",
    "begafftest": "begaffen",
    "begaffteste": "begafft",
    "begafftestem": "begafft",
    "begafftesten": "begafft",
    "begafftester": "begafft",
    "begafftestes": "begafft",
    "begafftet": "begaffen",
    "begangen": "begehen",
    "begangene": "begangen",
    "begangenem": "begangen",
    "begangenen": "begangen",
    "begangener": "begangen",
    "begangenes": "begangen",
    "begann": "beginnen",
    "begannen": "beginnen",
    "begannst": "beginnen",
    "begannt": "beginnen",
    "begatte": "begatten",
    "begattend": "begatten",
    "begattende": "begattend",
    "begattendem": "begattend",
    "begattenden": "begattend",
    "begattender": "begattend",
    "begattendes": "begattend",
    "begattest": "begatten",
    "begattet": "begatten",
    "begattete": "begatten",
    "begattetem": "begattet",
    "begatteten": "begatten",
    "begatteter": "begattet",
    "begattetes": "begattet",
    "begattetest": "begatten",
    "begattetet": "begatten",
    "begebe": "begeben",
    "begebend": "begeben",
    "begebende": "begebend",
    "begebendem": "begebend",
    "begebenden": "begebend",
    "begebender": "begebend",
    "begebendes": "begebend",
    "begebene": "begeben",
    "begebenem": "begeben",
    "begebenen": "begeben",
    "begebener": "begeben",
    "begebenes": "begeben",
    "begebest": "begeben",
    "begebet": "begeben",
    "begebt": "begeben",
    "begefallen": "befallen",
    "begegne": "begegnen",
    "begegnend": "begegnen",
    "begegnende": "begegnend",
    "begegnendem": "begegnend",
    "begegnenden": "begegnend",
    "begegnender": "begegnend",
    "begegnendes": "begegnend",
    "begegnest": "begegnen",
    "begegnet": "begegnen",
    "begegnete": "begegnen",
    "begegnetem": "begegnet",
    "begegneten": "begegnen",
    "begegneter": "begegnet",
    "begegnetes": "begegnet",
    "begegnetest": "begegnen",
    "begegnetet": "begegnen",
    "begehbarem": "begehbar",
    "begehbaren": "begehbar",
    "begehbarer": "begehbar",
    "begehbarere": "begehbar",
    "begehbarerem": "begehbar",
    "begehbareren": "begehbar",
    "begehbarerer": "begehbar",
    "begehbareres": "begehbar",
    "begehbares": "begehbar",
    "begehbarste": "begehbar",
    "begehbarstem": "begehbar",
    "begehbarsten": "begehbar",
    "begehbarster": "begehbar",
    "begehbarstes": "begehbar",
    "begehe": "begehen",
    "begehend": "begehen",
    "begehende": "begehend",
    "begehendem": "begehend",
    "begehenden": "begehend",
    "begehender": "begehend",
    "begehendes": "begehend",
    "begehest": "begehen",
    "begehet": "begehen",
    "begehrend": "begehren",
    "begehrende": "begehrend",
    "begehrendem": "begehrend",
    "begehrenden": "begehrend",
    "begehrender": "begehrend",
    "begehrendere": "begehrend",
    "begehrenderem": "begehrend",
    "begehrenderen": "begehrend",
    "begehrenderer": "begehrend",
    "begehrenderes": "begehrend",
    "begehrendes": "begehrend",
    "begehrendste": "begehrend",
    "begehrendstem": "begehrend",
    "begehrendsten": "begehrend",
    "begehrendster": "begehrend",
    "begehrendstes": "begehrend",
    "begehrenswertem": "begehrenswert",
    "begehrenswerten": "begehrenswert",
    "begehrenswerter": "begehrenswert",
    "begehrenswertere": "begehrenswert",
    "begehrenswerterem": "begehrenswert",
    "begehrenswerteren": "begehrenswert",
    "begehrenswerterer": "begehrenswert",
    "begehrenswerteres": "begehrenswert",
    "begehrenswertes": "begehrenswert",
    "begehrenswerteste": "begehrenswert",
    "begehrenswertestem": "begehrenswert",
    "begehrenswertesten": "begehrenswert",
    "begehrenswertester": "begehrenswert",
    "begehrenswertestes": "begehrenswert",
    "begehrest": "begehren",
    "begehret": "begehren",
    "begehrst": "begehren",
    "begehrt": "begehren",
    "begehrte": "begehren",
    "begehrtem": "begehrt",
    "begehrten": "begehren",
    "begehrter": "begehrt",
    "begehrtere": "begehrt",
    "begehrterem": "begehrt",
    "begehrteren": "begehrt",
    "begehrterer": "begehrt",
    "begehrteres": "begehrt",
    "begehrtes": "begehrt",
    "begehrtest": "begehren",
    "begehrteste": "begehrt",
    "begehrtestem": "begehrt",
    "begehrtesten": "begehrt",
    "begehrtester": "begehrt",
    "begehrtestes": "begehrt",
    "begehrtet": "begehren",
    "begehst": "begehen",
    "begeht": "begehen",
    "begeistere": "begeistern",
    "begeisternd": "begeistern",
    "begeisternde": "begeisternd",
    "begeisterndem": "begeisternd",
    "begeisternden": "begeisternd",
    "begeisternder": "begeisternd",
    "begeisterndere": "begeisternd",
    "begeisternderem": "begeisternd",
    "begeisternderen": "begeisternd",
    "begeisternderer": "begeisternd",
    "begeisternderes": "begeisternd",
    "begeisterndes": "begeisternd",
    "begeisterndste": "begeisternd",
    "begeisterndstem": "begeisternd",
    "begeisterndsten": "begeisternd",
    "begeisterndster": "begeisternd",
    "begeisterndstes": "begeisternd",
    "begeisterst": "begeistern",
    "begeistert": "begeistern",
    "begeisterte": "begeistern",
    "begeistertem": "begeistert",
    "begeisterten": "begeistern",
    "begeisterter": "begeistert",
    "begeistertere": "begeistert",
    "begeisterterem": "begeistert",
    "begeisterteren": "begeistert",
    "begeisterterer": "begeistert",
    "begeisterteres": "begeistert",
    "begeistertes": "begeistert",
    "begeistertest": "begeistern",
    "begeisterteste": "begeistert",
    "begeistertestem": "begeistert",
    "begeistertesten": "begeistert",
    "begeistertester": "begeistert",
    "begeistertestes": "begeistert",
    "begeistertet": "begeistern",
    "begib": "begeben",
    "begibst": "begeben",
    "begibt": "begeben",
    "begierdelose": "begierdelos",
    "begierdelosem": "begierdelos",
    "begierdelosen": "begierdelos",
    "begierdeloser": "begierdelos",
    "begierdelosere": "begierdelos",
    "begierdeloserem": "begierdelos",
    "begierdeloseren": "begierdelos",
    "begierdeloserer": "begierdelos",
    "begierdeloseres": "begierdelos",
    "begierdeloses": "begierdelos",
    "begierdeloseste": "begierdelos",
    "begierdelosestem": "begierdelos",
    "begierdelosesten": "begierdelos",
    "begierdelosester": "begierdelos",
    "begierdelosestes": "begierdelos",
    "begierige": "begierig",
    "begierigem": "begierig",
    "begierigen": "begierig",
    "begieriger": "begierig",
    "begierigere": "begierig",
    "begierigerem": "begierig",
    "begierigeren": "begierig",
    "begierigerer": "begierig",
    "begierigeres": "begierig",
    "begieriges": "begierig",
    "begierigste": "begierig",
    "begierigstem": "begierig",
    "begierigsten": "begierig",
    "begierigster": "begierig",
    "begierigstes": "begierig",
    "begieße": "begießen",
    "begießend": "begießen",
    "begießende": "begießend",
    "begießendem": "begießend",
    "begießenden": "begießend",
    "begießender": "begießend",
    "begießendes": "begießend",
    "begießest": "begießen",
    "begießet": "begießen",
    "begießt": "begießen",
    "beging": "begehen",
    "beginge": "begehen",
    "begingen": "begehen",
    "begingest": "begehen",
    "beginget": "begehen",
    "begingst": "begehen",
    "begingt": "begehen",
    "beginne": "beginnen",
    "beginnend": "beginnen",
    "beginnende": "beginnend",
    "beginnendem": "beginnend",
    "beginnenden": "beginnend",
    "beginnender": "beginnend",
    "beginnendes": "beginnend",
    "beginnest": "beginnen",
    "beginnet": "beginnen",
    "beginnst": "beginnen",
    "beginnt": "beginnen",
    "beglaubige": "beglaubigen",
    "beglaubigend": "beglaubigen",
    "beglaubigende": "beglaubigend",
    "beglaubigendem": "beglaubigend",
    "beglaubigenden": "beglaubigend",
    "beglaubigender": "beglaubigend",
    "beglaubigendes": "beglaubigend",
    "beglaubigest": "beglaubigen",
    "beglaubiget": "beglaubigen",
    "beglaubigst": "beglaubigen",
    "beglaubigt": "beglaubigen",
    "beglaubigte": "beglaubigen",
    "beglaubigtem": "beglaubigt",
    "beglaubigten": "beglaubigen",
    "beglaubigter": "beglaubigt",
    "beglaubigtes": "beglaubigt",
    "beglaubigtest": "beglaubigen",
    "beglaubigtet": "beglaubigen",
    "begleiche": "begleichen",
    "begleichend": "begleichen",
    "begleichende": "begleichend",
    "begleichendem": "begleichend",
    "begleichenden": "begleichend",
    "begleichender": "begleichend",
    "begleichendes": "begleichend",
    "begleichest": "begleichen",
    "begleichet": "begleichen",
    "begleichst": "begleichen",
    "begleicht": "begleichen",
    "begleite": "begleiten",
    "begleitend": "begleiten",
    "begleitende": "begleitend",
    "begleitendem": "begleitend",
    "begleitenden": "begleitend",
    "begleitender": "begleitend",
    "begleitendes": "begleitend",
    "begleitest": "begleiten",
    "begleitet": "begleiten",
    "begleitete": "begleiten",
    "begleitetem": "begleitet",
    "begleiteten": "begleiten",
    "begleiteter": "begleitet",
    "begleitetes": "begleitet",
    "begleitetest": "begleiten",
    "begleitetet": "begleiten",
    "beglich": "begleichen",
    "begliche": "begleichen",
    "beglichen": "begleichen",
    "beglichene": "beglichen",
    "beglichenem": "beglichen",
    "beglichenen": "beglichen",
    "beglichener": "beglichen",
    "beglichenes": "beglichen",
    "beglichest": "begleichen",
    "beglichet": "begleichen",
    "beglichst": "begleichen",
    "beglicht": "begleichen",
    "beglotze": "beglotzen",
    "beglotzend": "beglotzen",
    "beglotzende": "beglotzend",
    "beglotzendem": "beglotzend",
    "beglotzenden": "beglotzend",
    "beglotzender": "beglotzend",
    "beglotzendere": "beglotzend",
    "beglotzenderem": "beglotzend",
    "beglotzenderen": "beglotzend",
    "beglotzenderer": "beglotzend",
    "beglotzenderes": "beglotzend",
    "beglotzendes": "beglotzend",
    "beglotzendste": "beglotzend",
    "beglotzendstem": "beglotzend",
    "beglotzendsten": "beglotzend",
    "beglotzendster": "beglotzend",
    "beglotzendstes": "beglotzend",
    "beglotzest": "beglotzen",
    "beglotzet": "beglotzen",
    "beglotzt": "beglotzen",
    "beglotzte": "beglotzen",
    "beglotztem": "beglotzt",
    "beglotzten": "beglotzen",
    "beglotzter": "beglotzt",
    "beglotztere": "beglotzt",
    "beglotzterem": "beglotzt",
    "beglotzteren": "beglotzt",
    "beglotzterer": "beglotzt",
    "beglotzteres": "beglotzt",
    "beglotztes": "beglotzt",
    "beglotztest": "beglotzen",
    "beglotzteste": "beglotzt",
    "beglotztestem": "beglotzt",
    "beglotztesten": "beglotzt",
    "beglotztester": "beglotzt",
    "beglotztestes": "beglotzt",
    "beglotztet": "beglotzen",
    "beglupsche": "beglupschen",
    "beglupschend": "beglupschen",
    "beglupschende": "beglupschend",
    "beglupschendem": "beglupschend",
    "beglupschenden": "beglupschend",
    "beglupschender": "beglupschend",
    "beglupschendere": "beglupschend",
    "beglupschenderem": "beglupschend",
    "beglupschenderen": "beglupschend",
    "beglupschenderer": "beglupschend",
    "beglupschenderes": "beglupschend",
    "beglupschendes": "beglupschend",
    "beglupschendste": "beglupschend",
    "beglupschendstem": "beglupschend",
    "beglupschendsten": "beglupschend",
    "beglupschendster": "beglupschend",
    "beglupschendstes": "beglupschend",
    "beglupschest": "beglupschen",
    "beglupschet": "beglupschen",
    "beglupschst": "beglupschen",
    "beglupscht": "beglupschen",
    "beglupschte": "beglupschen",
    "beglupschtem": "beglupscht",
    "beglupschten": "beglupschen",
    "beglupschter": "beglupscht",
    "beglupschtere": "beglupscht",
    "beglupschterem": "beglupscht",
    "beglupschteren": "beglupscht",
    "beglupschterer": "beglupscht",
    "beglupschteres": "beglupscht",
    "beglupschtes": "beglupscht",
    "beglupschtest": "beglupschen",
    "beglupschteste": "beglupscht",
    "beglupschtestem": "beglupscht",
    "beglupschtesten": "beglupscht",
    "beglupschtester": "beglupscht",
    "beglupschtestes": "beglupscht",
    "beglupschtet": "beglupschen",
    "beglücke": "beglücken",
    "beglückend": "beglücken",
    "beglückende": "beglückend",
    "beglückendem": "beglückend",
    "beglückenden": "beglückend",
    "beglückender": "beglückend",
    "beglückendere": "beglückend",
    "beglückenderem": "beglückend",
    "beglückenderen": "beglückend",
    "beglückenderer": "beglückend",
    "beglückenderes": "beglückend",
    "beglückendes": "beglückend",
    "beglückendste": "beglückend",
    "beglückendstem": "beglückend",
    "beglückendsten": "beglückend",
    "beglückendster": "beglückend",
    "beglückendstes": "beglückend",
    "beglückest": "beglücken",
    "beglücket": "beglücken",
    "beglückst": "beglücken",
    "beglückt": "beglücken",
    "beglückte": "beglücken",
    "beglücktem": "beglückt",
    "beglückten": "beglücken",
    "beglückter": "beglückt",
    "beglücktere": "beglückt",
    "beglückterem": "beglückt",
    "beglückteren": "beglückt",
    "beglückterer": "beglückt",
    "beglückteres": "beglückt",
    "beglücktes": "beglückt",
    "beglücktest": "beglücken",
    "beglückteste": "beglückt",
    "beglücktestem": "beglückt",
    "beglücktesten": "beglückt",
    "beglücktester": "beglückt",
    "beglücktestes": "beglückt",
    "beglücktet": "beglücken",
    "beglückwünsche": "beglückwünschen",
    "beglückwünschend": "beglückwünschen",
    "beglückwünschende": "beglückwünschend",
    "beglückwünschendem": "beglückwünschend",
    "beglückwünschenden": "beglückwünschend",
    "beglückwünschender": "beglückwünschend",
    "beglückwünschendes": "beglückwünschend",
    "beglückwünschest": "beglückwünschen",
    "beglückwünschet": "beglückwünschen",
    "beglückwünschst": "beglückwünschen",
    "beglückwünscht": "beglückwünschen",
    "beglückwünschte": "beglückwünschen",
    "beglückwünschtem": "beglückwünscht",
    "beglückwünschten": "beglückwünschen",
    "beglückwünschter": "beglückwünscht",
    "beglückwünschtes": "beglückwünscht",
    "beglückwünschtest": "beglückwünschen",
    "beglückwünschtet": "beglückwünschen",
    "begnadige": "begnadigen",
    "begnadigend": "begnadigen",
    "begnadigende": "begnadigend",
    "begnadigendem": "begnadigend",
    "begnadigenden": "begnadigend",
    "begnadigender": "begnadigend",
    "begnadigendes": "begnadigend",
    "begnadigest": "begnadigen",
    "begnadiget": "begnadigen",
    "begnadigst": "begnadigen",
    "begnadigt": "begnadigen",
    "begnadigte": "begnadigen",
    "begnadigtem": "begnadigt",
    "begnadigten": "begnadigen",
    "begnadigter": "begnadigt",
    "begnadigtes": "begnadigt",
    "begnadigtest": "begnadigen",
    "begnadigtet": "begnadigen",
    "begnüge": "begnügen",
    "begnügend": "begnügen",
    "begnügende": "begnügend",
    "begnügendem": "begnügend",
    "begnügenden": "begnügend",
    "begnügender": "begnügend",
    "begnügendes": "begnügend",
    "begnügest": "begnügen",
    "begnüget": "begnügen",
    "begnügst": "begnügen",
    "begnügt": "begnügen",
    "begnügte": "begnügen",
    "begnügtem": "begnügt",
    "begnügten": "begnügen",
    "begnügter": "begnügt",
    "begnügtes": "begnügt",
    "begnügtest": "begnügen",
    "begnügtet": "begnügen",
    "begonnen": "beginnen",
    "begonnene": "begonnen",
    "begonnenem": "begonnen",
    "begonnenen": "begonnen",
    "begonnener": "begonnen",
    "begonnenes": "begonnen",
    "begossen": "begießen",
    "begossene": "begossen",
    "begossenem": "begossen",
    "begossenen": "begossen",
    "begossener": "begossen",
    "begossenere": "begossen",
    "begossenerem": "begossen",
    "begosseneren": "begossen",
    "begossenerer": "begossen",
    "begosseneres": "begossen",
    "begossenes": "begossen",
    "begossenste": "begossen",
    "begossenstem": "begossen",
    "begossensten": "begossen",
    "begossenster": "begossen",
    "begossenstes": "begossen",
    "begoß": "begießen",
    "begoßt": "begießen",
    "begrabe": "begraben",
    "begrabend": "begraben",
    "begrabende": "begrabend",
    "begrabendem": "begrabend",
    "begrabenden": "begrabend",
    "begrabender": "begrabend",
    "begrabendes": "begrabend",
    "begrabene": "begraben",
    "begrabenem": "begraben",
    "begrabenen": "begraben",
    "begrabener": "begraben",
    "begrabenes": "begraben",
    "begrabest": "begraben",
    "begrabet": "begraben",
    "begrabsche": "begrabschen",
    "begrabschend": "begrabschen",
    "begrabschende": "begrabschend",
    "begrabschendem": "begrabschend",
    "begrabschenden": "begrabschend",
    "begrabschender": "begrabschend",
    "begrabschendere": "begrabschend",
    "begrabschenderem": "begrabschend",
    "begrabschenderen": "begrabschend",
    "begrabschenderer": "begrabschend",
    "begrabschenderes": "begrabschend",
    "begrabschendes": "begrabschend",
    "begrabschendste": "begrabschend",
    "begrabschendstem": "begrabschend",
    "begrabschendsten": "begrabschend",
    "begrabschendster": "begrabschend",
    "begrabschendstes": "begrabschend",
    "begrabschest": "begrabschen",
    "begrabschet": "begrabschen",
    "begrabschst": "begrabschen",
    "begrabscht": "begrabschen",
    "begrabschte": "begrabschen",
    "begrabschtem": "begrabscht",
    "begrabschten": "begrabschen",
    "begrabschter": "begrabscht",
    "begrabschtere": "begrabscht",
    "begrabschterem": "begrabscht",
    "begrabschteren": "begrabscht",
    "begrabschterer": "begrabscht",
    "begrabschteres": "begrabscht",
    "begrabschtes": "begrabscht",
    "begrabschtest": "begrabschen",
    "begrabschteste": "begrabscht",
    "begrabschtestem": "begrabscht",
    "begrabschtesten": "begrabscht",
    "begrabschtester": "begrabscht",
    "begrabschtestes": "begrabscht",
    "begrabschtet": "begrabschen",
    "begrabt": "begraben",
    "begradige": "begradigen",
    "begradigend": "begradigen",
    "begradigende": "begradigend",
    "begradigendem": "begradigend",
    "begradigenden": "begradigend",
    "begradigender": "begradigend",
    "begradigendes": "begradigend",
    "begradigest": "begradigen",
    "begradiget": "begradigen",
    "begradigst": "begradigen",
    "begradigt": "begradigen",
    "begradigte": "begradigen",
    "begradigtem": "begradigt",
    "begradigten": "begradigen",
    "begradigter": "begradigt",
    "begradigtes": "begradigt",
    "begradigtest": "begradigen",
    "begradigtet": "begradigen",
    "begreife": "begreifen",
    "begreifend": "begreifen",
    "begreifende": "begreifend",
    "begreifendem": "begreifend",
    "begreifenden": "begreifend",
    "begreifender": "begreifend",
    "begreifendes": "begreifend",
    "begreifest": "begreifen",
    "begreifet": "begreifen",
    "begreifliche": "begreiflich",
    "begreiflichem": "begreiflich",
    "begreiflichen": "begreiflich",
    "begreiflicher": "begreiflich",
    "begreifliches": "begreiflich",
    "begreifst": "begreifen",
    "begreift": "begreifen",
    "begrenze": "begrenzen",
    "begrenzend": "begrenzen",
    "begrenzende": "begrenzend",
    "begrenzendem": "begrenzend",
    "begrenzenden": "begrenzend",
    "begrenzender": "begrenzend",
    "begrenzendes": "begrenzend",
    "begrenzest": "begrenzen",
    "begrenzet": "begrenzen",
    "begrenzt": "begrenzen",
    "begrenzte": "begrenzen",
    "begrenztem": "begrenzt",
    "begrenzten": "begrenzen",
    "begrenzter": "begrenzt",
    "begrenztes": "begrenzt",
    "begrenztest": "begrenzen",
    "begrenztet": "begrenzen",
    "begriffe": "begreifen",
    "begriffenem": "begriffen",
    "begriffenen": "begriffen",
    "begriffener": "begriffen",
    "begriffenere": "begriffen",
    "begriffenerem": "begriffen",
    "begriffeneren": "begriffen",
    "begriffenerer": "begriffen",
    "begriffeneres": "begriffen",
    "begriffenes": "begriffen",
    "begriffenste": "begriffen",
    "begriffenstem": "begriffen",
    "begriffensten": "begriffen",
    "begriffenster": "begriffen",
    "begriffenstes": "begriffen",
    "begriffest": "begreifen",
    "begriffet": "begreifen",
    "begriffliche": "begrifflich",
    "begrifflichem": "begrifflich",
    "begrifflichen": "begrifflich",
    "begrifflicher": "begrifflich",
    "begriffliches": "begrifflich",
    "begriffst": "begreifen",
    "begrifft": "begreifen",
    "begrub": "begraben",
    "begruben": "begraben",
    "begrubst": "begraben",
    "begrubt": "begraben",
    "begräbst": "begraben",
    "begräbt": "begraben",
    "begrübe": "begraben",
    "begrüben": "begraben",
    "begrübest": "begraben",
    "begrübet": "begraben",
    "begründe": "begründen",
    "begründend": "begründen",
    "begründende": "begründend",
    "begründendem": "begründend",
    "begründenden": "begründend",
    "begründender": "begründend",
    "begründendes": "begründend",
    "begründest": "begründen",
    "begründet": "begründen",
    "begründete": "begründen",
    "begründetem": "begründet",
    "begründeten": "begründen",
    "begründeter": "begründet",
    "begründetere": "begründet",
    "begründeterem": "begründet",
    "begründeteren": "begründet",
    "begründeterer": "begründet",
    "begründeteres": "begründet",
    "begründetes": "begründet",
    "begründetest": "begründen",
    "begründeteste": "begründet",
    "begründetestem": "begründet",
    "begründetesten": "begründet",
    "begründetester": "begründet",
    "begründetestes": "begründet",
    "begründetet": "begründen",
    "begrüne": "begrünen",
    "begrünend": "begrünen",
    "begrünende": "begrünend",
    "begrünendem": "begrünend",
    "begrünenden": "begrünend",
    "begrünender": "begrünend",
    "begrünendere": "begrünend",
    "begrünenderem": "begrünend",
    "begrünenderen": "begrünend",
    "begrünenderer": "begrünend",
    "begrünenderes": "begrünend",
    "begrünendes": "begrünend",
    "begrünendste": "begrünend",
    "begrünendstem": "begrünend",
    "begrünendsten": "begrünend",
    "begrünendster": "begrünend",
    "begrünendstes": "begrünend",
    "begrünest": "begrünen",
    "begrünet": "begrünen",
    "begrünst": "begrünen",
    "begrünt": "begrünen",
    "begrünte": "begrünen",
    "begrüntem": "begrünt",
    "begrünten": "begrünen",
    "begrünter": "begrünt",
    "begrüntere": "begrünt",
    "begrünterem": "begrünt",
    "begrünteren": "begrünt",
    "begrünterer": "begrünt",
    "begrünteres": "begrünt",
    "begrüntes": "begrünt",
    "begrüntest": "begrünen",
    "begrünteste": "begrünt",
    "begrüntestem": "begrünt",
    "begrüntesten": "begrünt",
    "begrüntester": "begrünt",
    "begrüntestes": "begrünt",
    "begrüntet": "begrünen",
    "begrüße": "begrüßen",
    "begrüßend": "begrüßen",
    "begrüßende": "begrüßend",
    "begrüßendem": "begrüßend",
    "begrüßenden": "begrüßend",
    "begrüßender": "begrüßend",
    "begrüßendes": "begrüßend",
    "begrüßenswertem": "begrüßenswert",
    "begrüßenswerten": "begrüßenswert",
    "begrüßenswerter": "begrüßenswert",
    "begrüßenswertere": "begrüßenswert",
    "begrüßenswerterem": "begrüßenswert",
    "begrüßenswerteren": "begrüßenswert",
    "begrüßenswerterer": "begrüßenswert",
    "begrüßenswerteres": "begrüßenswert",
    "begrüßenswertes": "begrüßenswert",
    "begrüßenswerteste": "begrüßenswert",
    "begrüßenswertestem": "begrüßenswert",
    "begrüßenswertesten": "begrüßenswert",
    "begrüßenswertester": "begrüßenswert",
    "begrüßenswertestes": "begrüßenswert",
    "begrüßest": "begrüßen",
    "begrüßet": "begrüßen",
    "begrüßt": "begrüßen",
    "begrüßte": "begrüßen",
    "begrüßtem": "begrüßt",
    "begrüßten": "begrüßen",
    "begrüßter": "begrüßt",
    "begrüßtes": "begrüßt",
    "begrüßtest": "begrüßen",
    "begrüßtet": "begrüßen",
    "begucke": "begucken",
    "beguckend": "begucken",
    "beguckende": "beguckend",
    "beguckendem": "beguckend",
    "beguckenden": "beguckend",
    "beguckender": "beguckend",
    "beguckendes": "beguckend",
    "beguckest": "begucken",
    "begucket": "begucken",
    "beguckst": "begucken",
    "beguckt": "begucken",
    "beguckte": "begucken",
    "begucktem": "beguckt",
    "beguckten": "begucken",
    "beguckter": "beguckt",
    "begucktere": "beguckt",
    "beguckterem": "beguckt",
    "beguckteren": "beguckt",
    "beguckterer": "beguckt",
    "beguckteres": "beguckt",
    "begucktes": "beguckt",
    "begucktest": "begucken",
    "beguckteste": "beguckt",
    "begucktestem": "beguckt",
    "begucktesten": "beguckt",
    "begucktester": "beguckt",
    "begucktestes": "beguckt",
    "begucktet": "begucken",
    "begutachte": "begutachten",
    "begutachtend": "begutachten",
    "begutachtende": "begutachtend",
    "begutachtendem": "begutachtend",
    "begutachtenden": "begutachtend",
    "begutachtender": "begutachtend",
    "begutachtendes": "begutachtend",
    "begutachtest": "begutachten",
    "begutachtet": "begutachten",
    "begutachtete": "begutachten",
    "begutachtetem": "begutachtet",
    "begutachteten": "begutachten",
    "begutachteter": "begutachtet",
    "begutachtetes": "begutachtet",
    "begutachtetest": "begutachten",
    "begutachtetet": "begutachten",
    "begäbe": "begeben",
    "begäben": "begeben",
    "begäbest": "begeben",
    "begäbet": "begeben",
    "begänne": "beginnen",
    "begännen": "beginnen",
    "begännest": "beginnen",
    "begännet": "beginnen",
    "begösse": "begießen",
    "begössen": "begießen",
    "begössest": "begießen",
    "begösset": "begießen",
    "begünstige": "begünstigen",
    "begünstigend": "begünstigen",
    "begünstigende": "begünstigend",
    "begünstigendem": "begünstigend",
    "begünstigenden": "begünstigend",
    "begünstigender": "begünstigend",
    "begünstigendere": "begünstigend",
    "begünstigenderem": "begünstigend",
    "begünstigenderen": "begünstigend",
    "begünstigenderer": "begünstigend",
    "begünstigenderes": "begünstigend",
    "begünstigendes": "begünstigend",
    "begünstigendste": "begünstigend",
    "begünstigendstem": "begünstigend",
    "begünstigendsten": "begünstigend",
    "begünstigendster": "begünstigend",
    "begünstigendstes": "begünstigend",
    "begünstigest": "begünstigen",
    "begünstiget": "begünstigen",
    "begünstigst": "begünstigen",
    "begünstigt": "begünstigen",
    "begünstigte": "begünstigen",
    "begünstigtem": "begünstigt",
    "begünstigten": "begünstigen",
    "begünstigter": "begünstigt",
    "begünstigtere": "begünstigt",
    "begünstigterem": "begünstigt",
    "begünstigteren": "begünstigt",
    "begünstigterer": "begünstigt",
    "begünstigteres": "begünstigt",
    "begünstigtes": "begünstigt",
    "begünstigtest": "begünstigen",
    "begünstigteste": "begünstigt",
    "begünstigtestem": "begünstigt",
    "begünstigtesten": "begünstigt",
    "begünstigtester": "begünstigt",
    "begünstigtestes": "begünstigt",
    "begünstigtet": "begünstigen",
    "begütere": "begütern",
    "begüternd": "begütern",
    "begüternde": "begüternd",
    "begüterndem": "begüternd",
    "begüternden": "begüternd",
    "begüternder": "begüternd",
    "begüterndes": "begüternd",
    "begüterst": "begütern",
    "begütert": "begütern",
    "begüterte": "begütern",
    "begütertem": "begütert",
    "begüterten": "begütern",
    "begüterter": "begütert",
    "begütertere": "begütert",
    "begüterterem": "begütert",
    "begüterteren": "begütert",
    "begüterterer": "begütert",
    "begüterteres": "begütert",
    "begütertes": "begütert",
    "begütertest": "begütern",
    "begüterteste": "begütert",
    "begütertestem": "begütert",
    "begütertesten": "begütert",
    "begütertester": "begütert",
    "begütertestes": "begütert",
    "begütertet": "begütern",
    "behaarte": "behaart",
    "behaartem": "behaart",
    "behaarten": "behaart",
    "behaarter": "behaart",
    "behaartere": "behaart",
    "behaarterem": "behaart",
    "behaarteren": "behaart",
    "behaarterer": "behaart",
    "behaarteres": "behaart",
    "behaartes": "behaart",
    "behaarteste": "behaart",
    "behaartestem": "behaart",
    "behaartesten": "behaart",
    "behaartester": "behaart",
    "behaartestes": "behaart",
    "behafte": "behaften",
    "behaftend": "behaften",
    "behaftende": "behaftend",
    "behaftendem": "behaftend",
    "behaftenden": "behaftend",
    "behaftender": "behaftend",
    "behaftendes": "behaftend",
    "behaftest": "behaften",
    "behaftet": "behaften",
    "behaftete": "behaften",
    "behaftetem": "behaftet",
    "behafteten": "behaften",
    "behafteter": "behaftet",
    "behaftetes": "behaftet",
    "behaftetest": "behaften",
    "behaftetet": "behaften",
    "behage": "behagen",
    "behagend": "behagen",
    "behagende": "behagend",
    "behagendem": "behagend",
    "behagenden": "behagend",
    "behagender": "behagend",
    "behagendere": "behagend",
    "behagenderem": "behagend",
    "behagenderen": "behagend",
    "behagenderer": "behagend",
    "behagenderes": "behagend",
    "behagendes": "behagend",
    "behagendste": "behagend",
    "behagendstem": "behagend",
    "behagendsten": "behagend",
    "behagendster": "behagend",
    "behagendstes": "behagend",
    "behagest": "behagen",
    "behaget": "behagen",
    "behagliche": "behaglich",
    "behaglichem": "behaglich",
    "behaglichen": "behaglich",
    "behaglicher": "behaglich",
    "behaglichere": "behaglich",
    "behaglicherem": "behaglich",
    "behaglicheren": "behaglich",
    "behaglicherer": "behaglich",
    "behaglicheres": "behaglich",
    "behagliches": "behaglich",
    "behaglichste": "behaglich",
    "behaglichstem": "behaglich",
    "behaglichsten": "behaglich",
    "behaglichster": "behaglich",
    "behaglichstes": "behaglich",
    "behagst": "behagen",
    "behagt": "behagen",
    "behagte": "behagen",
    "behagtem": "behagt",
    "behagten": "behagen",
    "behagter": "behagt",
    "behagtes": "behagt",
    "behagtest": "behagen",
    "behagtet": "behagen",
    "behalf": "behelfen",
    "behalfen": "behelfen",
    "behalfst": "behelfen",
    "behalft": "behelfen",
    "behalte": "behalten",
    "behaltend": "behalten",
    "behaltende": "behaltend",
    "behaltendem": "behaltend",
    "behaltenden": "behaltend",
    "behaltender": "behaltend",
    "behaltendes": "behaltend",
    "behaltene": "behalten",
    "behaltenem": "behalten",
    "behaltenen": "behalten",
    "behaltener": "behalten",
    "behaltenes": "behalten",
    "behaltest": "behalten",
    "behaltet": "behalten",
    "behandele": "behandeln",
    "behandelnd": "behandeln",
    "behandelnde": "behandelnd",
    "behandelndem": "behandelnd",
    "behandelnden": "behandelnd",
    "behandelnder": "behandelnd",
    "behandelndes": "behandelnd",
    "behandelst": "behandeln",
    "behandelt": "behandeln",
    "behandelte": "behandeln",
    "behandeltem": "behandelt",
    "behandelten": "behandeln",
    "behandelter": "behandelt",
    "behandeltes": "behandelt",
    "behandeltest": "behandeln",
    "behandeltet": "behandeln",
    "behandle": "behandeln",
    "beharre": "beharren",
    "beharrend": "beharren",
    "beharrende": "beharrend",
    "beharrendem": "beharrend",
    "beharrenden": "beharrend",
    "beharrender": "beharrend",
    "beharrendes": "beharrend",
    "beharrest": "beharren",
    "beharret": "beharren",
    "beharrliche": "beharrlich",
    "beharrlichem": "beharrlich",
    "beharrlichen": "beharrlich",
    "beharrlicher": "beharrlich",
    "beharrlichere": "beharrlich",
    "beharrlicherem": "beharrlich",
    "beharrlicheren": "beharrlich",
    "beharrlicherer": "beharrlich",
    "beharrlicheres": "beharrlich",
    "beharrliches": "beharrlich",
    "beharrlichste": "beharrlich",
    "beharrlichstem": "beharrlich",
    "beharrlichsten": "beharrlich",
    "beharrlichster": "beharrlich",
    "beharrlichstes": "beharrlich",
    "beharrst": "beharren",
    "beharrt": "beharren",
    "beharrte": "beharren",
    "beharrtem": "beharrt",
    "beharrten": "beharren",
    "beharrter": "beharrt",
    "beharrtes": "beharrt",
    "beharrtest": "beharren",
    "beharrtet": "beharren",
    "behaue": "behauen",
    "behauend": "behauen",
    "behauende": "behauend",
    "behauendem": "behauend",
    "behauenden": "behauend",
    "behauender": "behauend",
    "behauendere": "behauend",
    "behauenderem": "behauend",
    "behauenderen": "behauend",
    "behauenderer": "behauend",
    "behauenderes": "behauend",
    "behauendes": "behauend",
    "behauendste": "behauend",
    "behauendstem": "behauend",
    "behauendsten": "behauend",
    "behauendster": "behauend",
    "behauendstes": "behauend",
    "behauene": "behauen",
    "behauenem": "behauen",
    "behauenen": "behauen",
    "behauener": "behauen",
    "behauenere": "behauen",
    "behauenerem": "behauen",
    "behaueneren": "behauen",
    "behauenerer": "behauen",
    "behaueneres": "behauen",
    "behauenes": "behauen",
    "behauenstem": "behauen",
    "behauensten": "behauen",
    "behauenster": "behauen",
    "behauenstes": "behauen",
    "behauest": "behauen",
    "behauet": "behauen",
    "behaupte": "behaupten",
    "behauptend": "behaupten",
    "behauptende": "behauptend",
    "behauptendem": "behauptend",
    "behauptenden": "behauptend",
    "behauptender": "behauptend",
    "behauptendes": "behauptend",
    "behauptest": "behaupten",
    "behauptet": "behaupten",
    "behauptete": "behaupten",
    "behauptetem": "behauptet",
    "behaupteten": "behaupten",
    "behaupteter": "behauptet",
    "behauptetes": "behauptet",
    "behauptetest": "behaupten",
    "behauptetet": "behaupten",
    "behause": "behausen",
    "behausend": "behausen",
    "behausende": "behausend",
    "behausendem": "behausend",
    "behausenden": "behausend",
    "behausender": "behausend",
    "behausendes": "behausend",
    "behausest": "behausen",
    "behauset": "behausen",
    "behaust": "behausen",
    "behauste": "behausen",
    "behaustem": "behaust",
    "behausten": "behausen",
    "behauster": "behaust",
    "behaustes": "behaust",
    "behaustest": "behausen",
    "behaustet": "behausen",
    "behaut": "behauen",
    "behaute": "behauen",
    "behauten": "behauen",
    "behautest": "behauen",
    "behautet": "behauen",
    "behebe": "beheben",
    "behebend": "beheben",
    "behebende": "behebend",
    "behebendem": "behebend",
    "behebenden": "behebend",
    "behebender": "behebend",
    "behebendes": "behebend",
    "behebest": "beheben",
    "behebet": "beheben",
    "behebst": "beheben",
    "behebt": "beheben",
    "beheimatetem": "beheimatet",
    "beheimateten": "beheimatet",
    "beheimateter": "beheimatet",
    "beheimatetere": "beheimatet",
    "beheimateterem": "beheimatet",
    "beheimateteren": "beheimatet",
    "beheimateterer": "beheimatet",
    "beheimateteres": "beheimatet",
    "beheimatetes": "beheimatet",
    "beheimateteste": "beheimatet",
    "beheimatetestem": "beheimatet",
    "beheimatetesten": "beheimatet",
    "beheimatetester": "beheimatet",
    "beheimatetestes": "beheimatet",
    "beheizbare": "beheizbar",
    "beheizbarem": "beheizbar",
    "beheizbaren": "beheizbar",
    "beheizbarer": "beheizbar",
    "beheizbares": "beheizbar",
    "beheize": "beheizen",
    "beheizend": "beheizen",
    "beheizende": "beheizend",
    "beheizendem": "beheizend",
    "beheizenden": "beheizend",
    "beheizender": "beheizend",
    "beheizendere": "beheizend",
    "beheizenderem": "beheizend",
    "beheizenderen": "beheizend",
    "beheizenderer": "beheizend",
    "beheizenderes": "beheizend",
    "beheizendes": "beheizend",
    "beheizendste": "beheizend",
    "beheizendstem": "beheizend",
    "beheizendsten": "beheizend",
    "beheizendster": "beheizend",
    "beheizendstes": "beheizend",
    "beheizest": "beheizen",
    "beheizet": "beheizen",
    "beheizt": "beheizen",
    "beheizte": "beheizen",
    "beheiztem": "beheizt",
    "beheizten": "beheizen",
    "beheizter": "beheizt",
    "beheiztere": "beheizt",
    "beheizterem": "beheizt",
    "beheizteren": "beheizt",
    "beheizterer": "beheizt",
    "beheizteres": "beheizt",
    "beheiztes": "beheizt",
    "beheiztest": "beheizen",
    "beheizteste": "beheizt",
    "beheiztestem": "beheizt",
    "beheiztesten": "beheizt",
    "beheiztester": "beheizt",
    "beheiztestes": "beheizt",
    "beheiztet": "beheizen",
    "behelfend": "behelfen",
    "behelfende": "behelfend",
    "behelfendem": "behelfend",
    "behelfenden": "behelfend",
    "behelfender": "behelfend",
    "behelfendes": "behelfend",
    "behelfest": "behelfen",
    "behelfet": "behelfen",
    "behelfsmäßigem": "behelfsmäßig",
    "behelfsmäßigen": "behelfsmäßig",
    "behelfsmäßiger": "behelfsmäßig",
    "behelfsmäßiges": "behelfsmäßig",
    "behelft": "behelfen",
    "behellige": "behelligen",
    "behelligend": "behelligen",
    "behelligende": "behelligend",
    "behelligendem": "behelligend",
    "behelligenden": "behelligend",
    "behelligender": "behelligend",
    "behelligendes": "behelligend",
    "behelligest": "behelligen",
    "behelliget": "behelligen",
    "behelligst": "behelligen",
    "behelligt": "behelligen",
    "behelligte": "behelligen",
    "behelligtem": "behelligt",
    "behelligten": "behelligen",
    "behelligter": "behelligt",
    "behelligtes": "behelligt",
    "behelligtest": "behelligen",
    "behelligtet": "behelligen",
    "beherberge": "beherbergen",
    "beherbergend": "beherbergen",
    "beherbergende": "beherbergend",
    "beherbergendem": "beherbergend",
    "beherbergenden": "beherbergend",
    "beherbergender": "beherbergend",
    "beherbergendes": "beherbergend",
    "beherbergest": "beherbergen",
    "beherberget": "beherbergen",
    "beherbergst": "beherbergen",
    "beherbergt": "beherbergen",
    "beherbergte": "beherbergen",
    "beherbergtem": "beherbergt",
    "beherbergten": "beherbergen",
    "beherbergter": "beherbergt",
    "beherbergtes": "beherbergt",
    "beherbergtest": "beherbergen",
    "beherbergtet": "beherbergen",
    "beherrschbare": "beherrschbar",
    "beherrschbarem": "beherrschbar",
    "beherrschbaren": "beherrschbar",
    "beherrschbarer": "beherrschbar",
    "beherrschbarere": "beherrschbar",
    "beherrschbarerem": "beherrschbar",
    "beherrschbareren": "beherrschbar",
    "beherrschbarerer": "beherrschbar",
    "beherrschbareres": "beherrschbar",
    "beherrschbares": "beherrschbar",
    "beherrschbarste": "beherrschbar",
    "beherrschbarstem": "beherrschbar",
    "beherrschbarsten": "beherrschbar",
    "beherrschbarster": "beherrschbar",
    "beherrschbarstes": "beherrschbar",
    "beherrsche": "beherrschen",
    "beherrschend": "beherrschen",
    "beherrschende": "beherrschend",
    "beherrschendem": "beherrschend",
    "beherrschenden": "beherrschend",
    "beherrschender": "beherrschend",
    "beherrschendere": "beherrschend",
    "beherrschenderem": "beherrschend",
    "beherrschenderen": "beherrschend",
    "beherrschenderer": "beherrschend",
    "beherrschenderes": "beherrschend",
    "beherrschendes": "beherrschend",
    "beherrschendste": "beherrschend",
    "beherrschendstem": "beherrschend",
    "beherrschendsten": "beherrschend",
    "beherrschendster": "beherrschend",
    "beherrschendstes": "beherrschend",
    "beherrschest": "beherrschen",
    "beherrschet": "beherrschen",
    "beherrschst": "beherrschen",
    "beherrscht": "beherrschen",
    "beherrschte": "beherrschen",
    "beherrschtem": "beherrscht",
    "beherrschten": "beherrschen",
    "beherrschter": "beherrscht",
    "beherrschtere": "beherrscht",
    "beherrschterem": "beherrscht",
    "beherrschteren": "beherrscht",
    "beherrschterer": "beherrscht",
    "beherrschteres": "beherrscht",
    "beherrschtes": "beherrscht",
    "beherrschtest": "beherrschen",
    "beherrschteste": "beherrscht",
    "beherrschtestem": "beherrscht",
    "beherrschtesten": "beherrscht",
    "beherrschtester": "beherrscht",
    "beherrschtestes": "beherrscht",
    "beherrschtet": "beherrschen",
    "beherzige": "beherzigen",
    "beherzigend": "beherzigen",
    "beherzigende": "beherzigend",
    "beherzigendem": "beherzigend",
    "beherzigenden": "beherzigend",
    "beherzigender": "beherzigend",
    "beherzigendes": "beherzigend",
    "beherzigest": "beherzigen",
    "beherziget": "beherzigen",
    "beherzigst": "beherzigen",
    "beherzigt": "beherzigen",
    "beherzigte": "beherzigen",
    "beherzigtem": "beherzigt",
    "beherzigten": "beherzigen",
    "beherzigter": "beherzigt",
    "beherzigtes": "beherzigt",
    "beherzigtest": "beherzigen",
    "beherzigtet": "beherzigen",
    "beherzte": "beherzt",
    "beherztem": "beherzt",
    "beherzten": "beherzt",
    "beherzter": "beherzt",
    "beherztere": "beherzt",
    "beherzterem": "beherzt",
    "beherzteren": "beherzt",
    "beherzterer": "beherzt",
    "beherzteres": "beherzt",
    "beherztes": "beherzt",
    "beherzteste": "beherzt",
    "beherztestem": "beherzt",
    "beherztesten": "beherzt",
    "beherztester": "beherzt",
    "beherztestes": "beherzt",
    "behielt": "behalten",
    "behielte": "behalten",
    "behielten": "behalten",
    "behieltest": "behalten",
    "behieltet": "behalten",
    "behilf": "behelfen",
    "behilfliche": "behilflich",
    "behilflichem": "behilflich",
    "behilflichen": "behilflich",
    "behilflicher": "behilflich",
    "behilfliches": "behilflich",
    "behilfst": "behelfen",
    "behilft": "behelfen",
    "behindere": "behindern",
    "behindernd": "behindern",
    "behindernde": "behindernd",
    "behinderndem": "behindernd",
    "behindernden": "behindernd",
    "behindernder": "behindernd",
    "behinderndes": "behindernd",
    "behinderst": "behindern",
    "behindert": "behindern",
    "behinderte": "behindern",
    "behindertem": "behindert",
    "behinderten": "behindern",
    "behinderter": "behindert",
    "behindertere": "behindert",
    "behinderterem": "behindert",
    "behinderteren": "behindert",
    "behinderterer": "behindert",
    "behinderteres": "behindert",
    "behindertes": "behindert",
    "behindertest": "behindern",
    "behinderteste": "behindert",
    "behindertestem": "behindert",
    "behindertesten": "behindert",
    "behindertester": "behindert",
    "behindertestes": "behindert",
    "behindertet": "behindern",
    "behob": "beheben",
    "behoben": "beheben",
    "behobene": "behoben",
    "behobenem": "behoben",
    "behobenen": "behoben",
    "behobener": "behoben",
    "behobenes": "behoben",
    "behobst": "beheben",
    "behobt": "beheben",
    "beholfen": "behelfen",
    "beholfene": "beholfen",
    "beholfenem": "beholfen",
    "beholfenen": "beholfen",
    "beholfener": "beholfen",
    "beholfenere": "beholfen",
    "beholfenerem": "beholfen",
    "beholfeneren": "beholfen",
    "beholfenerer": "beholfen",
    "beholfeneres": "beholfen",
    "beholfenes": "beholfen",
    "beholfenste": "beholfen",
    "beholfenstem": "beholfen",
    "beholfensten": "beholfen",
    "beholfenster": "beholfen",
    "beholfenstes": "beholfen",
    "behutsame": "behutsam",
    "behutsamem": "behutsam",
    "behutsamen": "behutsam",
    "behutsamer": "behutsam",
    "behutsamere": "behutsam",
    "behutsamerem": "behutsam",
    "behutsameren": "behutsam",
    "behutsamerer": "behutsam",
    "behutsameres": "behutsam",
    "behutsames": "behutsam",
    "behutsamste": "behutsam",
    "behutsamstem": "behutsam",
    "behutsamsten": "behutsam",
    "behutsamster": "behutsam",
    "behutsamstes": "behutsam",
    "behäbige": "behäbig",
    "behäbigem": "behäbig",
    "behäbigen": "behäbig",
    "behäbiger": "behäbig",
    "behäbigere": "behäbig",
    "behäbigerem": "behäbig",
    "behäbigeren": "behäbig",
    "behäbigerer": "behäbig",
    "behäbigeres": "behäbig",
    "behäbiges": "behäbig",
    "behäbigste": "behäbig",
    "behäbigstem": "behäbig",
    "behäbigsten": "behäbig",
    "behäbigster": "behäbig",
    "behäbigstes": "behäbig",
    "behälfe": "behelfen",
    "behälfen": "behelfen",
    "behälfest": "behelfen",
    "behälfet": "behelfen",
    "behält": "behalten",
    "behältst": "behalten",
    "behämmerte": "behämmert",
    "behämmertem": "behämmert",
    "behämmerten": "behämmert",
    "behämmerter": "behämmert",
    "behämmertere": "behämmert",
    "behämmerterem": "behämmert",
    "behämmerteren": "behämmert",
    "behämmerterer": "behämmert",
    "behämmerteres": "behämmert",
    "behämmertes": "behämmert",
    "behämmerteste": "behämmert",
    "behämmertestem": "behämmert",
    "behämmertesten": "behämmert",
    "behämmertester": "behämmert",
    "behämmertestes": "behämmert",
    "behängend": "behängen",
    "behängende": "behängend",
    "behängendem": "behängend",
    "behängenden": "behängend",
    "behängender": "behängend",
    "behängendes": "behängend",
    "behängest": "behängen",
    "behänget": "behängen",
    "behängst": "behängen",
    "behängt": "behängen",
    "behängte": "behängen",
    "behängtem": "behängt",
    "behängten": "behängen",
    "behängter": "behängt",
    "behängtes": "behängt",
    "behängtest": "behängen",
    "behängtet": "behängen",
    "behöbe": "beheben",
    "behöben": "beheben",
    "behöbest": "beheben",
    "behöbet": "beheben",
    "behüte": "behüten",
    "behütend": "behüten",
    "behütende": "behütend",
    "behütendem": "behütend",
    "behütenden": "behütend",
    "behütender": "behütend",
    "behütendere": "behütend",
    "behütenderem": "behütend",
    "behütenderen": "behütend",
    "behütenderer": "behütend",
    "behütenderes": "behütend",
    "behütendes": "behütend",
    "behütendste": "behütend",
    "behütendstem": "behütend",
    "behütendsten": "behütend",
    "behütendster": "behütend",
    "behütendstes": "behütend",
    "behütest": "behüten",
    "behütet": "behüten",
    "behütete": "behüten",
    "behütetem": "behütet",
    "behüteten": "behüten",
    "behüteter": "behütet",
    "behütetere": "behütet",
    "behüteterem": "behütet",
    "behüteteren": "behütet",
    "behüteterer": "behütet",
    "behüteteres": "behütet",
    "behütetes": "behütet",
    "behütetest": "behüten",
    "behüteteste": "behütet",
    "behütetestem": "behütet",
    "behütetesten": "behütet",
    "behütetester": "behütet",
    "behütetestes": "behütet",
    "behütetet": "behüten",
    "beibehalte": "beibehalten",
    "beibehaltend": "beibehalten",
    "beibehaltende": "beibehaltend",
    "beibehaltendem": "beibehaltend",
    "beibehaltenden": "beibehaltend",
    "beibehaltender": "beibehaltend",
    "beibehaltendes": "beibehaltend",
    "beibehaltene": "beibehalten",
    "beibehaltenem": "beibehalten",
    "beibehaltenen": "beibehalten",
    "beibehaltener": "beibehalten",
    "beibehaltenes": "beibehalten",
    "beibehaltest": "beibehalten",
    "beibehaltet": "beibehalten",
    "beibehielt": "beibehalten",
    "beibehielte": "beibehalten",
    "beibehielten": "beibehalten",
    "beibehieltest": "beibehalten",
    "beibehieltet": "beibehalten",
    "beibehält": "beibehalten",
    "beibehältst": "beibehalten",
    "beibiege": "beibiegen",
    "beibiegend": "beibiegen",
    "beibiegende": "beibiegend",
    "beibiegendem": "beibiegend",
    "beibiegenden": "beibiegend",
    "beibiegender": "beibiegend",
    "beibiegendes": "beibiegend",
    "beibiegest": "beibiegen",
    "beibieget": "beibiegen",
    "beibiegst": "beibiegen",
    "beibiegt": "beibiegen",
    "beibog": "beibiegen",
    "beibogen": "beibiegen",
    "beibogst": "beibiegen",
    "beibogt": "beibiegen",
    "beibrachte": "beibringen",
    "beibrachten": "beibringen",
    "beibrachtest": "beibringen",
    "beibrachtet": "beibringen",
    "beibringe": "beibringen",
    "beibringend": "beibringen",
    "beibringende": "beibringend",
    "beibringendem": "beibringend",
    "beibringenden": "beibringend",
    "beibringender": "beibringend",
    "beibringendes": "beibringend",
    "beibringest": "beibringen",
    "beibringet": "beibringen",
    "beibringst": "beibringen",
    "beibringt": "beibringen",
    "beibrächte": "beibringen",
    "beibrächten": "beibringen",
    "beibrächtest": "beibringen",
    "beibrächtet": "beibringen",
    "beiböge": "beibiegen",
    "beibögen": "beibiegen",
    "beibögest": "beibiegen",
    "beiböget": "beibiegen",
    "beichte": "beichten",
    "beichtend": "beichten",
    "beichtende": "beichtend",
    "beichtendem": "beichtend",
    "beichtenden": "beichtend",
    "beichtender": "beichtend",
    "beichtendere": "beichtend",
    "beichtenderem": "beichtend",
    "beichtenderen": "beichtend",
    "beichtenderer": "beichtend",
    "beichtenderes": "beichtend",
    "beichtendes": "beichtend",
    "beichtendste": "beichtend",
    "beichtendstem": "beichtend",
    "beichtendsten": "beichtend",
    "beichtendster": "beichtend",
    "beichtendstes": "beichtend",
    "beichtest": "beichten",
    "beichtet": "beichten",
    "beichtete": "beichten",
    "beichteten": "beichten",
    "beichtetest": "beichten",
    "beichtetet": "beichten",
    "beide": "beid",
    "beiden": "beid",
    "beider": "beid",
    "beiderseitige": "beiderseitig",
    "beiderseitigem": "beiderseitig",
    "beiderseitigen": "beiderseitig",
    "beiderseitiger": "beiderseitig",
    "beiderseitiges": "beiderseitig",
    "beides": "beide",
    "beidhändigem": "beidhändig",
    "beidhändigen": "beidhändig",
    "beidhändiger": "beidhändig",
    "beidhändiges": "beidhändig",
    "beidrehe": "beidrehen",
    "beidrehend": "beidrehen",
    "beidrehende": "beidrehend",
    "beidrehendem": "beidrehend",
    "beidrehenden": "beidrehend",
    "beidrehender": "beidrehend",
    "beidrehendes": "beidrehend",
    "beidrehest": "beidrehen",
    "beidrehet": "beidrehen",
    "beidrehst": "beidrehen",
    "beidreht": "beidrehen",
    "beidrehte": "beidrehen",
    "beidrehten": "beidrehen",
    "beidrehtest": "beidrehen",
    "beidrehtet": "beidrehen",
    "beidseitige": "beidseitig",
    "beidseitigem": "beidseitig",
    "beidseitigen": "beidseitig",
    "beidseitiger": "beidseitig",
    "beidseitiges": "beidseitig",
    "beifolge": "beifolgen",
    "beifolgend": "beifolgen",
    "beifolgende": "beifolgend",
    "beifolgendem": "beifolgend",
    "beifolgenden": "beifolgend",
    "beifolgender": "beifolgend",
    "beifolgendes": "beifolgend",
    "beifolgest": "beifolgen",
    "beifolget": "beifolgen",
    "beifolgst": "beifolgen",
    "beifolgt": "beifolgen",
    "beifolgte": "beifolgen",
    "beifolgten": "beifolgen",
    "beifolgtest": "beifolgen",
    "beifolgtet": "beifolgen",
    "beifüge": "beifügen",
    "beifügend": "beifügen",
    "beifügende": "beifügend",
    "beifügendem": "beifügend",
    "beifügenden": "beifügend",
    "beifügender": "beifügend",
    "beifügendes": "beifügend",
    "beifügest": "beifügen",
    "beifüget": "beifügen",
    "beifügst": "beifügen",
    "beifügt": "beifügen",
    "beifügte": "beifügen",
    "beifügten": "beifügen",
    "beifügtest": "beifügen",
    "beifügtet": "beifügen",
    "beigab": "beigeben",
    "beigabst": "beigeben",
    "beigabt": "beigeben",
    "beigebe": "beigeben",
    "beigebend": "beigeben",
    "beigebende": "beigebend",
    "beigebendem": "beigebend",
    "beigebenden": "beigebend",
    "beigebender": "beigebend",
    "beigebendes": "beigebend",
    "beigebest": "beigeben",
    "beigebet": "beigeben",
    "beigebogen": "beibiegen",
    "beigebogene": "beigebogen",
    "beigebogenem": "beigebogen",
    "beigebogenen": "beigebogen",
    "beigebogener": "beigebogen",
    "beigebogenes": "beigebogen",
    "beigebracht": "beibringen",
    "beigebrachte": "beigebracht",
    "beigebrachtem": "beigebracht",
    "beigebrachten": "beigebracht",
    "beigebrachter": "beigebracht",
    "beigebrachtes": "beigebracht",
    "beigebt": "beigeben",
    "beigedreht": "beidrehen",
    "beigedrehte": "beigedreht",
    "beigedrehtem": "beigedreht",
    "beigedrehten": "beigedreht",
    "beigedrehter": "beigedreht",
    "beigedrehtes": "beigedreht",
    "beigefolgt": "beifolgen",
    "beigefolgte": "beigefolgt",
    "beigefolgtem": "beigefolgt",
    "beigefolgten": "beigefolgt",
    "beigefolgter": "beigefolgt",
    "beigefolgtes": "beigefolgt",
    "beigefügt": "beifügen",
    "beigefügte": "beigefügt",
    "beigefügtem": "beigefügt",
    "beigefügten": "beigefügt",
    "beigefügter": "beigefügt",
    "beigefügtes": "beigefügt",
    "beigegeben": "beigeben",
    "beigegebene": "beigegeben",
    "beigegebenem": "beigegeben",
    "beigegebenen": "beigegeben",
    "beigegebener": "beigegeben",
    "beigegebenes": "beigegeben",
    "beigeholt": "beiholen",
    "beigeholte": "beigeholt",
    "beigeholtem": "beigeholt",
    "beigeholten": "beigeholt",
    "beigeholter": "beigeholt",
    "beigeholtes": "beigeholt",
    "beigekommen": "beikommen",
    "beigekommene": "beigekommen",
    "beigekommenem": "beigekommen",
    "beigekommenen": "beigekommen",
    "beigekommener": "beigekommen",
    "beigekommenes": "beigekommen",
    "beigeladen": "beiladen",
    "beigeladene": "beigeladen",
    "beigeladenem": "beigeladen",
    "beigeladenen": "beigeladen",
    "beigeladener": "beigeladen",
    "beigeladenes": "beigeladen",
    "beigelegen": "beiliegen",
    "beigelegene": "beigelegen",
    "beigelegenem": "beigelegen",
    "beigelegenen": "beigelegen",
    "beigelegener": "beigelegen",
    "beigelegenes": "beigelegen",
    "beigelegt": "beilegen",
    "beigelegte": "beigelegt",
    "beigelegtem": "beigelegt",
    "beigelegten": "beigelegt",
    "beigelegter": "beigelegt",
    "beigelegtes": "beigelegt",
    "beigemengt": "beimengen",
    "beigemengte": "beigemengt",
    "beigemengtem": "beigemengt",
    "beigemengten": "beigemengt",
    "beigemengter": "beigemengt",
    "beigemengtes": "beigemengt",
    "beigemessen": "beimessen",
    "beigemessene": "beigemessen",
    "beigemessenem": "beigemessen",
    "beigemessenen": "beigemessen",
    "beigemessener": "beigemessen",
    "beigemessenes": "beigemessen",
    "beigemischt": "beimischen",
    "beigemischte": "beigemischt",
    "beigemischtem": "beigemischt",
    "beigemischten": "beigemischt",
    "beigemischter": "beigemischt",
    "beigemischtes": "beigemischt",
    "beigeordnet": "beiordnen",
    "beigeordnete": "beigeordnet",
    "beigeordnetem": "beigeordnet",
    "beigeordneten": "beigeordnet",
    "beigeordneter": "beigeordnet",
    "beigeordnetes": "beigeordnet",
    "beigepflichtet": "beipflichten",
    "beigepflichtete": "beigepflichtet",
    "beigepflichtetem": "beigepflichtet",
    "beigepflichteten": "beigepflichtet",
    "beigepflichteter": "beigepflichtet",
    "beigepflichtetes": "beigepflichtet",
    "beigeschaffen": "beischaffen",
    "beigeschaffene": "beigeschaffen",
    "beigeschaffenem": "beigeschaffen",
    "beigeschaffenen": "beigeschaffen",
    "beigeschaffener": "beigeschaffen",
    "beigeschaffenes": "beigeschaffen",
    "beigeschafft": "beischaffen",
    "beigeschaffte": "beigeschafft",
    "beigeschafftem": "beigeschafft",
    "beigeschafften": "beigeschafft",
    "beigeschaffter": "beigeschafft",
    "beigeschafftes": "beigeschafft",
    "beigeselle": "beigesellen",
    "beigesellend": "beigesellen",
    "beigesellende": "beigesellend",
    "beigesellendem": "beigesellend",
    "beigesellenden": "beigesellend",
    "beigesellender": "beigesellend",
    "beigesellendes": "beigesellend",
    "beigesellest": "beigesellen",
    "beigesellet": "beigesellen",
    "beigesellst": "beigesellen",
    "beigesellt": "beigesellen",
    "beigesellte": "beigesellen",
    "beigeselltem": "beigesellt",
    "beigesellten": "beigesellen",
    "beigesellter": "beigesellt",
    "beigeselltes": "beigesellt",
    "beigeselltest": "beigesellen",
    "beigeselltet": "beigesellen",
    "beigesessen": "beisitzen",
    "beigesessene": "beigesessen",
    "beigesessenem": "beigesessen",
    "beigesessenen": "beigesessen",
    "beigesessener": "beigesessen",
    "beigesessenes": "beigesessen",
    "beigesetzt": "beisetzen",
    "beigesetzte": "beigesetzt",
    "beigesetztem": "beigesetzt",
    "beigesetzten": "beigesetzt",
    "beigesetzter": "beigesetzt",
    "beigesetztes": "beigesetzt",
    "beigesprungen": "beispringen",
    "beigesprungene": "beigesprungen",
    "beigesprungenem": "beigesprungen",
    "beigesprungenen": "beigesprungen",
    "beigesprungener": "beigesprungen",
    "beigesprungenes": "beigesprungen",
    "beigestanden": "beistehen",
    "beigestandene": "beigestanden",
    "beigestandenem": "beigestanden",
    "beigestandenen": "beigestanden",
    "beigestandener": "beigestanden",
    "beigestandenes": "beigestanden",
    "beigestimmt": "beistimmen",
    "beigestimmte": "beigestimmt",
    "beigestimmtem": "beigestimmt",
    "beigestimmten": "beigestimmt",
    "beigestimmter": "beigestimmt",
    "beigestimmtes": "beigestimmt",
    "beigetragen": "beitragen",
    "beigetragene": "beigetragen",
    "beigetragenem": "beigetragen",
    "beigetragenen": "beigetragen",
    "beigetragener": "beigetragen",
    "beigetragenes": "beigetragen",
    "beigetreten": "beitreten",
    "beigetretene": "beigetreten",
    "beigetretenem": "beigetreten",
    "beigetretenen": "beigetreten",
    "beigetretener": "beigetreten",
    "beigetretenes": "beigetreten",
    "beigewohnt": "beiwohnen",
    "beigewohnte": "beigewohnt",
    "beigewohntem": "beigewohnt",
    "beigewohnten": "beigewohnt",
    "beigewohnter": "beigewohnt",
    "beigewohntes": "beigewohnt",
    "beigibst": "beigeben",
    "beigibt": "beigeben",
    "beigäbe": "beigeben",
    "beigäben": "beigeben",
    "beigäbest": "beigeben",
    "beigäbet": "beigeben",
    "beihole": "beiholen",
    "beiholend": "beiholen",
    "beiholende": "beiholend",
    "beiholendem": "beiholend",
    "beiholenden": "beiholend",
    "beiholender": "beiholend",
    "beiholendes": "beiholend",
    "beiholest": "beiholen",
    "beiholet": "beiholen",
    "beiholst": "beiholen",
    "beiholt": "beiholen",
    "beiholte": "beiholen",
    "beiholten": "beiholen",
    "beiholtest": "beiholen",
    "beiholtet": "beiholen",
    "beikam": "beikommen",
    "beikamen": "beikommen",
    "beikamst": "beikommen",
    "beikamt": "beikommen",
    "beikomme": "beikommen",
    "beikommend": "beikommen",
    "beikommende": "beikommend",
    "beikommendem": "beikommend",
    "beikommenden": "beikommend",
    "beikommender": "beikommend",
    "beikommendes": "beikommend",
    "beikommest": "beikommen",
    "beikommet": "beikommen",
    "beikommst": "beikommen",
    "beikommt": "beikommen",
    "beikäme": "beikommen",
    "beikämen": "beikommen",
    "beikämest": "beikommen",
    "beikämet": "beikommen",
    "beilade": "beiladen",
    "beiladend": "beiladen",
    "beiladende": "beiladend",
    "beiladendem": "beiladend",
    "beiladenden": "beiladend",
    "beiladender": "beiladend",
    "beiladendes": "beiladend",
    "beiladest": "beiladen",
    "beiladet": "beiladen",
    "beilag": "beiliegen",
    "beilagst": "beiliegen",
    "beilagt": "beiliegen",
    "beilege": "beilegen",
    "beilegend": "beilegen",
    "beilegende": "beilegend",
    "beilegendem": "beilegend",
    "beilegenden": "beilegend",
    "beilegender": "beilegend",
    "beilegendes": "beilegend",
    "beilegest": "beilegen",
    "beileget": "beilegen",
    "beilegst": "beilegen",
    "beilegt": "beilegen",
    "beilegte": "beilegen",
    "beilegten": "beilegen",
    "beilegtest": "beilegen",
    "beilegtet": "beilegen",
    "beiliege": "beiliegen",
    "beiliegend": "beiliegen",
    "beiliegende": "beiliegend",
    "beiliegendem": "beiliegend",
    "beiliegenden": "beiliegend",
    "beiliegender": "beiliegend",
    "beiliegendes": "beiliegend",
    "beiliegest": "beiliegen",
    "beilieget": "beiliegen",
    "beiliegst": "beiliegen",
    "beiliegt": "beiliegen",
    "beilud": "beiladen",
    "beiluden": "beiladen",
    "beiludest": "beiladen",
    "beiludet": "beiladen",
    "beilädst": "beiladen",
    "beilädt": "beiladen",
    "beiläge": "beiliegen",
    "beilägen": "beiliegen",
    "beilägest": "beiliegen",
    "beiläget": "beiliegen",
    "beiläufige": "beiläufig",
    "beiläufigem": "beiläufig",
    "beiläufigen": "beiläufig",
    "beiläufiger": "beiläufig",
    "beiläufiges": "beiläufig",
    "beilüde": "beiladen",
    "beilüden": "beiladen",
    "beilüdest": "beiladen",
    "beilüdet": "beiladen",
    "beimaß": "beimessen",
    "beimaßen": "beimessen",
    "beimaßt": "beimessen",
    "beimenge": "beimengen",
    "beimengend": "beimengen",
    "beimengende": "beimengend",
    "beimengendem": "beimengend",
    "beimengenden": "beimengend",
    "beimengender": "beimengend",
    "beimengendes": "beimengend",
    "beimengest": "beimengen",
    "beimenget": "beimengen",
    "beimengst": "beimengen",
    "beimengt": "beimengen",
    "beimengte": "beimengen",
    "beimengten": "beimengen",
    "beimengtest": "beimengen",
    "beimengtet": "beimengen",
    "beimesse": "beimessen",
    "beimessend": "beimessen",
    "beimessende": "beimessend",
    "beimessendem": "beimessend",
    "beimessenden": "beimessend",
    "beimessender": "beimessend",
    "beimessendes": "beimessend",
    "beimessest": "beimessen",
    "beimesset": "beimessen",
    "beimeßt": "beimessen",
    "beimische": "beimischen",
    "beimischend": "beimischen",
    "beimischende": "beimischend",
    "beimischendem": "beimischend",
    "beimischenden": "beimischend",
    "beimischender": "beimischend",
    "beimischendes": "beimischend",
    "beimischest": "beimischen",
    "beimischet": "beimischen",
    "beimischst": "beimischen",
    "beimischt": "beimischen",
    "beimischte": "beimischen",
    "beimischten": "beimischen",
    "beimischtest": "beimischen",
    "beimischtet": "beimischen",
    "beimißt": "beimessen",
    "beimäße": "beimessen",
    "beimäßen": "beimessen",
    "beimäßest": "beimessen",
    "beimäßet": "beimessen",
    "beinhalte": "beinhalten",
    "beinhaltend": "beinhalten",
    "beinhaltende": "beinhaltend",
    "beinhaltendem": "beinhaltend",
    "beinhaltenden": "beinhaltend",
    "beinhaltender": "beinhaltend",
    "beinhaltendes": "beinhaltend",
    "beinhaltest": "beinhalten",
    "beinhaltet": "beinhalten",
    "beinhaltete": "beinhalten",
    "beinhaltetem": "beinhaltet",
    "beinhalteten": "beinhalten",
    "beinhalteter": "beinhaltet",
    "beinhaltetes": "beinhaltet",
    "beinhaltetest": "beinhalten",
    "beinhaltetet": "beinhalten",
    "beinhartem": "beinhart",
    "beinharten": "beinhart",
    "beinharter": "beinhart",
    "beinhartes": "beinhart",
    "beinhärter": "beinhart",
    "beinhärtere": "beinhart",
    "beinhärterem": "beinhart",
    "beinhärteren": "beinhart",
    "beinhärterer": "beinhart",
    "beinhärteres": "beinhart",
    "beinhärteste": "beinhart",
    "beinhärtestem": "beinhart",
    "beinhärtesten": "beinhart",
    "beinhärtester": "beinhart",
    "beinhärtestes": "beinhart",
    "beiordne": "beiordnen",
    "beiordnend": "beiordnen",
    "beiordnende": "beiordnend",
    "beiordnendem": "beiordnend",
    "beiordnenden": "beiordnend",
    "beiordnender": "beiordnend",
    "beiordnendes": "beiordnend",
    "beiordnest": "beiordnen",
    "beiordnet": "beiordnen",
    "beiordnete": "beiordnen",
    "beiordneten": "beiordnen",
    "beiordnetest": "beiordnen",
    "beiordnetet": "beiordnen",
    "beipflichte": "beipflichten",
    "beipflichtend": "beipflichten",
    "beipflichtende": "beipflichtend",
    "beipflichtendem": "beipflichtend",
    "beipflichtenden": "beipflichtend",
    "beipflichtender": "beipflichtend",
    "beipflichtendes": "beipflichtend",
    "beipflichtest": "beipflichten",
    "beipflichtet": "beipflichten",
    "beipflichtete": "beipflichten",
    "beipflichteten": "beipflichten",
    "beipflichtetest": "beipflichten",
    "beipflichtetet": "beipflichten",
    "beirre": "beirren",
    "beirrend": "beirren",
    "beirrende": "beirrend",
    "beirrendem": "beirrend",
    "beirrenden": "beirrend",
    "beirrender": "beirrend",
    "beirrendes": "beirrend",
    "beirrest": "beirren",
    "beirret": "beirren",
    "beirrst": "beirren",
    "beirrt": "beirren",
    "beirrte": "beirren",
    "beirrtem": "beirrt",
    "beirrten": "beirren",
    "beirrter": "beirrt",
    "beirrtes": "beirrt",
    "beirrtest": "beirren",
    "beirrtet": "beirren",
    "beisaß": "beisitzen",
    "beisaßen": "beisitzen",
    "beisaßt": "beisitzen",
    "beischaffe": "beischaffen",
    "beischaffend": "beischaffen",
    "beischaffende": "beischaffend",
    "beischaffendem": "beischaffend",
    "beischaffenden": "beischaffend",
    "beischaffender": "beischaffend",
    "beischaffendes": "beischaffend",
    "beischaffest": "beischaffen",
    "beischaffet": "beischaffen",
    "beischaffst": "beischaffen",
    "beischafft": "beischaffen",
    "beischaffte": "beischaffen",
    "beischafften": "beischaffen",
    "beischafftest": "beischaffen",
    "beischafftet": "beischaffen",
    "beischuf": "beischaffen",
    "beischufen": "beischaffen",
    "beischufst": "beischaffen",
    "beischuft": "beischaffen",
    "beischüfe": "beischaffen",
    "beischüfen": "beischaffen",
    "beischüfest": "beischaffen",
    "beischüfet": "beischaffen",
    "beisetze": "beisetzen",
    "beisetzend": "beisetzen",
    "beisetzende": "beisetzend",
    "beisetzendem": "beisetzend",
    "beisetzenden": "beisetzend",
    "beisetzender": "beisetzend",
    "beisetzendes": "beisetzend",
    "beisetzest": "beisetzen",
    "beisetzet": "beisetzen",
    "beisetzt": "beisetzen",
    "beisetzte": "beisetzen",
    "beisetzten": "beisetzen",
    "beisetztest": "beisetzen",
    "beisetztet": "beisetzen",
    "beisitze": "beisitzen",
    "beisitzend": "beisitzen",
    "beisitzende": "beisitzend",
    "beisitzendem": "beisitzend",
    "beisitzenden": "beisitzend",
    "beisitzender": "beisitzend",
    "beisitzendes": "beisitzend",
    "beisitzest": "beisitzen",
    "beisitzet": "beisitzen",
    "beisitzt": "beisitzen",
    "beispielhaftem": "beispielhaft",
    "beispielhaften": "beispielhaft",
    "beispielhafter": "beispielhaft",
    "beispielhaftere": "beispielhaft",
    "beispielhafterem": "beispielhaft",
    "beispielhafteren": "beispielhaft",
    "beispielhafterer": "beispielhaft",
    "beispielhafteres": "beispielhaft",
    "beispielhaftes": "beispielhaft",
    "beispielhafteste": "beispielhaft",
    "beispielhaftestem": "beispielhaft",
    "beispielhaftesten": "beispielhaft",
    "beispielhaftester": "beispielhaft",
    "beispielhaftestes": "beispielhaft",
    "beispiellose": "beispiellos",
    "beispiellosem": "beispiellos",
    "beispiellosen": "beispiellos",
    "beispielloser": "beispiellos",
    "beispiellosere": "beispiellos",
    "beispielloserem": "beispiellos",
    "beispielloseren": "beispiellos",
    "beispielloserer": "beispiellos",
    "beispielloseres": "beispiellos",
    "beispielloses": "beispiellos",
    "beispielloseste": "beispiellos",
    "beispiellosestem": "beispiellos",
    "beispiellosesten": "beispiellos",
    "beispiellosester": "beispiellos",
    "beispiellosestes": "beispiellos",
    "beisprang": "beispringen",
    "beisprangen": "beispringen",
    "beisprangst": "beispringen",
    "beisprangt": "beispringen",
    "beispringe": "beispringen",
    "beispringend": "beispringen",
    "beispringende": "beispringend",
    "beispringendem": "beispringend",
    "beispringenden": "beispringend",
    "beispringender": "beispringend",
    "beispringendes": "beispringend",
    "beispringest": "beispringen",
    "beispringet": "beispringen",
    "beispringst": "beispringen",
    "beispringt": "beispringen",
    "beispränge": "beispringen",
    "beisprängen": "beispringen",
    "beisprängest": "beispringen",
    "beispränget": "beispringen",
    "beistand": "beistehen",
    "beistanden": "beistehen",
    "beistandest": "beistehen",
    "beistandet": "beistehen",
    "beistehe": "beistehen",
    "beistehend": "beistehen",
    "beistehende": "beistehend",
    "beistehendem": "beistehend",
    "beistehenden": "beistehend",
    "beistehender": "beistehend",
    "beistehendes": "beistehend",
    "beistehest": "beistehen",
    "beistehet": "beistehen",
    "beistehst": "beistehen",
    "beisteht": "beistehen",
    "beisteuerndem": "beisteuernd",
    "beisteuernden": "beisteuernd",
    "beisteuernder": "beisteuernd",
    "beisteuerndes": "beisteuernd",
    "beisteuertem": "beisteuert",
    "beisteuerten": "beisteuert",
    "beisteuerter": "beisteuert",
    "beisteuertes": "beisteuert",
    "beistimme": "beistimmen",
    "beistimmend": "beistimmen",
    "beistimmende": "beistimmend",
    "beistimmendem": "beistimmend",
    "beistimmenden": "beistimmend",
    "beistimmender": "beistimmend",
    "beistimmendes": "beistimmend",
    "beistimmest": "beistimmen",
    "beistimmet": "beistimmen",
    "beistimmst": "beistimmen",
    "beistimmt": "beistimmen",
    "beistimmte": "beistimmen",
    "beistimmten": "beistimmen",
    "beistimmtest": "beistimmen",
    "beistimmtet": "beistimmen",
    "beistünde": "beistehen",
    "beistünden": "beistehen",
    "beistündest": "beistehen",
    "beistündet": "beistehen",
    "beisäße": "beisitzen",
    "beisäßen": "beisitzen",
    "beisäßest": "beisitzen",
    "beisäßet": "beisitzen",
    "beitragend": "beitragen",
    "beitragende": "beitragend",
    "beitragendem": "beitragend",
    "beitragenden": "beitragend",
    "beitragender": "beitragend",
    "beitragendere": "beitragend",
    "beitragenderem": "beitragend",
    "beitragenderen": "beitragend",
    "beitragenderer": "beitragend",
    "beitragenderes": "beitragend",
    "beitragendes": "beitragend",
    "beitragendste": "beitragend",
    "beitragendstem": "beitragend",
    "beitragendsten": "beitragend",
    "beitragendster": "beitragend",
    "beitragendstes": "beitragend",
    "beitragest": "beitragen",
    "beitraget": "beitragen",
    "beitragspflichtigem": "beitragspflichtig",
    "beitragspflichtigen": "beitragspflichtig",
    "beitragspflichtiger": "beitragspflichtig",
    "beitragspflichtiges": "beitragspflichtig",
    "beitragt": "beitragen",
    "beitrat": "beitreten",
    "beitraten": "beitreten",
    "beitratest": "beitreten",
    "beitratet": "beitreten",
    "beitrete": "beitreten",
    "beitretend": "beitreten",
    "beitretende": "beitretend",
    "beitretendem": "beitretend",
    "beitretenden": "beitretend",
    "beitretender": "beitretend",
    "beitretendes": "beitretend",
    "beitretest": "beitreten",
    "beitretet": "beitreten",
    "beitritt": "beitreten",
    "beitrittst": "beitreten",
    "beitrug": "beitragen",
    "beitrugen": "beitragen",
    "beitrugst": "beitragen",
    "beitrugt": "beitragen",
    "beiträgst": "beitragen",
    "beiträgt": "beitragen",
    "beiträte": "beitreten",
    "beiträten": "beitreten",
    "beiträtest": "beitreten",
    "beiträtet": "beitreten",
    "beitrüge": "beitragen",
    "beitrügen": "beitragen",
    "beitrügest": "beitragen",
    "beitrüget": "beitragen",
    "beiwohne": "beiwohnen",
    "beiwohnend": "beiwohnen",
    "beiwohnende": "beiwohnend",
    "beiwohnendem": "beiwohnend",
    "beiwohnenden": "beiwohnend",
    "beiwohnender": "beiwohnend",
    "beiwohnendes": "beiwohnend",
    "beiwohnest": "beiwohnen",
    "beiwohnet": "beiwohnen",
    "beiwohnst": "beiwohnen",
    "beiwohnt": "beiwohnen",
    "beiwohnte": "beiwohnen",
    "beiwohnten": "beiwohnen",
    "beiwohntest": "beiwohnen",
    "beiwohntet": "beiwohnen",
    "beizend": "beizen",
    "beizende": "beizend",
    "beizendem": "beizend",
    "beizenden": "beizend",
    "beizender": "beizend",
    "beizendes": "beizend",
    "beizest": "beizen",
    "beizet": "beizen",
    "beizt": "beizen",
    "beizte": "beizen",
    "beizten": "beizen",
    "beiztest": "beizen",
    "beiztet": "beizen",
    "beizubehalten": "beibehalten",
    "beizubiegen": "beibiegen",
    "beizubringen": "beibringen",
    "beizudrehen": "beidrehen",
    "beizufolgen": "beifolgen",
    "beizufügen": "beifügen",
    "beizugeben": "beigeben",
    "beizugesellen": "beigesellen",
    "beizuholen": "beiholen",
    "beizukommen": "beikommen",
    "beizuladen": "beiladen",
    "beizulegen": "beilegen",
    "beizuliegen": "beiliegen",
    "beizumengen": "beimengen",
    "beizumessen": "beimessen",
    "beizumischen": "beimischen",
    "beizuordnen": "beiordnen",
    "beizupflichten": "beipflichten",
    "beizuschaffen": "beischaffen",
    "beizusetzen": "beisetzen",
    "beizusitzen": "beisitzen",
    "beizuspringen": "beispringen",
    "beizustehen": "beistehen",
    "beizustimmen": "beistimmen",
    "beizutragen": "beitragen",
    "beizutreten": "beitreten",
    "beizuwohnen": "beiwohnen",
    "beiße": "beißen",
    "beißend": "beißen",
    "beißende": "beißend",
    "beißendem": "beißend",
    "beißenden": "beißend",
    "beißender": "beißend",
    "beißendes": "beißend",
    "beißest": "beißen",
    "beißet": "beißen",
    "beißt": "beißen",
    "bejahe": "bejahen",
    "bejahend": "bejahen",
    "bejahende": "bejahend",
    "bejahendem": "bejahend",
    "bejahenden": "bejahend",
    "bejahender": "bejahend",
    "bejahendes": "bejahend",
    "bejahest": "bejahen",
    "bejahet": "bejahen",
    "bejahst": "bejahen",
    "bejaht": "bejahen",
    "bejahte": "bejahen",
    "bejahtem": "bejaht",
    "bejahten": "bejahen",
    "bejahter": "bejaht",
    "bejahtes": "bejaht",
    "bejahtest": "bejahen",
    "bejahtet": "bejahen",
    "bejammernswertem": "bejammernswert",
    "bejammernswerten": "bejammernswert",
    "bejammernswerter": "bejammernswert",
    "bejammernswertere": "bejammernswert",
    "bejammernswerterem": "bejammernswert",
    "bejammernswerteren": "bejammernswert",
    "bejammernswerterer": "bejammernswert",
    "bejammernswerteres": "bejammernswert",
    "bejammernswertes": "bejammernswert",
    "bejammernswerteste": "bejammernswert",
    "bejammernswertestem": "bejammernswert",
    "bejammernswertesten": "bejammernswert",
    "bejammernswertester": "bejammernswert",
    "bejammernswertestes": "bejammernswert",
    "bejubele": "bejubeln",
    "bejubelnd": "bejubeln",
    "bejubelnde": "bejubelnd",
    "bejubelndem": "bejubelnd",
    "bejubelnden": "bejubelnd",
    "bejubelnder": "bejubelnd",
    "bejubelndere": "bejubelnd",
    "bejubelnderem": "bejubelnd",
    "bejubelnderen": "bejubelnd",
    "bejubelnderer": "bejubelnd",
    "bejubelnderes": "bejubelnd",
    "bejubelndes": "bejubelnd",
    "bejubelndste": "bejubelnd",
    "bejubelndstem": "bejubelnd",
    "bejubelndsten": "bejubelnd",
    "bejubelndster": "bejubelnd",
    "bejubelndstes": "bejubelnd",
    "bejubelst": "bejubeln",
    "bejubelt": "bejubeln",
    "bejubelte": "bejubeln",
    "bejubeltem": "bejubelt",
    "bejubelten": "bejubeln",
    "bejubelter": "bejubelt",
    "bejubeltere": "bejubelt",
    "bejubelterem": "bejubelt",
    "bejubelteren": "bejubelt",
    "bejubelterer": "bejubelt",
    "bejubelteres": "bejubelt",
    "bejubeltes": "bejubelt",
    "bejubeltest": "bejubeln",
    "bejubelteste": "bejubelt",
    "bejubeltestem": "bejubelt",
    "bejubeltesten": "bejubelt",
    "bejubeltester": "bejubelt",
    "bejubeltestes": "bejubelt",
    "bejubeltet": "bejubeln",
    "bejuble": "bejubeln",
    "bekakele": "bekakeln",
    "bekakelnd": "bekakeln",
    "bekakelnde": "bekakelnd",
    "bekakelndem": "bekakelnd",
    "bekakelnden": "bekakelnd",
    "bekakelnder": "bekakelnd",
    "bekakelndere": "bekakelnd",
    "bekakelnderem": "bekakelnd",
    "bekakelnderen": "bekakelnd",
    "bekakelnderer": "bekakelnd",
    "bekakelnderes": "bekakelnd",
    "bekakelndes": "bekakelnd",
    "bekakelndste": "bekakelnd",
    "bekakelndstem": "bekakelnd",
    "bekakelndsten": "bekakelnd",
    "bekakelndster": "bekakelnd",
    "bekakelndstes": "bekakelnd",
    "bekakelst": "bekakeln",
    "bekakelt": "bekakeln",
    "bekakelte": "bekakeln",
    "bekakeltem": "bekakelt",
    "bekakelten": "bekakeln",
    "bekakelter": "bekakelt",
    "bekakeltere": "bekakelt",
    "bekakelterem": "bekakelt",
    "bekakelteren": "bekakelt",
    "bekakelterer": "bekakelt",
    "bekakelteres": "bekakelt",
    "bekakeltes": "bekakelt",
    "bekakeltest": "bekakeln",
    "bekakelteste": "bekakelt",
    "bekakeltestem": "bekakelt",
    "bekakeltesten": "bekakelt",
    "bekakeltester": "bekakelt",
    "bekakeltestes": "bekakelt",
    "bekakeltet": "bekakeln",
    "bekakle": "bekakeln",
    "bekam": "bekommen",
    "bekamen": "bekommen",
    "bekamst": "bekommen",
    "bekamt": "bekommen",
    "bekannt": "bekennen",
    "bekannte": "bekannt",
    "bekanntem": "bekannt",
    "bekannten": "bekannt",
    "bekannter": "bekannt",
    "bekanntere": "bekannt",
    "bekannterem": "bekannt",
    "bekannteren": "bekannt",
    "bekannterer": "bekannt",
    "bekannteres": "bekannt",
    "bekanntes": "bekannt",
    "bekanntest": "bekennen",
    "bekannteste": "bekannt",
    "bekanntestem": "bekannt",
    "bekanntesten": "bekannt",
    "bekanntester": "bekannt",
    "bekanntestes": "bekannt",
    "bekanntet": "bekennen",
    "bekanntgab": "bekanntgeben",
    "bekanntgaben": "bekanntgeben",
    "bekanntgabst": "bekanntgeben",
    "bekanntgabt": "bekanntgeben",
    "bekanntgebe": "bekanntgeben",
    "bekanntgebend": "bekanntgeben",
    "bekanntgebende": "bekanntgebend",
    "bekanntgebendem": "bekanntgebend",
    "bekanntgebenden": "bekanntgebend",
    "bekanntgebender": "bekanntgebend",
    "bekanntgebendes": "bekanntgebend",
    "bekanntgebest": "bekanntgeben",
    "bekanntgebet": "bekanntgeben",
    "bekanntgebt": "bekanntgeben",
    "bekanntgegeben": "bekanntgeben",
    "bekanntgegebene": "bekanntgegeben",
    "bekanntgegebenem": "bekanntgegeben",
    "bekanntgegebenen": "bekanntgegeben",
    "bekanntgegebener": "bekanntgegeben",
    "bekanntgegebenes": "bekanntgegeben",
    "bekanntgibst": "bekanntgeben",
    "bekanntgibt": "bekanntgeben",
    "bekanntgäbe": "bekanntgeben",
    "bekanntgäben": "bekanntgeben",
    "bekanntgäbest": "bekanntgeben",
    "bekanntgäbet": "bekanntgeben",
    "bekanntzugeben": "bekanntgeben",
    "bekehre": "bekehren",
    "bekehrend": "bekehren",
    "bekehrende": "bekehrend",
    "bekehrendem": "bekehrend",
    "bekehrenden": "bekehrend",
    "bekehrender": "bekehrend",
    "bekehrendere": "bekehrend",
    "bekehrenderem": "bekehrend",
    "bekehrenderen": "bekehrend",
    "bekehrenderer": "bekehrend",
    "bekehrenderes": "bekehrend",
    "bekehrendes": "bekehrend",
    "bekehrendste": "bekehrend",
    "bekehrendstem": "bekehrend",
    "bekehrendsten": "bekehrend",
    "bekehrendster": "bekehrend",
    "bekehrendstes": "bekehrend",
    "bekehrest": "bekehren",
    "bekehret": "bekehren",
    "bekehrst": "bekehren",
    "bekehrt": "bekehren",
    "bekehrte": "bekehren",
    "bekehrtem": "bekehrt",
    "bekehrten": "bekehren",
    "bekehrter": "bekehrt",
    "bekehrtere": "bekehrt",
    "bekehrterem": "bekehrt",
    "bekehrteren": "bekehrt",
    "bekehrterer": "bekehrt",
    "bekehrteres": "bekehrt",
    "bekehrtes": "bekehrt",
    "bekehrtest": "bekehren",
    "bekehrteste": "bekehrt",
    "bekehrtestem": "bekehrt",
    "bekehrtesten": "bekehrt",
    "bekehrtester": "bekehrt",
    "bekehrtestes": "bekehrt",
    "bekehrtet": "bekehren",
    "bekenne": "bekennen",
    "bekennend": "bekennen",
    "bekennende": "bekennend",
    "bekennendem": "bekennend",
    "bekennenden": "bekennend",
    "bekennender": "bekennend",
    "bekennendes": "bekennend",
    "bekennest": "bekennen",
    "bekennet": "bekennen",
    "bekennst": "bekennen",
    "bekennt": "bekennen",
    "beklagend": "beklagen",
    "beklagende": "beklagend",
    "beklagendem": "beklagend",
    "beklagenden": "beklagend",
    "beklagender": "beklagend",
    "beklagendere": "beklagend",
    "beklagenderem": "beklagend",
    "beklagenderen": "beklagend",
    "beklagenderer": "beklagend",
    "beklagenderes": "beklagend",
    "beklagendes": "beklagend",
    "beklagendste": "beklagend",
    "beklagendstem": "beklagend",
    "beklagendsten": "beklagend",
    "beklagendster": "beklagend",
    "beklagendstes": "beklagend",
    "beklagenswertem": "beklagenswert",
    "beklagenswerten": "beklagenswert",
    "beklagenswerter": "beklagenswert",
    "beklagenswertere": "beklagenswert",
    "beklagenswerterem": "beklagenswert",
    "beklagenswerteren": "beklagenswert",
    "beklagenswerterer": "beklagenswert",
    "beklagenswerteres": "beklagenswert",
    "beklagenswertes": "beklagenswert",
    "beklagenswerteste": "beklagenswert",
    "beklagenswertestem": "beklagenswert",
    "beklagenswertesten": "beklagenswert",
    "beklagenswertester": "beklagenswert",
    "beklagenswertestes": "beklagenswert",
    "beklagenswürdige": "beklagenswürdig",
    "beklagenswürdigem": "beklagenswürdig",
    "beklagenswürdigen": "beklagenswürdig",
    "beklagenswürdiger": "beklagenswürdig",
    "beklagenswürdigere": "beklagenswürdig",
    "beklagenswürdigerem": "beklagenswürdig",
    "beklagenswürdigeren": "beklagenswürdig",
    "beklagenswürdigerer": "beklagenswürdig",
    "beklagenswürdigeres": "beklagenswürdig",
    "beklagenswürdiges": "beklagenswürdig",
    "beklagenswürdigste": "beklagenswürdig",
    "beklagenswürdigstem": "beklagenswürdig",
    "beklagenswürdigsten": "beklagenswürdig",
    "beklagenswürdigster": "beklagenswürdig",
    "beklagenswürdigstes": "beklagenswürdig",
    "beklagest": "beklagen",
    "beklaget": "beklagen",
    "beklagst": "beklagen",
    "beklagt": "beklagen",
    "beklagte": "beklagen",
    "beklagtem": "beklagt",
    "beklagten": "beklagen",
    "beklagter": "beklagt",
    "beklagtere": "beklagt",
    "beklagterem": "beklagt",
    "beklagteren": "beklagt",
    "beklagterer": "beklagt",
    "beklagteres": "beklagt",
    "beklagtes": "beklagt",
    "beklagtest": "beklagen",
    "beklagteste": "beklagt",
    "beklagtestem": "beklagt",
    "beklagtesten": "beklagt",
    "beklagtester": "beklagt",
    "beklagtestes": "beklagt",
    "beklagtet": "beklagen",
    "beklatsche": "beklatschen",
    "beklatschend": "beklatschen",
    "beklatschende": "beklatschend",
    "beklatschendem": "beklatschend",
    "beklatschenden": "beklatschend",
    "beklatschender": "beklatschend",
    "beklatschendere": "beklatschend",
    "beklatschenderem": "beklatschend",
    "beklatschenderen": "beklatschend",
    "beklatschenderer": "beklatschend",
    "beklatschenderes": "beklatschend",
    "beklatschendes": "beklatschend",
    "beklatschendste": "beklatschend",
    "beklatschendstem": "beklatschend",
    "beklatschendsten": "beklatschend",
    "beklatschendster": "beklatschend",
    "beklatschendstes": "beklatschend",
    "beklatschest": "beklatschen",
    "beklatschet": "beklatschen",
    "beklatschst": "beklatschen",
    "beklatscht": "beklatschen",
    "beklatschte": "beklatschen",
    "beklatschtem": "beklatscht",
    "beklatschten": "beklatschen",
    "beklatschter": "beklatscht",
    "beklatschtere": "beklatscht",
    "beklatschterem": "beklatscht",
    "beklatschteren": "beklatscht",
    "beklatschterer": "beklatscht",
    "beklatschteres": "beklatscht",
    "beklatschtes": "beklatscht",
    "beklatschtest": "beklatschen",
    "beklatschteste": "beklatscht",
    "beklatschtestem": "beklatscht",
    "beklatschtesten": "beklatscht",
    "beklatschtester": "beklatscht",
    "beklatschtestes": "beklatscht",
    "beklatschtet": "beklatschen",
    "beklaue": "beklauen",
    "beklauend": "beklauen",
    "beklauende": "beklauend",
    "beklauendem": "beklauend",
    "beklauenden": "beklauend",
    "beklauender": "beklauend",
    "beklauendere": "beklauend",
    "beklauenderem": "beklauend",
    "beklauenderen": "beklauend",
    "beklauenderer": "beklauend",
    "beklauenderes": "beklauend",
    "beklauendes": "beklauend",
    "beklauendste": "beklauend",
    "beklauendstem": "beklauend",
    "beklauendsten": "beklauend",
    "beklauendster": "beklauend",
    "beklauendstes": "beklauend",
    "beklauest": "beklauen",
    "beklauet": "beklauen",
    "beklaust": "beklauen",
    "beklaut": "beklauen",
    "beklaute": "beklauen",
    "beklautem": "beklaut",
    "beklauten": "beklauen",
    "beklauter": "beklaut",
    "beklautes": "beklaut",
    "beklautest": "beklauen",
    "beklautet": "beklauen",
    "beklebe": "bekleben",
    "beklebend": "bekleben",
    "beklebende": "beklebend",
    "beklebendem": "beklebend",
    "beklebenden": "beklebend",
    "beklebender": "beklebend",
    "beklebendere": "beklebend",
    "beklebenderem": "beklebend",
    "beklebenderen": "beklebend",
    "beklebenderer": "beklebend",
    "beklebenderes": "beklebend",
    "beklebendes": "beklebend",
    "beklebendste": "beklebend",
    "beklebendstem": "beklebend",
    "beklebendsten": "beklebend",
    "beklebendster": "beklebend",
    "beklebendstes": "beklebend",
    "beklebest": "bekleben",
    "beklebet": "bekleben",
    "beklebst": "bekleben",
    "beklebt": "bekleben",
    "beklebte": "bekleben",
    "beklebtem": "beklebt",
    "beklebten": "bekleben",
    "beklebter": "beklebt",
    "beklebtere": "beklebt",
    "beklebterem": "beklebt",
    "beklebteren": "beklebt",
    "beklebterer": "beklebt",
    "beklebteres": "beklebt",
    "beklebtes": "beklebt",
    "beklebtest": "bekleben",
    "beklebteste": "beklebt",
    "beklebtestem": "beklebt",
    "beklebtesten": "beklebt",
    "beklebtester": "beklebt",
    "beklebtestes": "beklebt",
    "beklebtet": "bekleben",
    "bekleckere": "bekleckern",
    "bekleckernd": "bekleckern",
    "bekleckernde": "bekleckernd",
    "bekleckerndem": "bekleckernd",
    "bekleckernden": "bekleckernd",
    "bekleckernder": "bekleckernd",
    "bekleckerndere": "bekleckernd",
    "bekleckernderem": "bekleckernd",
    "bekleckernderen": "bekleckernd",
    "bekleckernderer": "bekleckernd",
    "bekleckernderes": "bekleckernd",
    "bekleckerndes": "bekleckernd",
    "bekleckerndste": "bekleckernd",
    "bekleckerndstem": "bekleckernd",
    "bekleckerndsten": "bekleckernd",
    "bekleckerndster": "bekleckernd",
    "bekleckerndstes": "bekleckernd",
    "bekleckerst": "bekleckern",
    "bekleckert": "bekleckern",
    "bekleckerte": "bekleckern",
    "bekleckertem": "bekleckert",
    "bekleckerten": "bekleckern",
    "bekleckerter": "bekleckert",
    "bekleckertere": "bekleckert",
    "bekleckerterem": "bekleckert",
    "bekleckerteren": "bekleckert",
    "bekleckerterer": "bekleckert",
    "bekleckerteres": "bekleckert",
    "bekleckertes": "bekleckert",
    "bekleckertest": "bekleckern",
    "bekleckerteste": "bekleckert",
    "bekleckertestem": "bekleckert",
    "bekleckertesten": "bekleckert",
    "bekleckertester": "bekleckert",
    "bekleckertestes": "bekleckert",
    "bekleckertet": "bekleckern",
    "bekleckse": "beklecksen",
    "beklecksend": "beklecksen",
    "beklecksende": "beklecksend",
    "beklecksendem": "beklecksend",
    "beklecksenden": "beklecksend",
    "beklecksender": "beklecksend",
    "beklecksendere": "beklecksend",
    "beklecksenderem": "beklecksend",
    "beklecksenderen": "beklecksend",
    "beklecksenderer": "beklecksend",
    "beklecksenderes": "beklecksend",
    "beklecksendes": "beklecksend",
    "beklecksendste": "beklecksend",
    "beklecksendstem": "beklecksend",
    "beklecksendsten": "beklecksend",
    "beklecksendster": "beklecksend",
    "beklecksendstes": "beklecksend",
    "beklecksest": "beklecksen",
    "bekleckset": "beklecksen",
    "bekleckst": "beklecksen",
    "bekleckste": "beklecksen",
    "bekleckstem": "bekleckst",
    "beklecksten": "beklecksen",
    "bekleckster": "bekleckst",
    "bekleckstere": "bekleckst",
    "beklecksterem": "bekleckst",
    "beklecksteren": "bekleckst",
    "beklecksterer": "bekleckst",
    "beklecksteres": "bekleckst",
    "bekleckstes": "bekleckst",
    "bekleckstest": "beklecksen",
    "beklecksteste": "bekleckst",
    "bekleckstestem": "bekleckst",
    "bekleckstesten": "bekleckst",
    "bekleckstester": "bekleckst",
    "bekleckstestes": "bekleckst",
    "bekleckstet": "beklecksen",
    "bekleide": "bekleiden",
    "bekleidend": "bekleiden",
    "bekleidende": "bekleidend",
    "bekleidendem": "bekleidend",
    "bekleidenden": "bekleidend",
    "bekleidender": "bekleidend",
    "bekleidendes": "bekleidend",
    "bekleidest": "bekleiden",
    "bekleidet": "bekleiden",
    "bekleidete": "bekleiden",
    "bekleidetem": "bekleidet",
    "bekleideten": "bekleiden",
    "bekleideter": "bekleidet",
    "bekleidetes": "bekleidet",
    "bekleidetest": "bekleiden",
    "bekleidetet": "bekleiden",
    "beklemme": "beklemmen",
    "beklemmend": "beklemmen",
    "beklemmende": "beklemmend",
    "beklemmendem": "beklemmend",
    "beklemmenden": "beklemmend",
    "beklemmender": "beklemmend",
    "beklemmendes": "beklemmend",
    "beklemmest": "beklemmen",
    "beklemmet": "beklemmen",
    "beklemmst": "beklemmen",
    "beklemmt": "beklemmen",
    "beklemmte": "beklemmen",
    "beklemmtem": "beklemmt",
    "beklemmten": "beklemmen",
    "beklemmter": "beklemmt",
    "beklemmtes": "beklemmt",
    "beklemmtest": "beklemmen",
    "beklemmtet": "beklemmen",
    "bekloppte": "bekloppt",
    "beklopptem": "bekloppt",
    "bekloppten": "bekloppt",
    "bekloppter": "bekloppt",
    "beklopptere": "bekloppt",
    "bekloppterem": "bekloppt",
    "bekloppteren": "bekloppt",
    "bekloppterer": "bekloppt",
    "bekloppteres": "bekloppt",
    "beklopptes": "bekloppt",
    "bekloppteste": "bekloppt",
    "beklopptestem": "bekloppt",
    "beklopptesten": "bekloppt",
    "beklopptester": "bekloppt",
    "beklopptestes": "bekloppt",
    "beknackte": "beknackt",
    "beknacktem": "beknackt",
    "beknackten": "beknackt",
    "beknackter": "beknackt",
    "beknacktere": "beknackt",
    "beknackterem": "beknackt",
    "beknackteren": "beknackt",
    "beknackterer": "beknackt",
    "beknackteres": "beknackt",
    "beknacktes": "beknackt",
    "beknackteste": "beknackt",
    "beknacktestem": "beknackt",
    "beknacktesten": "beknackt",
    "beknacktester": "beknackt",
    "beknacktestes": "beknackt",
    "beknie": "beknien",
    "bekniend": "beknien",
    "bekniende": "bekniend",
    "bekniendem": "bekniend",
    "beknienden": "bekniend",
    "bekniender": "bekniend",
    "bekniendere": "bekniend",
    "beknienderem": "bekniend",
    "beknienderen": "bekniend",
    "beknienderer": "bekniend",
    "beknienderes": "bekniend",
    "bekniendes": "bekniend",
    "bekniendste": "bekniend",
    "bekniendstem": "bekniend",
    "bekniendsten": "bekniend",
    "bekniendster": "bekniend",
    "bekniendstes": "bekniend",
    "bekniest": "beknien",
    "bekniet": "beknien",
    "bekniete": "beknien",
    "beknietem": "bekniet",
    "beknieten": "beknien",
    "beknieter": "bekniet",
    "beknietes": "bekniet",
    "beknietest": "beknien",
    "beknietet": "beknien",
    "bekoche": "bekochen",
    "bekochend": "bekochen",
    "bekochende": "bekochend",
    "bekochendem": "bekochend",
    "bekochenden": "bekochend",
    "bekochender": "bekochend",
    "bekochendes": "bekochend",
    "bekochest": "bekochen",
    "bekochet": "bekochen",
    "bekochst": "bekochen",
    "bekocht": "bekochen",
    "bekochte": "bekochen",
    "bekochtem": "bekocht",
    "bekochten": "bekochen",
    "bekochter": "bekocht",
    "bekochtes": "bekocht",
    "bekochtest": "bekochen",
    "bekochtet": "bekochen",
    "bekomme": "bekommen",
    "bekommend": "bekommen",
    "bekommende": "bekommend",
    "bekommendem": "bekommend",
    "bekommenden": "bekommend",
    "bekommender": "bekommend",
    "bekommendes": "bekommend",
    "bekommene": "bekommen",
    "bekommenem": "bekommen",
    "bekommenen": "bekommen",
    "bekommener": "bekommen",
    "bekommenes": "bekommen",
    "bekommest": "bekommen",
    "bekommet": "bekommen",
    "bekommst": "bekommen",
    "bekommt": "bekommen",
    "bekreuzige": "bekreuzigen",
    "bekreuzigend": "bekreuzigen",
    "bekreuzigende": "bekreuzigend",
    "bekreuzigendem": "bekreuzigend",
    "bekreuzigenden": "bekreuzigend",
    "bekreuzigender": "bekreuzigend",
    "bekreuzigendes": "bekreuzigend",
    "bekreuzigest": "bekreuzigen",
    "bekreuziget": "bekreuzigen",
    "bekreuzigst": "bekreuzigen",
    "bekreuzigt": "bekreuzigen",
    "bekreuzigte": "bekreuzigen",
    "bekreuzigtem": "bekreuzigt",
    "bekreuzigten": "bekreuzigen",
    "bekreuzigter": "bekreuzigt",
    "bekreuzigtes": "bekreuzigt",
    "bekreuzigtest": "bekreuzigen",
    "bekreuzigtet": "bekreuzigen",
    "bekriege": "bekriegen",
    "bekriegend": "bekriegen",
    "bekriegende": "bekriegend",
    "bekriegendem": "bekriegend",
    "bekriegenden": "bekriegend",
    "bekriegender": "bekriegend",
    "bekriegendes": "bekriegend",
    "bekriegest": "bekriegen",
    "bekrieget": "bekriegen",
    "bekriegst": "bekriegen",
    "bekriegt": "bekriegen",
    "bekriegte": "bekriegen",
    "bekriegtem": "bekriegt",
    "bekriegten": "bekriegen",
    "bekriegter": "bekriegt",
    "bekriegtes": "bekriegt",
    "bekriegtest": "bekriegen",
    "bekriegtet": "bekriegen",
    "bekräftige": "bekräftigen",
    "bekräftigend": "bekräftigen",
    "bekräftigende": "bekräftigend",
    "bekräftigendem": "bekräftigend",
    "bekräftigenden": "bekräftigend",
    "bekräftigender": "bekräftigend",
    "bekräftigendes": "bekräftigend",
    "bekräftigest": "bekräftigen",
    "bekräftiget": "bekräftigen",
    "bekräftigst": "bekräftigen",
    "bekräftigt": "bekräftigen",
    "bekräftigte": "bekräftigen",
    "bekräftigtem": "bekräftigt",
    "bekräftigten": "bekräftigen",
    "bekräftigter": "bekräftigt",
    "bekräftigtes": "bekräftigt",
    "bekräftigtest": "bekräftigen",
    "bekräftigtet": "bekräftigen",
    "bekrümele": "bekrümeln",
    "bekrümelnd": "bekrümeln",
    "bekrümelnde": "bekrümelnd",
    "bekrümelndem": "bekrümelnd",
    "bekrümelnden": "bekrümelnd",
    "bekrümelnder": "bekrümelnd",
    "bekrümelndere": "bekrümelnd",
    "bekrümelnderem": "bekrümelnd",
    "bekrümelnderen": "bekrümelnd",
    "bekrümelnderer": "bekrümelnd",
    "bekrümelnderes": "bekrümelnd",
    "bekrümelndes": "bekrümelnd",
    "bekrümelndste": "bekrümelnd",
    "bekrümelndstem": "bekrümelnd",
    "bekrümelndsten": "bekrümelnd",
    "bekrümelndster": "bekrümelnd",
    "bekrümelndstes": "bekrümelnd",
    "bekrümelst": "bekrümeln",
    "bekrümelt": "bekrümeln",
    "bekrümelte": "bekrümeln",
    "bekrümeltem": "bekrümelt",
    "bekrümelten": "bekrümeln",
    "bekrümelter": "bekrümelt",
    "bekrümeltere": "bekrümelt",
    "bekrümelterem": "bekrümelt",
    "bekrümelteren": "bekrümelt",
    "bekrümelterer": "bekrümelt",
    "bekrümelteres": "bekrümelt",
    "bekrümeltes": "bekrümelt",
    "bekrümeltest": "bekrümeln",
    "bekrümelteste": "bekrümelt",
    "bekrümeltestem": "bekrümelt",
    "bekrümeltesten": "bekrümelt",
    "bekrümeltester": "bekrümelt",
    "bekrümeltestes": "bekrümelt",
    "bekrümeltet": "bekrümeln",
    "bekrümle": "bekrümeln",
    "bekunde": "bekunden",
    "bekundend": "bekunden",
    "bekundende": "bekundend",
    "bekundendem": "bekundend",
    "bekundenden": "bekundend",
    "bekundender": "bekundend",
    "bekundendes": "bekundend",
    "bekundest": "bekunden",
    "bekundet": "bekunden",
    "bekundete": "bekunden",
    "bekundetem": "bekundet",
    "bekundeten": "bekunden",
    "bekundeter": "bekundet",
    "bekundetes": "bekundet",
    "bekundetest": "bekunden",
    "bekundetet": "bekunden",
    "bekäme": "bekommen",
    "bekämen": "bekommen",
    "bekämest": "bekommen",
    "bekämet": "bekommen",
    "bekämpfe": "bekämpfen",
    "bekämpfend": "bekämpfen",
    "bekämpfende": "bekämpfend",
    "bekämpfendem": "bekämpfend",
    "bekämpfenden": "bekämpfend",
    "bekämpfender": "bekämpfend",
    "bekämpfendes": "bekämpfend",
    "bekämpfest": "bekämpfen",
    "bekämpfet": "bekämpfen",
    "bekämpfst": "bekämpfen",
    "bekämpft": "bekämpfen",
    "bekämpfte": "bekämpfen",
    "bekämpftem": "bekämpft",
    "bekämpften": "bekämpfen",
    "bekämpfter": "bekämpft",
    "bekämpftes": "bekämpft",
    "bekämpftest": "bekämpfen",
    "bekämpftet": "bekämpfen",
    "bekömmliche": "bekömmlich",
    "bekömmlichem": "bekömmlich",
    "bekömmlichen": "bekömmlich",
    "bekömmlicher": "bekömmlich",
    "bekömmlichere": "bekömmlich",
    "bekömmlicherem": "bekömmlich",
    "bekömmlicheren": "bekömmlich",
    "bekömmlicherer": "bekömmlich",
    "bekömmlicheres": "bekömmlich",
    "bekömmliches": "bekömmlich",
    "bekömmlichste": "bekömmlich",
    "bekömmlichstem": "bekömmlich",
    "bekömmlichsten": "bekömmlich",
    "bekömmlichster": "bekömmlich",
    "bekömmlichstes": "bekömmlich",
    "beköstige": "beköstigen",
    "beköstigend": "beköstigen",
    "beköstigende": "beköstigend",
    "beköstigendem": "beköstigend",
    "beköstigenden": "beköstigend",
    "beköstigender": "beköstigend",
    "beköstigendes": "beköstigend",
    "beköstigest": "beköstigen",
    "beköstiget": "beköstigen",
    "beköstigst": "beköstigen",
    "beköstigt": "beköstigen",
    "beköstigte": "beköstigen",
    "beköstigtem": "beköstigt",
    "beköstigten": "beköstigen",
    "beköstigter": "beköstigt",
    "beköstigtes": "beköstigt",
    "beköstigtest": "beköstigen",
    "beköstigtet": "beköstigen",
    "bekümmertem": "bekümmert",
    "bekümmerten": "bekümmert",
    "bekümmerter": "bekümmert",
    "bekümmertere": "bekümmert",
    "bekümmerterem": "bekümmert",
    "bekümmerteren": "bekümmert",
    "bekümmerterer": "bekümmert",
    "bekümmerteres": "bekümmert",
    "bekümmertes": "bekümmert",
    "bekümmerteste": "bekümmert",
    "bekümmertestem": "bekümmert",
    "bekümmertesten": "bekümmert",
    "bekümmertester": "bekümmert",
    "bekümmertestes": "bekümmert",
    "bekürze": "bekürzen",
    "bekürzend": "bekürzen",
    "bekürzende": "bekürzend",
    "bekürzendem": "bekürzend",
    "bekürzenden": "bekürzend",
    "bekürzender": "bekürzend",
    "bekürzendes": "bekürzend",
    "bekürzest": "bekürzen",
    "bekürzet": "bekürzen",
    "bekürzt": "bekürzen",
    "bekürzte": "bekürzen",
    "bekürztem": "bekürzt",
    "bekürzten": "bekürzen",
    "bekürzter": "bekürzt",
    "bekürztes": "bekürzt",
    "bekürztest": "bekürzen",
    "bekürztet": "bekürzen",
    "belade": "beladen",
    "beladend": "beladen",
    "beladende": "beladend",
    "beladendem": "beladend",
    "beladenden": "beladend",
    "beladender": "beladend",
    "beladendes": "beladend",
    "beladene": "beladen",
    "beladenem": "beladen",
    "beladenen": "beladen",
    "beladener": "beladen",
    "beladenere": "beladen",
    "beladenerem": "beladen",
    "beladeneren": "beladen",
    "beladenerer": "beladen",
    "beladeneres": "beladen",
    "beladenes": "beladen",
    "beladenstem": "beladen",
    "beladensten": "beladen",
    "beladenster": "beladen",
    "beladenstes": "beladen",
    "beladest": "beladen",
    "beladet": "beladen",
    "belagere": "belagern",
    "belagernd": "belagern",
    "belagernde": "belagernd",
    "belagerndem": "belagernd",
    "belagernden": "belagernd",
    "belagernder": "belagernd",
    "belagerndere": "belagernd",
    "belagernderem": "belagernd",
    "belagernderen": "belagernd",
    "belagernderer": "belagernd",
    "belagernderes": "belagernd",
    "belagerndes": "belagernd",
    "belagerndste": "belagernd",
    "belagerndstem": "belagernd",
    "belagerndsten": "belagernd",
    "belagerndster": "belagernd",
    "belagerndstes": "belagernd",
    "belagerst": "belagern",
    "belagert": "belagern",
    "belagerte": "belagern",
    "belagertem": "belagert",
    "belagerten": "belagern",
    "belagerter": "belagert",
    "belagertere": "belagert",
    "belagerterem": "belagert",
    "belagerteren": "belagert",
    "belagerterer": "belagert",
    "belagerteres": "belagert",
    "belagertes": "belagert",
    "belagertest": "belagern",
    "belagerteste": "belagert",
    "belagertestem": "belagert",
    "belagertesten": "belagert",
    "belagertester": "belagert",
    "belagertestes": "belagert",
    "belagertet": "belagern",
    "belange": "belangen",
    "belangend": "belangen",
    "belangende": "belangend",
    "belangendem": "belangend",
    "belangenden": "belangend",
    "belangender": "belangend",
    "belangendes": "belangend",
    "belangest": "belangen",
    "belanget": "belangen",
    "belanglose": "belanglos",
    "belanglosem": "belanglos",
    "belanglosen": "belanglos",
    "belangloser": "belanglos",
    "belanglosere": "belanglos",
    "belangloserem": "belanglos",
    "belangloseren": "belanglos",
    "belangloserer": "belanglos",
    "belangloseres": "belanglos",
    "belangloses": "belanglos",
    "belangloseste": "belanglos",
    "belanglosestem": "belanglos",
    "belanglosesten": "belanglos",
    "belanglosester": "belanglos",
    "belanglosestes": "belanglos",
    "belangst": "belangen",
    "belangt": "belangen",
    "belangte": "belangen",
    "belangtem": "belangt",
    "belangten": "belangen",
    "belangter": "belangt",
    "belangtes": "belangt",
    "belangtest": "belangen",
    "belangtet": "belangen",
    "belangvolle": "belangvoll",
    "belangvollem": "belangvoll",
    "belangvollen": "belangvoll",
    "belangvoller": "belangvoll",
    "belangvollere": "belangvoll",
    "belangvollerem": "belangvoll",
    "belangvolleren": "belangvoll",
    "belangvollerer": "belangvoll",
    "belangvolleres": "belangvoll",
    "belangvolles": "belangvoll",
    "belangvollste": "belangvoll",
    "belangvollstem": "belangvoll",
    "belangvollsten": "belangvoll",
    "belangvollster": "belangvoll",
    "belangvollstes": "belangvoll",
    "belasse": "belassen",
    "belassend": "belassen",
    "belassende": "belassend",
    "belassendem": "belassend",
    "belassenden": "belassend",
    "belassender": "belassend",
    "belassendes": "belassend",
    "belassene": "belassen",
    "belassenem": "belassen",
    "belassenen": "belassen",
    "belassener": "belassen",
    "belassenes": "belassen",
    "belassest": "belassen",
    "belasset": "belassen",
    "belastbare": "belastbar",
    "belastbarem": "belastbar",
    "belastbaren": "belastbar",
    "belastbarer": "belastbar",
    "belastbarere": "belastbar",
    "belastbarerem": "belastbar",
    "belastbareren": "belastbar",
    "belastbarerer": "belastbar",
    "belastbareres": "belastbar",
    "belastbares": "belastbar",
    "belastbarste": "belastbar",
    "belastbarstem": "belastbar",
    "belastbarsten": "belastbar",
    "belastbarster": "belastbar",
    "belastbarstes": "belastbar",
    "belaste": "belasten",
    "belastend": "belasten",
    "belastende": "belastend",
    "belastendem": "belastend",
    "belastenden": "belastend",
    "belastender": "belastend",
    "belastendere": "belastend",
    "belastenderem": "belastend",
    "belastenderen": "belastend",
    "belastenderer": "belastend",
    "belastenderes": "belastend",
    "belastendes": "belastend",
    "belastendste": "belastend",
    "belastendstem": "belastend",
    "belastendsten": "belastend",
    "belastendster": "belastend",
    "belastendstes": "belastend",
    "belastest": "belasten",
    "belastet": "belasten",
    "belastete": "belasten",
    "belastetem": "belastet",
    "belasteten": "belasten",
    "belasteter": "belastet",
    "belastetere": "belastet",
    "belasteterem": "belastet",
    "belasteteren": "belastet",
    "belasteterer": "belastet",
    "belasteteres": "belastet",
    "belastetes": "belastet",
    "belastetest": "belasten",
    "belasteteste": "belastet",
    "belastetestem": "belastet",
    "belastetesten": "belastet",
    "belastetester": "belastet",
    "belastetestes": "belastet",
    "belastetet": "belasten",
    "belauere": "belauern",
    "belauernd": "belauern",
    "belauernde": "belauernd",
    "belauerndem": "belauernd",
    "belauernden": "belauernd",
    "belauernder": "belauernd",
    "belauerndere": "belauernd",
    "belauernderem": "belauernd",
    "belauernderen": "belauernd",
    "belauernderer": "belauernd",
    "belauernderes": "belauernd",
    "belauerndes": "belauernd",
    "belauerndste": "belauernd",
    "belauerndstem": "belauernd",
    "belauerndsten": "belauernd",
    "belauerndster": "belauernd",
    "belauerndstes": "belauernd",
    "belauerst": "belauern",
    "belauert": "belauern",
    "belauerte": "belauern",
    "belauertem": "belauert",
    "belauerten": "belauern",
    "belauerter": "belauert",
    "belauertes": "belauert",
    "belauertest": "belauern",
    "belauertet": "belauern",
    "belaufe": "belaufen",
    "belaufend": "belaufen",
    "belaufende": "belaufend",
    "belaufendem": "belaufend",
    "belaufenden": "belaufend",
    "belaufender": "belaufend",
    "belaufendes": "belaufend",
    "belaufene": "belaufen",
    "belaufenem": "belaufen",
    "belaufenen": "belaufen",
    "belaufener": "belaufen",
    "belaufenes": "belaufen",
    "belaufest": "belaufen",
    "belaufet": "belaufen",
    "belauft": "belaufen",
    "belausche": "belauschen",
    "belauschend": "belauschen",
    "belauschende": "belauschend",
    "belauschendem": "belauschend",
    "belauschenden": "belauschend",
    "belauschender": "belauschend",
    "belauschendere": "belauschend",
    "belauschenderem": "belauschend",
    "belauschenderen": "belauschend",
    "belauschenderer": "belauschend",
    "belauschenderes": "belauschend",
    "belauschendes": "belauschend",
    "belauschendste": "belauschend",
    "belauschendstem": "belauschend",
    "belauschendsten": "belauschend",
    "belauschendster": "belauschend",
    "belauschendstes": "belauschend",
    "belauschest": "belauschen",
    "belauschet": "belauschen",
    "belauschst": "belauschen",
    "belauscht": "belauschen",
    "belauschte": "belauschen",
    "belauschtem": "belauscht",
    "belauschten": "belauschen",
    "belauschter": "belauscht",
    "belauschtes": "belauscht",
    "belauschtest": "belauschen",
    "belauschtet": "belauschen",
    "belaß": "belassen",
    "belaßt": "belassen",
    "belebe": "beleben",
    "belebend": "beleben",
    "belebende": "belebend",
    "belebendem": "belebend",
    "belebenden": "belebend",
    "belebender": "belebend",
    "belebendere": "belebend",
    "belebenderem": "belebend",
    "belebenderen": "belebend",
    "belebenderer": "belebend",
    "belebenderes": "belebend",
    "belebendes": "belebend",
    "belebendste": "belebend",
    "belebendstem": "belebend",
    "belebendsten": "belebend",
    "belebendster": "belebend",
    "belebendstes": "belebend",
    "belebest": "beleben",
    "belebet": "beleben",
    "belebst": "beleben",
    "belebt": "beleben",
    "belebte": "beleben",
    "belebtem": "belebt",
    "belebten": "beleben",
    "belebter": "belebt",
    "belebtere": "belebt",
    "belebterem": "belebt",
    "belebteren": "belebt",
    "belebterer": "belebt",
    "belebteres": "belebt",
    "belebtes": "belebt",
    "belebtest": "beleben",
    "belebteste": "belebt",
    "belebtestem": "belebt",
    "belebtesten": "belebt",
    "belebtester": "belebt",
    "belebtestes": "belebt",
    "belebtet": "beleben",
    "belegend": "belegen",
    "belegende": "belegend",
    "belegendem": "belegend",
    "belegenden": "belegend",
    "belegender": "belegend",
    "belegendes": "belegend",
    "belegest": "belegen",
    "beleget": "belegen",
    "belegst": "belegen",
    "belegt": "belegen",
    "belegte": "belegen",
    "belegtem": "belegt",
    "belegten": "belegen",
    "belegter": "belegt",
    "belegtere": "belegt",
    "belegterem": "belegt",
    "belegteren": "belegt",
    "belegterer": "belegt",
    "belegteres": "belegt",
    "belegtes": "belegt",
    "belegtest": "belegen",
    "belegteste": "belegt",
    "belegtestem": "belegt",
    "belegtesten": "belegt",
    "belegtester": "belegt",
    "belegtestes": "belegt",
    "belegtet": "belegen",
    "belehre": "belehren",
    "belehrend": "belehren",
    "belehrende": "belehrend",
    "belehrendem": "belehrend",
    "belehrenden": "belehrend",
    "belehrender": "belehrend",
    "belehrendes": "belehrend",
    "belehrest": "belehren",
    "belehret": "belehren",
    "belehrst": "belehren",
    "belehrt": "belehren",
    "belehrte": "belehren",
    "belehrtem": "belehrt",
    "belehrten": "belehren",
    "belehrter": "belehrt",
    "belehrtes": "belehrt",
    "belehrtest": "belehren",
    "belehrtet": "belehren",
    "beleibte": "beleibt",
    "beleibtem": "beleibt",
    "beleibten": "beleibt",
    "beleibter": "beleibt",
    "beleibtere": "beleibt",
    "beleibterem": "beleibt",
    "beleibteren": "beleibt",
    "beleibterer": "beleibt",
    "beleibteres": "beleibt",
    "beleibtes": "beleibt",
    "beleibteste": "beleibt",
    "beleibtestem": "beleibt",
    "beleibtesten": "beleibt",
    "beleibtester": "beleibt",
    "beleibtestes": "beleibt",
    "beleidige": "beleidigen",
    "beleidigend": "beleidigen",
    "beleidigende": "beleidigend",
    "beleidigendem": "beleidigend",
    "beleidigenden": "beleidigend",
    "beleidigender": "beleidigend",
    "beleidigendere": "beleidigend",
    "beleidigenderem": "beleidigend",
    "beleidigenderen": "beleidigend",
    "beleidigenderer": "beleidigend",
    "beleidigenderes": "beleidigend",
    "beleidigendes": "beleidigend",
    "beleidigendste": "beleidigend",
    "beleidigendstem": "beleidigend",
    "beleidigendsten": "beleidigend",
    "beleidigendster": "beleidigend",
    "beleidigendstes": "beleidigend",
    "beleidigest": "beleidigen",
    "beleidiget": "beleidigen",
    "beleidigst": "beleidigen",
    "beleidigt": "beleidigen",
    "beleidigte": "beleidigen",
    "beleidigtem": "beleidigt",
    "beleidigten": "beleidigen",
    "beleidigter": "beleidigt",
    "beleidigtere": "beleidigt",
    "beleidigterem": "beleidigt",
    "beleidigteren": "beleidigt",
    "beleidigterer": "beleidigt",
    "beleidigteres": "beleidigt",
    "beleidigtes": "beleidigt",
    "beleidigtest": "beleidigen",
    "beleidigteste": "beleidigt",
    "beleidigtestem": "beleidigt",
    "beleidigtesten": "beleidigt",
    "beleidigtester": "beleidigt",
    "beleidigtestes": "beleidigt",
    "beleidigtet": "beleidigen",
    "beleihe": "beleihen",
    "beleihend": "beleihen",
    "beleihende": "beleihend",
    "beleihendem": "beleihend",
    "beleihenden": "beleihend",
    "beleihender": "beleihend",
    "beleihendes": "beleihend",
    "beleihest": "beleihen",
    "beleihet": "beleihen",
    "beleihst": "beleihen",
    "beleiht": "beleihen",
    "belesenem": "belesen",
    "belesenen": "belesen",
    "belesener": "belesen",
    "belesenere": "belesen",
    "belesenerem": "belesen",
    "beleseneren": "belesen",
    "belesenerer": "belesen",
    "beleseneres": "belesen",
    "belesenes": "belesen",
    "belesenste": "belesen",
    "belesenstem": "belesen",
    "belesensten": "belesen",
    "belesenster": "belesen",
    "belesenstes": "belesen",
    "beleuchte": "beleuchten",
    "beleuchtend": "beleuchten",
    "beleuchtende": "beleuchtend",
    "beleuchtendem": "beleuchtend",
    "beleuchtenden": "beleuchtend",
    "beleuchtender": "beleuchtend",
    "beleuchtendes": "beleuchtend",
    "beleuchtest": "beleuchten",
    "beleuchtet": "beleuchten",
    "beleuchtete": "beleuchten",
    "beleuchtetem": "beleuchtet",
    "beleuchteten": "beleuchten",
    "beleuchteter": "beleuchtet",
    "beleuchtetere": "beleuchtet",
    "beleuchteterem": "beleuchtet",
    "beleuchteteren": "beleuchtet",
    "beleuchteterer": "beleuchtet",
    "beleuchteteres": "beleuchtet",
    "beleuchtetes": "beleuchtet",
    "beleuchtetest": "beleuchten",
    "beleuchteteste": "beleuchtet",
    "beleuchtetestem": "beleuchtet",
    "beleuchtetesten": "beleuchtet",
    "beleuchtetester": "beleuchtet",
    "beleuchtetestes": "beleuchtet",
    "beleuchtetet": "beleuchten",
    "belgischem": "belgisch",
    "belgischen": "belgisch",
    "belgischer": "belgisch",
    "belgischere": "belgisch",
    "belgischerem": "belgisch",
    "belgischeren": "belgisch",
    "belgischerer": "belgisch",
    "belgischeres": "belgisch",
    "belgisches": "belgisch",
    "belgischste": "belgisch",
    "belgischstem": "belgisch",
    "belgischsten": "belgisch",
    "belgischster": "belgisch",
    "belgischstes": "belgisch",
    "belichte": "belichten",
    "belichtend": "belichten",
    "belichtende": "belichtend",
    "belichtendem": "belichtend",
    "belichtenden": "belichtend",
    "belichtender": "belichtend",
    "belichtendes": "belichtend",
    "belichtest": "belichten",
    "belichtet": "belichten",
    "belichtete": "belichten",
    "belichtetem": "belichtet",
    "belichteten": "belichten",
    "belichteter": "belichtet",
    "belichtetes": "belichtet",
    "belichtetest": "belichten",
    "belichtetet": "belichten",
    "beliebe": "belieben",
    "beliebend": "belieben",
    "beliebende": "beliebend",
    "beliebendem": "beliebend",
    "beliebenden": "beliebend",
    "beliebender": "beliebend",
    "beliebendes": "beliebend",
    "beliebest": "belieben",
    "beliebet": "belieben",
    "beliebige": "beliebig",
    "beliebigem": "beliebig",
    "beliebigen": "beliebig",
    "beliebiger": "beliebig",
    "beliebiges": "beliebig",
    "beliebst": "belieben",
    "beliebt": "belieben",
    "beliebte": "belieben",
    "beliebtem": "beliebt",
    "beliebten": "belieben",
    "beliebter": "beliebt",
    "beliebtere": "beliebt",
    "beliebterem": "beliebt",
    "beliebteren": "beliebt",
    "beliebterer": "beliebt",
    "beliebteres": "beliebt",
    "beliebtes": "beliebt",
    "beliebtest": "belieben",
    "beliebteste": "beliebt",
    "beliebtestem": "beliebt",
    "beliebtesten": "beliebt",
    "beliebtester": "beliebt",
    "beliebtestes": "beliebt",
    "beliebtet": "belieben",
    "belief": "belaufen",
    "beliefe": "belaufen",
    "beliefen": "belaufen",
    "beliefere": "beliefern",
    "beliefernd": "beliefern",
    "beliefernde": "beliefernd",
    "belieferndem": "beliefernd",
    "beliefernden": "beliefernd",
    "beliefernder": "beliefernd",
    "belieferndes": "beliefernd",
    "belieferst": "beliefern",
    "beliefert": "beliefern",
    "belieferte": "beliefern",
    "beliefertem": "beliefert",
    "belieferten": "beliefern",
    "belieferter": "beliefert",
    "beliefertes": "beliefert",
    "beliefertest": "beliefern",
    "beliefertet": "beliefern",
    "beliefest": "belaufen",
    "beliefet": "belaufen",
    "beliefst": "belaufen",
    "belieft": "belaufen",
    "belieh": "beleihen",
    "beliehe": "beleihen",
    "beliehen": "beleihen",
    "beliehene": "beliehen",
    "beliehenem": "beliehen",
    "beliehenen": "beliehen",
    "beliehener": "beliehen",
    "beliehenes": "beliehen",
    "beliehest": "beleihen",
    "beliehet": "beleihen",
    "beliehst": "beleihen",
    "belieht": "beleihen",
    "beließ": "belassen",
    "beließe": "belassen",
    "beließen": "belassen",
    "beließest": "belassen",
    "beließet": "belassen",
    "beließt": "belassen",
    "belle": "bellen",
    "bellend": "bellen",
    "bellende": "bellend",
    "bellendem": "bellend",
    "bellenden": "bellend",
    "bellender": "bellend",
    "bellendere": "bellend",
    "bellenderem": "bellend",
    "bellenderen": "bellend",
    "bellenderer": "bellend",
    "bellenderes": "bellend",
    "bellendes": "bellend",
    "bellendste": "bellend",
    "bellendstem": "bellend",
    "bellendsten": "bellend",
    "bellendster": "bellend",
    "bellendstes": "bellend",
    "bellest": "bellen",
    "bellet": "bellen",
    "bellst": "bellen",
    "bellt": "bellen",
    "bellte": "bellen",
    "bellten": "bellen",
    "belltest": "bellen",
    "belltet": "bellen",
    "belog": "belügen",
    "belogen": "belügen",
    "belogene": "belogen",
    "belogenem": "belogen",
    "belogenen": "belogen",
    "belogener": "belogen",
    "belogenere": "belogen",
    "belogenerem": "belogen",
    "belogeneren": "belogen",
    "belogenerer": "belogen",
    "belogeneres": "belogen",
    "belogenes": "belogen",
    "belogenste": "belogen",
    "belogenstem": "belogen",
    "belogensten": "belogen",
    "belogenster": "belogen",
    "belogenstes": "belogen",
    "belogst": "belügen",
    "belogt": "belügen",
    "belohne": "belohnen",
    "belohnend": "belohnen",
    "belohnende": "belohnend",
    "belohnendem": "belohnend",
    "belohnenden": "belohnend",
    "belohnender": "belohnend",
    "belohnendes": "belohnend",
    "belohnest": "belohnen",
    "belohnet": "belohnen",
    "belohnst": "belohnen",
    "belohnt": "belohnen",
    "belohnte": "belohnen",
    "belohntem": "belohnt",
    "belohnten": "belohnen",
    "belohnter": "belohnt",
    "belohntes": "belohnt",
    "belohntest": "belohnen",
    "belohntet": "belohnen",
    "belud": "beladen",
    "beluden": "beladen",
    "beludest": "beladen",
    "beludet": "beladen",
    "belustige": "belustigen",
    "belustigend": "belustigen",
    "belustigende": "belustigend",
    "belustigendem": "belustigend",
    "belustigenden": "belustigend",
    "belustigender": "belustigend",
    "belustigendere": "belustigend",
    "belustigenderem": "belustigend",
    "belustigenderen": "belustigend",
    "belustigenderer": "belustigend",
    "belustigenderes": "belustigend",
    "belustigendes": "belustigend",
    "belustigendste": "belustigend",
    "belustigendstem": "belustigend",
    "belustigendsten": "belustigend",
    "belustigendster": "belustigend",
    "belustigendstes": "belustigend",
    "belustigest": "belustigen",
    "belustiget": "belustigen",
    "belustigst": "belustigen",
    "belustigt": "belustigen",
    "belustigte": "belustigen",
    "belustigtem": "belustigt",
    "belustigten": "belustigen",
    "belustigter": "belustigt",
    "belustigtes": "belustigt",
    "belustigtest": "belustigen",
    "belustigtet": "belustigen",
    "belächele": "belächeln",
    "belächelnd": "belächeln",
    "belächelnde": "belächelnd",
    "belächelndem": "belächelnd",
    "belächelnden": "belächelnd",
    "belächelnder": "belächelnd",
    "belächelndere": "belächelnd",
    "belächelnderem": "belächelnd",
    "belächelnderen": "belächelnd",
    "belächelnderer": "belächelnd",
    "belächelnderes": "belächelnd",
    "belächelndes": "belächelnd",
    "belächelndste": "belächelnd",
    "belächelndstem": "belächelnd",
    "belächelndsten": "belächelnd",
    "belächelndster": "belächelnd",
    "belächelndstes": "belächelnd",
    "belächelst": "belächeln",
    "belächelt": "belächeln",
    "belächelte": "belächeln",
    "belächeltem": "belächelt",
    "belächelten": "belächeln",
    "belächelter": "belächelt",
    "belächeltere": "belächelt",
    "belächelterem": "belächelt",
    "belächelteren": "belächelt",
    "belächelterer": "belächelt",
    "belächelteres": "belächelt",
    "belächeltes": "belächelt",
    "belächeltest": "belächeln",
    "belächelteste": "belächelt",
    "belächeltestem": "belächelt",
    "belächeltesten": "belächelt",
    "belächeltester": "belächelt",
    "belächeltestes": "belächelt",
    "belächeltet": "belächeln",
    "belächle": "belächeln",
    "belädst": "beladen",
    "belädt": "beladen",
    "belämmere": "belämmern",
    "belämmernd": "belämmern",
    "belämmernde": "belämmernd",
    "belämmerndem": "belämmernd",
    "belämmernden": "belämmernd",
    "belämmernder": "belämmernd",
    "belämmerndere": "belämmernd",
    "belämmernderem": "belämmernd",
    "belämmernderen": "belämmernd",
    "belämmernderer": "belämmernd",
    "belämmernderes": "belämmernd",
    "belämmerndes": "belämmernd",
    "belämmerndste": "belämmernd",
    "belämmerndstem": "belämmernd",
    "belämmerndsten": "belämmernd",
    "belämmerndster": "belämmernd",
    "belämmerndstes": "belämmernd",
    "belämmerst": "belämmern",
    "belämmert": "belämmern",
    "belämmerte": "belämmern",
    "belämmertem": "belämmert",
    "belämmerten": "belämmern",
    "belämmerter": "belämmert",
    "belämmertere": "belämmert",
    "belämmerterem": "belämmert",
    "belämmerteren": "belämmert",
    "belämmerterer": "belämmert",
    "belämmerteres": "belämmert",
    "belämmertes": "belämmert",
    "belämmertest": "belämmern",
    "belämmerteste": "belämmert",
    "belämmertestem": "belämmert",
    "belämmertesten": "belämmert",
    "belämmertester": "belämmert",
    "belämmertestes": "belämmert",
    "belämmertet": "belämmern",
    "belästige": "belästigen",
    "belästigend": "belästigen",
    "belästigende": "belästigend",
    "belästigendem": "belästigend",
    "belästigenden": "belästigend",
    "belästigender": "belästigend",
    "belästigendere": "belästigend",
    "belästigenderem": "belästigend",
    "belästigenderen": "belästigend",
    "belästigenderer": "belästigend",
    "belästigenderes": "belästigend",
    "belästigendes": "belästigend",
    "belästigendste": "belästigend",
    "belästigendstem": "belästigend",
    "belästigendsten": "belästigend",
    "belästigendster": "belästigend",
    "belästigendstes": "belästigend",
    "belästigest": "belästigen",
    "belästiget": "belästigen",
    "belästigst": "belästigen",
    "belästigt": "belästigen",
    "belästigte": "belästigen",
    "belästigtem": "belästigt",
    "belästigten": "belästigen",
    "belästigter": "belästigt",
    "belästigtere": "belästigt",
    "belästigterem": "belästigt",
    "belästigteren": "belästigt",
    "belästigterer": "belästigt",
    "belästigteres": "belästigt",
    "belästigtes": "belästigt",
    "belästigtest": "belästigen",
    "belästigteste": "belästigt",
    "belästigtestem": "belästigt",
    "belästigtesten": "belästigt",
    "belästigtester": "belästigt",
    "belästigtestes": "belästigt",
    "belästigtet": "belästigen",
    "beläufst": "belaufen",
    "beläuft": "belaufen",
    "beläßt": "belassen",
    "belöge": "belügen",
    "belögen": "belügen",
    "belögest": "belügen",
    "belöget": "belügen",
    "belüde": "beladen",
    "belüden": "beladen",
    "belüdest": "beladen",
    "belüdet": "beladen",
    "belüfte": "belüften",
    "belüftend": "belüften",
    "belüftende": "belüftend",
    "belüftendem": "belüftend",
    "belüftenden": "belüftend",
    "belüftender": "belüftend",
    "belüftendere": "belüftend",
    "belüftenderem": "belüftend",
    "belüftenderen": "belüftend",
    "belüftenderer": "belüftend",
    "belüftenderes": "belüftend",
    "belüftendes": "belüftend",
    "belüftendste": "belüftend",
    "belüftendstem": "belüftend",
    "belüftendsten": "belüftend",
    "belüftendster": "belüftend",
    "belüftendstes": "belüftend",
    "belüftest": "belüften",
    "belüftet": "belüften",
    "belüftete": "belüften",
    "belüftetem": "belüftet",
    "belüfteten": "belüften",
    "belüfteter": "belüftet",
    "belüftetere": "belüftet",
    "belüfteterem": "belüftet",
    "belüfteteren": "belüftet",
    "belüfteterer": "belüftet",
    "belüfteteres": "belüftet",
    "belüftetes": "belüftet",
    "belüftetest": "belüften",
    "belüfteteste": "belüftet",
    "belüftetestem": "belüftet",
    "belüftetesten": "belüftet",
    "belüftetester": "belüftet",
    "belüftetestes": "belüftet",
    "belüftetet": "belüften",
    "belüge": "belügen",
    "belügend": "belügen",
    "belügende": "belügend",
    "belügendem": "belügend",
    "belügenden": "belügend",
    "belügender": "belügend",
    "belügendes": "belügend",
    "belügest": "belügen",
    "belüget": "belügen",
    "belügst": "belügen",
    "belügt": "belügen",
    "bemale": "bemalen",
    "bemalend": "bemalen",
    "bemalende": "bemalend",
    "bemalendem": "bemalend",
    "bemalenden": "bemalend",
    "bemalender": "bemalend",
    "bemalendes": "bemalend",
    "bemalest": "bemalen",
    "bemalet": "bemalen",
    "bemalst": "bemalen",
    "bemalt": "bemalen",
    "bemalte": "bemalen",
    "bemaltem": "bemalt",
    "bemalten": "bemalen",
    "bemalter": "bemalt",
    "bemaltere": "bemalt",
    "bemalterem": "bemalt",
    "bemalteren": "bemalt",
    "bemalterer": "bemalt",
    "bemalteres": "bemalt",
    "bemaltes": "bemalt",
    "bemaltest": "bemalen",
    "bemalteste": "bemalt",
    "bemaltestem": "bemalt",
    "bemaltesten": "bemalt",
    "bemaltester": "bemalt",
    "bemaltestes": "bemalt",
    "bemaltet": "bemalen",
    "bemanne": "bemannen",
    "bemannend": "bemannen",
    "bemannende": "bemannend",
    "bemannendem": "bemannend",
    "bemannenden": "bemannend",
    "bemannender": "bemannend",
    "bemannendes": "bemannend",
    "bemannest": "bemannen",
    "bemannet": "bemannen",
    "bemannst": "bemannen",
    "bemannt": "bemannen",
    "bemannte": "bemannen",
    "bemanntem": "bemannt",
    "bemannten": "bemannen",
    "bemannter": "bemannt",
    "bemanntes": "bemannt",
    "bemanntest": "bemannen",
    "bemanntet": "bemannen",
    "bemerkbarem": "bemerkbar",
    "bemerkbaren": "bemerkbar",
    "bemerkbarer": "bemerkbar",
    "bemerkbares": "bemerkbar",
    "bemerke": "bemerken",
    "bemerkend": "bemerken",
    "bemerkende": "bemerkend",
    "bemerkendem": "bemerkend",
    "bemerkenden": "bemerkend",
    "bemerkender": "bemerkend",
    "bemerkendes": "bemerkend",
    "bemerkenswertem": "bemerkenswert",
    "bemerkenswerten": "bemerkenswert",
    "bemerkenswerter": "bemerkenswert",
    "bemerkenswertere": "bemerkenswert",
    "bemerkenswerterem": "bemerkenswert",
    "bemerkenswerteren": "bemerkenswert",
    "bemerkenswerterer": "bemerkenswert",
    "bemerkenswerteres": "bemerkenswert",
    "bemerkenswertes": "bemerkenswert",
    "bemerkenswerteste": "bemerkenswert",
    "bemerkenswertestem": "bemerkenswert",
    "bemerkenswertesten": "bemerkenswert",
    "bemerkenswertester": "bemerkenswert",
    "bemerkenswertestes": "bemerkenswert",
    "bemerkest": "bemerken",
    "bemerket": "bemerken",
    "bemerkst": "bemerken",
    "bemerkt": "bemerken",
    "bemerkte": "bemerken",
    "bemerktem": "bemerkt",
    "bemerkten": "bemerken",
    "bemerkter": "bemerkt",
    "bemerktes": "bemerkt",
    "bemerktest": "bemerken",
    "bemerktet": "bemerken",
    "bemitleide": "bemitleiden",
    "bemitleidend": "bemitleiden",
    "bemitleidende": "bemitleidend",
    "bemitleidendem": "bemitleidend",
    "bemitleidenden": "bemitleidend",
    "bemitleidender": "bemitleidend",
    "bemitleidendere": "bemitleidend",
    "bemitleidenderem": "bemitleidend",
    "bemitleidenderen": "bemitleidend",
    "bemitleidenderer": "bemitleidend",
    "bemitleidenderes": "bemitleidend",
    "bemitleidendes": "bemitleidend",
    "bemitleidendste": "bemitleidend",
    "bemitleidendstem": "bemitleidend",
    "bemitleidendsten": "bemitleidend",
    "bemitleidendster": "bemitleidend",
    "bemitleidendstes": "bemitleidend",
    "bemitleidenswertem": "bemitleidenswert",
    "bemitleidenswerten": "bemitleidenswert",
    "bemitleidenswerter": "bemitleidenswert",
    "bemitleidenswertere": "bemitleidenswert",
    "bemitleidenswerterem": "bemitleidenswert",
    "bemitleidenswerteren": "bemitleidenswert",
    "bemitleidenswerterer": "bemitleidenswert",
    "bemitleidenswerteres": "bemitleidenswert",
    "bemitleidenswertes": "bemitleidenswert",
    "bemitleidenswerteste": "bemitleidenswert",
    "bemitleidenswertestem": "bemitleidenswert",
    "bemitleidenswertesten": "bemitleidenswert",
    "bemitleidenswertester": "bemitleidenswert",
    "bemitleidenswertestes": "bemitleidenswert",
    "bemitleidest": "bemitleiden",
    "bemitleidet": "bemitleiden",
    "bemitleidete": "bemitleiden",
    "bemitleidetem": "bemitleidet",
    "bemitleideten": "bemitleiden",
    "bemitleideter": "bemitleidet",
    "bemitleidetere": "bemitleidet",
    "bemitleideterem": "bemitleidet",
    "bemitleideteren": "bemitleidet",
    "bemitleideterer": "bemitleidet",
    "bemitleideteres": "bemitleidet",
    "bemitleidetes": "bemitleidet",
    "bemitleidetest": "bemitleiden",
    "bemitleideteste": "bemitleidet",
    "bemitleidetestem": "bemitleidet",
    "bemitleidetesten": "bemitleidet",
    "bemitleidetester": "bemitleidet",
    "bemitleidetestes": "bemitleidet",
    "bemitleidetet": "bemitleiden",
    "bemuttere": "bemuttern",
    "bemutternd": "bemuttern",
    "bemutternde": "bemutternd",
    "bemutterndem": "bemutternd",
    "bemutternden": "bemutternd",
    "bemutternder": "bemutternd",
    "bemutterndes": "bemutternd",
    "bemutterst": "bemuttern",
    "bemuttert": "bemuttern",
    "bemutterte": "bemuttern",
    "bemuttertem": "bemuttert",
    "bemutterten": "bemuttern",
    "bemutterter": "bemuttert",
    "bemuttertes": "bemuttert",
    "bemuttertest": "bemuttern",
    "bemuttertet": "bemuttern",
    "bemächtige": "bemächtigen",
    "bemächtigend": "bemächtigen",
    "bemächtigende": "bemächtigend",
    "bemächtigendem": "bemächtigend",
    "bemächtigenden": "bemächtigend",
    "bemächtigender": "bemächtigend",
    "bemächtigendes": "bemächtigend",
    "bemächtigest": "bemächtigen",
    "bemächtiget": "bemächtigen",
    "bemächtigst": "bemächtigen",
    "bemächtigt": "bemächtigen",
    "bemächtigte": "bemächtigen",
    "bemächtigtem": "bemächtigt",
    "bemächtigten": "bemächtigen",
    "bemächtigter": "bemächtigt",
    "bemächtigtes": "bemächtigt",
    "bemächtigtest": "bemächtigen",
    "bemächtigtet": "bemächtigen",
    "bemängele": "bemängeln",
    "bemängelnd": "bemängeln",
    "bemängelnde": "bemängelnd",
    "bemängelndem": "bemängelnd",
    "bemängelnden": "bemängelnd",
    "bemängelnder": "bemängelnd",
    "bemängelndes": "bemängelnd",
    "bemängelst": "bemängeln",
    "bemängelt": "bemängeln",
    "bemängelte": "bemängeln",
    "bemängeltem": "bemängelt",
    "bemängelten": "bemängeln",
    "bemängelter": "bemängelt",
    "bemängeltere": "bemängelt",
    "bemängelterem": "bemängelt",
    "bemängelteren": "bemängelt",
    "bemängelterer": "bemängelt",
    "bemängelteres": "bemängelt",
    "bemängeltes": "bemängelt",
    "bemängeltest": "bemängeln",
    "bemängelteste": "bemängelt",
    "bemängeltestem": "bemängelt",
    "bemängeltesten": "bemängelt",
    "bemängeltester": "bemängelt",
    "bemängeltestes": "bemängelt",
    "bemängeltet": "bemängeln",
    "bemängle": "bemängeln",
    "bemäntele": "bemänteln",
    "bemäntelnd": "bemänteln",
    "bemäntelnde": "bemäntelnd",
    "bemäntelndem": "bemäntelnd",
    "bemäntelnden": "bemäntelnd",
    "bemäntelnder": "bemäntelnd",
    "bemäntelndes": "bemäntelnd",
    "bemäntelst": "bemänteln",
    "bemäntelt": "bemänteln",
    "bemäntelte": "bemänteln",
    "bemänteltem": "bemäntelt",
    "bemäntelten": "bemänteln",
    "bemäntelter": "bemäntelt",
    "bemänteltes": "bemäntelt",
    "bemänteltest": "bemänteln",
    "bemänteltet": "bemänteln",
    "bemäntle": "bemänteln",
    "bemühe": "bemühen",
    "bemühend": "bemühen",
    "bemühende": "bemühend",
    "bemühendem": "bemühend",
    "bemühenden": "bemühend",
    "bemühender": "bemühend",
    "bemühendes": "bemühend",
    "bemühest": "bemühen",
    "bemühet": "bemühen",
    "bemühst": "bemühen",
    "bemüht": "bemühen",
    "bemühte": "bemühen",
    "bemühtem": "bemüht",
    "bemühten": "bemühen",
    "bemühter": "bemüht",
    "bemühtes": "bemüht",
    "bemühtest": "bemühen",
    "bemühtet": "bemühen",
    "benachbarte": "benachbart",
    "benachbartem": "benachbart",
    "benachbarten": "benachbart",
    "benachbarter": "benachbart",
    "benachbartes": "benachbart",
    "benachrichtige": "benachrichtigen",
    "benachrichtigend": "benachrichtigen",
    "benachrichtigende": "benachrichtigend",
    "benachrichtigendem": "benachrichtigend",
    "benachrichtigenden": "benachrichtigend",
    "benachrichtigender": "benachrichtigend",
    "benachrichtigendes": "benachrichtigend",
    "benachrichtigest": "benachrichtigen",
    "benachrichtiget": "benachrichtigen",
    "benachrichtigst": "benachrichtigen",
    "benachrichtigt": "benachrichtigen",
    "benachrichtigte": "benachrichtigen",
    "benachrichtigtem": "benachrichtigt",
    "benachrichtigten": "benachrichtigen",
    "benachrichtigter": "benachrichtigt",
    "benachrichtigtes": "benachrichtigt",
    "benachrichtigtest": "benachrichtigen",
    "benachrichtigtet": "benachrichtigen",
    "benachteilige": "benachteiligen",
    "benachteiligend": "benachteiligen",
    "benachteiligende": "benachteiligend",
    "benachteiligendem": "benachteiligend",
    "benachteiligenden": "benachteiligend",
    "benachteiligender": "benachteiligend",
    "benachteiligendes": "benachteiligend",
    "benachteiligest": "benachteiligen",
    "benachteiliget": "benachteiligen",
    "benachteiligst": "benachteiligen",
    "benachteiligt": "benachteiligen",
    "benachteiligte": "benachteiligen",
    "benachteiligtem": "benachteiligt",
    "benachteiligten": "benachteiligen",
    "benachteiligter": "benachteiligt",
    "benachteiligtere": "benachteiligt",
    "benachteiligterem": "benachteiligt",
    "benachteiligteren": "benachteiligt",
    "benachteiligterer": "benachteiligt",
    "benachteiligteres": "benachteiligt",
    "benachteiligtes": "benachteiligt",
    "benachteiligtest": "benachteiligen",
    "benachteiligtestem": "benachteiligt",
    "benachteiligtesten": "benachteiligt",
    "benachteiligtester": "benachteiligt",
    "benachteiligtestes": "benachteiligt",
    "benachteiligtet": "benachteiligen",
    "benahm": "benehmen",
    "benahmen": "benehmen",
    "benahmst": "benehmen",
    "benahmt": "benehmen",
    "benannt": "benennen",
    "benannte": "benannt",
    "benanntem": "benannt",
    "benannten": "benannt",
    "benannter": "benannt",
    "benanntes": "benannt",
    "benanntest": "benennen",
    "benanntet": "benennen",
    "benebele": "benebeln",
    "benebelnd": "benebeln",
    "benebelnde": "benebelnd",
    "benebelndem": "benebelnd",
    "benebelnden": "benebelnd",
    "benebelnder": "benebelnd",
    "benebelndere": "benebelnd",
    "benebelnderem": "benebelnd",
    "benebelnderen": "benebelnd",
    "benebelnderer": "benebelnd",
    "benebelnderes": "benebelnd",
    "benebelndes": "benebelnd",
    "benebelndste": "benebelnd",
    "benebelndstem": "benebelnd",
    "benebelndsten": "benebelnd",
    "benebelndster": "benebelnd",
    "benebelndstes": "benebelnd",
    "benebelst": "benebeln",
    "benebelt": "benebeln",
    "benebelte": "benebeln",
    "benebeltem": "benebelt",
    "benebelten": "benebeln",
    "benebelter": "benebelt",
    "benebeltere": "benebelt",
    "benebelterem": "benebelt",
    "benebelteren": "benebelt",
    "benebelterer": "benebelt",
    "benebelteres": "benebelt",
    "benebeltes": "benebelt",
    "benebeltest": "benebeln",
    "benebelteste": "benebelt",
    "benebeltestem": "benebelt",
    "benebeltesten": "benebelt",
    "benebeltester": "benebelt",
    "benebeltestes": "benebelt",
    "benebeltet": "benebeln",
    "beneble": "benebeln",
    "benehme": "benehmen",
    "benehmend": "benehmen",
    "benehmende": "benehmend",
    "benehmendem": "benehmend",
    "benehmenden": "benehmend",
    "benehmender": "benehmend",
    "benehmendere": "benehmend",
    "benehmenderem": "benehmend",
    "benehmenderen": "benehmend",
    "benehmenderer": "benehmend",
    "benehmenderes": "benehmend",
    "benehmendes": "benehmend",
    "benehmendste": "benehmend",
    "benehmendstem": "benehmend",
    "benehmendsten": "benehmend",
    "benehmendster": "benehmend",
    "benehmendstes": "benehmend",
    "benehmest": "benehmen",
    "benehmet": "benehmen",
    "benehmt": "benehmen",
    "beneide": "beneiden",
    "beneidend": "beneiden",
    "beneidende": "beneidend",
    "beneidendem": "beneidend",
    "beneidenden": "beneidend",
    "beneidender": "beneidend",
    "beneidendere": "beneidend",
    "beneidenderem": "beneidend",
    "beneidenderen": "beneidend",
    "beneidenderer": "beneidend",
    "beneidenderes": "beneidend",
    "beneidendes": "beneidend",
    "beneidendste": "beneidend",
    "beneidendstem": "beneidend",
    "beneidendsten": "beneidend",
    "beneidendster": "beneidend",
    "beneidendstes": "beneidend",
    "beneidenswertem": "beneidenswert",
    "beneidenswerten": "beneidenswert",
    "beneidenswerter": "beneidenswert",
    "beneidenswertere": "beneidenswert",
    "beneidenswerterem": "beneidenswert",
    "beneidenswerteren": "beneidenswert",
    "beneidenswerterer": "beneidenswert",
    "beneidenswerteres": "beneidenswert",
    "beneidenswertes": "beneidenswert",
    "beneidenswerteste": "beneidenswert",
    "beneidenswertestem": "beneidenswert",
    "beneidenswertesten": "beneidenswert",
    "beneidenswertester": "beneidenswert",
    "beneidenswertestes": "beneidenswert",
    "beneidest": "beneiden",
    "beneidet": "beneiden",
    "beneidete": "beneiden",
    "beneidetem": "beneidet",
    "beneideten": "beneiden",
    "beneideter": "beneidet",
    "beneidetere": "beneidet",
    "beneideterem": "beneidet",
    "beneideteren": "beneidet",
    "beneideterer": "beneidet",
    "beneideteres": "beneidet",
    "beneidetes": "beneidet",
    "beneidetest": "beneiden",
    "beneideteste": "beneidet",
    "beneidetestem": "beneidet",
    "beneidetesten": "beneidet",
    "beneidetester": "beneidet",
    "beneidetestes": "beneidet",
    "beneidetet": "beneiden",
    "benenne": "benennen",
    "benennend": "benennen",
    "benennende": "benennend",
    "benennendem": "benennend",
    "benennenden": "benennend",
    "benennender": "benennend",
    "benennendes": "benennend",
    "benennest": "benennen",
    "benennet": "benennen",
    "benennst": "benennen",
    "benennt": "benennen",
    "benetze": "benetzen",
    "benetzend": "benetzen",
    "benetzende": "benetzend",
    "benetzendem": "benetzend",
    "benetzenden": "benetzend",
    "benetzender": "benetzend",
    "benetzendes": "benetzend",
    "benetzest": "benetzen",
    "benetzet": "benetzen",
    "benetzt": "benetzen",
    "benetzte": "benetzen",
    "benetztem": "benetzt",
    "benetzten": "benetzen",
    "benetzter": "benetzt",
    "benetztes": "benetzt",
    "benetztest": "benetzen",
    "benetztet": "benetzen",
    "benimm": "benehmen",
    "benimmst": "benehmen",
    "benimmt": "benehmen",
    "benommen": "benehmen",
    "benommene": "benommen",
    "benommenem": "benommen",
    "benommenen": "benommen",
    "benommener": "benommen",
    "benommenere": "benommen",
    "benommenerem": "benommen",
    "benommeneren": "benommen",
    "benommenerer": "benommen",
    "benommeneres": "benommen",
    "benommenes": "benommen",
    "benommenste": "benommen",
    "benommenstem": "benommen",
    "benommensten": "benommen",
    "benommenster": "benommen",
    "benommenstes": "benommen",
    "benote": "benoten",
    "benotend": "benoten",
    "benotende": "benotend",
    "benotendem": "benotend",
    "benotenden": "benotend",
    "benotender": "benotend",
    "benotendes": "benotend",
    "benotest": "benoten",
    "benotet": "benoten",
    "benotete": "benoten",
    "benotetem": "benotet",
    "benoteten": "benoten",
    "benoteter": "benotet",
    "benotetes": "benotet",
    "benotetest": "benoten",
    "benotetet": "benoten",
    "benutze": "benutzen",
    "benutzend": "benutzen",
    "benutzende": "benutzend",
    "benutzendem": "benutzend",
    "benutzenden": "benutzend",
    "benutzender": "benutzend",
    "benutzendes": "benutzend",
    "benutzest": "benutzen",
    "benutzet": "benutzen",
    "benutzt": "benutzen",
    "benutzte": "benutzen",
    "benutztem": "benutzt",
    "benutzten": "benutzen",
    "benutzter": "benutzt",
    "benutztere": "benutzt",
    "benutzterem": "benutzt",
    "benutzteren": "benutzt",
    "benutzterer": "benutzt",
    "benutzteres": "benutzt",
    "benutztes": "benutzt",
    "benutztest": "benutzen",
    "benutzteste": "benutzt",
    "benutztestem": "benutzt",
    "benutztesten": "benutzt",
    "benutztester": "benutzt",
    "benutztestes": "benutzt",
    "benutztet": "benutzen",
    "benähme": "benehmen",
    "benähmen": "benehmen",
    "benähmest": "benehmen",
    "benähmet": "benehmen",
    "benötige": "benötigen",
    "benötigend": "benötigen",
    "benötigende": "benötigend",
    "benötigendem": "benötigend",
    "benötigenden": "benötigend",
    "benötigender": "benötigend",
    "benötigendes": "benötigend",
    "benötigest": "benötigen",
    "benötiget": "benötigen",
    "benötigst": "benötigen",
    "benötigt": "benötigen",
    "benötigte": "benötigen",
    "benötigtem": "benötigt",
    "benötigten": "benötigen",
    "benötigter": "benötigt",
    "benötigtere": "benötigt",
    "benötigterem": "benötigt",
    "benötigteren": "benötigt",
    "benötigterer": "benötigt",
    "benötigteres": "benötigt",
    "benötigtes": "benötigt",
    "benötigtest": "benötigen",
    "benötigteste": "benötigt",
    "benötigtestem": "benötigt",
    "benötigtesten": "benötigt",
    "benötigtester": "benötigt",
    "benötigtestes": "benötigt",
    "benötigtet": "benötigen",
    "benütze": "benützen",
    "benützend": "benützen",
    "benützendem": "benützend",
    "benützender": "benützend",
    "benützendes": "benützend",
    "benützest": "benützen",
    "benützet": "benützen",
    "benützt": "benützen",
    "benützte": "benützen",
    "benütztem": "benützt",
    "benützten": "benützt",
    "benützter": "benützt",
    "benützterem": "benützt",
    "benützterer": "benützt",
    "benützteres": "benützt",
    "benütztes": "benützt",
    "benütztest": "benützen",
    "benütztestem": "benützt",
    "benütztester": "benützt",
    "benütztestes": "benützt",
    "benütztet": "benützen",
    "beobachte": "beobachten",
    "beobachtend": "beobachten",
    "beobachtende": "beobachtend",
    "beobachtendem": "beobachtend",
    "beobachtenden": "beobachtend",
    "beobachtender": "beobachtend",
    "beobachtendes": "beobachtend",
    "beobachtest": "beobachten",
    "beobachtet": "beobachten",
    "beobachtete": "beobachten",
    "beobachtetem": "beobachtet",
    "beobachteten": "beobachten",
    "beobachteter": "beobachtet",
    "beobachtetere": "beobachtet",
    "beobachteterem": "beobachtet",
    "beobachteteren": "beobachtet",
    "beobachteterer": "beobachtet",
    "beobachteteres": "beobachtet",
    "beobachtetes": "beobachtet",
    "beobachtetest": "beobachten",
    "beobachteteste": "beobachtet",
    "beobachtetestem": "beobachtet",
    "beobachtetesten": "beobachtet",
    "beobachtetester": "beobachtet",
    "beobachtetestes": "beobachtet",
    "beobachtetet": "beobachten",
    "beordere": "beordern",
    "beordernd": "beordern",
    "beordernde": "beordernd",
    "beorderndem": "beordernd",
    "beordernden": "beordernd",
    "beordernder": "beordernd",
    "beorderndere": "beordernd",
    "beordernderem": "beordernd",
    "beordernderen": "beordernd",
    "beordernderer": "beordernd",
    "beordernderes": "beordernd",
    "beorderndes": "beordernd",
    "beorderndste": "beordernd",
    "beorderndstem": "beordernd",
    "beorderndsten": "beordernd",
    "beorderndster": "beordernd",
    "beorderndstes": "beordernd",
    "beorderst": "beordern",
    "beordert": "beordern",
    "beorderte": "beordern",
    "beordertem": "beordert",
    "beorderten": "beordern",
    "beorderter": "beordert",
    "beordertere": "beordert",
    "beorderterem": "beordert",
    "beorderteren": "beordert",
    "beorderterer": "beordert",
    "beorderteres": "beordert",
    "beordertes": "beordert",
    "beordertest": "beordern",
    "beorderteste": "beordert",
    "beordertestem": "beordert",
    "beordertesten": "beordert",
    "beordertester": "beordert",
    "beordertestes": "beordert",
    "beordertet": "beordern",
    "bepacke": "bepacken",
    "bepackend": "bepacken",
    "bepackende": "bepackend",
    "bepackendem": "bepackend",
    "bepackenden": "bepackend",
    "bepackender": "bepackend",
    "bepackendes": "bepackend",
    "bepackest": "bepacken",
    "bepacket": "bepacken",
    "bepackst": "bepacken",
    "bepackt": "bepacken",
    "bepackte": "bepacken",
    "bepacktem": "bepackt",
    "bepackten": "bepacken",
    "bepackter": "bepackt",
    "bepacktere": "bepackt",
    "bepackterem": "bepackt",
    "bepackteren": "bepackt",
    "bepackterer": "bepackt",
    "bepackteres": "bepackt",
    "bepacktes": "bepackt",
    "bepacktest": "bepacken",
    "bepackteste": "bepackt",
    "bepacktestem": "bepackt",
    "bepacktesten": "bepackt",
    "bepacktester": "bepackt",
    "bepacktestes": "bepackt",
    "bepacktet": "bepacken",
    "bepflanze": "bepflanzen",
    "bepflanzend": "bepflanzen",
    "bepflanzende": "bepflanzend",
    "bepflanzendem": "bepflanzend",
    "bepflanzenden": "bepflanzend",
    "bepflanzender": "bepflanzend",
    "bepflanzendes": "bepflanzend",
    "bepflanzest": "bepflanzen",
    "bepflanzet": "bepflanzen",
    "bepflanzt": "bepflanzen",
    "bepflanzte": "bepflanzen",
    "bepflanztem": "bepflanzt",
    "bepflanzten": "bepflanzen",
    "bepflanzter": "bepflanzt",
    "bepflanztere": "bepflanzt",
    "bepflanzterem": "bepflanzt",
    "bepflanzteren": "bepflanzt",
    "bepflanzterer": "bepflanzt",
    "bepflanzteres": "bepflanzt",
    "bepflanztes": "bepflanzt",
    "bepflanztest": "bepflanzen",
    "bepflanzteste": "bepflanzt",
    "bepflanztestem": "bepflanzt",
    "bepflanztesten": "bepflanzt",
    "bepflanztester": "bepflanzt",
    "bepflanztestes": "bepflanzt",
    "bepflanztet": "bepflanzen",
    "bepiesele": "bepieseln",
    "bepieselnd": "bepieseln",
    "bepieselnde": "bepieselnd",
    "bepieselndem": "bepieselnd",
    "bepieselnden": "bepieselnd",
    "bepieselnder": "bepieselnd",
    "bepieselndere": "bepieselnd",
    "bepieselnderem": "bepieselnd",
    "bepieselnderen": "bepieselnd",
    "bepieselnderer": "bepieselnd",
    "bepieselnderes": "bepieselnd",
    "bepieselndes": "bepieselnd",
    "bepieselndste": "bepieselnd",
    "bepieselndstem": "bepieselnd",
    "bepieselndsten": "bepieselnd",
    "bepieselndster": "bepieselnd",
    "bepieselndstes": "bepieselnd",
    "bepieselst": "bepieseln",
    "bepieselt": "bepieseln",
    "bepieselte": "bepieseln",
    "bepieseltem": "bepieselt",
    "bepieselten": "bepieseln",
    "bepieselter": "bepieselt",
    "bepieseltes": "bepieselt",
    "bepieseltest": "bepieseln",
    "bepieseltet": "bepieseln",
    "bepiesle": "bepieseln",
    "bepinsele": "bepinseln",
    "bepinselnd": "bepinseln",
    "bepinselnde": "bepinselnd",
    "bepinselndem": "bepinselnd",
    "bepinselnden": "bepinselnd",
    "bepinselnder": "bepinselnd",
    "bepinselndere": "bepinselnd",
    "bepinselnderem": "bepinselnd",
    "bepinselnderen": "bepinselnd",
    "bepinselnderer": "bepinselnd",
    "bepinselnderes": "bepinselnd",
    "bepinselndes": "bepinselnd",
    "bepinselndste": "bepinselnd",
    "bepinselndstem": "bepinselnd",
    "bepinselndsten": "bepinselnd",
    "bepinselndster": "bepinselnd",
    "bepinselndstes": "bepinselnd",
    "bepinselst": "bepinseln",
    "bepinselt": "bepinseln",
    "bepinselte": "bepinseln",
    "bepinseltem": "bepinselt",
    "bepinselten": "bepinseln",
    "bepinselter": "bepinselt",
    "bepinseltes": "bepinselt",
    "bepinseltest": "bepinseln",
    "bepinseltet": "bepinseln",
    "bepinsle": "bepinseln",
    "bepisse": "bepissen",
    "bepissend": "bepissen",
    "bepissende": "bepissend",
    "bepissendem": "bepissend",
    "bepissenden": "bepissend",
    "bepissender": "bepissend",
    "bepissendere": "bepissend",
    "bepissenderem": "bepissend",
    "bepissenderen": "bepissend",
    "bepissenderer": "bepissend",
    "bepissenderes": "bepissend",
    "bepissendes": "bepissend",
    "bepissendste": "bepissend",
    "bepissendstem": "bepissend",
    "bepissendsten": "bepissend",
    "bepissendster": "bepissend",
    "bepissendstes": "bepissend",
    "bepissest": "bepissen",
    "bepisset": "bepissen",
    "bepißt": "bepissen",
    "bepißte": "bepissen",
    "bepißtem": "bepißt",
    "bepißten": "bepissen",
    "bepißter": "bepißt",
    "bepißtere": "bepißt",
    "bepißterem": "bepißt",
    "bepißteren": "bepißt",
    "bepißterer": "bepißt",
    "bepißteres": "bepißt",
    "bepißtes": "bepißt",
    "bepißtest": "bepissen",
    "bepißteste": "bepißt",
    "bepißtestem": "bepißt",
    "bepißtesten": "bepißt",
    "bepißtester": "bepißt",
    "bepißtestes": "bepißt",
    "bepißtet": "bepissen",
    "bequem": "bequemen",
    "bequeme": "bequem",
    "bequemem": "bequem",
    "bequemen": "bequem",
    "bequemend": "bequemen",
    "bequemende": "bequemend",
    "bequemendem": "bequemend",
    "bequemenden": "bequemend",
    "bequemender": "bequemend",
    "bequemendes": "bequemend",
    "bequemer": "bequem",
    "bequemere": "bequem",
    "bequemerem": "bequem",
    "bequemeren": "bequem",
    "bequemerer": "bequem",
    "bequemeres": "bequem",
    "bequemes": "bequem",
    "bequemest": "bequemen",
    "bequemet": "bequemen",
    "bequemliche": "bequemlich",
    "bequemlichem": "bequemlich",
    "bequemlichen": "bequemlich",
    "bequemlicher": "bequemlich",
    "bequemlichere": "bequemlich",
    "bequemlicherem": "bequemlich",
    "bequemlicheren": "bequemlich",
    "bequemlicherer": "bequemlich",
    "bequemlicheres": "bequemlich",
    "bequemliches": "bequemlich",
    "bequemlichstem": "bequemlich",
    "bequemlichsten": "bequemlich",
    "bequemlichster": "bequemlich",
    "bequemlichstes": "bequemlich",
    "bequemst": "bequemen",
    "bequemste": "bequem",
    "bequemstem": "bequem",
    "bequemsten": "bequem",
    "bequemster": "bequem",
    "bequemstes": "bequem",
    "bequemt": "bequemen",
    "bequemte": "bequemen",
    "bequemtem": "bequemt",
    "bequemten": "bequemen",
    "bequemter": "bequemt",
    "bequemtes": "bequemt",
    "bequemtest": "bequemen",
    "bequemtet": "bequemen",
    "berappe": "berappen",
    "berappend": "berappen",
    "berappende": "berappend",
    "berappendem": "berappend",
    "berappenden": "berappend",
    "berappender": "berappend",
    "berappendes": "berappend",
    "berappest": "berappen",
    "berappet": "berappen",
    "berappst": "berappen",
    "berappt": "berappen",
    "berappte": "berappen",
    "berapptem": "berappt",
    "berappten": "berappen",
    "berappter": "berappt",
    "berapptes": "berappt",
    "berapptest": "berappen",
    "berapptet": "berappen",
    "berate": "beraten",
    "beratend": "beraten",
    "beratende": "beratend",
    "beratendem": "beratend",
    "beratenden": "beratend",
    "beratender": "beratend",
    "beratendes": "beratend",
    "beratene": "beraten",
    "beratenem": "beraten",
    "beratenen": "beraten",
    "beratener": "beraten",
    "beratenes": "beraten",
    "beratest": "beraten",
    "beratet": "beraten",
    "beratschlage": "beratschlagen",
    "beratschlagend": "beratschlagen",
    "beratschlagende": "beratschlagend",
    "beratschlagendem": "beratschlagend",
    "beratschlagenden": "beratschlagend",
    "beratschlagender": "beratschlagend",
    "beratschlagendere": "beratschlagend",
    "beratschlagenderem": "beratschlagend",
    "beratschlagenderen": "beratschlagend",
    "beratschlagenderer": "beratschlagend",
    "beratschlagenderes": "beratschlagend",
    "beratschlagendes": "beratschlagend",
    "beratschlagendste": "beratschlagend",
    "beratschlagendstem": "beratschlagend",
    "beratschlagendsten": "beratschlagend",
    "beratschlagendster": "beratschlagend",
    "beratschlagendstes": "beratschlagend",
    "beratschlagene": "beratschlagen",
    "beratschlagenem": "beratschlagen",
    "beratschlagenen": "beratschlagen",
    "beratschlagener": "beratschlagen",
    "beratschlagenes": "beratschlagen",
    "beratschlagest": "beratschlagen",
    "beratschlaget": "beratschlagen",
    "beratschlagt": "beratschlagen",
    "beratschlug": "beratschlagen",
    "beratschlugen": "beratschlagen",
    "beratschlugst": "beratschlagen",
    "beratschlugt": "beratschlagen",
    "beratschlägst": "beratschlagen",
    "beratschlägt": "beratschlagen",
    "beratschlüge": "beratschlagen",
    "beratschlügen": "beratschlagen",
    "beratschlügest": "beratschlagen",
    "beratschlüget": "beratschlagen",
    "beraube": "berauben",
    "beraubend": "berauben",
    "beraubende": "beraubend",
    "beraubendem": "beraubend",
    "beraubenden": "beraubend",
    "beraubender": "beraubend",
    "beraubendes": "beraubend",
    "beraubest": "berauben",
    "beraubet": "berauben",
    "beraubst": "berauben",
    "beraubt": "berauben",
    "beraubte": "berauben",
    "beraubtem": "beraubt",
    "beraubten": "berauben",
    "beraubter": "beraubt",
    "beraubtes": "beraubt",
    "beraubtest": "berauben",
    "beraubtet": "berauben",
    "beraume": "beraumen",
    "beraumend": "beraumen",
    "beraumende": "beraumend",
    "beraumendem": "beraumend",
    "beraumenden": "beraumend",
    "beraumender": "beraumend",
    "beraumendes": "beraumend",
    "beraumest": "beraumen",
    "beraumet": "beraumen",
    "beraumst": "beraumen",
    "beraumt": "beraumen",
    "beraumte": "beraumen",
    "beraumtem": "beraumt",
    "beraumten": "beraumen",
    "beraumter": "beraumt",
    "beraumtes": "beraumt",
    "beraumtest": "beraumen",
    "beraumtet": "beraumen",
    "berauschende": "berauschend",
    "berauschendem": "berauschend",
    "berauschenden": "berauschend",
    "berauschender": "berauschend",
    "berauschendere": "berauschend",
    "berauschenderem": "berauschend",
    "berauschenderen": "berauschend",
    "berauschenderer": "berauschend",
    "berauschenderes": "berauschend",
    "berauschendes": "berauschend",
    "berauschendste": "berauschend",
    "berauschendstem": "berauschend",
    "berauschendsten": "berauschend",
    "berauschendster": "berauschend",
    "berauschendstes": "berauschend",
    "berberische": "berberisch",
    "berberischem": "berberisch",
    "berberischen": "berberisch",
    "berberischer": "berberisch",
    "berberisches": "berberisch",
    "berechenbarem": "berechenbar",
    "berechenbaren": "berechenbar",
    "berechenbarer": "berechenbar",
    "berechenbarere": "berechenbar",
    "berechenbarerem": "berechenbar",
    "berechenbareren": "berechenbar",
    "berechenbarerer": "berechenbar",
    "berechenbareres": "berechenbar",
    "berechenbares": "berechenbar",
    "berechenbarste": "berechenbar",
    "berechenbarstem": "berechenbar",
    "berechenbarsten": "berechenbar",
    "berechenbarster": "berechenbar",
    "berechenbarstes": "berechenbar",
    "berechne": "berechnen",
    "berechnend": "berechnen",
    "berechnende": "berechnend",
    "berechnendem": "berechnend",
    "berechnenden": "berechnend",
    "berechnender": "berechnend",
    "berechnendes": "berechnend",
    "berechnest": "berechnen",
    "berechnet": "berechnen",
    "berechnete": "berechnen",
    "berechnetem": "berechnet",
    "berechneten": "berechnen",
    "berechneter": "berechnet",
    "berechnetes": "berechnet",
    "berechnetest": "berechnen",
    "berechnetet": "berechnen",
    "berechtige": "berechtigen",
    "berechtigend": "berechtigen",
    "berechtigende": "berechtigend",
    "berechtigendem": "berechtigend",
    "berechtigenden": "berechtigend",
    "berechtigender": "berechtigend",
    "berechtigendes": "berechtigend",
    "berechtigest": "berechtigen",
    "berechtiget": "berechtigen",
    "berechtigst": "berechtigen",
    "berechtigt": "berechtigen",
    "berechtigte": "berechtigen",
    "berechtigtem": "berechtigt",
    "berechtigten": "berechtigen",
    "berechtigter": "berechtigt",
    "berechtigtes": "berechtigt",
    "berechtigtest": "berechtigen",
    "berechtigtet": "berechtigen",
    "berede": "bereden",
    "beredend": "bereden",
    "beredende": "beredend",
    "beredendem": "beredend",
    "beredenden": "beredend",
    "beredender": "beredend",
    "beredendes": "beredend",
    "beredest": "bereden",
    "beredet": "bereden",
    "beredete": "bereden",
    "beredetem": "beredet",
    "beredeten": "bereden",
    "beredeter": "beredet",
    "beredetes": "beredet",
    "beredetest": "bereden",
    "beredetet": "bereden",
    "bereichere": "bereichern",
    "bereichernd": "bereichern",
    "bereichernde": "bereichernd",
    "bereicherndem": "bereichernd",
    "bereichernden": "bereichernd",
    "bereichernder": "bereichernd",
    "bereicherndes": "bereichernd",
    "bereicherst": "bereichern",
    "bereichert": "bereichern",
    "bereicherte": "bereichern",
    "bereichertem": "bereichert",
    "bereicherten": "bereichern",
    "bereicherter": "bereichert",
    "bereichertes": "bereichert",
    "bereichertest": "bereichern",
    "bereichertet": "bereichern",
    "bereife": "bereifen",
    "bereifend": "bereifen",
    "bereifende": "bereifend",
    "bereifendem": "bereifend",
    "bereifenden": "bereifend",
    "bereifender": "bereifend",
    "bereifendes": "bereifend",
    "bereifest": "bereifen",
    "bereifet": "bereifen",
    "bereifst": "bereifen",
    "bereift": "bereifen",
    "bereifte": "bereifen",
    "bereiftem": "bereift",
    "bereiften": "bereifen",
    "bereifter": "bereift",
    "bereiftes": "bereift",
    "bereiftest": "bereifen",
    "bereiftet": "bereifen",
    "bereinige": "bereinigen",
    "bereinigend": "bereinigen",
    "bereinigende": "bereinigend",
    "bereinigendem": "bereinigend",
    "bereinigenden": "bereinigend",
    "bereinigender": "bereinigend",
    "bereinigendere": "bereinigend",
    "bereinigenderem": "bereinigend",
    "bereinigenderen": "bereinigend",
    "bereinigenderer": "bereinigend",
    "bereinigenderes": "bereinigend",
    "bereinigendes": "bereinigend",
    "bereinigendste": "bereinigend",
    "bereinigendstem": "bereinigend",
    "bereinigendsten": "bereinigend",
    "bereinigendster": "bereinigend",
    "bereinigendstes": "bereinigend",
    "bereinigest": "bereinigen",
    "bereiniget": "bereinigen",
    "bereinigst": "bereinigen",
    "bereinigt": "bereinigen",
    "bereinigte": "bereinigen",
    "bereinigtem": "bereinigt",
    "bereinigten": "bereinigen",
    "bereinigter": "bereinigt",
    "bereinigtere": "bereinigt",
    "bereinigterem": "bereinigt",
    "bereinigteren": "bereinigt",
    "bereinigterer": "bereinigt",
    "bereinigteres": "bereinigt",
    "bereinigtes": "bereinigt",
    "bereinigtest": "bereinigen",
    "bereinigteste": "bereinigt",
    "bereinigtestem": "bereinigt",
    "bereinigtesten": "bereinigt",
    "bereinigtester": "bereinigt",
    "bereinigtestes": "bereinigt",
    "bereinigtet": "bereinigen",
    "bereise": "bereisen",
    "bereisend": "bereisen",
    "bereisende": "bereisend",
    "bereisendem": "bereisend",
    "bereisenden": "bereisend",
    "bereisender": "bereisend",
    "bereisendes": "bereisend",
    "bereisest": "bereisen",
    "bereiset": "bereisen",
    "bereist": "bereisen",
    "bereiste": "bereisen",
    "bereistem": "bereist",
    "bereisten": "bereisen",
    "bereister": "bereist",
    "bereistes": "bereist",
    "bereistest": "bereisen",
    "bereistet": "bereisen",
    "bereit": "bereiten",
    "bereite": "bereit",
    "bereitem": "bereit",
    "bereiten": "bereit",
    "bereitend": "bereiten",
    "bereitende": "bereitend",
    "bereitendem": "bereitend",
    "bereitenden": "bereitend",
    "bereitender": "bereitend",
    "bereitendes": "bereitend",
    "bereiter": "bereit",
    "bereites": "bereit",
    "bereitest": "bereiten",
    "bereitet": "bereiten",
    "bereitete": "bereiten",
    "bereitetem": "bereitet",
    "bereiteten": "bereiten",
    "bereiteter": "bereitet",
    "bereitetes": "bereitet",
    "bereitetest": "bereiten",
    "bereitetet": "bereiten",
    "bereitgehalten": "bereithalten",
    "bereitgehaltene": "bereitgehalten",
    "bereitgehaltenem": "bereitgehalten",
    "bereitgehaltenen": "bereitgehalten",
    "bereitgehaltener": "bereitgehalten",
    "bereitgehaltenes": "bereitgehalten",
    "bereitgestanden": "bereitstehen",
    "bereitgestandene": "bereitgestanden",
    "bereitgestandenem": "bereitgestanden",
    "bereitgestandenen": "bereitgestanden",
    "bereitgestandener": "bereitgestanden",
    "bereitgestandenes": "bereitgestanden",
    "bereitgestellt": "bereitstellen",
    "bereitgestellte": "bereitgestellt",
    "bereitgestelltem": "bereitgestellt",
    "bereitgestellten": "bereitgestellt",
    "bereitgestellter": "bereitgestellt",
    "bereitgestelltes": "bereitgestellt",
    "bereithalte": "bereithalten",
    "bereithaltend": "bereithalten",
    "bereithaltende": "bereithaltend",
    "bereithaltendem": "bereithaltend",
    "bereithaltenden": "bereithaltend",
    "bereithaltender": "bereithaltend",
    "bereithaltendes": "bereithaltend",
    "bereithaltest": "bereithalten",
    "bereithaltet": "bereithalten",
    "bereithielt": "bereithalten",
    "bereithielte": "bereithalten",
    "bereithielten": "bereithalten",
    "bereithieltest": "bereithalten",
    "bereithieltet": "bereithalten",
    "bereithält": "bereithalten",
    "bereithältst": "bereithalten",
    "bereitstand": "bereitstehen",
    "bereitstanden": "bereitstehen",
    "bereitstandest": "bereitstehen",
    "bereitstandet": "bereitstehen",
    "bereitstehe": "bereitstehen",
    "bereitstehend": "bereitstehen",
    "bereitstehende": "bereitstehend",
    "bereitstehendem": "bereitstehend",
    "bereitstehenden": "bereitstehend",
    "bereitstehender": "bereitstehend",
    "bereitstehendes": "bereitstehend",
    "bereitstehest": "bereitstehen",
    "bereitstehet": "bereitstehen",
    "bereitstehst": "bereitstehen",
    "bereitsteht": "bereitstehen",
    "bereitstelle": "bereitstellen",
    "bereitstellend": "bereitstellen",
    "bereitstellende": "bereitstellend",
    "bereitstellendem": "bereitstellend",
    "bereitstellenden": "bereitstellend",
    "bereitstellender": "bereitstellend",
    "bereitstellendes": "bereitstellend",
    "bereitstellest": "bereitstellen",
    "bereitstellet": "bereitstellen",
    "bereitstellst": "bereitstellen",
    "bereitstellt": "bereitstellen",
    "bereitstellte": "bereitstellen",
    "bereitstellten": "bereitstellen",
    "bereitstelltest": "bereitstellen",
    "bereitstelltet": "bereitstellen",
    "bereitstünde": "bereitstehen",
    "bereitstünden": "bereitstehen",
    "bereitstündest": "bereitstehen",
    "bereitstündet": "bereitstehen",
    "bereitwillige": "bereitwillig",
    "bereitwilligem": "bereitwillig",
    "bereitwilligen": "bereitwillig",
    "bereitwilliger": "bereitwillig",
    "bereitwilligere": "bereitwillig",
    "bereitwilligerem": "bereitwillig",
    "bereitwilligeren": "bereitwillig",
    "bereitwilligerer": "bereitwillig",
    "bereitwilligeres": "bereitwillig",
    "bereitwilliges": "bereitwillig",
    "bereitwilligste": "bereitwillig",
    "bereitwilligstem": "bereitwillig",
    "bereitwilligsten": "bereitwillig",
    "bereitwilligster": "bereitwillig",
    "bereitwilligstes": "bereitwillig",
    "bereitzuhalten": "bereithalten",
    "bereitzustehen": "bereitstehen",
    "bereitzustellen": "bereitstellen",
    "bereue": "bereuen",
    "bereuend": "bereuen",
    "bereuende": "bereuend",
    "bereuendem": "bereuend",
    "bereuenden": "bereuend",
    "bereuender": "bereuend",
    "bereuendere": "bereuend",
    "bereuenderem": "bereuend",
    "bereuenderen": "bereuend",
    "bereuenderer": "bereuend",
    "bereuenderes": "bereuend",
    "bereuendes": "bereuend",
    "bereuendste": "bereuend",
    "bereuendstem": "bereuend",
    "bereuendsten": "bereuend",
    "bereuendster": "bereuend",
    "bereuendstes": "bereuend",
    "bereuest": "bereuen",
    "bereuet": "bereuen",
    "bereust": "bereuen",
    "bereut": "bereuen",
    "bereute": "bereuen",
    "bereutem": "bereut",
    "bereuten": "bereuen",
    "bereuter": "bereut",
    "bereutere": "bereut",
    "bereuterem": "bereut",
    "bereuteren": "bereut",
    "bereuterer": "bereut",
    "bereuteres": "bereut",
    "bereutes": "bereut",
    "bereutest": "bereuen",
    "bereuteste": "bereut",
    "bereutestem": "bereut",
    "bereutesten": "bereut",
    "bereutester": "bereut",
    "bereutestes": "bereut",
    "bereutet": "bereuen",
    "bergend": "bergen",
    "bergende": "bergend",
    "bergendem": "bergend",
    "bergenden": "bergend",
    "bergender": "bergend",
    "bergendes": "bergend",
    "bergest": "bergen",
    "berget": "bergen",
    "bergige": "bergig",
    "bergigem": "bergig",
    "bergigen": "bergig",
    "bergiger": "bergig",
    "bergigere": "bergig",
    "bergigerem": "bergig",
    "bergigeren": "bergig",
    "bergigerer": "bergig",
    "bergigeres": "bergig",
    "bergiges": "bergig",
    "bergigste": "bergig",
    "bergigstem": "bergig",
    "bergigsten": "bergig",
    "bergigster": "bergig",
    "bergigstes": "bergig",
    "bergmännischem": "bergmännisch",
    "bergmännischen": "bergmännisch",
    "bergmännischer": "bergmännisch",
    "bergmännisches": "bergmännisch",
    "bergt": "bergen",
    "berichtend": "berichten",
    "berichtende": "berichtend",
    "berichtendem": "berichtend",
    "berichtenden": "berichtend",
    "berichtender": "berichtend",
    "berichtendes": "berichtend",
    "berichtest": "berichten",
    "berichtet": "berichten",
    "berichtete": "berichten",
    "berichtetem": "berichtet",
    "berichteten": "berichten",
    "berichteter": "berichtet",
    "berichtetes": "berichtet",
    "berichtetest": "berichten",
    "berichtetet": "berichten",
    "berichtige": "berichtigen",
    "berichtigend": "berichtigen",
    "berichtigende": "berichtigend",
    "berichtigendem": "berichtigend",
    "berichtigenden": "berichtigend",
    "berichtigender": "berichtigend",
    "berichtigendes": "berichtigend",
    "berichtigest": "berichtigen",
    "berichtiget": "berichtigen",
    "berichtigst": "berichtigen",
    "berichtigt": "berichtigen",
    "berichtigte": "berichtigen",
    "berichtigtem": "berichtigt",
    "berichtigten": "berichtigen",
    "berichtigter": "berichtigt",
    "berichtigtes": "berichtigt",
    "berichtigtest": "berichtigen",
    "berichtigtet": "berichtigen",
    "berief": "berufen",
    "beriefe": "berufen",
    "beriefen": "berufen",
    "beriefest": "berufen",
    "beriefet": "berufen",
    "beriefst": "berufen",
    "berieft": "berufen",
    "beriet": "beraten",
    "beriete": "beraten",
    "berieten": "beraten",
    "berietest": "beraten",
    "berietet": "beraten",
    "beritt": "bereiten",
    "beritte": "bereiten",
    "beritten": "bereiten",
    "berittene": "beritten",
    "berittenem": "beritten",
    "berittenen": "beritten",
    "berittener": "beritten",
    "berittenere": "beritten",
    "berittenerem": "beritten",
    "beritteneren": "beritten",
    "berittenerer": "beritten",
    "beritteneres": "beritten",
    "berittenes": "beritten",
    "berittenste": "beritten",
    "berittenstem": "beritten",
    "berittensten": "beritten",
    "berittenster": "beritten",
    "berittenstes": "beritten",
    "berittest": "bereiten",
    "berittet": "bereiten",
    "bernsteinfarbenem": "bernsteinfarben",
    "bernsteinfarbenen": "bernsteinfarben",
    "bernsteinfarbener": "bernsteinfarben",
    "bernsteinfarbenes": "bernsteinfarben",
    "berste": "bersten",
    "berstend": "bersten",
    "berstende": "berstend",
    "berstendem": "berstend",
    "berstenden": "berstend",
    "berstender": "berstend",
    "berstendes": "berstend",
    "berstest": "bersten",
    "berstet": "bersten",
    "berufend": "berufen",
    "berufende": "berufend",
    "berufendem": "berufend",
    "berufenden": "berufend",
    "berufender": "berufend",
    "berufendes": "berufend",
    "berufene": "berufen",
    "berufenem": "berufen",
    "berufenen": "berufen",
    "berufener": "berufen",
    "berufenes": "berufen",
    "berufest": "berufen",
    "berufet": "berufen",
    "berufliche": "beruflich",
    "beruflichem": "beruflich",
    "beruflichen": "beruflich",
    "beruflicher": "beruflich",
    "berufliches": "beruflich",
    "berufsbedingtem": "berufsbedingt",
    "berufsbedingten": "berufsbedingt",
    "berufsbedingter": "berufsbedingt",
    "berufsbedingtes": "berufsbedingt",
    "berufsbegleitende": "berufsbegleitend",
    "berufsbegleitendem": "berufsbegleitend",
    "berufsbegleitenden": "berufsbegleitend",
    "berufsbegleitender": "berufsbegleitend",
    "berufsbegleitendes": "berufsbegleitend",
    "berufsbezogene": "berufsbezogen",
    "berufsbezogenem": "berufsbezogen",
    "berufsbezogenen": "berufsbezogen",
    "berufsbezogener": "berufsbezogen",
    "berufsbezogenes": "berufsbezogen",
    "berufsbildende": "berufsbildend",
    "berufsbildendem": "berufsbildend",
    "berufsbildenden": "berufsbildend",
    "berufsbildender": "berufsbildend",
    "berufsbildendes": "berufsbildend",
    "berufst": "berufen",
    "berufstätige": "berufstätig",
    "berufstätigem": "berufstätig",
    "berufstätigen": "berufstätig",
    "berufstätiger": "berufstätig",
    "berufstätiges": "berufstätig",
    "berufsunfähige": "berufsunfähig",
    "berufsunfähigem": "berufsunfähig",
    "berufsunfähigen": "berufsunfähig",
    "berufsunfähiger": "berufsunfähig",
    "berufsunfähiges": "berufsunfähig",
    "beruft": "berufen",
    "beruhe": "beruhen",
    "beruhend": "beruhen",
    "beruhende": "beruhend",
    "beruhendem": "beruhend",
    "beruhenden": "beruhend",
    "beruhender": "beruhend",
    "beruhendes": "beruhend",
    "beruhest": "beruhen",
    "beruhet": "beruhen",
    "beruhige": "beruhigen",
    "beruhigend": "beruhigen",
    "beruhigende": "beruhigend",
    "beruhigendem": "beruhigend",
    "beruhigenden": "beruhigend",
    "beruhigender": "beruhigend",
    "beruhigendere": "beruhigend",
    "beruhigenderem": "beruhigend",
    "beruhigenderen": "beruhigend",
    "beruhigenderer": "beruhigend",
    "beruhigenderes": "beruhigend",
    "beruhigendes": "beruhigend",
    "beruhigendste": "beruhigend",
    "beruhigendstem": "beruhigend",
    "beruhigendsten": "beruhigend",
    "beruhigendster": "beruhigend",
    "beruhigendstes": "beruhigend",
    "beruhigest": "beruhigen",
    "beruhiget": "beruhigen",
    "beruhigst": "beruhigen",
    "beruhigt": "beruhigen",
    "beruhigte": "beruhigen",
    "beruhigtem": "beruhigt",
    "beruhigten": "beruhigen",
    "beruhigter": "beruhigt",
    "beruhigtere": "beruhigt",
    "beruhigterem": "beruhigt",
    "beruhigteren": "beruhigt",
    "beruhigterer": "beruhigt",
    "beruhigteres": "beruhigt",
    "beruhigtes": "beruhigt",
    "beruhigtest": "beruhigen",
    "beruhigteste": "beruhigt",
    "beruhigtestem": "beruhigt",
    "beruhigtesten": "beruhigt",
    "beruhigtester": "beruhigt",
    "beruhigtestes": "beruhigt",
    "beruhigtet": "beruhigen",
    "beruhst": "beruhen",
    "beruht": "beruhen",
    "beruhte": "beruhen",
    "beruhtem": "beruht",
    "beruhten": "beruhen",
    "beruhter": "beruht",
    "beruhtes": "beruht",
    "beruhtest": "beruhen",
    "beruhtet": "beruhen",
    "berät": "beraten",
    "berätst": "beraten",
    "berüchtigtem": "berüchtigt",
    "berüchtigten": "berüchtigt",
    "berüchtigter": "berüchtigt",
    "berüchtigtere": "berüchtigt",
    "berüchtigterem": "berüchtigt",
    "berüchtigteren": "berüchtigt",
    "berüchtigterer": "berüchtigt",
    "berüchtigteres": "berüchtigt",
    "berüchtigtes": "berüchtigt",
    "berüchtigteste": "berüchtigt",
    "berüchtigtestem": "berüchtigt",
    "berüchtigtesten": "berüchtigt",
    "berüchtigtester": "berüchtigt",
    "berüchtigtestes": "berüchtigt",
    "berücksichtige": "berücksichtigen",
    "berücksichtigend": "berücksichtigen",
    "berücksichtigende": "berücksichtigend",
    "berücksichtigendem": "berücksichtigend",
    "berücksichtigenden": "berücksichtigend",
    "berücksichtigender": "berücksichtigend",
    "berücksichtigendes": "berücksichtigend",
    "berücksichtigest": "berücksichtigen",
    "berücksichtiget": "berücksichtigen",
    "berücksichtigst": "berücksichtigen",
    "berücksichtigt": "berücksichtigen",
    "berücksichtigte": "berücksichtigen",
    "berücksichtigtem": "berücksichtigt",
    "berücksichtigten": "berücksichtigen",
    "berücksichtigter": "berücksichtigt",
    "berücksichtigtere": "berücksichtigt",
    "berücksichtigterem": "berücksichtigt",
    "berücksichtigteren": "berücksichtigt",
    "berücksichtigterer": "berücksichtigt",
    "berücksichtigteres": "berücksichtigt",
    "berücksichtigtes": "berücksichtigt",
    "berücksichtigtest": "berücksichtigen",
    "berücksichtigteste": "berücksichtigt",
    "berücksichtigtestem": "berücksichtigt",
    "berücksichtigtesten": "berücksichtigt",
    "berücksichtigtester": "berücksichtigt",
    "berücksichtigtestes": "berücksichtigt",
    "berücksichtigtet": "berücksichtigen",
    "berühmtem": "berühmt",
    "berühmten": "berühmt",
    "berühmter": "berühmt",
    "berühmtere": "berühmt",
    "berühmterem": "berühmt",
    "berühmteren": "berühmt",
    "berühmterer": "berühmt",
    "berühmteres": "berühmt",
    "berühmtes": "berühmt",
    "berühmteste": "berühmt",
    "berühmtestem": "berühmt",
    "berühmtesten": "berühmt",
    "berühmtester": "berühmt",
    "berühmtestes": "berühmt",
    "berühre": "berühren",
    "berührend": "berühren",
    "berührende": "berührend",
    "berührendem": "berührend",
    "berührenden": "berührend",
    "berührender": "berührend",
    "berührendes": "berührend",
    "berührest": "berühren",
    "berühret": "berühren",
    "berührst": "berühren",
    "berührt": "berühren",
    "berührte": "berühren",
    "berührtem": "berührt",
    "berührten": "berühren",
    "berührter": "berührt",
    "berührtes": "berührt",
    "berührtest": "berühren",
    "berührtet": "berühren",
    "berüste": "berüsten",
    "berüstend": "berüsten",
    "berüstende": "berüstend",
    "berüstendem": "berüstend",
    "berüstenden": "berüstend",
    "berüstender": "berüstend",
    "berüstendes": "berüstend",
    "berüstest": "berüsten",
    "berüstet": "berüsten",
    "berüstete": "berüsten",
    "berüstetem": "berüstet",
    "berüsteten": "berüsten",
    "berüsteter": "berüstet",
    "berüstetes": "berüstet",
    "berüstetest": "berüsten",
    "berüstetet": "berüsten",
    "besabbere": "besabbern",
    "besabbernd": "besabbern",
    "besabbernde": "besabbernd",
    "besabberndem": "besabbernd",
    "besabbernden": "besabbernd",
    "besabbernder": "besabbernd",
    "besabberndere": "besabbernd",
    "besabbernderem": "besabbernd",
    "besabbernderen": "besabbernd",
    "besabbernderer": "besabbernd",
    "besabbernderes": "besabbernd",
    "besabberndes": "besabbernd",
    "besabberndste": "besabbernd",
    "besabberndstem": "besabbernd",
    "besabberndsten": "besabbernd",
    "besabberndster": "besabbernd",
    "besabberndstes": "besabbernd",
    "besabberst": "besabbern",
    "besabbert": "besabbern",
    "besabberte": "besabbern",
    "besabbertem": "besabbert",
    "besabberten": "besabbern",
    "besabberter": "besabbert",
    "besabbertere": "besabbert",
    "besabberterem": "besabbert",
    "besabberteren": "besabbert",
    "besabberterer": "besabbert",
    "besabberteres": "besabbert",
    "besabbertes": "besabbert",
    "besabbertest": "besabbern",
    "besabberteste": "besabbert",
    "besabbertestem": "besabbert",
    "besabbertesten": "besabbert",
    "besabbertester": "besabbert",
    "besabbertestes": "besabbert",
    "besabbertet": "besabbern",
    "besage": "besagen",
    "besagend": "besagen",
    "besagende": "besagend",
    "besagendem": "besagend",
    "besagenden": "besagend",
    "besagender": "besagend",
    "besagendes": "besagend",
    "besagest": "besagen",
    "besaget": "besagen",
    "besagst": "besagen",
    "besagt": "besagen",
    "besagte": "besagen",
    "besagtem": "besagt",
    "besagten": "besagen",
    "besagter": "besagt",
    "besagtes": "besagt",
    "besagtest": "besagen",
    "besagtet": "besagen",
    "besaite": "besaiten",
    "besaitend": "besaiten",
    "besaitende": "besaitend",
    "besaitendem": "besaitend",
    "besaitenden": "besaitend",
    "besaitender": "besaitend",
    "besaitendes": "besaitend",
    "besaitest": "besaiten",
    "besaitet": "besaiten",
    "besaitete": "besaiten",
    "besaitetem": "besaitet",
    "besaiteten": "besaiten",
    "besaiteter": "besaitet",
    "besaitetes": "besaitet",
    "besaitetest": "besaiten",
    "besaitetet": "besaiten",
    "besame": "besamen",
    "besamend": "besamen",
    "besamende": "besamend",
    "besamendem": "besamend",
    "besamenden": "besamend",
    "besamender": "besamend",
    "besamendere": "besamend",
    "besamenderem": "besamend",
    "besamenderen": "besamend",
    "besamenderer": "besamend",
    "besamenderes": "besamend",
    "besamendes": "besamend",
    "besamendste": "besamend",
    "besamendstem": "besamend",
    "besamendsten": "besamend",
    "besamendster": "besamend",
    "besamendstes": "besamend",
    "besamest": "besamen",
    "besamet": "besamen",
    "besamst": "besamen",
    "besamt": "besamen",
    "besamte": "besamen",
    "besamtem": "besamt",
    "besamten": "besamen",
    "besamter": "besamt",
    "besamtere": "besamt",
    "besamterem": "besamt",
    "besamteren": "besamt",
    "besamterer": "besamt",
    "besamteres": "besamt",
    "besamtes": "besamt",
    "besamtest": "besamen",
    "besamteste": "besamt",
    "besamtestem": "besamt",
    "besamtesten": "besamt",
    "besamtester": "besamt",
    "besamtestes": "besamt",
    "besamtet": "besamen",
    "besang": "besingen",
    "besangen": "besingen",
    "besangst": "besingen",
    "besangt": "besingen",
    "besann": "besinnen",
    "besannen": "besinnen",
    "besannst": "besinnen",
    "besannt": "besinnen",
    "besaufe": "besaufen",
    "besaufend": "besaufen",
    "besaufende": "besaufend",
    "besaufendem": "besaufend",
    "besaufenden": "besaufend",
    "besaufender": "besaufend",
    "besaufendere": "besaufend",
    "besaufenderem": "besaufend",
    "besaufenderen": "besaufend",
    "besaufenderer": "besaufend",
    "besaufenderes": "besaufend",
    "besaufendes": "besaufend",
    "besaufendste": "besaufend",
    "besaufendstem": "besaufend",
    "besaufendsten": "besaufend",
    "besaufendster": "besaufend",
    "besaufendstes": "besaufend",
    "besaufest": "besaufen",
    "besaufet": "besaufen",
    "besauft": "besaufen",
    "besaß": "besitzen",
    "besaßen": "besitzen",
    "besaßt": "besitzen",
    "beschade": "beschaden",
    "beschadend": "beschaden",
    "beschadende": "beschadend",
    "beschadendem": "beschadend",
    "beschadenden": "beschadend",
    "beschadender": "beschadend",
    "beschadendes": "beschadend",
    "beschadest": "beschaden",
    "beschadet": "beschaden",
    "beschadete": "beschaden",
    "beschadetem": "beschadet",
    "beschadeten": "beschaden",
    "beschadeter": "beschadet",
    "beschadetere": "beschadet",
    "beschadeterem": "beschadet",
    "beschadeteren": "beschadet",
    "beschadeterer": "beschadet",
    "beschadeteres": "beschadet",
    "beschadetes": "beschadet",
    "beschadetest": "beschaden",
    "beschadeteste": "beschadet",
    "beschadetestem": "beschadet",
    "beschadetesten": "beschadet",
    "beschadetester": "beschadet",
    "beschadetestes": "beschadet",
    "beschadetet": "beschaden",
    "beschaffe": "beschaffen",
    "beschaffend": "beschaffen",
    "beschaffende": "beschaffend",
    "beschaffendem": "beschaffend",
    "beschaffenden": "beschaffend",
    "beschaffender": "beschaffend",
    "beschaffendes": "beschaffend",
    "beschaffest": "beschaffen",
    "beschaffet": "beschaffen",
    "beschaffst": "beschaffen",
    "beschafft": "beschaffen",
    "beschaffte": "beschaffen",
    "beschafftem": "beschafft",
    "beschafften": "beschaffen",
    "beschaffter": "beschafft",
    "beschafftes": "beschafft",
    "beschafftest": "beschaffen",
    "beschafftet": "beschaffen",
    "beschalle": "beschallen",
    "beschallend": "beschallen",
    "beschallende": "beschallend",
    "beschallendem": "beschallend",
    "beschallenden": "beschallend",
    "beschallender": "beschallend",
    "beschallendere": "beschallend",
    "beschallenderem": "beschallend",
    "beschallenderen": "beschallend",
    "beschallenderer": "beschallend",
    "beschallenderes": "beschallend",
    "beschallendes": "beschallend",
    "beschallendste": "beschallend",
    "beschallendstem": "beschallend",
    "beschallendsten": "beschallend",
    "beschallendster": "beschallend",
    "beschallendstes": "beschallend",
    "beschallest": "beschallen",
    "beschallet": "beschallen",
    "beschallst": "beschallen",
    "beschallt": "beschallen",
    "beschallte": "beschallen",
    "beschalltem": "beschallt",
    "beschallten": "beschallen",
    "beschallter": "beschallt",
    "beschalltere": "beschallt",
    "beschallterem": "beschallt",
    "beschallteren": "beschallt",
    "beschallterer": "beschallt",
    "beschallteres": "beschallt",
    "beschalltes": "beschallt",
    "beschalltest": "beschallen",
    "beschallteste": "beschallt",
    "beschalltestem": "beschallt",
    "beschalltesten": "beschallt",
    "beschalltester": "beschallt",
    "beschalltestes": "beschallt",
    "beschalltet": "beschallen",
    "beschatte": "beschatten",
    "beschattend": "beschatten",
    "beschattende": "beschattend",
    "beschattendem": "beschattend",
    "beschattenden": "beschattend",
    "beschattender": "beschattend",
    "beschattendere": "beschattend",
    "beschattenderem": "beschattend",
    "beschattenderen": "beschattend",
    "beschattenderer": "beschattend",
    "beschattenderes": "beschattend",
    "beschattendes": "beschattend",
    "beschattendste": "beschattend",
    "beschattendstem": "beschattend",
    "beschattendsten": "beschattend",
    "beschattendster": "beschattend",
    "beschattendstes": "beschattend",
    "beschattest": "beschatten",
    "beschattet": "beschatten",
    "beschattete": "beschatten",
    "beschattetem": "beschattet",
    "beschatteten": "beschatten",
    "beschatteter": "beschattet",
    "beschattetere": "beschattet",
    "beschatteterem": "beschattet",
    "beschatteteren": "beschattet",
    "beschatteterer": "beschattet",
    "beschatteteres": "beschattet",
    "beschattetes": "beschattet",
    "beschattetest": "beschatten",
    "beschatteteste": "beschattet",
    "beschattetestem": "beschattet",
    "beschattetesten": "beschattet",
    "beschattetester": "beschattet",
    "beschattetestes": "beschattet",
    "beschattetet": "beschatten",
    "beschaue": "beschauen",
    "beschauend": "beschauen",
    "beschauende": "beschauend",
    "beschauendem": "beschauend",
    "beschauenden": "beschauend",
    "beschauender": "beschauend",
    "beschauendes": "beschauend",
    "beschauest": "beschauen",
    "beschauet": "beschauen",
    "beschauliche": "beschaulich",
    "beschaulichem": "beschaulich",
    "beschaulichen": "beschaulich",
    "beschaulicher": "beschaulich",
    "beschaulichere": "beschaulich",
    "beschaulicherem": "beschaulich",
    "beschaulicheren": "beschaulich",
    "beschaulicherer": "beschaulich",
    "beschaulicheres": "beschaulich",
    "beschauliches": "beschaulich",
    "beschaulichstem": "beschaulich",
    "beschaulichsten": "beschaulich",
    "beschaulichster": "beschaulich",
    "beschaulichstes": "beschaulich",
    "beschaust": "beschauen",
    "beschaut": "beschauen",
    "beschaute": "beschauen",
    "beschautem": "beschaut",
    "beschauten": "beschauen",
    "beschauter": "beschaut",
    "beschautes": "beschaut",
    "beschautest": "beschauen",
    "beschautet": "beschauen",
    "bescheidenem": "bescheiden",
    "bescheidenen": "bescheiden",
    "bescheidener": "bescheiden",
    "bescheidenere": "bescheiden",
    "bescheidenerem": "bescheiden",
    "bescheideneren": "bescheiden",
    "bescheidenerer": "bescheiden",
    "bescheideneres": "bescheiden",
    "bescheidenes": "bescheiden",
    "bescheidenstem": "bescheiden",
    "bescheidensten": "bescheiden",
    "bescheidenster": "bescheiden",
    "bescheidenstes": "bescheiden",
    "bescheine": "bescheinen",
    "bescheinend": "bescheinen",
    "bescheinende": "bescheinend",
    "bescheinendem": "bescheinend",
    "bescheinenden": "bescheinend",
    "bescheinender": "bescheinend",
    "bescheinendes": "bescheinend",
    "bescheinest": "bescheinen",
    "bescheinet": "bescheinen",
    "bescheinige": "bescheinigen",
    "bescheinigend": "bescheinigen",
    "bescheinigende": "bescheinigend",
    "bescheinigendem": "bescheinigend",
    "bescheinigenden": "bescheinigend",
    "bescheinigender": "bescheinigend",
    "bescheinigendes": "bescheinigend",
    "bescheinigest": "bescheinigen",
    "bescheiniget": "bescheinigen",
    "bescheinigst": "bescheinigen",
    "bescheinigt": "bescheinigen",
    "bescheinigte": "bescheinigen",
    "bescheinigtem": "bescheinigt",
    "bescheinigten": "bescheinigen",
    "bescheinigter": "bescheinigt",
    "bescheinigtes": "bescheinigt",
    "bescheinigtest": "bescheinigen",
    "bescheinigtet": "bescheinigen",
    "bescheinst": "bescheinen",
    "bescheint": "bescheinen",
    "bescheiße": "bescheißen",
    "bescheißend": "bescheißen",
    "bescheißende": "bescheißend",
    "bescheißendem": "bescheißend",
    "bescheißenden": "bescheißend",
    "bescheißender": "bescheißend",
    "bescheißendes": "bescheißend",
    "bescheißest": "bescheißen",
    "bescheißet": "bescheißen",
    "bescheißt": "bescheißen",
    "beschenke": "beschenken",
    "beschenkend": "beschenken",
    "beschenkende": "beschenkend",
    "beschenkendem": "beschenkend",
    "beschenkenden": "beschenkend",
    "beschenkender": "beschenkend",
    "beschenkendes": "beschenkend",
    "beschenkest": "beschenken",
    "beschenket": "beschenken",
    "beschenkst": "beschenken",
    "beschenkt": "beschenken",
    "beschenkte": "beschenken",
    "beschenktem": "beschenkt",
    "beschenkten": "beschenken",
    "beschenkter": "beschenkt",
    "beschenktes": "beschenkt",
    "beschenktest": "beschenken",
    "beschenktet": "beschenken",
    "beschere": "bescheren",
    "bescherend": "bescheren",
    "bescherende": "bescherend",
    "bescherendem": "bescherend",
    "bescherenden": "bescherend",
    "bescherender": "bescherend",
    "bescherendes": "bescherend",
    "bescherest": "bescheren",
    "bescheret": "bescheren",
    "bescherst": "bescheren",
    "beschert": "bescheren",
    "bescherte": "bescheren",
    "beschertem": "beschert",
    "bescherten": "bescheren",
    "bescherter": "beschert",
    "beschertes": "beschert",
    "beschertest": "bescheren",
    "beschertet": "bescheren",
    "bescheuertem": "bescheuert",
    "bescheuerten": "bescheuert",
    "bescheuerter": "bescheuert",
    "bescheuertere": "bescheuert",
    "bescheuerterem": "bescheuert",
    "bescheuerteren": "bescheuert",
    "bescheuerterer": "bescheuert",
    "bescheuerteres": "bescheuert",
    "bescheuertes": "bescheuert",
    "bescheuerteste": "bescheuert",
    "bescheuertestem": "bescheuert",
    "bescheuertesten": "bescheuert",
    "bescheuertester": "bescheuert",
    "bescheuertestes": "bescheuert",
    "beschichte": "beschichten",
    "beschichtend": "beschichten",
    "beschichtende": "beschichtend",
    "beschichtendem": "beschichtend",
    "beschichtenden": "beschichtend",
    "beschichtender": "beschichtend",
    "beschichtendes": "beschichtend",
    "beschichtest": "beschichten",
    "beschichtet": "beschichten",
    "beschichtete": "beschichten",
    "beschichtetem": "beschichtet",
    "beschichteten": "beschichten",
    "beschichteter": "beschichtet",
    "beschichtetere": "beschichtet",
    "beschichteterem": "beschichtet",
    "beschichteteren": "beschichtet",
    "beschichteterer": "beschichtet",
    "beschichteteres": "beschichtet",
    "beschichtetes": "beschichtet",
    "beschichtetest": "beschichten",
    "beschichteteste": "beschichtet",
    "beschichtetestem": "beschichtet",
    "beschichtetesten": "beschichtet",
    "beschichtetester": "beschichtet",
    "beschichtetestes": "beschichtet",
    "beschichtetet": "beschichten",
    "beschien": "bescheinen",
    "beschiene": "bescheinen",
    "beschienen": "bescheinen",
    "beschienene": "beschienen",
    "beschienenem": "beschienen",
    "beschienenen": "beschienen",
    "beschienener": "beschienen",
    "beschienenes": "beschienen",
    "beschienest": "bescheinen",
    "beschienet": "bescheinen",
    "beschienst": "bescheinen",
    "beschient": "bescheinen",
    "beschieße": "beschießen",
    "beschießend": "beschießen",
    "beschießende": "beschießend",
    "beschießendem": "beschießend",
    "beschießenden": "beschießend",
    "beschießender": "beschießend",
    "beschießendes": "beschießend",
    "beschießest": "beschießen",
    "beschießet": "beschießen",
    "beschießt": "beschießen",
    "beschildere": "beschildern",
    "beschildernd": "beschildern",
    "beschildernde": "beschildernd",
    "beschilderndem": "beschildernd",
    "beschildernden": "beschildernd",
    "beschildernder": "beschildernd",
    "beschilderndes": "beschildernd",
    "beschilderst": "beschildern",
    "beschildert": "beschildern",
    "beschilderte": "beschildern",
    "beschildertem": "beschildert",
    "beschilderten": "beschildern",
    "beschilderter": "beschildert",
    "beschildertes": "beschildert",
    "beschildertest": "beschildern",
    "beschildertet": "beschildern",
    "beschimpfe": "beschimpfen",
    "beschimpfend": "beschimpfen",
    "beschimpfende": "beschimpfend",
    "beschimpfendem": "beschimpfend",
    "beschimpfenden": "beschimpfend",
    "beschimpfender": "beschimpfend",
    "beschimpfendere": "beschimpfend",
    "beschimpfenderem": "beschimpfend",
    "beschimpfenderen": "beschimpfend",
    "beschimpfenderer": "beschimpfend",
    "beschimpfenderes": "beschimpfend",
    "beschimpfendes": "beschimpfend",
    "beschimpfendste": "beschimpfend",
    "beschimpfendstem": "beschimpfend",
    "beschimpfendsten": "beschimpfend",
    "beschimpfendster": "beschimpfend",
    "beschimpfendstes": "beschimpfend",
    "beschimpfest": "beschimpfen",
    "beschimpfet": "beschimpfen",
    "beschimpfst": "beschimpfen",
    "beschimpft": "beschimpfen",
    "beschimpfte": "beschimpfen",
    "beschimpftem": "beschimpft",
    "beschimpften": "beschimpfen",
    "beschimpfter": "beschimpft",
    "beschimpftere": "beschimpft",
    "beschimpfterem": "beschimpft",
    "beschimpfteren": "beschimpft",
    "beschimpfterer": "beschimpft",
    "beschimpfteres": "beschimpft",
    "beschimpftes": "beschimpft",
    "beschimpftest": "beschimpfen",
    "beschimpfteste": "beschimpft",
    "beschimpftestem": "beschimpft",
    "beschimpftesten": "beschimpft",
    "beschimpftester": "beschimpft",
    "beschimpftestes": "beschimpft",
    "beschimpftet": "beschimpfen",
    "beschirme": "beschirmen",
    "beschirmend": "beschirmen",
    "beschirmende": "beschirmend",
    "beschirmendem": "beschirmend",
    "beschirmenden": "beschirmend",
    "beschirmender": "beschirmend",
    "beschirmendes": "beschirmend",
    "beschirmest": "beschirmen",
    "beschirmet": "beschirmen",
    "beschirmst": "beschirmen",
    "beschirmt": "beschirmen",
    "beschirmte": "beschirmen",
    "beschirmtem": "beschirmt",
    "beschirmten": "beschirmen",
    "beschirmter": "beschirmt",
    "beschirmtes": "beschirmt",
    "beschirmtest": "beschirmen",
    "beschirmtet": "beschirmen",
    "beschisse": "bescheißen",
    "beschissen": "bescheißen",
    "beschissene": "beschissen",
    "beschissenem": "beschissen",
    "beschissenen": "beschissen",
    "beschissener": "beschissen",
    "beschissenere": "beschissen",
    "beschissenerem": "beschissen",
    "beschisseneren": "beschissen",
    "beschissenerer": "beschissen",
    "beschisseneres": "beschissen",
    "beschissenes": "beschissen",
    "beschissenste": "beschissen",
    "beschissenstem": "beschissen",
    "beschissensten": "beschissen",
    "beschissenster": "beschissen",
    "beschissenstes": "beschissen",
    "beschissest": "bescheißen",
    "beschisset": "bescheißen",
    "beschiß": "bescheißen",
    "beschißt": "bescheißen",
    "beschlagend": "beschlagen",
    "beschlagende": "beschlagend",
    "beschlagendem": "beschlagend",
    "beschlagenden": "beschlagend",
    "beschlagender": "beschlagend",
    "beschlagendes": "beschlagend",
    "beschlagene": "beschlagen",
    "beschlagenem": "beschlagen",
    "beschlagenen": "beschlagen",
    "beschlagener": "beschlagen",
    "beschlagenes": "beschlagen",
    "beschlagest": "beschlagen",
    "beschlaget": "beschlagen",
    "beschlagnahme": "beschlagnahmen",
    "beschlagnahmend": "beschlagnahmen",
    "beschlagnahmende": "beschlagnahmend",
    "beschlagnahmendem": "beschlagnahmend",
    "beschlagnahmenden": "beschlagnahmend",
    "beschlagnahmender": "beschlagnahmend",
    "beschlagnahmendes": "beschlagnahmend",
    "beschlagnahmest": "beschlagnahmen",
    "beschlagnahmet": "beschlagnahmen",
    "beschlagnahmst": "beschlagnahmen",
    "beschlagnahmt": "beschlagnahmen",
    "beschlagnahmte": "beschlagnahmen",
    "beschlagnahmtem": "beschlagnahmt",
    "beschlagnahmten": "beschlagnahmen",
    "beschlagnahmter": "beschlagnahmt",
    "beschlagnahmtes": "beschlagnahmt",
    "beschlagnahmtest": "beschlagnahmen",
    "beschlagnahmtet": "beschlagnahmen",
    "beschlagt": "beschlagen",
    "beschleiche": "beschleichen",
    "beschleichend": "beschleichen",
    "beschleichende": "beschleichend",
    "beschleichendem": "beschleichend",
    "beschleichenden": "beschleichend",
    "beschleichender": "beschleichend",
    "beschleichendes": "beschleichend",
    "beschleichest": "beschleichen",
    "beschleichet": "beschleichen",
    "beschleichst": "beschleichen",
    "beschleicht": "beschleichen",
    "beschleunige": "beschleunigen",
    "beschleunigend": "beschleunigen",
    "beschleunigende": "beschleunigend",
    "beschleunigendem": "beschleunigend",
    "beschleunigenden": "beschleunigend",
    "beschleunigender": "beschleunigend",
    "beschleunigendere": "beschleunigend",
    "beschleunigenderem": "beschleunigend",
    "beschleunigenderen": "beschleunigend",
    "beschleunigenderer": "beschleunigend",
    "beschleunigenderes": "beschleunigend",
    "beschleunigendes": "beschleunigend",
    "beschleunigendste": "beschleunigend",
    "beschleunigendstem": "beschleunigend",
    "beschleunigendsten": "beschleunigend",
    "beschleunigendster": "beschleunigend",
    "beschleunigendstes": "beschleunigend",
    "beschleunigest": "beschleunigen",
    "beschleuniget": "beschleunigen",
    "beschleunigst": "beschleunigen",
    "beschleunigt": "beschleunigen",
    "beschleunigte": "beschleunigen",
    "beschleunigtem": "beschleunigt",
    "beschleunigten": "beschleunigen",
    "beschleunigter": "beschleunigt",
    "beschleunigtere": "beschleunigt",
    "beschleunigterem": "beschleunigt",
    "beschleunigteren": "beschleunigt",
    "beschleunigterer": "beschleunigt",
    "beschleunigteres": "beschleunigt",
    "beschleunigtes": "beschleunigt",
    "beschleunigtest": "beschleunigen",
    "beschleunigteste": "beschleunigt",
    "beschleunigtestem": "beschleunigt",
    "beschleunigtesten": "beschleunigt",
    "beschleunigtester": "beschleunigt",
    "beschleunigtestes": "beschleunigt",
    "beschleunigtet": "beschleunigen",
    "beschlich": "beschleichen",
    "beschliche": "beschleichen",
    "beschlichen": "beschleichen",
    "beschlichene": "beschlichen",
    "beschlichenem": "beschlichen",
    "beschlichenen": "beschlichen",
    "beschlichener": "beschlichen",
    "beschlichenes": "beschlichen",
    "beschlichest": "beschleichen",
    "beschlichet": "beschleichen",
    "beschlichst": "beschleichen",
    "beschlicht": "beschleichen",
    "beschließe": "beschließen",
    "beschließend": "beschließen",
    "beschließende": "beschließend",
    "beschließendem": "beschließend",
    "beschließenden": "beschließend",
    "beschließender": "beschließend",
    "beschließendes": "beschließend",
    "beschließest": "beschließen",
    "beschließet": "beschließen",
    "beschließt": "beschließen",
    "beschlossen": "beschließen",
    "beschlossene": "beschlossen",
    "beschlossenem": "beschlossen",
    "beschlossenen": "beschlossen",
    "beschlossener": "beschlossen",
    "beschlossenere": "beschlossen",
    "beschlossenerem": "beschlossen",
    "beschlosseneren": "beschlossen",
    "beschlossenerer": "beschlossen",
    "beschlosseneres": "beschlossen",
    "beschlossenes": "beschlossen",
    "beschlossenste": "beschlossen",
    "beschlossenstem": "beschlossen",
    "beschlossensten": "beschlossen",
    "beschlossenster": "beschlossen",
    "beschlossenstes": "beschlossen",
    "beschloß": "beschließen",
    "beschloßt": "beschließen",
    "beschlug": "beschlagen",
    "beschlugen": "beschlagen",
    "beschlugst": "beschlagen",
    "beschlugt": "beschlagen",
    "beschlußfähigem": "beschlußfähig",
    "beschlußfähigen": "beschlußfähig",
    "beschlußfähiger": "beschlußfähig",
    "beschlußfähiges": "beschlußfähig",
    "beschlußreife": "beschlußreif",
    "beschlußreifem": "beschlußreif",
    "beschlußreifen": "beschlußreif",
    "beschlußreifer": "beschlußreif",
    "beschlußreifes": "beschlußreif",
    "beschlägst": "beschlagen",
    "beschlägt": "beschlagen",
    "beschlösse": "beschließen",
    "beschlössen": "beschließen",
    "beschlössest": "beschließen",
    "beschlösset": "beschließen",
    "beschlüge": "beschlagen",
    "beschlügen": "beschlagen",
    "beschlügest": "beschlagen",
    "beschlüget": "beschlagen",
    "beschmiere": "beschmieren",
    "beschmierend": "beschmieren",
    "beschmierende": "beschmierend",
    "beschmierendem": "beschmierend",
    "beschmierenden": "beschmierend",
    "beschmierender": "beschmierend",
    "beschmierendere": "beschmierend",
    "beschmierenderem": "beschmierend",
    "beschmierenderen": "beschmierend",
    "beschmierenderer": "beschmierend",
    "beschmierenderes": "beschmierend",
    "beschmierendes": "beschmierend",
    "beschmierendste": "beschmierend",
    "beschmierendstem": "beschmierend",
    "beschmierendsten": "beschmierend",
    "beschmierendster": "beschmierend",
    "beschmierendstes": "beschmierend",
    "beschmierest": "beschmieren",
    "beschmieret": "beschmieren",
    "beschmierst": "beschmieren",
    "beschmiert": "beschmieren",
    "beschmierte": "beschmieren",
    "beschmiertem": "beschmiert",
    "beschmierten": "beschmieren",
    "beschmierter": "beschmiert",
    "beschmiertere": "beschmiert",
    "beschmierterem": "beschmiert",
    "beschmierteren": "beschmiert",
    "beschmierterer": "beschmiert",
    "beschmierteres": "beschmiert",
    "beschmiertes": "beschmiert",
    "beschmiertest": "beschmieren",
    "beschmierteste": "beschmiert",
    "beschmiertestem": "beschmiert",
    "beschmiertesten": "beschmiert",
    "beschmiertester": "beschmiert",
    "beschmiertestes": "beschmiert",
    "beschmiertet": "beschmieren",
    "beschmunzele": "beschmunzeln",
    "beschmunzelnd": "beschmunzeln",
    "beschmunzelnde": "beschmunzelnd",
    "beschmunzelndem": "beschmunzelnd",
    "beschmunzelnden": "beschmunzelnd",
    "beschmunzelnder": "beschmunzelnd",
    "beschmunzelndere": "beschmunzelnd",
    "beschmunzelnderem": "beschmunzelnd",
    "beschmunzelnderen": "beschmunzelnd",
    "beschmunzelnderer": "beschmunzelnd",
    "beschmunzelnderes": "beschmunzelnd",
    "beschmunzelndes": "beschmunzelnd",
    "beschmunzelndste": "beschmunzelnd",
    "beschmunzelndstem": "beschmunzelnd",
    "beschmunzelndsten": "beschmunzelnd",
    "beschmunzelndster": "beschmunzelnd",
    "beschmunzelndstes": "beschmunzelnd",
    "beschmunzelst": "beschmunzeln",
    "beschmunzelt": "beschmunzeln",
    "beschmunzelte": "beschmunzeln",
    "beschmunzeltem": "beschmunzelt",
    "beschmunzelten": "beschmunzeln",
    "beschmunzelter": "beschmunzelt",
    "beschmunzeltere": "beschmunzelt",
    "beschmunzelterem": "beschmunzelt",
    "beschmunzelteren": "beschmunzelt",
    "beschmunzelterer": "beschmunzelt",
    "beschmunzelteres": "beschmunzelt",
    "beschmunzeltes": "beschmunzelt",
    "beschmunzeltest": "beschmunzeln",
    "beschmunzelteste": "beschmunzelt",
    "beschmunzeltestem": "beschmunzelt",
    "beschmunzeltesten": "beschmunzelt",
    "beschmunzeltester": "beschmunzelt",
    "beschmunzeltestes": "beschmunzelt",
    "beschmunzeltet": "beschmunzeln",
    "beschmunzle": "beschmunzeln",
    "beschmutze": "beschmutzen",
    "beschmutzend": "beschmutzen",
    "beschmutzende": "beschmutzend",
    "beschmutzendem": "beschmutzend",
    "beschmutzenden": "beschmutzend",
    "beschmutzender": "beschmutzend",
    "beschmutzendere": "beschmutzend",
    "beschmutzenderem": "beschmutzend",
    "beschmutzenderen": "beschmutzend",
    "beschmutzenderer": "beschmutzend",
    "beschmutzenderes": "beschmutzend",
    "beschmutzendes": "beschmutzend",
    "beschmutzendste": "beschmutzend",
    "beschmutzendstem": "beschmutzend",
    "beschmutzendsten": "beschmutzend",
    "beschmutzendster": "beschmutzend",
    "beschmutzendstes": "beschmutzend",
    "beschmutzest": "beschmutzen",
    "beschmutzet": "beschmutzen",
    "beschmutzt": "beschmutzen",
    "beschmutzte": "beschmutzen",
    "beschmutztem": "beschmutzt",
    "beschmutzten": "beschmutzen",
    "beschmutzter": "beschmutzt",
    "beschmutztere": "beschmutzt",
    "beschmutzterem": "beschmutzt",
    "beschmutzteren": "beschmutzt",
    "beschmutzterer": "beschmutzt",
    "beschmutzteres": "beschmutzt",
    "beschmutztes": "beschmutzt",
    "beschmutztest": "beschmutzen",
    "beschmutzteste": "beschmutzt",
    "beschmutztestem": "beschmutzt",
    "beschmutztesten": "beschmutzt",
    "beschmutztester": "beschmutzt",
    "beschmutztestes": "beschmutzt",
    "beschmutztet": "beschmutzen",
    "beschneide": "beschneiden",
    "beschneidend": "beschneiden",
    "beschneidende": "beschneidend",
    "beschneidendem": "beschneidend",
    "beschneidenden": "beschneidend",
    "beschneidender": "beschneidend",
    "beschneidendes": "beschneidend",
    "beschneidest": "beschneiden",
    "beschneidet": "beschneiden",
    "beschnitt": "beschneiden",
    "beschnitte": "beschneiden",
    "beschnitten": "beschneiden",
    "beschnittene": "beschnitten",
    "beschnittenem": "beschnitten",
    "beschnittenen": "beschnitten",
    "beschnittener": "beschnitten",
    "beschnittenere": "beschnitten",
    "beschnittenerem": "beschnitten",
    "beschnitteneren": "beschnitten",
    "beschnittenerer": "beschnitten",
    "beschnitteneres": "beschnitten",
    "beschnittenes": "beschnitten",
    "beschnittenste": "beschnitten",
    "beschnittenstem": "beschnitten",
    "beschnittensten": "beschnitten",
    "beschnittenster": "beschnitten",
    "beschnittenstes": "beschnitten",
    "beschnittest": "beschneiden",
    "beschnittet": "beschneiden",
    "beschnuppere": "beschnuppern",
    "beschnuppernd": "beschnuppern",
    "beschnuppernde": "beschnuppernd",
    "beschnupperndem": "beschnuppernd",
    "beschnuppernden": "beschnuppernd",
    "beschnuppernder": "beschnuppernd",
    "beschnupperndes": "beschnuppernd",
    "beschnupperst": "beschnuppern",
    "beschnuppert": "beschnuppern",
    "beschnupperte": "beschnuppern",
    "beschnuppertem": "beschnuppert",
    "beschnupperten": "beschnuppern",
    "beschnupperter": "beschnuppert",
    "beschnuppertes": "beschnuppert",
    "beschnuppertest": "beschnuppern",
    "beschnuppertet": "beschnuppern",
    "beschnüffele": "beschnüffeln",
    "beschnüffelnd": "beschnüffeln",
    "beschnüffelnde": "beschnüffelnd",
    "beschnüffelndem": "beschnüffelnd",
    "beschnüffelnden": "beschnüffelnd",
    "beschnüffelnder": "beschnüffelnd",
    "beschnüffelndere": "beschnüffelnd",
    "beschnüffelnderem": "beschnüffelnd",
    "beschnüffelnderen": "beschnüffelnd",
    "beschnüffelnderer": "beschnüffelnd",
    "beschnüffelnderes": "beschnüffelnd",
    "beschnüffelndes": "beschnüffelnd",
    "beschnüffelndste": "beschnüffelnd",
    "beschnüffelndstem": "beschnüffelnd",
    "beschnüffelndsten": "beschnüffelnd",
    "beschnüffelndster": "beschnüffelnd",
    "beschnüffelndstes": "beschnüffelnd",
    "beschnüffelst": "beschnüffeln",
    "beschnüffelt": "beschnüffeln",
    "beschnüffelte": "beschnüffeln",
    "beschnüffeltem": "beschnüffelt",
    "beschnüffelten": "beschnüffeln",
    "beschnüffelter": "beschnüffelt",
    "beschnüffeltes": "beschnüffelt",
    "beschnüffeltest": "beschnüffeln",
    "beschnüffeltet": "beschnüffeln",
    "beschnüffle": "beschnüffeln",
    "beschosse": "beschießen",
    "beschossen": "beschießen",
    "beschossene": "beschossen",
    "beschossenem": "beschossen",
    "beschossenen": "beschossen",
    "beschossener": "beschossen",
    "beschossenere": "beschossen",
    "beschossenerem": "beschossen",
    "beschosseneren": "beschossen",
    "beschossenerer": "beschossen",
    "beschosseneres": "beschossen",
    "beschossenes": "beschossen",
    "beschossenste": "beschossen",
    "beschossenstem": "beschossen",
    "beschossensten": "beschossen",
    "beschossenster": "beschossen",
    "beschossenstes": "beschossen",
    "beschossest": "beschießen",
    "beschosset": "beschießen",
    "beschoß": "beschießen",
    "beschoßt": "beschießen",
    "beschreibe": "beschreiben",
    "beschreibend": "beschreiben",
    "beschreibende": "beschreibend",
    "beschreibendem": "beschreibend",
    "beschreibenden": "beschreibend",
    "beschreibender": "beschreibend",
    "beschreibendes": "beschreibend",
    "beschreibest": "beschreiben",
    "beschreibet": "beschreiben",
    "beschreibst": "beschreiben",
    "beschreibt": "beschreiben",
    "beschreie": "beschreien",
    "beschreiend": "beschreien",
    "beschreiende": "beschreiend",
    "beschreiendem": "beschreiend",
    "beschreienden": "beschreiend",
    "beschreiender": "beschreiend",
    "beschreiendere": "beschreiend",
    "beschreienderem": "beschreiend",
    "beschreienderen": "beschreiend",
    "beschreienderer": "beschreiend",
    "beschreienderes": "beschreiend",
    "beschreiendes": "beschreiend",
    "beschreiendste": "beschreiend",
    "beschreiendstem": "beschreiend",
    "beschreiendsten": "beschreiend",
    "beschreiendster": "beschreiend",
    "beschreiendstes": "beschreiend",
    "beschreiest": "beschreien",
    "beschreiet": "beschreien",
    "beschreist": "beschreien",
    "beschreit": "beschreiten",
    "beschreite": "beschreiten",
    "beschreitend": "beschreiten",
    "beschreitende": "beschreitend",
    "beschreitendem": "beschreitend",
    "beschreitenden": "beschreitend",
    "beschreitender": "beschreitend",
    "beschreitendes": "beschreitend",
    "beschreitest": "beschreiten",
    "beschreitet": "beschreiten",
    "beschrie": "beschreien",
    "beschrieb": "beschreiben",
    "beschriebe": "beschreiben",
    "beschrieben": "beschreiben",
    "beschriebene": "beschrieben",
    "beschriebenem": "beschrieben",
    "beschriebenen": "beschrieben",
    "beschriebener": "beschrieben",
    "beschriebenes": "beschrieben",
    "beschriebest": "beschreiben",
    "beschriebet": "beschreiben",
    "beschriebst": "beschreiben",
    "beschriebt": "beschreiben",
    "beschriee": "beschreien",
    "beschrieen": "beschreien",
    "beschrieest": "beschreien",
    "beschrieet": "beschreien",
    "beschrien": "beschreien",
    "beschriene": "beschrien",
    "beschrienem": "beschrien",
    "beschrienen": "beschrien",
    "beschriener": "beschrien",
    "beschrienes": "beschrien",
    "beschriest": "beschreien",
    "beschriet": "beschreien",
    "beschrifte": "beschriften",
    "beschriftend": "beschriften",
    "beschriftende": "beschriftend",
    "beschriftendem": "beschriftend",
    "beschriftenden": "beschriftend",
    "beschriftender": "beschriftend",
    "beschriftendes": "beschriftend",
    "beschriftest": "beschriften",
    "beschriftet": "beschriften",
    "beschriftete": "beschriften",
    "beschriftetem": "beschriftet",
    "beschrifteten": "beschriften",
    "beschrifteter": "beschriftet",
    "beschriftetes": "beschriftet",
    "beschriftetest": "beschriften",
    "beschriftetet": "beschriften",
    "beschritt": "beschreiten",
    "beschritte": "beschreiten",
    "beschritten": "beschreiten",
    "beschrittene": "beschritten",
    "beschrittenem": "beschritten",
    "beschrittenen": "beschritten",
    "beschrittener": "beschritten",
    "beschrittenes": "beschritten",
    "beschrittest": "beschreiten",
    "beschrittet": "beschreiten",
    "beschränke": "beschränken",
    "beschränkend": "beschränken",
    "beschränkende": "beschränkend",
    "beschränkendem": "beschränkend",
    "beschränkenden": "beschränkend",
    "beschränkender": "beschränkend",
    "beschränkendere": "beschränkend",
    "beschränkenderem": "beschränkend",
    "beschränkenderen": "beschränkend",
    "beschränkenderer": "beschränkend",
    "beschränkenderes": "beschränkend",
    "beschränkendes": "beschränkend",
    "beschränkendste": "beschränkend",
    "beschränkendstem": "beschränkend",
    "beschränkendsten": "beschränkend",
    "beschränkendster": "beschränkend",
    "beschränkendstes": "beschränkend",
    "beschränkest": "beschränken",
    "beschränket": "beschränken",
    "beschränkst": "beschränken",
    "beschränkt": "beschränken",
    "beschränkte": "beschränken",
    "beschränktem": "beschränkt",
    "beschränkten": "beschränken",
    "beschränkter": "beschränkt",
    "beschränktere": "beschränkt",
    "beschränkterem": "beschränkt",
    "beschränkteren": "beschränkt",
    "beschränkterer": "beschränkt",
    "beschränkteres": "beschränkt",
    "beschränktes": "beschränkt",
    "beschränktest": "beschränken",
    "beschränkteste": "beschränkt",
    "beschränktestem": "beschränkt",
    "beschränktesten": "beschränkt",
    "beschränktester": "beschränkt",
    "beschränktestes": "beschränkt",
    "beschränktet": "beschränken",
    "beschuhe": "beschuhen",
    "beschuhend": "beschuhen",
    "beschuhende": "beschuhend",
    "beschuhendem": "beschuhend",
    "beschuhenden": "beschuhend",
    "beschuhender": "beschuhend",
    "beschuhendes": "beschuhend",
    "beschuhest": "beschuhen",
    "beschuhet": "beschuhen",
    "beschuhst": "beschuhen",
    "beschuht": "beschuhen",
    "beschuhte": "beschuhen",
    "beschuhtem": "beschuht",
    "beschuhten": "beschuhen",
    "beschuhter": "beschuht",
    "beschuhtes": "beschuht",
    "beschuhtest": "beschuhen",
    "beschuhtet": "beschuhen",
    "beschuldige": "beschuldigen",
    "beschuldigend": "beschuldigen",
    "beschuldigende": "beschuldigend",
    "beschuldigendem": "beschuldigend",
    "beschuldigenden": "beschuldigend",
    "beschuldigender": "beschuldigend",
    "beschuldigendes": "beschuldigend",
    "beschuldigest": "beschuldigen",
    "beschuldiget": "beschuldigen",
    "beschuldigst": "beschuldigen",
    "beschuldigt": "beschuldigen",
    "beschuldigte": "beschuldigen",
    "beschuldigtem": "beschuldigt",
    "beschuldigten": "beschuldigen",
    "beschuldigter": "beschuldigt",
    "beschuldigtes": "beschuldigt",
    "beschuldigtest": "beschuldigen",
    "beschuldigtet": "beschuldigen",
    "beschwere": "beschweren",
    "beschwerend": "beschweren",
    "beschwerende": "beschwerend",
    "beschwerendem": "beschwerend",
    "beschwerenden": "beschwerend",
    "beschwerender": "beschwerend",
    "beschwerendes": "beschwerend",
    "beschwerest": "beschweren",
    "beschweret": "beschweren",
    "beschwerliche": "beschwerlich",
    "beschwerlichem": "beschwerlich",
    "beschwerlichen": "beschwerlich",
    "beschwerlicher": "beschwerlich",
    "beschwerlichere": "beschwerlich",
    "beschwerlicherem": "beschwerlich",
    "beschwerlicheren": "beschwerlich",
    "beschwerlicherer": "beschwerlich",
    "beschwerlicheres": "beschwerlich",
    "beschwerliches": "beschwerlich",
    "beschwerlichste": "beschwerlich",
    "beschwerlichstem": "beschwerlich",
    "beschwerlichsten": "beschwerlich",
    "beschwerlichster": "beschwerlich",
    "beschwerlichstes": "beschwerlich",
    "beschwerst": "beschweren",
    "beschwert": "beschweren",
    "beschwerte": "beschweren",
    "beschwertem": "beschwert",
    "beschwerten": "beschweren",
    "beschwerter": "beschwert",
    "beschwertes": "beschwert",
    "beschwertest": "beschweren",
    "beschwertet": "beschweren",
    "beschwichtige": "beschwichtigen",
    "beschwichtigend": "beschwichtigen",
    "beschwichtigende": "beschwichtigend",
    "beschwichtigendem": "beschwichtigend",
    "beschwichtigenden": "beschwichtigend",
    "beschwichtigender": "beschwichtigend",
    "beschwichtigendere": "beschwichtigend",
    "beschwichtigenderem": "beschwichtigend",
    "beschwichtigenderen": "beschwichtigend",
    "beschwichtigenderer": "beschwichtigend",
    "beschwichtigenderes": "beschwichtigend",
    "beschwichtigendes": "beschwichtigend",
    "beschwichtigendste": "beschwichtigend",
    "beschwichtigendstem": "beschwichtigend",
    "beschwichtigendsten": "beschwichtigend",
    "beschwichtigendster": "beschwichtigend",
    "beschwichtigendstes": "beschwichtigend",
    "beschwichtigest": "beschwichtigen",
    "beschwichtiget": "beschwichtigen",
    "beschwichtigst": "beschwichtigen",
    "beschwichtigt": "beschwichtigen",
    "beschwichtigte": "beschwichtigen",
    "beschwichtigtem": "beschwichtigt",
    "beschwichtigten": "beschwichtigen",
    "beschwichtigter": "beschwichtigt",
    "beschwichtigtes": "beschwichtigt",
    "beschwichtigtest": "beschwichtigen",
    "beschwichtigtet": "beschwichtigen",
    "beschwingte": "beschwingt",
    "beschwingtem": "beschwingt",
    "beschwingten": "beschwingt",
    "beschwingter": "beschwingt",
    "beschwingtere": "beschwingt",
    "beschwingterem": "beschwingt",
    "beschwingteren": "beschwingt",
    "beschwingterer": "beschwingt",
    "beschwingteres": "beschwingt",
    "beschwingtes": "beschwingt",
    "beschwingteste": "beschwingt",
    "beschwingtestem": "beschwingt",
    "beschwingtesten": "beschwingt",
    "beschwingtester": "beschwingt",
    "beschwingtestes": "beschwingt",
    "beschwor": "beschwören",
    "beschworen": "beschwören",
    "beschworene": "beschworen",
    "beschworenem": "beschworen",
    "beschworenen": "beschworen",
    "beschworener": "beschworen",
    "beschworenes": "beschworen",
    "beschworst": "beschwören",
    "beschwort": "beschwören",
    "beschwöre": "beschwören",
    "beschwörend": "beschwören",
    "beschwörende": "beschwörend",
    "beschwörendem": "beschwörend",
    "beschwörenden": "beschwörend",
    "beschwörender": "beschwörend",
    "beschwörendes": "beschwörend",
    "beschwörest": "beschwören",
    "beschwöret": "beschwören",
    "beschwörst": "beschwören",
    "beschwört": "beschwören",
    "beschädige": "beschädigen",
    "beschädigend": "beschädigen",
    "beschädigende": "beschädigend",
    "beschädigendem": "beschädigend",
    "beschädigenden": "beschädigend",
    "beschädigender": "beschädigend",
    "beschädigendes": "beschädigend",
    "beschädigest": "beschädigen",
    "beschädiget": "beschädigen",
    "beschädigst": "beschädigen",
    "beschädigt": "beschädigen",
    "beschädigte": "beschädigen",
    "beschädigtem": "beschädigt",
    "beschädigten": "beschädigen",
    "beschädigter": "beschädigt",
    "beschädigtere": "beschädigt",
    "beschädigterem": "beschädigt",
    "beschädigteren": "beschädigt",
    "beschädigterer": "beschädigt",
    "beschädigteres": "beschädigt",
    "beschädigtes": "beschädigt",
    "beschädigtest": "beschädigen",
    "beschädigteste": "beschädigt",
    "beschädigtestem": "beschädigt",
    "beschädigtesten": "beschädigt",
    "beschädigtester": "beschädigt",
    "beschädigtestes": "beschädigt",
    "beschädigtet": "beschädigen",
    "beschäftige": "beschäftigen",
    "beschäftigend": "beschäftigen",
    "beschäftigende": "beschäftigend",
    "beschäftigendem": "beschäftigend",
    "beschäftigenden": "beschäftigend",
    "beschäftigender": "beschäftigend",
    "beschäftigendes": "beschäftigend",
    "beschäftigest": "beschäftigen",
    "beschäftiget": "beschäftigen",
    "beschäftigst": "beschäftigen",
    "beschäftigt": "beschäftigen",
    "beschäftigte": "beschäftigen",
    "beschäftigtem": "beschäftigt",
    "beschäftigten": "beschäftigen",
    "beschäftigter": "beschäftigt",
    "beschäftigtere": "beschäftigt",
    "beschäftigterem": "beschäftigt",
    "beschäftigteren": "beschäftigt",
    "beschäftigterer": "beschäftigt",
    "beschäftigteres": "beschäftigt",
    "beschäftigtes": "beschäftigt",
    "beschäftigtest": "beschäftigen",
    "beschäftigteste": "beschäftigt",
    "beschäftigtestem": "beschäftigt",
    "beschäftigtesten": "beschäftigt",
    "beschäftigtester": "beschäftigt",
    "beschäftigtestes": "beschäftigt",
    "beschäftigtet": "beschäftigen",
    "beschäftigungslosem": "beschäftigungslos",
    "beschäftigungslosen": "beschäftigungslos",
    "beschäftigungsloser": "beschäftigungslos",
    "beschäftigungsloses": "beschäftigungslos",
    "beschönige": "beschönigen",
    "beschönigend": "beschönigen",
    "beschönigende": "beschönigend",
    "beschönigendem": "beschönigend",
    "beschönigenden": "beschönigend",
    "beschönigender": "beschönigend",
    "beschönigendere": "beschönigend",
    "beschönigenderem": "beschönigend",
    "beschönigenderen": "beschönigend",
    "beschönigenderer": "beschönigend",
    "beschönigenderes": "beschönigend",
    "beschönigendes": "beschönigend",
    "beschönigendste": "beschönigend",
    "beschönigendstem": "beschönigend",
    "beschönigendsten": "beschönigend",
    "beschönigendster": "beschönigend",
    "beschönigendstes": "beschönigend",
    "beschönigest": "beschönigen",
    "beschöniget": "beschönigen",
    "beschönigst": "beschönigen",
    "beschönigt": "beschönigen",
    "beschönigte": "beschönigen",
    "beschönigtem": "beschönigt",
    "beschönigten": "beschönigen",
    "beschönigter": "beschönigt",
    "beschönigtere": "beschönigt",
    "beschönigterem": "beschönigt",
    "beschönigteren": "beschönigt",
    "beschönigterer": "beschönigt",
    "beschönigteres": "beschönigt",
    "beschönigtes": "beschönigt",
    "beschönigtest": "beschönigen",
    "beschönigteste": "beschönigt",
    "beschönigtestem": "beschönigt",
    "beschönigtesten": "beschönigt",
    "beschönigtester": "beschönigt",
    "beschönigtestes": "beschönigt",
    "beschönigtet": "beschönigen",
    "beschütze": "beschützen",
    "beschützend": "beschützen",
    "beschützende": "beschützend",
    "beschützendem": "beschützend",
    "beschützenden": "beschützend",
    "beschützender": "beschützend",
    "beschützendes": "beschützend",
    "beschützest": "beschützen",
    "beschützet": "beschützen",
    "beschützt": "beschützen",
    "beschützte": "beschützen",
    "beschütztem": "beschützt",
    "beschützten": "beschützen",
    "beschützter": "beschützt",
    "beschütztere": "beschützt",
    "beschützterem": "beschützt",
    "beschützteren": "beschützt",
    "beschützterer": "beschützt",
    "beschützteres": "beschützt",
    "beschütztes": "beschützt",
    "beschütztest": "beschützen",
    "beschützteste": "beschützt",
    "beschütztestem": "beschützt",
    "beschütztesten": "beschützt",
    "beschütztester": "beschützt",
    "beschütztestes": "beschützt",
    "beschütztet": "beschützen",
    "beseele": "beseelen",
    "beseelend": "beseelen",
    "beseelende": "beseelend",
    "beseelendem": "beseelend",
    "beseelenden": "beseelend",
    "beseelender": "beseelend",
    "beseelendes": "beseelend",
    "beseelest": "beseelen",
    "beseelet": "beseelen",
    "beseelst": "beseelen",
    "beseelt": "beseelen",
    "beseelte": "beseelen",
    "beseeltem": "beseelt",
    "beseelten": "beseelen",
    "beseelter": "beseelt",
    "beseeltes": "beseelt",
    "beseeltest": "beseelen",
    "beseeltet": "beseelen",
    "besegele": "besegeln",
    "besegelnd": "besegeln",
    "besegelnde": "besegelnd",
    "besegelndem": "besegelnd",
    "besegelnden": "besegelnd",
    "besegelnder": "besegelnd",
    "besegelndes": "besegelnd",
    "besegelst": "besegeln",
    "besegelt": "besegeln",
    "besegelte": "besegeln",
    "besegeltem": "besegelt",
    "besegelten": "besegeln",
    "besegelter": "besegelt",
    "besegeltes": "besegelt",
    "besegeltest": "besegeln",
    "besegeltet": "besegeln",
    "besegle": "besegeln",
    "beseitige": "beseitigen",
    "beseitigend": "beseitigen",
    "beseitigende": "beseitigend",
    "beseitigendem": "beseitigend",
    "beseitigenden": "beseitigend",
    "beseitigender": "beseitigend",
    "beseitigendes": "beseitigend",
    "beseitigest": "beseitigen",
    "beseitiget": "beseitigen",
    "beseitigst": "beseitigen",
    "beseitigt": "beseitigen",
    "beseitigte": "beseitigen",
    "beseitigtem": "beseitigt",
    "beseitigten": "beseitigen",
    "beseitigter": "beseitigt",
    "beseitigtes": "beseitigt",
    "beseitigtest": "beseitigen",
    "beseitigtet": "beseitigen",
    "besenreinem": "besenrein",
    "besenreinen": "besenrein",
    "besenreiner": "besenrein",
    "besenreines": "besenrein",
    "besessen": "besitzen",
    "besessene": "besessen",
    "besessenem": "besessen",
    "besessenen": "besessen",
    "besessener": "besessen",
    "besessenere": "besessen",
    "besessenerem": "besessen",
    "besesseneren": "besessen",
    "besessenerer": "besessen",
    "besesseneres": "besessen",
    "besessenes": "besessen",
    "besessenste": "besessen",
    "besessenstem": "besessen",
    "besessensten": "besessen",
    "besessenster": "besessen",
    "besessenstes": "besessen",
    "besetze": "besetzen",
    "besetzend": "besetzen",
    "besetzende": "besetzend",
    "besetzendem": "besetzend",
    "besetzenden": "besetzend",
    "besetzender": "besetzend",
    "besetzendes": "besetzend",
    "besetzest": "besetzen",
    "besetzet": "besetzen",
    "besetzt": "besetzen",
    "besetzte": "besetzen",
    "besetztem": "besetzt",
    "besetzten": "besetzen",
    "besetzter": "besetzt",
    "besetztes": "besetzt",
    "besetztest": "besetzen",
    "besetztet": "besetzen",
    "besichtige": "besichtigen",
    "besichtigend": "besichtigen",
    "besichtigende": "besichtigend",
    "besichtigendem": "besichtigend",
    "besichtigenden": "besichtigend",
    "besichtigender": "besichtigend",
    "besichtigendes": "besichtigend",
    "besichtigest": "besichtigen",
    "besichtiget": "besichtigen",
    "besichtigst": "besichtigen",
    "besichtigt": "besichtigen",
    "besichtigte": "besichtigen",
    "besichtigtem": "besichtigt",
    "besichtigten": "besichtigen",
    "besichtigter": "besichtigt",
    "besichtigtes": "besichtigt",
    "besichtigtest": "besichtigen",
    "besichtigtet": "besichtigen",
    "besiedele": "besiedeln",
    "besiedelnd": "besiedeln",
    "besiedelnde": "besiedelnd",
    "besiedelndem": "besiedelnd",
    "besiedelnden": "besiedelnd",
    "besiedelnder": "besiedelnd",
    "besiedelndes": "besiedelnd",
    "besiedelst": "besiedeln",
    "besiedelt": "besiedeln",
    "besiedelte": "besiedeln",
    "besiedeltem": "besiedelt",
    "besiedelten": "besiedeln",
    "besiedelter": "besiedelt",
    "besiedeltere": "besiedelt",
    "besiedelterem": "besiedelt",
    "besiedelteren": "besiedelt",
    "besiedelterer": "besiedelt",
    "besiedelteres": "besiedelt",
    "besiedeltes": "besiedelt",
    "besiedeltest": "besiedeln",
    "besiedelteste": "besiedelt",
    "besiedeltestem": "besiedelt",
    "besiedeltesten": "besiedelt",
    "besiedeltester": "besiedelt",
    "besiedeltestes": "besiedelt",
    "besiedeltet": "besiedeln",
    "besiedle": "besiedeln",
    "besiegbare": "besiegbar",
    "besiegbarem": "besiegbar",
    "besiegbaren": "besiegbar",
    "besiegbarer": "besiegbar",
    "besiegbares": "besiegbar",
    "besiege": "besiegen",
    "besiegele": "besiegeln",
    "besiegelnd": "besiegeln",
    "besiegelnde": "besiegelnd",
    "besiegelndem": "besiegelnd",
    "besiegelnden": "besiegelnd",
    "besiegelnder": "besiegelnd",
    "besiegelndes": "besiegelnd",
    "besiegelst": "besiegeln",
    "besiegelt": "besiegeln",
    "besiegelte": "besiegeln",
    "besiegeltem": "besiegelt",
    "besiegelten": "besiegeln",
    "besiegelter": "besiegelt",
    "besiegeltes": "besiegelt",
    "besiegeltest": "besiegeln",
    "besiegeltet": "besiegeln",
    "besiegend": "besiegen",
    "besiegende": "besiegend",
    "besiegendem": "besiegend",
    "besiegenden": "besiegend",
    "besiegender": "besiegend",
    "besiegendes": "besiegend",
    "besiegest": "besiegen",
    "besieget": "besiegen",
    "besiegle": "besiegeln",
    "besiegst": "besiegen",
    "besiegt": "besiegen",
    "besiegte": "besiegen",
    "besiegtem": "besiegt",
    "besiegten": "besiegen",
    "besiegter": "besiegt",
    "besiegtes": "besiegt",
    "besiegtest": "besiegen",
    "besiegtet": "besiegen",
    "besinge": "besingen",
    "besingend": "besingen",
    "besingende": "besingend",
    "besingendem": "besingend",
    "besingenden": "besingend",
    "besingender": "besingend",
    "besingendes": "besingend",
    "besingest": "besingen",
    "besinget": "besingen",
    "besingst": "besingen",
    "besingt": "besingen",
    "besinne": "besinnen",
    "besinnend": "besinnen",
    "besinnende": "besinnend",
    "besinnendem": "besinnend",
    "besinnenden": "besinnend",
    "besinnender": "besinnend",
    "besinnendere": "besinnend",
    "besinnenderem": "besinnend",
    "besinnenderen": "besinnend",
    "besinnenderer": "besinnend",
    "besinnenderes": "besinnend",
    "besinnendes": "besinnend",
    "besinnendste": "besinnend",
    "besinnendstem": "besinnend",
    "besinnendsten": "besinnend",
    "besinnendster": "besinnend",
    "besinnendstes": "besinnend",
    "besinnest": "besinnen",
    "besinnet": "besinnen",
    "besinnliche": "besinnlich",
    "besinnlichem": "besinnlich",
    "besinnlichen": "besinnlich",
    "besinnlicher": "besinnlich",
    "besinnlichere": "besinnlich",
    "besinnlicherem": "besinnlich",
    "besinnlicheren": "besinnlich",
    "besinnlicherer": "besinnlich",
    "besinnlicheres": "besinnlich",
    "besinnliches": "besinnlich",
    "besinnlichste": "besinnlich",
    "besinnlichstem": "besinnlich",
    "besinnlichsten": "besinnlich",
    "besinnlichster": "besinnlich",
    "besinnlichstes": "besinnlich",
    "besinnst": "besinnen",
    "besinnt": "besinnen",
    "besinnungslose": "besinnungslos",
    "besinnungslosem": "besinnungslos",
    "besinnungslosen": "besinnungslos",
    "besinnungsloser": "besinnungslos",
    "besinnungslosere": "besinnungslos",
    "besinnungsloserem": "besinnungslos",
    "besinnungsloseren": "besinnungslos",
    "besinnungsloserer": "besinnungslos",
    "besinnungsloseres": "besinnungslos",
    "besinnungsloses": "besinnungslos",
    "besinnungsloseste": "besinnungslos",
    "besinnungslosestem": "besinnungslos",
    "besinnungslosesten": "besinnungslos",
    "besinnungslosester": "besinnungslos",
    "besinnungslosestes": "besinnungslos",
    "besitz": "besitzen",
    "besitzend": "besitzen",
    "besitzende": "besitzend",
    "besitzendem": "besitzend",
    "besitzenden": "besitzend",
    "besitzender": "besitzend",
    "besitzendes": "besitzend",
    "besitzest": "besitzen",
    "besitzet": "besitzen",
    "besitzt": "besitzen",
    "besoff": "besaufen",
    "besoffen": "besaufen",
    "besoffene": "besoffen",
    "besoffenem": "besoffen",
    "besoffenen": "besoffen",
    "besoffener": "besoffen",
    "besoffenere": "besoffen",
    "besoffenerem": "besoffen",
    "besoffeneren": "besoffen",
    "besoffenerer": "besoffen",
    "besoffeneres": "besoffen",
    "besoffenes": "besoffen",
    "besoffenste": "besoffen",
    "besoffenstem": "besoffen",
    "besoffensten": "besoffen",
    "besoffenster": "besoffen",
    "besoffenstes": "besoffen",
    "besoffst": "besaufen",
    "besofft": "besaufen",
    "besohle": "besohlen",
    "besohlend": "besohlen",
    "besohlende": "besohlend",
    "besohlendem": "besohlend",
    "besohlenden": "besohlend",
    "besohlender": "besohlend",
    "besohlendes": "besohlend",
    "besohlest": "besohlen",
    "besohlet": "besohlen",
    "besohlst": "besohlen",
    "besohlt": "besohlen",
    "besohlte": "besohlen",
    "besohltem": "besohlt",
    "besohlten": "besohlen",
    "besohlter": "besohlt",
    "besohltes": "besohlt",
    "besohltest": "besohlen",
    "besohltet": "besohlen",
    "besolde": "besolden",
    "besoldend": "besolden",
    "besoldende": "besoldend",
    "besoldendem": "besoldend",
    "besoldenden": "besoldend",
    "besoldender": "besoldend",
    "besoldendes": "besoldend",
    "besoldest": "besolden",
    "besoldet": "besolden",
    "besoldete": "besolden",
    "besoldetem": "besoldet",
    "besoldeten": "besolden",
    "besoldeter": "besoldet",
    "besoldetes": "besoldet",
    "besoldetest": "besolden",
    "besoldetet": "besolden",
    "besondere": "besonder",
    "besonderem": "besonder",
    "besonderen": "besonder",
    "besonderer": "besonder",
    "besonderes": "besonder",
    "besonnen": "besinnen",
    "besonnene": "besonnen",
    "besonnenem": "besonnen",
    "besonnenen": "besonnen",
    "besonnener": "besonnen",
    "besonnenere": "besonnen",
    "besonnenerem": "besonnen",
    "besonneneren": "besonnen",
    "besonnenerer": "besonnen",
    "besonneneres": "besonnen",
    "besonnenes": "besonnen",
    "besonnenste": "besonnen",
    "besonnenstem": "besonnen",
    "besonnensten": "besonnen",
    "besonnenster": "besonnen",
    "besonnenstes": "besonnen",
    "besorge": "besorgen",
    "besorgend": "besorgen",
    "besorgende": "besorgend",
    "besorgendem": "besorgend",
    "besorgenden": "besorgend",
    "besorgender": "besorgend",
    "besorgendes": "besorgend",
    "besorgest": "besorgen",
    "besorget": "besorgen",
    "besorgniserregende": "besorgniserregend",
    "besorgniserregendem": "besorgniserregend",
    "besorgniserregenden": "besorgniserregend",
    "besorgniserregender": "besorgniserregend",
    "besorgniserregendere": "besorgniserregend",
    "besorgniserregenderem": "besorgniserregend",
    "besorgniserregenderen": "besorgniserregend",
    "besorgniserregenderer": "besorgniserregend",
    "besorgniserregenderes": "besorgniserregend",
    "besorgniserregendes": "besorgniserregend",
    "besorgniserregendste": "besorgniserregend",
    "besorgniserregendstem": "besorgniserregend",
    "besorgniserregendsten": "besorgniserregend",
    "besorgniserregendster": "besorgniserregend",
    "besorgniserregendstes": "besorgniserregend",
    "besorgst": "besorgen",
    "besorgt": "besorgen",
    "besorgte": "besorgen",
    "besorgtem": "besorgt",
    "besorgten": "besorgen",
    "besorgter": "besorgt",
    "besorgtere": "besorgt",
    "besorgterem": "besorgt",
    "besorgteren": "besorgt",
    "besorgterer": "besorgt",
    "besorgteres": "besorgt",
    "besorgtes": "besorgt",
    "besorgtest": "besorgen",
    "besorgteste": "besorgt",
    "besorgtestem": "besorgt",
    "besorgtesten": "besorgt",
    "besorgtester": "besorgt",
    "besorgtestes": "besorgt",
    "besorgtet": "besorgen",
    "bespanne": "bespannen",
    "bespannend": "bespannen",
    "bespannende": "bespannend",
    "bespannendem": "bespannend",
    "bespannenden": "bespannend",
    "bespannender": "bespannend",
    "bespannendes": "bespannend",
    "bespannest": "bespannen",
    "bespannet": "bespannen",
    "bespannst": "bespannen",
    "bespannt": "bespannen",
    "bespannte": "bespannen",
    "bespanntem": "bespannt",
    "bespannten": "bespannen",
    "bespannter": "bespannt",
    "bespanntes": "bespannt",
    "bespanntest": "bespannen",
    "bespanntet": "bespannen",
    "bespiele": "bespielen",
    "bespielend": "bespielen",
    "bespielende": "bespielend",
    "bespielendem": "bespielend",
    "bespielenden": "bespielend",
    "bespielender": "bespielend",
    "bespielendes": "bespielend",
    "bespielest": "bespielen",
    "bespielet": "bespielen",
    "bespielst": "bespielen",
    "bespielt": "bespielen",
    "bespielte": "bespielen",
    "bespieltem": "bespielt",
    "bespielten": "bespielen",
    "bespielter": "bespielt",
    "bespieltes": "bespielt",
    "bespieltest": "bespielen",
    "bespieltet": "bespielen",
    "bespitzele": "bespitzeln",
    "bespitzelnd": "bespitzeln",
    "bespitzelnde": "bespitzelnd",
    "bespitzelndem": "bespitzelnd",
    "bespitzelnden": "bespitzelnd",
    "bespitzelnder": "bespitzelnd",
    "bespitzelndere": "bespitzelnd",
    "bespitzelnderem": "bespitzelnd",
    "bespitzelnderen": "bespitzelnd",
    "bespitzelnderer": "bespitzelnd",
    "bespitzelnderes": "bespitzelnd",
    "bespitzelndes": "bespitzelnd",
    "bespitzelndste": "bespitzelnd",
    "bespitzelndstem": "bespitzelnd",
    "bespitzelndsten": "bespitzelnd",
    "bespitzelndster": "bespitzelnd",
    "bespitzelndstes": "bespitzelnd",
    "bespitzelst": "bespitzeln",
    "bespitzelt": "bespitzeln",
    "bespitzelte": "bespitzeln",
    "bespitzeltem": "bespitzelt",
    "bespitzelten": "bespitzeln",
    "bespitzelter": "bespitzelt",
    "bespitzeltere": "bespitzelt",
    "bespitzelterem": "bespitzelt",
    "bespitzelteren": "bespitzelt",
    "bespitzelterer": "bespitzelt",
    "bespitzelteres": "bespitzelt",
    "bespitzeltes": "bespitzelt",
    "bespitzeltest": "bespitzeln",
    "bespitzelteste": "bespitzelt",
    "bespitzeltestem": "bespitzelt",
    "bespitzeltesten": "bespitzelt",
    "bespitzeltester": "bespitzelt",
    "bespitzeltestes": "bespitzelt",
    "bespitzeltet": "bespitzeln",
    "bespitzle": "bespitzeln",
    "besprach": "besprechen",
    "besprachen": "besprechen",
    "besprachst": "besprechen",
    "bespracht": "besprechen",
    "bespreche": "besprechen",
    "besprechend": "besprechen",
    "besprechende": "besprechend",
    "besprechendem": "besprechend",
    "besprechenden": "besprechend",
    "besprechender": "besprechend",
    "besprechendere": "besprechend",
    "besprechenderem": "besprechend",
    "besprechenderen": "besprechend",
    "besprechenderer": "besprechend",
    "besprechenderes": "besprechend",
    "besprechendes": "besprechend",
    "besprechendste": "besprechend",
    "besprechendstem": "besprechend",
    "besprechendsten": "besprechend",
    "besprechendster": "besprechend",
    "besprechendstes": "besprechend",
    "besprechest": "besprechen",
    "besprechet": "besprechen",
    "besprecht": "besprechen",
    "besprenkele": "besprenkeln",
    "besprenkelnd": "besprenkeln",
    "besprenkelnde": "besprenkelnd",
    "besprenkelndem": "besprenkelnd",
    "besprenkelnden": "besprenkelnd",
    "besprenkelnder": "besprenkelnd",
    "besprenkelndere": "besprenkelnd",
    "besprenkelnderem": "besprenkelnd",
    "besprenkelnderen": "besprenkelnd",
    "besprenkelnderer": "besprenkelnd",
    "besprenkelnderes": "besprenkelnd",
    "besprenkelndes": "besprenkelnd",
    "besprenkelndste": "besprenkelnd",
    "besprenkelndstem": "besprenkelnd",
    "besprenkelndsten": "besprenkelnd",
    "besprenkelndster": "besprenkelnd",
    "besprenkelndstes": "besprenkelnd",
    "besprenkelst": "besprenkeln",
    "besprenkelt": "besprenkeln",
    "besprenkelte": "besprenkeln",
    "besprenkeltem": "besprenkelt",
    "besprenkelten": "besprenkeln",
    "besprenkelter": "besprenkelt",
    "besprenkeltere": "besprenkelt",
    "besprenkelterem": "besprenkelt",
    "besprenkelteren": "besprenkelt",
    "besprenkelterer": "besprenkelt",
    "besprenkelteres": "besprenkelt",
    "besprenkeltes": "besprenkelt",
    "besprenkeltest": "besprenkeln",
    "besprenkelteste": "besprenkelt",
    "besprenkeltestem": "besprenkelt",
    "besprenkeltesten": "besprenkelt",
    "besprenkeltester": "besprenkelt",
    "besprenkeltestes": "besprenkelt",
    "besprenkeltet": "besprenkeln",
    "besprenkle": "besprenkeln",
    "besprich": "besprechen",
    "besprichst": "besprechen",
    "bespricht": "besprechen",
    "bespritze": "bespritzen",
    "bespritzend": "bespritzen",
    "bespritzende": "bespritzend",
    "bespritzendem": "bespritzend",
    "bespritzenden": "bespritzend",
    "bespritzender": "bespritzend",
    "bespritzendere": "bespritzend",
    "bespritzenderem": "bespritzend",
    "bespritzenderen": "bespritzend",
    "bespritzenderer": "bespritzend",
    "bespritzenderes": "bespritzend",
    "bespritzendes": "bespritzend",
    "bespritzendste": "bespritzend",
    "bespritzendstem": "bespritzend",
    "bespritzendsten": "bespritzend",
    "bespritzendster": "bespritzend",
    "bespritzendstes": "bespritzend",
    "bespritzest": "bespritzen",
    "bespritzet": "bespritzen",
    "bespritzt": "bespritzen",
    "bespritzte": "bespritzen",
    "bespritztem": "bespritzt",
    "bespritzten": "bespritzen",
    "bespritzter": "bespritzt",
    "bespritztere": "bespritzt",
    "bespritzterem": "bespritzt",
    "bespritzteren": "bespritzt",
    "bespritzterer": "bespritzt",
    "bespritzteres": "bespritzt",
    "bespritztes": "bespritzt",
    "bespritztest": "bespritzen",
    "bespritzteste": "bespritzt",
    "bespritztestem": "bespritzt",
    "bespritztesten": "bespritzt",
    "bespritztester": "bespritzt",
    "bespritztestes": "bespritzt",
    "bespritztet": "bespritzen",
    "besprochen": "besprechen",
    "besprochene": "besprochen",
    "besprochenem": "besprochen",
    "besprochenen": "besprochen",
    "besprochener": "besprochen",
    "besprochenere": "besprochen",
    "besprochenerem": "besprochen",
    "besprocheneren": "besprochen",
    "besprochenerer": "besprochen",
    "besprocheneres": "besprochen",
    "besprochenes": "besprochen",
    "besprochenste": "besprochen",
    "besprochenstem": "besprochen",
    "besprochensten": "besprochen",
    "besprochenster": "besprochen",
    "besprochenstes": "besprochen",
    "bespräche": "besprechen",
    "besprächen": "besprechen",
    "besprächest": "besprechen",
    "besprächet": "besprechen",
    "besprühe": "besprühen",
    "besprühend": "besprühen",
    "besprühende": "besprühend",
    "besprühendem": "besprühend",
    "besprühenden": "besprühend",
    "besprühender": "besprühend",
    "besprühendes": "besprühend",
    "besprühest": "besprühen",
    "besprühet": "besprühen",
    "besprühst": "besprühen",
    "besprüht": "besprühen",
    "besprühte": "besprühen",
    "besprühtem": "besprüht",
    "besprühten": "besprühen",
    "besprühter": "besprüht",
    "besprühtes": "besprüht",
    "besprühtest": "besprühen",
    "besprühtet": "besprühen",
    "bespucke": "bespucken",
    "bespuckend": "bespucken",
    "bespuckende": "bespuckend",
    "bespuckendem": "bespuckend",
    "bespuckenden": "bespuckend",
    "bespuckender": "bespuckend",
    "bespuckendere": "bespuckend",
    "bespuckenderem": "bespuckend",
    "bespuckenderen": "bespuckend",
    "bespuckenderer": "bespuckend",
    "bespuckenderes": "bespuckend",
    "bespuckendes": "bespuckend",
    "bespuckendste": "bespuckend",
    "bespuckendstem": "bespuckend",
    "bespuckendsten": "bespuckend",
    "bespuckendster": "bespuckend",
    "bespuckendstes": "bespuckend",
    "bespuckest": "bespucken",
    "bespucket": "bespucken",
    "bespuckst": "bespucken",
    "bespuckt": "bespucken",
    "bespuckte": "bespucken",
    "bespucktem": "bespuckt",
    "bespuckten": "bespucken",
    "bespuckter": "bespuckt",
    "bespucktere": "bespuckt",
    "bespuckterem": "bespuckt",
    "bespuckteren": "bespuckt",
    "bespuckterer": "bespuckt",
    "bespuckteres": "bespuckt",
    "bespucktes": "bespuckt",
    "bespucktest": "bespucken",
    "bespuckteste": "bespuckt",
    "bespucktestem": "bespuckt",
    "bespucktesten": "bespuckt",
    "bespucktester": "bespuckt",
    "bespucktestes": "bespuckt",
    "bespucktet": "bespucken",
    "besser": "gut",
    "bessere": "gut",
    "besserem": "gut",
    "besseren": "gut",
    "besserer": "gut",
    "besseres": "gut",
    "bessernd": "bessern",
    "bessernde": "bessernd",
    "besserndem": "bessernd",
    "bessernden": "bessernd",
    "bessernder": "bessernd",
    "besserndes": "bessernd",
    "besserst": "bessern",
    "bessert": "bessern",
    "besserte": "bessern",
    "besserten": "bessern",
    "bessertest": "bessern",
    "bessertet": "bessern",
    "bestach": "bestechen",
    "bestachen": "bestechen",
    "bestachst": "bestechen",
    "bestacht": "bestechen",
    "bestahl": "bestehlen",
    "bestahlen": "bestehlen",
    "bestahlst": "bestehlen",
    "bestahlt": "bestehlen",
    "bestanden": "bestehen",
    "bestandenem": "bestanden",
    "bestandenen": "bestanden",
    "bestandener": "bestanden",
    "bestandenes": "bestanden",
    "bestandest": "bestehen",
    "bestandet": "bestehen",
    "bestatte": "bestatten",
    "bestattend": "bestatten",
    "bestattende": "bestattend",
    "bestattendem": "bestattend",
    "bestattenden": "bestattend",
    "bestattender": "bestattend",
    "bestattendes": "bestattend",
    "bestattest": "bestatten",
    "bestattet": "bestatten",
    "bestattete": "bestatten",
    "bestattetem": "bestattet",
    "bestatteten": "bestatten",
    "bestatteter": "bestattet",
    "bestattetes": "bestattet",
    "bestattetest": "bestatten",
    "bestattetet": "bestatten",
    "bestaune": "bestaunen",
    "bestaunend": "bestaunen",
    "bestaunende": "bestaunend",
    "bestaunendem": "bestaunend",
    "bestaunenden": "bestaunend",
    "bestaunender": "bestaunend",
    "bestaunendes": "bestaunend",
    "bestaunest": "bestaunen",
    "bestaunet": "bestaunen",
    "bestaunst": "bestaunen",
    "bestaunt": "bestaunen",
    "bestaunte": "bestaunen",
    "bestauntem": "bestaunt",
    "bestaunten": "bestaunen",
    "bestaunter": "bestaunt",
    "bestauntere": "bestaunt",
    "bestaunterem": "bestaunt",
    "bestaunteren": "bestaunt",
    "bestaunterer": "bestaunt",
    "bestaunteres": "bestaunt",
    "bestauntes": "bestaunt",
    "bestauntest": "bestaunen",
    "bestaunteste": "bestaunt",
    "bestauntestem": "bestaunt",
    "bestauntesten": "bestaunt",
    "bestauntester": "bestaunt",
    "bestauntestes": "bestaunt",
    "bestauntet": "bestaunen",
    "beste": "gut",
    "besteche": "bestechen",
    "bestechend": "bestechen",
    "bestechende": "bestechend",
    "bestechendem": "bestechend",
    "bestechenden": "bestechend",
    "bestechender": "bestechend",
    "bestechendere": "bestechend",
    "bestechenderem": "bestechend",
    "bestechenderen": "bestechend",
    "bestechenderer": "bestechend",
    "bestechenderes": "bestechend",
    "bestechendes": "bestechend",
    "bestechendste": "bestechend",
    "bestechendstem": "bestechend",
    "bestechendsten": "bestechend",
    "bestechendster": "bestechend",
    "bestechendstes": "bestechend",
    "bestechest": "bestechen",
    "bestechet": "bestechen",
    "bestechliche": "bestechlich",
    "bestechlichem": "bestechlich",
    "bestechlichen": "bestechlich",
    "bestechlicher": "bestechlich",
    "bestechlichere": "bestechlich",
    "bestechlicherem": "bestechlich",
    "bestechlicheren": "bestechlich",
    "bestechlicherer": "bestechlich",
    "bestechlicheres": "bestechlich",
    "bestechliches": "bestechlich",
    "bestechlichste": "bestechlich",
    "bestechlichstem": "bestechlich",
    "bestechlichsten": "bestechlich",
    "bestechlichster": "bestechlich",
    "bestechlichstes": "bestechlich",
    "bestecht": "bestechen",
    "bestehe": "bestehen",
    "bestehenbleibe": "bestehenbleiben",
    "bestehenbleibend": "bestehenbleiben",
    "bestehenbleibende": "bestehenbleibend",
    "bestehenbleibendem": "bestehenbleibend",
    "bestehenbleibenden": "bestehenbleibend",
    "bestehenbleibender": "bestehenbleibend",
    "bestehenbleibendes": "bestehenbleibend",
    "bestehenbleibest": "bestehenbleiben",
    "bestehenbleibet": "bestehenbleiben",
    "bestehenbleibst": "bestehenbleiben",
    "bestehenbleibt": "bestehenbleiben",
    "bestehenblieb": "bestehenbleiben",
    "bestehenbliebe": "bestehenbleiben",
    "bestehenblieben": "bestehenbleiben",
    "bestehenbliebest": "bestehenbleiben",
    "bestehenbliebet": "bestehenbleiben",
    "bestehenbliebst": "bestehenbleiben",
    "bestehenbliebt": "bestehenbleiben",
    "bestehend": "bestehen",
    "bestehende": "bestehend",
    "bestehendem": "bestehend",
    "bestehenden": "bestehend",
    "bestehender": "bestehend",
    "bestehendes": "bestehend",
    "bestehengeblieben": "bestehenbleiben",
    "bestehengebliebene": "bestehengeblieben",
    "bestehengebliebenem": "bestehengeblieben",
    "bestehengebliebenen": "bestehengeblieben",
    "bestehengebliebener": "bestehengeblieben",
    "bestehengebliebenes": "bestehengeblieben",
    "bestehenzubleiben": "bestehenbleiben",
    "bestehest": "bestehen",
    "bestehet": "bestehen",
    "bestehle": "bestehlen",
    "bestehlend": "bestehlen",
    "bestehlende": "bestehlend",
    "bestehlendem": "bestehlend",
    "bestehlenden": "bestehlend",
    "bestehlender": "bestehlend",
    "bestehlendes": "bestehlend",
    "bestehlest": "bestehlen",
    "bestehlet": "bestehlen",
    "bestehlt": "bestehlen",
    "bestehst": "bestehen",
    "besteht": "bestehen",
    "besteige": "besteigen",
    "besteigend": "besteigen",
    "besteigende": "besteigend",
    "besteigendem": "besteigend",
    "besteigenden": "besteigend",
    "besteigender": "besteigend",
    "besteigendes": "besteigend",
    "besteigest": "besteigen",
    "besteiget": "besteigen",
    "besteigst": "besteigen",
    "besteigt": "besteigen",
    "bestelle": "bestellen",
    "bestellend": "bestellen",
    "bestellende": "bestellend",
    "bestellendem": "bestellend",
    "bestellenden": "bestellend",
    "bestellender": "bestellend",
    "bestellendes": "bestellend",
    "bestellest": "bestellen",
    "bestellet": "bestellen",
    "bestellst": "bestellen",
    "bestellt": "bestellen",
    "bestellte": "bestellen",
    "bestelltem": "bestellt",
    "bestellten": "bestellen",
    "bestellter": "bestellt",
    "bestelltes": "bestellt",
    "bestelltest": "bestellen",
    "bestelltet": "bestellen",
    "bestem": "gut",
    "besten": "gut",
    "bester": "gut",
    "bestes": "gut",
    "besteuere": "besteuern",
    "besteuernd": "besteuern",
    "besteuernde": "besteuernd",
    "besteuerndem": "besteuernd",
    "besteuernden": "besteuernd",
    "besteuernder": "besteuernd",
    "besteuerndes": "besteuernd",
    "besteuerst": "besteuern",
    "besteuert": "besteuern",
    "besteuerte": "besteuern",
    "besteuertem": "besteuert",
    "besteuerten": "besteuern",
    "besteuerter": "besteuert",
    "besteuertes": "besteuert",
    "besteuertest": "besteuern",
    "besteuertet": "besteuern",
    "bestich": "bestechen",
    "bestichst": "bestechen",
    "besticht": "bestechen",
    "bestieg": "besteigen",
    "bestiege": "besteigen",
    "bestiegen": "besteigen",
    "bestiegene": "bestiegen",
    "bestiegenem": "bestiegen",
    "bestiegenen": "bestiegen",
    "bestiegener": "bestiegen",
    "bestiegenes": "bestiegen",
    "bestiegest": "besteigen",
    "bestieget": "besteigen",
    "bestiegst": "besteigen",
    "bestiegt": "besteigen",
    "bestiehl": "bestehlen",
    "bestiehlst": "bestehlen",
    "bestiehlt": "bestehlen",
    "bestimmbare": "bestimmbar",
    "bestimmbarem": "bestimmbar",
    "bestimmbaren": "bestimmbar",
    "bestimmbarer": "bestimmbar",
    "bestimmbares": "bestimmbar",
    "bestimme": "bestimmen",
    "bestimmend": "bestimmen",
    "bestimmende": "bestimmend",
    "bestimmendem": "bestimmend",
    "bestimmenden": "bestimmend",
    "bestimmender": "bestimmend",
    "bestimmendere": "bestimmend",
    "bestimmenderem": "bestimmend",
    "bestimmenderen": "bestimmend",
    "bestimmenderer": "bestimmend",
    "bestimmenderes": "bestimmend",
    "bestimmendes": "bestimmend",
    "bestimmendste": "bestimmend",
    "bestimmendstem": "bestimmend",
    "bestimmendsten": "bestimmend",
    "bestimmendster": "bestimmend",
    "bestimmendstes": "bestimmend",
    "bestimmest": "bestimmen",
    "bestimmet": "bestimmen",
    "bestimmst": "bestimmen",
    "bestimmt": "bestimmen",
    "bestimmte": "bestimmen",
    "bestimmtem": "bestimmt",
    "bestimmten": "bestimmen",
    "bestimmter": "bestimmt",
    "bestimmtere": "bestimmt",
    "bestimmterem": "bestimmt",
    "bestimmteren": "bestimmt",
    "bestimmterer": "bestimmt",
    "bestimmteres": "bestimmt",
    "bestimmtes": "bestimmt",
    "bestimmtest": "bestimmen",
    "bestimmteste": "bestimmt",
    "bestimmtestem": "bestimmt",
    "bestimmtesten": "bestimmt",
    "bestimmtester": "bestimmt",
    "bestimmtestes": "bestimmt",
    "bestimmtet": "bestimmen",
    "bestmöglichem": "bestmöglich",
    "bestmöglichen": "bestmöglich",
    "bestmöglicher": "bestmöglich",
    "bestmögliches": "bestmöglich",
    "bestochen": "bestechen",
    "bestochene": "bestochen",
    "bestochenem": "bestochen",
    "bestochenen": "bestochen",
    "bestochener": "bestochen",
    "bestochenere": "bestochen",
    "bestochenerem": "bestochen",
    "bestocheneren": "bestochen",
    "bestochenerer": "bestochen",
    "bestocheneres": "bestochen",
    "bestochenes": "bestochen",
    "bestochenste": "bestochen",
    "bestochenstem": "bestochen",
    "bestochensten": "bestochen",
    "bestochenster": "bestochen",
    "bestochenstes": "bestochen",
    "bestohlen": "bestehlen",
    "bestohlene": "bestohlen",
    "bestohlenem": "bestohlen",
    "bestohlenen": "bestohlen",
    "bestohlener": "bestohlen",
    "bestohlenes": "bestohlen",
    "bestrafe": "bestrafen",
    "bestrafend": "bestrafen",
    "bestrafende": "bestrafend",
    "bestrafendem": "bestrafend",
    "bestrafenden": "bestrafend",
    "bestrafender": "bestrafend",
    "bestrafendere": "bestrafend",
    "bestrafenderem": "bestrafend",
    "bestrafenderen": "bestrafend",
    "bestrafenderer": "bestrafend",
    "bestrafenderes": "bestrafend",
    "bestrafendes": "bestrafend",
    "bestrafendste": "bestrafend",
    "bestrafendstem": "bestrafend",
    "bestrafendsten": "bestrafend",
    "bestrafendster": "bestrafend",
    "bestrafendstes": "bestrafend",
    "bestrafest": "bestrafen",
    "bestrafet": "bestrafen",
    "bestrafst": "bestrafen",
    "bestraft": "bestrafen",
    "bestrafte": "bestrafen",
    "bestraftem": "bestraft",
    "bestraften": "bestrafen",
    "bestrafter": "bestraft",
    "bestraftere": "bestraft",
    "bestrafterem": "bestraft",
    "bestrafteren": "bestraft",
    "bestrafterer": "bestraft",
    "bestrafteres": "bestraft",
    "bestraftes": "bestraft",
    "bestraftest": "bestrafen",
    "bestrafteste": "bestraft",
    "bestraftestem": "bestraft",
    "bestraftesten": "bestraft",
    "bestraftester": "bestraft",
    "bestraftestes": "bestraft",
    "bestraftet": "bestrafen",
    "bestrahle": "bestrahlen",
    "bestrahlend": "bestrahlen",
    "bestrahlende": "bestrahlend",
    "bestrahlendem": "bestrahlend",
    "bestrahlenden": "bestrahlend",
    "bestrahlender": "bestrahlend",
    "bestrahlendes": "bestrahlend",
    "bestrahlest": "bestrahlen",
    "bestrahlet": "bestrahlen",
    "bestrahlst": "bestrahlen",
    "bestrahlt": "bestrahlen",
    "bestrahlte": "bestrahlen",
    "bestrahltem": "bestrahlt",
    "bestrahlten": "bestrahlen",
    "bestrahlter": "bestrahlt",
    "bestrahltere": "bestrahlt",
    "bestrahlterem": "bestrahlt",
    "bestrahlteren": "bestrahlt",
    "bestrahlterer": "bestrahlt",
    "bestrahlteres": "bestrahlt",
    "bestrahltes": "bestrahlt",
    "bestrahltest": "bestrahlen",
    "bestrahlteste": "bestrahlt",
    "bestrahltestem": "bestrahlt",
    "bestrahltesten": "bestrahlt",
    "bestrahltester": "bestrahlt",
    "bestrahltestes": "bestrahlt",
    "bestrahltet": "bestrahlen",
    "bestreike": "bestreiken",
    "bestreikend": "bestreiken",
    "bestreikende": "bestreikend",
    "bestreikendem": "bestreikend",
    "bestreikenden": "bestreikend",
    "bestreikender": "bestreikend",
    "bestreikendes": "bestreikend",
    "bestreikest": "bestreiken",
    "bestreiket": "bestreiken",
    "bestreikst": "bestreiken",
    "bestreikt": "bestreiken",
    "bestreikte": "bestreiken",
    "bestreiktem": "bestreikt",
    "bestreikten": "bestreiken",
    "bestreikter": "bestreikt",
    "bestreiktes": "bestreikt",
    "bestreiktest": "bestreiken",
    "bestreiktet": "bestreiken",
    "bestreite": "bestreiten",
    "bestreitend": "bestreiten",
    "bestreitende": "bestreitend",
    "bestreitendem": "bestreitend",
    "bestreitenden": "bestreitend",
    "bestreitender": "bestreitend",
    "bestreitendes": "bestreitend",
    "bestreitest": "bestreiten",
    "bestreitet": "bestreiten",
    "bestreue": "bestreuen",
    "bestreuend": "bestreuen",
    "bestreuende": "bestreuend",
    "bestreuendem": "bestreuend",
    "bestreuenden": "bestreuend",
    "bestreuender": "bestreuend",
    "bestreuendes": "bestreuend",
    "bestreuest": "bestreuen",
    "bestreuet": "bestreuen",
    "bestreust": "bestreuen",
    "bestreut": "bestreuen",
    "bestreute": "bestreuen",
    "bestreutem": "bestreut",
    "bestreuten": "bestreuen",
    "bestreuter": "bestreut",
    "bestreutes": "bestreut",
    "bestreutest": "bestreuen",
    "bestreutet": "bestreuen",
    "bestritt": "bestreiten",
    "bestritte": "bestreiten",
    "bestritten": "bestreiten",
    "bestrittene": "bestritten",
    "bestrittenem": "bestritten",
    "bestrittenen": "bestritten",
    "bestrittener": "bestritten",
    "bestrittenere": "bestritten",
    "bestrittenerem": "bestritten",
    "bestritteneren": "bestritten",
    "bestrittenerer": "bestritten",
    "bestritteneres": "bestritten",
    "bestrittenes": "bestritten",
    "bestrittenste": "bestritten",
    "bestrittenstem": "bestritten",
    "bestrittensten": "bestritten",
    "bestrittenster": "bestritten",
    "bestrittenstes": "bestritten",
    "bestrittest": "bestreiten",
    "bestrittet": "bestreiten",
    "bestuhle": "bestuhlen",
    "bestuhlend": "bestuhlen",
    "bestuhlende": "bestuhlend",
    "bestuhlendem": "bestuhlend",
    "bestuhlenden": "bestuhlend",
    "bestuhlender": "bestuhlend",
    "bestuhlendes": "bestuhlend",
    "bestuhlest": "bestuhlen",
    "bestuhlet": "bestuhlen",
    "bestuhlst": "bestuhlen",
    "bestuhlt": "bestuhlen",
    "bestuhlte": "bestuhlen",
    "bestuhltem": "bestuhlt",
    "bestuhlten": "bestuhlen",
    "bestuhlter": "bestuhlt",
    "bestuhltes": "bestuhlt",
    "bestuhltest": "bestuhlen",
    "bestuhltet": "bestuhlen",
    "bestäche": "bestechen",
    "bestächen": "bestechen",
    "bestächest": "bestechen",
    "bestächet": "bestechen",
    "bestähle": "bestehlen",
    "bestählen": "bestehlen",
    "bestählest": "bestehlen",
    "bestählet": "bestehlen",
    "bestärke": "bestärken",
    "bestärkend": "bestärken",
    "bestärkende": "bestärkend",
    "bestärkendem": "bestärkend",
    "bestärkenden": "bestärkend",
    "bestärkender": "bestärkend",
    "bestärkendere": "bestärkend",
    "bestärkenderem": "bestärkend",
    "bestärkenderen": "bestärkend",
    "bestärkenderer": "bestärkend",
    "bestärkenderes": "bestärkend",
    "bestärkendes": "bestärkend",
    "bestärkendste": "bestärkend",
    "bestärkendstem": "bestärkend",
    "bestärkendsten": "bestärkend",
    "bestärkendster": "bestärkend",
    "bestärkendstes": "bestärkend",
    "bestärkest": "bestärken",
    "bestärket": "bestärken",
    "bestärkst": "bestärken",
    "bestärkt": "bestärken",
    "bestärkte": "bestärken",
    "bestärktem": "bestärkt",
    "bestärkten": "bestärken",
    "bestärkter": "bestärkt",
    "bestärktere": "bestärkt",
    "bestärkterem": "bestärkt",
    "bestärkteren": "bestärkt",
    "bestärkterer": "bestärkt",
    "bestärkteres": "bestärkt",
    "bestärktes": "bestärkt",
    "bestärktest": "bestärken",
    "bestärkteste": "bestärkt",
    "bestärktestem": "bestärkt",
    "bestärktesten": "bestärkt",
    "bestärktester": "bestärkt",
    "bestärktestes": "bestärkt",
    "bestärktet": "bestärken",
    "bestätige": "bestätigen",
    "bestätigend": "bestätigen",
    "bestätigende": "bestätigend",
    "bestätigendem": "bestätigend",
    "bestätigenden": "bestätigend",
    "bestätigender": "bestätigend",
    "bestätigendes": "bestätigend",
    "bestätigest": "bestätigen",
    "bestätiget": "bestätigen",
    "bestätigst": "bestätigen",
    "bestätigt": "bestätigen",
    "bestätigte": "bestätigen",
    "bestätigtem": "bestätigt",
    "bestätigten": "bestätigen",
    "bestätigter": "bestätigt",
    "bestätigtes": "bestätigt",
    "bestätigtest": "bestätigen",
    "bestätigtet": "bestätigen",
    "bestäube": "bestäuben",
    "bestäubend": "bestäuben",
    "bestäubende": "bestäubend",
    "bestäubendem": "bestäubend",
    "bestäubenden": "bestäubend",
    "bestäubender": "bestäubend",
    "bestäubendes": "bestäubend",
    "bestäubest": "bestäuben",
    "bestäubet": "bestäuben",
    "bestäubst": "bestäuben",
    "bestäubt": "bestäuben",
    "bestäubte": "bestäuben",
    "bestäubtem": "bestäubt",
    "bestäubten": "bestäuben",
    "bestäubter": "bestäubt",
    "bestäubtere": "bestäubt",
    "bestäubterem": "bestäubt",
    "bestäubteren": "bestäubt",
    "bestäubterer": "bestäubt",
    "bestäubteres": "bestäubt",
    "bestäubtes": "bestäubt",
    "bestäubtest": "bestäuben",
    "bestäubteste": "bestäubt",
    "bestäubtestem": "bestäubt",
    "bestäubtesten": "bestäubt",
    "bestäubtester": "bestäubt",
    "bestäubtestes": "bestäubt",
    "bestäubtet": "bestäuben",
    "bestöhne": "bestöhnen",
    "bestöhnend": "bestöhnen",
    "bestöhnende": "bestöhnend",
    "bestöhnendem": "bestöhnend",
    "bestöhnenden": "bestöhnend",
    "bestöhnender": "bestöhnend",
    "bestöhnendere": "bestöhnend",
    "bestöhnenderem": "bestöhnend",
    "bestöhnenderen": "bestöhnend",
    "bestöhnenderer": "bestöhnend",
    "bestöhnenderes": "bestöhnend",
    "bestöhnendes": "bestöhnend",
    "bestöhnendste": "bestöhnend",
    "bestöhnendstem": "bestöhnend",
    "bestöhnendsten": "bestöhnend",
    "bestöhnendster": "bestöhnend",
    "bestöhnendstes": "bestöhnend",
    "bestöhnest": "bestöhnen",
    "bestöhnet": "bestöhnen",
    "bestöhnst": "bestöhnen",
    "bestöhnt": "bestöhnen",
    "bestöhnte": "bestöhnen",
    "bestöhntem": "bestöhnt",
    "bestöhnten": "bestöhnen",
    "bestöhnter": "bestöhnt",
    "bestöhntere": "bestöhnt",
    "bestöhnterem": "bestöhnt",
    "bestöhnteren": "bestöhnt",
    "bestöhnterer": "bestöhnt",
    "bestöhnteres": "bestöhnt",
    "bestöhntes": "bestöhnt",
    "bestöhntest": "bestöhnen",
    "bestöhnteste": "bestöhnt",
    "bestöhntestem": "bestöhnt",
    "bestöhntesten": "bestöhnt",
    "bestöhntester": "bestöhnt",
    "bestöhntestes": "bestöhnt",
    "bestöhntet": "bestöhnen",
    "bestünde": "bestehen",
    "bestünden": "bestehen",
    "bestündest": "bestehen",
    "bestündet": "bestehen",
    "bestürze": "bestürzen",
    "bestürzend": "bestürzen",
    "bestürzende": "bestürzend",
    "bestürzendem": "bestürzend",
    "bestürzenden": "bestürzend",
    "bestürzender": "bestürzend",
    "bestürzendes": "bestürzend",
    "bestürzest": "bestürzen",
    "bestürzet": "bestürzen",
    "bestürzt": "bestürzen",
    "bestürzte": "bestürzen",
    "bestürztem": "bestürzt",
    "bestürzten": "bestürzen",
    "bestürzter": "bestürzt",
    "bestürztere": "bestürzt",
    "bestürzterem": "bestürzt",
    "bestürzteren": "bestürzt",
    "bestürzterer": "bestürzt",
    "bestürzteres": "bestürzt",
    "bestürztes": "bestürzt",
    "bestürztest": "bestürzen",
    "bestürzteste": "bestürzt",
    "bestürztestem": "bestürzt",
    "bestürztesten": "bestürzt",
    "bestürztester": "bestürzt",
    "bestürztestes": "bestürzt",
    "bestürztet": "bestürzen",
    "besuchend": "besuchen",
    "besuchende": "besuchend",
    "besuchendem": "besuchend",
    "besuchenden": "besuchend",
    "besuchender": "besuchend",
    "besuchendes": "besuchend",
    "besuchest": "besuchen",
    "besuchet": "besuchen",
    "besuchst": "besuchen",
    "besucht": "besuchen",
    "besuchte": "besuchen",
    "besuchtem": "besucht",
    "besuchten": "besuchen",
    "besuchter": "besucht",
    "besuchtere": "besucht",
    "besuchterem": "besucht",
    "besuchteren": "besucht",
    "besuchterer": "besucht",
    "besuchteres": "besucht",
    "besuchtes": "besucht",
    "besuchtest": "besuchen",
    "besuchteste": "besucht",
    "besuchtestem": "besucht",
    "besuchtesten": "besucht",
    "besuchtester": "besucht",
    "besuchtestes": "besucht",
    "besuchtet": "besuchen",
    "besudele": "besudeln",
    "besudelnd": "besudeln",
    "besudelnde": "besudelnd",
    "besudelndem": "besudelnd",
    "besudelnden": "besudelnd",
    "besudelnder": "besudelnd",
    "besudelndere": "besudelnd",
    "besudelnderem": "besudelnd",
    "besudelnderen": "besudelnd",
    "besudelnderer": "besudelnd",
    "besudelnderes": "besudelnd",
    "besudelndes": "besudelnd",
    "besudelndste": "besudelnd",
    "besudelndstem": "besudelnd",
    "besudelndsten": "besudelnd",
    "besudelndster": "besudelnd",
    "besudelndstes": "besudelnd",
    "besudelst": "besudeln",
    "besudelt": "besudeln",
    "besudelte": "besudeln",
    "besudeltem": "besudelt",
    "besudelten": "besudeln",
    "besudelter": "besudelt",
    "besudeltere": "besudelt",
    "besudelterem": "besudelt",
    "besudelteren": "besudelt",
    "besudelterer": "besudelt",
    "besudelteres": "besudelt",
    "besudeltes": "besudelt",
    "besudeltest": "besudeln",
    "besudelteste": "besudelt",
    "besudeltestem": "besudelt",
    "besudeltesten": "besudelt",
    "besudeltester": "besudelt",
    "besudeltestes": "besudelt",
    "besudeltet": "besudeln",
    "besudle": "besudeln",
    "besungen": "besingen",
    "besungene": "besungen",
    "besungenem": "besungen",
    "besungenen": "besungen",
    "besungener": "besungen",
    "besungenes": "besungen",
    "beswinge": "beswingen",
    "beswingend": "beswingen",
    "beswingende": "beswingend",
    "beswingendem": "beswingend",
    "beswingenden": "beswingend",
    "beswingender": "beswingend",
    "beswingendere": "beswingend",
    "beswingenderem": "beswingend",
    "beswingenderen": "beswingend",
    "beswingenderer": "beswingend",
    "beswingenderes": "beswingend",
    "beswingendes": "beswingend",
    "beswingendste": "beswingend",
    "beswingendstem": "beswingend",
    "beswingendsten": "beswingend",
    "beswingendster": "beswingend",
    "beswingendstes": "beswingend",
    "beswingest": "beswingen",
    "beswinget": "beswingen",
    "beswingst": "beswingen",
    "beswingt": "beswingen",
    "beswingte": "beswingen",
    "beswingtem": "beswingt",
    "beswingten": "beswingen",
    "beswingter": "beswingt",
    "beswingtere": "beswingt",
    "beswingterem": "beswingt",
    "beswingteren": "beswingt",
    "beswingterer": "beswingt",
    "beswingteres": "beswingt",
    "beswingtes": "beswingt",
    "beswingtest": "beswingen",
    "beswingteste": "beswingt",
    "beswingtestem": "beswingt",
    "beswingtesten": "beswingt",
    "beswingtester": "beswingt",
    "beswingtestes": "beswingt",
    "beswingtet": "beswingen",
    "besänftige": "besänftigen",
    "besänftigend": "besänftigen",
    "besänftigende": "besänftigend",
    "besänftigendem": "besänftigend",
    "besänftigenden": "besänftigend",
    "besänftigender": "besänftigend",
    "besänftigendere": "besänftigend",
    "besänftigenderem": "besänftigend",
    "besänftigenderen": "besänftigend",
    "besänftigenderer": "besänftigend",
    "besänftigenderes": "besänftigend",
    "besänftigendes": "besänftigend",
    "besänftigendste": "besänftigend",
    "besänftigendstem": "besänftigend",
    "besänftigendsten": "besänftigend",
    "besänftigendster": "besänftigend",
    "besänftigendstes": "besänftigend",
    "besänftigest": "besänftigen",
    "besänftiget": "besänftigen",
    "besänftigst": "besänftigen",
    "besänftigt": "besänftigen",
    "besänftigte": "besänftigen",
    "besänftigtem": "besänftigt",
    "besänftigten": "besänftigen",
    "besänftigter": "besänftigt",
    "besänftigtere": "besänftigt",
    "besänftigterem": "besänftigt",
    "besänftigteren": "besänftigt",
    "besänftigterer": "besänftigt",
    "besänftigteres": "besänftigt",
    "besänftigtes": "besänftigt",
    "besänftigtest": "besänftigen",
    "besänftigteste": "besänftigt",
    "besänftigtestem": "besänftigt",
    "besänftigtesten": "besänftigt",
    "besänftigtester": "besänftigt",
    "besänftigtestes": "besänftigt",
    "besänftigtet": "besänftigen",
    "besänge": "besingen",
    "besängen": "besingen",
    "besängest": "besingen",
    "besänget": "besingen",
    "besänne": "besinnen",
    "besännen": "besinnen",
    "besännest": "besinnen",
    "besännet": "besinnen",
    "besäufst": "besaufen",
    "besäuft": "besaufen",
    "besäße": "besitzen",
    "besäßen": "besitzen",
    "besäßest": "besitzen",
    "besäßet": "besitzen",
    "besöffe": "besaufen",
    "besöffen": "besaufen",
    "besöffest": "besaufen",
    "besöffet": "besaufen",
    "betagte": "betagt",
    "betagtem": "betagt",
    "betagten": "betagt",
    "betagter": "betagt",
    "betagtere": "betagt",
    "betagterem": "betagt",
    "betagteren": "betagt",
    "betagterer": "betagt",
    "betagteres": "betagt",
    "betagtes": "betagt",
    "betagteste": "betagt",
    "betagtestem": "betagt",
    "betagtesten": "betagt",
    "betagtester": "betagt",
    "betagtestes": "betagt",
    "betanke": "betanken",
    "betankend": "betanken",
    "betankende": "betankend",
    "betankendem": "betankend",
    "betankenden": "betankend",
    "betankender": "betankend",
    "betankendes": "betankend",
    "betankest": "betanken",
    "betanket": "betanken",
    "betankst": "betanken",
    "betankt": "betanken",
    "betankte": "betanken",
    "betanktem": "betankt",
    "betankten": "betanken",
    "betankter": "betankt",
    "betanktes": "betankt",
    "betanktest": "betanken",
    "betanktet": "betanken",
    "betatsche": "betatschen",
    "betatschend": "betatschen",
    "betatschende": "betatschend",
    "betatschendem": "betatschend",
    "betatschenden": "betatschend",
    "betatschender": "betatschend",
    "betatschendes": "betatschend",
    "betatschest": "betatschen",
    "betatschet": "betatschen",
    "betatschst": "betatschen",
    "betatscht": "betatschen",
    "betatschte": "betatschen",
    "betatschtem": "betatscht",
    "betatschten": "betatschen",
    "betatschter": "betatscht",
    "betatschtes": "betatscht",
    "betatschtest": "betatschen",
    "betatschtet": "betatschen",
    "bete": "beten",
    "beteilige": "beteiligen",
    "beteiligend": "beteiligen",
    "beteiligende": "beteiligend",
    "beteiligendem": "beteiligend",
    "beteiligenden": "beteiligend",
    "beteiligender": "beteiligend",
    "beteiligendes": "beteiligend",
    "beteiligest": "beteiligen",
    "beteiliget": "beteiligen",
    "beteiligst": "beteiligen",
    "beteiligt": "beteiligen",
    "beteiligte": "beteiligen",
    "beteiligtem": "beteiligt",
    "beteiligten": "beteiligen",
    "beteiligter": "beteiligt",
    "beteiligtes": "beteiligt",
    "beteiligtest": "beteiligen",
    "beteiligtet": "beteiligen",
    "betend": "beten",
    "betende": "betend",
    "betendem": "betend",
    "betenden": "betend",
    "betender": "betend",
    "betendes": "betend",
    "betest": "beten",
    "betet": "beten",
    "betete": "beten",
    "beteten": "beten",
    "betetest": "beten",
    "betetet": "beten",
    "beteuere": "beteuern",
    "beteuernd": "beteuern",
    "beteuernde": "beteuernd",
    "beteuerndem": "beteuernd",
    "beteuernden": "beteuernd",
    "beteuernder": "beteuernd",
    "beteuerndes": "beteuernd",
    "beteuerst": "beteuern",
    "beteuert": "beteuern",
    "beteuerte": "beteuern",
    "beteuertem": "beteuert",
    "beteuerten": "beteuern",
    "beteuerter": "beteuert",
    "beteuertes": "beteuert",
    "beteuertest": "beteuern",
    "beteuertet": "beteuern",
    "betitele": "betiteln",
    "betitelnd": "betiteln",
    "betitelnde": "betitelnd",
    "betitelndem": "betitelnd",
    "betitelnden": "betitelnd",
    "betitelnder": "betitelnd",
    "betitelndes": "betitelnd",
    "betitelst": "betiteln",
    "betitelt": "betiteln",
    "betitelte": "betiteln",
    "betiteltem": "betitelt",
    "betitelten": "betiteln",
    "betitelter": "betitelt",
    "betiteltes": "betitelt",
    "betiteltest": "betiteln",
    "betiteltet": "betiteln",
    "betitle": "betiteln",
    "betone": "betonen",
    "betonend": "betonen",
    "betonende": "betonend",
    "betonendem": "betonend",
    "betonenden": "betonend",
    "betonender": "betonend",
    "betonendes": "betonend",
    "betonest": "betonen",
    "betonet": "betonen",
    "betoniere": "betonieren",
    "betonierend": "betonieren",
    "betonierende": "betonierend",
    "betonierendem": "betonierend",
    "betonierenden": "betonierend",
    "betonierender": "betonierend",
    "betonierendes": "betonierend",
    "betonierest": "betonieren",
    "betonieret": "betonieren",
    "betonierst": "betonieren",
    "betoniert": "betonieren",
    "betonierte": "betonieren",
    "betoniertem": "betoniert",
    "betonierten": "betonieren",
    "betonierter": "betoniert",
    "betoniertere": "betoniert",
    "betonierterem": "betoniert",
    "betonierteren": "betoniert",
    "betonierterer": "betoniert",
    "betonierteres": "betoniert",
    "betoniertes": "betoniert",
    "betoniertest": "betonieren",
    "betonierteste": "betoniert",
    "betoniertestem": "betoniert",
    "betoniertesten": "betoniert",
    "betoniertester": "betoniert",
    "betoniertestes": "betoniert",
    "betoniertet": "betonieren",
    "betonst": "betonen",
    "betont": "betonen",
    "betonte": "betonen",
    "betontem": "betont",
    "betonten": "betonen",
    "betonter": "betont",
    "betontere": "betont",
    "betonterem": "betont",
    "betonteren": "betont",
    "betonterer": "betont",
    "betonteres": "betont",
    "betontes": "betont",
    "betontest": "betonen",
    "betonteste": "betont",
    "betontestem": "betont",
    "betontesten": "betont",
    "betontester": "betont",
    "betontestes": "betont",
    "betontet": "betonen",
    "betrachtend": "betrachten",
    "betrachtende": "betrachtend",
    "betrachtendem": "betrachtend",
    "betrachtenden": "betrachtend",
    "betrachtender": "betrachtend",
    "betrachtendes": "betrachtend",
    "betrachtest": "betrachten",
    "betrachtet": "betrachten",
    "betrachtete": "betrachten",
    "betrachtetem": "betrachtet",
    "betrachteten": "betrachten",
    "betrachteter": "betrachtet",
    "betrachtetere": "betrachtet",
    "betrachteterem": "betrachtet",
    "betrachteteren": "betrachtet",
    "betrachteterer": "betrachtet",
    "betrachteteres": "betrachtet",
    "betrachtetes": "betrachtet",
    "betrachtetest": "betrachten",
    "betrachteteste": "betrachtet",
    "betrachtetestem": "betrachtet",
    "betrachtetesten": "betrachtet",
    "betrachtetester": "betrachtet",
    "betrachtetestes": "betrachtet",
    "betrachtetet": "betrachten",
    "betraf": "betreffen",
    "betrafen": "betreffen",
    "betrafst": "betreffen",
    "betraft": "betreffen",
    "betragend": "betragen",
    "betragende": "betragend",
    "betragendem": "betragend",
    "betragenden": "betragend",
    "betragender": "betragend",
    "betragendes": "betragend",
    "betragene": "betragen",
    "betragenem": "betragen",
    "betragenen": "betragen",
    "betragener": "betragen",
    "betragenes": "betragen",
    "betragest": "betragen",
    "betraget": "betragen",
    "betragt": "betragen",
    "betrank": "betrinken",
    "betranken": "betrinken",
    "betrankst": "betrinken",
    "betrankt": "betrinken",
    "betrat": "betreten",
    "betraten": "betreten",
    "betratest": "betreten",
    "betratet": "betreten",
    "betraue": "betrauen",
    "betrauend": "betrauen",
    "betrauende": "betrauend",
    "betrauendem": "betrauend",
    "betrauenden": "betrauend",
    "betrauender": "betrauend",
    "betrauendes": "betrauend",
    "betrauest": "betrauen",
    "betrauet": "betrauen",
    "betraust": "betrauen",
    "betraut": "betrauen",
    "betraute": "betrauen",
    "betrautem": "betraut",
    "betrauten": "betrauen",
    "betrauter": "betraut",
    "betrautes": "betraut",
    "betrautest": "betrauen",
    "betrautet": "betrauen",
    "betreffe": "betreffen",
    "betreffend": "betreffen",
    "betreffende": "betreffend",
    "betreffendem": "betreffend",
    "betreffenden": "betreffend",
    "betreffender": "betreffend",
    "betreffendes": "betreffend",
    "betreffest": "betreffen",
    "betreffet": "betreffen",
    "betrefft": "betreffen",
    "betreibe": "betreiben",
    "betreibend": "betreiben",
    "betreibende": "betreibend",
    "betreibendem": "betreibend",
    "betreibenden": "betreibend",
    "betreibender": "betreibend",
    "betreibendes": "betreibend",
    "betreibest": "betreiben",
    "betreibet": "betreiben",
    "betreibst": "betreiben",
    "betreibt": "betreiben",
    "betrete": "betreten",
    "betretend": "betreten",
    "betretende": "betretend",
    "betretendem": "betretend",
    "betretenden": "betretend",
    "betretender": "betretend",
    "betretendes": "betretend",
    "betretene": "betreten",
    "betretenem": "betreten",
    "betretenen": "betreten",
    "betretener": "betreten",
    "betretenere": "betreten",
    "betretenerem": "betreten",
    "betreteneren": "betreten",
    "betretenerer": "betreten",
    "betreteneres": "betreten",
    "betretenes": "betreten",
    "betretenstem": "betreten",
    "betretensten": "betreten",
    "betretenster": "betreten",
    "betretenstes": "betreten",
    "betretest": "betreten",
    "betretet": "betreten",
    "betreue": "betreuen",
    "betreuend": "betreuen",
    "betreuende": "betreuend",
    "betreuendem": "betreuend",
    "betreuenden": "betreuend",
    "betreuender": "betreuend",
    "betreuendes": "betreuend",
    "betreuest": "betreuen",
    "betreuet": "betreuen",
    "betreust": "betreuen",
    "betreut": "betreuen",
    "betreute": "betreuen",
    "betreutem": "betreut",
    "betreuten": "betreuen",
    "betreuter": "betreut",
    "betreutes": "betreut",
    "betreutest": "betreuen",
    "betreutet": "betreuen",
    "betriebe": "betreiben",
    "betriebenem": "betrieben",
    "betriebenen": "betrieben",
    "betriebener": "betrieben",
    "betriebenes": "betrieben",
    "betriebest": "betreiben",
    "betriebet": "betreiben",
    "betriebliche": "betrieblich",
    "betrieblichem": "betrieblich",
    "betrieblichen": "betrieblich",
    "betrieblicher": "betrieblich",
    "betriebliches": "betrieblich",
    "betriebsamem": "betriebsam",
    "betriebsamen": "betriebsam",
    "betriebsamer": "betriebsam",
    "betriebsamere": "betriebsam",
    "betriebsamerem": "betriebsam",
    "betriebsameren": "betriebsam",
    "betriebsamerer": "betriebsam",
    "betriebsameres": "betriebsam",
    "betriebsames": "betriebsam",
    "betriebsamste": "betriebsam",
    "betriebsamstem": "betriebsam",
    "betriebsamsten": "betriebsam",
    "betriebsamster": "betriebsam",
    "betriebsamstes": "betriebsam",
    "betriebsbereite": "betriebsbereit",
    "betriebsbereitem": "betriebsbereit",
    "betriebsbereiten": "betriebsbereit",
    "betriebsbereiter": "betriebsbereit",
    "betriebsbereites": "betriebsbereit",
    "betriebseigene": "betriebseigen",
    "betriebseigenem": "betriebseigen",
    "betriebseigenen": "betriebseigen",
    "betriebseigener": "betriebseigen",
    "betriebseigenes": "betriebseigen",
    "betriebst": "betreiben",
    "betriebt": "betreiben",
    "betriff": "betreffen",
    "betriffst": "betreffen",
    "betrifft": "betreffen",
    "betrinke": "betrinken",
    "betrinkend": "betrinken",
    "betrinkende": "betrinkend",
    "betrinkendem": "betrinkend",
    "betrinkenden": "betrinkend",
    "betrinkender": "betrinkend",
    "betrinkendere": "betrinkend",
    "betrinkenderem": "betrinkend",
    "betrinkenderen": "betrinkend",
    "betrinkenderer": "betrinkend",
    "betrinkenderes": "betrinkend",
    "betrinkendes": "betrinkend",
    "betrinkendste": "betrinkend",
    "betrinkendstem": "betrinkend",
    "betrinkendsten": "betrinkend",
    "betrinkendster": "betrinkend",
    "betrinkendstes": "betrinkend",
    "betrinkest": "betrinken",
    "betrinket": "betrinken",
    "betrinkst": "betrinken",
    "betrinkt": "betrinken",
    "betritt": "betreten",
    "betrittst": "betreten",
    "betroffen": "betreffen",
    "betroffene": "betroffen",
    "betroffenem": "betroffen",
    "betroffenen": "betroffen",
    "betroffener": "betroffen",
    "betroffenere": "betroffen",
    "betroffenerem": "betroffen",
    "betroffeneren": "betroffen",
    "betroffenerer": "betroffen",
    "betroffeneres": "betroffen",
    "betroffenes": "betroffen",
    "betroffenstem": "betroffen",
    "betroffensten": "betroffen",
    "betroffenster": "betroffen",
    "betroffenstes": "betroffen",
    "betrog": "betrügen",
    "betrogen": "betrügen",
    "betrogene": "betrogen",
    "betrogenem": "betrogen",
    "betrogenen": "betrogen",
    "betrogener": "betrogen",
    "betrogenere": "betrogen",
    "betrogenerem": "betrogen",
    "betrogeneren": "betrogen",
    "betrogenerer": "betrogen",
    "betrogeneres": "betrogen",
    "betrogenes": "betrogen",
    "betrogenste": "betrogen",
    "betrogenstem": "betrogen",
    "betrogensten": "betrogen",
    "betrogenster": "betrogen",
    "betrogenstes": "betrogen",
    "betrogst": "betrügen",
    "betrogt": "betrügen",
    "betrug": "betragen",
    "betrugen": "betragen",
    "betrugst": "betragen",
    "betrugt": "betragen",
    "betrunken": "betrinken",
    "betrunkene": "betrunken",
    "betrunkenem": "betrunken",
    "betrunkenen": "betrunken",
    "betrunkener": "betrunken",
    "betrunkenere": "betrunken",
    "betrunkenerem": "betrunken",
    "betrunkeneren": "betrunken",
    "betrunkenerer": "betrunken",
    "betrunkeneres": "betrunken",
    "betrunkenes": "betrunken",
    "betrunkenste": "betrunken",
    "betrunkenstem": "betrunken",
    "betrunkensten": "betrunken",
    "betrunkenster": "betrunken",
    "betrunkenstes": "betrunken",
    "beträchtliche": "beträchtlich",
    "beträchtlichem": "beträchtlich",
    "beträchtlichen": "beträchtlich",
    "beträchtlicher": "beträchtlich",
    "beträchtliches": "beträchtlich",
    "beträfe": "betreffen",
    "beträfen": "betreffen",
    "beträfest": "betreffen",
    "beträfet": "betreffen",
    "beträgst": "betragen",
    "beträgt": "betragen",
    "betränke": "betrinken",
    "betränken": "betrinken",
    "betränkest": "betrinken",
    "betränket": "betrinken",
    "beträte": "betreten",
    "beträten": "betreten",
    "beträtest": "betreten",
    "beträtet": "betreten",
    "beträufele": "beträufeln",
    "beträufelnd": "beträufeln",
    "beträufelnde": "beträufelnd",
    "beträufelndem": "beträufelnd",
    "beträufelnden": "beträufelnd",
    "beträufelnder": "beträufelnd",
    "beträufelndere": "beträufelnd",
    "beträufelnderem": "beträufelnd",
    "beträufelnderen": "beträufelnd",
    "beträufelnderer": "beträufelnd",
    "beträufelnderes": "beträufelnd",
    "beträufelndes": "beträufelnd",
    "beträufelndste": "beträufelnd",
    "beträufelndstem": "beträufelnd",
    "beträufelndsten": "beträufelnd",
    "beträufelndster": "beträufelnd",
    "beträufelndstes": "beträufelnd",
    "beträufelst": "beträufeln",
    "beträufelt": "beträufeln",
    "beträufelte": "beträufeln",
    "beträufeltem": "beträufelt",
    "beträufelten": "beträufeln",
    "beträufelter": "beträufelt",
    "beträufeltere": "beträufelt",
    "beträufelterem": "beträufelt",
    "beträufelteren": "beträufelt",
    "beträufelterer": "beträufelt",
    "beträufelteres": "beträufelt",
    "beträufeltes": "beträufelt",
    "beträufeltest": "beträufeln",
    "beträufelteste": "beträufelt",
    "beträufeltestem": "beträufelt",
    "beträufeltesten": "beträufelt",
    "beträufeltester": "beträufelt",
    "beträufeltestes": "beträufelt",
    "beträufeltet": "beträufeln",
    "beträufle": "beträufeln",
    "betröge": "betrügen",
    "betrögen": "betrügen",
    "betrögest": "betrügen",
    "betröget": "betrügen",
    "betrübe": "betrüben",
    "betrübend": "betrüben",
    "betrübende": "betrübend",
    "betrübendem": "betrübend",
    "betrübenden": "betrübend",
    "betrübender": "betrübend",
    "betrübendere": "betrübend",
    "betrübenderem": "betrübend",
    "betrübenderen": "betrübend",
    "betrübenderer": "betrübend",
    "betrübenderes": "betrübend",
    "betrübendes": "betrübend",
    "betrübendste": "betrübend",
    "betrübendstem": "betrübend",
    "betrübendsten": "betrübend",
    "betrübendster": "betrübend",
    "betrübendstes": "betrübend",
    "betrübest": "betrüben",
    "betrübet": "betrüben",
    "betrübliche": "betrüblich",
    "betrüblichem": "betrüblich",
    "betrüblichen": "betrüblich",
    "betrüblicher": "betrüblich",
    "betrüblichere": "betrüblich",
    "betrüblicherem": "betrüblich",
    "betrüblicheren": "betrüblich",
    "betrüblicherer": "betrüblich",
    "betrüblicheres": "betrüblich",
    "betrübliches": "betrüblich",
    "betrüblichste": "betrüblich",
    "betrüblichstem": "betrüblich",
    "betrüblichsten": "betrüblich",
    "betrüblichster": "betrüblich",
    "betrüblichstes": "betrüblich",
    "betrübst": "betrüben",
    "betrübt": "betrüben",
    "betrübte": "betrüben",
    "betrübtem": "betrübt",
    "betrübten": "betrüben",
    "betrübter": "betrübt",
    "betrübtere": "betrübt",
    "betrübterem": "betrübt",
    "betrübteren": "betrübt",
    "betrübterer": "betrübt",
    "betrübteres": "betrübt",
    "betrübtes": "betrübt",
    "betrübtest": "betrüben",
    "betrübteste": "betrübt",
    "betrübtestem": "betrübt",
    "betrübtesten": "betrübt",
    "betrübtester": "betrübt",
    "betrübtestes": "betrübt",
    "betrübtet": "betrüben",
    "betrügen": "betragen",
    "betrügend": "betrügen",
    "betrügende": "betrügend",
    "betrügendem": "betrügend",
    "betrügenden": "betrügend",
    "betrügender": "betrügend",
    "betrügendere": "betrügend",
    "betrügenderem": "betrügend",
    "betrügenderen": "betrügend",
    "betrügenderer": "betrügend",
    "betrügenderes": "betrügend",
    "betrügendes": "betrügend",
    "betrügendste": "betrügend",
    "betrügendstem": "betrügend",
    "betrügendsten": "betrügend",
    "betrügendster": "betrügend",
    "betrügendstes": "betrügend",
    "betrügerischem": "betrügerisch",
    "betrügerischen": "betrügerisch",
    "betrügerischer": "betrügerisch",
    "betrügerisches": "betrügerisch",
    "betrügest": "betrügen",
    "betrüget": "betrügen",
    "betrügst": "betrügen",
    "betrügt": "betrügen",
    "bettelarme": "bettelarm",
    "bettelarmem": "bettelarm",
    "bettelarmen": "bettelarm",
    "bettelarmer": "bettelarm",
    "bettelarmes": "bettelarm",
    "bettele": "betteln",
    "bettelnd": "betteln",
    "bettelnde": "bettelnd",
    "bettelndem": "bettelnd",
    "bettelnden": "bettelnd",
    "bettelnder": "bettelnd",
    "bettelndere": "bettelnd",
    "bettelnderem": "bettelnd",
    "bettelnderen": "bettelnd",
    "bettelnderer": "bettelnd",
    "bettelnderes": "bettelnd",
    "bettelndes": "bettelnd",
    "bettelndste": "bettelnd",
    "bettelndstem": "bettelnd",
    "bettelndsten": "bettelnd",
    "bettelndster": "bettelnd",
    "bettelndstes": "bettelnd",
    "bettelst": "betteln",
    "bettelt": "betteln",
    "bettelte": "betteln",
    "bettelten": "betteln",
    "betteltest": "betteln",
    "betteltet": "betteln",
    "bettend": "betten",
    "bettende": "bettend",
    "bettendem": "bettend",
    "bettenden": "bettend",
    "bettender": "bettend",
    "bettendes": "bettend",
    "bettest": "betten",
    "bettet": "betten",
    "bettete": "betten",
    "betteten": "betten",
    "bettetest": "betten",
    "bettetet": "betten",
    "bettle": "betteln",
    "bettlägerigem": "bettlägerig",
    "bettlägerigen": "bettlägerig",
    "bettlägeriger": "bettlägerig",
    "bettlägeriges": "bettlägerig",
    "betuchtem": "betucht",
    "betuchten": "betucht",
    "betuchter": "betucht",
    "betuchtere": "betucht",
    "betuchterem": "betucht",
    "betuchteren": "betucht",
    "betuchterer": "betucht",
    "betuchteres": "betucht",
    "betuchtes": "betucht",
    "betuchteste": "betucht",
    "betuchtestem": "betucht",
    "betuchtesten": "betucht",
    "betuchtester": "betucht",
    "betuchtestes": "betucht",
    "betupfe": "betupfen",
    "betupfend": "betupfen",
    "betupfende": "betupfend",
    "betupfendem": "betupfend",
    "betupfenden": "betupfend",
    "betupfender": "betupfend",
    "betupfendes": "betupfend",
    "betupfest": "betupfen",
    "betupfet": "betupfen",
    "betupfst": "betupfen",
    "betupft": "betupfen",
    "betupfte": "betupfen",
    "betupftem": "betupft",
    "betupften": "betupfen",
    "betupfter": "betupft",
    "betupftes": "betupft",
    "betupftest": "betupfen",
    "betupftet": "betupfen",
    "betätige": "betätigen",
    "betätigend": "betätigen",
    "betätigende": "betätigend",
    "betätigendem": "betätigend",
    "betätigenden": "betätigend",
    "betätigender": "betätigend",
    "betätigendes": "betätigend",
    "betätigest": "betätigen",
    "betätiget": "betätigen",
    "betätigst": "betätigen",
    "betätigt": "betätigen",
    "betätigte": "betätigen",
    "betätigtem": "betätigt",
    "betätigten": "betätigen",
    "betätigter": "betätigt",
    "betätigtes": "betätigt",
    "betätigtest": "betätigen",
    "betätigtet": "betätigen",
    "betäube": "betäuben",
    "betäubend": "betäuben",
    "betäubende": "betäubend",
    "betäubendem": "betäubend",
    "betäubenden": "betäubend",
    "betäubender": "betäubend",
    "betäubendes": "betäubend",
    "betäubest": "betäuben",
    "betäubet": "betäuben",
    "betäubst": "betäuben",
    "betäubt": "betäuben",
    "betäubte": "betäuben",
    "betäubtem": "betäubt",
    "betäubten": "betäuben",
    "betäubter": "betäubt",
    "betäubtere": "betäubt",
    "betäubterem": "betäubt",
    "betäubteren": "betäubt",
    "betäubterer": "betäubt",
    "betäubteres": "betäubt",
    "betäubtes": "betäubt",
    "betäubtest": "betäuben",
    "betäubteste": "betäubt",
    "betäubtestem": "betäubt",
    "betäubtesten": "betäubt",
    "betäubtester": "betäubt",
    "betäubtestes": "betäubt",
    "betäubtet": "betäuben",
    "betöre": "betören",
    "betörend": "betören",
    "betörende": "betörend",
    "betörendem": "betörend",
    "betörenden": "betörend",
    "betörender": "betörend",
    "betörendere": "betörend",
    "betörenderem": "betörend",
    "betörenderen": "betörend",
    "betörenderer": "betörend",
    "betörenderes": "betörend",
    "betörendes": "betörend",
    "betörendste": "betörend",
    "betörendstem": "betörend",
    "betörendsten": "betörend",
    "betörendster": "betörend",
    "betörendstes": "betörend",
    "betörest": "betören",
    "betöret": "betören",
    "betörst": "betören",
    "betört": "betören",
    "betörte": "betören",
    "betörtem": "betört",
    "betörten": "betören",
    "betörter": "betört",
    "betörtere": "betört",
    "betörterem": "betört",
    "betörteren": "betört",
    "betörterer": "betört",
    "betörteres": "betört",
    "betörtes": "betört",
    "betörtest": "betören",
    "betörteste": "betört",
    "betörtestem": "betört",
    "betörtesten": "betört",
    "betörtester": "betört",
    "betörtestes": "betört",
    "betörtet": "betören",
    "beuge": "beugen",
    "beugend": "beugen",
    "beugende": "beugend",
    "beugendem": "beugend",
    "beugenden": "beugend",
    "beugender": "beugend",
    "beugendere": "beugend",
    "beugenderem": "beugend",
    "beugenderen": "beugend",
    "beugenderer": "beugend",
    "beugenderes": "beugend",
    "beugendes": "beugend",
    "beugendste": "beugend",
    "beugendstem": "beugend",
    "beugendsten": "beugend",
    "beugendster": "beugend",
    "beugendstes": "beugend",
    "beugest": "beugen",
    "beuget": "beugen",
    "beugst": "beugen",
    "beugt": "beugen",
    "beugte": "beugen",
    "beugten": "beugen",
    "beugtest": "beugen",
    "beugtet": "beugen",
    "beule": "beulen",
    "beulend": "beulen",
    "beulende": "beulend",
    "beulendem": "beulend",
    "beulenden": "beulend",
    "beulender": "beulend",
    "beulendes": "beulend",
    "beulest": "beulen",
    "beulet": "beulen",
    "beulst": "beulen",
    "beult": "beulen",
    "beulte": "beulen",
    "beulten": "beulen",
    "beultest": "beulen",
    "beultet": "beulen",
    "beunruhige": "beunruhigen",
    "beunruhigend": "beunruhigen",
    "beunruhigende": "beunruhigend",
    "beunruhigendem": "beunruhigend",
    "beunruhigenden": "beunruhigend",
    "beunruhigender": "beunruhigend",
    "beunruhigendere": "beunruhigend",
    "beunruhigenderem": "beunruhigend",
    "beunruhigenderen": "beunruhigend",
    "beunruhigenderer": "beunruhigend",
    "beunruhigenderes": "beunruhigend",
    "beunruhigendes": "beunruhigend",
    "beunruhigendste": "beunruhigend",
    "beunruhigendstem": "beunruhigend",
    "beunruhigendsten": "beunruhigend",
    "beunruhigendster": "beunruhigend",
    "beunruhigendstes": "beunruhigend",
    "beunruhigest": "beunruhigen",
    "beunruhiget": "beunruhigen",
    "beunruhigst": "beunruhigen",
    "beunruhigt": "beunruhigen",
    "beunruhigte": "beunruhigen",
    "beunruhigtem": "beunruhigt",
    "beunruhigten": "beunruhigen",
    "beunruhigter": "beunruhigt",
    "beunruhigtes": "beunruhigt",
    "beunruhigtest": "beunruhigen",
    "beunruhigtet": "beunruhigen",
    "beurkunde": "beurkunden",
    "beurkundend": "beurkunden",
    "beurkundende": "beurkundend",
    "beurkundendem": "beurkundend",
    "beurkundenden": "beurkundend",
    "beurkundender": "beurkundend",
    "beurkundendes": "beurkundend",
    "beurkundest": "beurkunden",
    "beurkundet": "beurkunden",
    "beurkundete": "beurkunden",
    "beurkundetem": "beurkundet",
    "beurkundeten": "beurkunden",
    "beurkundeter": "beurkundet",
    "beurkundetes": "beurkundet",
    "beurkundetest": "beurkunden",
    "beurkundetet": "beurkunden",
    "beurlaube": "beurlauben",
    "beurlaubend": "beurlauben",
    "beurlaubende": "beurlaubend",
    "beurlaubendem": "beurlaubend",
    "beurlaubenden": "beurlaubend",
    "beurlaubender": "beurlaubend",
    "beurlaubendes": "beurlaubend",
    "beurlaubest": "beurlauben",
    "beurlaubet": "beurlauben",
    "beurlaubst": "beurlauben",
    "beurlaubt": "beurlauben",
    "beurlaubte": "beurlauben",
    "beurlaubtem": "beurlaubt",
    "beurlaubten": "beurlauben",
    "beurlaubter": "beurlaubt",
    "beurlaubtes": "beurlaubt",
    "beurlaubtest": "beurlauben",
    "beurlaubtet": "beurlauben",
    "beurteile": "beurteilen",
    "beurteilend": "beurteilen",
    "beurteilende": "beurteilend",
    "beurteilendem": "beurteilend",
    "beurteilenden": "beurteilend",
    "beurteilender": "beurteilend",
    "beurteilendes": "beurteilend",
    "beurteilest": "beurteilen",
    "beurteilet": "beurteilen",
    "beurteilst": "beurteilen",
    "beurteilt": "beurteilen",
    "beurteilte": "beurteilen",
    "beurteiltem": "beurteilt",
    "beurteilten": "beurteilen",
    "beurteilter": "beurteilt",
    "beurteiltes": "beurteilt",
    "beurteiltest": "beurteilen",
    "beurteiltet": "beurteilen",
    "beutele": "beuteln",
    "beutelnd": "beuteln",
    "beutelnde": "beutelnd",
    "beutelndem": "beutelnd",
    "beutelnden": "beutelnd",
    "beutelnder": "beutelnd",
    "beutelndes": "beutelnd",
    "beutelst": "beuteln",
    "beutelt": "beuteln",
    "beutelte": "beuteln",
    "beutelten": "beuteln",
    "beuteltest": "beuteln",
    "beuteltet": "beuteln",
    "beutend": "beuten",
    "beutende": "beutend",
    "beutendem": "beutend",
    "beutenden": "beutend",
    "beutender": "beutend",
    "beutendere": "beutend",
    "beutenderem": "beutend",
    "beutenderen": "beutend",
    "beutenderer": "beutend",
    "beutenderes": "beutend",
    "beutendes": "beutend",
    "beutendste": "beutend",
    "beutendstem": "beutend",
    "beutendsten": "beutend",
    "beutendster": "beutend",
    "beutendstes": "beutend",
    "beutest": "beuten",
    "beutet": "beuten",
    "beutete": "beuten",
    "beuteten": "beuten",
    "beutetest": "beuten",
    "beutetet": "beuten",
    "beutle": "beuteln",
    "bevollmächtige": "bevollmächtigen",
    "bevollmächtigend": "bevollmächtigen",
    "bevollmächtigende": "bevollmächtigend",
    "bevollmächtigendem": "bevollmächtigend",
    "bevollmächtigenden": "bevollmächtigend",
    "bevollmächtigender": "bevollmächtigend",
    "bevollmächtigendes": "bevollmächtigend",
    "bevollmächtigest": "bevollmächtigen",
    "bevollmächtiget": "bevollmächtigen",
    "bevollmächtigst": "bevollmächtigen",
    "bevollmächtigt": "bevollmächtigen",
    "bevollmächtigte": "bevollmächtigen",
    "bevollmächtigtem": "bevollmächtigt",
    "bevollmächtigten": "bevollmächtigen",
    "bevollmächtigter": "bevollmächtigt",
    "bevollmächtigtes": "bevollmächtigt",
    "bevollmächtigtest": "bevollmächtigen",
    "bevollmächtigtet": "bevollmächtigen",
    "bevorgestanden": "bevorstehen",
    "bevorgestandene": "bevorgestanden",
    "bevorgestandenem": "bevorgestanden",
    "bevorgestandenen": "bevorgestanden",
    "bevorgestandener": "bevorgestanden",
    "bevorgestandenes": "bevorgestanden",
    "bevormunde": "bevormunden",
    "bevormundend": "bevormunden",
    "bevormundende": "bevormundend",
    "bevormundendem": "bevormundend",
    "bevormundenden": "bevormundend",
    "bevormundender": "bevormundend",
    "bevormundendere": "bevormundend",
    "bevormundenderem": "bevormundend",
    "bevormundenderen": "bevormundend",
    "bevormundenderer": "bevormundend",
    "bevormundenderes": "bevormundend",
    "bevormundendes": "bevormundend",
    "bevormundendste": "bevormundend",
    "bevormundendstem": "bevormundend",
    "bevormundendsten": "bevormundend",
    "bevormundendster": "bevormundend",
    "bevormundendstes": "bevormundend",
    "bevormundest": "bevormunden",
    "bevormundet": "bevormunden",
    "bevormundete": "bevormunden",
    "bevormundetem": "bevormundet",
    "bevormundeten": "bevormunden",
    "bevormundeter": "bevormundet",
    "bevormundetere": "bevormundet",
    "bevormundeterem": "bevormundet",
    "bevormundeteren": "bevormundet",
    "bevormundeterer": "bevormundet",
    "bevormundeteres": "bevormundet",
    "bevormundetes": "bevormundet",
    "bevormundetest": "bevormunden",
    "bevormundeteste": "bevormundet",
    "bevormundetestem": "bevormundet",
    "bevormundetesten": "bevormundet",
    "bevormundetester": "bevormundet",
    "bevormundetestes": "bevormundet",
    "bevormundetet": "bevormunden",
    "bevorstand": "bevorstehen",
    "bevorstanden": "bevorstehen",
    "bevorstandest": "bevorstehen",
    "bevorstandet": "bevorstehen",
    "bevorstehe": "bevorstehen",
    "bevorstehend": "bevorstehen",
    "bevorstehende": "bevorstehend",
    "bevorstehendem": "bevorstehend",
    "bevorstehenden": "bevorstehend",
    "bevorstehender": "bevorstehend",
    "bevorstehendes": "bevorstehend",
    "bevorstehest": "bevorstehen",
    "bevorstehet": "bevorstehen",
    "bevorstehst": "bevorstehen",
    "bevorsteht": "bevorstehen",
    "bevorstünde": "bevorstehen",
    "bevorstünden": "bevorstehen",
    "bevorstündest": "bevorstehen",
    "bevorstündet": "bevorstehen",
    "bevorteile": "bevorteilen",
    "bevorteilend": "bevorteilen",
    "bevorteilende": "bevorteilend",
    "bevorteilendem": "bevorteilend",
    "bevorteilenden": "bevorteilend",
    "bevorteilender": "bevorteilend",
    "bevorteilendes": "bevorteilend",
    "bevorteilest": "bevorteilen",
    "bevorteilet": "bevorteilen",
    "bevorteilst": "bevorteilen",
    "bevorteilt": "bevorteilen",
    "bevorteilte": "bevorteilen",
    "bevorteiltem": "bevorteilt",
    "bevorteilten": "bevorteilen",
    "bevorteilter": "bevorteilt",
    "bevorteiltes": "bevorteilt",
    "bevorteiltest": "bevorteilen",
    "bevorteiltet": "bevorteilen",
    "bevorzuge": "bevorzugen",
    "bevorzugend": "bevorzugen",
    "bevorzugende": "bevorzugend",
    "bevorzugendem": "bevorzugend",
    "bevorzugenden": "bevorzugend",
    "bevorzugender": "bevorzugend",
    "bevorzugendes": "bevorzugend",
    "bevorzugest": "bevorzugen",
    "bevorzuget": "bevorzugen",
    "bevorzugst": "bevorzugen",
    "bevorzugt": "bevorzugen",
    "bevorzugte": "bevorzugen",
    "bevorzugtem": "bevorzugt",
    "bevorzugten": "bevorzugen",
    "bevorzugter": "bevorzugt",
    "bevorzugtere": "bevorzugt",
    "bevorzugterem": "bevorzugt",
    "bevorzugteren": "bevorzugt",
    "bevorzugterer": "bevorzugt",
    "bevorzugteres": "bevorzugt",
    "bevorzugtes": "bevorzugt",
    "bevorzugtest": "bevorzugen",
    "bevorzugteste": "bevorzugt",
    "bevorzugtestem": "bevorzugt",
    "bevorzugtesten": "bevorzugt",
    "bevorzugtester": "bevorzugt",
    "bevorzugtestes": "bevorzugt",
    "bevorzugtet": "bevorzugen",
    "bevorzustehen": "bevorstehen",
    "bevölkere": "bevölkern",
    "bevölkernd": "bevölkern",
    "bevölkernde": "bevölkernd",
    "bevölkerndem": "bevölkernd",
    "bevölkernden": "bevölkernd",
    "bevölkernder": "bevölkernd",
    "bevölkerndere": "bevölkernd",
    "bevölkernderem": "bevölkernd",
    "bevölkernderen": "bevölkernd",
    "bevölkernderer": "bevölkernd",
    "bevölkernderes": "bevölkernd",
    "bevölkerndes": "bevölkernd",
    "bevölkerndste": "bevölkernd",
    "bevölkerndstem": "bevölkernd",
    "bevölkerndsten": "bevölkernd",
    "bevölkerndster": "bevölkernd",
    "bevölkerndstes": "bevölkernd",
    "bevölkerst": "bevölkern",
    "bevölkert": "bevölkern",
    "bevölkerte": "bevölkern",
    "bevölkertem": "bevölkert",
    "bevölkerten": "bevölkern",
    "bevölkerter": "bevölkert",
    "bevölkertere": "bevölkert",
    "bevölkerterem": "bevölkert",
    "bevölkerteren": "bevölkert",
    "bevölkerterer": "bevölkert",
    "bevölkerteres": "bevölkert",
    "bevölkertes": "bevölkert",
    "bevölkertest": "bevölkern",
    "bevölkerteste": "bevölkert",
    "bevölkertestem": "bevölkert",
    "bevölkertesten": "bevölkert",
    "bevölkertester": "bevölkert",
    "bevölkertestes": "bevölkert",
    "bevölkertet": "bevölkern",
    "bewache": "bewachen",
    "bewachend": "bewachen",
    "bewachende": "bewachend",
    "bewachendem": "bewachend",
    "bewachenden": "bewachend",
    "bewachender": "bewachend",
    "bewachendes": "bewachend",
    "bewachest": "bewachen",
    "bewachet": "bewachen",
    "bewachse": "bewachsen",
    "bewachsend": "bewachsen",
    "bewachsende": "bewachsend",
    "bewachsendem": "bewachsend",
    "bewachsenden": "bewachsend",
    "bewachsender": "bewachsend",
    "bewachsendes": "bewachsend",
    "bewachsene": "bewachsen",
    "bewachsenem": "bewachsen",
    "bewachsenen": "bewachsen",
    "bewachsener": "bewachsen",
    "bewachsenere": "bewachsen",
    "bewachsenerem": "bewachsen",
    "bewachseneren": "bewachsen",
    "bewachsenerer": "bewachsen",
    "bewachseneres": "bewachsen",
    "bewachsenes": "bewachsen",
    "bewachsenstem": "bewachsen",
    "bewachsensten": "bewachsen",
    "bewachsenster": "bewachsen",
    "bewachsenstes": "bewachsen",
    "bewachsest": "bewachsen",
    "bewachset": "bewachsen",
    "bewachst": "bewachsen",
    "bewacht": "bewachen",
    "bewachte": "bewachen",
    "bewachtem": "bewacht",
    "bewachten": "bewachen",
    "bewachter": "bewacht",
    "bewachtere": "bewacht",
    "bewachterem": "bewacht",
    "bewachteren": "bewacht",
    "bewachterer": "bewacht",
    "bewachteres": "bewacht",
    "bewachtes": "bewacht",
    "bewachtest": "bewachen",
    "bewachteste": "bewacht",
    "bewachtestem": "bewacht",
    "bewachtesten": "bewacht",
    "bewachtester": "bewacht",
    "bewachtestes": "bewacht",
    "bewachtet": "bewachen",
    "bewaffne": "bewaffnen",
    "bewaffnend": "bewaffnen",
    "bewaffnende": "bewaffnend",
    "bewaffnendem": "bewaffnend",
    "bewaffnenden": "bewaffnend",
    "bewaffnender": "bewaffnend",
    "bewaffnendes": "bewaffnend",
    "bewaffnest": "bewaffnen",
    "bewaffnet": "bewaffnen",
    "bewaffnete": "bewaffnen",
    "bewaffnetem": "bewaffnet",
    "bewaffneten": "bewaffnen",
    "bewaffneter": "bewaffnet",
    "bewaffnetere": "bewaffnet",
    "bewaffneterem": "bewaffnet",
    "bewaffneteren": "bewaffnet",
    "bewaffneterer": "bewaffnet",
    "bewaffneteres": "bewaffnet",
    "bewaffnetes": "bewaffnet",
    "bewaffnetest": "bewaffnen",
    "bewaffneteste": "bewaffnet",
    "bewaffnetestem": "bewaffnet",
    "bewaffnetesten": "bewaffnet",
    "bewaffnetester": "bewaffnet",
    "bewaffnetestes": "bewaffnet",
    "bewaffnetet": "bewaffnen",
    "bewahre": "bewahren",
    "bewahrend": "bewahren",
    "bewahrende": "bewahrend",
    "bewahrendem": "bewahrend",
    "bewahrenden": "bewahrend",
    "bewahrender": "bewahrend",
    "bewahrendes": "bewahrend",
    "bewahrest": "bewahren",
    "bewahret": "bewahren",
    "bewahrst": "bewahren",
    "bewahrt": "bewahren",
    "bewahrte": "bewahren",
    "bewahrtem": "bewahrt",
    "bewahrten": "bewahren",
    "bewahrter": "bewahrt",
    "bewahrtere": "bewahrt",
    "bewahrterem": "bewahrt",
    "bewahrteren": "bewahrt",
    "bewahrterer": "bewahrt",
    "bewahrteres": "bewahrt",
    "bewahrtes": "bewahrt",
    "bewahrtest": "bewahren",
    "bewahrteste": "bewahrt",
    "bewahrtestem": "bewahrt",
    "bewahrtesten": "bewahrt",
    "bewahrtester": "bewahrt",
    "bewahrtestes": "bewahrt",
    "bewahrtet": "bewahren",
    "bewarb": "bewerben",
    "bewarben": "bewerben",
    "bewarbst": "bewerben",
    "bewarbt": "bewerben",
    "bewarf": "bewerfen",
    "bewarfen": "bewerfen",
    "bewarfst": "bewerfen",
    "bewarft": "bewerfen",
    "bewegbarem": "bewegbar",
    "bewegbaren": "bewegbar",
    "bewegbarer": "bewegbar",
    "bewegbares": "bewegbar",
    "bewege": "bewegen",
    "bewegend": "bewegen",
    "bewegende": "bewegend",
    "bewegendem": "bewegend",
    "bewegenden": "bewegend",
    "bewegender": "bewegend",
    "bewegendere": "bewegend",
    "bewegenderem": "bewegend",
    "bewegenderen": "bewegend",
    "bewegenderer": "bewegend",
    "bewegenderes": "bewegend",
    "bewegendes": "bewegend",
    "bewegendste": "bewegend",
    "bewegendstem": "bewegend",
    "bewegendsten": "bewegend",
    "bewegendster": "bewegend",
    "bewegendstes": "bewegend",
    "bewegest": "bewegen",
    "beweget": "bewegen",
    "bewegliche": "beweglich",
    "beweglichem": "beweglich",
    "beweglichen": "beweglich",
    "beweglicher": "beweglich",
    "beweglichere": "beweglich",
    "beweglicherem": "beweglich",
    "beweglicheren": "beweglich",
    "beweglicherer": "beweglich",
    "beweglicheres": "beweglich",
    "bewegliches": "beweglich",
    "beweglichste": "beweglich",
    "beweglichstem": "beweglich",
    "beweglichsten": "beweglich",
    "beweglichster": "beweglich",
    "beweglichstes": "beweglich",
    "bewegst": "bewegen",
    "bewegt": "bewegen",
    "bewegte": "bewegen",
    "bewegtem": "bewegt",
    "bewegten": "bewegen",
    "bewegter": "bewegt",
    "bewegtere": "bewegt",
    "bewegterem": "bewegt",
    "bewegteren": "bewegt",
    "bewegterer": "bewegt",
    "bewegteres": "bewegt",
    "bewegtes": "bewegt",
    "bewegtest": "bewegen",
    "bewegteste": "bewegt",
    "bewegtestem": "bewegt",
    "bewegtesten": "bewegt",
    "bewegtester": "bewegt",
    "bewegtestes": "bewegt",
    "bewegtet": "bewegen",
    "bewegungslosem": "bewegungslos",
    "bewegungslosen": "bewegungslos",
    "bewegungsloser": "bewegungslos",
    "bewegungslosere": "bewegungslos",
    "bewegungsloserem": "bewegungslos",
    "bewegungsloseren": "bewegungslos",
    "bewegungsloserer": "bewegungslos",
    "bewegungsloseres": "bewegungslos",
    "bewegungsloses": "bewegungslos",
    "bewegungsloseste": "bewegungslos",
    "bewegungslosestem": "bewegungslos",
    "bewegungslosesten": "bewegungslos",
    "bewegungslosester": "bewegungslos",
    "bewegungslosestes": "bewegungslos",
    "beweihräuchere": "beweihräuchern",
    "beweihräuchernd": "beweihräuchern",
    "beweihräuchernde": "beweihräuchernd",
    "beweihräucherndem": "beweihräuchernd",
    "beweihräuchernden": "beweihräuchernd",
    "beweihräuchernder": "beweihräuchernd",
    "beweihräucherndere": "beweihräuchernd",
    "beweihräuchernderem": "beweihräuchernd",
    "beweihräuchernderen": "beweihräuchernd",
    "beweihräuchernderer": "beweihräuchernd",
    "beweihräuchernderes": "beweihräuchernd",
    "beweihräucherndes": "beweihräuchernd",
    "beweihräucherndste": "beweihräuchernd",
    "beweihräucherndstem": "beweihräuchernd",
    "beweihräucherndsten": "beweihräuchernd",
    "beweihräucherndster": "beweihräuchernd",
    "beweihräucherndstes": "beweihräuchernd",
    "beweihräucherst": "beweihräuchern",
    "beweihräuchert": "beweihräuchern",
    "beweihräucherte": "beweihräuchern",
    "beweihräuchertem": "beweihräuchert",
    "beweihräucherten": "beweihräuchern",
    "beweihräucherter": "beweihräuchert",
    "beweihräuchertere": "beweihräuchert",
    "beweihräucherterem": "beweihräuchert",
    "beweihräucherteren": "beweihräuchert",
    "beweihräucherterer": "beweihräuchert",
    "beweihräucherteres": "beweihräuchert",
    "beweihräuchertes": "beweihräuchert",
    "beweihräuchertest": "beweihräuchern",
    "beweihräucherteste": "beweihräuchert",
    "beweihräuchertestem": "beweihräuchert",
    "beweihräuchertesten": "beweihräuchert",
    "beweihräuchertester": "beweihräuchert",
    "beweihräuchertestes": "beweihräuchert",
    "beweihräuchertet": "beweihräuchern",
    "beweine": "beweinen",
    "beweinend": "beweinen",
    "beweinende": "beweinend",
    "beweinendem": "beweinend",
    "beweinenden": "beweinend",
    "beweinender": "beweinend",
    "beweinendere": "beweinend",
    "beweinenderem": "beweinend",
    "beweinenderen": "beweinend",
    "beweinenderer": "beweinend",
    "beweinenderes": "beweinend",
    "beweinendes": "beweinend",
    "beweinendste": "beweinend",
    "beweinendstem": "beweinend",
    "beweinendsten": "beweinend",
    "beweinendster": "beweinend",
    "beweinendstes": "beweinend",
    "beweinest": "beweinen",
    "beweinet": "beweinen",
    "beweinst": "beweinen",
    "beweint": "beweinen",
    "beweinte": "beweinen",
    "beweintem": "beweint",
    "beweinten": "beweinen",
    "beweinter": "beweint",
    "beweintere": "beweint",
    "beweinterem": "beweint",
    "beweinteren": "beweint",
    "beweinterer": "beweint",
    "beweinteres": "beweint",
    "beweintes": "beweint",
    "beweintest": "beweinen",
    "beweinteste": "beweint",
    "beweintestem": "beweint",
    "beweintesten": "beweint",
    "beweintester": "beweint",
    "beweintestes": "beweint",
    "beweintet": "beweinen",
    "beweisend": "beweisen",
    "beweisende": "beweisend",
    "beweisendem": "beweisend",
    "beweisenden": "beweisend",
    "beweisender": "beweisend",
    "beweisendes": "beweisend",
    "beweisest": "beweisen",
    "beweiset": "beweisen",
    "beweiskräftigem": "beweiskräftig",
    "beweiskräftigen": "beweiskräftig",
    "beweiskräftiger": "beweiskräftig",
    "beweiskräftiges": "beweiskräftig",
    "beweist": "beweisen",
    "bewende": "bewenden",
    "bewendend": "bewenden",
    "bewendende": "bewendend",
    "bewendendem": "bewendend",
    "bewendenden": "bewendend",
    "bewendender": "bewendend",
    "bewendendes": "bewendend",
    "bewendest": "bewenden",
    "bewendet": "bewenden",
    "bewendete": "bewenden",
    "bewendetem": "bewendet",
    "bewendeten": "bewenden",
    "bewendeter": "bewendet",
    "bewendetes": "bewendet",
    "bewendetest": "bewenden",
    "bewendetet": "bewenden",
    "bewerbe": "bewerben",
    "bewerbend": "bewerben",
    "bewerbende": "bewerbend",
    "bewerbendem": "bewerbend",
    "bewerbenden": "bewerbend",
    "bewerbender": "bewerbend",
    "bewerbendes": "bewerbend",
    "bewerbest": "bewerben",
    "bewerbet": "bewerben",
    "bewerbt": "bewerben",
    "bewerfe": "bewerfen",
    "bewerfend": "bewerfen",
    "bewerfende": "bewerfend",
    "bewerfendem": "bewerfend",
    "bewerfenden": "bewerfend",
    "bewerfender": "bewerfend",
    "bewerfendes": "bewerfend",
    "bewerfest": "bewerfen",
    "bewerfet": "bewerfen",
    "bewerft": "bewerfen",
    "bewerkstellige": "bewerkstelligen",
    "bewerkstelligend": "bewerkstelligen",
    "bewerkstelligende": "bewerkstelligend",
    "bewerkstelligendem": "bewerkstelligend",
    "bewerkstelligenden": "bewerkstelligend",
    "bewerkstelligender": "bewerkstelligend",
    "bewerkstelligendes": "bewerkstelligend",
    "bewerkstelligest": "bewerkstelligen",
    "bewerkstelliget": "bewerkstelligen",
    "bewerkstelligst": "bewerkstelligen",
    "bewerkstelligt": "bewerkstelligen",
    "bewerkstelligte": "bewerkstelligen",
    "bewerkstelligtem": "bewerkstelligt",
    "bewerkstelligten": "bewerkstelligen",
    "bewerkstelligter": "bewerkstelligt",
    "bewerkstelligtes": "bewerkstelligt",
    "bewerkstelligtest": "bewerkstelligen",
    "bewerkstelligtet": "bewerkstelligen",
    "bewerte": "bewerten",
    "bewertend": "bewerten",
    "bewertende": "bewertend",
    "bewertendem": "bewertend",
    "bewertenden": "bewertend",
    "bewertender": "bewertend",
    "bewertendere": "bewertend",
    "bewertenderem": "bewertend",
    "bewertenderen": "bewertend",
    "bewertenderer": "bewertend",
    "bewertenderes": "bewertend",
    "bewertendes": "bewertend",
    "bewertendste": "bewertend",
    "bewertendstem": "bewertend",
    "bewertendsten": "bewertend",
    "bewertendster": "bewertend",
    "bewertendstes": "bewertend",
    "bewertest": "bewerten",
    "bewertet": "bewerten",
    "bewertete": "bewerten",
    "bewertetem": "bewertet",
    "bewerteten": "bewerten",
    "bewerteter": "bewertet",
    "bewertetes": "bewertet",
    "bewertetest": "bewerten",
    "bewertetet": "bewerten",
    "bewies": "beweisen",
    "bewiese": "beweisen",
    "bewiesen": "beweisen",
    "bewiesene": "bewiesen",
    "bewiesenem": "bewiesen",
    "bewiesenen": "bewiesen",
    "bewiesener": "bewiesen",
    "bewiesenere": "bewiesen",
    "bewiesenerem": "bewiesen",
    "bewieseneren": "bewiesen",
    "bewiesenerer": "bewiesen",
    "bewieseneres": "bewiesen",
    "bewiesenes": "bewiesen",
    "bewiesenste": "bewiesen",
    "bewiesenstem": "bewiesen",
    "bewiesensten": "bewiesen",
    "bewiesenster": "bewiesen",
    "bewiesenstes": "bewiesen",
    "bewiesest": "beweisen",
    "bewieset": "beweisen",
    "bewiest": "beweisen",
    "bewillige": "bewilligen",
    "bewilligend": "bewilligen",
    "bewilligende": "bewilligend",
    "bewilligendem": "bewilligend",
    "bewilligenden": "bewilligend",
    "bewilligender": "bewilligend",
    "bewilligendes": "bewilligend",
    "bewilligest": "bewilligen",
    "bewilliget": "bewilligen",
    "bewilligst": "bewilligen",
    "bewilligt": "bewilligen",
    "bewilligte": "bewilligen",
    "bewilligtem": "bewilligt",
    "bewilligten": "bewilligen",
    "bewilligter": "bewilligt",
    "bewilligtes": "bewilligt",
    "bewilligtest": "bewilligen",
    "bewilligtet": "bewilligen",
    "bewirb": "bewerben",
    "bewirbst": "bewerben",
    "bewirbt": "bewerben",
    "bewirf": "bewerfen",
    "bewirfst": "bewerfen",
    "bewirft": "bewerfen",
    "bewirke": "bewirken",
    "bewirkend": "bewirken",
    "bewirkende": "bewirkend",
    "bewirkendem": "bewirkend",
    "bewirkenden": "bewirkend",
    "bewirkender": "bewirkend",
    "bewirkendere": "bewirkend",
    "bewirkenderem": "bewirkend",
    "bewirkenderen": "bewirkend",
    "bewirkenderer": "bewirkend",
    "bewirkenderes": "bewirkend",
    "bewirkendes": "bewirkend",
    "bewirkendste": "bewirkend",
    "bewirkendstem": "bewirkend",
    "bewirkendsten": "bewirkend",
    "bewirkendster": "bewirkend",
    "bewirkendstes": "bewirkend",
    "bewirkest": "bewirken",
    "bewirket": "bewirken",
    "bewirkst": "bewirken",
    "bewirkt": "bewirken",
    "bewirkte": "bewirken",
    "bewirktem": "bewirkt",
    "bewirkten": "bewirken",
    "bewirkter": "bewirkt",
    "bewirktes": "bewirkt",
    "bewirktest": "bewirken",
    "bewirktet": "bewirken",
    "bewirte": "bewirten",
    "bewirtend": "bewirten",
    "bewirtende": "bewirtend",
    "bewirtendem": "bewirtend",
    "bewirtenden": "bewirtend",
    "bewirtender": "bewirtend",
    "bewirtendere": "bewirtend",
    "bewirtenderem": "bewirtend",
    "bewirtenderen": "bewirtend",
    "bewirtenderer": "bewirtend",
    "bewirtenderes": "bewirtend",
    "bewirtendes": "bewirtend",
    "bewirtendste": "bewirtend",
    "bewirtendstem": "bewirtend",
    "bewirtendsten": "bewirtend",
    "bewirtendster": "bewirtend",
    "bewirtendstes": "bewirtend",
    "bewirtest": "bewirten",
    "bewirtet": "bewirten",
    "bewirtete": "bewirten",
    "bewirtetem": "bewirtet",
    "bewirteten": "bewirten",
    "bewirteter": "bewirtet",
    "bewirtetere": "bewirtet",
    "bewirteterem": "bewirtet",
    "bewirteteren": "bewirtet",
    "bewirteterer": "bewirtet",
    "bewirteteres": "bewirtet",
    "bewirtetes": "bewirtet",
    "bewirtetest": "bewirten",
    "bewirteteste": "bewirtet",
    "bewirtetestem": "bewirtet",
    "bewirtetesten": "bewirtet",
    "bewirtetester": "bewirtet",
    "bewirtetestes": "bewirtet",
    "bewirtetet": "bewirten",
    "bewirtschafte": "bewirtschaften",
    "bewirtschaftend": "bewirtschaften",
    "bewirtschaftende": "bewirtschaftend",
    "bewirtschaftendem": "bewirtschaftend",
    "bewirtschaftenden": "bewirtschaftend",
    "bewirtschaftender": "bewirtschaftend",
    "bewirtschaftendes": "bewirtschaftend",
    "bewirtschaftest": "bewirtschaften",
    "bewirtschaftet": "bewirtschaften",
    "bewirtschaftete": "bewirtschaften",
    "bewirtschaftetem": "bewirtschaftet",
    "bewirtschafteten": "bewirtschaften",
    "bewirtschafteter": "bewirtschaftet",
    "bewirtschaftetes": "bewirtschaftet",
    "bewirtschaftetest": "bewirtschaften",
    "bewirtschaftetet": "bewirtschaften",
    "bewog": "bewegen",
    "bewogen": "bewegen",
    "bewogene": "bewogen",
    "bewogenem": "bewogen",
    "bewogenen": "bewogen",
    "bewogener": "bewogen",
    "bewogenes": "bewogen",
    "bewogst": "bewegen",
    "bewogt": "bewegen",
    "bewohnbare": "bewohnbar",
    "bewohnbarem": "bewohnbar",
    "bewohnbaren": "bewohnbar",
    "bewohnbarer": "bewohnbar",
    "bewohnbarere": "bewohnbar",
    "bewohnbarerem": "bewohnbar",
    "bewohnbareren": "bewohnbar",
    "bewohnbarerer": "bewohnbar",
    "bewohnbareres": "bewohnbar",
    "bewohnbares": "bewohnbar",
    "bewohnbarste": "bewohnbar",
    "bewohnbarstem": "bewohnbar",
    "bewohnbarsten": "bewohnbar",
    "bewohnbarster": "bewohnbar",
    "bewohnbarstes": "bewohnbar",
    "bewohne": "bewohnen",
    "bewohnend": "bewohnen",
    "bewohnende": "bewohnend",
    "bewohnendem": "bewohnend",
    "bewohnenden": "bewohnend",
    "bewohnender": "bewohnend",
    "bewohnendes": "bewohnend",
    "bewohnest": "bewohnen",
    "bewohnet": "bewohnen",
    "bewohnst": "bewohnen",
    "bewohnt": "bewohnen",
    "bewohnte": "bewohnen",
    "bewohntem": "bewohnt",
    "bewohnten": "bewohnen",
    "bewohnter": "bewohnt",
    "bewohntere": "bewohnt",
    "bewohnterem": "bewohnt",
    "bewohnteren": "bewohnt",
    "bewohnterer": "bewohnt",
    "bewohnteres": "bewohnt",
    "bewohntes": "bewohnt",
    "bewohntest": "bewohnen",
    "bewohnteste": "bewohnt",
    "bewohntestem": "bewohnt",
    "bewohntesten": "bewohnt",
    "bewohntester": "bewohnt",
    "bewohntestes": "bewohnt",
    "bewohntet": "bewohnen",
    "beworben": "bewerben",
    "beworbene": "beworben",
    "beworbenem": "beworben",
    "beworbenen": "beworben",
    "beworbener": "beworben",
    "beworbenes": "beworben",
    "beworfen": "bewerfen",
    "beworfene": "beworfen",
    "beworfenem": "beworfen",
    "beworfenen": "beworfen",
    "beworfener": "beworfen",
    "beworfenere": "beworfen",
    "beworfenerem": "beworfen",
    "beworfeneren": "beworfen",
    "beworfenerer": "beworfen",
    "beworfeneres": "beworfen",
    "beworfenes": "beworfen",
    "beworfenste": "beworfen",
    "beworfenstem": "beworfen",
    "beworfensten": "beworfen",
    "beworfenster": "beworfen",
    "beworfenstes": "beworfen",
    "bewuchere": "bewuchern",
    "bewuchernd": "bewuchern",
    "bewuchernde": "bewuchernd",
    "bewucherndem": "bewuchernd",
    "bewuchernden": "bewuchernd",
    "bewuchernder": "bewuchernd",
    "bewucherndere": "bewuchernd",
    "bewuchernderem": "bewuchernd",
    "bewuchernderen": "bewuchernd",
    "bewuchernderer": "bewuchernd",
    "bewuchernderes": "bewuchernd",
    "bewucherndes": "bewuchernd",
    "bewucherndste": "bewuchernd",
    "bewucherndstem": "bewuchernd",
    "bewucherndsten": "bewuchernd",
    "bewucherndster": "bewuchernd",
    "bewucherndstes": "bewuchernd",
    "bewucherst": "bewuchern",
    "bewuchert": "bewuchern",
    "bewucherte": "bewuchern",
    "bewuchertem": "bewuchert",
    "bewucherten": "bewuchern",
    "bewucherter": "bewuchert",
    "bewuchertere": "bewuchert",
    "bewucherterem": "bewuchert",
    "bewucherteren": "bewuchert",
    "bewucherterer": "bewuchert",
    "bewucherteres": "bewuchert",
    "bewuchertes": "bewuchert",
    "bewuchertest": "bewuchern",
    "bewucherteste": "bewuchert",
    "bewuchertestem": "bewuchert",
    "bewuchertesten": "bewuchert",
    "bewuchertester": "bewuchert",
    "bewuchertestes": "bewuchert",
    "bewuchertet": "bewuchern",
    "bewuchs": "bewachsen",
    "bewuchsen": "bewachsen",
    "bewuchst": "bewachsen",
    "bewundere": "bewundern",
    "bewundernd": "bewundern",
    "bewundernde": "bewundernd",
    "bewunderndem": "bewundernd",
    "bewundernden": "bewundernd",
    "bewundernder": "bewundernd",
    "bewunderndes": "bewundernd",
    "bewundernswertem": "bewundernswert",
    "bewundernswerten": "bewundernswert",
    "bewundernswerter": "bewundernswert",
    "bewundernswertere": "bewundernswert",
    "bewundernswerterem": "bewundernswert",
    "bewundernswerteren": "bewundernswert",
    "bewundernswerterer": "bewundernswert",
    "bewundernswerteres": "bewundernswert",
    "bewundernswertes": "bewundernswert",
    "bewundernswerteste": "bewundernswert",
    "bewundernswertestem": "bewundernswert",
    "bewundernswertesten": "bewundernswert",
    "bewundernswertester": "bewundernswert",
    "bewundernswertestes": "bewundernswert",
    "bewunderst": "bewundern",
    "bewundert": "bewundern",
    "bewunderte": "bewundern",
    "bewundertem": "bewundert",
    "bewunderten": "bewundern",
    "bewunderter": "bewundert",
    "bewundertere": "bewundert",
    "bewunderterem": "bewundert",
    "bewunderteren": "bewundert",
    "bewunderterer": "bewundert",
    "bewunderteres": "bewundert",
    "bewundertes": "bewundert",
    "bewundertest": "bewundern",
    "bewunderteste": "bewundert",
    "bewundertestem": "bewundert",
    "bewundertesten": "bewundert",
    "bewundertester": "bewundert",
    "bewundertestes": "bewundert",
    "bewundertet": "bewundern",
    "bewußtem": "bewußt",
    "bewußten": "bewußt",
    "bewußter": "bewußt",
    "bewußtere": "bewußt",
    "bewußterem": "bewußt",
    "bewußteren": "bewußt",
    "bewußterer": "bewußt",
    "bewußteres": "bewußt",
    "bewußtes": "bewußt",
    "bewußteste": "bewußt",
    "bewußtestem": "bewußt",
    "bewußtesten": "bewußt",
    "bewußtester": "bewußt",
    "bewußtestes": "bewußt",
    "bewußtlose": "bewußtlos",
    "bewußtlosem": "bewußtlos",
    "bewußtlosen": "bewußtlos",
    "bewußtloser": "bewußtlos",
    "bewußtloses": "bewußtlos",
    "bewächst": "bewachsen",
    "bewähre": "bewähren",
    "bewährend": "bewähren",
    "bewährendem": "bewährend",
    "bewährender": "bewährend",
    "bewährendes": "bewährend",
    "bewährest": "bewähren",
    "bewähret": "bewähren",
    "bewährst": "bewähren",
    "bewährt": "bewähren",
    "bewährte": "bewähren",
    "bewährtem": "bewährt",
    "bewährten": "bewährt",
    "bewährter": "bewährt",
    "bewährterem": "bewährt",
    "bewährterer": "bewährt",
    "bewährteres": "bewährt",
    "bewährtes": "bewährt",
    "bewährtest": "bewähren",
    "bewährtestem": "bewährt",
    "bewährtester": "bewährt",
    "bewährtestes": "bewährt",
    "bewährtet": "bewähren",
    "bewältige": "bewältigen",
    "bewältigend": "bewältigen",
    "bewältigende": "bewältigend",
    "bewältigendem": "bewältigend",
    "bewältigenden": "bewältigend",
    "bewältigender": "bewältigend",
    "bewältigendes": "bewältigend",
    "bewältigest": "bewältigen",
    "bewältiget": "bewältigen",
    "bewältigst": "bewältigen",
    "bewältigt": "bewältigen",
    "bewältigte": "bewältigen",
    "bewältigtem": "bewältigt",
    "bewältigten": "bewältigen",
    "bewältigter": "bewältigt",
    "bewältigtes": "bewältigt",
    "bewältigtest": "bewältigen",
    "bewältigtet": "bewältigen",
    "bewärbe": "bewerben",
    "bewärben": "bewerben",
    "bewärbest": "bewerben",
    "bewärbet": "bewerben",
    "bewärfe": "bewerfen",
    "bewärfen": "bewerfen",
    "bewärfest": "bewerfen",
    "bewärfet": "bewerfen",
    "bewässere": "bewässern",
    "bewässernd": "bewässern",
    "bewässernde": "bewässernd",
    "bewässerndem": "bewässernd",
    "bewässernden": "bewässernd",
    "bewässernder": "bewässernd",
    "bewässerndere": "bewässernd",
    "bewässernderem": "bewässernd",
    "bewässernderen": "bewässernd",
    "bewässernderer": "bewässernd",
    "bewässernderes": "bewässernd",
    "bewässerndes": "bewässernd",
    "bewässerndste": "bewässernd",
    "bewässerndstem": "bewässernd",
    "bewässerndsten": "bewässernd",
    "bewässerndster": "bewässernd",
    "bewässerndstes": "bewässernd",
    "bewässerst": "bewässern",
    "bewässert": "bewässern",
    "bewässerte": "bewässern",
    "bewässertem": "bewässert",
    "bewässerten": "bewässern",
    "bewässerter": "bewässert",
    "bewässertere": "bewässert",
    "bewässerterem": "bewässert",
    "bewässerteren": "bewässert",
    "bewässerterer": "bewässert",
    "bewässerteres": "bewässert",
    "bewässertes": "bewässert",
    "bewässertest": "bewässern",
    "bewässerteste": "bewässert",
    "bewässertestem": "bewässert",
    "bewässertesten": "bewässert",
    "bewässertester": "bewässert",
    "bewässertestes": "bewässert",
    "bewässertet": "bewässern",
    "bewöge": "bewegen",
    "bewögen": "bewegen",
    "bewögest": "bewegen",
    "bewöget": "bewegen",
    "bewölke": "bewölken",
    "bewölkend": "bewölken",
    "bewölkende": "bewölkend",
    "bewölkendem": "bewölkend",
    "bewölkenden": "bewölkend",
    "bewölkender": "bewölkend",
    "bewölkendes": "bewölkend",
    "bewölkest": "bewölken",
    "bewölket": "bewölken",
    "bewölkst": "bewölken",
    "bewölkt": "bewölken",
    "bewölkte": "bewölken",
    "bewölktem": "bewölkt",
    "bewölkten": "bewölken",
    "bewölkter": "bewölkt",
    "bewölktere": "bewölkt",
    "bewölkterem": "bewölkt",
    "bewölkteren": "bewölkt",
    "bewölkterer": "bewölkt",
    "bewölkteres": "bewölkt",
    "bewölktes": "bewölkt",
    "bewölktest": "bewölken",
    "bewölkteste": "bewölkt",
    "bewölktestem": "bewölkt",
    "bewölktesten": "bewölkt",
    "bewölktester": "bewölkt",
    "bewölktestes": "bewölkt",
    "bewölktet": "bewölken",
    "bewüchse": "bewachsen",
    "bewüchsen": "bewachsen",
    "bewüchsest": "bewachsen",
    "bewüchset": "bewachsen",
    "bezahlbarem": "bezahlbar",
    "bezahlbaren": "bezahlbar",
    "bezahlbarer": "bezahlbar",
    "bezahlbares": "bezahlbar",
    "bezahle": "bezahlen",
    "bezahlend": "bezahlen",
    "bezahlende": "bezahlend",
    "bezahlendem": "bezahlend",
    "bezahlenden": "bezahlend",
    "bezahlender": "bezahlend",
    "bezahlendes": "bezahlend",
    "bezahlest": "bezahlen",
    "bezahlet": "bezahlen",
    "bezahlst": "bezahlen",
    "bezahlt": "bezahlen",
    "bezahlte": "bezahlen",
    "bezahltem": "bezahlt",
    "bezahlten": "bezahlen",
    "bezahlter": "bezahlt",
    "bezahltere": "bezahlt",
    "bezahlterem": "bezahlt",
    "bezahlteren": "bezahlt",
    "bezahlterer": "bezahlt",
    "bezahlteres": "bezahlt",
    "bezahltes": "bezahlt",
    "bezahltest": "bezahlen",
    "bezahlteste": "bezahlt",
    "bezahltestem": "bezahlt",
    "bezahltesten": "bezahlt",
    "bezahltester": "bezahlt",
    "bezahltestes": "bezahlt",
    "bezahltet": "bezahlen",
    "bezaubere": "bezaubern",
    "bezaubernd": "bezaubern",
    "bezaubernde": "bezaubernd",
    "bezauberndem": "bezaubernd",
    "bezaubernden": "bezaubernd",
    "bezaubernder": "bezaubernd",
    "bezauberndere": "bezaubernd",
    "bezaubernderem": "bezaubernd",
    "bezaubernderen": "bezaubernd",
    "bezaubernderer": "bezaubernd",
    "bezaubernderes": "bezaubernd",
    "bezauberndes": "bezaubernd",
    "bezauberndste": "bezaubernd",
    "bezauberndstem": "bezaubernd",
    "bezauberndsten": "bezaubernd",
    "bezauberndster": "bezaubernd",
    "bezauberndstes": "bezaubernd",
    "bezauberst": "bezaubern",
    "bezaubert": "bezaubern",
    "bezauberte": "bezaubern",
    "bezaubertem": "bezaubert",
    "bezauberten": "bezaubern",
    "bezauberter": "bezaubert",
    "bezaubertes": "bezaubert",
    "bezaubertest": "bezaubern",
    "bezaubertet": "bezaubern",
    "bezeichne": "bezeichnen",
    "bezeichnend": "bezeichnen",
    "bezeichnende": "bezeichnend",
    "bezeichnendem": "bezeichnend",
    "bezeichnenden": "bezeichnend",
    "bezeichnender": "bezeichnend",
    "bezeichnendes": "bezeichnend",
    "bezeichnest": "bezeichnen",
    "bezeichnet": "bezeichnen",
    "bezeichnete": "bezeichnen",
    "bezeichnetem": "bezeichnet",
    "bezeichneten": "bezeichnen",
    "bezeichneter": "bezeichnet",
    "bezeichnetes": "bezeichnet",
    "bezeichnetest": "bezeichnen",
    "bezeichnetet": "bezeichnen",
    "bezeuge": "bezeugen",
    "bezeugend": "bezeugen",
    "bezeugende": "bezeugend",
    "bezeugendem": "bezeugend",
    "bezeugenden": "bezeugend",
    "bezeugender": "bezeugend",
    "bezeugendes": "bezeugend",
    "bezeugest": "bezeugen",
    "bezeuget": "bezeugen",
    "bezeugst": "bezeugen",
    "bezeugt": "bezeugen",
    "bezeugte": "bezeugen",
    "bezeugtem": "bezeugt",
    "bezeugten": "bezeugen",
    "bezeugter": "bezeugt",
    "bezeugtes": "bezeugt",
    "bezeugtest": "bezeugen",
    "bezeugtet": "bezeugen",
    "bezichtige": "bezichtigen",
    "bezichtigend": "bezichtigen",
    "bezichtigende": "bezichtigend",
    "bezichtigendem": "bezichtigend",
    "bezichtigenden": "bezichtigend",
    "bezichtigender": "bezichtigend",
    "bezichtigendes": "bezichtigend",
    "bezichtigest": "bezichtigen",
    "bezichtiget": "bezichtigen",
    "bezichtigst": "bezichtigen",
    "bezichtigt": "bezichtigen",
    "bezichtigte": "bezichtigen",
    "bezichtigtem": "bezichtigt",
    "bezichtigten": "bezichtigen",
    "bezichtigter": "bezichtigt",
    "bezichtigtes": "bezichtigt",
    "bezichtigtest": "bezichtigen",
    "bezichtigtet": "bezichtigen",
    "beziehe": "beziehen",
    "beziehend": "beziehen",
    "beziehende": "beziehend",
    "beziehendem": "beziehend",
    "beziehenden": "beziehend",
    "beziehender": "beziehend",
    "beziehendes": "beziehend",
    "beziehest": "beziehen",
    "beziehet": "beziehen",
    "beziehst": "beziehen",
    "bezieht": "beziehen",
    "beziffere": "beziffern",
    "beziffernd": "beziffern",
    "beziffernde": "beziffernd",
    "bezifferndem": "beziffernd",
    "beziffernden": "beziffernd",
    "beziffernder": "beziffernd",
    "bezifferndes": "beziffernd",
    "bezifferst": "beziffern",
    "beziffert": "beziffern",
    "bezifferte": "beziffern",
    "beziffertem": "beziffert",
    "bezifferten": "beziffern",
    "bezifferter": "beziffert",
    "beziffertes": "beziffert",
    "beziffertest": "beziffern",
    "beziffertet": "beziffern",
    "bezog": "beziehen",
    "bezogen": "beziehen",
    "bezogene": "bezogen",
    "bezogenem": "bezogen",
    "bezogenen": "bezogen",
    "bezogener": "bezogen",
    "bezogenes": "bezogen",
    "bezogst": "beziehen",
    "bezogt": "beziehen",
    "bezugsfertigem": "bezugsfertig",
    "bezugsfertigen": "bezugsfertig",
    "bezugsfertiger": "bezugsfertig",
    "bezugsfertiges": "bezugsfertig",
    "bezuschusse": "bezuschussen",
    "bezuschussend": "bezuschussen",
    "bezuschussende": "bezuschussend",
    "bezuschussendem": "bezuschussend",
    "bezuschussenden": "bezuschussend",
    "bezuschussender": "bezuschussend",
    "bezuschussendere": "bezuschussend",
    "bezuschussenderem": "bezuschussend",
    "bezuschussenderen": "bezuschussend",
    "bezuschussenderer": "bezuschussend",
    "bezuschussenderes": "bezuschussend",
    "bezuschussendes": "bezuschussend",
    "bezuschussendste": "bezuschussend",
    "bezuschussendstem": "bezuschussend",
    "bezuschussendsten": "bezuschussend",
    "bezuschussendster": "bezuschussend",
    "bezuschussendstes": "bezuschussend",
    "bezuschussest": "bezuschussen",
    "bezuschusset": "bezuschussen",
    "bezuschußt": "bezuschussen",
    "bezuschußte": "bezuschussen",
    "bezuschußtem": "bezuschußt",
    "bezuschußten": "bezuschussen",
    "bezuschußter": "bezuschußt",
    "bezuschußtere": "bezuschußt",
    "bezuschußterem": "bezuschußt",
    "bezuschußteren": "bezuschußt",
    "bezuschußterer": "bezuschußt",
    "bezuschußteres": "bezuschußt",
    "bezuschußtes": "bezuschußt",
    "bezuschußtest": "bezuschussen",
    "bezuschußteste": "bezuschußt",
    "bezuschußtestem": "bezuschußt",
    "bezuschußtesten": "bezuschußt",
    "bezuschußtester": "bezuschußt",
    "bezuschußtestes": "bezuschußt",
    "bezuschußtet": "bezuschussen",
    "bezwecke": "bezwecken",
    "bezweckend": "bezwecken",
    "bezweckende": "bezweckend",
    "bezweckendem": "bezweckend",
    "bezweckenden": "bezweckend",
    "bezweckender": "bezweckend",
    "bezweckendes": "bezweckend",
    "bezweckest": "bezwecken",
    "bezwecket": "bezwecken",
    "bezweckst": "bezwecken",
    "bezweckt": "bezwecken",
    "bezweckte": "bezwecken",
    "bezwecktem": "bezweckt",
    "bezweckten": "bezwecken",
    "bezweckter": "bezweckt",
    "bezwecktes": "bezweckt",
    "bezwecktest": "bezwecken",
    "bezwecktet": "bezwecken",
    "bezweifele": "bezweifeln",
    "bezweifelnd": "bezweifeln",
    "bezweifelnde": "bezweifelnd",
    "bezweifelndem": "bezweifelnd",
    "bezweifelnden": "bezweifelnd",
    "bezweifelnder": "bezweifelnd",
    "bezweifelndes": "bezweifelnd",
    "bezweifelst": "bezweifeln",
    "bezweifelt": "bezweifeln",
    "bezweifelte": "bezweifeln",
    "bezweifeltem": "bezweifelt",
    "bezweifelten": "bezweifeln",
    "bezweifelter": "bezweifelt",
    "bezweifeltere": "bezweifelt",
    "bezweifelterem": "bezweifelt",
    "bezweifelteren": "bezweifelt",
    "bezweifelterer": "bezweifelt",
    "bezweifelteres": "bezweifelt",
    "bezweifeltes": "bezweifelt",
    "bezweifeltest": "bezweifeln",
    "bezweifelteste": "bezweifelt",
    "bezweifeltestem": "bezweifelt",
    "bezweifeltesten": "bezweifelt",
    "bezweifeltester": "bezweifelt",
    "bezweifeltestes": "bezweifelt",
    "bezweifeltet": "bezweifeln",
    "bezweifle": "bezweifeln",
    "bezwingbare": "bezwingbar",
    "bezwingbarem": "bezwingbar",
    "bezwingbaren": "bezwingbar",
    "bezwingbarer": "bezwingbar",
    "bezwingbares": "bezwingbar",
    "bezöge": "beziehen",
    "bezögen": "beziehen",
    "bezögest": "beziehen",
    "bezöget": "beziehen",
    "beängstige": "beängstigen",
    "beängstigend": "beängstigen",
    "beängstigende": "beängstigend",
    "beängstigendem": "beängstigend",
    "beängstigenden": "beängstigend",
    "beängstigender": "beängstigend",
    "beängstigendere": "beängstigend",
    "beängstigenderem": "beängstigend",
    "beängstigenderen": "beängstigend",
    "beängstigenderer": "beängstigend",
    "beängstigenderes": "beängstigend",
    "beängstigendes": "beängstigend",
    "beängstigendste": "beängstigend",
    "beängstigendstem": "beängstigend",
    "beängstigendsten": "beängstigend",
    "beängstigendster": "beängstigend",
    "beängstigendstes": "beängstigend",
    "beängstigest": "beängstigen",
    "beängstiget": "beängstigen",
    "beängstigst": "beängstigen",
    "beängstigt": "beängstigen",
    "beängstigte": "beängstigen",
    "beängstigtem": "beängstigt",
    "beängstigten": "beängstigen",
    "beängstigter": "beängstigt",
    "beängstigtere": "beängstigt",
    "beängstigterem": "beängstigt",
    "beängstigteren": "beängstigt",
    "beängstigterer": "beängstigt",
    "beängstigteres": "beängstigt",
    "beängstigtes": "beängstigt",
    "beängstigtest": "beängstigen",
    "beängstigteste": "beängstigt",
    "beängstigtestem": "beängstigt",
    "beängstigtesten": "beängstigt",
    "beängstigtester": "beängstigt",
    "beängstigtestes": "beängstigt",
    "beängstigtet": "beängstigen",
    "beäuge": "beäugen",
    "beäugend": "beäugen",
    "beäugende": "beäugend",
    "beäugendem": "beäugend",
    "beäugenden": "beäugend",
    "beäugender": "beäugend",
    "beäugendere": "beäugend",
    "beäugenderem": "beäugend",
    "beäugenderen": "beäugend",
    "beäugenderer": "beäugend",
    "beäugenderes": "beäugend",
    "beäugendes": "beäugend",
    "beäugendste": "beäugend",
    "beäugendstem": "beäugend",
    "beäugendsten": "beäugend",
    "beäugendster": "beäugend",
    "beäugendstes": "beäugend",
    "beäugest": "beäugen",
    "beäuget": "beäugen",
    "beäugst": "beäugen",
    "beäugt": "beäugen",
    "beäugte": "beäugen",
    "beäugtem": "beäugt",
    "beäugten": "beäugen",
    "beäugter": "beäugt",
    "beäugtere": "beäugt",
    "beäugterem": "beäugt",
    "beäugteren": "beäugt",
    "beäugterer": "beäugt",
    "beäugteres": "beäugt",
    "beäugtes": "beäugt",
    "beäugtest": "beäugen",
    "beäugteste": "beäugt",
    "beäugtestem": "beäugt",
    "beäugtesten": "beäugt",
    "beäugtester": "beäugt",
    "beäugtestes": "beäugt",
    "beäugtet": "beäugen",
    "bibbere": "bibbern",
    "bibbernd": "bibbern",
    "bibbernde": "bibbernd",
    "bibberndem": "bibbernd",
    "bibbernden": "bibbernd",
    "bibbernder": "bibbernd",
    "bibberndere": "bibbernd",
    "bibbernderem": "bibbernd",
    "bibbernderen": "bibbernd",
    "bibbernderer": "bibbernd",
    "bibbernderes": "bibbernd",
    "bibberndes": "bibbernd",
    "bibberndste": "bibbernd",
    "bibberndstem": "bibbernd",
    "bibberndsten": "bibbernd",
    "bibberndster": "bibbernd",
    "bibberndstes": "bibbernd",
    "bibberst": "bibbern",
    "bibbert": "bibbern",
    "bibberte": "bibbern",
    "bibberten": "bibbern",
    "bibbertest": "bibbern",
    "bibbertet": "bibbern",
    "bibelfeste": "bibelfest",
    "bibelfestem": "bibelfest",
    "bibelfesten": "bibelfest",
    "bibelfester": "bibelfest",
    "bibelfestere": "bibelfest",
    "bibelfesterem": "bibelfest",
    "bibelfesteren": "bibelfest",
    "bibelfesterer": "bibelfest",
    "bibelfesteres": "bibelfest",
    "bibelfestes": "bibelfest",
    "bibelfesteste": "bibelfest",
    "bibelfestestem": "bibelfest",
    "bibelfestesten": "bibelfest",
    "bibelfestester": "bibelfest",
    "bibelfestestes": "bibelfest",
    "bibliographiere": "bibliographieren",
    "bibliographierend": "bibliographieren",
    "bibliographierende": "bibliographierend",
    "bibliographierendem": "bibliographierend",
    "bibliographierenden": "bibliographierend",
    "bibliographierender": "bibliographierend",
    "bibliographierendere": "bibliographierend",
    "bibliographierenderem": "bibliographierend",
    "bibliographierenderen": "bibliographierend",
    "bibliographierenderer": "bibliographierend",
    "bibliographierenderes": "bibliographierend",
    "bibliographierendes": "bibliographierend",
    "bibliographierendste": "bibliographierend",
    "bibliographierendstem": "bibliographierend",
    "bibliographierendsten": "bibliographierend",
    "bibliographierendster": "bibliographierend",
    "bibliographierendstes": "bibliographierend",
    "bibliographierest": "bibliographieren",
    "bibliographieret": "bibliographieren",
    "bibliographierst": "bibliographieren",
    "bibliographiert": "bibliographieren",
    "bibliographierte": "bibliographieren",
    "bibliographiertem": "bibliographiert",
    "bibliographierten": "bibliographieren",
    "bibliographierter": "bibliographiert",
    "bibliographiertere": "bibliographiert",
    "bibliographierterem": "bibliographiert",
    "bibliographierteren": "bibliographiert",
    "bibliographierterer": "bibliographiert",
    "bibliographierteres": "bibliographiert",
    "bibliographiertes": "bibliographiert",
    "bibliographiertest": "bibliographieren",
    "bibliographierteste": "bibliographiert",
    "bibliographiertestem": "bibliographiert",
    "bibliographiertesten": "bibliographiert",
    "bibliographiertester": "bibliographiert",
    "bibliographiertestes": "bibliographiert",
    "bibliographiertet": "bibliographieren",
    "bibliographische": "bibliographisch",
    "bibliographischem": "bibliographisch",
    "bibliographischen": "bibliographisch",
    "bibliographischer": "bibliographisch",
    "bibliographisches": "bibliographisch",
    "bieder": "biedern",
    "biedere": "bieder",
    "biederem": "bieder",
    "biederen": "bieder",
    "biederer": "bieder",
    "biederere": "bieder",
    "biedererem": "bieder",
    "biedereren": "bieder",
    "biedererer": "bieder",
    "biedereres": "bieder",
    "biederes": "bieder",
    "biedernd": "biedern",
    "biedernde": "biedernd",
    "biederndem": "biedernd",
    "biedernden": "biedernd",
    "biedernder": "biedernd",
    "biederndes": "biedernd",
    "biederst": "biedern",
    "biederste": "bieder",
    "biederstem": "bieder",
    "biedersten": "bieder",
    "biederster": "bieder",
    "biederstes": "bieder",
    "biedert": "biedern",
    "biederte": "biedern",
    "biederten": "biedern",
    "biedertest": "biedern",
    "biedertet": "biedern",
    "biegbare": "biegbar",
    "biegbarem": "biegbar",
    "biegbaren": "biegbar",
    "biegbarer": "biegbar",
    "biegbarere": "biegbar",
    "biegbarerem": "biegbar",
    "biegbareren": "biegbar",
    "biegbarerer": "biegbar",
    "biegbareres": "biegbar",
    "biegbares": "biegbar",
    "biegbarste": "biegbar",
    "biegbarstem": "biegbar",
    "biegbarsten": "biegbar",
    "biegbarster": "biegbar",
    "biegbarstes": "biegbar",
    "biege": "biegen",
    "biegend": "biegen",
    "biegende": "biegend",
    "biegendem": "biegend",
    "biegenden": "biegend",
    "biegender": "biegend",
    "biegendes": "biegend",
    "biegest": "biegen",
    "bieget": "biegen",
    "biegsame": "biegsam",
    "biegsamem": "biegsam",
    "biegsamen": "biegsam",
    "biegsamer": "biegsam",
    "biegsamere": "biegsam",
    "biegsamerem": "biegsam",
    "biegsameren": "biegsam",
    "biegsamerer": "biegsam",
    "biegsameres": "biegsam",
    "biegsames": "biegsam",
    "biegsamste": "biegsam",
    "biegsamstem": "biegsam",
    "biegsamsten": "biegsam",
    "biegsamster": "biegsam",
    "biegsamstes": "biegsam",
    "biegst": "biegen",
    "biegt": "biegen",
    "bierernstem": "bierernst",
    "bierernsten": "bierernst",
    "bierernster": "bierernst",
    "bierernstes": "bierernst",
    "biestigem": "biestig",
    "biestigen": "biestig",
    "biestiger": "biestig",
    "biestigere": "biestig",
    "biestigerem": "biestig",
    "biestigeren": "biestig",
    "biestigerer": "biestig",
    "biestigeres": "biestig",
    "biestiges": "biestig",
    "biestigste": "biestig",
    "biestigstem": "biestig",
    "biestigsten": "biestig",
    "biestigster": "biestig",
    "biestigstes": "biestig",
    "biete": "bieten",
    "bietend": "bieten",
    "bietende": "bietend",
    "bietendem": "bietend",
    "bietenden": "bietend",
    "bietender": "bietend",
    "bietendes": "bietend",
    "bietest": "bieten",
    "bietet": "bieten",
    "bilanziere": "bilanzieren",
    "bilanzierend": "bilanzieren",
    "bilanzierende": "bilanzierend",
    "bilanzierendem": "bilanzierend",
    "bilanzierenden": "bilanzierend",
    "bilanzierender": "bilanzierend",
    "bilanzierendere": "bilanzierend",
    "bilanzierenderem": "bilanzierend",
    "bilanzierenderen": "bilanzierend",
    "bilanzierenderer": "bilanzierend",
    "bilanzierenderes": "bilanzierend",
    "bilanzierendes": "bilanzierend",
    "bilanzierendste": "bilanzierend",
    "bilanzierendstem": "bilanzierend",
    "bilanzierendsten": "bilanzierend",
    "bilanzierendster": "bilanzierend",
    "bilanzierendstes": "bilanzierend",
    "bilanzierest": "bilanzieren",
    "bilanzieret": "bilanzieren",
    "bilanzierst": "bilanzieren",
    "bilanziert": "bilanzieren",
    "bilanzierte": "bilanzieren",
    "bilanziertem": "bilanziert",
    "bilanzierten": "bilanzieren",
    "bilanzierter": "bilanziert",
    "bilanziertere": "bilanziert",
    "bilanzierterem": "bilanziert",
    "bilanzierteren": "bilanziert",
    "bilanzierterer": "bilanziert",
    "bilanzierteres": "bilanziert",
    "bilanziertes": "bilanziert",
    "bilanziertest": "bilanzieren",
    "bilanzierteste": "bilanziert",
    "bilanziertestem": "bilanziert",
    "bilanziertesten": "bilanziert",
    "bilanziertester": "bilanziert",
    "bilanziertestes": "bilanziert",
    "bilanziertet": "bilanzieren",
    "bilaterale": "bilateral",
    "bilateralem": "bilateral",
    "bilateralen": "bilateral",
    "bilateraler": "bilateral",
    "bilaterales": "bilateral",
    "bildend": "bilden",
    "bildende": "bildend",
    "bildendem": "bildend",
    "bildenden": "bildend",
    "bildender": "bildend",
    "bildendes": "bildend",
    "bilderreichem": "bilderreich",
    "bilderreichen": "bilderreich",
    "bilderreicher": "bilderreich",
    "bilderreichere": "bilderreich",
    "bilderreicherem": "bilderreich",
    "bilderreicheren": "bilderreich",
    "bilderreicherer": "bilderreich",
    "bilderreicheres": "bilderreich",
    "bilderreiches": "bilderreich",
    "bilderreichste": "bilderreich",
    "bilderreichstem": "bilderreich",
    "bilderreichsten": "bilderreich",
    "bilderreichster": "bilderreich",
    "bilderreichstes": "bilderreich",
    "bildest": "bilden",
    "bildet": "bilden",
    "bildete": "bilden",
    "bildeten": "bilden",
    "bildetest": "bilden",
    "bildetet": "bilden",
    "bildhafte": "bildhaft",
    "bildhaftem": "bildhaft",
    "bildhaften": "bildhaft",
    "bildhafter": "bildhaft",
    "bildhaftes": "bildhaft",
    "bildhauere": "bildhauern",
    "bildhauerische": "bildhauerisch",
    "bildhauerischem": "bildhauerisch",
    "bildhauerischen": "bildhauerisch",
    "bildhauerischer": "bildhauerisch",
    "bildhauerisches": "bildhauerisch",
    "bildhauernd": "bildhauern",
    "bildhauernde": "bildhauernd",
    "bildhauerndem": "bildhauernd",
    "bildhauernden": "bildhauernd",
    "bildhauernder": "bildhauernd",
    "bildhauerndes": "bildhauernd",
    "bildhauerst": "bildhauern",
    "bildhauert": "bildhauern",
    "bildhauerte": "bildhauern",
    "bildhauerten": "bildhauern",
    "bildhauertest": "bildhauern",
    "bildhauertet": "bildhauern",
    "bildhübsche": "bildhübsch",
    "bildhübschem": "bildhübsch",
    "bildhübschen": "bildhübsch",
    "bildhübscher": "bildhübsch",
    "bildhübsches": "bildhübsch",
    "bildschönem": "bildschön",
    "bildschönen": "bildschön",
    "bildschöner": "bildschön",
    "bildschönere": "bildschön",
    "bildschönerem": "bildschön",
    "bildschöneren": "bildschön",
    "bildschönerer": "bildschön",
    "bildschöneres": "bildschön",
    "bildschönes": "bildschön",
    "bildschönste": "bildschön",
    "bildschönstem": "bildschön",
    "bildschönsten": "bildschön",
    "bildschönster": "bildschön",
    "bildschönstes": "bildschön",
    "bildungsfähigem": "bildungsfähig",
    "bildungsfähigen": "bildungsfähig",
    "bildungsfähiger": "bildungsfähig",
    "bildungsfähiges": "bildungsfähig",
    "bildungshungrige": "bildungshungrig",
    "bildungshungrigem": "bildungshungrig",
    "bildungshungrigen": "bildungshungrig",
    "bildungshungriger": "bildungshungrig",
    "bildungshungrigere": "bildungshungrig",
    "bildungshungrigerem": "bildungshungrig",
    "bildungshungrigeren": "bildungshungrig",
    "bildungshungrigerer": "bildungshungrig",
    "bildungshungrigeres": "bildungshungrig",
    "bildungshungriges": "bildungshungrig",
    "bildungshungrigste": "bildungshungrig",
    "bildungshungrigstem": "bildungshungrig",
    "bildungshungrigsten": "bildungshungrig",
    "bildungshungrigster": "bildungshungrig",
    "bildungshungrigstes": "bildungshungrig",
    "bildungspolitische": "bildungspolitisch",
    "bildungspolitischem": "bildungspolitisch",
    "bildungspolitischen": "bildungspolitisch",
    "bildungspolitischer": "bildungspolitisch",
    "bildungspolitisches": "bildungspolitisch",
    "bilingualem": "bilingual",
    "bilingualen": "bilingual",
    "bilingualer": "bilingual",
    "bilinguales": "bilingual",
    "billig": "billigen",
    "billige": "billig",
    "billigem": "billig",
    "billigen": "billig",
    "billigend": "billigen",
    "billigende": "billigend",
    "billigendem": "billigend",
    "billigenden": "billigend",
    "billigender": "billigend",
    "billigendes": "billigend",
    "billiger": "billig",
    "billigere": "billig",
    "billigerem": "billig",
    "billigeren": "billig",
    "billigerer": "billig",
    "billigeres": "billig",
    "billiges": "billig",
    "billigest": "billigen",
    "billiget": "billigen",
    "billigst": "billigen",
    "billigste": "billig",
    "billigstem": "billig",
    "billigsten": "billig",
    "billigster": "billig",
    "billigstes": "billig",
    "billigt": "billigen",
    "billigte": "billigen",
    "billigten": "billigen",
    "billigtest": "billigen",
    "billigtet": "billigen",
    "bimmele": "bimmeln",
    "bimmelnd": "bimmeln",
    "bimmelnde": "bimmelnd",
    "bimmelndem": "bimmelnd",
    "bimmelnden": "bimmelnd",
    "bimmelnder": "bimmelnd",
    "bimmelndere": "bimmelnd",
    "bimmelnderem": "bimmelnd",
    "bimmelnderen": "bimmelnd",
    "bimmelnderer": "bimmelnd",
    "bimmelnderes": "bimmelnd",
    "bimmelndes": "bimmelnd",
    "bimmelndste": "bimmelnd",
    "bimmelndstem": "bimmelnd",
    "bimmelndsten": "bimmelnd",
    "bimmelndster": "bimmelnd",
    "bimmelndstes": "bimmelnd",
    "bimmelst": "bimmeln",
    "bimmelt": "bimmeln",
    "bimmelte": "bimmeln",
    "bimmelten": "bimmeln",
    "bimmeltest": "bimmeln",
    "bimmeltet": "bimmeln",
    "bimmle": "bimmeln",
    "bimse": "bimsen",
    "bimsend": "bimsen",
    "bimsende": "bimsend",
    "bimsendem": "bimsend",
    "bimsenden": "bimsend",
    "bimsender": "bimsend",
    "bimsendere": "bimsend",
    "bimsenderem": "bimsend",
    "bimsenderen": "bimsend",
    "bimsenderer": "bimsend",
    "bimsenderes": "bimsend",
    "bimsendes": "bimsend",
    "bimsendste": "bimsend",
    "bimsendstem": "bimsend",
    "bimsendsten": "bimsend",
    "bimsendster": "bimsend",
    "bimsendstes": "bimsend",
    "bimsest": "bimsen",
    "bimset": "bimsen",
    "bimst": "bimsen",
    "bimste": "bimsen",
    "bimsten": "bimsen",
    "bimstest": "bimsen",
    "bimstet": "bimsen",
    "bin": "sein",
    "bindend": "binden",
    "bindende": "bindend",
    "bindendem": "bindend",
    "bindenden": "bindend",
    "bindender": "bindend",
    "bindendes": "bindend",
    "bindest": "binden",
    "bindet": "binden",
    "binomischem": "binomisch",
    "binomischen": "binomisch",
    "binomischer": "binomisch",
    "binomisches": "binomisch",
    "biochemischem": "biochemisch",
    "biochemischen": "biochemisch",
    "biochemischer": "biochemisch",
    "biochemisches": "biochemisch",
    "biogenetischem": "biogenetisch",
    "biogenetischen": "biogenetisch",
    "biogenetischer": "biogenetisch",
    "biogenetisches": "biogenetisch",
    "biographischem": "biographisch",
    "biographischen": "biographisch",
    "biographischer": "biographisch",
    "biographisches": "biographisch",
    "biologischem": "biologisch",
    "biologischen": "biologisch",
    "biologischer": "biologisch",
    "biologisches": "biologisch",
    "biologisiere": "biologisieren",
    "biologisierend": "biologisieren",
    "biologisierende": "biologisierend",
    "biologisierendem": "biologisierend",
    "biologisierenden": "biologisierend",
    "biologisierender": "biologisierend",
    "biologisierendes": "biologisierend",
    "biologisierest": "biologisieren",
    "biologisieret": "biologisieren",
    "biologisierst": "biologisieren",
    "biologisiert": "biologisieren",
    "biologisierte": "biologisieren",
    "biologisiertem": "biologisiert",
    "biologisierten": "biologisieren",
    "biologisierter": "biologisiert",
    "biologisiertes": "biologisiert",
    "biologisiertest": "biologisieren",
    "biologisiertet": "biologisieren",
    "biophysikalischem": "biophysikalisch",
    "biophysikalischen": "biophysikalisch",
    "biophysikalischer": "biophysikalisch",
    "biophysikalisches": "biophysikalisch",
    "biotechnischem": "biotechnisch",
    "biotechnischen": "biotechnisch",
    "biotechnischer": "biotechnisch",
    "biotechnisches": "biotechnisch",
    "birg": "bergen",
    "birgst": "bergen",
    "birgt": "bergen",
    "birkenem": "birken",
    "birkenen": "birken",
    "birkener": "birken",
    "birkenes": "birken",
    "birst": "bersten",
    "bischöflichem": "bischöflich",
    "bischöflichen": "bischöflich",
    "bischöflicher": "bischöflich",
    "bischöfliches": "bischöflich",
    "bisexuellem": "bisexuell",
    "bisexuellen": "bisexuell",
    "bisexueller": "bisexuell",
    "bisexuelles": "bisexuell",
    "bisherige": "bisherig",
    "bisherigem": "bisherig",
    "bisherigen": "bisherig",
    "bisheriger": "bisherig",
    "bisheriges": "bisherig",
    "bisse": "beißen",
    "bissen": "beißen",
    "bissest": "beißen",
    "bisset": "beißen",
    "bissige": "bissig",
    "bissigem": "bissig",
    "bissigen": "bissig",
    "bissiger": "bissig",
    "bissigere": "bissig",
    "bissigerem": "bissig",
    "bissigeren": "bissig",
    "bissigerer": "bissig",
    "bissigeres": "bissig",
    "bissiges": "bissig",
    "bissigste": "bissig",
    "bissigstem": "bissig",
    "bissigsten": "bissig",
    "bissigster": "bissig",
    "bissigstes": "bissig",
    "bist": "sein",
    "bittend": "bitten",
    "bittende": "bittend",
    "bittendem": "bittend",
    "bittenden": "bittend",
    "bittender": "bittend",
    "bittendes": "bittend",
    "bitterbösem": "bitterböse",
    "bitterbösen": "bitterböse",
    "bitterböser": "bitterböse",
    "bitterbösere": "bitterböse",
    "bitterböserem": "bitterböse",
    "bitterböseren": "bitterböse",
    "bitterböserer": "bitterböse",
    "bitterböseres": "bitterböse",
    "bitterböses": "bitterböse",
    "bitterböseste": "bitterböse",
    "bitterbösestem": "bitterböse",
    "bitterbösesten": "bitterböse",
    "bitterbösester": "bitterböse",
    "bitterbösestes": "bitterböse",
    "bittere": "bitter",
    "bitterem": "bitter",
    "bitteren": "bitter",
    "bitterer": "bitter",
    "bitterere": "bitter",
    "bittererem": "bitter",
    "bittereren": "bitter",
    "bittererer": "bitter",
    "bittereres": "bitter",
    "bitteres": "bitter",
    "bitterstem": "bitter",
    "bittersten": "bitter",
    "bitterster": "bitter",
    "bitterstes": "bitter",
    "bittersüße": "bittersüß",
    "bittersüßem": "bittersüß",
    "bittersüßen": "bittersüß",
    "bittersüßer": "bittersüß",
    "bittersüßere": "bittersüß",
    "bittersüßerem": "bittersüß",
    "bittersüßeren": "bittersüß",
    "bittersüßerer": "bittersüß",
    "bittersüßeres": "bittersüß",
    "bittersüßes": "bittersüß",
    "bittersüßeste": "bittersüß",
    "bittersüßestem": "bittersüß",
    "bittersüßesten": "bittersüß",
    "bittersüßester": "bittersüß",
    "bittersüßestes": "bittersüß",
    "bittest": "bitten",
    "bittet": "bitten",
    "bizarrem": "bizarr",
    "bizarren": "bizarr",
    "bizarrer": "bizarr",
    "bizarrere": "bizarr",
    "bizarrerem": "bizarr",
    "bizarreren": "bizarr",
    "bizarrerer": "bizarr",
    "bizarreres": "bizarr",
    "bizarres": "bizarr",
    "bizarrste": "bizarr",
    "bizarrstem": "bizarr",
    "bizarrsten": "bizarr",
    "bizarrster": "bizarr",
    "bizarrstes": "bizarr",
    "biß": "beißen",
    "bißt": "beißen",
    "blaffe": "blaffen",
    "blaffend": "blaffen",
    "blaffende": "blaffend",
    "blaffendem": "blaffend",
    "blaffenden": "blaffend",
    "blaffender": "blaffend",
    "blaffendere": "blaffend",
    "blaffenderem": "blaffend",
    "blaffenderen": "blaffend",
    "blaffenderer": "blaffend",
    "blaffenderes": "blaffend",
    "blaffendes": "blaffend",
    "blaffendste": "blaffend",
    "blaffendstem": "blaffend",
    "blaffendsten": "blaffend",
    "blaffendster": "blaffend",
    "blaffendstes": "blaffend",
    "blaffest": "blaffen",
    "blaffet": "blaffen",
    "blaffst": "blaffen",
    "blafft": "blaffen",
    "blaffte": "blaffen",
    "blafften": "blaffen",
    "blafftest": "blaffen",
    "blafftet": "blaffen",
    "blamabelstem": "blamabel",
    "blamabelsten": "blamabel",
    "blamabelster": "blamabel",
    "blamabelstes": "blamabel",
    "blamable": "blamabel",
    "blamablem": "blamabel",
    "blamablen": "blamabel",
    "blamabler": "blamabel",
    "blamablere": "blamabel",
    "blamablerem": "blamabel",
    "blamableren": "blamabel",
    "blamablerer": "blamabel",
    "blamableres": "blamabel",
    "blamables": "blamabel",
    "blamiere": "blamieren",
    "blamierend": "blamieren",
    "blamierende": "blamierend",
    "blamierendem": "blamierend",
    "blamierenden": "blamierend",
    "blamierender": "blamierend",
    "blamierendere": "blamierend",
    "blamierenderem": "blamierend",
    "blamierenderen": "blamierend",
    "blamierenderer": "blamierend",
    "blamierenderes": "blamierend",
    "blamierendes": "blamierend",
    "blamierendste": "blamierend",
    "blamierendstem": "blamierend",
    "blamierendsten": "blamierend",
    "blamierendster": "blamierend",
    "blamierendstes": "blamierend",
    "blamierest": "blamieren",
    "blamieret": "blamieren",
    "blamierst": "blamieren",
    "blamiert": "blamieren",
    "blamierte": "blamieren",
    "blamiertem": "blamiert",
    "blamierten": "blamieren",
    "blamierter": "blamiert",
    "blamiertere": "blamiert",
    "blamierterem": "blamiert",
    "blamierteren": "blamiert",
    "blamierterer": "blamiert",
    "blamierteres": "blamiert",
    "blamiertes": "blamiert",
    "blamiertest": "blamieren",
    "blamierteste": "blamiert",
    "blamiertestem": "blamiert",
    "blamiertesten": "blamiert",
    "blamiertester": "blamiert",
    "blamiertestes": "blamiert",
    "blamiertet": "blamieren",
    "blanke": "blank",
    "blankem": "blank",
    "blanken": "blank",
    "blanker": "blank",
    "blankere": "blank",
    "blankerem": "blank",
    "blankeren": "blank",
    "blankerer": "blank",
    "blankeres": "blank",
    "blankes": "blank",
    "blankeste": "blank",
    "blankestem": "blank",
    "blankesten": "blank",
    "blankester": "blank",
    "blankestes": "blank",
    "blasend": "blasen",
    "blasende": "blasend",
    "blasendem": "blasend",
    "blasenden": "blasend",
    "blasender": "blasend",
    "blasendes": "blasend",
    "blasest": "blasen",
    "blaset": "blasen",
    "blasierte": "blasiert",
    "blasiertem": "blasiert",
    "blasierten": "blasiert",
    "blasierter": "blasiert",
    "blasiertere": "blasiert",
    "blasierterem": "blasiert",
    "blasierteren": "blasiert",
    "blasierterer": "blasiert",
    "blasierteres": "blasiert",
    "blasiertes": "blasiert",
    "blasierteste": "blasiert",
    "blasiertestem": "blasiert",
    "blasiertesten": "blasiert",
    "blasiertester": "blasiert",
    "blasiertestes": "blasiert",
    "blasphemischem": "blasphemisch",
    "blasphemischen": "blasphemisch",
    "blasphemischer": "blasphemisch",
    "blasphemischere": "blasphemisch",
    "blasphemischerem": "blasphemisch",
    "blasphemischeren": "blasphemisch",
    "blasphemischerer": "blasphemisch",
    "blasphemischeres": "blasphemisch",
    "blasphemisches": "blasphemisch",
    "blasphemischste": "blasphemisch",
    "blasphemischstem": "blasphemisch",
    "blasphemischsten": "blasphemisch",
    "blasphemischster": "blasphemisch",
    "blasphemischstes": "blasphemisch",
    "blasse": "blaß",
    "blassem": "blaß",
    "blassen": "blaß",
    "blassend": "blassen",
    "blassende": "blassend",
    "blassendem": "blassend",
    "blassenden": "blassend",
    "blassender": "blassend",
    "blassendes": "blassend",
    "blasser": "blaß",
    "blassere": "blaß",
    "blasserem": "blaß",
    "blasseren": "blaß",
    "blasserer": "blaß",
    "blasseres": "blaß",
    "blasses": "blaß",
    "blassest": "blassen",
    "blasseste": "blaß",
    "blassestem": "blaß",
    "blassesten": "blaß",
    "blassester": "blaß",
    "blassestes": "blaß",
    "blasset": "blassen",
    "blast": "blasen",
    "blattlosem": "blattlos",
    "blattlosen": "blattlos",
    "blattloser": "blattlos",
    "blattlosere": "blattlos",
    "blattloserem": "blattlos",
    "blattloseren": "blattlos",
    "blattloserer": "blattlos",
    "blattloseres": "blattlos",
    "blattloses": "blattlos",
    "blattloseste": "blattlos",
    "blattlosestem": "blattlos",
    "blattlosesten": "blattlos",
    "blattlosester": "blattlos",
    "blattlosestes": "blattlos",
    "blattweisem": "blattweise",
    "blattweisen": "blattweise",
    "blattweiser": "blattweise",
    "blattweisere": "blattweise",
    "blattweiserem": "blattweise",
    "blattweiseren": "blattweise",
    "blattweiserer": "blattweise",
    "blattweiseres": "blattweise",
    "blattweises": "blattweise",
    "blattweiseste": "blattweise",
    "blattweisestem": "blattweise",
    "blattweisesten": "blattweise",
    "blattweisester": "blattweise",
    "blattweisestes": "blattweise",
    "blaublütigem": "blaublütig",
    "blaublütigen": "blaublütig",
    "blaublütiger": "blaublütig",
    "blaublütigere": "blaublütig",
    "blaublütigerem": "blaublütig",
    "blaublütigeren": "blaublütig",
    "blaublütigerer": "blaublütig",
    "blaublütigeres": "blaublütig",
    "blaublütiges": "blaublütig",
    "blaublütigste": "blaublütig",
    "blaublütigstem": "blaublütig",
    "blaublütigsten": "blaublütig",
    "blaublütigster": "blaublütig",
    "blaublütigstes": "blaublütig",
    "blaue": "blau",
    "blauem": "blau",
    "blauen": "blau",
    "blauer": "blau",
    "blaues": "blau",
    "blaustichige": "blaustichig",
    "blaustichigem": "blaustichig",
    "blaustichigen": "blaustichig",
    "blaustichiger": "blaustichig",
    "blaustichigere": "blaustichig",
    "blaustichigerem": "blaustichig",
    "blaustichigeren": "blaustichig",
    "blaustichigerer": "blaustichig",
    "blaustichigeres": "blaustichig",
    "blaustichiges": "blaustichig",
    "blaustichigste": "blaustichig",
    "blaustichigstem": "blaustichig",
    "blaustichigsten": "blaustichig",
    "blaustichigster": "blaustichig",
    "blaustichigstes": "blaustichig",
    "blauäugigem": "blauäugig",
    "blauäugigen": "blauäugig",
    "blauäugiger": "blauäugig",
    "blauäugigere": "blauäugig",
    "blauäugigerem": "blauäugig",
    "blauäugigeren": "blauäugig",
    "blauäugigerer": "blauäugig",
    "blauäugigeres": "blauäugig",
    "blauäugiges": "blauäugig",
    "blauäugigste": "blauäugig",
    "blauäugigstem": "blauäugig",
    "blauäugigsten": "blauäugig",
    "blauäugigster": "blauäugig",
    "blauäugigstes": "blauäugig",
    "blaß": "blassen",
    "blaßt": "blassen",
    "blaßte": "blassen",
    "blaßten": "blassen",
    "blaßtest": "blassen",
    "blaßtet": "blassen",
    "blechend": "blechen",
    "blechende": "blechend",
    "blechendem": "blechend",
    "blechenden": "blechend",
    "blechender": "blechend",
    "blechendes": "blechend",
    "blechernem": "blechern",
    "blechernen": "blechern",
    "blecherner": "blechern",
    "blechernere": "blechern",
    "blechernerem": "blechern",
    "blecherneren": "blechern",
    "blechernerer": "blechern",
    "blecherneres": "blechern",
    "blechernes": "blechern",
    "blechernste": "blechern",
    "blechernstem": "blechern",
    "blechernsten": "blechern",
    "blechernster": "blechern",
    "blechernstes": "blechern",
    "blechest": "blechen",
    "blechet": "blechen",
    "blechst": "blechen",
    "blecht": "blechen",
    "blechte": "blechen",
    "blechten": "blechen",
    "blechtest": "blechen",
    "blechtet": "blechen",
    "bleibe": "bleiben",
    "bleibend": "bleiben",
    "bleibende": "bleibend",
    "bleibendem": "bleibend",
    "bleibenden": "bleibend",
    "bleibender": "bleibend",
    "bleibendes": "bleibend",
    "bleibengelassen": "bleibenlassen",
    "bleibengelassene": "bleibengelassen",
    "bleibengelassenem": "bleibengelassen",
    "bleibengelassenen": "bleibengelassen",
    "bleibengelassener": "bleibengelassen",
    "bleibengelassenes": "bleibengelassen",
    "bleibenlasse": "bleibenlassen",
    "bleibenlassend": "bleibenlassen",
    "bleibenlassende": "bleibenlassend",
    "bleibenlassendem": "bleibenlassend",
    "bleibenlassenden": "bleibenlassend",
    "bleibenlassender": "bleibenlassend",
    "bleibenlassendes": "bleibenlassend",
    "bleibenlassest": "bleibenlassen",
    "bleibenlasset": "bleibenlassen",
    "bleibenlaßt": "bleibenlassen",
    "bleibenließ": "bleibenlassen",
    "bleibenließe": "bleibenlassen",
    "bleibenließen": "bleibenlassen",
    "bleibenließest": "bleibenlassen",
    "bleibenließet": "bleibenlassen",
    "bleibenließt": "bleibenlassen",
    "bleibenläßt": "bleibenlassen",
    "bleibenzulassen": "bleibenlassen",
    "bleibest": "bleiben",
    "bleibet": "bleiben",
    "bleibst": "bleiben",
    "bleibt": "bleiben",
    "bleiche": "bleichen",
    "bleichend": "bleichen",
    "bleichende": "bleichend",
    "bleichendem": "bleichend",
    "bleichenden": "bleichend",
    "bleichender": "bleichend",
    "bleichendes": "bleichend",
    "bleichest": "bleichen",
    "bleichet": "bleichen",
    "bleichst": "bleichen",
    "bleicht": "bleichen",
    "bleiernem": "bleiern",
    "bleiernen": "bleiern",
    "bleierner": "bleiern",
    "bleiernere": "bleiern",
    "bleiernerem": "bleiern",
    "bleierneren": "bleiern",
    "bleiernerer": "bleiern",
    "bleierneres": "bleiern",
    "bleiernes": "bleiern",
    "bleiernste": "bleiern",
    "bleiernstem": "bleiern",
    "bleiernsten": "bleiern",
    "bleiernster": "bleiern",
    "bleiernstes": "bleiern",
    "bleifreie": "bleifrei",
    "bleifreiem": "bleifrei",
    "bleifreien": "bleifrei",
    "bleifreier": "bleifrei",
    "bleifreiere": "bleifrei",
    "bleifreierem": "bleifrei",
    "bleifreieren": "bleifrei",
    "bleifreierer": "bleifrei",
    "bleifreieres": "bleifrei",
    "bleifreies": "bleifrei",
    "bleifreieste": "bleifrei",
    "bleifreiestem": "bleifrei",
    "bleifreiesten": "bleifrei",
    "bleifreiester": "bleifrei",
    "bleifreiestes": "bleifrei",
    "bleihaltigem": "bleihaltig",
    "bleihaltigen": "bleihaltig",
    "bleihaltiger": "bleihaltig",
    "bleihaltigere": "bleihaltig",
    "bleihaltigerem": "bleihaltig",
    "bleihaltigeren": "bleihaltig",
    "bleihaltigerer": "bleihaltig",
    "bleihaltigeres": "bleihaltig",
    "bleihaltiges": "bleihaltig",
    "bleihaltigste": "bleihaltig",
    "bleihaltigstem": "bleihaltig",
    "bleihaltigsten": "bleihaltig",
    "bleihaltigster": "bleihaltig",
    "bleihaltigstes": "bleihaltig",
    "blendend": "blenden",
    "blendende": "blendend",
    "blendendem": "blendend",
    "blendenden": "blendend",
    "blendender": "blendend",
    "blendendere": "blendend",
    "blendenderem": "blendend",
    "blendenderen": "blendend",
    "blendenderer": "blendend",
    "blendenderes": "blendend",
    "blendendes": "blendend",
    "blendendste": "blendend",
    "blendendstem": "blendend",
    "blendendsten": "blendend",
    "blendendster": "blendend",
    "blendendstes": "blendend",
    "blendest": "blenden",
    "blendet": "blenden",
    "blendete": "blenden",
    "blendeten": "blenden",
    "blendetest": "blenden",
    "blendetet": "blenden",
    "bleue": "bleuen",
    "bleuend": "bleuen",
    "bleuende": "bleuend",
    "bleuendem": "bleuend",
    "bleuenden": "bleuend",
    "bleuender": "bleuend",
    "bleuendes": "bleuend",
    "bleuest": "bleuen",
    "bleuet": "bleuen",
    "bleust": "bleuen",
    "bleut": "bleuen",
    "bleute": "bleuen",
    "bleuten": "bleuen",
    "bleutest": "bleuen",
    "bleutet": "bleuen",
    "blich": "bleichen",
    "bliche": "bleichen",
    "blichen": "bleichen",
    "blichest": "bleichen",
    "blichet": "bleichen",
    "blichst": "bleichen",
    "blicht": "bleichen",
    "blickend": "blicken",
    "blickende": "blickend",
    "blickendem": "blickend",
    "blickenden": "blickend",
    "blickender": "blickend",
    "blickendes": "blickend",
    "blickest": "blicken",
    "blicket": "blicken",
    "blickst": "blicken",
    "blickt": "blicken",
    "blickte": "blicken",
    "blickten": "blicken",
    "blicktest": "blicken",
    "blicktet": "blicken",
    "blieb": "bleiben",
    "bliebe": "bleiben",
    "blieben": "bleiben",
    "bliebest": "bleiben",
    "bliebet": "bleiben",
    "bliebst": "bleiben",
    "bliebt": "bleiben",
    "blies": "blasen",
    "bliese": "blasen",
    "bliesen": "blasen",
    "bliesest": "blasen",
    "blieset": "blasen",
    "bliest": "blasen",
    "blindem": "blind",
    "blinden": "blind",
    "blinder": "blind",
    "blindere": "blind",
    "blinderem": "blind",
    "blinderen": "blind",
    "blinderer": "blind",
    "blinderes": "blind",
    "blindes": "blind",
    "blindeste": "blind",
    "blindestem": "blind",
    "blindesten": "blind",
    "blindester": "blind",
    "blindestes": "blind",
    "blindfliege": "blindfliegen",
    "blindfliegend": "blindfliegen",
    "blindfliegende": "blindfliegend",
    "blindfliegendem": "blindfliegend",
    "blindfliegenden": "blindfliegend",
    "blindfliegender": "blindfliegend",
    "blindfliegendes": "blindfliegend",
    "blindfliegest": "blindfliegen",
    "blindflieget": "blindfliegen",
    "blindfliegst": "blindfliegen",
    "blindfliegt": "blindfliegen",
    "blindflog": "blindfliegen",
    "blindflogen": "blindfliegen",
    "blindflogst": "blindfliegen",
    "blindflogt": "blindfliegen",
    "blindflöge": "blindfliegen",
    "blindflögen": "blindfliegen",
    "blindflögest": "blindfliegen",
    "blindflöget": "blindfliegen",
    "blindgeflogen": "blindfliegen",
    "blindgeflogene": "blindgeflogen",
    "blindgeflogenem": "blindgeflogen",
    "blindgeflogenen": "blindgeflogen",
    "blindgeflogener": "blindgeflogen",
    "blindgeflogenes": "blindgeflogen",
    "blindzufliegen": "blindfliegen",
    "blinke": "blinken",
    "blinkend": "blinken",
    "blinkende": "blinkend",
    "blinkendem": "blinkend",
    "blinkenden": "blinkend",
    "blinkender": "blinkend",
    "blinkendere": "blinkend",
    "blinkenderem": "blinkend",
    "blinkenderen": "blinkend",
    "blinkenderer": "blinkend",
    "blinkenderes": "blinkend",
    "blinkendes": "blinkend",
    "blinkendste": "blinkend",
    "blinkendstem": "blinkend",
    "blinkendsten": "blinkend",
    "blinkendster": "blinkend",
    "blinkendstes": "blinkend",
    "blinkest": "blinken",
    "blinket": "blinken",
    "blinkst": "blinken",
    "blinkt": "blinken",
    "blinkte": "blinken",
    "blinkten": "blinken",
    "blinktest": "blinken",
    "blinktet": "blinken",
    "blinzele": "blinzeln",
    "blinzelnd": "blinzeln",
    "blinzelnde": "blinzelnd",
    "blinzelndem": "blinzelnd",
    "blinzelnden": "blinzelnd",
    "blinzelnder": "blinzelnd",
    "blinzelndere": "blinzelnd",
    "blinzelnderem": "blinzelnd",
    "blinzelnderen": "blinzelnd",
    "blinzelnderer": "blinzelnd",
    "blinzelnderes": "blinzelnd",
    "blinzelndes": "blinzelnd",
    "blinzelndste": "blinzelnd",
    "blinzelndstem": "blinzelnd",
    "blinzelndsten": "blinzelnd",
    "blinzelndster": "blinzelnd",
    "blinzelndstes": "blinzelnd",
    "blinzelst": "blinzeln",
    "blinzelt": "blinzeln",
    "blinzelte": "blinzeln",
    "blinzelten": "blinzeln",
    "blinzeltest": "blinzeln",
    "blinzeltet": "blinzeln",
    "blinzle": "blinzeln",
    "blitzartigem": "blitzartig",
    "blitzartigen": "blitzartig",
    "blitzartiger": "blitzartig",
    "blitzartigere": "blitzartig",
    "blitzartigerem": "blitzartig",
    "blitzartigeren": "blitzartig",
    "blitzartigerer": "blitzartig",
    "blitzartigeres": "blitzartig",
    "blitzartiges": "blitzartig",
    "blitzartigste": "blitzartig",
    "blitzartigstem": "blitzartig",
    "blitzartigsten": "blitzartig",
    "blitzartigster": "blitzartig",
    "blitzartigstes": "blitzartig",
    "blitzblanke": "blitzblank",
    "blitzblankem": "blitzblank",
    "blitzblanken": "blitzblank",
    "blitzblanker": "blitzblank",
    "blitzblankere": "blitzblank",
    "blitzblankerem": "blitzblank",
    "blitzblankeren": "blitzblank",
    "blitzblankerer": "blitzblank",
    "blitzblankeres": "blitzblank",
    "blitzblankes": "blitzblank",
    "blitzblankeste": "blitzblank",
    "blitzblankestem": "blitzblank",
    "blitzblankesten": "blitzblank",
    "blitzblankester": "blitzblank",
    "blitzblankestes": "blitzblank",
    "blitzend": "blitzen",
    "blitzende": "blitzend",
    "blitzendem": "blitzend",
    "blitzenden": "blitzend",
    "blitzender": "blitzend",
    "blitzendes": "blitzend",
    "blitzest": "blitzen",
    "blitzet": "blitzen",
    "blitzgescheite": "blitzgescheit",
    "blitzgescheitem": "blitzgescheit",
    "blitzgescheiten": "blitzgescheit",
    "blitzgescheiter": "blitzgescheit",
    "blitzgescheitere": "blitzgescheit",
    "blitzgescheiterem": "blitzgescheit",
    "blitzgescheiteren": "blitzgescheit",
    "blitzgescheiterer": "blitzgescheit",
    "blitzgescheiteres": "blitzgescheit",
    "blitzgescheites": "blitzgescheit",
    "blitzgescheiteste": "blitzgescheit",
    "blitzgescheitestem": "blitzgescheit",
    "blitzgescheitesten": "blitzgescheit",
    "blitzgescheitester": "blitzgescheit",
    "blitzgescheitestes": "blitzgescheit",
    "blitzsauberem": "blitzsauber",
    "blitzsauberen": "blitzsauber",
    "blitzsauberer": "blitzsauber",
    "blitzsauberere": "blitzsauber",
    "blitzsaubererem": "blitzsauber",
    "blitzsaubereren": "blitzsauber",
    "blitzsaubererer": "blitzsauber",
    "blitzsaubereres": "blitzsauber",
    "blitzsauberes": "blitzsauber",
    "blitzsauberste": "blitzsauber",
    "blitzsauberstem": "blitzsauber",
    "blitzsaubersten": "blitzsauber",
    "blitzsauberster": "blitzsauber",
    "blitzsauberstes": "blitzsauber",
    "blitzschnelle": "blitzschnell",
    "blitzschnellem": "blitzschnell",
    "blitzschnellen": "blitzschnell",
    "blitzschneller": "blitzschnell",
    "blitzschnellere": "blitzschnell",
    "blitzschnellerem": "blitzschnell",
    "blitzschnelleren": "blitzschnell",
    "blitzschnellerer": "blitzschnell",
    "blitzschnelleres": "blitzschnell",
    "blitzschnelles": "blitzschnell",
    "blitzschnellste": "blitzschnell",
    "blitzschnellstem": "blitzschnell",
    "blitzschnellsten": "blitzschnell",
    "blitzschnellster": "blitzschnell",
    "blitzschnellstes": "blitzschnell",
    "blitzt": "blitzen",
    "blitzte": "blitzen",
    "blitzten": "blitzen",
    "blitztest": "blitzen",
    "blitztet": "blitzen",
    "blockiere": "blockieren",
    "blockierend": "blockieren",
    "blockierende": "blockierend",
    "blockierendem": "blockierend",
    "blockierenden": "blockierend",
    "blockierender": "blockierend",
    "blockierendere": "blockierend",
    "blockierenderem": "blockierend",
    "blockierenderen": "blockierend",
    "blockierenderer": "blockierend",
    "blockierenderes": "blockierend",
    "blockierendes": "blockierend",
    "blockierendste": "blockierend",
    "blockierendstem": "blockierend",
    "blockierendsten": "blockierend",
    "blockierendster": "blockierend",
    "blockierendstes": "blockierend",
    "blockierest": "blockieren",
    "blockieret": "blockieren",
    "blockierst": "blockieren",
    "blockiert": "blockieren",
    "blockierte": "blockieren",
    "blockiertem": "blockiert",
    "blockierten": "blockieren",
    "blockierter": "blockiert",
    "blockiertere": "blockiert",
    "blockierterem": "blockiert",
    "blockierteren": "blockiert",
    "blockierterer": "blockiert",
    "blockierteres": "blockiert",
    "blockiertes": "blockiert",
    "blockiertest": "blockieren",
    "blockierteste": "blockiert",
    "blockiertestem": "blockiert",
    "blockiertesten": "blockiert",
    "blockiertester": "blockiert",
    "blockiertestes": "blockiert",
    "blockiertet": "blockieren",
    "blonde": "blond",
    "blondem": "blond",
    "blonden": "blond",
    "blonder": "blond",
    "blondere": "blond",
    "blonderem": "blond",
    "blonderen": "blond",
    "blonderer": "blond",
    "blonderes": "blond",
    "blondes": "blond",
    "blondeste": "blond",
    "blondestem": "blond",
    "blondesten": "blond",
    "blondester": "blond",
    "blondestes": "blond",
    "blondhaarige": "blondhaarig",
    "blondhaarigem": "blondhaarig",
    "blondhaarigen": "blondhaarig",
    "blondhaariger": "blondhaarig",
    "blondhaariges": "blondhaarig",
    "bloßem": "bloß",
    "bloßen": "bloß",
    "bloßer": "bloß",
    "bloßes": "bloß",
    "bloßgelegen": "bloßliegen",
    "bloßgelegene": "bloßgelegen",
    "bloßgelegenem": "bloßgelegen",
    "bloßgelegenen": "bloßgelegen",
    "bloßgelegener": "bloßgelegen",
    "bloßgelegenere": "bloßgelegen",
    "bloßgelegenerem": "bloßgelegen",
    "bloßgelegeneren": "bloßgelegen",
    "bloßgelegenerer": "bloßgelegen",
    "bloßgelegeneres": "bloßgelegen",
    "bloßgelegenes": "bloßgelegen",
    "bloßgelegenste": "bloßgelegen",
    "bloßgelegenstem": "bloßgelegen",
    "bloßgelegensten": "bloßgelegen",
    "bloßgelegenster": "bloßgelegen",
    "bloßgelegenstes": "bloßgelegen",
    "bloßgelegt": "bloßlegen",
    "bloßgelegte": "bloßgelegt",
    "bloßgelegtem": "bloßgelegt",
    "bloßgelegten": "bloßgelegt",
    "bloßgelegter": "bloßgelegt",
    "bloßgelegtere": "bloßgelegt",
    "bloßgelegterem": "bloßgelegt",
    "bloßgelegteren": "bloßgelegt",
    "bloßgelegterer": "bloßgelegt",
    "bloßgelegteres": "bloßgelegt",
    "bloßgelegtes": "bloßgelegt",
    "bloßgelegteste": "bloßgelegt",
    "bloßgelegtestem": "bloßgelegt",
    "bloßgelegtesten": "bloßgelegt",
    "bloßgelegtester": "bloßgelegt",
    "bloßgelegtestes": "bloßgelegt",
    "bloßgestellt": "bloßstellen",
    "bloßgestellte": "bloßgestellt",
    "bloßgestelltem": "bloßgestellt",
    "bloßgestellten": "bloßgestellt",
    "bloßgestellter": "bloßgestellt",
    "bloßgestelltere": "bloßgestellt",
    "bloßgestellterem": "bloßgestellt",
    "bloßgestellteren": "bloßgestellt",
    "bloßgestellterer": "bloßgestellt",
    "bloßgestellteres": "bloßgestellt",
    "bloßgestelltes": "bloßgestellt",
    "bloßgestellteste": "bloßgestellt",
    "bloßgestelltestem": "bloßgestellt",
    "bloßgestelltesten": "bloßgestellt",
    "bloßgestelltester": "bloßgestellt",
    "bloßgestelltestes": "bloßgestellt",
    "bloßlag": "bloßliegen",
    "bloßlagen": "bloßliegen",
    "bloßlagst": "bloßliegen",
    "bloßlagt": "bloßliegen",
    "bloßlege": "bloßlegen",
    "bloßlegend": "bloßlegen",
    "bloßlegende": "bloßlegend",
    "bloßlegendem": "bloßlegend",
    "bloßlegenden": "bloßlegend",
    "bloßlegender": "bloßlegend",
    "bloßlegendere": "bloßlegend",
    "bloßlegenderem": "bloßlegend",
    "bloßlegenderen": "bloßlegend",
    "bloßlegenderer": "bloßlegend",
    "bloßlegenderes": "bloßlegend",
    "bloßlegendes": "bloßlegend",
    "bloßlegendste": "bloßlegend",
    "bloßlegendstem": "bloßlegend",
    "bloßlegendsten": "bloßlegend",
    "bloßlegendster": "bloßlegend",
    "bloßlegendstes": "bloßlegend",
    "bloßlegest": "bloßlegen",
    "bloßleget": "bloßlegen",
    "bloßlegst": "bloßlegen",
    "bloßlegt": "bloßlegen",
    "bloßlegte": "bloßlegen",
    "bloßlegten": "bloßlegen",
    "bloßlegtest": "bloßlegen",
    "bloßlegtet": "bloßlegen",
    "bloßliege": "bloßliegen",
    "bloßliegend": "bloßliegen",
    "bloßliegende": "bloßliegend",
    "bloßliegendem": "bloßliegend",
    "bloßliegenden": "bloßliegend",
    "bloßliegender": "bloßliegend",
    "bloßliegendere": "bloßliegend",
    "bloßliegenderem": "bloßliegend",
    "bloßliegenderen": "bloßliegend",
    "bloßliegenderer": "bloßliegend",
    "bloßliegenderes": "bloßliegend",
    "bloßliegendes": "bloßliegend",
    "bloßliegendste": "bloßliegend",
    "bloßliegendstem": "bloßliegend",
    "bloßliegendsten": "bloßliegend",
    "bloßliegendster": "bloßliegend",
    "bloßliegendstes": "bloßliegend",
    "bloßliegest": "bloßliegen",
    "bloßlieget": "bloßliegen",
    "bloßliegst": "bloßliegen",
    "bloßliegt": "bloßliegen",
    "bloßläge": "bloßliegen",
    "bloßlägen": "bloßliegen",
    "bloßlägest": "bloßliegen",
    "bloßläget": "bloßliegen",
    "bloßstelle": "bloßstellen",
    "bloßstellend": "bloßstellen",
    "bloßstellende": "bloßstellend",
    "bloßstellendem": "bloßstellend",
    "bloßstellenden": "bloßstellend",
    "bloßstellender": "bloßstellend",
    "bloßstellendere": "bloßstellend",
    "bloßstellenderem": "bloßstellend",
    "bloßstellenderen": "bloßstellend",
    "bloßstellenderer": "bloßstellend",
    "bloßstellenderes": "bloßstellend",
    "bloßstellendes": "bloßstellend",
    "bloßstellendste": "bloßstellend",
    "bloßstellendstem": "bloßstellend",
    "bloßstellendsten": "bloßstellend",
    "bloßstellendster": "bloßstellend",
    "bloßstellendstes": "bloßstellend",
    "bloßstellest": "bloßstellen",
    "bloßstellet": "bloßstellen",
    "bloßstellst": "bloßstellen",
    "bloßstellt": "bloßstellen",
    "bloßstellte": "bloßstellen",
    "bloßstellten": "bloßstellen",
    "bloßstelltest": "bloßstellen",
    "bloßstelltet": "bloßstellen",
    "bloßzulegen": "bloßlegen",
    "bloßzuliegen": "bloßliegen",
    "bloßzustellen": "bloßstellen",
    "blubbere": "blubbern",
    "blubbernd": "blubbern",
    "blubbernde": "blubbernd",
    "blubberndem": "blubbernd",
    "blubbernden": "blubbernd",
    "blubbernder": "blubbernd",
    "blubberndere": "blubbernd",
    "blubbernderem": "blubbernd",
    "blubbernderen": "blubbernd",
    "blubbernderer": "blubbernd",
    "blubbernderes": "blubbernd",
    "blubberndes": "blubbernd",
    "blubberndste": "blubbernd",
    "blubberndstem": "blubbernd",
    "blubberndsten": "blubbernd",
    "blubberndster": "blubbernd",
    "blubberndstes": "blubbernd",
    "blubberst": "blubbern",
    "blubbert": "blubbern",
    "blubberte": "blubbern",
    "blubberten": "blubbern",
    "blubbertest": "blubbern",
    "blubbertet": "blubbern",
    "blumenreichem": "blumenreich",
    "blumenreichen": "blumenreich",
    "blumenreicher": "blumenreich",
    "blumenreichere": "blumenreich",
    "blumenreicherem": "blumenreich",
    "blumenreicheren": "blumenreich",
    "blumenreicherer": "blumenreich",
    "blumenreicheres": "blumenreich",
    "blumenreiches": "blumenreich",
    "blumenreichste": "blumenreich",
    "blumenreichstem": "blumenreich",
    "blumenreichsten": "blumenreich",
    "blumenreichster": "blumenreich",
    "blumenreichstes": "blumenreich",
    "blumige": "blumig",
    "blumigem": "blumig",
    "blumigen": "blumig",
    "blumiger": "blumig",
    "blumigere": "blumig",
    "blumigerem": "blumig",
    "blumigeren": "blumig",
    "blumigerer": "blumig",
    "blumigeres": "blumig",
    "blumiges": "blumig",
    "blumigste": "blumig",
    "blumigstem": "blumig",
    "blumigsten": "blumig",
    "blumigster": "blumig",
    "blumigstes": "blumig",
    "blutarmem": "blutarm",
    "blutarmen": "blutarm",
    "blutarmer": "blutarm",
    "blutarmes": "blutarm",
    "blutbefleckte": "blutbefleckt",
    "blutbeflecktem": "blutbefleckt",
    "blutbefleckten": "blutbefleckt",
    "blutbefleckter": "blutbefleckt",
    "blutbeflecktes": "blutbefleckt",
    "blutend": "bluten",
    "blutende": "blutend",
    "blutendem": "blutend",
    "blutenden": "blutend",
    "blutender": "blutend",
    "blutendere": "blutend",
    "blutenderem": "blutend",
    "blutenderen": "blutend",
    "blutenderer": "blutend",
    "blutenderes": "blutend",
    "blutendes": "blutend",
    "blutendste": "blutend",
    "blutendstem": "blutend",
    "blutendsten": "blutend",
    "blutendster": "blutend",
    "blutendstes": "blutend",
    "blutest": "bluten",
    "blutet": "bluten",
    "blutete": "bluten",
    "bluteten": "bluten",
    "blutetest": "bluten",
    "blutetet": "bluten",
    "blutigem": "blutig",
    "blutigen": "blutig",
    "blutiger": "blutig",
    "blutigere": "blutig",
    "blutigerem": "blutig",
    "blutigeren": "blutig",
    "blutigerer": "blutig",
    "blutigeres": "blutig",
    "blutiges": "blutig",
    "blutigste": "blutig",
    "blutigstem": "blutig",
    "blutigsten": "blutig",
    "blutigster": "blutig",
    "blutigstes": "blutig",
    "blutjunge": "blutjung",
    "blutjungem": "blutjung",
    "blutjungen": "blutjung",
    "blutjunger": "blutjung",
    "blutjunges": "blutjung",
    "blutrünstigem": "blutrünstig",
    "blutrünstigen": "blutrünstig",
    "blutrünstiger": "blutrünstig",
    "blutrünstigere": "blutrünstig",
    "blutrünstigerem": "blutrünstig",
    "blutrünstigeren": "blutrünstig",
    "blutrünstigerer": "blutrünstig",
    "blutrünstigeres": "blutrünstig",
    "blutrünstiges": "blutrünstig",
    "blutrünstigste": "blutrünstig",
    "blutrünstigstem": "blutrünstig",
    "blutrünstigsten": "blutrünstig",
    "blutrünstigster": "blutrünstig",
    "blutrünstigstes": "blutrünstig",
    "blutsverwandtem": "blutsverwandt",
    "blutsverwandten": "blutsverwandt",
    "blutsverwandter": "blutsverwandt",
    "blutsverwandtes": "blutsverwandt",
    "blutunterlaufenem": "blutunterlaufen",
    "blutunterlaufenen": "blutunterlaufen",
    "blutunterlaufener": "blutunterlaufen",
    "blutunterlaufenes": "blutunterlaufen",
    "blutärmer": "blutarm",
    "blutärmere": "blutarm",
    "blutärmerem": "blutarm",
    "blutärmeren": "blutarm",
    "blutärmerer": "blutarm",
    "blutärmeres": "blutarm",
    "blutärmsten": "blutarm",
    "blähe": "blähen",
    "blähend": "blähen",
    "blähende": "blähend",
    "blähendem": "blähend",
    "blähenden": "blähend",
    "blähender": "blähend",
    "blähendere": "blähend",
    "blähenderem": "blähend",
    "blähenderen": "blähend",
    "blähenderer": "blähend",
    "blähenderes": "blähend",
    "blähendes": "blähend",
    "blähendste": "blähend",
    "blähendstem": "blähend",
    "blähendsten": "blähend",
    "blähendster": "blähend",
    "blähendstes": "blähend",
    "blähest": "blähen",
    "blähet": "blähen",
    "blähst": "blähen",
    "bläht": "blähen",
    "blähte": "blähen",
    "blähten": "blähen",
    "blähtest": "blähen",
    "blähtet": "blähen",
    "blässliche": "blässlich",
    "blässlichem": "blässlich",
    "blässlichen": "blässlich",
    "blässlicher": "blässlich",
    "blässlichere": "blässlich",
    "blässlicherem": "blässlich",
    "blässlicheren": "blässlich",
    "blässlicherer": "blässlich",
    "blässlicheres": "blässlich",
    "blässliches": "blässlich",
    "blässlichste": "blässlich",
    "blässlichstem": "blässlich",
    "blässlichsten": "blässlich",
    "blässlichster": "blässlich",
    "blässlichstes": "blässlich",
    "bläst": "blasen",
    "blättere": "blättern",
    "blätterige": "blätterig",
    "blätterigem": "blätterig",
    "blätterigen": "blätterig",
    "blätteriger": "blätterig",
    "blätterigere": "blätterig",
    "blätterigerem": "blätterig",
    "blätterigeren": "blätterig",
    "blätterigerer": "blätterig",
    "blätterigeres": "blätterig",
    "blätteriges": "blätterig",
    "blätterigste": "blätterig",
    "blätterigstem": "blätterig",
    "blätterigsten": "blätterig",
    "blätterigster": "blätterig",
    "blätterigstes": "blätterig",
    "blätterlose": "blätterlos",
    "blätterlosem": "blätterlos",
    "blätterlosen": "blätterlos",
    "blätterloser": "blätterlos",
    "blätterlosere": "blätterlos",
    "blätterloserem": "blätterlos",
    "blätterloseren": "blätterlos",
    "blätterloserer": "blätterlos",
    "blätterloseres": "blätterlos",
    "blätterloses": "blätterlos",
    "blätterloseste": "blätterlos",
    "blätterlosestem": "blätterlos",
    "blätterlosesten": "blätterlos",
    "blätterlosester": "blätterlos",
    "blätterlosestes": "blätterlos",
    "blätternd": "blättern",
    "blätternde": "blätternd",
    "blätterndem": "blätternd",
    "blätternden": "blätternd",
    "blätternder": "blätternd",
    "blätterndes": "blätternd",
    "blätterst": "blättern",
    "blättert": "blättern",
    "blätterte": "blättern",
    "blätterten": "blättern",
    "blättertest": "blättern",
    "blättertet": "blättern",
    "blättrige": "blättrig",
    "blättrigem": "blättrig",
    "blättrigen": "blättrig",
    "blättriger": "blättrig",
    "blättriges": "blättrig",
    "bläue": "bläuen",
    "bläuend": "bläuen",
    "bläuende": "bläuend",
    "bläuendem": "bläuend",
    "bläuenden": "bläuend",
    "bläuender": "bläuend",
    "bläuendes": "bläuend",
    "bläuest": "bläuen",
    "bläuet": "bläuen",
    "bläulichem": "bläulich",
    "bläulichen": "bläulich",
    "bläulicher": "bläulich",
    "bläulichere": "bläulich",
    "bläulicherem": "bläulich",
    "bläulicheren": "bläulich",
    "bläulicherer": "bläulich",
    "bläulicheres": "bläulich",
    "bläuliches": "bläulich",
    "bläulichste": "bläulich",
    "bläulichstem": "bläulich",
    "bläulichsten": "bläulich",
    "bläulichster": "bläulich",
    "bläulichstes": "bläulich",
    "bläust": "bläuen",
    "bläut": "bläuen",
    "bläute": "bläuen",
    "bläuten": "bläuen",
    "bläutest": "bläuen",
    "bläutet": "bläuen",
    "blödele": "blödeln",
    "blödelnd": "blödeln",
    "blödelnde": "blödelnd",
    "blödelndem": "blödelnd",
    "blödelnden": "blödelnd",
    "blödelnder": "blödelnd",
    "blödelndere": "blödelnd",
    "blödelnderem": "blödelnd",
    "blödelnderen": "blödelnd",
    "blödelnderer": "blödelnd",
    "blödelnderes": "blödelnd",
    "blödelndes": "blödelnd",
    "blödelndste": "blödelnd",
    "blödelndstem": "blödelnd",
    "blödelndsten": "blödelnd",
    "blödelndster": "blödelnd",
    "blödelndstes": "blödelnd",
    "blödelst": "blödeln",
    "blödelt": "blödeln",
    "blödelte": "blödeln",
    "blödelten": "blödeln",
    "blödeltest": "blödeln",
    "blödeltet": "blödeln",
    "blödem": "blöd",
    "blöden": "blöd",
    "blöder": "blöd",
    "blödere": "blöd",
    "blöderem": "blöd",
    "blöderen": "blöd",
    "blöderer": "blöd",
    "blöderes": "blöd",
    "blödes": "blöd",
    "blödeste": "blöd",
    "blödestem": "blöd",
    "blödesten": "blöd",
    "blödester": "blöd",
    "blödestes": "blöd",
    "blödle": "blödeln",
    "blödsinnigem": "blödsinnig",
    "blödsinnigen": "blödsinnig",
    "blödsinniger": "blödsinnig",
    "blödsinnigere": "blödsinnig",
    "blödsinnigerem": "blödsinnig",
    "blödsinnigeren": "blödsinnig",
    "blödsinnigerer": "blödsinnig",
    "blödsinnigeres": "blödsinnig",
    "blödsinniges": "blödsinnig",
    "blödsinnigste": "blödsinnig",
    "blödsinnigstem": "blödsinnig",
    "blödsinnigsten": "blödsinnig",
    "blödsinnigster": "blödsinnig",
    "blödsinnigstes": "blödsinnig",
    "blöke": "blöken",
    "blökend": "blöken",
    "blökende": "blökend",
    "blökendem": "blökend",
    "blökenden": "blökend",
    "blökender": "blökend",
    "blökendere": "blökend",
    "blökenderem": "blökend",
    "blökenderen": "blökend",
    "blökenderer": "blökend",
    "blökenderes": "blökend",
    "blökendes": "blökend",
    "blökendste": "blökend",
    "blökendstem": "blökend",
    "blökendsten": "blökend",
    "blökendster": "blökend",
    "blökendstes": "blökend",
    "blökest": "blöken",
    "blöket": "blöken",
    "blökst": "blöken",
    "blökt": "blöken",
    "blökte": "blöken",
    "blökten": "blöken",
    "blöktest": "blöken",
    "blöktet": "blöken",
    "blühe": "blühen",
    "blühend": "blühen",
    "blühende": "blühend",
    "blühendem": "blühend",
    "blühenden": "blühend",
    "blühender": "blühend",
    "blühendere": "blühend",
    "blühenderem": "blühend",
    "blühenderen": "blühend",
    "blühenderer": "blühend",
    "blühenderes": "blühend",
    "blühendes": "blühend",
    "blühendste": "blühend",
    "blühendstem": "blühend",
    "blühendsten": "blühend",
    "blühendster": "blühend",
    "blühendstes": "blühend",
    "blühest": "blühen",
    "blühet": "blühen",
    "blühst": "blühen",
    "blüht": "blühen",
    "blühte": "blühen",
    "blühten": "blühen",
    "blühtest": "blühen",
    "blühtet": "blühen",
    "blütenreichem": "blütenreich",
    "blütenreichen": "blütenreich",
    "blütenreicher": "blütenreich",
    "blütenreichere": "blütenreich",
    "blütenreicherem": "blütenreich",
    "blütenreicheren": "blütenreich",
    "blütenreicherer": "blütenreich",
    "blütenreicheres": "blütenreich",
    "blütenreiches": "blütenreich",
    "blütenreichste": "blütenreich",
    "blütenreichstem": "blütenreich",
    "blütenreichsten": "blütenreich",
    "blütenreichster": "blütenreich",
    "blütenreichstes": "blütenreich",
    "bodenlosem": "bodenlos",
    "bodenlosen": "bodenlos",
    "bodenloser": "bodenlos",
    "bodenlosere": "bodenlos",
    "bodenloserem": "bodenlos",
    "bodenloseren": "bodenlos",
    "bodenloserer": "bodenlos",
    "bodenloseres": "bodenlos",
    "bodenloses": "bodenlos",
    "bodenloseste": "bodenlos",
    "bodenlosestem": "bodenlos",
    "bodenlosesten": "bodenlos",
    "bodenlosester": "bodenlos",
    "bodenlosestes": "bodenlos",
    "bodenständigem": "bodenständig",
    "bodenständigen": "bodenständig",
    "bodenständiger": "bodenständig",
    "bodenständigere": "bodenständig",
    "bodenständigerem": "bodenständig",
    "bodenständigeren": "bodenständig",
    "bodenständigerer": "bodenständig",
    "bodenständigeres": "bodenständig",
    "bodenständiges": "bodenständig",
    "bodenständigste": "bodenständig",
    "bodenständigstem": "bodenständig",
    "bodenständigsten": "bodenständig",
    "bodenständigster": "bodenständig",
    "bodenständigstes": "bodenständig",
    "bog": "biegen",
    "bogen": "biegen",
    "bogst": "biegen",
    "bogt": "biegen",
    "bohnere": "bohnern",
    "bohnernd": "bohnern",
    "bohnernde": "bohnernd",
    "bohnerndem": "bohnernd",
    "bohnernden": "bohnernd",
    "bohnernder": "bohnernd",
    "bohnerndere": "bohnernd",
    "bohnernderem": "bohnernd",
    "bohnernderen": "bohnernd",
    "bohnernderer": "bohnernd",
    "bohnernderes": "bohnernd",
    "bohnerndes": "bohnernd",
    "bohnerndste": "bohnernd",
    "bohnerndstem": "bohnernd",
    "bohnerndsten": "bohnernd",
    "bohnerndster": "bohnernd",
    "bohnerndstes": "bohnernd",
    "bohnerst": "bohnern",
    "bohnert": "bohnern",
    "bohnerte": "bohnern",
    "bohnerten": "bohnern",
    "bohnertest": "bohnern",
    "bohnertet": "bohnern",
    "bohre": "bohren",
    "bohrend": "bohren",
    "bohrende": "bohrend",
    "bohrendem": "bohrend",
    "bohrenden": "bohrend",
    "bohrender": "bohrend",
    "bohrendere": "bohrend",
    "bohrenderem": "bohrend",
    "bohrenderen": "bohrend",
    "bohrenderer": "bohrend",
    "bohrenderes": "bohrend",
    "bohrendes": "bohrend",
    "bohrendste": "bohrend",
    "bohrendstem": "bohrend",
    "bohrendsten": "bohrend",
    "bohrendster": "bohrend",
    "bohrendstes": "bohrend",
    "bohrest": "bohren",
    "bohret": "bohren",
    "bohrst": "bohren",
    "bohrt": "bohren",
    "bohrte": "bohren",
    "bohrten": "bohren",
    "bohrtest": "bohren",
    "bohrtet": "bohren",
    "bolschewistischem": "bolschewistisch",
    "bolschewistischen": "bolschewistisch",
    "bolschewistischer": "bolschewistisch",
    "bolschewistisches": "bolschewistisch",
    "bolze": "bolzen",
    "bolzend": "bolzen",
    "bolzende": "bolzend",
    "bolzendem": "bolzend",
    "bolzenden": "bolzend",
    "bolzender": "bolzend",
    "bolzendere": "bolzend",
    "bolzenderem": "bolzend",
    "bolzenderen": "bolzend",
    "bolzenderer": "bolzend",
    "bolzenderes": "bolzend",
    "bolzendes": "bolzend",
    "bolzendste": "bolzend",
    "bolzendstem": "bolzend",
    "bolzendsten": "bolzend",
    "bolzendster": "bolzend",
    "bolzendstes": "bolzend",
    "bolzest": "bolzen",
    "bolzet": "bolzen",
    "bolzt": "bolzen",
    "bolzte": "bolzen",
    "bolzten": "bolzen",
    "bolztest": "bolzen",
    "bolztet": "bolzen",
    "bombardiere": "bombardieren",
    "bombardierend": "bombardieren",
    "bombardierende": "bombardierend",
    "bombardierendem": "bombardierend",
    "bombardierenden": "bombardierend",
    "bombardierender": "bombardierend",
    "bombardierendere": "bombardierend",
    "bombardierenderem": "bombardierend",
    "bombardierenderen": "bombardierend",
    "bombardierenderer": "bombardierend",
    "bombardierenderes": "bombardierend",
    "bombardierendes": "bombardierend",
    "bombardierendste": "bombardierend",
    "bombardierendstem": "bombardierend",
    "bombardierendsten": "bombardierend",
    "bombardierendster": "bombardierend",
    "bombardierendstes": "bombardierend",
    "bombardierest": "bombardieren",
    "bombardieret": "bombardieren",
    "bombardierst": "bombardieren",
    "bombardiert": "bombardieren",
    "bombardierte": "bombardieren",
    "bombardiertem": "bombardiert",
    "bombardierten": "bombardieren",
    "bombardierter": "bombardiert",
    "bombardiertere": "bombardiert",
    "bombardierterem": "bombardiert",
    "bombardierteren": "bombardiert",
    "bombardierterer": "bombardiert",
    "bombardierteres": "bombardiert",
    "bombardiertes": "bombardiert",
    "bombardiertest": "bombardieren",
    "bombardierteste": "bombardiert",
    "bombardiertestem": "bombardiert",
    "bombardiertesten": "bombardiert",
    "bombardiertester": "bombardiert",
    "bombardiertestes": "bombardiert",
    "bombardiertet": "bombardieren",
    "bombastische": "bombastisch",
    "bombastischem": "bombastisch",
    "bombastischen": "bombastisch",
    "bombastischer": "bombastisch",
    "bombastischere": "bombastisch",
    "bombastischerem": "bombastisch",
    "bombastischeren": "bombastisch",
    "bombastischerer": "bombastisch",
    "bombastischeres": "bombastisch",
    "bombastisches": "bombastisch",
    "bombastischste": "bombastisch",
    "bombastischstem": "bombastisch",
    "bombastischsten": "bombastisch",
    "bombastischster": "bombastisch",
    "bombastischstes": "bombastisch",
    "bombe": "bomben",
    "bombend": "bomben",
    "bombende": "bombend",
    "bombendem": "bombend",
    "bombenden": "bombend",
    "bombender": "bombend",
    "bombendes": "bombend",
    "bombenfeste": "bombenfest",
    "bombenfestem": "bombenfest",
    "bombenfesten": "bombenfest",
    "bombenfester": "bombenfest",
    "bombenfestes": "bombenfest",
    "bombensicherem": "bombensicher",
    "bombensicheren": "bombensicher",
    "bombensicherer": "bombensicher",
    "bombensicherere": "bombensicher",
    "bombensichererem": "bombensicher",
    "bombensichereren": "bombensicher",
    "bombensichererer": "bombensicher",
    "bombensichereres": "bombensicher",
    "bombensicheres": "bombensicher",
    "bombensicherste": "bombensicher",
    "bombensicherstem": "bombensicher",
    "bombensichersten": "bombensicher",
    "bombensicherster": "bombensicher",
    "bombensicherstes": "bombensicher",
    "bombest": "bomben",
    "bombet": "bomben",
    "bombige": "bombig",
    "bombigem": "bombig",
    "bombigen": "bombig",
    "bombiger": "bombig",
    "bombigere": "bombig",
    "bombigerem": "bombig",
    "bombigeren": "bombig",
    "bombigerer": "bombig",
    "bombigeres": "bombig",
    "bombiges": "bombig",
    "bombigste": "bombig",
    "bombigstem": "bombig",
    "bombigsten": "bombig",
    "bombigster": "bombig",
    "bombigstes": "bombig",
    "bombst": "bomben",
    "bombt": "bomben",
    "bombte": "bomben",
    "bombten": "bomben",
    "bombtest": "bomben",
    "bombtet": "bomben",
    "bonifiziere": "bonifizieren",
    "bonifizierend": "bonifizieren",
    "bonifizierende": "bonifizierend",
    "bonifizierendem": "bonifizierend",
    "bonifizierenden": "bonifizierend",
    "bonifizierender": "bonifizierend",
    "bonifizierendere": "bonifizierend",
    "bonifizierenderem": "bonifizierend",
    "bonifizierenderen": "bonifizierend",
    "bonifizierenderer": "bonifizierend",
    "bonifizierenderes": "bonifizierend",
    "bonifizierendes": "bonifizierend",
    "bonifizierendste": "bonifizierend",
    "bonifizierendstem": "bonifizierend",
    "bonifizierendsten": "bonifizierend",
    "bonifizierendster": "bonifizierend",
    "bonifizierendstes": "bonifizierend",
    "bonifizierest": "bonifizieren",
    "bonifizieret": "bonifizieren",
    "bonifizierst": "bonifizieren",
    "bonifiziert": "bonifizieren",
    "bonifizierte": "bonifizieren",
    "bonifiziertem": "bonifiziert",
    "bonifizierten": "bonifizieren",
    "bonifizierter": "bonifiziert",
    "bonifiziertere": "bonifiziert",
    "bonifizierterem": "bonifiziert",
    "bonifizierteren": "bonifiziert",
    "bonifizierterer": "bonifiziert",
    "bonifizierteres": "bonifiziert",
    "bonifiziertes": "bonifiziert",
    "bonifiziertest": "bonifizieren",
    "bonifizierteste": "bonifiziert",
    "bonifiziertestem": "bonifiziert",
    "bonifiziertesten": "bonifiziert",
    "bonifiziertester": "bonifiziert",
    "bonifiziertestes": "bonifiziert",
    "bonifiziertet": "bonifizieren",
    "boome": "boomen",
    "boomend": "boomen",
    "boomende": "boomend",
    "boomendem": "boomend",
    "boomenden": "boomend",
    "boomender": "boomend",
    "boomendere": "boomend",
    "boomenderem": "boomend",
    "boomenderen": "boomend",
    "boomenderer": "boomend",
    "boomenderes": "boomend",
    "boomendes": "boomend",
    "boomendste": "boomend",
    "boomendstem": "boomend",
    "boomendsten": "boomend",
    "boomendster": "boomend",
    "boomendstes": "boomend",
    "boomest": "boomen",
    "boomet": "boomen",
    "boomst": "boomen",
    "boomt": "boomen",
    "boomte": "boomen",
    "boomten": "boomen",
    "boomtest": "boomen",
    "boomtet": "boomen",
    "bootend": "booten",
    "bootende": "bootend",
    "bootendem": "bootend",
    "bootenden": "bootend",
    "bootender": "bootend",
    "bootendes": "bootend",
    "bootest": "booten",
    "bootet": "booten",
    "bootete": "booten",
    "booteten": "booten",
    "bootetest": "booten",
    "bootetet": "booten",
    "borge": "borgen",
    "borgend": "borgen",
    "borgende": "borgend",
    "borgendem": "borgend",
    "borgenden": "borgend",
    "borgender": "borgend",
    "borgendes": "borgend",
    "borgest": "borgen",
    "borget": "borgen",
    "borgst": "borgen",
    "borgt": "borgen",
    "borgte": "borgen",
    "borgten": "borgen",
    "borgtest": "borgen",
    "borgtet": "borgen",
    "borniertem": "borniert",
    "bornierten": "borniert",
    "bornierter": "borniert",
    "borniertere": "borniert",
    "bornierterem": "borniert",
    "bornierteren": "borniert",
    "bornierterer": "borniert",
    "bornierteres": "borniert",
    "borniertes": "borniert",
    "bornierteste": "borniert",
    "borniertestem": "borniert",
    "borniertesten": "borniert",
    "borniertester": "borniert",
    "borniertestes": "borniert",
    "borstigem": "borstig",
    "borstigen": "borstig",
    "borstiger": "borstig",
    "borstigere": "borstig",
    "borstigerem": "borstig",
    "borstigeren": "borstig",
    "borstigerer": "borstig",
    "borstigeres": "borstig",
    "borstiges": "borstig",
    "borstigste": "borstig",
    "borstigstem": "borstig",
    "borstigsten": "borstig",
    "borstigster": "borstig",
    "borstigstes": "borstig",
    "boshaftem": "boshaft",
    "boshaften": "boshaft",
    "boshafter": "boshaft",
    "boshaftere": "boshaft",
    "boshafterem": "boshaft",
    "boshafteren": "boshaft",
    "boshafterer": "boshaft",
    "boshafteres": "boshaft",
    "boshaftes": "boshaft",
    "boshafteste": "boshaft",
    "boshaftestem": "boshaft",
    "boshaftesten": "boshaft",
    "boshaftester": "boshaft",
    "boshaftestes": "boshaft",
    "bosnischem": "bosnisch",
    "bosnischen": "bosnisch",
    "bosnischer": "bosnisch",
    "bosnisches": "bosnisch",
    "bot": "bieten",
    "botanischem": "botanisch",
    "botanischen": "botanisch",
    "botanischer": "botanisch",
    "botanisches": "botanisch",
    "botanisiere": "botanisieren",
    "botanisierend": "botanisieren",
    "botanisierende": "botanisierend",
    "botanisierendem": "botanisierend",
    "botanisierenden": "botanisierend",
    "botanisierender": "botanisierend",
    "botanisierendes": "botanisierend",
    "botanisierest": "botanisieren",
    "botanisieret": "botanisieren",
    "botanisierst": "botanisieren",
    "botanisiert": "botanisieren",
    "botanisierte": "botanisieren",
    "botanisiertem": "botanisiert",
    "botanisierten": "botanisieren",
    "botanisierter": "botanisiert",
    "botanisiertes": "botanisiert",
    "botanisiertest": "botanisieren",
    "botanisiertet": "botanisieren",
    "boten": "bieten",
    "botest": "bieten",
    "botet": "bieten",
    "boxe": "boxen",
    "boxend": "boxen",
    "boxende": "boxend",
    "boxendem": "boxend",
    "boxenden": "boxend",
    "boxender": "boxend",
    "boxendere": "boxend",
    "boxenderem": "boxend",
    "boxenderen": "boxend",
    "boxenderer": "boxend",
    "boxenderes": "boxend",
    "boxendes": "boxend",
    "boxendste": "boxend",
    "boxendstem": "boxend",
    "boxendsten": "boxend",
    "boxendster": "boxend",
    "boxendstes": "boxend",
    "boxest": "boxen",
    "boxet": "boxen",
    "boxt": "boxen",
    "boxte": "boxen",
    "boxten": "boxen",
    "boxtest": "boxen",
    "boxtet": "boxen",
    "brabbele": "brabbeln",
    "brabbelnd": "brabbeln",
    "brabbelnde": "brabbelnd",
    "brabbelndem": "brabbelnd",
    "brabbelnden": "brabbelnd",
    "brabbelnder": "brabbelnd",
    "brabbelndere": "brabbelnd",
    "brabbelnderem": "brabbelnd",
    "brabbelnderen": "brabbelnd",
    "brabbelnderer": "brabbelnd",
    "brabbelnderes": "brabbelnd",
    "brabbelndes": "brabbelnd",
    "brabbelndste": "brabbelnd",
    "brabbelndstem": "brabbelnd",
    "brabbelndsten": "brabbelnd",
    "brabbelndster": "brabbelnd",
    "brabbelndstes": "brabbelnd",
    "brabbelst": "brabbeln",
    "brabbelt": "brabbeln",
    "brabbelte": "brabbeln",
    "brabbelten": "brabbeln",
    "brabbeltest": "brabbeln",
    "brabbeltet": "brabbeln",
    "brabble": "brabbeln",
    "brach": "brechen",
    "brache": "brach",
    "brachem": "brach",
    "brachen": "brach",
    "bracher": "brach",
    "braches": "brach",
    "brachgelegen": "brachliegen",
    "brachgelegene": "brachgelegen",
    "brachgelegenem": "brachgelegen",
    "brachgelegenen": "brachgelegen",
    "brachgelegener": "brachgelegen",
    "brachgelegenere": "brachgelegen",
    "brachgelegenerem": "brachgelegen",
    "brachgelegeneren": "brachgelegen",
    "brachgelegenerer": "brachgelegen",
    "brachgelegeneres": "brachgelegen",
    "brachgelegenes": "brachgelegen",
    "brachgelegenste": "brachgelegen",
    "brachgelegenstem": "brachgelegen",
    "brachgelegensten": "brachgelegen",
    "brachgelegenster": "brachgelegen",
    "brachgelegenstes": "brachgelegen",
    "brachlag": "brachliegen",
    "brachlagen": "brachliegen",
    "brachlagst": "brachliegen",
    "brachlagt": "brachliegen",
    "brachliege": "brachliegen",
    "brachliegend": "brachliegen",
    "brachliegende": "brachliegend",
    "brachliegendem": "brachliegend",
    "brachliegenden": "brachliegend",
    "brachliegender": "brachliegend",
    "brachliegendere": "brachliegend",
    "brachliegenderem": "brachliegend",
    "brachliegenderen": "brachliegend",
    "brachliegenderer": "brachliegend",
    "brachliegenderes": "brachliegend",
    "brachliegendes": "brachliegend",
    "brachliegendste": "brachliegend",
    "brachliegendstem": "brachliegend",
    "brachliegendsten": "brachliegend",
    "brachliegendster": "brachliegend",
    "brachliegendstes": "brachliegend",
    "brachliegest": "brachliegen",
    "brachlieget": "brachliegen",
    "brachliegst": "brachliegen",
    "brachliegt": "brachliegen",
    "brachläge": "brachliegen",
    "brachlägen": "brachliegen",
    "brachlägest": "brachliegen",
    "brachläget": "brachliegen",
    "brachst": "brechen",
    "bracht": "brechen",
    "brachte": "bringen",
    "brachten": "bringen",
    "brachtest": "bringen",
    "brachtet": "bringen",
    "brachzuliegen": "brachliegen",
    "brandaktuellem": "brandaktuell",
    "brandaktuellen": "brandaktuell",
    "brandaktueller": "brandaktuell",
    "brandaktuelles": "brandaktuell",
    "brandeiligem": "brandeilig",
    "brandeiligen": "brandeilig",
    "brandeiliger": "brandeilig",
    "brandeiliges": "brandeilig",
    "brandenburgischem": "brandenburgisch",
    "brandenburgischen": "brandenburgisch",
    "brandenburgischer": "brandenburgisch",
    "brandenburgisches": "brandenburgisch",
    "brandend": "branden",
    "brandende": "brandend",
    "brandendem": "brandend",
    "brandenden": "brandend",
    "brandender": "brandend",
    "brandendere": "brandend",
    "brandenderem": "brandend",
    "brandenderen": "brandend",
    "brandenderer": "brandend",
    "brandenderes": "brandend",
    "brandendes": "brandend",
    "brandendste": "brandend",
    "brandendstem": "brandend",
    "brandendsten": "brandend",
    "brandendster": "brandend",
    "brandendstes": "brandend",
    "brandest": "branden",
    "brandet": "branden",
    "brandete": "branden",
    "brandeten": "branden",
    "brandetest": "branden",
    "brandetet": "branden",
    "brandheiße": "brandheiß",
    "brandheißem": "brandheiß",
    "brandheißen": "brandheiß",
    "brandheißer": "brandheiß",
    "brandheißes": "brandheiß",
    "brandmarke": "brandmarken",
    "brandmarkend": "brandmarken",
    "brandmarkende": "brandmarkend",
    "brandmarkendem": "brandmarkend",
    "brandmarkenden": "brandmarkend",
    "brandmarkender": "brandmarkend",
    "brandmarkendere": "brandmarkend",
    "brandmarkenderem": "brandmarkend",
    "brandmarkenderen": "brandmarkend",
    "brandmarkenderer": "brandmarkend",
    "brandmarkenderes": "brandmarkend",
    "brandmarkendes": "brandmarkend",
    "brandmarkendste": "brandmarkend",
    "brandmarkendstem": "brandmarkend",
    "brandmarkendsten": "brandmarkend",
    "brandmarkendster": "brandmarkend",
    "brandmarkendstes": "brandmarkend",
    "brandmarkest": "brandmarken",
    "brandmarket": "brandmarken",
    "brandmarkst": "brandmarken",
    "brandmarkt": "brandmarken",
    "brandmarkte": "brandmarken",
    "brandmarkten": "brandmarken",
    "brandmarktest": "brandmarken",
    "brandmarktet": "brandmarken",
    "brandneue": "brandneu",
    "brandneuem": "brandneu",
    "brandneuen": "brandneu",
    "brandneuer": "brandneu",
    "brandneues": "brandneu",
    "brannte": "brennen",
    "brannten": "brennen",
    "branntest": "brennen",
    "branntet": "brennen",
    "brasilianischem": "brasilianisch",
    "brasilianischen": "brasilianisch",
    "brasilianischer": "brasilianisch",
    "brasilianisches": "brasilianisch",
    "brate": "braten",
    "bratend": "braten",
    "bratende": "bratend",
    "bratendem": "bratend",
    "bratenden": "bratend",
    "bratender": "bratend",
    "bratendere": "bratend",
    "bratenderem": "bratend",
    "bratenderen": "bratend",
    "bratenderer": "bratend",
    "bratenderes": "bratend",
    "bratendes": "bratend",
    "bratendste": "bratend",
    "bratendstem": "bratend",
    "bratendsten": "bratend",
    "bratendster": "bratend",
    "bratendstes": "bratend",
    "bratest": "braten",
    "bratet": "braten",
    "bratfertige": "bratfertig",
    "bratfertigem": "bratfertig",
    "bratfertigen": "bratfertig",
    "bratfertiger": "bratfertig",
    "bratfertiges": "bratfertig",
    "brauchbarem": "brauchbar",
    "brauchbaren": "brauchbar",
    "brauchbarer": "brauchbar",
    "brauchbarere": "brauchbar",
    "brauchbarerem": "brauchbar",
    "brauchbareren": "brauchbar",
    "brauchbarerer": "brauchbar",
    "brauchbareres": "brauchbar",
    "brauchbares": "brauchbar",
    "brauchbarstem": "brauchbar",
    "brauchbarsten": "brauchbar",
    "brauchbarster": "brauchbar",
    "brauchbarstes": "brauchbar",
    "brauchend": "brauchen",
    "brauchende": "brauchend",
    "brauchendem": "brauchend",
    "brauchenden": "brauchend",
    "brauchender": "brauchend",
    "brauchendes": "brauchend",
    "brauchest": "brauchen",
    "brauchet": "brauchen",
    "brauchst": "brauchen",
    "braucht": "brauchen",
    "brauchte": "brauchen",
    "brauchten": "brauchen",
    "brauchtest": "brauchen",
    "brauchtet": "brauchen",
    "brauend": "brauen",
    "brauende": "brauend",
    "brauendem": "brauend",
    "brauenden": "brauend",
    "brauender": "brauend",
    "brauendere": "brauend",
    "brauenderem": "brauend",
    "brauenderen": "brauend",
    "brauenderer": "brauend",
    "brauenderes": "brauend",
    "brauendes": "brauend",
    "brauendste": "brauend",
    "brauendstem": "brauend",
    "brauendsten": "brauend",
    "brauendster": "brauend",
    "brauendstes": "brauend",
    "brauest": "brauen",
    "brauet": "brauen",
    "braunem": "braun",
    "braunen": "braun",
    "brauner": "braun",
    "braunere": "braun",
    "braunerem": "braun",
    "brauneren": "braun",
    "braunerer": "braun",
    "brauneres": "braun",
    "braunes": "braun",
    "braungebrannte": "braungebrannt",
    "braungebranntem": "braungebrannt",
    "braungebrannten": "braungebrannt",
    "braungebrannter": "braungebrannt",
    "braungebranntere": "braungebrannt",
    "braungebrannterem": "braungebrannt",
    "braungebrannteren": "braungebrannt",
    "braungebrannterer": "braungebrannt",
    "braungebrannteres": "braungebrannt",
    "braungebranntes": "braungebrannt",
    "braungebrannteste": "braungebrannt",
    "braungebranntestem": "braungebrannt",
    "braungebranntesten": "braungebrannt",
    "braungebranntester": "braungebrannt",
    "braungebranntestes": "braungebrannt",
    "braunhaarige": "braunhaarig",
    "braunhaarigem": "braunhaarig",
    "braunhaarigen": "braunhaarig",
    "braunhaariger": "braunhaarig",
    "braunhaariges": "braunhaarig",
    "braunstem": "braun",
    "braunsten": "braun",
    "braunster": "braun",
    "braunstes": "braun",
    "brausend": "brausen",
    "brausende": "brausend",
    "brausendem": "brausend",
    "brausenden": "brausend",
    "brausender": "brausend",
    "brausendere": "brausend",
    "brausenderem": "brausend",
    "brausenderen": "brausend",
    "brausenderer": "brausend",
    "brausenderes": "brausend",
    "brausendes": "brausend",
    "brausendste": "brausend",
    "brausendstem": "brausend",
    "brausendsten": "brausend",
    "brausendster": "brausend",
    "brausendstes": "brausend",
    "brausest": "brausen",
    "brauset": "brausen",
    "braust": "brausen",
    "brauste": "brausen",
    "brausten": "brausen",
    "braustest": "brausen",
    "braustet": "brausen",
    "braut": "brauen",
    "braute": "brauen",
    "brauten": "brauen",
    "brautest": "brauen",
    "brautet": "brauen",
    "bravem": "brav",
    "braven": "brav",
    "braver": "brav",
    "bravere": "brav",
    "braverem": "brav",
    "braveren": "brav",
    "braverer": "brav",
    "braveres": "brav",
    "braves": "brav",
    "bravstem": "brav",
    "bravsten": "brav",
    "bravster": "brav",
    "bravstes": "brav",
    "breche": "brechen",
    "brechend": "brechen",
    "brechende": "brechend",
    "brechendem": "brechend",
    "brechenden": "brechend",
    "brechender": "brechend",
    "brechendes": "brechend",
    "brechest": "brechen",
    "brechet": "brechen",
    "brecht": "brechen",
    "breitbeinigem": "breitbeinig",
    "breitbeinigen": "breitbeinig",
    "breitbeiniger": "breitbeinig",
    "breitbeinigere": "breitbeinig",
    "breitbeinigerem": "breitbeinig",
    "breitbeinigeren": "breitbeinig",
    "breitbeinigerer": "breitbeinig",
    "breitbeinigeres": "breitbeinig",
    "breitbeiniges": "breitbeinig",
    "breitbeinigste": "breitbeinig",
    "breitbeinigstem": "breitbeinig",
    "breitbeinigsten": "breitbeinig",
    "breitbeinigster": "breitbeinig",
    "breitbeinigstes": "breitbeinig",
    "breite": "breit",
    "breitem": "breit",
    "breiten": "breit",
    "breitend": "breiten",
    "breitende": "breitend",
    "breitendem": "breitend",
    "breitenden": "breitend",
    "breitender": "breitend",
    "breitendes": "breitend",
    "breiter": "breit",
    "breitere": "breit",
    "breiterem": "breit",
    "breiteren": "breit",
    "breiterer": "breit",
    "breiteres": "breit",
    "breites": "breit",
    "breitest": "breiten",
    "breiteste": "breit",
    "breitestem": "breit",
    "breitesten": "breit",
    "breitester": "breit",
    "breitestes": "breit",
    "breitet": "breiten",
    "breitete": "breiten",
    "breiteten": "breiten",
    "breitetest": "breiten",
    "breitetet": "breiten",
    "breitgefächerte": "breitgefächert",
    "breitgefächertem": "breitgefächert",
    "breitgefächerten": "breitgefächert",
    "breitgefächerter": "breitgefächert",
    "breitgefächertes": "breitgefächert",
    "breitgeschlagen": "breitschlagen",
    "breitgeschlagene": "breitgeschlagen",
    "breitgeschlagenem": "breitgeschlagen",
    "breitgeschlagenen": "breitgeschlagen",
    "breitgeschlagener": "breitgeschlagen",
    "breitgeschlagenere": "breitgeschlagen",
    "breitgeschlagenerem": "breitgeschlagen",
    "breitgeschlageneren": "breitgeschlagen",
    "breitgeschlagenerer": "breitgeschlagen",
    "breitgeschlageneres": "breitgeschlagen",
    "breitgeschlagenes": "breitgeschlagen",
    "breitgeschlagenste": "breitgeschlagen",
    "breitgeschlagenstem": "breitgeschlagen",
    "breitgeschlagensten": "breitgeschlagen",
    "breitgeschlagenster": "breitgeschlagen",
    "breitgeschlagenstes": "breitgeschlagen",
    "breitgetreten": "breittreten",
    "breitgetretene": "breitgetreten",
    "breitgetretenem": "breitgetreten",
    "breitgetretenen": "breitgetreten",
    "breitgetretener": "breitgetreten",
    "breitgetretenere": "breitgetreten",
    "breitgetretenerem": "breitgetreten",
    "breitgetreteneren": "breitgetreten",
    "breitgetretenerer": "breitgetreten",
    "breitgetreteneres": "breitgetreten",
    "breitgetretenes": "breitgetreten",
    "breitgetretenste": "breitgetreten",
    "breitgetretenstem": "breitgetreten",
    "breitgetretensten": "breitgetreten",
    "breitgetretenster": "breitgetreten",
    "breitgetretenstes": "breitgetreten",
    "breitrandige": "breitrandig",
    "breitrandigem": "breitrandig",
    "breitrandigen": "breitrandig",
    "breitrandiger": "breitrandig",
    "breitrandigere": "breitrandig",
    "breitrandigerem": "breitrandig",
    "breitrandigeren": "breitrandig",
    "breitrandigerer": "breitrandig",
    "breitrandigeres": "breitrandig",
    "breitrandiges": "breitrandig",
    "breitrandigste": "breitrandig",
    "breitrandigstem": "breitrandig",
    "breitrandigsten": "breitrandig",
    "breitrandigster": "breitrandig",
    "breitrandigstes": "breitrandig",
    "breitschlage": "breitschlagen",
    "breitschlagend": "breitschlagen",
    "breitschlagende": "breitschlagend",
    "breitschlagendem": "breitschlagend",
    "breitschlagenden": "breitschlagend",
    "breitschlagender": "breitschlagend",
    "breitschlagendere": "breitschlagend",
    "breitschlagenderem": "breitschlagend",
    "breitschlagenderen": "breitschlagend",
    "breitschlagenderer": "breitschlagend",
    "breitschlagenderes": "breitschlagend",
    "breitschlagendes": "breitschlagend",
    "breitschlagendste": "breitschlagend",
    "breitschlagendstem": "breitschlagend",
    "breitschlagendsten": "breitschlagend",
    "breitschlagendster": "breitschlagend",
    "breitschlagendstes": "breitschlagend",
    "breitschlagest": "breitschlagen",
    "breitschlaget": "breitschlagen",
    "breitschlagt": "breitschlagen",
    "breitschlug": "breitschlagen",
    "breitschlugen": "breitschlagen",
    "breitschlugst": "breitschlagen",
    "breitschlugt": "breitschlagen",
    "breitschlägst": "breitschlagen",
    "breitschlägt": "breitschlagen",
    "breitschlüge": "breitschlagen",
    "breitschlügen": "breitschlagen",
    "breitschlügest": "breitschlagen",
    "breitschlüget": "breitschlagen",
    "breitschulterige": "breitschulterig",
    "breitschulterigem": "breitschulterig",
    "breitschulterigen": "breitschulterig",
    "breitschulteriger": "breitschulterig",
    "breitschulteriges": "breitschulterig",
    "breitspurigem": "breitspurig",
    "breitspurigen": "breitspurig",
    "breitspuriger": "breitspurig",
    "breitspuriges": "breitspurig",
    "breittrat": "breittreten",
    "breittraten": "breittreten",
    "breittratest": "breittreten",
    "breittratet": "breittreten",
    "breittrete": "breittreten",
    "breittretend": "breittreten",
    "breittretende": "breittretend",
    "breittretendem": "breittretend",
    "breittretenden": "breittretend",
    "breittretender": "breittretend",
    "breittretendere": "breittretend",
    "breittretenderem": "breittretend",
    "breittretenderen": "breittretend",
    "breittretenderer": "breittretend",
    "breittretenderes": "breittretend",
    "breittretendes": "breittretend",
    "breittretendste": "breittretend",
    "breittretendstem": "breittretend",
    "breittretendsten": "breittretend",
    "breittretendster": "breittretend",
    "breittretendstes": "breittretend",
    "breittretest": "breittreten",
    "breittretet": "breittreten",
    "breittritt": "breittreten",
    "breittrittst": "breittreten",
    "breitträte": "breittreten",
    "breitträten": "breittreten",
    "breitträtest": "breittreten",
    "breitträtet": "breittreten",
    "breitzuschlagen": "breitschlagen",
    "breitzutreten": "breittreten",
    "bremischem": "bremisch",
    "bremischen": "bremisch",
    "bremischer": "bremisch",
    "bremisches": "bremisch",
    "bremsend": "bremsen",
    "bremsende": "bremsend",
    "bremsendem": "bremsend",
    "bremsenden": "bremsend",
    "bremsender": "bremsend",
    "bremsendes": "bremsend",
    "bremsest": "bremsen",
    "bremset": "bremsen",
    "bremst": "bremsen",
    "bremste": "bremsen",
    "bremsten": "bremsen",
    "bremstest": "bremsen",
    "bremstet": "bremsen",
    "brennbarem": "brennbar",
    "brennbaren": "brennbar",
    "brennbarer": "brennbar",
    "brennbarere": "brennbar",
    "brennbarerem": "brennbar",
    "brennbareren": "brennbar",
    "brennbarerer": "brennbar",
    "brennbareres": "brennbar",
    "brennbares": "brennbar",
    "brennbarste": "brennbar",
    "brennbarstem": "brennbar",
    "brennbarsten": "brennbar",
    "brennbarster": "brennbar",
    "brennbarstes": "brennbar",
    "brenne": "brennen",
    "brennend": "brennen",
    "brennende": "brennend",
    "brennendem": "brennend",
    "brennenden": "brennend",
    "brennender": "brennend",
    "brennendere": "brennend",
    "brennenderem": "brennend",
    "brennenderen": "brennend",
    "brennenderer": "brennend",
    "brennenderes": "brennend",
    "brennendes": "brennend",
    "brennendste": "brennend",
    "brennendstem": "brennend",
    "brennendsten": "brennend",
    "brennendster": "brennend",
    "brennendstes": "brennend",
    "brennest": "brennen",
    "brennet": "brennen",
    "brennst": "brennen",
    "brennt": "brennen",
    "brenzligem": "brenzlig",
    "brenzligen": "brenzlig",
    "brenzliger": "brenzlig",
    "brenzligere": "brenzlig",
    "brenzligerem": "brenzlig",
    "brenzligeren": "brenzlig",
    "brenzligerer": "brenzlig",
    "brenzligeres": "brenzlig",
    "brenzliges": "brenzlig",
    "brenzligste": "brenzlig",
    "brenzligstem": "brenzlig",
    "brenzligsten": "brenzlig",
    "brenzligster": "brenzlig",
    "brenzligstes": "brenzlig",
    "brich": "brechen",
    "brichst": "brechen",
    "bricht": "brechen",
    "brieflichem": "brieflich",
    "brieflichen": "brieflich",
    "brieflicher": "brieflich",
    "briefliches": "brieflich",
    "briet": "braten",
    "briete": "braten",
    "brieten": "braten",
    "brietest": "braten",
    "brietet": "braten",
    "brilliere": "brillieren",
    "brillierend": "brillieren",
    "brillierende": "brillierend",
    "brillierendem": "brillierend",
    "brillierenden": "brillierend",
    "brillierender": "brillierend",
    "brillierendes": "brillierend",
    "brillierest": "brillieren",
    "brillieret": "brillieren",
    "brillierst": "brillieren",
    "brilliert": "brillieren",
    "brillierte": "brillieren",
    "brilliertem": "brilliert",
    "brillierten": "brillieren",
    "brillierter": "brilliert",
    "brilliertes": "brilliert",
    "brilliertest": "brillieren",
    "brilliertet": "brillieren",
    "bringe": "bringen",
    "bringend": "bringen",
    "bringende": "bringend",
    "bringendem": "bringend",
    "bringenden": "bringend",
    "bringender": "bringend",
    "bringendes": "bringend",
    "bringest": "bringen",
    "bringet": "bringen",
    "bringst": "bringen",
    "bringt": "bringen",
    "brisante": "brisant",
    "brisantem": "brisant",
    "brisanten": "brisant",
    "brisanter": "brisant",
    "brisantere": "brisant",
    "brisanterem": "brisant",
    "brisanteren": "brisant",
    "brisanterer": "brisant",
    "brisanteres": "brisant",
    "brisantes": "brisant",
    "brisanteste": "brisant",
    "brisantestem": "brisant",
    "brisantesten": "brisant",
    "brisantester": "brisant",
    "brisantestes": "brisant",
    "britischem": "britisch",
    "britischen": "britisch",
    "britischer": "britisch",
    "britischere": "britisch",
    "britischerem": "britisch",
    "britischeren": "britisch",
    "britischerer": "britisch",
    "britischeres": "britisch",
    "britisches": "britisch",
    "britischste": "britisch",
    "britischstem": "britisch",
    "britischsten": "britisch",
    "britischster": "britisch",
    "britischstes": "britisch",
    "brodele": "brodeln",
    "brodelnd": "brodeln",
    "brodelnde": "brodelnd",
    "brodelndem": "brodelnd",
    "brodelnden": "brodelnd",
    "brodelnder": "brodelnd",
    "brodelndere": "brodelnd",
    "brodelnderem": "brodelnd",
    "brodelnderen": "brodelnd",
    "brodelnderer": "brodelnd",
    "brodelnderes": "brodelnd",
    "brodelndes": "brodelnd",
    "brodelndste": "brodelnd",
    "brodelndstem": "brodelnd",
    "brodelndsten": "brodelnd",
    "brodelndster": "brodelnd",
    "brodelndstes": "brodelnd",
    "brodelst": "brodeln",
    "brodelt": "brodeln",
    "brodelte": "brodeln",
    "brodelten": "brodeln",
    "brodeltest": "brodeln",
    "brodeltet": "brodeln",
    "brodle": "brodeln",
    "bronzenem": "bronzen",
    "bronzenen": "bronzen",
    "bronzener": "bronzen",
    "bronzenere": "bronzen",
    "bronzenerem": "bronzen",
    "bronzeneren": "bronzen",
    "bronzenerer": "bronzen",
    "bronzeneres": "bronzen",
    "bronzenes": "bronzen",
    "bronzenste": "bronzen",
    "bronzenstem": "bronzen",
    "bronzensten": "bronzen",
    "bronzenster": "bronzen",
    "bronzenstes": "bronzen",
    "brotlosem": "brotlos",
    "brotlosen": "brotlos",
    "brotloser": "brotlos",
    "brotlosere": "brotlos",
    "brotloserem": "brotlos",
    "brotloseren": "brotlos",
    "brotloserer": "brotlos",
    "brotloseres": "brotlos",
    "brotloses": "brotlos",
    "brotloseste": "brotlos",
    "brotlosestem": "brotlos",
    "brotlosesten": "brotlos",
    "brotlosester": "brotlos",
    "brotlosestes": "brotlos",
    "bruchempfindlichem": "bruchempfindlich",
    "bruchempfindlichen": "bruchempfindlich",
    "bruchempfindlicher": "bruchempfindlich",
    "bruchempfindlichere": "bruchempfindlich",
    "bruchempfindlicherem": "bruchempfindlich",
    "bruchempfindlicheren": "bruchempfindlich",
    "bruchempfindlicherer": "bruchempfindlich",
    "bruchempfindlicheres": "bruchempfindlich",
    "bruchempfindliches": "bruchempfindlich",
    "bruchempfindlichste": "bruchempfindlich",
    "bruchempfindlichstem": "bruchempfindlich",
    "bruchempfindlichsten": "bruchempfindlich",
    "bruchempfindlichster": "bruchempfindlich",
    "bruchempfindlichstes": "bruchempfindlich",
    "bruchfestem": "bruchfest",
    "bruchfesten": "bruchfest",
    "bruchfester": "bruchfest",
    "bruchfestere": "bruchfest",
    "bruchfesterem": "bruchfest",
    "bruchfesteren": "bruchfest",
    "bruchfesterer": "bruchfest",
    "bruchfesteres": "bruchfest",
    "bruchfestes": "bruchfest",
    "bruchfesteste": "bruchfest",
    "bruchfestestem": "bruchfest",
    "bruchfestesten": "bruchfest",
    "bruchfestester": "bruchfest",
    "bruchfestestes": "bruchfest",
    "bruchlose": "bruchlos",
    "bruchlosem": "bruchlos",
    "bruchlosen": "bruchlos",
    "bruchloser": "bruchlos",
    "bruchlosere": "bruchlos",
    "bruchloserem": "bruchlos",
    "bruchloseren": "bruchlos",
    "bruchloserer": "bruchlos",
    "bruchloseres": "bruchlos",
    "bruchloses": "bruchlos",
    "bruchloseste": "bruchlos",
    "bruchlosestem": "bruchlos",
    "bruchlosesten": "bruchlos",
    "bruchlosester": "bruchlos",
    "bruchlosestes": "bruchlos",
    "bruchstückhaftem": "bruchstückhaft",
    "bruchstückhaften": "bruchstückhaft",
    "bruchstückhafter": "bruchstückhaft",
    "bruchstückhaftere": "bruchstückhaft",
    "bruchstückhafterem": "bruchstückhaft",
    "bruchstückhafteren": "bruchstückhaft",
    "bruchstückhafterer": "bruchstückhaft",
    "bruchstückhafteres": "bruchstückhaft",
    "bruchstückhaftes": "bruchstückhaft",
    "bruchstückhafteste": "bruchstückhaft",
    "bruchstückhaftestem": "bruchstückhaft",
    "bruchstückhaftesten": "bruchstückhaft",
    "bruchstückhaftester": "bruchstückhaft",
    "bruchstückhaftestes": "bruchstückhaft",
    "brumme": "brummen",
    "brummend": "brummen",
    "brummende": "brummend",
    "brummendem": "brummend",
    "brummenden": "brummend",
    "brummender": "brummend",
    "brummendere": "brummend",
    "brummenderem": "brummend",
    "brummenderen": "brummend",
    "brummenderer": "brummend",
    "brummenderes": "brummend",
    "brummendes": "brummend",
    "brummendste": "brummend",
    "brummendstem": "brummend",
    "brummendsten": "brummend",
    "brummendster": "brummend",
    "brummendstes": "brummend",
    "brummest": "brummen",
    "brummet": "brummen",
    "brummigem": "brummig",
    "brummigen": "brummig",
    "brummiger": "brummig",
    "brummigere": "brummig",
    "brummigerem": "brummig",
    "brummigeren": "brummig",
    "brummigerer": "brummig",
    "brummigeres": "brummig",
    "brummiges": "brummig",
    "brummigste": "brummig",
    "brummigstem": "brummig",
    "brummigsten": "brummig",
    "brummigster": "brummig",
    "brummigstes": "brummig",
    "brummst": "brummen",
    "brummt": "brummen",
    "brummte": "brummen",
    "brummten": "brummen",
    "brummtest": "brummen",
    "brummtet": "brummen",
    "brutalem": "brutal",
    "brutalen": "brutal",
    "brutaler": "brutal",
    "brutalere": "brutal",
    "brutalerem": "brutal",
    "brutaleren": "brutal",
    "brutalerer": "brutal",
    "brutaleres": "brutal",
    "brutales": "brutal",
    "brutalstem": "brutal",
    "brutalsten": "brutal",
    "brutalster": "brutal",
    "brutalstes": "brutal",
    "brutzele": "brutzeln",
    "brutzelnd": "brutzeln",
    "brutzelnde": "brutzelnd",
    "brutzelndem": "brutzelnd",
    "brutzelnden": "brutzelnd",
    "brutzelnder": "brutzelnd",
    "brutzelndere": "brutzelnd",
    "brutzelnderem": "brutzelnd",
    "brutzelnderen": "brutzelnd",
    "brutzelnderer": "brutzelnd",
    "brutzelnderes": "brutzelnd",
    "brutzelndes": "brutzelnd",
    "brutzelndste": "brutzelnd",
    "brutzelndstem": "brutzelnd",
    "brutzelndsten": "brutzelnd",
    "brutzelndster": "brutzelnd",
    "brutzelndstes": "brutzelnd",
    "brutzelst": "brutzeln",
    "brutzelt": "brutzeln",
    "brutzelte": "brutzeln",
    "brutzelten": "brutzeln",
    "brutzeltest": "brutzeln",
    "brutzeltet": "brutzeln",
    "brutzle": "brutzeln",
    "bräche": "brechen",
    "brächen": "brechen",
    "brächest": "brechen",
    "brächet": "brechen",
    "brächte": "bringen",
    "brächten": "bringen",
    "brächtest": "bringen",
    "brächtet": "bringen",
    "brät": "braten",
    "brätst": "braten",
    "bräunlichem": "bräunlich",
    "bräunlichen": "bräunlich",
    "bräunlicher": "bräunlich",
    "bräunliches": "bräunlich",
    "bröckele": "bröckeln",
    "bröckelnd": "bröckeln",
    "bröckelnde": "bröckelnd",
    "bröckelndem": "bröckelnd",
    "bröckelnden": "bröckelnd",
    "bröckelnder": "bröckelnd",
    "bröckelndere": "bröckelnd",
    "bröckelnderem": "bröckelnd",
    "bröckelnderen": "bröckelnd",
    "bröckelnderer": "bröckelnd",
    "bröckelnderes": "bröckelnd",
    "bröckelndes": "bröckelnd",
    "bröckelndste": "bröckelnd",
    "bröckelndstem": "bröckelnd",
    "bröckelndsten": "bröckelnd",
    "bröckelndster": "bröckelnd",
    "bröckelndstes": "bröckelnd",
    "bröckelst": "bröckeln",
    "bröckelt": "bröckeln",
    "bröckelte": "bröckeln",
    "bröckelten": "bröckeln",
    "bröckeltest": "bröckeln",
    "bröckeltet": "bröckeln",
    "bröckle": "bröckeln",
    "bröcklige": "bröcklig",
    "bröckligem": "bröcklig",
    "bröckligen": "bröcklig",
    "bröckliger": "bröcklig",
    "bröckligere": "bröcklig",
    "bröckligerem": "bröcklig",
    "bröckligeren": "bröcklig",
    "bröckligerer": "bröcklig",
    "bröckligeres": "bröcklig",
    "bröckliges": "bröcklig",
    "bröckligste": "bröcklig",
    "bröckligstem": "bröcklig",
    "bröckligsten": "bröcklig",
    "bröckligster": "bröcklig",
    "bröckligstes": "bröcklig",
    "brüchigem": "brüchig",
    "brüchigen": "brüchig",
    "brüchiger": "brüchig",
    "brüchigere": "brüchig",
    "brüchigerem": "brüchig",
    "brüchigeren": "brüchig",
    "brüchigerer": "brüchig",
    "brüchigeres": "brüchig",
    "brüchiges": "brüchig",
    "brüchigste": "brüchig",
    "brüchigstem": "brüchig",
    "brüchigsten": "brüchig",
    "brüchigster": "brüchig",
    "brüchigstes": "brüchig",
    "brüderlichem": "brüderlich",
    "brüderlichen": "brüderlich",
    "brüderlicher": "brüderlich",
    "brüderlichere": "brüderlich",
    "brüderlicherem": "brüderlich",
    "brüderlicheren": "brüderlich",
    "brüderlicherer": "brüderlich",
    "brüderlicheres": "brüderlich",
    "brüderliches": "brüderlich",
    "brüderlichste": "brüderlich",
    "brüderlichstem": "brüderlich",
    "brüderlichsten": "brüderlich",
    "brüderlichster": "brüderlich",
    "brüderlichstes": "brüderlich",
    "brühend": "brühen",
    "brühende": "brühend",
    "brühendem": "brühend",
    "brühenden": "brühend",
    "brühender": "brühend",
    "brühendere": "brühend",
    "brühenderem": "brühend",
    "brühenderen": "brühend",
    "brühenderer": "brühend",
    "brühenderes": "brühend",
    "brühendes": "brühend",
    "brühendste": "brühend",
    "brühendstem": "brühend",
    "brühendsten": "brühend",
    "brühendster": "brühend",
    "brühendstes": "brühend",
    "brühest": "brühen",
    "brühet": "brühen",
    "brühst": "brühen",
    "brüht": "brühen",
    "brühte": "brühen",
    "brühten": "brühen",
    "brühtest": "brühen",
    "brühtet": "brühen",
    "brühwarme": "brühwarm",
    "brühwarmem": "brühwarm",
    "brühwarmen": "brühwarm",
    "brühwarmer": "brühwarm",
    "brühwarmes": "brühwarm",
    "brülle": "brüllen",
    "brüllend": "brüllen",
    "brüllende": "brüllend",
    "brüllendem": "brüllend",
    "brüllenden": "brüllend",
    "brüllender": "brüllend",
    "brüllendere": "brüllend",
    "brüllenderem": "brüllend",
    "brüllenderen": "brüllend",
    "brüllenderer": "brüllend",
    "brüllenderes": "brüllend",
    "brüllendes": "brüllend",
    "brüllendste": "brüllend",
    "brüllendstem": "brüllend",
    "brüllendsten": "brüllend",
    "brüllendster": "brüllend",
    "brüllendstes": "brüllend",
    "brüllest": "brüllen",
    "brüllet": "brüllen",
    "brüllst": "brüllen",
    "brüllt": "brüllen",
    "brüllte": "brüllen",
    "brüllten": "brüllen",
    "brülltest": "brüllen",
    "brülltet": "brüllen",
    "brünettem": "brünett",
    "brünetten": "brünett",
    "brünetter": "brünett",
    "brünettes": "brünett",
    "brüskiere": "brüskieren",
    "brüskierend": "brüskieren",
    "brüskierende": "brüskierend",
    "brüskierendem": "brüskierend",
    "brüskierenden": "brüskierend",
    "brüskierender": "brüskierend",
    "brüskierendere": "brüskierend",
    "brüskierenderem": "brüskierend",
    "brüskierenderen": "brüskierend",
    "brüskierenderer": "brüskierend",
    "brüskierenderes": "brüskierend",
    "brüskierendes": "brüskierend",
    "brüskierendste": "brüskierend",
    "brüskierendstem": "brüskierend",
    "brüskierendsten": "brüskierend",
    "brüskierendster": "brüskierend",
    "brüskierendstes": "brüskierend",
    "brüskierest": "brüskieren",
    "brüskieret": "brüskieren",
    "brüskierst": "brüskieren",
    "brüskiert": "brüskieren",
    "brüskierte": "brüskieren",
    "brüskiertem": "brüskiert",
    "brüskierten": "brüskieren",
    "brüskierter": "brüskiert",
    "brüskiertere": "brüskiert",
    "brüskierterem": "brüskiert",
    "brüskierteren": "brüskiert",
    "brüskierterer": "brüskiert",
    "brüskierteres": "brüskiert",
    "brüskiertes": "brüskiert",
    "brüskiertest": "brüskieren",
    "brüskierteste": "brüskiert",
    "brüskiertestem": "brüskiert",
    "brüskiertesten": "brüskiert",
    "brüskiertester": "brüskiert",
    "brüskiertestes": "brüskiert",
    "brüskiertet": "brüskieren",
    "brüstend": "brüsten",
    "brüstende": "brüstend",
    "brüstendem": "brüstend",
    "brüstenden": "brüstend",
    "brüstender": "brüstend",
    "brüstendere": "brüstend",
    "brüstenderem": "brüstend",
    "brüstenderen": "brüstend",
    "brüstenderer": "brüstend",
    "brüstenderes": "brüstend",
    "brüstendes": "brüstend",
    "brüstendste": "brüstend",
    "brüstendstem": "brüstend",
    "brüstendsten": "brüstend",
    "brüstendster": "brüstend",
    "brüstendstes": "brüstend",
    "brüstest": "brüsten",
    "brüstet": "brüsten",
    "brüstete": "brüsten",
    "brüsteten": "brüsten",
    "brüstetest": "brüsten",
    "brüstetet": "brüsten",
    "brüte": "brüten",
    "brütend": "brüten",
    "brütende": "brütend",
    "brütendem": "brütend",
    "brütenden": "brütend",
    "brütender": "brütend",
    "brütendere": "brütend",
    "brütenderem": "brütend",
    "brütenderen": "brütend",
    "brütenderer": "brütend",
    "brütenderes": "brütend",
    "brütendes": "brütend",
    "brütendste": "brütend",
    "brütendstem": "brütend",
    "brütendsten": "brütend",
    "brütendster": "brütend",
    "brütendstes": "brütend",
    "brütest": "brüten",
    "brütet": "brüten",
    "brütete": "brüten",
    "brüteten": "brüten",
    "brütetest": "brüten",
    "brütetet": "brüten",
    "bubenhaftem": "bubenhaft",
    "bubenhaften": "bubenhaft",
    "bubenhafter": "bubenhaft",
    "bubenhaftere": "bubenhaft",
    "bubenhafterem": "bubenhaft",
    "bubenhafteren": "bubenhaft",
    "bubenhafterer": "bubenhaft",
    "bubenhafteres": "bubenhaft",
    "bubenhaftes": "bubenhaft",
    "bubenhafteste": "bubenhaft",
    "bubenhaftestem": "bubenhaft",
    "bubenhaftesten": "bubenhaft",
    "bubenhaftester": "bubenhaft",
    "bubenhaftestes": "bubenhaft",
    "buchend": "buchen",
    "buchende": "buchend",
    "buchendem": "buchend",
    "buchenden": "buchend",
    "buchender": "buchend",
    "buchendes": "buchend",
    "buchest": "buchen",
    "buchet": "buchen",
    "buchst": "buchen",
    "buchstabiere": "buchstabieren",
    "buchstabierend": "buchstabieren",
    "buchstabierende": "buchstabierend",
    "buchstabierendem": "buchstabierend",
    "buchstabierenden": "buchstabierend",
    "buchstabierender": "buchstabierend",
    "buchstabierendes": "buchstabierend",
    "buchstabierest": "buchstabieren",
    "buchstabieret": "buchstabieren",
    "buchstabierst": "buchstabieren",
    "buchstabiert": "buchstabieren",
    "buchstabierte": "buchstabieren",
    "buchstabiertem": "buchstabiert",
    "buchstabierten": "buchstabieren",
    "buchstabierter": "buchstabiert",
    "buchstabiertes": "buchstabiert",
    "buchstabiertest": "buchstabieren",
    "buchstabiertet": "buchstabieren",
    "buchstäbliche": "buchstäblich",
    "buchstäblichem": "buchstäblich",
    "buchstäblichen": "buchstäblich",
    "buchstäblicher": "buchstäblich",
    "buchstäblichere": "buchstäblich",
    "buchstäblicherem": "buchstäblich",
    "buchstäblicheren": "buchstäblich",
    "buchstäblicherer": "buchstäblich",
    "buchstäblicheres": "buchstäblich",
    "buchstäbliches": "buchstäblich",
    "buchstäblichste": "buchstäblich",
    "buchstäblichstem": "buchstäblich",
    "buchstäblichsten": "buchstäblich",
    "buchstäblichster": "buchstäblich",
    "buchstäblichstes": "buchstäblich",
    "bucht": "buchen",
    "buchte": "buchten",
    "buchten": "buchen",
    "buchtend": "buchten",
    "buchtende": "buchtend",
    "buchtendem": "buchtend",
    "buchtenden": "buchtend",
    "buchtender": "buchtend",
    "buchtendes": "buchtend",
    "buchtest": "buchten",
    "buchtet": "buchten",
    "buchtete": "buchten",
    "buchteten": "buchten",
    "buchtetest": "buchten",
    "buchtetet": "buchten",
    "buckligem": "bucklig",
    "buckligen": "bucklig",
    "buckliger": "bucklig",
    "buckligere": "bucklig",
    "buckligerem": "bucklig",
    "buckligeren": "bucklig",
    "buckligerer": "bucklig",
    "buckligeres": "bucklig",
    "buckliges": "bucklig",
    "buckligste": "bucklig",
    "buckligstem": "bucklig",
    "buckligsten": "bucklig",
    "buckligster": "bucklig",
    "buckligstes": "bucklig",
    "buddele": "buddeln",
    "buddelnd": "buddeln",
    "buddelnde": "buddelnd",
    "buddelndem": "buddelnd",
    "buddelnden": "buddelnd",
    "buddelnder": "buddelnd",
    "buddelndere": "buddelnd",
    "buddelnderem": "buddelnd",
    "buddelnderen": "buddelnd",
    "buddelnderer": "buddelnd",
    "buddelnderes": "buddelnd",
    "buddelndes": "buddelnd",
    "buddelndste": "buddelnd",
    "buddelndstem": "buddelnd",
    "buddelndsten": "buddelnd",
    "buddelndster": "buddelnd",
    "buddelndstes": "buddelnd",
    "buddelst": "buddeln",
    "buddelt": "buddeln",
    "buddelte": "buddeln",
    "buddelten": "buddeln",
    "buddeltest": "buddeln",
    "buddeltet": "buddeln",
    "buddle": "buddeln",
    "bugsiere": "bugsieren",
    "bugsierend": "bugsieren",
    "bugsierende": "bugsierend",
    "bugsierendem": "bugsierend",
    "bugsierenden": "bugsierend",
    "bugsierender": "bugsierend",
    "bugsierendes": "bugsierend",
    "bugsierest": "bugsieren",
    "bugsieret": "bugsieren",
    "bugsierst": "bugsieren",
    "bugsiert": "bugsieren",
    "bugsierte": "bugsieren",
    "bugsiertem": "bugsiert",
    "bugsierten": "bugsieren",
    "bugsierter": "bugsiert",
    "bugsiertes": "bugsiert",
    "bugsiertest": "bugsieren",
    "bugsiertet": "bugsieren",
    "buhe": "buhen",
    "buhend": "buhen",
    "buhende": "buhend",
    "buhendem": "buhend",
    "buhenden": "buhend",
    "buhender": "buhend",
    "buhendere": "buhend",
    "buhenderem": "buhend",
    "buhenderen": "buhend",
    "buhenderer": "buhend",
    "buhenderes": "buhend",
    "buhendes": "buhend",
    "buhendste": "buhend",
    "buhendstem": "buhend",
    "buhendsten": "buhend",
    "buhendster": "buhend",
    "buhendstes": "buhend",
    "buhest": "buhen",
    "buhet": "buhen",
    "buhle": "buhlen",
    "buhlend": "buhlen",
    "buhlende": "buhlend",
    "buhlendem": "buhlend",
    "buhlenden": "buhlend",
    "buhlender": "buhlend",
    "buhlendere": "buhlend",
    "buhlenderem": "buhlend",
    "buhlenderen": "buhlend",
    "buhlenderer": "buhlend",
    "buhlenderes": "buhlend",
    "buhlendes": "buhlend",
    "buhlendste": "buhlend",
    "buhlendstem": "buhlend",
    "buhlendsten": "buhlend",
    "buhlendster": "buhlend",
    "buhlendstes": "buhlend",
    "buhlest": "buhlen",
    "buhlet": "buhlen",
    "buhlst": "buhlen",
    "buhlt": "buhlen",
    "buhlte": "buhlen",
    "buhlten": "buhlen",
    "buhltest": "buhlen",
    "buhltet": "buhlen",
    "buhst": "buhen",
    "buht": "buhen",
    "buhte": "buhen",
    "buhten": "buhen",
    "buhtest": "buhen",
    "buhtet": "buhen",
    "bukkalem": "bukkal",
    "bukkalen": "bukkal",
    "bukkaler": "bukkal",
    "bukkales": "bukkal",
    "bulgarischem": "bulgarisch",
    "bulgarischen": "bulgarisch",
    "bulgarischer": "bulgarisch",
    "bulgarisches": "bulgarisch",
    "bullere": "bullern",
    "bullernd": "bullern",
    "bullernde": "bullernd",
    "bullerndem": "bullernd",
    "bullernden": "bullernd",
    "bullernder": "bullernd",
    "bullerndere": "bullernd",
    "bullernderem": "bullernd",
    "bullernderen": "bullernd",
    "bullernderer": "bullernd",
    "bullernderes": "bullernd",
    "bullerndes": "bullernd",
    "bullerndste": "bullernd",
    "bullerndstem": "bullernd",
    "bullerndsten": "bullernd",
    "bullerndster": "bullernd",
    "bullerndstes": "bullernd",
    "bullerst": "bullern",
    "bullert": "bullern",
    "bullerte": "bullern",
    "bullerten": "bullern",
    "bullertest": "bullern",
    "bullertet": "bullern",
    "bulligem": "bullig",
    "bulligen": "bullig",
    "bulliger": "bullig",
    "bulligere": "bullig",
    "bulligerem": "bullig",
    "bulligeren": "bullig",
    "bulligerer": "bullig",
    "bulligeres": "bullig",
    "bulliges": "bullig",
    "bulligste": "bullig",
    "bulligstem": "bullig",
    "bulligsten": "bullig",
    "bulligster": "bullig",
    "bulligstes": "bullig",
    "bummele": "bummeln",
    "bummelnd": "bummeln",
    "bummelnde": "bummelnd",
    "bummelndem": "bummelnd",
    "bummelnden": "bummelnd",
    "bummelnder": "bummelnd",
    "bummelndere": "bummelnd",
    "bummelnderem": "bummelnd",
    "bummelnderen": "bummelnd",
    "bummelnderer": "bummelnd",
    "bummelnderes": "bummelnd",
    "bummelndes": "bummelnd",
    "bummelndste": "bummelnd",
    "bummelndstem": "bummelnd",
    "bummelndsten": "bummelnd",
    "bummelndster": "bummelnd",
    "bummelndstes": "bummelnd",
    "bummelst": "bummeln",
    "bummelt": "bummeln",
    "bummelte": "bummeln",
    "bummelten": "bummeln",
    "bummeltest": "bummeln",
    "bummeltet": "bummeln",
    "bummle": "bummeln",
    "bumse": "bumsen",
    "bumsend": "bumsen",
    "bumsende": "bumsend",
    "bumsendem": "bumsend",
    "bumsenden": "bumsend",
    "bumsender": "bumsend",
    "bumsendere": "bumsend",
    "bumsenderem": "bumsend",
    "bumsenderen": "bumsend",
    "bumsenderer": "bumsend",
    "bumsenderes": "bumsend",
    "bumsendes": "bumsend",
    "bumsendste": "bumsend",
    "bumsendstem": "bumsend",
    "bumsendsten": "bumsend",
    "bumsendster": "bumsend",
    "bumsendstes": "bumsend",
    "bumsest": "bumsen",
    "bumset": "bumsen",
    "bumst": "bumsen",
    "bumste": "bumsen",
    "bumsten": "bumsen",
    "bumstest": "bumsen",
    "bumstet": "bumsen",
    "bundesdeutschem": "bundesdeutsch",
    "bundesdeutschen": "bundesdeutsch",
    "bundesdeutscher": "bundesdeutsch",
    "bundesdeutsches": "bundesdeutsch",
    "bundeseigene": "bundeseigen",
    "bundeseigenem": "bundeseigen",
    "bundeseigenen": "bundeseigen",
    "bundeseigener": "bundeseigen",
    "bundeseigenes": "bundeseigen",
    "bundesgenössische": "bundesgenössisch",
    "bundesgenössischem": "bundesgenössisch",
    "bundesgenössischen": "bundesgenössisch",
    "bundesgenössischer": "bundesgenössisch",
    "bundesgenössisches": "bundesgenössisch",
    "bundesrepublikanischem": "bundesrepublikanisch",
    "bundesrepublikanischen": "bundesrepublikanisch",
    "bundesrepublikanischer": "bundesrepublikanisch",
    "bundesrepublikanisches": "bundesrepublikanisch",
    "bundesweitem": "bundesweit",
    "bundesweiten": "bundesweit",
    "bundesweiter": "bundesweit",
    "bundesweites": "bundesweit",
    "bundweisem": "bundweise",
    "bundweisen": "bundweise",
    "bundweiser": "bundweise",
    "bundweises": "bundweise",
    "bunkere": "bunkern",
    "bunkernd": "bunkern",
    "bunkernde": "bunkernd",
    "bunkerndem": "bunkernd",
    "bunkernden": "bunkernd",
    "bunkernder": "bunkernd",
    "bunkerndere": "bunkernd",
    "bunkernderem": "bunkernd",
    "bunkernderen": "bunkernd",
    "bunkernderer": "bunkernd",
    "bunkernderes": "bunkernd",
    "bunkerndes": "bunkernd",
    "bunkerndste": "bunkernd",
    "bunkerndstem": "bunkernd",
    "bunkerndsten": "bunkernd",
    "bunkerndster": "bunkernd",
    "bunkerndstes": "bunkernd",
    "bunkerst": "bunkern",
    "bunkert": "bunkern",
    "bunkerte": "bunkern",
    "bunkerten": "bunkern",
    "bunkertest": "bunkern",
    "bunkertet": "bunkern",
    "bunte": "bunt",
    "buntem": "bunt",
    "bunten": "bunt",
    "bunter": "bunt",
    "buntere": "bunt",
    "bunterem": "bunt",
    "bunteren": "bunt",
    "bunterer": "bunt",
    "bunteres": "bunt",
    "buntes": "bunt",
    "bunteste": "bunt",
    "buntestem": "bunt",
    "buntesten": "bunt",
    "buntester": "bunt",
    "buntestes": "bunt",
    "burgähnliche": "burgähnlich",
    "burgähnlichem": "burgähnlich",
    "burgähnlichen": "burgähnlich",
    "burgähnlicher": "burgähnlich",
    "burgähnliches": "burgähnlich",
    "buschigem": "buschig",
    "buschigen": "buschig",
    "buschiger": "buschig",
    "buschigere": "buschig",
    "buschigerem": "buschig",
    "buschigeren": "buschig",
    "buschigerer": "buschig",
    "buschigeres": "buschig",
    "buschiges": "buschig",
    "buschigste": "buschig",
    "buschigstem": "buschig",
    "buschigsten": "buschig",
    "buschigster": "buschig",
    "buschigstes": "buschig",
    "buttere": "buttern",
    "butternd": "buttern",
    "butternde": "butternd",
    "butterndem": "butternd",
    "butternden": "butternd",
    "butternder": "butternd",
    "butterndes": "butternd",
    "butterst": "buttern",
    "buttert": "buttern",
    "butterte": "buttern",
    "butterten": "buttern",
    "buttertest": "buttern",
    "buttertet": "buttern",
    "butterweiche": "butterweich",
    "butterweichem": "butterweich",
    "butterweichen": "butterweich",
    "butterweicher": "butterweich",
    "butterweichere": "butterweich",
    "butterweicherem": "butterweich",
    "butterweicheren": "butterweich",
    "butterweicherer": "butterweich",
    "butterweicheres": "butterweich",
    "butterweiches": "butterweich",
    "butterweichste": "butterweich",
    "butterweichstem": "butterweich",
    "butterweichsten": "butterweich",
    "butterweichster": "butterweich",
    "butterweichstes": "butterweich",
    "bußfertige": "bußfertig",
    "bußfertigem": "bußfertig",
    "bußfertigen": "bußfertig",
    "bußfertiger": "bußfertig",
    "bußfertigere": "bußfertig",
    "bußfertigerem": "bußfertig",
    "bußfertigeren": "bußfertig",
    "bußfertigerer": "bußfertig",
    "bußfertigeres": "bußfertig",
    "bußfertiges": "bußfertig",
    "bußfertigste": "bußfertig",
    "bußfertigstem": "bußfertig",
    "bußfertigsten": "bußfertig",
    "bußfertigster": "bußfertig",
    "bußfertigstes": "bußfertig",
    "byzantinischem": "byzantinisch",
    "byzantinischen": "byzantinisch",
    "byzantinischer": "byzantinisch",
    "byzantinisches": "byzantinisch",
    "bände": "binden",
    "bänden": "binden",
    "bändest": "binden",
    "bändet": "binden",
    "bändige": "bändigen",
    "bändigend": "bändigen",
    "bändigende": "bändigend",
    "bändigendem": "bändigend",
    "bändigenden": "bändigend",
    "bändigender": "bändigend",
    "bändigendere": "bändigend",
    "bändigenderem": "bändigend",
    "bändigenderen": "bändigend",
    "bändigenderer": "bändigend",
    "bändigenderes": "bändigend",
    "bändigendes": "bändigend",
    "bändigendste": "bändigend",
    "bändigendstem": "bändigend",
    "bändigendsten": "bändigend",
    "bändigendster": "bändigend",
    "bändigendstes": "bändigend",
    "bändigest": "bändigen",
    "bändiget": "bändigen",
    "bändigst": "bändigen",
    "bändigt": "bändigen",
    "bändigte": "bändigen",
    "bändigten": "bändigen",
    "bändigtest": "bändigen",
    "bändigtet": "bändigen",
    "bärge": "bergen",
    "bärgen": "bergen",
    "bärgest": "bergen",
    "bärget": "bergen",
    "bärste": "bersten",
    "bärsten": "bersten",
    "bärstest": "bersten",
    "bärstet": "bersten",
    "bärtigem": "bärtig",
    "bärtigen": "bärtig",
    "bärtiger": "bärtig",
    "bärtiges": "bärtig",
    "bäte": "bitten",
    "bäten": "bitten",
    "bätest": "bitten",
    "bätet": "bitten",
    "bäuerischem": "bäuerisch",
    "bäuerischen": "bäuerisch",
    "bäuerischer": "bäuerisch",
    "bäuerischere": "bäuerisch",
    "bäuerischerem": "bäuerisch",
    "bäuerischeren": "bäuerisch",
    "bäuerischerer": "bäuerisch",
    "bäuerischeres": "bäuerisch",
    "bäuerisches": "bäuerisch",
    "bäuerischste": "bäuerisch",
    "bäuerischstem": "bäuerisch",
    "bäuerischsten": "bäuerisch",
    "bäuerischster": "bäuerisch",
    "bäuerischstes": "bäuerisch",
    "bäuerliche": "bäuerlich",
    "bäuerlichem": "bäuerlich",
    "bäuerlichen": "bäuerlich",
    "bäuerlicher": "bäuerlich",
    "bäuerlichere": "bäuerlich",
    "bäuerlicherem": "bäuerlich",
    "bäuerlicheren": "bäuerlich",
    "bäuerlicherer": "bäuerlich",
    "bäuerlicheres": "bäuerlich",
    "bäuerliches": "bäuerlich",
    "bäuerlichste": "bäuerlich",
    "bäuerlichstem": "bäuerlich",
    "bäuerlichsten": "bäuerlich",
    "bäuerlichster": "bäuerlich",
    "bäuerlichstes": "bäuerlich",
    "bäumend": "bäumen",
    "bäumende": "bäumend",
    "bäumendem": "bäumend",
    "bäumenden": "bäumend",
    "bäumender": "bäumend",
    "bäumendes": "bäumend",
    "bäumest": "bäumen",
    "bäumet": "bäumen",
    "bäumst": "bäumen",
    "bäumt": "bäumen",
    "bäumte": "bäumen",
    "bäumten": "bäumen",
    "bäumtest": "bäumen",
    "bäumtet": "bäumen",
    "böge": "biegen",
    "bögen": "biegen",
    "bögest": "biegen",
    "böget": "biegen",
    "böhmischem": "böhmisch",
    "böhmischen": "böhmisch",
    "böhmischer": "böhmisch",
    "böhmisches": "böhmisch",
    "böigem": "böig",
    "böigen": "böig",
    "böiger": "böig",
    "böigere": "böig",
    "böigerem": "böig",
    "böigeren": "böig",
    "böigerer": "böig",
    "böigeres": "böig",
    "böiges": "böig",
    "böigste": "böig",
    "böigstem": "böig",
    "böigsten": "böig",
    "böigster": "böig",
    "böigstes": "böig",
    "bölke": "bölken",
    "bölkend": "bölken",
    "bölkende": "bölkend",
    "bölkendem": "bölkend",
    "bölkenden": "bölkend",
    "bölkender": "bölkend",
    "bölkendere": "bölkend",
    "bölkenderem": "bölkend",
    "bölkenderen": "bölkend",
    "bölkenderer": "bölkend",
    "bölkenderes": "bölkend",
    "bölkendes": "bölkend",
    "bölkendste": "bölkend",
    "bölkendstem": "bölkend",
    "bölkendsten": "bölkend",
    "bölkendster": "bölkend",
    "bölkendstes": "bölkend",
    "bölkest": "bölken",
    "bölket": "bölken",
    "bölkst": "bölken",
    "bölkt": "bölken",
    "bölkte": "bölken",
    "bölkten": "bölken",
    "bölktest": "bölken",
    "bölktet": "bölken",
    "böllere": "böllern",
    "böllernd": "böllern",
    "böllernde": "böllernd",
    "böllerndem": "böllernd",
    "böllernden": "böllernd",
    "böllernder": "böllernd",
    "böllerndere": "böllernd",
    "böllernderem": "böllernd",
    "böllernderen": "böllernd",
    "böllernderer": "böllernd",
    "böllernderes": "böllernd",
    "böllerndes": "böllernd",
    "böllerndste": "böllernd",
    "böllerndstem": "böllernd",
    "böllerndsten": "böllernd",
    "böllerndster": "böllernd",
    "böllerndstes": "böllernd",
    "böllerst": "böllern",
    "böllert": "böllern",
    "böllerte": "böllern",
    "böllerten": "böllern",
    "böllertest": "böllern",
    "böllertet": "böllern",
    "bösartigem": "bösartig",
    "bösartigen": "bösartig",
    "bösartiger": "bösartig",
    "bösartigere": "bösartig",
    "bösartigerem": "bösartig",
    "bösartigeren": "bösartig",
    "bösartigerer": "bösartig",
    "bösartigeres": "bösartig",
    "bösartiges": "bösartig",
    "bösartigste": "bösartig",
    "bösartigstem": "bösartig",
    "bösartigsten": "bösartig",
    "bösartigster": "bösartig",
    "bösartigstes": "bösartig",
    "bösem": "böse",
    "bösen": "böse",
    "böser": "böse",
    "bösere": "böse",
    "böserem": "böse",
    "böseren": "böse",
    "böserer": "böse",
    "böseres": "böse",
    "böses": "böse",
    "böseste": "böse",
    "bösestem": "böse",
    "bösesten": "böse",
    "bösester": "böse",
    "bösestes": "böse",
    "böswilligem": "böswillig",
    "böswilligen": "böswillig",
    "böswilliger": "böswillig",
    "böswilligere": "böswillig",
    "böswilligerem": "böswillig",
    "böswilligeren": "böswillig",
    "böswilligerer": "böswillig",
    "böswilligeres": "böswillig",
    "böswilliges": "böswillig",
    "böswilligste": "böswillig",
    "böswilligstem": "böswillig",
    "böswilligsten": "böswillig",
    "böswilligster": "böswillig",
    "böswilligstes": "böswillig",
    "böte": "bieten",
    "böten": "bieten",
    "bötest": "bieten",
    "bötet": "bieten",
    "bübischem": "bübisch",
    "bübischen": "bübisch",
    "bübischer": "bübisch",
    "bübischere": "bübisch",
    "bübischerem": "bübisch",
    "bübischeren": "bübisch",
    "bübischerer": "bübisch",
    "bübischeres": "bübisch",
    "bübisches": "bübisch",
    "bübischste": "bübisch",
    "bübischstem": "bübisch",
    "bübischsten": "bübisch",
    "bübischster": "bübisch",
    "bübischstes": "bübisch",
    "büffele": "büffeln",
    "büffelnd": "büffeln",
    "büffelnde": "büffelnd",
    "büffelndem": "büffelnd",
    "büffelnden": "büffelnd",
    "büffelnder": "büffelnd",
    "büffelndere": "büffelnd",
    "büffelnderem": "büffelnd",
    "büffelnderen": "büffelnd",
    "büffelnderer": "büffelnd",
    "büffelnderes": "büffelnd",
    "büffelndes": "büffelnd",
    "büffelndste": "büffelnd",
    "büffelndstem": "büffelnd",
    "büffelndsten": "büffelnd",
    "büffelndster": "büffelnd",
    "büffelndstes": "büffelnd",
    "büffelst": "büffeln",
    "büffelt": "büffeln",
    "büffelte": "büffeln",
    "büffelten": "büffeln",
    "büffeltest": "büffeln",
    "büffeltet": "büffeln",
    "büffle": "büffeln",
    "bügele": "bügeln",
    "bügelfestem": "bügelfest",
    "bügelfesten": "bügelfest",
    "bügelfester": "bügelfest",
    "bügelfestere": "bügelfest",
    "bügelfesterem": "bügelfest",
    "bügelfesteren": "bügelfest",
    "bügelfesterer": "bügelfest",
    "bügelfesteres": "bügelfest",
    "bügelfestes": "bügelfest",
    "bügelfesteste": "bügelfest",
    "bügelfestestem": "bügelfest",
    "bügelfestesten": "bügelfest",
    "bügelfestester": "bügelfest",
    "bügelfestestes": "bügelfest",
    "bügelnd": "bügeln",
    "bügelnde": "bügelnd",
    "bügelndem": "bügelnd",
    "bügelnden": "bügelnd",
    "bügelnder": "bügelnd",
    "bügelndes": "bügelnd",
    "bügelst": "bügeln",
    "bügelt": "bügeln",
    "bügelte": "bügeln",
    "bügelten": "bügeln",
    "bügeltest": "bügeln",
    "bügeltet": "bügeln",
    "bügle": "bügeln",
    "bühnenfähigem": "bühnenfähig",
    "bühnenfähigen": "bühnenfähig",
    "bühnenfähiger": "bühnenfähig",
    "bühnenfähiges": "bühnenfähig",
    "bühnenreife": "bühnenreif",
    "bühnenreifem": "bühnenreif",
    "bühnenreifen": "bühnenreif",
    "bühnenreifer": "bühnenreif",
    "bühnenreifere": "bühnenreif",
    "bühnenreiferem": "bühnenreif",
    "bühnenreiferen": "bühnenreif",
    "bühnenreiferer": "bühnenreif",
    "bühnenreiferes": "bühnenreif",
    "bühnenreifes": "bühnenreif",
    "bühnenreifste": "bühnenreif",
    "bühnenreifstem": "bühnenreif",
    "bühnenreifsten": "bühnenreif",
    "bühnenreifster": "bühnenreif",
    "bühnenreifstes": "bühnenreif",
    "bühnenwirksame": "bühnenwirksam",
    "bühnenwirksamem": "bühnenwirksam",
    "bühnenwirksamen": "bühnenwirksam",
    "bühnenwirksamer": "bühnenwirksam",
    "bühnenwirksamere": "bühnenwirksam",
    "bühnenwirksamerem": "bühnenwirksam",
    "bühnenwirksameren": "bühnenwirksam",
    "bühnenwirksamerer": "bühnenwirksam",
    "bühnenwirksameres": "bühnenwirksam",
    "bühnenwirksames": "bühnenwirksam",
    "bühnenwirksamste": "bühnenwirksam",
    "bühnenwirksamstem": "bühnenwirksam",
    "bühnenwirksamsten": "bühnenwirksam",
    "bühnenwirksamster": "bühnenwirksam",
    "bühnenwirksamstes": "bühnenwirksam",
    "bündele": "bündeln",
    "bündelnd": "bündeln",
    "bündelnde": "bündelnd",
    "bündelndem": "bündelnd",
    "bündelnden": "bündelnd",
    "bündelnder": "bündelnd",
    "bündelndere": "bündelnd",
    "bündelnderem": "bündelnd",
    "bündelnderen": "bündelnd",
    "bündelnderer": "bündelnd",
    "bündelnderes": "bündelnd",
    "bündelndes": "bündelnd",
    "bündelndste": "bündelnd",
    "bündelndstem": "bündelnd",
    "bündelndsten": "bündelnd",
    "bündelndster": "bündelnd",
    "bündelndstes": "bündelnd",
    "bündelst": "bündeln",
    "bündelt": "bündeln",
    "bündelte": "bündeln",
    "bündelten": "bündeln",
    "bündeltest": "bündeln",
    "bündeltet": "bündeln",
    "bündelweisem": "bündelweise",
    "bündelweisen": "bündelweise",
    "bündelweiser": "bündelweise",
    "bündelweises": "bündelweise",
    "bündige": "bündig",
    "bündigem": "bündig",
    "bündigen": "bündig",
    "bündiger": "bündig",
    "bündigere": "bündig",
    "bündigerem": "bündig",
    "bündigeren": "bündig",
    "bündigerer": "bündig",
    "bündigeres": "bündig",
    "bündiges": "bündig",
    "bündigste": "bündig",
    "bündigstem": "bündig",
    "bündigsten": "bündig",
    "bündigster": "bündig",
    "bündigstes": "bündig",
    "bündle": "bündeln",
    "bürdend": "bürden",
    "bürdende": "bürdend",
    "bürdendem": "bürdend",
    "bürdenden": "bürdend",
    "bürdender": "bürdend",
    "bürdendes": "bürdend",
    "bürdest": "bürden",
    "bürdet": "bürden",
    "bürdete": "bürden",
    "bürdeten": "bürden",
    "bürdetest": "bürden",
    "bürdetet": "bürden",
    "bürgend": "bürgen",
    "bürgende": "bürgend",
    "bürgendem": "bürgend",
    "bürgenden": "bürgend",
    "bürgender": "bürgend",
    "bürgendes": "bürgend",
    "bürgeraktivem": "bürgeraktiv",
    "bürgeraktiven": "bürgeraktiv",
    "bürgeraktiver": "bürgeraktiv",
    "bürgeraktivere": "bürgeraktiv",
    "bürgeraktiverem": "bürgeraktiv",
    "bürgeraktiveren": "bürgeraktiv",
    "bürgeraktiverer": "bürgeraktiv",
    "bürgeraktiveres": "bürgeraktiv",
    "bürgeraktives": "bürgeraktiv",
    "bürgeraktivste": "bürgeraktiv",
    "bürgeraktivstem": "bürgeraktiv",
    "bürgeraktivsten": "bürgeraktiv",
    "bürgeraktivster": "bürgeraktiv",
    "bürgeraktivstes": "bürgeraktiv",
    "bürgere": "bürgern",
    "bürgerlichem": "bürgerlich",
    "bürgerlichen": "bürgerlich",
    "bürgerlicher": "bürgerlich",
    "bürgerlichere": "bürgerlich",
    "bürgerlicherem": "bürgerlich",
    "bürgerlicheren": "bürgerlich",
    "bürgerlicherer": "bürgerlich",
    "bürgerlicheres": "bürgerlich",
    "bürgerliches": "bürgerlich",
    "bürgerlichste": "bürgerlich",
    "bürgerlichstem": "bürgerlich",
    "bürgerlichsten": "bürgerlich",
    "bürgerlichster": "bürgerlich",
    "bürgerlichstes": "bürgerlich",
    "bürgernd": "bürgern",
    "bürgernde": "bürgernd",
    "bürgerndem": "bürgernd",
    "bürgernden": "bürgernd",
    "bürgernder": "bürgernd",
    "bürgerndes": "bürgernd",
    "bürgerrechtlichem": "bürgerrechtlich",
    "bürgerrechtlichen": "bürgerrechtlich",
    "bürgerrechtlicher": "bürgerrechtlich",
    "bürgerrechtliches": "bürgerrechtlich",
    "bürgerst": "bürgern",
    "bürgert": "bürgern",
    "bürgerte": "bürgern",
    "bürgerten": "bürgern",
    "bürgertest": "bürgern",
    "bürgertet": "bürgern",
    "bürgest": "bürgen",
    "bürget": "bürgen",
    "bürgst": "bürgen",
    "bürgt": "bürgen",
    "bürgte": "bürgen",
    "bürgten": "bürgen",
    "bürgtest": "bürgen",
    "bürgtet": "bürgen",
    "bürokratischem": "bürokratisch",
    "bürokratischen": "bürokratisch",
    "bürokratischer": "bürokratisch",
    "bürokratischere": "bürokratisch",
    "bürokratischerem": "bürokratisch",
    "bürokratischeren": "bürokratisch",
    "bürokratischerer": "bürokratisch",
    "bürokratischeres": "bürokratisch",
    "bürokratisches": "bürokratisch",
    "bürokratischste": "bürokratisch",
    "bürokratischstem": "bürokratisch",
    "bürokratischsten": "bürokratisch",
    "bürokratischster": "bürokratisch",
    "bürokratischstes": "bürokratisch",
    "bürokratisiere": "bürokratisieren",
    "bürokratisierend": "bürokratisieren",
    "bürokratisierende": "bürokratisierend",
    "bürokratisierendem": "bürokratisierend",
    "bürokratisierenden": "bürokratisierend",
    "bürokratisierender": "bürokratisierend",
    "bürokratisierendere": "bürokratisierend",
    "bürokratisierenderem": "bürokratisierend",
    "bürokratisierenderen": "bürokratisierend",
    "bürokratisierenderer": "bürokratisierend",
    "bürokratisierenderes": "bürokratisierend",
    "bürokratisierendes": "bürokratisierend",
    "bürokratisierendste": "bürokratisierend",
    "bürokratisierendstem": "bürokratisierend",
    "bürokratisierendsten": "bürokratisierend",
    "bürokratisierendster": "bürokratisierend",
    "bürokratisierendstes": "bürokratisierend",
    "bürokratisierest": "bürokratisieren",
    "bürokratisieret": "bürokratisieren",
    "bürokratisierst": "bürokratisieren",
    "bürokratisiert": "bürokratisieren",
    "bürokratisierte": "bürokratisieren",
    "bürokratisiertem": "bürokratisiert",
    "bürokratisierten": "bürokratisieren",
    "bürokratisierter": "bürokratisiert",
    "bürokratisiertere": "bürokratisiert",
    "bürokratisierterem": "bürokratisiert",
    "bürokratisierteren": "bürokratisiert",
    "bürokratisierterer": "bürokratisiert",
    "bürokratisierteres": "bürokratisiert",
    "bürokratisiertes": "bürokratisiert",
    "bürokratisiertest": "bürokratisieren",
    "bürokratisierteste": "bürokratisiert",
    "bürokratisiertestem": "bürokratisiert",
    "bürokratisiertesten": "bürokratisiert",
    "bürokratisiertester": "bürokratisiert",
    "bürokratisiertestes": "bürokratisiert",
    "bürokratisiertet": "bürokratisieren",
    "bürstend": "bürsten",
    "bürstende": "bürstend",
    "bürstendem": "bürstend",
    "bürstenden": "bürstend",
    "bürstender": "bürstend",
    "bürstendes": "bürstend",
    "bürstest": "bürsten",
    "bürstet": "bürsten",
    "bürstete": "bürsten",
    "bürsteten": "bürsten",
    "bürstetest": "bürsten",
    "bürstetet": "bürsten",
    "büschelweisem": "büschelweise",
    "büschelweisen": "büschelweise",
    "büschelweiser": "büschelweise",
    "büschelweises": "büschelweise",
    "büxe": "büxen",
    "büxend": "büxen",
    "büxende": "büxend",
    "büxendem": "büxend",
    "büxenden": "büxend",
    "büxender": "büxend",
    "büxendes": "büxend",
    "büxest": "büxen",
    "büxet": "büxen",
    "büxt": "büxen",
    "büxte": "büxen",
    "büxten": "büxen",
    "büxtest": "büxen",
    "büxtet": "büxen",
    "büße": "büßen",
    "büßend": "büßen",
    "büßende": "büßend",
    "büßendem": "büßend",
    "büßenden": "büßend",
    "büßender": "büßend",
    "büßendere": "büßend",
    "büßenderem": "büßend",
    "büßenderen": "büßend",
    "büßenderer": "büßend",
    "büßenderes": "büßend",
    "büßendes": "büßend",
    "büßendste": "büßend",
    "büßendstem": "büßend",
    "büßendsten": "büßend",
    "büßendster": "büßend",
    "büßendstes": "büßend",
    "büßest": "büßen",
    "büßet": "büßen",
    "büßt": "büßen",
    "büßte": "büßen",
    "büßten": "büßen",
    "büßtest": "büßen",
    "büßtet": "büßen",
    "campiere": "campieren",
    "campierend": "campieren",
    "campierende": "campierend",
    "campierendem": "campierend",
    "campierenden": "campierend",
    "campierender": "campierend",
    "campierendere": "campierend",
    "campierenderem": "campierend",
    "campierenderen": "campierend",
    "campierenderer": "campierend",
    "campierenderes": "campierend",
    "campierendes": "campierend",
    "campierendste": "campierend",
    "campierendstem": "campierend",
    "campierendsten": "campierend",
    "campierendster": "campierend",
    "campierendstes": "campierend",
    "campierest": "campieren",
    "campieret": "campieren",
    "campierst": "campieren",
    "campiert": "campieren",
    "campierte": "campieren",
    "campiertem": "campiert",
    "campierten": "campieren",
    "campierter": "campiert",
    "campiertes": "campiert",
    "campiertest": "campieren",
    "campiertet": "campieren",
    "carbonisierend": "carbonisieren",
    "carbonisierende": "carbonisierend",
    "carbonisierendem": "carbonisierend",
    "carbonisierenden": "carbonisierend",
    "carbonisierender": "carbonisierend",
    "carbonisierendere": "carbonisierend",
    "carbonisierenderem": "carbonisierend",
    "carbonisierenderen": "carbonisierend",
    "carbonisierenderer": "carbonisierend",
    "carbonisierenderes": "carbonisierend",
    "carbonisierendes": "carbonisierend",
    "carbonisierendste": "carbonisierend",
    "carbonisierendstem": "carbonisierend",
    "carbonisierendsten": "carbonisierend",
    "carbonisierendster": "carbonisierend",
    "carbonisierendstes": "carbonisierend",
    "carbonisierest": "carbonisieren",
    "carbonisieret": "carbonisieren",
    "carbonisierst": "carbonisieren",
    "carbonisiert": "carbonisieren",
    "carbonisierte": "carbonisieren",
    "carbonisiertem": "carbonisiert",
    "carbonisierten": "carbonisieren",
    "carbonisierter": "carbonisiert",
    "carbonisiertere": "carbonisiert",
    "carbonisierterem": "carbonisiert",
    "carbonisierteren": "carbonisiert",
    "carbonisierterer": "carbonisiert",
    "carbonisierteres": "carbonisiert",
    "carbonisiertes": "carbonisiert",
    "carbonisiertest": "carbonisieren",
    "carbonisierteste": "carbonisiert",
    "carbonisiertestem": "carbonisiert",
    "carbonisiertesten": "carbonisiert",
    "carbonisiertester": "carbonisiert",
    "carbonisiertestes": "carbonisiert",
    "carbonisiertet": "carbonisieren",
    "charakterisiere": "charakterisieren",
    "charakterisierend": "charakterisieren",
    "charakterisierende": "charakterisierend",
    "charakterisierendem": "charakterisierend",
    "charakterisierenden": "charakterisierend",
    "charakterisierender": "charakterisierend",
    "charakterisierendes": "charakterisierend",
    "charakterisierest": "charakterisieren",
    "charakterisieret": "charakterisieren",
    "charakterisierst": "charakterisieren",
    "charakterisiert": "charakterisieren",
    "charakterisierte": "charakterisieren",
    "charakterisiertem": "charakterisiert",
    "charakterisierten": "charakterisieren",
    "charakterisierter": "charakterisiert",
    "charakterisiertes": "charakterisiert",
    "charakterisiertest": "charakterisieren",
    "charakterisiertet": "charakterisieren",
    "charakteristischem": "charakteristisch",
    "charakteristischen": "charakteristisch",
    "charakteristischer": "charakteristisch",
    "charakteristischere": "charakteristisch",
    "charakteristischerem": "charakteristisch",
    "charakteristischeren": "charakteristisch",
    "charakteristischerer": "charakteristisch",
    "charakteristischeres": "charakteristisch",
    "charakteristisches": "charakteristisch",
    "charakteristischste": "charakteristisch",
    "charakteristischstem": "charakteristisch",
    "charakteristischsten": "charakteristisch",
    "charakteristischster": "charakteristisch",
    "charakteristischstes": "charakteristisch",
    "charakterliche": "charakterlich",
    "charakterlichem": "charakterlich",
    "charakterlichen": "charakterlich",
    "charakterlicher": "charakterlich",
    "charakterliches": "charakterlich",
    "charmantem": "charmant",
    "charmanten": "charmant",
    "charmanter": "charmant",
    "charmantere": "charmant",
    "charmanterem": "charmant",
    "charmanteren": "charmant",
    "charmanterer": "charmant",
    "charmanteres": "charmant",
    "charmantes": "charmant",
    "charmanteste": "charmant",
    "charmantestem": "charmant",
    "charmantesten": "charmant",
    "charmantester": "charmant",
    "charmantestes": "charmant",
    "chauvinistischem": "chauvinistisch",
    "chauvinistischen": "chauvinistisch",
    "chauvinistischer": "chauvinistisch",
    "chauvinistischere": "chauvinistisch",
    "chauvinistischerem": "chauvinistisch",
    "chauvinistischeren": "chauvinistisch",
    "chauvinistischerer": "chauvinistisch",
    "chauvinistischeres": "chauvinistisch",
    "chauvinistisches": "chauvinistisch",
    "chauvinistischste": "chauvinistisch",
    "chauvinistischstem": "chauvinistisch",
    "chauvinistischsten": "chauvinistisch",
    "chauvinistischster": "chauvinistisch",
    "chauvinistischstes": "chauvinistisch",
    "checke": "checken",
    "checkend": "checken",
    "checkende": "checkend",
    "checkendem": "checkend",
    "checkenden": "checkend",
    "checkender": "checkend",
    "checkendes": "checkend",
    "checkest": "checken",
    "checket": "checken",
    "checkst": "checken",
    "checkt": "checken",
    "checkte": "checken",
    "checkten": "checken",
    "checktest": "checken",
    "checktet": "checken",
    "chemischem": "chemisch",
    "chemischen": "chemisch",
    "chemischer": "chemisch",
    "chemisches": "chemisch",
    "chicem": "chic",
    "chicen": "chic",
    "chicer": "chic",
    "chicere": "chic",
    "chicerem": "chic",
    "chiceren": "chic",
    "chicerer": "chic",
    "chiceres": "chic",
    "chices": "chic",
    "chicste": "chic",
    "chicstem": "chic",
    "chicsten": "chic",
    "chicster": "chic",
    "chicstes": "chic",
    "chinesischem": "chinesisch",
    "chinesischen": "chinesisch",
    "chinesischer": "chinesisch",
    "chinesisches": "chinesisch",
    "chirurgischem": "chirurgisch",
    "chirurgischen": "chirurgisch",
    "chirurgischer": "chirurgisch",
    "chirurgisches": "chirurgisch",
    "christlichem": "christlich",
    "christlichen": "christlich",
    "christlicher": "christlich",
    "christlichere": "christlich",
    "christlicherem": "christlich",
    "christlicheren": "christlich",
    "christlicherer": "christlich",
    "christlicheres": "christlich",
    "christliches": "christlich",
    "christlichste": "christlich",
    "christlichstem": "christlich",
    "christlichsten": "christlich",
    "christlichster": "christlich",
    "christlichstes": "christlich",
    "chronischem": "chronisch",
    "chronischen": "chronisch",
    "chronischer": "chronisch",
    "chronisches": "chronisch",
    "clone": "clonen",
    "clonend": "clonen",
    "clonende": "clonend",
    "clonendem": "clonend",
    "clonenden": "clonend",
    "clonender": "clonend",
    "clonendere": "clonend",
    "clonenderem": "clonend",
    "clonenderen": "clonend",
    "clonenderer": "clonend",
    "clonenderes": "clonend",
    "clonendes": "clonend",
    "clonendste": "clonend",
    "clonendstem": "clonend",
    "clonendsten": "clonend",
    "clonendster": "clonend",
    "clonendstes": "clonend",
    "clonest": "clonen",
    "clonet": "clonen",
    "clonst": "clonen",
    "clont": "clonen",
    "clonte": "clonen",
    "clonten": "clonen",
    "clontest": "clonen",
    "clontet": "clonen",
    "codiere": "codieren",
    "codierend": "codieren",
    "codierende": "codierend",
    "codierendem": "codierend",
    "codierenden": "codierend",
    "codierender": "codierend",
    "codierendes": "codierend",
    "codierest": "codieren",
    "codieret": "codieren",
    "codierst": "codieren",
    "codiert": "codieren",
    "codierte": "codieren",
    "codiertem": "codiert",
    "codierten": "codieren",
    "codierter": "codiert",
    "codiertes": "codiert",
    "codiertest": "codieren",
    "codiertet": "codieren",
    "coolem": "cool",
    "coolen": "cool",
    "cooler": "cool",
    "coolere": "cool",
    "coolerem": "cool",
    "cooleren": "cool",
    "coolerer": "cool",
    "cooleres": "cool",
    "cooles": "cool",
    "coolste": "cool",
    "coolstem": "cool",
    "coolsten": "cool",
    "coolster": "cool",
    "coolstes": "cool",
    "cooperative": "cooperativ",
    "cooperativem": "cooperativ",
    "cooperativen": "cooperativ",
    "cooperativer": "cooperativ",
    "cooperativere": "cooperativ",
    "cooperativerem": "cooperativ",
    "cooperativeren": "cooperativ",
    "cooperativerer": "cooperativ",
    "cooperativeres": "cooperativ",
    "cooperatives": "cooperativ",
    "cooperativste": "cooperativ",
    "cooperativstem": "cooperativ",
    "cooperativsten": "cooperativ",
    "cooperativster": "cooperativ",
    "cooperativstes": "cooperativ",
    "cremend": "cremen",
    "cremende": "cremend",
    "cremendem": "cremend",
    "cremenden": "cremend",
    "cremender": "cremend",
    "cremendes": "cremend",
    "cremest": "cremen",
    "cremet": "cremen",
    "cremst": "cremen",
    "cremt": "cremen",
    "cremte": "cremen",
    "cremten": "cremen",
    "cremtest": "cremen",
    "cremtet": "cremen",
    "curricularem": "curricular",
    "curricularen": "curricular",
    "curricularer": "curricular",
    "curriculares": "curricular",
    "dabehalte": "dabehalten",
    "dabehaltend": "dabehalten",
    "dabehaltende": "dabehaltend",
    "dabehaltendem": "dabehaltend",
    "dabehaltenden": "dabehaltend",
    "dabehaltender": "dabehaltend",
    "dabehaltendes": "dabehaltend",
    "dabehaltene": "dabehalten",
    "dabehaltenem": "dabehalten",
    "dabehaltenen": "dabehalten",
    "dabehaltener": "dabehalten",
    "dabehaltenes": "dabehalten",
    "dabehaltest": "dabehalten",
    "dabehaltet": "dabehalten",
    "dabehielt": "dabehalten",
    "dabehielte": "dabehalten",
    "dabehielten": "dabehalten",
    "dabehieltest": "dabehalten",
    "dabehieltet": "dabehalten",
    "dabehält": "dabehalten",
    "dabehältst": "dabehalten",
    "dabeibleibe": "dabeibleiben",
    "dabeibleibend": "dabeibleiben",
    "dabeibleibende": "dabeibleibend",
    "dabeibleibendem": "dabeibleibend",
    "dabeibleibenden": "dabeibleibend",
    "dabeibleibender": "dabeibleibend",
    "dabeibleibendes": "dabeibleibend",
    "dabeibleibest": "dabeibleiben",
    "dabeibleibet": "dabeibleiben",
    "dabeibleibst": "dabeibleiben",
    "dabeibleibt": "dabeibleiben",
    "dabeiblieb": "dabeibleiben",
    "dabeibliebe": "dabeibleiben",
    "dabeiblieben": "dabeibleiben",
    "dabeibliebest": "dabeibleiben",
    "dabeibliebet": "dabeibleiben",
    "dabeibliebst": "dabeibleiben",
    "dabeibliebt": "dabeibleiben",
    "dabeigeblieben": "dabeibleiben",
    "dabeigebliebene": "dabeigeblieben",
    "dabeigebliebenem": "dabeigeblieben",
    "dabeigebliebenen": "dabeigeblieben",
    "dabeigebliebener": "dabeigeblieben",
    "dabeigebliebenes": "dabeigeblieben",
    "dabeigesessen": "dabeisitzen",
    "dabeigesessene": "dabeigesessen",
    "dabeigesessenem": "dabeigesessen",
    "dabeigesessenen": "dabeigesessen",
    "dabeigesessener": "dabeigesessen",
    "dabeigesessenes": "dabeigesessen",
    "dabeisaß": "dabeisitzen",
    "dabeisaßen": "dabeisitzen",
    "dabeisaßt": "dabeisitzen",
    "dabeisitze": "dabeisitzen",
    "dabeisitzend": "dabeisitzen",
    "dabeisitzende": "dabeisitzend",
    "dabeisitzendem": "dabeisitzend",
    "dabeisitzenden": "dabeisitzend",
    "dabeisitzender": "dabeisitzend",
    "dabeisitzendes": "dabeisitzend",
    "dabeisitzest": "dabeisitzen",
    "dabeisitzet": "dabeisitzen",
    "dabeisitzt": "dabeisitzen",
    "dabeisäße": "dabeisitzen",
    "dabeisäßen": "dabeisitzen",
    "dabeisäßest": "dabeisitzen",
    "dabeisäßet": "dabeisitzen",
    "dabeizubleiben": "dabeibleiben",
    "dabeizusitzen": "dabeisitzen",
    "dableibe": "dableiben",
    "dableibend": "dableiben",
    "dableibende": "dableibend",
    "dableibendem": "dableibend",
    "dableibenden": "dableibend",
    "dableibender": "dableibend",
    "dableibendes": "dableibend",
    "dableibest": "dableiben",
    "dableibet": "dableiben",
    "dableibst": "dableiben",
    "dableibt": "dableiben",
    "dablieb": "dableiben",
    "dabliebe": "dableiben",
    "dablieben": "dableiben",
    "dabliebest": "dableiben",
    "dabliebet": "dableiben",
    "dabliebst": "dableiben",
    "dabliebt": "dableiben",
    "dachend": "dachen",
    "dachende": "dachend",
    "dachendem": "dachend",
    "dachenden": "dachend",
    "dachender": "dachend",
    "dachendes": "dachend",
    "dachest": "dachen",
    "dachet": "dachen",
    "dachst": "dachen",
    "dacht": "dachen",
    "dachte": "denken",
    "dachten": "denken",
    "dachtest": "denken",
    "dachtet": "denken",
    "dafürgehalten": "dafürhalten",
    "dafürgehaltene": "dafürgehalten",
    "dafürgehaltenem": "dafürgehalten",
    "dafürgehaltenen": "dafürgehalten",
    "dafürgehaltener": "dafürgehalten",
    "dafürgehaltenes": "dafürgehalten",
    "dafürgestanden": "dafürstehen",
    "dafürgestandene": "dafürgestanden",
    "dafürgestandenem": "dafürgestanden",
    "dafürgestandenen": "dafürgestanden",
    "dafürgestandener": "dafürgestanden",
    "dafürgestandenes": "dafürgestanden",
    "dafürhalte": "dafürhalten",
    "dafürhaltend": "dafürhalten",
    "dafürhaltende": "dafürhaltend",
    "dafürhaltendem": "dafürhaltend",
    "dafürhaltenden": "dafürhaltend",
    "dafürhaltender": "dafürhaltend",
    "dafürhaltendes": "dafürhaltend",
    "dafürhaltest": "dafürhalten",
    "dafürhaltet": "dafürhalten",
    "dafürhielt": "dafürhalten",
    "dafürhielte": "dafürhalten",
    "dafürhielten": "dafürhalten",
    "dafürhieltest": "dafürhalten",
    "dafürhieltet": "dafürhalten",
    "dafürhält": "dafürhalten",
    "dafürhältst": "dafürhalten",
    "dafürstand": "dafürstehen",
    "dafürstanden": "dafürstehen",
    "dafürstandest": "dafürstehen",
    "dafürstandet": "dafürstehen",
    "dafürstehe": "dafürstehen",
    "dafürstehend": "dafürstehen",
    "dafürstehende": "dafürstehend",
    "dafürstehendem": "dafürstehend",
    "dafürstehenden": "dafürstehend",
    "dafürstehender": "dafürstehend",
    "dafürstehendes": "dafürstehend",
    "dafürstehest": "dafürstehen",
    "dafürstehet": "dafürstehen",
    "dafürstehst": "dafürstehen",
    "dafürsteht": "dafürstehen",
    "dafürstünde": "dafürstehen",
    "dafürstünden": "dafürstehen",
    "dafürstündest": "dafürstehen",
    "dafürstündet": "dafürstehen",
    "dafürzuhalten": "dafürhalten",
    "dafürzustehen": "dafürstehen",
    "dageblieben": "dableiben",
    "dagebliebene": "dageblieben",
    "dagebliebenem": "dageblieben",
    "dagebliebenen": "dageblieben",
    "dagebliebener": "dageblieben",
    "dagebliebenes": "dageblieben",
    "dagegengehalten": "dagegenhalten",
    "dagegengehaltene": "dagegengehalten",
    "dagegengehaltenem": "dagegengehalten",
    "dagegengehaltenen": "dagegengehalten",
    "dagegengehaltener": "dagegengehalten",
    "dagegengehaltenes": "dagegengehalten",
    "dagegengehandelt": "dagegenhandeln",
    "dagegengehandelte": "dagegengehandelt",
    "dagegengehandeltem": "dagegengehandelt",
    "dagegengehandelten": "dagegengehandelt",
    "dagegengehandelter": "dagegengehandelt",
    "dagegengehandeltes": "dagegengehandelt",
    "dagegengewirkt": "dagegenwirken",
    "dagegengewirkte": "dagegengewirkt",
    "dagegengewirktem": "dagegengewirkt",
    "dagegengewirkten": "dagegengewirkt",
    "dagegengewirkter": "dagegengewirkt",
    "dagegengewirktes": "dagegengewirkt",
    "dagegenhalte": "dagegenhalten",
    "dagegenhaltend": "dagegenhalten",
    "dagegenhaltende": "dagegenhaltend",
    "dagegenhaltendem": "dagegenhaltend",
    "dagegenhaltenden": "dagegenhaltend",
    "dagegenhaltender": "dagegenhaltend",
    "dagegenhaltendes": "dagegenhaltend",
    "dagegenhaltest": "dagegenhalten",
    "dagegenhaltet": "dagegenhalten",
    "dagegenhandele": "dagegenhandeln",
    "dagegenhandelnd": "dagegenhandeln",
    "dagegenhandelnde": "dagegenhandelnd",
    "dagegenhandelndem": "dagegenhandelnd",
    "dagegenhandelnden": "dagegenhandelnd",
    "dagegenhandelnder": "dagegenhandelnd",
    "dagegenhandelndes": "dagegenhandelnd",
    "dagegenhandelst": "dagegenhandeln",
    "dagegenhandelt": "dagegenhandeln",
    "dagegenhandelte": "dagegenhandeln",
    "dagegenhandelten": "dagegenhandeln",
    "dagegenhandeltest": "dagegenhandeln",
    "dagegenhandeltet": "dagegenhandeln",
    "dagegenhandle": "dagegenhandeln",
    "dagegenhielt": "dagegenhalten",
    "dagegenhielte": "dagegenhalten",
    "dagegenhielten": "dagegenhalten",
    "dagegenhieltest": "dagegenhalten",
    "dagegenhieltet": "dagegenhalten",
    "dagegenhält": "dagegenhalten",
    "dagegenhältst": "dagegenhalten",
    "dagegenwirke": "dagegenwirken",
    "dagegenwirkend": "dagegenwirken",
    "dagegenwirkende": "dagegenwirkend",
    "dagegenwirkendem": "dagegenwirkend",
    "dagegenwirkenden": "dagegenwirkend",
    "dagegenwirkender": "dagegenwirkend",
    "dagegenwirkendes": "dagegenwirkend",
    "dagegenwirkest": "dagegenwirken",
    "dagegenwirket": "dagegenwirken",
    "dagegenwirkst": "dagegenwirken",
    "dagegenwirkt": "dagegenwirken",
    "dagegenwirkte": "dagegenwirken",
    "dagegenwirkten": "dagegenwirken",
    "dagegenwirktest": "dagegenwirken",
    "dagegenwirktet": "dagegenwirken",
    "dagegenzuhalten": "dagegenhalten",
    "dagegenzuhandeln": "dagegenhandeln",
    "dagegenzuwirken": "dagegenwirken",
    "dagelassen": "dalassen",
    "dagelassene": "dagelassen",
    "dagelassenem": "dagelassen",
    "dagelassenen": "dagelassen",
    "dagelassener": "dagelassen",
    "dagelassenes": "dagelassen",
    "dagelegen": "daliegen",
    "dagelegene": "dagelegen",
    "dagelegenem": "dagelegen",
    "dagelegenen": "dagelegen",
    "dagelegener": "dagelegen",
    "dagelegenes": "dagelegen",
    "dagesessen": "dasitzen",
    "dagesessene": "dagesessen",
    "dagesessenem": "dagesessen",
    "dagesessenen": "dagesessen",
    "dagesessener": "dagesessen",
    "dagesessenes": "dagesessen",
    "dagestanden": "dastehen",
    "dagestandene": "dagestanden",
    "dagestandenem": "dagestanden",
    "dagestandenen": "dagestanden",
    "dagestandener": "dagestanden",
    "dagestandenes": "dagestanden",
    "daherfliege": "daherfliegen",
    "daherfliegend": "daherfliegen",
    "daherfliegende": "daherfliegend",
    "daherfliegendem": "daherfliegend",
    "daherfliegenden": "daherfliegend",
    "daherfliegender": "daherfliegend",
    "daherfliegendes": "daherfliegend",
    "daherfliegest": "daherfliegen",
    "daherflieget": "daherfliegen",
    "daherfliegst": "daherfliegen",
    "daherfliegt": "daherfliegen",
    "daherflog": "daherfliegen",
    "daherflogen": "daherfliegen",
    "daherflogst": "daherfliegen",
    "daherflogt": "daherfliegen",
    "daherflöge": "daherfliegen",
    "daherflögen": "daherfliegen",
    "daherflögest": "daherfliegen",
    "daherflöget": "daherfliegen",
    "dahergeflogen": "daherfliegen",
    "dahergeflogene": "dahergeflogen",
    "dahergeflogenem": "dahergeflogen",
    "dahergeflogenen": "dahergeflogen",
    "dahergeflogener": "dahergeflogen",
    "dahergeflogenes": "dahergeflogen",
    "dahergekommen": "daherkommen",
    "dahergekommene": "dahergekommen",
    "dahergekommenem": "dahergekommen",
    "dahergekommenen": "dahergekommen",
    "dahergekommener": "dahergekommen",
    "dahergekommenes": "dahergekommen",
    "dahergelaufen": "daherlaufen",
    "dahergelaufene": "dahergelaufen",
    "dahergelaufenem": "dahergelaufen",
    "dahergelaufenen": "dahergelaufen",
    "dahergelaufener": "dahergelaufen",
    "dahergelaufenes": "dahergelaufen",
    "dahergeredet": "daherreden",
    "dahergeredete": "dahergeredet",
    "dahergeredetem": "dahergeredet",
    "dahergeredeten": "dahergeredet",
    "dahergeredeter": "dahergeredet",
    "dahergeredetes": "dahergeredet",
    "daherkam": "daherkommen",
    "daherkamen": "daherkommen",
    "daherkamst": "daherkommen",
    "daherkamt": "daherkommen",
    "daherkomme": "daherkommen",
    "daherkommend": "daherkommen",
    "daherkommende": "daherkommend",
    "daherkommendem": "daherkommend",
    "daherkommenden": "daherkommend",
    "daherkommender": "daherkommend",
    "daherkommendes": "daherkommend",
    "daherkommest": "daherkommen",
    "daherkommet": "daherkommen",
    "daherkommst": "daherkommen",
    "daherkommt": "daherkommen",
    "daherkäme": "daherkommen",
    "daherkämen": "daherkommen",
    "daherkämest": "daherkommen",
    "daherkämet": "daherkommen",
    "daherlaufe": "daherlaufen",
    "daherlaufend": "daherlaufen",
    "daherlaufende": "daherlaufend",
    "daherlaufendem": "daherlaufend",
    "daherlaufenden": "daherlaufend",
    "daherlaufender": "daherlaufend",
    "daherlaufendes": "daherlaufend",
    "daherlaufest": "daherlaufen",
    "daherlaufet": "daherlaufen",
    "daherlauft": "daherlaufen",
    "daherlief": "daherlaufen",
    "daherliefe": "daherlaufen",
    "daherliefen": "daherlaufen",
    "daherliefest": "daherlaufen",
    "daherliefet": "daherlaufen",
    "daherliefst": "daherlaufen",
    "daherlieft": "daherlaufen",
    "daherläufst": "daherlaufen",
    "daherläuft": "daherlaufen",
    "daherrede": "daherreden",
    "daherredend": "daherreden",
    "daherredende": "daherredend",
    "daherredendem": "daherredend",
    "daherredenden": "daherredend",
    "daherredender": "daherredend",
    "daherredendes": "daherredend",
    "daherredest": "daherreden",
    "daherredet": "daherreden",
    "daherredete": "daherreden",
    "daherredeten": "daherreden",
    "daherredetest": "daherreden",
    "daherredetet": "daherreden",
    "daherzufliegen": "daherfliegen",
    "daherzukommen": "daherkommen",
    "daherzulaufen": "daherlaufen",
    "daherzureden": "daherreden",
    "dahindämmere": "dahindämmern",
    "dahindämmernd": "dahindämmern",
    "dahindämmernde": "dahindämmernd",
    "dahindämmerndem": "dahindämmernd",
    "dahindämmernden": "dahindämmernd",
    "dahindämmernder": "dahindämmernd",
    "dahindämmerndes": "dahindämmernd",
    "dahindämmerst": "dahindämmern",
    "dahindämmert": "dahindämmern",
    "dahindämmerte": "dahindämmern",
    "dahindämmerten": "dahindämmern",
    "dahindämmertest": "dahindämmern",
    "dahindämmertet": "dahindämmern",
    "dahineile": "dahineilen",
    "dahineilend": "dahineilen",
    "dahineilende": "dahineilend",
    "dahineilendem": "dahineilend",
    "dahineilenden": "dahineilend",
    "dahineilender": "dahineilend",
    "dahineilendes": "dahineilend",
    "dahineilest": "dahineilen",
    "dahineilet": "dahineilen",
    "dahineilst": "dahineilen",
    "dahineilt": "dahineilen",
    "dahineilte": "dahineilen",
    "dahineilten": "dahineilen",
    "dahineiltest": "dahineilen",
    "dahineiltet": "dahineilen",
    "dahinfahre": "dahinfahren",
    "dahinfahrend": "dahinfahren",
    "dahinfahrende": "dahinfahrend",
    "dahinfahrendem": "dahinfahrend",
    "dahinfahrenden": "dahinfahrend",
    "dahinfahrender": "dahinfahrend",
    "dahinfahrendes": "dahinfahrend",
    "dahinfahrest": "dahinfahren",
    "dahinfahret": "dahinfahren",
    "dahinfahrt": "dahinfahren",
    "dahinfliege": "dahinfliegen",
    "dahinfliegend": "dahinfliegen",
    "dahinfliegende": "dahinfliegend",
    "dahinfliegendem": "dahinfliegend",
    "dahinfliegenden": "dahinfliegend",
    "dahinfliegender": "dahinfliegend",
    "dahinfliegendes": "dahinfliegend",
    "dahinfliegest": "dahinfliegen",
    "dahinflieget": "dahinfliegen",
    "dahinfliegst": "dahinfliegen",
    "dahinfliegt": "dahinfliegen",
    "dahinflog": "dahinfliegen",
    "dahinflogen": "dahinfliegen",
    "dahinflogst": "dahinfliegen",
    "dahinflogt": "dahinfliegen",
    "dahinflöge": "dahinfliegen",
    "dahinflögen": "dahinfliegen",
    "dahinflögest": "dahinfliegen",
    "dahinflöget": "dahinfliegen",
    "dahinfuhr": "dahinfahren",
    "dahinfuhren": "dahinfahren",
    "dahinfuhrst": "dahinfahren",
    "dahinfuhrt": "dahinfahren",
    "dahinfährst": "dahinfahren",
    "dahinfährt": "dahinfahren",
    "dahinführe": "dahinfahren",
    "dahinführen": "dahinfahren",
    "dahinführest": "dahinfahren",
    "dahinführet": "dahinfahren",
    "dahingab": "dahingeben",
    "dahingaben": "dahingeben",
    "dahingabst": "dahingeben",
    "dahingabt": "dahingeben",
    "dahingebe": "dahingeben",
    "dahingebend": "dahingeben",
    "dahingebende": "dahingebend",
    "dahingebendem": "dahingebend",
    "dahingebenden": "dahingebend",
    "dahingebender": "dahingebend",
    "dahingebendes": "dahingebend",
    "dahingebest": "dahingeben",
    "dahingebet": "dahingeben",
    "dahingebt": "dahingeben",
    "dahingedämmert": "dahindämmern",
    "dahingedämmerte": "dahingedämmert",
    "dahingedämmertem": "dahingedämmert",
    "dahingedämmerten": "dahingedämmert",
    "dahingedämmerter": "dahingedämmert",
    "dahingedämmertes": "dahingedämmert",
    "dahingeeilt": "dahineilen",
    "dahingeeilte": "dahingeeilt",
    "dahingeeiltem": "dahingeeilt",
    "dahingeeilten": "dahingeeilt",
    "dahingeeilter": "dahingeeilt",
    "dahingeeiltes": "dahingeeilt",
    "dahingefahren": "dahinfahren",
    "dahingefahrene": "dahingefahren",
    "dahingefahrenem": "dahingefahren",
    "dahingefahrenen": "dahingefahren",
    "dahingefahrener": "dahingefahren",
    "dahingefahrenes": "dahingefahren",
    "dahingeflogen": "dahinfliegen",
    "dahingeflogene": "dahingeflogen",
    "dahingeflogenem": "dahingeflogen",
    "dahingeflogenen": "dahingeflogen",
    "dahingeflogener": "dahingeflogen",
    "dahingeflogenes": "dahingeflogen",
    "dahingegangen": "dahingehen",
    "dahingegangene": "dahingegangen",
    "dahingegangenem": "dahingegangen",
    "dahingegangenen": "dahingegangen",
    "dahingegangener": "dahingegangen",
    "dahingegangenes": "dahingegangen",
    "dahingegeben": "dahingeben",
    "dahingegebene": "dahingegeben",
    "dahingegebenem": "dahingegeben",
    "dahingegebenen": "dahingegeben",
    "dahingegebener": "dahingegeben",
    "dahingegebenes": "dahingegeben",
    "dahingehe": "dahingehen",
    "dahingehend": "dahingehen",
    "dahingehende": "dahingehend",
    "dahingehendem": "dahingehend",
    "dahingehenden": "dahingehend",
    "dahingehender": "dahingehend",
    "dahingehendes": "dahingehend",
    "dahingehest": "dahingehen",
    "dahingehet": "dahingehen",
    "dahingehst": "dahingehen",
    "dahingeht": "dahingehen",
    "dahingelebt": "dahinleben",
    "dahingelebte": "dahingelebt",
    "dahingelebtem": "dahingelebt",
    "dahingelebten": "dahingelebt",
    "dahingelebter": "dahingelebt",
    "dahingelebtes": "dahingelebt",
    "dahingerafft": "dahinraffen",
    "dahingeraffte": "dahingerafft",
    "dahingerafftem": "dahingerafft",
    "dahingerafften": "dahingerafft",
    "dahingeraffter": "dahingerafft",
    "dahingerafftes": "dahingerafft",
    "dahingeschieden": "dahinscheiden",
    "dahingeschiedene": "dahingeschieden",
    "dahingeschiedenem": "dahingeschieden",
    "dahingeschiedenen": "dahingeschieden",
    "dahingeschiedener": "dahingeschieden",
    "dahingeschiedenes": "dahingeschieden",
    "dahingeschleppt": "dahinschleppen",
    "dahingeschleppte": "dahingeschleppt",
    "dahingeschlepptem": "dahingeschleppt",
    "dahingeschleppten": "dahingeschleppt",
    "dahingeschleppter": "dahingeschleppt",
    "dahingeschlepptes": "dahingeschleppt",
    "dahingeschmolzen": "dahinschmelzen",
    "dahingeschmolzene": "dahingeschmolzen",
    "dahingeschmolzenem": "dahingeschmolzen",
    "dahingeschmolzenen": "dahingeschmolzen",
    "dahingeschmolzener": "dahingeschmolzen",
    "dahingeschmolzenere": "dahingeschmolzen",
    "dahingeschmolzenerem": "dahingeschmolzen",
    "dahingeschmolzeneren": "dahingeschmolzen",
    "dahingeschmolzenerer": "dahingeschmolzen",
    "dahingeschmolzeneres": "dahingeschmolzen",
    "dahingeschmolzenes": "dahingeschmolzen",
    "dahingeschmolzenste": "dahingeschmolzen",
    "dahingeschmolzenstem": "dahingeschmolzen",
    "dahingeschmolzensten": "dahingeschmolzen",
    "dahingeschmolzenster": "dahingeschmolzen",
    "dahingeschmolzenstes": "dahingeschmolzen",
    "dahingeschwunden": "dahinschwinden",
    "dahingeschwundene": "dahingeschwunden",
    "dahingeschwundenem": "dahingeschwunden",
    "dahingeschwundenen": "dahingeschwunden",
    "dahingeschwundener": "dahingeschwunden",
    "dahingeschwundenes": "dahingeschwunden",
    "dahingesiecht": "dahinsiechen",
    "dahingesiechte": "dahingesiecht",
    "dahingesiechtem": "dahingesiecht",
    "dahingesiechten": "dahingesiecht",
    "dahingesiechter": "dahingesiecht",
    "dahingesiechtere": "dahingesiecht",
    "dahingesiechterem": "dahingesiecht",
    "dahingesiechteren": "dahingesiecht",
    "dahingesiechterer": "dahingesiecht",
    "dahingesiechteres": "dahingesiecht",
    "dahingesiechtes": "dahingesiecht",
    "dahingesiechteste": "dahingesiecht",
    "dahingesiechtestem": "dahingesiecht",
    "dahingesiechtesten": "dahingesiecht",
    "dahingesiechtester": "dahingesiecht",
    "dahingesiechtestes": "dahingesiecht",
    "dahingestellt": "dahinstellen",
    "dahingestellte": "dahingestellt",
    "dahingestelltem": "dahingestellt",
    "dahingestellten": "dahingestellt",
    "dahingestellter": "dahingestellt",
    "dahingestelltes": "dahingestellt",
    "dahingesunken": "dahinsinken",
    "dahingesunkene": "dahingesunken",
    "dahingesunkenem": "dahingesunken",
    "dahingesunkenen": "dahingesunken",
    "dahingesunkener": "dahingesunken",
    "dahingesunkenes": "dahingesunken",
    "dahingewelkt": "dahinwelken",
    "dahingewelkte": "dahingewelkt",
    "dahingewelktem": "dahingewelkt",
    "dahingewelkten": "dahingewelkt",
    "dahingewelkter": "dahingewelkt",
    "dahingewelktere": "dahingewelkt",
    "dahingewelkterem": "dahingewelkt",
    "dahingewelkteren": "dahingewelkt",
    "dahingewelkterer": "dahingewelkt",
    "dahingewelkteres": "dahingewelkt",
    "dahingewelktes": "dahingewelkt",
    "dahingewelkteste": "dahingewelkt",
    "dahingewelktestem": "dahingewelkt",
    "dahingewelktesten": "dahingewelkt",
    "dahingewelktester": "dahingewelkt",
    "dahingewelktestes": "dahingewelkt",
    "dahingibst": "dahingeben",
    "dahingibt": "dahingeben",
    "dahinging": "dahingehen",
    "dahinginge": "dahingehen",
    "dahingingen": "dahingehen",
    "dahingingest": "dahingehen",
    "dahinginget": "dahingehen",
    "dahingingst": "dahingehen",
    "dahingingt": "dahingehen",
    "dahingäbe": "dahingeben",
    "dahingäben": "dahingeben",
    "dahingäbest": "dahingeben",
    "dahingäbet": "dahingeben",
    "dahinlebe": "dahinleben",
    "dahinlebend": "dahinleben",
    "dahinlebende": "dahinlebend",
    "dahinlebendem": "dahinlebend",
    "dahinlebenden": "dahinlebend",
    "dahinlebender": "dahinlebend",
    "dahinlebendes": "dahinlebend",
    "dahinlebest": "dahinleben",
    "dahinlebet": "dahinleben",
    "dahinlebst": "dahinleben",
    "dahinlebt": "dahinleben",
    "dahinlebte": "dahinleben",
    "dahinlebten": "dahinleben",
    "dahinlebtest": "dahinleben",
    "dahinlebtet": "dahinleben",
    "dahinraffe": "dahinraffen",
    "dahinraffend": "dahinraffen",
    "dahinraffende": "dahinraffend",
    "dahinraffendem": "dahinraffend",
    "dahinraffenden": "dahinraffend",
    "dahinraffender": "dahinraffend",
    "dahinraffendes": "dahinraffend",
    "dahinraffest": "dahinraffen",
    "dahinraffet": "dahinraffen",
    "dahinraffst": "dahinraffen",
    "dahinrafft": "dahinraffen",
    "dahinraffte": "dahinraffen",
    "dahinrafften": "dahinraffen",
    "dahinrafftest": "dahinraffen",
    "dahinrafftet": "dahinraffen",
    "dahinsank": "dahinsinken",
    "dahinsanken": "dahinsinken",
    "dahinsankst": "dahinsinken",
    "dahinsankt": "dahinsinken",
    "dahinscheide": "dahinscheiden",
    "dahinscheidend": "dahinscheiden",
    "dahinscheidende": "dahinscheidend",
    "dahinscheidendem": "dahinscheidend",
    "dahinscheidenden": "dahinscheidend",
    "dahinscheidender": "dahinscheidend",
    "dahinscheidendes": "dahinscheidend",
    "dahinscheidest": "dahinscheiden",
    "dahinscheidet": "dahinscheiden",
    "dahinschied": "dahinscheiden",
    "dahinschiede": "dahinscheiden",
    "dahinschieden": "dahinscheiden",
    "dahinschiedest": "dahinscheiden",
    "dahinschiedet": "dahinscheiden",
    "dahinschleppe": "dahinschleppen",
    "dahinschleppend": "dahinschleppen",
    "dahinschleppende": "dahinschleppend",
    "dahinschleppendem": "dahinschleppend",
    "dahinschleppenden": "dahinschleppend",
    "dahinschleppender": "dahinschleppend",
    "dahinschleppendes": "dahinschleppend",
    "dahinschleppest": "dahinschleppen",
    "dahinschleppet": "dahinschleppen",
    "dahinschleppst": "dahinschleppen",
    "dahinschleppt": "dahinschleppen",
    "dahinschleppte": "dahinschleppen",
    "dahinschleppten": "dahinschleppen",
    "dahinschlepptest": "dahinschleppen",
    "dahinschlepptet": "dahinschleppen",
    "dahinschmelze": "dahinschmelzen",
    "dahinschmelzend": "dahinschmelzen",
    "dahinschmelzende": "dahinschmelzend",
    "dahinschmelzendem": "dahinschmelzend",
    "dahinschmelzenden": "dahinschmelzend",
    "dahinschmelzender": "dahinschmelzend",
    "dahinschmelzendere": "dahinschmelzend",
    "dahinschmelzenderem": "dahinschmelzend",
    "dahinschmelzenderen": "dahinschmelzend",
    "dahinschmelzenderer": "dahinschmelzend",
    "dahinschmelzenderes": "dahinschmelzend",
    "dahinschmelzendes": "dahinschmelzend",
    "dahinschmelzendste": "dahinschmelzend",
    "dahinschmelzendstem": "dahinschmelzend",
    "dahinschmelzendsten": "dahinschmelzend",
    "dahinschmelzendster": "dahinschmelzend",
    "dahinschmelzendstes": "dahinschmelzend",
    "dahinschmelzest": "dahinschmelzen",
    "dahinschmelzet": "dahinschmelzen",
    "dahinschmelzt": "dahinschmelzen",
    "dahinschmilzt": "dahinschmelzen",
    "dahinschmolz": "dahinschmelzen",
    "dahinschmolzen": "dahinschmelzen",
    "dahinschmolzst": "dahinschmelzen",
    "dahinschmolzt": "dahinschmelzen",
    "dahinschmölze": "dahinschmelzen",
    "dahinschmölzen": "dahinschmelzen",
    "dahinschmölzest": "dahinschmelzen",
    "dahinschmölzet": "dahinschmelzen",
    "dahinschwand": "dahinschwinden",
    "dahinschwanden": "dahinschwinden",
    "dahinschwandest": "dahinschwinden",
    "dahinschwandet": "dahinschwinden",
    "dahinschwinde": "dahinschwinden",
    "dahinschwindend": "dahinschwinden",
    "dahinschwindende": "dahinschwindend",
    "dahinschwindendem": "dahinschwindend",
    "dahinschwindenden": "dahinschwindend",
    "dahinschwindender": "dahinschwindend",
    "dahinschwindendes": "dahinschwindend",
    "dahinschwindest": "dahinschwinden",
    "dahinschwindet": "dahinschwinden",
    "dahinschwände": "dahinschwinden",
    "dahinschwänden": "dahinschwinden",
    "dahinschwändest": "dahinschwinden",
    "dahinschwändet": "dahinschwinden",
    "dahinsieche": "dahinsiechen",
    "dahinsiechend": "dahinsiechen",
    "dahinsiechende": "dahinsiechend",
    "dahinsiechendem": "dahinsiechend",
    "dahinsiechenden": "dahinsiechend",
    "dahinsiechender": "dahinsiechend",
    "dahinsiechendere": "dahinsiechend",
    "dahinsiechenderem": "dahinsiechend",
    "dahinsiechenderen": "dahinsiechend",
    "dahinsiechenderer": "dahinsiechend",
    "dahinsiechenderes": "dahinsiechend",
    "dahinsiechendes": "dahinsiechend",
    "dahinsiechendste": "dahinsiechend",
    "dahinsiechendstem": "dahinsiechend",
    "dahinsiechendsten": "dahinsiechend",
    "dahinsiechendster": "dahinsiechend",
    "dahinsiechendstes": "dahinsiechend",
    "dahinsiechest": "dahinsiechen",
    "dahinsiechet": "dahinsiechen",
    "dahinsiechst": "dahinsiechen",
    "dahinsiecht": "dahinsiechen",
    "dahinsiechte": "dahinsiechen",
    "dahinsiechten": "dahinsiechen",
    "dahinsiechtest": "dahinsiechen",
    "dahinsiechtet": "dahinsiechen",
    "dahinsinke": "dahinsinken",
    "dahinsinkend": "dahinsinken",
    "dahinsinkende": "dahinsinkend",
    "dahinsinkendem": "dahinsinkend",
    "dahinsinkenden": "dahinsinkend",
    "dahinsinkender": "dahinsinkend",
    "dahinsinkendes": "dahinsinkend",
    "dahinsinkest": "dahinsinken",
    "dahinsinket": "dahinsinken",
    "dahinsinkst": "dahinsinken",
    "dahinsinkt": "dahinsinken",
    "dahinstelle": "dahinstellen",
    "dahinstellend": "dahinstellen",
    "dahinstellende": "dahinstellend",
    "dahinstellendem": "dahinstellend",
    "dahinstellenden": "dahinstellend",
    "dahinstellender": "dahinstellend",
    "dahinstellendes": "dahinstellend",
    "dahinstellest": "dahinstellen",
    "dahinstellet": "dahinstellen",
    "dahinstellst": "dahinstellen",
    "dahinstellt": "dahinstellen",
    "dahinstellte": "dahinstellen",
    "dahinstellten": "dahinstellen",
    "dahinstelltest": "dahinstellen",
    "dahinstelltet": "dahinstellen",
    "dahinsänke": "dahinsinken",
    "dahinsänken": "dahinsinken",
    "dahinsänkest": "dahinsinken",
    "dahinsänket": "dahinsinken",
    "dahintergeklemmt": "dahinterklemmen",
    "dahintergeklemmte": "dahintergeklemmt",
    "dahintergeklemmtem": "dahintergeklemmt",
    "dahintergeklemmten": "dahintergeklemmt",
    "dahintergeklemmter": "dahintergeklemmt",
    "dahintergeklemmtes": "dahintergeklemmt",
    "dahintergekniet": "dahinterknien",
    "dahintergekniete": "dahintergekniet",
    "dahintergeknietem": "dahintergekniet",
    "dahintergeknieten": "dahintergekniet",
    "dahintergeknieter": "dahintergekniet",
    "dahintergeknietes": "dahintergekniet",
    "dahintergekommen": "dahinterkommen",
    "dahintergekommene": "dahintergekommen",
    "dahintergekommenem": "dahintergekommen",
    "dahintergekommenen": "dahintergekommen",
    "dahintergekommener": "dahintergekommen",
    "dahintergekommenes": "dahintergekommen",
    "dahintergestanden": "dahinterstehen",
    "dahintergestandene": "dahintergestanden",
    "dahintergestandenem": "dahintergestanden",
    "dahintergestandenen": "dahintergestanden",
    "dahintergestandener": "dahintergestanden",
    "dahintergestandenes": "dahintergestanden",
    "dahinterkam": "dahinterkommen",
    "dahinterkamen": "dahinterkommen",
    "dahinterkamst": "dahinterkommen",
    "dahinterkamt": "dahinterkommen",
    "dahinterklemme": "dahinterklemmen",
    "dahinterklemmend": "dahinterklemmen",
    "dahinterklemmende": "dahinterklemmend",
    "dahinterklemmendem": "dahinterklemmend",
    "dahinterklemmenden": "dahinterklemmend",
    "dahinterklemmender": "dahinterklemmend",
    "dahinterklemmendere": "dahinterklemmend",
    "dahinterklemmenderem": "dahinterklemmend",
    "dahinterklemmenderen": "dahinterklemmend",
    "dahinterklemmenderer": "dahinterklemmend",
    "dahinterklemmenderes": "dahinterklemmend",
    "dahinterklemmendes": "dahinterklemmend",
    "dahinterklemmendste": "dahinterklemmend",
    "dahinterklemmendstem": "dahinterklemmend",
    "dahinterklemmendsten": "dahinterklemmend",
    "dahinterklemmendster": "dahinterklemmend",
    "dahinterklemmendstes": "dahinterklemmend",
    "dahinterklemmest": "dahinterklemmen",
    "dahinterklemmet": "dahinterklemmen",
    "dahinterklemmst": "dahinterklemmen",
    "dahinterklemmt": "dahinterklemmen",
    "dahinterklemmte": "dahinterklemmen",
    "dahinterklemmten": "dahinterklemmen",
    "dahinterklemmtest": "dahinterklemmen",
    "dahinterklemmtet": "dahinterklemmen",
    "dahinterknie": "dahinterknien",
    "dahinterkniend": "dahinterknien",
    "dahinterkniende": "dahinterkniend",
    "dahinterkniendem": "dahinterkniend",
    "dahinterknienden": "dahinterkniend",
    "dahinterkniender": "dahinterkniend",
    "dahinterkniendes": "dahinterkniend",
    "dahinterkniest": "dahinterknien",
    "dahinterkniet": "dahinterknien",
    "dahinterkniete": "dahinterknien",
    "dahinterknieten": "dahinterknien",
    "dahinterknietest": "dahinterknien",
    "dahinterknietet": "dahinterknien",
    "dahinterkomme": "dahinterkommen",
    "dahinterkommend": "dahinterkommen",
    "dahinterkommende": "dahinterkommend",
    "dahinterkommendem": "dahinterkommend",
    "dahinterkommenden": "dahinterkommend",
    "dahinterkommender": "dahinterkommend",
    "dahinterkommendes": "dahinterkommend",
    "dahinterkommest": "dahinterkommen",
    "dahinterkommet": "dahinterkommen",
    "dahinterkommst": "dahinterkommen",
    "dahinterkommt": "dahinterkommen",
    "dahinterkäme": "dahinterkommen",
    "dahinterkämen": "dahinterkommen",
    "dahinterkämest": "dahinterkommen",
    "dahinterkämet": "dahinterkommen",
    "dahinterstand": "dahinterstehen",
    "dahinterstanden": "dahinterstehen",
    "dahinterstandest": "dahinterstehen",
    "dahinterstandet": "dahinterstehen",
    "dahinterstehe": "dahinterstehen",
    "dahinterstehend": "dahinterstehen",
    "dahinterstehende": "dahinterstehend",
    "dahinterstehendem": "dahinterstehend",
    "dahinterstehenden": "dahinterstehend",
    "dahinterstehender": "dahinterstehend",
    "dahinterstehendes": "dahinterstehend",
    "dahinterstehest": "dahinterstehen",
    "dahinterstehet": "dahinterstehen",
    "dahinterstehst": "dahinterstehen",
    "dahintersteht": "dahinterstehen",
    "dahinterstünde": "dahinterstehen",
    "dahinterstünden": "dahinterstehen",
    "dahinterstündest": "dahinterstehen",
    "dahinterstündet": "dahinterstehen",
    "dahinterzuklemmen": "dahinterklemmen",
    "dahinterzuknien": "dahinterknien",
    "dahinterzukommen": "dahinterkommen",
    "dahinterzustehen": "dahinterstehen",
    "dahinwelke": "dahinwelken",
    "dahinwelkend": "dahinwelken",
    "dahinwelkende": "dahinwelkend",
    "dahinwelkendem": "dahinwelkend",
    "dahinwelkenden": "dahinwelkend",
    "dahinwelkender": "dahinwelkend",
    "dahinwelkendere": "dahinwelkend",
    "dahinwelkenderem": "dahinwelkend",
    "dahinwelkenderen": "dahinwelkend",
    "dahinwelkenderer": "dahinwelkend",
    "dahinwelkenderes": "dahinwelkend",
    "dahinwelkendes": "dahinwelkend",
    "dahinwelkendste": "dahinwelkend",
    "dahinwelkendstem": "dahinwelkend",
    "dahinwelkendsten": "dahinwelkend",
    "dahinwelkendster": "dahinwelkend",
    "dahinwelkendstes": "dahinwelkend",
    "dahinwelkest": "dahinwelken",
    "dahinwelket": "dahinwelken",
    "dahinwelkst": "dahinwelken",
    "dahinwelkt": "dahinwelken",
    "dahinwelkte": "dahinwelken",
    "dahinwelkten": "dahinwelken",
    "dahinwelktest": "dahinwelken",
    "dahinwelktet": "dahinwelken",
    "dahinzudämmern": "dahindämmern",
    "dahinzueilen": "dahineilen",
    "dahinzufahren": "dahinfahren",
    "dahinzufliegen": "dahinfliegen",
    "dahinzugeben": "dahingeben",
    "dahinzugehen": "dahingehen",
    "dahinzuleben": "dahinleben",
    "dahinzuraffen": "dahinraffen",
    "dahinzuscheiden": "dahinscheiden",
    "dahinzuschleppen": "dahinschleppen",
    "dahinzuschmelzen": "dahinschmelzen",
    "dahinzuschwinden": "dahinschwinden",
    "dahinzusiechen": "dahinsiechen",
    "dahinzusinken": "dahinsinken",
    "dahinzustellen": "dahinstellen",
    "dahinzuwelken": "dahinwelken",
    "dalag": "daliegen",
    "dalagen": "daliegen",
    "dalagst": "daliegen",
    "dalagt": "daliegen",
    "dalasse": "dalassen",
    "dalassend": "dalassen",
    "dalassende": "dalassend",
    "dalassendem": "dalassend",
    "dalassenden": "dalassend",
    "dalassender": "dalassend",
    "dalassendes": "dalassend",
    "dalassest": "dalassen",
    "dalasset": "dalassen",
    "dalaßt": "dalassen",
    "daliege": "daliegen",
    "daliegend": "daliegen",
    "daliegende": "daliegend",
    "daliegendem": "daliegend",
    "daliegenden": "daliegend",
    "daliegender": "daliegend",
    "daliegendes": "daliegend",
    "daliegest": "daliegen",
    "dalieget": "daliegen",
    "daliegst": "daliegen",
    "daliegt": "daliegen",
    "daließ": "dalassen",
    "daließe": "dalassen",
    "daließen": "dalassen",
    "daließest": "dalassen",
    "daließet": "dalassen",
    "daließt": "dalassen",
    "daläge": "daliegen",
    "dalägen": "daliegen",
    "dalägest": "daliegen",
    "daläget": "daliegen",
    "daläßt": "dalassen",
    "damaligem": "damalig",
    "damaligen": "damalig",
    "damaliger": "damalig",
    "damaliges": "damalig",
    "damele": "dameln",
    "damelnd": "dameln",
    "damelnde": "damelnd",
    "damelndem": "damelnd",
    "damelnden": "damelnd",
    "damelnder": "damelnd",
    "damelndere": "damelnd",
    "damelnderem": "damelnd",
    "damelnderen": "damelnd",
    "damelnderer": "damelnd",
    "damelnderes": "damelnd",
    "damelndes": "damelnd",
    "damelndste": "damelnd",
    "damelndstem": "damelnd",
    "damelndsten": "damelnd",
    "damelndster": "damelnd",
    "damelndstes": "damelnd",
    "damelst": "dameln",
    "damelt": "dameln",
    "damelte": "dameln",
    "damelten": "dameln",
    "dameltest": "dameln",
    "dameltet": "dameln",
    "damle": "dameln",
    "dampfend": "dampfen",
    "dampfende": "dampfend",
    "dampfendem": "dampfend",
    "dampfenden": "dampfend",
    "dampfender": "dampfend",
    "dampfendere": "dampfend",
    "dampfenderem": "dampfend",
    "dampfenderen": "dampfend",
    "dampfenderer": "dampfend",
    "dampfenderes": "dampfend",
    "dampfendes": "dampfend",
    "dampfendste": "dampfend",
    "dampfendstem": "dampfend",
    "dampfendsten": "dampfend",
    "dampfendster": "dampfend",
    "dampfendstes": "dampfend",
    "dampfest": "dampfen",
    "dampfet": "dampfen",
    "dampfst": "dampfen",
    "dampft": "dampfen",
    "dampfte": "dampfen",
    "dampften": "dampfen",
    "dampftest": "dampfen",
    "dampftet": "dampfen",
    "danebenbenahm": "danebenbenehmen",
    "danebenbenahmen": "danebenbenehmen",
    "danebenbenahmst": "danebenbenehmen",
    "danebenbenahmt": "danebenbenehmen",
    "danebenbenehme": "danebenbenehmen",
    "danebenbenehmend": "danebenbenehmen",
    "danebenbenehmende": "danebenbenehmend",
    "danebenbenehmendem": "danebenbenehmend",
    "danebenbenehmenden": "danebenbenehmend",
    "danebenbenehmender": "danebenbenehmend",
    "danebenbenehmendere": "danebenbenehmend",
    "danebenbenehmenderem": "danebenbenehmend",
    "danebenbenehmenderen": "danebenbenehmend",
    "danebenbenehmenderer": "danebenbenehmend",
    "danebenbenehmenderes": "danebenbenehmend",
    "danebenbenehmendes": "danebenbenehmend",
    "danebenbenehmendste": "danebenbenehmend",
    "danebenbenehmendstem": "danebenbenehmend",
    "danebenbenehmendsten": "danebenbenehmend",
    "danebenbenehmendster": "danebenbenehmend",
    "danebenbenehmendstes": "danebenbenehmend",
    "danebenbenehmest": "danebenbenehmen",
    "danebenbenehmet": "danebenbenehmen",
    "danebenbenehmt": "danebenbenehmen",
    "danebenbenimmst": "danebenbenehmen",
    "danebenbenimmt": "danebenbenehmen",
    "danebenbenommen": "danebenbenehmen",
    "danebenbenommene": "danebenbenommen",
    "danebenbenommenem": "danebenbenommen",
    "danebenbenommenen": "danebenbenommen",
    "danebenbenommener": "danebenbenommen",
    "danebenbenommenere": "danebenbenommen",
    "danebenbenommenerem": "danebenbenommen",
    "danebenbenommeneren": "danebenbenommen",
    "danebenbenommenerer": "danebenbenommen",
    "danebenbenommeneres": "danebenbenommen",
    "danebenbenommenes": "danebenbenommen",
    "danebenbenommenste": "danebenbenommen",
    "danebenbenommenstem": "danebenbenommen",
    "danebenbenommensten": "danebenbenommen",
    "danebenbenommenster": "danebenbenommen",
    "danebenbenommenstes": "danebenbenommen",
    "danebenbenähme": "danebenbenehmen",
    "danebenbenähmen": "danebenbenehmen",
    "danebenbenähmest": "danebenbenehmen",
    "danebenbenähmet": "danebenbenehmen",
    "danebenfalle": "danebenfallen",
    "danebenfallend": "danebenfallen",
    "danebenfallende": "danebenfallend",
    "danebenfallendem": "danebenfallend",
    "danebenfallenden": "danebenfallend",
    "danebenfallender": "danebenfallend",
    "danebenfallendes": "danebenfallend",
    "danebenfallest": "danebenfallen",
    "danebenfallet": "danebenfallen",
    "danebenfallt": "danebenfallen",
    "danebenfiel": "danebenfallen",
    "danebenfiele": "danebenfallen",
    "danebenfielen": "danebenfallen",
    "danebenfielest": "danebenfallen",
    "danebenfielet": "danebenfallen",
    "danebenfielst": "danebenfallen",
    "danebenfielt": "danebenfallen",
    "danebenfällst": "danebenfallen",
    "danebenfällt": "danebenfallen",
    "danebengefallen": "danebenfallen",
    "danebengefallene": "danebengefallen",
    "danebengefallenem": "danebengefallen",
    "danebengefallenen": "danebengefallen",
    "danebengefallener": "danebengefallen",
    "danebengefallenes": "danebengefallen",
    "danebengehaucht": "danebenhauchen",
    "danebengehauchte": "danebengehaucht",
    "danebengehauchtem": "danebengehaucht",
    "danebengehauchten": "danebengehaucht",
    "danebengehauchter": "danebengehaucht",
    "danebengehauchtes": "danebengehaucht",
    "danebengehauen": "danebenhauen",
    "danebengehauene": "danebengehauen",
    "danebengehauenem": "danebengehauen",
    "danebengehauenen": "danebengehauen",
    "danebengehauener": "danebengehauen",
    "danebengehauenes": "danebengehauen",
    "danebengelegen": "danebenliegen",
    "danebengelegene": "danebengelegen",
    "danebengelegenem": "danebengelegen",
    "danebengelegenen": "danebengelegen",
    "danebengelegener": "danebengelegen",
    "danebengelegenes": "danebengelegen",
    "danebengeschossen": "danebenschießen",
    "danebengeschossene": "danebengeschossen",
    "danebengeschossenem": "danebengeschossen",
    "danebengeschossenen": "danebengeschossen",
    "danebengeschossener": "danebengeschossen",
    "danebengeschossenes": "danebengeschossen",
    "danebenhauche": "danebenhauchen",
    "danebenhauchend": "danebenhauchen",
    "danebenhauchende": "danebenhauchend",
    "danebenhauchendem": "danebenhauchend",
    "danebenhauchenden": "danebenhauchend",
    "danebenhauchender": "danebenhauchend",
    "danebenhauchendes": "danebenhauchend",
    "danebenhauchest": "danebenhauchen",
    "danebenhauchet": "danebenhauchen",
    "danebenhauchst": "danebenhauchen",
    "danebenhaucht": "danebenhauchen",
    "danebenhauchte": "danebenhauchen",
    "danebenhauchten": "danebenhauchen",
    "danebenhauchtest": "danebenhauchen",
    "danebenhauchtet": "danebenhauchen",
    "danebenhaue": "danebenhauen",
    "danebenhauend": "danebenhauen",
    "danebenhauende": "danebenhauend",
    "danebenhauendem": "danebenhauend",
    "danebenhauenden": "danebenhauend",
    "danebenhauender": "danebenhauend",
    "danebenhauendes": "danebenhauend",
    "danebenhauest": "danebenhauen",
    "danebenhauet": "danebenhauen",
    "danebenhaust": "danebenhauen",
    "danebenhaut": "danebenhauen",
    "danebenhaute": "danebenhauen",
    "danebenhauten": "danebenhauen",
    "danebenhautest": "danebenhauen",
    "danebenhautet": "danebenhauen",
    "danebenlag": "danebenliegen",
    "danebenlagen": "danebenliegen",
    "danebenlagst": "danebenliegen",
    "danebenlagt": "danebenliegen",
    "danebenliege": "danebenliegen",
    "danebenliegend": "danebenliegen",
    "danebenliegende": "danebenliegend",
    "danebenliegendem": "danebenliegend",
    "danebenliegenden": "danebenliegend",
    "danebenliegender": "danebenliegend",
    "danebenliegendes": "danebenliegend",
    "danebenliegest": "danebenliegen",
    "danebenlieget": "danebenliegen",
    "danebenliegst": "danebenliegen",
    "danebenliegt": "danebenliegen",
    "danebenläge": "danebenliegen",
    "danebenlägen": "danebenliegen",
    "danebenlägest": "danebenliegen",
    "danebenläget": "danebenliegen",
    "danebenschieße": "danebenschießen",
    "danebenschießend": "danebenschießen",
    "danebenschießende": "danebenschießend",
    "danebenschießendem": "danebenschießend",
    "danebenschießenden": "danebenschießend",
    "danebenschießender": "danebenschießend",
    "danebenschießendes": "danebenschießend",
    "danebenschießest": "danebenschießen",
    "danebenschießet": "danebenschießen",
    "danebenschießt": "danebenschießen",
    "danebenschossen": "danebenschießen",
    "danebenschoß": "danebenschießen",
    "danebenschoßt": "danebenschießen",
    "danebenschösse": "danebenschießen",
    "danebenschössen": "danebenschießen",
    "danebenschössest": "danebenschießen",
    "danebenschösset": "danebenschießen",
    "danebenzubenehmen": "danebenbenehmen",
    "danebenzufallen": "danebenfallen",
    "danebenzuhauchen": "danebenhauchen",
    "danebenzuhauen": "danebenhauen",
    "danebenzuliegen": "danebenliegen",
    "danebenzuschießen": "danebenschießen",
    "dang": "dingen",
    "dangen": "dingen",
    "dangst": "dingen",
    "dangt": "dingen",
    "dank": "danken",
    "dankbarem": "dankbar",
    "dankbaren": "dankbar",
    "dankbarer": "dankbar",
    "dankbarere": "dankbar",
    "dankbarerem": "dankbar",
    "dankbareren": "dankbar",
    "dankbarerer": "dankbar",
    "dankbareres": "dankbar",
    "dankbares": "dankbar",
    "dankbarstem": "dankbar",
    "dankbarsten": "dankbar",
    "dankbarster": "dankbar",
    "dankbarstes": "dankbar",
    "dankend": "danken",
    "dankende": "dankend",
    "dankendem": "dankend",
    "dankenden": "dankend",
    "dankender": "dankend",
    "dankendere": "dankend",
    "dankenderem": "dankend",
    "dankenderen": "dankend",
    "dankenderer": "dankend",
    "dankenderes": "dankend",
    "dankendes": "dankend",
    "dankendste": "dankend",
    "dankendstem": "dankend",
    "dankendsten": "dankend",
    "dankendster": "dankend",
    "dankendstes": "dankend",
    "dankenswertem": "dankenswert",
    "dankenswerten": "dankenswert",
    "dankenswerter": "dankenswert",
    "dankenswertes": "dankenswert",
    "dankest": "danken",
    "danket": "danken",
    "dankst": "danken",
    "dankt": "danken",
    "dankte": "danken",
    "dankten": "danken",
    "danktest": "danken",
    "danktet": "danken",
    "darangeklebt": "darankleben",
    "darangeklebte": "darangeklebt",
    "darangeklebtem": "darangeklebt",
    "darangeklebten": "darangeklebt",
    "darangeklebter": "darangeklebt",
    "darangeklebtes": "darangeklebt",
    "darangesetzt": "daransetzen",
    "darangesetzte": "darangesetzt",
    "darangesetztem": "darangesetzt",
    "darangesetzten": "darangesetzt",
    "darangesetzter": "darangesetzt",
    "darangesetztes": "darangesetzt",
    "daranklebe": "darankleben",
    "daranklebend": "darankleben",
    "daranklebende": "daranklebend",
    "daranklebendem": "daranklebend",
    "daranklebenden": "daranklebend",
    "daranklebender": "daranklebend",
    "daranklebendes": "daranklebend",
    "daranklebest": "darankleben",
    "daranklebet": "darankleben",
    "daranklebst": "darankleben",
    "daranklebt": "darankleben",
    "daranklebte": "darankleben",
    "daranklebten": "darankleben",
    "daranklebtest": "darankleben",
    "daranklebtet": "darankleben",
    "daransetze": "daransetzen",
    "daransetzend": "daransetzen",
    "daransetzende": "daransetzend",
    "daransetzendem": "daransetzend",
    "daransetzenden": "daransetzend",
    "daransetzender": "daransetzend",
    "daransetzendere": "daransetzend",
    "daransetzenderem": "daransetzend",
    "daransetzenderen": "daransetzend",
    "daransetzenderer": "daransetzend",
    "daransetzenderes": "daransetzend",
    "daransetzendes": "daransetzend",
    "daransetzendste": "daransetzend",
    "daransetzendstem": "daransetzend",
    "daransetzendsten": "daransetzend",
    "daransetzendster": "daransetzend",
    "daransetzendstes": "daransetzend",
    "daransetzest": "daransetzen",
    "daransetzet": "daransetzen",
    "daransetzt": "daransetzen",
    "daransetzte": "daransetzen",
    "daransetzten": "daransetzen",
    "daransetztest": "daransetzen",
    "daransetztet": "daransetzen",
    "daranzukleben": "darankleben",
    "daranzusetzen": "daransetzen",
    "darauffolgende": "darauffolgend",
    "darauffolgendem": "darauffolgend",
    "darauffolgenden": "darauffolgend",
    "darauffolgender": "darauffolgend",
    "darauffolgendes": "darauffolgend",
    "darbe": "darben",
    "darbend": "darben",
    "darbende": "darbend",
    "darbendem": "darbend",
    "darbenden": "darbend",
    "darbender": "darbend",
    "darbendes": "darbend",
    "darbest": "darben",
    "darbet": "darben",
    "darbiete": "darbieten",
    "darbietend": "darbieten",
    "darbietende": "darbietend",
    "darbietendem": "darbietend",
    "darbietenden": "darbietend",
    "darbietender": "darbietend",
    "darbietendes": "darbietend",
    "darbietest": "darbieten",
    "darbietet": "darbieten",
    "darbot": "darbieten",
    "darboten": "darbieten",
    "darbotest": "darbieten",
    "darbotet": "darbieten",
    "darbrachte": "darbringen",
    "darbrachten": "darbringen",
    "darbrachtest": "darbringen",
    "darbrachtet": "darbringen",
    "darbringe": "darbringen",
    "darbringend": "darbringen",
    "darbringende": "darbringend",
    "darbringendem": "darbringend",
    "darbringenden": "darbringend",
    "darbringender": "darbringend",
    "darbringendes": "darbringend",
    "darbringest": "darbringen",
    "darbringet": "darbringen",
    "darbringst": "darbringen",
    "darbringt": "darbringen",
    "darbrächte": "darbringen",
    "darbrächten": "darbringen",
    "darbrächtest": "darbringen",
    "darbrächtet": "darbringen",
    "darbst": "darben",
    "darbt": "darben",
    "darbte": "darben",
    "darbten": "darben",
    "darbtest": "darben",
    "darbtet": "darben",
    "darböte": "darbieten",
    "darböten": "darbieten",
    "darbötest": "darbieten",
    "darbötet": "darbieten",
    "darf": "dürfen",
    "darfst": "dürfen",
    "dargeboten": "darbieten",
    "dargebotene": "dargeboten",
    "dargebotenem": "dargeboten",
    "dargebotenen": "dargeboten",
    "dargebotener": "dargeboten",
    "dargebotenes": "dargeboten",
    "dargebracht": "darbringen",
    "dargebrachte": "dargebracht",
    "dargebrachtem": "dargebracht",
    "dargebrachten": "dargebracht",
    "dargebrachter": "dargebracht",
    "dargebrachtes": "dargebracht",
    "dargelegt": "darlegen",
    "dargelegte": "dargelegt",
    "dargelegtem": "dargelegt",
    "dargelegten": "dargelegt",
    "dargelegter": "dargelegt",
    "dargelegtes": "dargelegt",
    "dargereicht": "darreichen",
    "dargereichte": "dargereicht",
    "dargereichtem": "dargereicht",
    "dargereichten": "dargereicht",
    "dargereichter": "dargereicht",
    "dargereichtes": "dargereicht",
    "dargestellt": "darstellen",
    "dargestellte": "dargestellt",
    "dargestelltem": "dargestellt",
    "dargestellten": "dargestellt",
    "dargestellter": "dargestellt",
    "dargestelltes": "dargestellt",
    "daringesessen": "darinsitzen",
    "daringesessene": "daringesessen",
    "daringesessenem": "daringesessen",
    "daringesessenen": "daringesessen",
    "daringesessener": "daringesessen",
    "daringesessenes": "daringesessen",
    "darinsaß": "darinsitzen",
    "darinsaßen": "darinsitzen",
    "darinsaßt": "darinsitzen",
    "darinsitze": "darinsitzen",
    "darinsitzend": "darinsitzen",
    "darinsitzende": "darinsitzend",
    "darinsitzendem": "darinsitzend",
    "darinsitzenden": "darinsitzend",
    "darinsitzender": "darinsitzend",
    "darinsitzendes": "darinsitzend",
    "darinsitzest": "darinsitzen",
    "darinsitzet": "darinsitzen",
    "darinsitzt": "darinsitzen",
    "darinsäße": "darinsitzen",
    "darinsäßen": "darinsitzen",
    "darinsäßest": "darinsitzen",
    "darinsäßet": "darinsitzen",
    "darinzusitzen": "darinsitzen",
    "darlege": "darlegen",
    "darlegend": "darlegen",
    "darlegende": "darlegend",
    "darlegendem": "darlegend",
    "darlegenden": "darlegend",
    "darlegender": "darlegend",
    "darlegendes": "darlegend",
    "darlegest": "darlegen",
    "darleget": "darlegen",
    "darlegst": "darlegen",
    "darlegt": "darlegen",
    "darlegte": "darlegen",
    "darlegten": "darlegen",
    "darlegtest": "darlegen",
    "darlegtet": "darlegen",
    "darreiche": "darreichen",
    "darreichend": "darreichen",
    "darreichende": "darreichend",
    "darreichendem": "darreichend",
    "darreichenden": "darreichend",
    "darreichender": "darreichend",
    "darreichendes": "darreichend",
    "darreichest": "darreichen",
    "darreichet": "darreichen",
    "darreichst": "darreichen",
    "darreicht": "darreichen",
    "darreichte": "darreichen",
    "darreichten": "darreichen",
    "darreichtest": "darreichen",
    "darreichtet": "darreichen",
    "darstellbare": "darstellbar",
    "darstellbarem": "darstellbar",
    "darstellbaren": "darstellbar",
    "darstellbarer": "darstellbar",
    "darstellbarere": "darstellbar",
    "darstellbarerem": "darstellbar",
    "darstellbareren": "darstellbar",
    "darstellbarerer": "darstellbar",
    "darstellbareres": "darstellbar",
    "darstellbares": "darstellbar",
    "darstellbarste": "darstellbar",
    "darstellbarstem": "darstellbar",
    "darstellbarsten": "darstellbar",
    "darstellbarster": "darstellbar",
    "darstellbarstes": "darstellbar",
    "darstelle": "darstellen",
    "darstellend": "darstellen",
    "darstellende": "darstellend",
    "darstellendem": "darstellend",
    "darstellenden": "darstellend",
    "darstellender": "darstellend",
    "darstellendes": "darstellend",
    "darstellerischem": "darstellerisch",
    "darstellerischen": "darstellerisch",
    "darstellerischer": "darstellerisch",
    "darstellerisches": "darstellerisch",
    "darstellest": "darstellen",
    "darstellet": "darstellen",
    "darstellst": "darstellen",
    "darstellt": "darstellen",
    "darstellte": "darstellen",
    "darstellten": "darstellen",
    "darstelltest": "darstellen",
    "darstelltet": "darstellen",
    "darunterbleibe": "darunterbleiben",
    "darunterbleibend": "darunterbleiben",
    "darunterbleibende": "darunterbleibend",
    "darunterbleibendem": "darunterbleibend",
    "darunterbleibenden": "darunterbleibend",
    "darunterbleibender": "darunterbleibend",
    "darunterbleibendes": "darunterbleibend",
    "darunterbleibest": "darunterbleiben",
    "darunterbleibet": "darunterbleiben",
    "darunterbleibst": "darunterbleiben",
    "darunterbleibt": "darunterbleiben",
    "darunterblieb": "darunterbleiben",
    "darunterbliebe": "darunterbleiben",
    "darunterblieben": "darunterbleiben",
    "darunterbliebest": "darunterbleiben",
    "darunterbliebet": "darunterbleiben",
    "darunterbliebst": "darunterbleiben",
    "darunterbliebt": "darunterbleiben",
    "darunterfalle": "darunterfallen",
    "darunterfallend": "darunterfallen",
    "darunterfallende": "darunterfallend",
    "darunterfallendem": "darunterfallend",
    "darunterfallenden": "darunterfallend",
    "darunterfallender": "darunterfallend",
    "darunterfallendes": "darunterfallend",
    "darunterfallest": "darunterfallen",
    "darunterfallet": "darunterfallen",
    "darunterfallt": "darunterfallen",
    "darunterfiel": "darunterfallen",
    "darunterfiele": "darunterfallen",
    "darunterfielen": "darunterfallen",
    "darunterfielest": "darunterfallen",
    "darunterfielet": "darunterfallen",
    "darunterfielst": "darunterfallen",
    "darunterfielt": "darunterfallen",
    "darunterfällst": "darunterfallen",
    "darunterfällt": "darunterfallen",
    "daruntergeblieben": "darunterbleiben",
    "daruntergebliebene": "daruntergeblieben",
    "daruntergebliebenem": "daruntergeblieben",
    "daruntergebliebenen": "daruntergeblieben",
    "daruntergebliebener": "daruntergeblieben",
    "daruntergebliebenes": "daruntergeblieben",
    "daruntergefallen": "darunterfallen",
    "daruntergefallene": "daruntergefallen",
    "daruntergefallenem": "daruntergefallen",
    "daruntergefallenen": "daruntergefallen",
    "daruntergefallener": "daruntergefallen",
    "daruntergefallenes": "daruntergefallen",
    "daruntergehoben": "darunterheben",
    "daruntergehobene": "daruntergehoben",
    "daruntergehobenem": "daruntergehoben",
    "daruntergehobenen": "daruntergehoben",
    "daruntergehobener": "daruntergehoben",
    "daruntergehobenes": "daruntergehoben",
    "daruntergeschrieben": "darunterschreiben",
    "daruntergeschriebene": "daruntergeschrieben",
    "daruntergeschriebenem": "daruntergeschrieben",
    "daruntergeschriebenen": "daruntergeschrieben",
    "daruntergeschriebener": "daruntergeschrieben",
    "daruntergeschriebenes": "daruntergeschrieben",
    "daruntergesetzt": "daruntersetzen",
    "daruntergesetzte": "daruntergesetzt",
    "daruntergesetztem": "daruntergesetzt",
    "daruntergesetzten": "daruntergesetzt",
    "daruntergesetzter": "daruntergesetzt",
    "daruntergesetztes": "daruntergesetzt",
    "darunterhebe": "darunterheben",
    "darunterhebend": "darunterheben",
    "darunterhebende": "darunterhebend",
    "darunterhebendem": "darunterhebend",
    "darunterhebenden": "darunterhebend",
    "darunterhebender": "darunterhebend",
    "darunterhebendes": "darunterhebend",
    "darunterhebest": "darunterheben",
    "darunterhebet": "darunterheben",
    "darunterhebst": "darunterheben",
    "darunterhebt": "darunterheben",
    "darunterhob": "darunterheben",
    "darunterhoben": "darunterheben",
    "darunterhobst": "darunterheben",
    "darunterhobt": "darunterheben",
    "darunterhöbe": "darunterheben",
    "darunterhöben": "darunterheben",
    "darunterhöbest": "darunterheben",
    "darunterhöbet": "darunterheben",
    "darunterschreibe": "darunterschreiben",
    "darunterschreibend": "darunterschreiben",
    "darunterschreibende": "darunterschreibend",
    "darunterschreibendem": "darunterschreibend",
    "darunterschreibenden": "darunterschreibend",
    "darunterschreibender": "darunterschreibend",
    "darunterschreibendes": "darunterschreibend",
    "darunterschreibest": "darunterschreiben",
    "darunterschreibet": "darunterschreiben",
    "darunterschreibst": "darunterschreiben",
    "darunterschreibt": "darunterschreiben",
    "darunterschrieb": "darunterschreiben",
    "darunterschriebe": "darunterschreiben",
    "darunterschrieben": "darunterschreiben",
    "darunterschriebest": "darunterschreiben",
    "darunterschriebet": "darunterschreiben",
    "darunterschriebst": "darunterschreiben",
    "darunterschriebt": "darunterschreiben",
    "daruntersetze": "daruntersetzen",
    "daruntersetzend": "daruntersetzen",
    "daruntersetzende": "daruntersetzend",
    "daruntersetzendem": "daruntersetzend",
    "daruntersetzenden": "daruntersetzend",
    "daruntersetzender": "daruntersetzend",
    "daruntersetzendes": "daruntersetzend",
    "daruntersetzest": "daruntersetzen",
    "daruntersetzet": "daruntersetzen",
    "daruntersetzt": "daruntersetzen",
    "daruntersetzte": "daruntersetzen",
    "daruntersetzten": "daruntersetzen",
    "daruntersetztest": "daruntersetzen",
    "daruntersetztet": "daruntersetzen",
    "darunterzubleiben": "darunterbleiben",
    "darunterzufallen": "darunterfallen",
    "darunterzuheben": "darunterheben",
    "darunterzuschreiben": "darunterschreiben",
    "darunterzusetzen": "daruntersetzen",
    "darwinistischem": "darwinistisch",
    "darwinistischen": "darwinistisch",
    "darwinistischer": "darwinistisch",
    "darwinistisches": "darwinistisch",
    "darzubieten": "darbieten",
    "darzubringen": "darbringen",
    "darzulegen": "darlegen",
    "darzureichen": "darreichen",
    "darzustellen": "darstellen",
    "darüberfahre": "darüberfahren",
    "darüberfahrend": "darüberfahren",
    "darüberfahrende": "darüberfahrend",
    "darüberfahrendem": "darüberfahrend",
    "darüberfahrenden": "darüberfahrend",
    "darüberfahrender": "darüberfahrend",
    "darüberfahrendes": "darüberfahrend",
    "darüberfahrest": "darüberfahren",
    "darüberfahret": "darüberfahren",
    "darüberfahrt": "darüberfahren",
    "darüberfuhr": "darüberfahren",
    "darüberfuhren": "darüberfahren",
    "darüberfuhrst": "darüberfahren",
    "darüberfuhrt": "darüberfahren",
    "darüberfährst": "darüberfahren",
    "darüberfährt": "darüberfahren",
    "darüberführe": "darüberfahren",
    "darüberführen": "darüberfahren",
    "darüberführest": "darüberfahren",
    "darüberführet": "darüberfahren",
    "darübergefahren": "darüberfahren",
    "darübergefahrene": "darübergefahren",
    "darübergefahrenem": "darübergefahren",
    "darübergefahrenen": "darübergefahren",
    "darübergefahrener": "darübergefahren",
    "darübergefahrenes": "darübergefahren",
    "darübergelegt": "darüberlegen",
    "darübergelegte": "darübergelegt",
    "darübergelegtem": "darübergelegt",
    "darübergelegten": "darübergelegt",
    "darübergelegter": "darübergelegt",
    "darübergelegtes": "darübergelegt",
    "darübergeschrieben": "darüberschreiben",
    "darübergeschriebene": "darübergeschrieben",
    "darübergeschriebenem": "darübergeschrieben",
    "darübergeschriebenen": "darübergeschrieben",
    "darübergeschriebener": "darübergeschrieben",
    "darübergeschriebenes": "darübergeschrieben",
    "darübergestanden": "darüberstehen",
    "darübergestandene": "darübergestanden",
    "darübergestandenem": "darübergestanden",
    "darübergestandenen": "darübergestanden",
    "darübergestandener": "darübergestanden",
    "darübergestandenes": "darübergestanden",
    "darüberlege": "darüberlegen",
    "darüberlegend": "darüberlegen",
    "darüberlegende": "darüberlegend",
    "darüberlegendem": "darüberlegend",
    "darüberlegenden": "darüberlegend",
    "darüberlegender": "darüberlegend",
    "darüberlegendes": "darüberlegend",
    "darüberlegest": "darüberlegen",
    "darüberleget": "darüberlegen",
    "darüberlegst": "darüberlegen",
    "darüberlegt": "darüberlegen",
    "darüberlegte": "darüberlegen",
    "darüberlegten": "darüberlegen",
    "darüberlegtest": "darüberlegen",
    "darüberlegtet": "darüberlegen",
    "darüberschreibe": "darüberschreiben",
    "darüberschreibend": "darüberschreiben",
    "darüberschreibende": "darüberschreibend",
    "darüberschreibendem": "darüberschreibend",
    "darüberschreibenden": "darüberschreibend",
    "darüberschreibender": "darüberschreibend",
    "darüberschreibendes": "darüberschreibend",
    "darüberschreibest": "darüberschreiben",
    "darüberschreibet": "darüberschreiben",
    "darüberschreibst": "darüberschreiben",
    "darüberschreibt": "darüberschreiben",
    "darüberschrieb": "darüberschreiben",
    "darüberschriebe": "darüberschreiben",
    "darüberschrieben": "darüberschreiben",
    "darüberschriebest": "darüberschreiben",
    "darüberschriebet": "darüberschreiben",
    "darüberschriebst": "darüberschreiben",
    "darüberschriebt": "darüberschreiben",
    "darüberstand": "darüberstehen",
    "darüberstanden": "darüberstehen",
    "darüberstandest": "darüberstehen",
    "darüberstandet": "darüberstehen",
    "darüberstehe": "darüberstehen",
    "darüberstehend": "darüberstehen",
    "darüberstehende": "darüberstehend",
    "darüberstehendem": "darüberstehend",
    "darüberstehenden": "darüberstehend",
    "darüberstehender": "darüberstehend",
    "darüberstehendes": "darüberstehend",
    "darüberstehest": "darüberstehen",
    "darüberstehet": "darüberstehen",
    "darüberstehst": "darüberstehen",
    "darübersteht": "darüberstehen",
    "darüberstünde": "darüberstehen",
    "darüberstünden": "darüberstehen",
    "darüberstündest": "darüberstehen",
    "darüberstündet": "darüberstehen",
    "darüberzufahren": "darüberfahren",
    "darüberzulegen": "darüberlegen",
    "darüberzuschreiben": "darüberschreiben",
    "darüberzustehen": "darüberstehen",
    "das": "der",
    "dasaß": "dasitzen",
    "dasaßen": "dasitzen",
    "dasaßt": "dasitzen",
    "dasitze": "dasitzen",
    "dasitzend": "dasitzen",
    "dasitzende": "dasitzend",
    "dasitzendem": "dasitzend",
    "dasitzenden": "dasitzend",
    "dasitzender": "dasitzend",
    "dasitzendes": "dasitzend",
    "dasitzest": "dasitzen",
    "dasitzet": "dasitzen",
    "dasitzt": "dasitzen",
    "dasjenige": "derjenige",
    "dasselbe": "derselbe",
    "dastand": "dastehen",
    "dastanden": "dastehen",
    "dastandest": "dastehen",
    "dastandet": "dastehen",
    "dastehe": "dastehen",
    "dastehend": "dastehen",
    "dastehende": "dastehend",
    "dastehendem": "dastehend",
    "dastehenden": "dastehend",
    "dastehender": "dastehend",
    "dastehendes": "dastehend",
    "dastehest": "dastehen",
    "dastehet": "dastehen",
    "dastehst": "dastehen",
    "dasteht": "dastehen",
    "dastünde": "dastehen",
    "dastünden": "dastehen",
    "dastündest": "dastehen",
    "dastündet": "dastehen",
    "dasäße": "dasitzen",
    "dasäßen": "dasitzen",
    "dasäßest": "dasitzen",
    "dasäßet": "dasitzen",
    "datierbarem": "datierbar",
    "datierbaren": "datierbar",
    "datierbarer": "datierbar",
    "datierbarere": "datierbar",
    "datierbarerem": "datierbar",
    "datierbareren": "datierbar",
    "datierbarerer": "datierbar",
    "datierbareres": "datierbar",
    "datierbares": "datierbar",
    "datierbarste": "datierbar",
    "datierbarstem": "datierbar",
    "datierbarsten": "datierbar",
    "datierbarster": "datierbar",
    "datierbarstes": "datierbar",
    "datiere": "datieren",
    "datierend": "datieren",
    "datierende": "datierend",
    "datierendem": "datierend",
    "datierenden": "datierend",
    "datierender": "datierend",
    "datierendere": "datierend",
    "datierenderem": "datierend",
    "datierenderen": "datierend",
    "datierenderer": "datierend",
    "datierenderes": "datierend",
    "datierendes": "datierend",
    "datierendste": "datierend",
    "datierendstem": "datierend",
    "datierendsten": "datierend",
    "datierendster": "datierend",
    "datierendstes": "datierend",
    "datierest": "datieren",
    "datieret": "datieren",
    "datierst": "datieren",
    "datiert": "datieren",
    "datierte": "datieren",
    "datiertem": "datiert",
    "datierten": "datieren",
    "datierter": "datiert",
    "datiertes": "datiert",
    "datiertest": "datieren",
    "datiertet": "datieren",
    "dauere": "dauern",
    "dauerhafte": "dauerhaft",
    "dauerhaftem": "dauerhaft",
    "dauerhaften": "dauerhaft",
    "dauerhafter": "dauerhaft",
    "dauerhaftere": "dauerhaft",
    "dauerhafterem": "dauerhaft",
    "dauerhafteren": "dauerhaft",
    "dauerhafterer": "dauerhaft",
    "dauerhafteres": "dauerhaft",
    "dauerhaftes": "dauerhaft",
    "dauerhafteste": "dauerhaft",
    "dauerhaftestem": "dauerhaft",
    "dauerhaftesten": "dauerhaft",
    "dauerhaftester": "dauerhaft",
    "dauerhaftestes": "dauerhaft",
    "dauernd": "dauern",
    "dauernde": "dauernd",
    "dauerndem": "dauernd",
    "dauernden": "dauernd",
    "dauernder": "dauernd",
    "dauerndes": "dauernd",
    "dauerst": "dauern",
    "dauert": "dauern",
    "dauerte": "dauern",
    "dauerten": "dauern",
    "dauertest": "dauern",
    "dauertet": "dauern",
    "daumenbreite": "daumenbreit",
    "daumenbreitem": "daumenbreit",
    "daumenbreiten": "daumenbreit",
    "daumenbreiter": "daumenbreit",
    "daumenbreites": "daumenbreit",
    "davonbleibe": "davonbleiben",
    "davonbleibend": "davonbleiben",
    "davonbleibende": "davonbleibend",
    "davonbleibendem": "davonbleibend",
    "davonbleibenden": "davonbleibend",
    "davonbleibender": "davonbleibend",
    "davonbleibendes": "davonbleibend",
    "davonbleibest": "davonbleiben",
    "davonbleibet": "davonbleiben",
    "davonbleibst": "davonbleiben",
    "davonbleibt": "davonbleiben",
    "davonblieb": "davonbleiben",
    "davonbliebe": "davonbleiben",
    "davonblieben": "davonbleiben",
    "davonbliebest": "davonbleiben",
    "davonbliebet": "davonbleiben",
    "davonbliebst": "davonbleiben",
    "davonbliebt": "davonbleiben",
    "davoneile": "davoneilen",
    "davoneilend": "davoneilen",
    "davoneilende": "davoneilend",
    "davoneilendem": "davoneilend",
    "davoneilenden": "davoneilend",
    "davoneilender": "davoneilend",
    "davoneilendes": "davoneilend",
    "davoneilest": "davoneilen",
    "davoneilet": "davoneilen",
    "davoneilst": "davoneilen",
    "davoneilt": "davoneilen",
    "davoneilte": "davoneilen",
    "davoneilten": "davoneilen",
    "davoneiltest": "davoneilen",
    "davoneiltet": "davoneilen",
    "davonfahre": "davonfahren",
    "davonfahrend": "davonfahren",
    "davonfahrende": "davonfahrend",
    "davonfahrendem": "davonfahrend",
    "davonfahrenden": "davonfahrend",
    "davonfahrender": "davonfahrend",
    "davonfahrendes": "davonfahrend",
    "davonfahrest": "davonfahren",
    "davonfahret": "davonfahren",
    "davonfahrt": "davonfahren",
    "davonfliege": "davonfliegen",
    "davonfliegend": "davonfliegen",
    "davonfliegende": "davonfliegend",
    "davonfliegendem": "davonfliegend",
    "davonfliegenden": "davonfliegend",
    "davonfliegender": "davonfliegend",
    "davonfliegendes": "davonfliegend",
    "davonfliegest": "davonfliegen",
    "davonflieget": "davonfliegen",
    "davonfliegst": "davonfliegen",
    "davonfliegt": "davonfliegen",
    "davonflog": "davonfliegen",
    "davonflogen": "davonfliegen",
    "davonflogst": "davonfliegen",
    "davonflogt": "davonfliegen",
    "davonflöge": "davonfliegen",
    "davonflögen": "davonfliegen",
    "davonflögest": "davonfliegen",
    "davonflöget": "davonfliegen",
    "davonfuhr": "davonfahren",
    "davonfuhren": "davonfahren",
    "davonfuhrst": "davonfahren",
    "davonfuhrt": "davonfahren",
    "davonfährst": "davonfahren",
    "davonfährt": "davonfahren",
    "davonführe": "davonfahren",
    "davonführen": "davonfahren",
    "davonführest": "davonfahren",
    "davonführet": "davonfahren",
    "davongeblieben": "davonbleiben",
    "davongebliebene": "davongeblieben",
    "davongebliebenem": "davongeblieben",
    "davongebliebenen": "davongeblieben",
    "davongebliebener": "davongeblieben",
    "davongebliebenes": "davongeblieben",
    "davongeeilt": "davoneilen",
    "davongeeilte": "davongeeilt",
    "davongeeiltem": "davongeeilt",
    "davongeeilten": "davongeeilt",
    "davongeeilter": "davongeeilt",
    "davongeeiltes": "davongeeilt",
    "davongefahren": "davonfahren",
    "davongefahrene": "davongefahren",
    "davongefahrenem": "davongefahren",
    "davongefahrenen": "davongefahren",
    "davongefahrener": "davongefahren",
    "davongefahrenes": "davongefahren",
    "davongeflogen": "davonfliegen",
    "davongeflogene": "davongeflogen",
    "davongeflogenem": "davongeflogen",
    "davongeflogenen": "davongeflogen",
    "davongeflogener": "davongeflogen",
    "davongeflogenes": "davongeflogen",
    "davongekommen": "davonkommen",
    "davongekommene": "davongekommen",
    "davongekommenem": "davongekommen",
    "davongekommenen": "davongekommen",
    "davongekommener": "davongekommen",
    "davongekommenes": "davongekommen",
    "davongelaufen": "davonlaufen",
    "davongelaufene": "davongelaufen",
    "davongelaufenem": "davongelaufen",
    "davongelaufenen": "davongelaufen",
    "davongelaufener": "davongelaufen",
    "davongelaufenes": "davongelaufen",
    "davongemacht": "davonmachen",
    "davongemachte": "davongemacht",
    "davongemachtem": "davongemacht",
    "davongemachten": "davongemacht",
    "davongemachter": "davongemacht",
    "davongemachtes": "davongemacht",
    "davongestohlen": "davonstehlen",
    "davongestohlene": "davongestohlen",
    "davongestohlenem": "davongestohlen",
    "davongestohlenen": "davongestohlen",
    "davongestohlener": "davongestohlen",
    "davongestohlenere": "davongestohlen",
    "davongestohlenerem": "davongestohlen",
    "davongestohleneren": "davongestohlen",
    "davongestohlenerer": "davongestohlen",
    "davongestohleneres": "davongestohlen",
    "davongestohlenes": "davongestohlen",
    "davongestohlenste": "davongestohlen",
    "davongestohlenstem": "davongestohlen",
    "davongestohlensten": "davongestohlen",
    "davongestohlenster": "davongestohlen",
    "davongestohlenstes": "davongestohlen",
    "davongetragen": "davontragen",
    "davongetragene": "davongetragen",
    "davongetragenem": "davongetragen",
    "davongetragenen": "davongetragen",
    "davongetragener": "davongetragen",
    "davongetragenes": "davongetragen",
    "davongezogen": "davonziehen",
    "davongezogene": "davongezogen",
    "davongezogenem": "davongezogen",
    "davongezogenen": "davongezogen",
    "davongezogener": "davongezogen",
    "davongezogenes": "davongezogen",
    "davonkam": "davonkommen",
    "davonkamen": "davonkommen",
    "davonkamst": "davonkommen",
    "davonkamt": "davonkommen",
    "davonkomme": "davonkommen",
    "davonkommend": "davonkommen",
    "davonkommende": "davonkommend",
    "davonkommendem": "davonkommend",
    "davonkommenden": "davonkommend",
    "davonkommender": "davonkommend",
    "davonkommendes": "davonkommend",
    "davonkommest": "davonkommen",
    "davonkommet": "davonkommen",
    "davonkommst": "davonkommen",
    "davonkommt": "davonkommen",
    "davonkäme": "davonkommen",
    "davonkämen": "davonkommen",
    "davonkämest": "davonkommen",
    "davonkämet": "davonkommen",
    "davonlaufe": "davonlaufen",
    "davonlaufend": "davonlaufen",
    "davonlaufende": "davonlaufend",
    "davonlaufendem": "davonlaufend",
    "davonlaufenden": "davonlaufend",
    "davonlaufender": "davonlaufend",
    "davonlaufendes": "davonlaufend",
    "davonlaufest": "davonlaufen",
    "davonlaufet": "davonlaufen",
    "davonlauft": "davonlaufen",
    "davonlief": "davonlaufen",
    "davonliefe": "davonlaufen",
    "davonliefen": "davonlaufen",
    "davonliefest": "davonlaufen",
    "davonliefet": "davonlaufen",
    "davonliefst": "davonlaufen",
    "davonlieft": "davonlaufen",
    "davonläufst": "davonlaufen",
    "davonläuft": "davonlaufen",
    "davonmache": "davonmachen",
    "davonmachend": "davonmachen",
    "davonmachende": "davonmachend",
    "davonmachendem": "davonmachend",
    "davonmachenden": "davonmachend",
    "davonmachender": "davonmachend",
    "davonmachendes": "davonmachend",
    "davonmachest": "davonmachen",
    "davonmachet": "davonmachen",
    "davonmachst": "davonmachen",
    "davonmacht": "davonmachen",
    "davonmachte": "davonmachen",
    "davonmachten": "davonmachen",
    "davonmachtest": "davonmachen",
    "davonmachtet": "davonmachen",
    "davonstahl": "davonstehlen",
    "davonstahlen": "davonstehlen",
    "davonstahlst": "davonstehlen",
    "davonstahlt": "davonstehlen",
    "davonstehle": "davonstehlen",
    "davonstehlend": "davonstehlen",
    "davonstehlende": "davonstehlend",
    "davonstehlendem": "davonstehlend",
    "davonstehlenden": "davonstehlend",
    "davonstehlender": "davonstehlend",
    "davonstehlendere": "davonstehlend",
    "davonstehlenderem": "davonstehlend",
    "davonstehlenderen": "davonstehlend",
    "davonstehlenderer": "davonstehlend",
    "davonstehlenderes": "davonstehlend",
    "davonstehlendes": "davonstehlend",
    "davonstehlendste": "davonstehlend",
    "davonstehlendstem": "davonstehlend",
    "davonstehlendsten": "davonstehlend",
    "davonstehlendster": "davonstehlend",
    "davonstehlendstes": "davonstehlend",
    "davonstehlest": "davonstehlen",
    "davonstehlet": "davonstehlen",
    "davonstehlt": "davonstehlen",
    "davonstiehlst": "davonstehlen",
    "davonstiehlt": "davonstehlen",
    "davonstähle": "davonstehlen",
    "davonstählen": "davonstehlen",
    "davonstählest": "davonstehlen",
    "davonstählet": "davonstehlen",
    "davontrage": "davontragen",
    "davontragend": "davontragen",
    "davontragende": "davontragend",
    "davontragendem": "davontragend",
    "davontragenden": "davontragend",
    "davontragender": "davontragend",
    "davontragendes": "davontragend",
    "davontragest": "davontragen",
    "davontraget": "davontragen",
    "davontragt": "davontragen",
    "davontrug": "davontragen",
    "davontrugen": "davontragen",
    "davontrugst": "davontragen",
    "davontrugt": "davontragen",
    "davonträgst": "davontragen",
    "davonträgt": "davontragen",
    "davontrüge": "davontragen",
    "davontrügen": "davontragen",
    "davontrügest": "davontragen",
    "davontrüget": "davontragen",
    "davonziehe": "davonziehen",
    "davonziehend": "davonziehen",
    "davonziehende": "davonziehend",
    "davonziehendem": "davonziehend",
    "davonziehenden": "davonziehend",
    "davonziehender": "davonziehend",
    "davonziehendes": "davonziehend",
    "davonziehest": "davonziehen",
    "davonziehet": "davonziehen",
    "davonziehst": "davonziehen",
    "davonzieht": "davonziehen",
    "davonzog": "davonziehen",
    "davonzogen": "davonziehen",
    "davonzogst": "davonziehen",
    "davonzogt": "davonziehen",
    "davonzubleiben": "davonbleiben",
    "davonzueilen": "davoneilen",
    "davonzufahren": "davonfahren",
    "davonzufliegen": "davonfliegen",
    "davonzukommen": "davonkommen",
    "davonzulaufen": "davonlaufen",
    "davonzumachen": "davonmachen",
    "davonzustehlen": "davonstehlen",
    "davonzutragen": "davontragen",
    "davonzuziehen": "davonziehen",
    "davonzöge": "davonziehen",
    "davonzögen": "davonziehen",
    "davonzögest": "davonziehen",
    "davonzöget": "davonziehen",
    "davorgelegen": "davorliegen",
    "davorgelegene": "davorgelegen",
    "davorgelegenem": "davorgelegen",
    "davorgelegenen": "davorgelegen",
    "davorgelegener": "davorgelegen",
    "davorgelegenes": "davorgelegen",
    "davorgelegt": "davorlegen",
    "davorgelegte": "davorgelegt",
    "davorgelegtem": "davorgelegt",
    "davorgelegten": "davorgelegt",
    "davorgelegter": "davorgelegt",
    "davorgelegtes": "davorgelegt",
    "davorgestanden": "davorstehen",
    "davorgestandene": "davorgestanden",
    "davorgestandenem": "davorgestanden",
    "davorgestandenen": "davorgestanden",
    "davorgestandener": "davorgestanden",
    "davorgestandenes": "davorgestanden",
    "davorgestellt": "davorstellen",
    "davorgestellte": "davorgestellt",
    "davorgestelltem": "davorgestellt",
    "davorgestellten": "davorgestellt",
    "davorgestellter": "davorgestellt",
    "davorgestelltes": "davorgestellt",
    "davorlag": "davorliegen",
    "davorlagen": "davorliegen",
    "davorlagst": "davorliegen",
    "davorlagt": "davorliegen",
    "davorlege": "davorlegen",
    "davorlegend": "davorlegen",
    "davorlegende": "davorlegend",
    "davorlegendem": "davorlegend",
    "davorlegenden": "davorlegend",
    "davorlegender": "davorlegend",
    "davorlegendes": "davorlegend",
    "davorlegest": "davorlegen",
    "davorleget": "davorlegen",
    "davorlegst": "davorlegen",
    "davorlegt": "davorlegen",
    "davorlegte": "davorlegen",
    "davorlegten": "davorlegen",
    "davorlegtest": "davorlegen",
    "davorlegtet": "davorlegen",
    "davorliege": "davorliegen",
    "davorliegend": "davorliegen",
    "davorliegende": "davorliegend",
    "davorliegendem": "davorliegend",
    "davorliegenden": "davorliegend",
    "davorliegender": "davorliegend",
    "davorliegendes": "davorliegend",
    "davorliegest": "davorliegen",
    "davorlieget": "davorliegen",
    "davorliegst": "davorliegen",
    "davorliegt": "davorliegen",
    "davorläge": "davorliegen",
    "davorlägen": "davorliegen",
    "davorlägest": "davorliegen",
    "davorläget": "davorliegen",
    "davorstand": "davorstehen",
    "davorstanden": "davorstehen",
    "davorstandest": "davorstehen",
    "davorstandet": "davorstehen",
    "davorstehe": "davorstehen",
    "davorstehend": "davorstehen",
    "davorstehende": "davorstehend",
    "davorstehendem": "davorstehend",
    "davorstehenden": "davorstehend",
    "davorstehender": "davorstehend",
    "davorstehendes": "davorstehend",
    "davorstehest": "davorstehen",
    "davorstehet": "davorstehen",
    "davorstehst": "davorstehen",
    "davorsteht": "davorstehen",
    "davorstelle": "davorstellen",
    "davorstellend": "davorstellen",
    "davorstellende": "davorstellend",
    "davorstellendem": "davorstellend",
    "davorstellenden": "davorstellend",
    "davorstellender": "davorstellend",
    "davorstellendes": "davorstellend",
    "davorstellest": "davorstellen",
    "davorstellet": "davorstellen",
    "davorstellst": "davorstellen",
    "davorstellt": "davorstellen",
    "davorstellte": "davorstellen",
    "davorstellten": "davorstellen",
    "davorstelltest": "davorstellen",
    "davorstelltet": "davorstellen",
    "davorstünde": "davorstehen",
    "davorstünden": "davorstehen",
    "davorstündest": "davorstehen",
    "davorstündet": "davorstehen",
    "davorzulegen": "davorlegen",
    "davorzuliegen": "davorliegen",
    "davorzustehen": "davorstehen",
    "davorzustellen": "davorstellen",
    "dazubehalten": "dabehalten",
    "dazubleiben": "dableiben",
    "dazugehörige": "dazugehörig",
    "dazugehörigem": "dazugehörig",
    "dazugehörigen": "dazugehörig",
    "dazugehöriger": "dazugehörig",
    "dazugehöriges": "dazugehörig",
    "dazugekommen": "dazukommen",
    "dazugekommene": "dazugekommen",
    "dazugekommenem": "dazugekommen",
    "dazugekommenen": "dazugekommen",
    "dazugekommener": "dazugekommen",
    "dazugekommenes": "dazugekommen",
    "dazugelernt": "dazulernen",
    "dazugelernte": "dazugelernt",
    "dazugelerntem": "dazugelernt",
    "dazugelernten": "dazugelernt",
    "dazugelernter": "dazugelernt",
    "dazugelerntes": "dazugelernt",
    "dazugeschrieben": "dazuschreiben",
    "dazugeschriebene": "dazugeschrieben",
    "dazugeschriebenem": "dazugeschrieben",
    "dazugeschriebenen": "dazugeschrieben",
    "dazugeschriebener": "dazugeschrieben",
    "dazugeschriebenes": "dazugeschrieben",
    "dazugesetzt": "dazusetzen",
    "dazugesetzte": "dazugesetzt",
    "dazugesetztem": "dazugesetzt",
    "dazugesetzten": "dazugesetzt",
    "dazugesetzter": "dazugesetzt",
    "dazugesetztes": "dazugesetzt",
    "dazugezahlt": "dazuzahlen",
    "dazugezahlte": "dazugezahlt",
    "dazugezahltem": "dazugezahlt",
    "dazugezahlten": "dazugezahlt",
    "dazugezahlter": "dazugezahlt",
    "dazugezahltes": "dazugezahlt",
    "dazukam": "dazukommen",
    "dazukamen": "dazukommen",
    "dazukamst": "dazukommen",
    "dazukamt": "dazukommen",
    "dazukomme": "dazukommen",
    "dazukommend": "dazukommen",
    "dazukommende": "dazukommend",
    "dazukommendem": "dazukommend",
    "dazukommenden": "dazukommend",
    "dazukommender": "dazukommend",
    "dazukommendes": "dazukommend",
    "dazukommest": "dazukommen",
    "dazukommet": "dazukommen",
    "dazukommst": "dazukommen",
    "dazukommt": "dazukommen",
    "dazukäme": "dazukommen",
    "dazukämen": "dazukommen",
    "dazukämest": "dazukommen",
    "dazukämet": "dazukommen",
    "dazulassen": "dalassen",
    "dazulerne": "dazulernen",
    "dazulernend": "dazulernen",
    "dazulernende": "dazulernend",
    "dazulernendem": "dazulernend",
    "dazulernenden": "dazulernend",
    "dazulernender": "dazulernend",
    "dazulernendes": "dazulernend",
    "dazulernest": "dazulernen",
    "dazulernet": "dazulernen",
    "dazulernst": "dazulernen",
    "dazulernt": "dazulernen",
    "dazulernte": "dazulernen",
    "dazulernten": "dazulernen",
    "dazulerntest": "dazulernen",
    "dazulerntet": "dazulernen",
    "dazuliegen": "daliegen",
    "dazuschreibe": "dazuschreiben",
    "dazuschreibend": "dazuschreiben",
    "dazuschreibende": "dazuschreibend",
    "dazuschreibendem": "dazuschreibend",
    "dazuschreibenden": "dazuschreibend",
    "dazuschreibender": "dazuschreibend",
    "dazuschreibendes": "dazuschreibend",
    "dazuschreibest": "dazuschreiben",
    "dazuschreibet": "dazuschreiben",
    "dazuschreibst": "dazuschreiben",
    "dazuschreibt": "dazuschreiben",
    "dazuschrieb": "dazuschreiben",
    "dazuschriebe": "dazuschreiben",
    "dazuschrieben": "dazuschreiben",
    "dazuschriebest": "dazuschreiben",
    "dazuschriebet": "dazuschreiben",
    "dazuschriebst": "dazuschreiben",
    "dazuschriebt": "dazuschreiben",
    "dazusetze": "dazusetzen",
    "dazusetzend": "dazusetzen",
    "dazusetzende": "dazusetzend",
    "dazusetzendem": "dazusetzend",
    "dazusetzenden": "dazusetzend",
    "dazusetzender": "dazusetzend",
    "dazusetzendes": "dazusetzend",
    "dazusetzest": "dazusetzen",
    "dazusetzet": "dazusetzen",
    "dazusetzt": "dazusetzen",
    "dazusetzte": "dazusetzen",
    "dazusetzten": "dazusetzen",
    "dazusetztest": "dazusetzen",
    "dazusetztet": "dazusetzen",
    "dazusitzen": "dasitzen",
    "dazustehen": "dastehen",
    "dazuzahle": "dazuzahlen",
    "dazuzahlend": "dazuzahlen",
    "dazuzahlende": "dazuzahlend",
    "dazuzahlendem": "dazuzahlend",
    "dazuzahlenden": "dazuzahlend",
    "dazuzahlender": "dazuzahlend",
    "dazuzahlendes": "dazuzahlend",
    "dazuzahlest": "dazuzahlen",
    "dazuzahlet": "dazuzahlen",
    "dazuzahlst": "dazuzahlen",
    "dazuzahlt": "dazuzahlen",
    "dazuzahlte": "dazuzahlen",
    "dazuzahlten": "dazuzahlen",
    "dazuzahltest": "dazuzahlen",
    "dazuzahltet": "dazuzahlen",
    "dazuzukommen": "dazukommen",
    "dazuzulernen": "dazulernen",
    "dazuzuschreiben": "dazuschreiben",
    "dazuzusetzen": "dazusetzen",
    "dazuzuzahlen": "dazuzahlen",
    "dazwischenfahre": "dazwischenfahren",
    "dazwischenfahrend": "dazwischenfahren",
    "dazwischenfahrende": "dazwischenfahrend",
    "dazwischenfahrendem": "dazwischenfahrend",
    "dazwischenfahrenden": "dazwischenfahrend",
    "dazwischenfahrender": "dazwischenfahrend",
    "dazwischenfahrendes": "dazwischenfahrend",
    "dazwischenfahrest": "dazwischenfahren",
    "dazwischenfahret": "dazwischenfahren",
    "dazwischenfahrt": "dazwischenfahren",
    "dazwischenfuhr": "dazwischenfahren",
    "dazwischenfuhren": "dazwischenfahren",
    "dazwischenfuhrst": "dazwischenfahren",
    "dazwischenfuhrt": "dazwischenfahren",
    "dazwischenfunke": "dazwischenfunken",
    "dazwischenfunkend": "dazwischenfunken",
    "dazwischenfunkende": "dazwischenfunkend",
    "dazwischenfunkendem": "dazwischenfunkend",
    "dazwischenfunkenden": "dazwischenfunkend",
    "dazwischenfunkender": "dazwischenfunkend",
    "dazwischenfunkendes": "dazwischenfunkend",
    "dazwischenfunkest": "dazwischenfunken",
    "dazwischenfunket": "dazwischenfunken",
    "dazwischenfunkst": "dazwischenfunken",
    "dazwischenfunkt": "dazwischenfunken",
    "dazwischenfunkte": "dazwischenfunken",
    "dazwischenfunkten": "dazwischenfunken",
    "dazwischenfunktest": "dazwischenfunken",
    "dazwischenfunktet": "dazwischenfunken",
    "dazwischenfährst": "dazwischenfahren",
    "dazwischenfährt": "dazwischenfahren",
    "dazwischenführe": "dazwischenfahren",
    "dazwischenführen": "dazwischenfahren",
    "dazwischenführest": "dazwischenfahren",
    "dazwischenführet": "dazwischenfahren",
    "dazwischengefahren": "dazwischengefahre",
    "dazwischengefahrene": "dazwischengefahren",
    "dazwischengefahrenem": "dazwischengefahren",
    "dazwischengefahrenen": "dazwischengefahren",
    "dazwischengefahrener": "dazwischengefahren",
    "dazwischengefahrenes": "dazwischengefahren",
    "dazwischengefunkt": "dazwischengefunke",
    "dazwischengefunkte": "dazwischengefunke",
    "dazwischengefunktem": "dazwischengefunkt",
    "dazwischengefunkten": "dazwischengefunke",
    "dazwischengefunkter": "dazwischengefunkt",
    "dazwischengefunktes": "dazwischengefunkt",
    "dazwischengeredet": "dazwischenreden",
    "dazwischengeredete": "dazwischengereden",
    "dazwischengeredetem": "dazwischengeredet",
    "dazwischengeredeten": "dazwischengereden",
    "dazwischengeredeter": "dazwischengeredet",
    "dazwischengeredetes": "dazwischengeredet",
    "dazwischengerufen": "dazwischenrufen",
    "dazwischengerufene": "dazwischengerufen",
    "dazwischengerufenem": "dazwischengerufen",
    "dazwischengerufenen": "dazwischengerufen",
    "dazwischengerufener": "dazwischengerufen",
    "dazwischengerufenes": "dazwischengerufen",
    "dazwischengestanden": "dazwischenstehen",
    "dazwischengestandene": "dazwischengestanden",
    "dazwischengestandenem": "dazwischengestanden",
    "dazwischengestandenen": "dazwischengestanden",
    "dazwischengestandener": "dazwischengestanden",
    "dazwischengestandenes": "dazwischengestanden",
    "dazwischengetreten": "dazwischentreten",
    "dazwischengetretene": "dazwischengetreten",
    "dazwischengetretenem": "dazwischengetreten",
    "dazwischengetretenen": "dazwischengetreten",
    "dazwischengetretener": "dazwischengetreten",
    "dazwischengetretenes": "dazwischengetreten",
    "dazwischenrede": "dazwischenreden",
    "dazwischenredend": "dazwischenreden",
    "dazwischenredende": "dazwischenredend",
    "dazwischenredendem": "dazwischenredend",
    "dazwischenredenden": "dazwischenredend",
    "dazwischenredender": "dazwischenredend",
    "dazwischenredendes": "dazwischenredend",
    "dazwischenredest": "dazwischenreden",
    "dazwischenredet": "dazwischenreden",
    "dazwischenredete": "dazwischenreden",
    "dazwischenredeten": "dazwischenreden",
    "dazwischenredetest": "dazwischenreden",
    "dazwischenredetet": "dazwischenreden",
    "dazwischenrief": "dazwischenrufen",
    "dazwischenriefe": "dazwischenrufen",
    "dazwischenriefen": "dazwischenrufen",
    "dazwischenriefest": "dazwischenrufen",
    "dazwischenriefet": "dazwischenrufen",
    "dazwischenriefst": "dazwischenrufen",
    "dazwischenrieft": "dazwischenrufen",
    "dazwischenrufe": "dazwischenrufen",
    "dazwischenrufend": "dazwischenrufen",
    "dazwischenrufende": "dazwischenrufend",
    "dazwischenrufendem": "dazwischenrufend",
    "dazwischenrufenden": "dazwischenrufend",
    "dazwischenrufender": "dazwischenrufend",
    "dazwischenrufendes": "dazwischenrufend",
    "dazwischenrufest": "dazwischenrufen",
    "dazwischenrufet": "dazwischenrufen",
    "dazwischenrufst": "dazwischenrufen",
    "dazwischenruft": "dazwischenrufen",
    "dazwischenstand": "dazwischenstehen",
    "dazwischenstanden": "dazwischenstehen",
    "dazwischenstandest": "dazwischenstehen",
    "dazwischenstandet": "dazwischenstehen",
    "dazwischenstehe": "dazwischenstehen",
    "dazwischenstehend": "dazwischenstehen",
    "dazwischenstehende": "dazwischenstehend",
    "dazwischenstehendem": "dazwischenstehend",
    "dazwischenstehenden": "dazwischenstehend",
    "dazwischenstehender": "dazwischenstehend",
    "dazwischenstehendes": "dazwischenstehend",
    "dazwischenstehest": "dazwischenstehen",
    "dazwischenstehet": "dazwischenstehen",
    "dazwischenstehst": "dazwischenstehen",
    "dazwischensteht": "dazwischenstehen",
    "dazwischenstünde": "dazwischenstehen",
    "dazwischenstünden": "dazwischenstehen",
    "dazwischenstündest": "dazwischenstehen",
    "dazwischenstündet": "dazwischenstehen",
    "dazwischentrat": "dazwischentreten",
    "dazwischentraten": "dazwischentreten",
    "dazwischentratest": "dazwischentreten",
    "dazwischentratet": "dazwischentreten",
    "dazwischentrete": "dazwischentreten",
    "dazwischentretend": "dazwischentreten",
    "dazwischentretende": "dazwischentretend",
    "dazwischentretendem": "dazwischentretend",
    "dazwischentretenden": "dazwischentretend",
    "dazwischentretender": "dazwischentretend",
    "dazwischentretendes": "dazwischentretend",
    "dazwischentretest": "dazwischentreten",
    "dazwischentretet": "dazwischentreten",
    "dazwischentritt": "dazwischentreten",
    "dazwischentrittst": "dazwischentreten",
    "dazwischenträte": "dazwischentreten",
    "dazwischenträten": "dazwischentreten",
    "dazwischenträtest": "dazwischentreten",
    "dazwischenträtet": "dazwischentreten",
    "dazwischenzufahren": "dazwischenzufahre",
    "dazwischenzufunken": "dazwischenzufunke",
    "dazwischenzureden": "dazwischenreden",
    "dazwischenzurufen": "dazwischenrufen",
    "dazwischenzustehen": "dazwischenzustehe",
    "dazwischenzutreten": "dazwischenzutrete",
    "debattiere": "debattieren",
    "debattierend": "debattieren",
    "debattierende": "debattierend",
    "debattierendem": "debattierend",
    "debattierenden": "debattierend",
    "debattierender": "debattierend",
    "debattierendere": "debattierend",
    "debattierenderem": "debattierend",
    "debattierenderen": "debattierend",
    "debattierenderer": "debattierend",
    "debattierenderes": "debattierend",
    "debattierendes": "debattierend",
    "debattierendste": "debattierend",
    "debattierendstem": "debattierend",
    "debattierendsten": "debattierend",
    "debattierendster": "debattierend",
    "debattierendstes": "debattierend",
    "debattierest": "debattieren",
    "debattieret": "debattieren",
    "debattierst": "debattieren",
    "debattiert": "debattieren",
    "debattierte": "debattieren",
    "debattiertem": "debattiert",
    "debattierten": "debattieren",
    "debattierter": "debattiert",
    "debattiertere": "debattiert",
    "debattierterem": "debattiert",
    "debattierteren": "debattiert",
    "debattierterer": "debattiert",
    "debattierteres": "debattiert",
    "debattiertes": "debattiert",
    "debattiertest": "debattieren",
    "debattierteste": "debattiert",
    "debattiertestem": "debattiert",
    "debattiertesten": "debattiert",
    "debattiertester": "debattiert",
    "debattiertestes": "debattiert",
    "debattiertet": "debattieren",
    "debütiere": "debütieren",
    "debütierend": "debütieren",
    "debütierende": "debütierend",
    "debütierendem": "debütierend",
    "debütierenden": "debütierend",
    "debütierender": "debütierend",
    "debütierendere": "debütierend",
    "debütierenderem": "debütierend",
    "debütierenderen": "debütierend",
    "debütierenderer": "debütierend",
    "debütierenderes": "debütierend",
    "debütierendes": "debütierend",
    "debütierendste": "debütierend",
    "debütierendstem": "debütierend",
    "debütierendsten": "debütierend",
    "debütierendster": "debütierend",
    "debütierendstes": "debütierend",
    "debütierest": "debütieren",
    "debütieret": "debütieren",
    "debütierst": "debütieren",
    "debütiert": "debütieren",
    "debütierte": "debütieren",
    "debütiertem": "debütiert",
    "debütierten": "debütieren",
    "debütierter": "debütiert",
    "debütiertes": "debütiert",
    "debütiertest": "debütieren",
    "debütiertet": "debütieren",
    "deckend": "decken",
    "deckende": "deckend",
    "deckendem": "deckend",
    "deckenden": "deckend",
    "deckender": "deckend",
    "deckendes": "deckend",
    "deckest": "decken",
    "decket": "decken",
    "deckst": "decken",
    "deckt": "decken",
    "deckte": "decken",
    "deckten": "decken",
    "decktest": "decken",
    "decktet": "decken",
    "decodiere": "decodieren",
    "decodierend": "decodieren",
    "decodierende": "decodierend",
    "decodierendem": "decodierend",
    "decodierenden": "decodierend",
    "decodierender": "decodierend",
    "decodierendere": "decodierend",
    "decodierenderem": "decodierend",
    "decodierenderen": "decodierend",
    "decodierenderer": "decodierend",
    "decodierenderes": "decodierend",
    "decodierendes": "decodierend",
    "decodierendste": "decodierend",
    "decodierendstem": "decodierend",
    "decodierendsten": "decodierend",
    "decodierendster": "decodierend",
    "decodierendstes": "decodierend",
    "decodierest": "decodieren",
    "decodieret": "decodieren",
    "decodierst": "decodieren",
    "decodiert": "decodieren",
    "decodierte": "decodieren",
    "decodiertem": "decodiert",
    "decodierten": "decodieren",
    "decodierter": "decodiert",
    "decodiertere": "decodiert",
    "decodierterem": "decodiert",
    "decodierteren": "decodiert",
    "decodierterer": "decodiert",
    "decodierteres": "decodiert",
    "decodiertes": "decodiert",
    "decodiertest": "decodieren",
    "decodierteste": "decodiert",
    "decodiertestem": "decodiert",
    "decodiertesten": "decodiert",
    "decodiertester": "decodiert",
    "decodiertestes": "decodiert",
    "decodiertet": "decodieren",
    "deduktivem": "deduktiv",
    "deduktiven": "deduktiv",
    "deduktiver": "deduktiv",
    "deduktives": "deduktiv",
    "deduziere": "deduzieren",
    "deduzierend": "deduzieren",
    "deduzierende": "deduzierend",
    "deduzierendem": "deduzierend",
    "deduzierenden": "deduzierend",
    "deduzierender": "deduzierend",
    "deduzierendere": "deduzierend",
    "deduzierenderem": "deduzierend",
    "deduzierenderen": "deduzierend",
    "deduzierenderer": "deduzierend",
    "deduzierenderes": "deduzierend",
    "deduzierendes": "deduzierend",
    "deduzierendste": "deduzierend",
    "deduzierendstem": "deduzierend",
    "deduzierendsten": "deduzierend",
    "deduzierendster": "deduzierend",
    "deduzierendstes": "deduzierend",
    "deduzierest": "deduzieren",
    "deduzieret": "deduzieren",
    "deduzierst": "deduzieren",
    "deduziert": "deduzieren",
    "deduzierte": "deduzieren",
    "deduziertem": "deduziert",
    "deduzierten": "deduzieren",
    "deduzierter": "deduziert",
    "deduziertes": "deduziert",
    "deduziertest": "deduzieren",
    "deduziertet": "deduzieren",
    "deeskaliere": "deeskalieren",
    "deeskalierend": "deeskalieren",
    "deeskalierende": "deeskalierend",
    "deeskalierendem": "deeskalierend",
    "deeskalierenden": "deeskalierend",
    "deeskalierender": "deeskalierend",
    "deeskalierendere": "deeskalierend",
    "deeskalierenderem": "deeskalierend",
    "deeskalierenderen": "deeskalierend",
    "deeskalierenderer": "deeskalierend",
    "deeskalierenderes": "deeskalierend",
    "deeskalierendes": "deeskalierend",
    "deeskalierendste": "deeskalierend",
    "deeskalierendstem": "deeskalierend",
    "deeskalierendsten": "deeskalierend",
    "deeskalierendster": "deeskalierend",
    "deeskalierendstes": "deeskalierend",
    "deeskalierest": "deeskalieren",
    "deeskalieret": "deeskalieren",
    "deeskalierst": "deeskalieren",
    "deeskaliert": "deeskalieren",
    "deeskalierte": "deeskalieren",
    "deeskaliertem": "deeskaliert",
    "deeskalierten": "deeskalieren",
    "deeskalierter": "deeskaliert",
    "deeskaliertere": "deeskaliert",
    "deeskalierterem": "deeskaliert",
    "deeskalierteren": "deeskaliert",
    "deeskalierterer": "deeskaliert",
    "deeskalierteres": "deeskaliert",
    "deeskaliertes": "deeskaliert",
    "deeskaliertest": "deeskalieren",
    "deeskalierteste": "deeskaliert",
    "deeskaliertestem": "deeskaliert",
    "deeskaliertesten": "deeskaliert",
    "deeskaliertester": "deeskaliert",
    "deeskaliertestes": "deeskaliert",
    "deeskaliertet": "deeskalieren",
    "defekte": "defekt",
    "defektem": "defekt",
    "defekten": "defekt",
    "defekter": "defekt",
    "defektere": "defekt",
    "defekterem": "defekt",
    "defekteren": "defekt",
    "defekterer": "defekt",
    "defekteres": "defekt",
    "defektes": "defekt",
    "defektestem": "defekt",
    "defektesten": "defekt",
    "defektester": "defekt",
    "defektestes": "defekt",
    "defensivem": "defensiv",
    "defensiven": "defensiv",
    "defensiver": "defensiv",
    "defensivere": "defensiv",
    "defensiverem": "defensiv",
    "defensiveren": "defensiv",
    "defensiverer": "defensiv",
    "defensiveres": "defensiv",
    "defensives": "defensiv",
    "defensivste": "defensiv",
    "defensivstem": "defensiv",
    "defensivsten": "defensiv",
    "defensivster": "defensiv",
    "defensivstes": "defensiv",
    "definiere": "definieren",
    "definierend": "definieren",
    "definierende": "definierend",
    "definierendem": "definierend",
    "definierenden": "definierend",
    "definierender": "definierend",
    "definierendes": "definierend",
    "definierest": "definieren",
    "definieret": "definieren",
    "definierst": "definieren",
    "definiert": "definieren",
    "definierte": "definieren",
    "definiertem": "definiert",
    "definierten": "definieren",
    "definierter": "definiert",
    "definiertes": "definiert",
    "definiertest": "definieren",
    "definiertet": "definieren",
    "definite": "definit",
    "definitem": "definit",
    "definiten": "definit",
    "definiter": "definit",
    "definites": "definit",
    "definitivem": "definitiv",
    "definitiven": "definitiv",
    "definitiver": "definitiv",
    "definitivere": "definitiv",
    "definitiverem": "definitiv",
    "definitiveren": "definitiv",
    "definitiverer": "definitiv",
    "definitiveres": "definitiv",
    "definitives": "definitiv",
    "definitivste": "definitiv",
    "definitivstem": "definitiv",
    "definitivsten": "definitiv",
    "definitivster": "definitiv",
    "definitivstes": "definitiv",
    "definitorische": "definitorisch",
    "definitorischem": "definitorisch",
    "definitorischen": "definitorisch",
    "definitorischer": "definitorisch",
    "definitorischere": "definitorisch",
    "definitorischerem": "definitorisch",
    "definitorischeren": "definitorisch",
    "definitorischerer": "definitorisch",
    "definitorischeres": "definitorisch",
    "definitorisches": "definitorisch",
    "definitorischste": "definitorisch",
    "definitorischstem": "definitorisch",
    "definitorischsten": "definitorisch",
    "definitorischster": "definitorisch",
    "definitorischstes": "definitorisch",
    "defizitäre": "defizitär",
    "defizitärem": "defizitär",
    "defizitären": "defizitär",
    "defizitärer": "defizitär",
    "defizitärere": "defizitär",
    "defizitärerem": "defizitär",
    "defizitäreren": "defizitär",
    "defizitärerer": "defizitär",
    "defizitäreres": "defizitär",
    "defizitäres": "defizitär",
    "defizitärste": "defizitär",
    "defizitärstem": "defizitär",
    "defizitärsten": "defizitär",
    "defizitärster": "defizitär",
    "defizitärstes": "defizitär",
    "deflationärem": "deflationär",
    "deflationären": "deflationär",
    "deflationärer": "deflationär",
    "deflationärere": "deflationär",
    "deflationärerem": "deflationär",
    "deflationäreren": "deflationär",
    "deflationärerer": "deflationär",
    "deflationäreres": "deflationär",
    "deflationäres": "deflationär",
    "deflationärste": "deflationär",
    "deflationärstem": "deflationär",
    "deflationärsten": "deflationär",
    "deflationärster": "deflationär",
    "deflationärstes": "deflationär",
    "deformiere": "deformieren",
    "deformierend": "deformieren",
    "deformierende": "deformierend",
    "deformierendem": "deformierend",
    "deformierenden": "deformierend",
    "deformierender": "deformierend",
    "deformierendere": "deformierend",
    "deformierenderem": "deformierend",
    "deformierenderen": "deformierend",
    "deformierenderer": "deformierend",
    "deformierenderes": "deformierend",
    "deformierendes": "deformierend",
    "deformierendste": "deformierend",
    "deformierendstem": "deformierend",
    "deformierendsten": "deformierend",
    "deformierendster": "deformierend",
    "deformierendstes": "deformierend",
    "deformierest": "deformieren",
    "deformieret": "deformieren",
    "deformierst": "deformieren",
    "deformiert": "deformieren",
    "deformierte": "deformieren",
    "deformiertem": "deformiert",
    "deformierten": "deformieren",
    "deformierter": "deformiert",
    "deformiertere": "deformiert",
    "deformierterem": "deformiert",
    "deformierteren": "deformiert",
    "deformierterer": "deformiert",
    "deformierteres": "deformiert",
    "deformiertes": "deformiert",
    "deformiertest": "deformieren",
    "deformierteste": "deformiert",
    "deformiertestem": "deformiert",
    "deformiertesten": "deformiert",
    "deformiertester": "deformiert",
    "deformiertestes": "deformiert",
    "deformiertet": "deformieren",
    "deftigem": "deftig",
    "deftigen": "deftig",
    "deftiger": "deftig",
    "deftigere": "deftig",
    "deftigerem": "deftig",
    "deftigeren": "deftig",
    "deftigerer": "deftig",
    "deftigeres": "deftig",
    "deftiges": "deftig",
    "deftigste": "deftig",
    "deftigstem": "deftig",
    "deftigsten": "deftig",
    "deftigster": "deftig",
    "deftigstes": "deftig",
    "degradiere": "degradieren",
    "degradierend": "degradieren",
    "degradierende": "degradierend",
    "degradierendem": "degradierend",
    "degradierenden": "degradierend",
    "degradierender": "degradierend",
    "degradierendes": "degradierend",
    "degradierest": "degradieren",
    "degradieret": "degradieren",
    "degradierst": "degradieren",
    "degradiert": "degradieren",
    "degradierte": "degradieren",
    "degradiertem": "degradiert",
    "degradierten": "degradieren",
    "degradierter": "degradiert",
    "degradiertes": "degradiert",
    "degradiertest": "degradieren",
    "degradiertet": "degradieren",
    "degressivem": "degressiv",
    "degressiven": "degressiv",
    "degressiver": "degressiv",
    "degressives": "degressiv",
    "dehnbare": "dehnbar",
    "dehnbarem": "dehnbar",
    "dehnbaren": "dehnbar",
    "dehnbarer": "dehnbar",
    "dehnbares": "dehnbar",
    "dehne": "dehnen",
    "dehnend": "dehnen",
    "dehnende": "dehnend",
    "dehnendem": "dehnend",
    "dehnenden": "dehnend",
    "dehnender": "dehnend",
    "dehnendere": "dehnend",
    "dehnenderem": "dehnend",
    "dehnenderen": "dehnend",
    "dehnenderer": "dehnend",
    "dehnenderes": "dehnend",
    "dehnendes": "dehnend",
    "dehnendste": "dehnend",
    "dehnendstem": "dehnend",
    "dehnendsten": "dehnend",
    "dehnendster": "dehnend",
    "dehnendstes": "dehnend",
    "dehnest": "dehnen",
    "dehnet": "dehnen",
    "dehnst": "dehnen",
    "dehnt": "dehnen",
    "dehnte": "dehnen",
    "dehnten": "dehnen",
    "dehntest": "dehnen",
    "dehntet": "dehnen",
    "deichend": "deichen",
    "deichende": "deichend",
    "deichendem": "deichend",
    "deichenden": "deichend",
    "deichender": "deichend",
    "deichendes": "deichend",
    "deichest": "deichen",
    "deichet": "deichen",
    "deichsele": "deichseln",
    "deichselnd": "deichseln",
    "deichselnde": "deichselnd",
    "deichselndem": "deichselnd",
    "deichselnden": "deichselnd",
    "deichselnder": "deichselnd",
    "deichselndes": "deichselnd",
    "deichselst": "deichseln",
    "deichselt": "deichseln",
    "deichselte": "deichseln",
    "deichselten": "deichseln",
    "deichseltest": "deichseln",
    "deichseltet": "deichseln",
    "deichsle": "deichseln",
    "deichst": "deichen",
    "deicht": "deichen",
    "deichte": "deichen",
    "deichten": "deichen",
    "deichtest": "deichen",
    "deichtet": "deichen",
    "dein": "mein",
    "deine": "mein",
    "deinem": "mein",
    "deinen": "mein",
    "deiner": "sich",
    "deines": "mein",
    "deinesgleichen": "meinesgleichen",
    "dejustiere": "dejustieren",
    "dejustierend": "dejustieren",
    "dejustierende": "dejustierend",
    "dejustierendem": "dejustierend",
    "dejustierenden": "dejustierend",
    "dejustierender": "dejustierend",
    "dejustierendes": "dejustierend",
    "dejustierest": "dejustieren",
    "dejustieret": "dejustieren",
    "dejustierst": "dejustieren",
    "dejustiert": "dejustieren",
    "dejustierte": "dejustieren",
    "dejustiertem": "dejustiert",
    "dejustierten": "dejustieren",
    "dejustierter": "dejustiert",
    "dejustiertere": "dejustiert",
    "dejustierterem": "dejustiert",
    "dejustierteren": "dejustiert",
    "dejustierterer": "dejustiert",
    "dejustierteres": "dejustiert",
    "dejustiertes": "dejustiert",
    "dejustiertest": "dejustieren",
    "dejustierteste": "dejustiert",
    "dejustiertestem": "dejustiert",
    "dejustiertesten": "dejustiert",
    "dejustiertester": "dejustiert",
    "dejustiertestes": "dejustiert",
    "dejustiertet": "dejustieren",
    "dekadentem": "dekadent",
    "dekadenten": "dekadent",
    "dekadenter": "dekadent",
    "dekadentere": "dekadent",
    "dekadenterem": "dekadent",
    "dekadenteren": "dekadent",
    "dekadenterer": "dekadent",
    "dekadenteres": "dekadent",
    "dekadentes": "dekadent",
    "dekadenteste": "dekadent",
    "dekadentestem": "dekadent",
    "dekadentesten": "dekadent",
    "dekadentester": "dekadent",
    "dekadentestes": "dekadent",
    "dekadischem": "dekadisch",
    "dekadischen": "dekadisch",
    "dekadischer": "dekadisch",
    "dekadisches": "dekadisch",
    "dekartelliere": "dekartellieren",
    "dekartellierend": "dekartellieren",
    "dekartellierende": "dekartellierend",
    "dekartellierendem": "dekartellierend",
    "dekartellierenden": "dekartellierend",
    "dekartellierender": "dekartellierend",
    "dekartellierendere": "dekartellierend",
    "dekartellierenderem": "dekartellierend",
    "dekartellierenderen": "dekartellierend",
    "dekartellierenderer": "dekartellierend",
    "dekartellierenderes": "dekartellierend",
    "dekartellierendes": "dekartellierend",
    "dekartellierendste": "dekartellierend",
    "dekartellierendstem": "dekartellierend",
    "dekartellierendsten": "dekartellierend",
    "dekartellierendster": "dekartellierend",
    "dekartellierendstes": "dekartellierend",
    "dekartellierest": "dekartellieren",
    "dekartellieret": "dekartellieren",
    "dekartellierst": "dekartellieren",
    "dekartelliert": "dekartellieren",
    "dekartellierte": "dekartellieren",
    "dekartelliertem": "dekartelliert",
    "dekartellierten": "dekartellieren",
    "dekartellierter": "dekartelliert",
    "dekartelliertere": "dekartelliert",
    "dekartellierterem": "dekartelliert",
    "dekartellierteren": "dekartelliert",
    "dekartellierterer": "dekartelliert",
    "dekartellierteres": "dekartelliert",
    "dekartelliertes": "dekartelliert",
    "dekartelliertest": "dekartellieren",
    "dekartelliertestem": "dekartelliert",
    "dekartelliertesten": "dekartelliert",
    "dekartelliertester": "dekartelliert",
    "dekartelliertestes": "dekartelliert",
    "dekartelliertet": "dekartellieren",
    "deklariere": "deklarieren",
    "deklarierend": "deklarieren",
    "deklarierende": "deklarierend",
    "deklarierendem": "deklarierend",
    "deklarierenden": "deklarierend",
    "deklarierender": "deklarierend",
    "deklarierendes": "deklarierend",
    "deklarierest": "deklarieren",
    "deklarieret": "deklarieren",
    "deklarierst": "deklarieren",
    "deklariert": "deklarieren",
    "deklarierte": "deklarieren",
    "deklariertem": "deklariert",
    "deklarierten": "deklarieren",
    "deklarierter": "deklariert",
    "deklariertes": "deklariert",
    "deklariertest": "deklarieren",
    "deklariertet": "deklarieren",
    "deklassiere": "deklassieren",
    "deklassierend": "deklassieren",
    "deklassierende": "deklassierend",
    "deklassierendem": "deklassierend",
    "deklassierenden": "deklassierend",
    "deklassierender": "deklassierend",
    "deklassierendere": "deklassierend",
    "deklassierenderem": "deklassierend",
    "deklassierenderen": "deklassierend",
    "deklassierenderer": "deklassierend",
    "deklassierenderes": "deklassierend",
    "deklassierendes": "deklassierend",
    "deklassierendste": "deklassierend",
    "deklassierendstem": "deklassierend",
    "deklassierendsten": "deklassierend",
    "deklassierendster": "deklassierend",
    "deklassierendstes": "deklassierend",
    "deklassierest": "deklassieren",
    "deklassieret": "deklassieren",
    "deklassierst": "deklassieren",
    "deklassiert": "deklassieren",
    "deklassierte": "deklassieren",
    "deklassiertem": "deklassiert",
    "deklassierten": "deklassieren",
    "deklassierter": "deklassiert",
    "deklassiertere": "deklassiert",
    "deklassierterem": "deklassiert",
    "deklassierteren": "deklassiert",
    "deklassierterer": "deklassiert",
    "deklassierteres": "deklassiert",
    "deklassiertes": "deklassiert",
    "deklassiertest": "deklassieren",
    "deklassierteste": "deklassiert",
    "deklassiertestem": "deklassiert",
    "deklassiertesten": "deklassiert",
    "deklassiertester": "deklassiert",
    "deklassiertestes": "deklassiert",
    "deklassiertet": "deklassieren",
    "deklinabelstem": "deklinabel",
    "deklinabelsten": "deklinabel",
    "deklinabelster": "deklinabel",
    "deklinabelstes": "deklinabel",
    "deklinable": "deklinabel",
    "deklinablem": "deklinabel",
    "deklinablen": "deklinabel",
    "deklinabler": "deklinabel",
    "deklinablere": "deklinabel",
    "deklinablerem": "deklinabel",
    "deklinableren": "deklinabel",
    "deklinablerer": "deklinabel",
    "deklinableres": "deklinabel",
    "deklinables": "deklinabel",
    "dekliniere": "deklinieren",
    "deklinierend": "deklinieren",
    "deklinierende": "deklinierend",
    "deklinierendem": "deklinierend",
    "deklinierenden": "deklinierend",
    "deklinierender": "deklinierend",
    "deklinierendes": "deklinierend",
    "deklinierest": "deklinieren",
    "deklinieret": "deklinieren",
    "deklinierst": "deklinieren",
    "dekliniert": "deklinieren",
    "deklinierte": "deklinieren",
    "dekliniertem": "dekliniert",
    "deklinierten": "deklinieren",
    "deklinierter": "dekliniert",
    "dekliniertes": "dekliniert",
    "dekliniertest": "deklinieren",
    "dekliniertet": "deklinieren",
    "dekorativem": "dekorativ",
    "dekorativen": "dekorativ",
    "dekorativer": "dekorativ",
    "dekorativere": "dekorativ",
    "dekorativerem": "dekorativ",
    "dekorativeren": "dekorativ",
    "dekorativerer": "dekorativ",
    "dekorativeres": "dekorativ",
    "dekoratives": "dekorativ",
    "dekorativste": "dekorativ",
    "dekorativstem": "dekorativ",
    "dekorativsten": "dekorativ",
    "dekorativster": "dekorativ",
    "dekorativstes": "dekorativ",
    "dekoriere": "dekorieren",
    "dekorierend": "dekorieren",
    "dekorierende": "dekorierend",
    "dekorierendem": "dekorierend",
    "dekorierenden": "dekorierend",
    "dekorierender": "dekorierend",
    "dekorierendes": "dekorierend",
    "dekorierest": "dekorieren",
    "dekorieret": "dekorieren",
    "dekorierst": "dekorieren",
    "dekoriert": "dekorieren",
    "dekorierte": "dekorieren",
    "dekoriertem": "dekoriert",
    "dekorierten": "dekorieren",
    "dekorierter": "dekoriert",
    "dekoriertere": "dekoriert",
    "dekorierterem": "dekoriert",
    "dekorierteren": "dekoriert",
    "dekorierterer": "dekoriert",
    "dekorierteres": "dekoriert",
    "dekoriertes": "dekoriert",
    "dekoriertest": "dekorieren",
    "dekorierteste": "dekoriert",
    "dekoriertestem": "dekoriert",
    "dekoriertesten": "dekoriert",
    "dekoriertester": "dekoriert",
    "dekoriertestes": "dekoriert",
    "dekoriertet": "dekorieren",
    "dekreditierend": "dekreditieren",
    "dekreditierende": "dekreditierend",
    "dekreditierendem": "dekreditierend",
    "dekreditierenden": "dekreditierend",
    "dekreditierender": "dekreditierend",
    "dekreditierendere": "dekreditierend",
    "dekreditierenderem": "dekreditierend",
    "dekreditierenderen": "dekreditierend",
    "dekreditierenderer": "dekreditierend",
    "dekreditierenderes": "dekreditierend",
    "dekreditierendes": "dekreditierend",
    "dekreditierendste": "dekreditierend",
    "dekreditierendstem": "dekreditierend",
    "dekreditierendsten": "dekreditierend",
    "dekreditierendster": "dekreditierend",
    "dekreditierendstes": "dekreditierend",
    "dekreditierest": "dekreditieren",
    "dekreditieret": "dekreditieren",
    "dekreditierst": "dekreditieren",
    "dekreditiert": "dekreditieren",
    "dekreditierte": "dekreditieren",
    "dekreditiertem": "dekreditiert",
    "dekreditierten": "dekreditieren",
    "dekreditierter": "dekreditiert",
    "dekreditiertere": "dekreditiert",
    "dekreditierterem": "dekreditiert",
    "dekreditierteren": "dekreditiert",
    "dekreditierterer": "dekreditiert",
    "dekreditierteres": "dekreditiert",
    "dekreditiertes": "dekreditiert",
    "dekreditiertest": "dekreditieren",
    "dekreditierteste": "dekreditiert",
    "dekreditiertestem": "dekreditiert",
    "dekreditiertesten": "dekreditiert",
    "dekreditiertester": "dekreditiert",
    "dekreditiertestes": "dekreditiert",
    "dekreditiertet": "dekreditieren",
    "dekrementiere": "dekrementieren",
    "dekrementierend": "dekrementieren",
    "dekrementierende": "dekrementierend",
    "dekrementierendem": "dekrementierend",
    "dekrementierenden": "dekrementierend",
    "dekrementierender": "dekrementierend",
    "dekrementierendes": "dekrementierend",
    "dekrementierest": "dekrementieren",
    "dekrementieret": "dekrementieren",
    "dekrementierst": "dekrementieren",
    "dekrementiert": "dekrementieren",
    "dekrementierte": "dekrementieren",
    "dekrementiertem": "dekrementiert",
    "dekrementierten": "dekrementieren",
    "dekrementierter": "dekrementiert",
    "dekrementiertes": "dekrementiert",
    "dekrementiertest": "dekrementieren",
    "dekrementiertet": "dekrementieren",
    "delegiere": "delegieren",
    "delegierend": "delegieren",
    "delegierende": "delegierend",
    "delegierendem": "delegierend",
    "delegierenden": "delegierend",
    "delegierender": "delegierend",
    "delegierendes": "delegierend",
    "delegierest": "delegieren",
    "delegieret": "delegieren",
    "delegierst": "delegieren",
    "delegiert": "delegieren",
    "delegierte": "delegieren",
    "delegiertem": "delegiert",
    "delegierten": "delegieren",
    "delegierter": "delegiert",
    "delegiertes": "delegiert",
    "delegiertest": "delegieren",
    "delegiertet": "delegieren",
    "delernende": "delernend",
    "delernendem": "delernend",
    "delernenden": "delernend",
    "delernender": "delernend",
    "delernendes": "delernend",
    "delernte": "delernt",
    "delerntem": "delernt",
    "delernten": "delernt",
    "delernter": "delernt",
    "delerntes": "delernt",
    "delikatem": "delikat",
    "delikaten": "delikat",
    "delikater": "delikat",
    "delikatere": "delikat",
    "delikaterem": "delikat",
    "delikateren": "delikat",
    "delikaterer": "delikat",
    "delikateres": "delikat",
    "delikates": "delikat",
    "delikatestem": "delikat",
    "delikatesten": "delikat",
    "delikatester": "delikat",
    "delikatestes": "delikat",
    "delinquentem": "delinquent",
    "delinquenten": "delinquent",
    "delinquenter": "delinquent",
    "delinquentes": "delinquent",
    "delle": "dellen",
    "dellend": "dellen",
    "dellende": "dellend",
    "dellendem": "dellend",
    "dellenden": "dellend",
    "dellender": "dellend",
    "dellendes": "dellend",
    "dellest": "dellen",
    "dellet": "dellen",
    "dellst": "dellen",
    "dellt": "dellen",
    "dellte": "dellen",
    "dellten": "dellen",
    "delltest": "dellen",
    "delltet": "dellen",
    "dem": "der",
    "demaskiere": "demaskieren",
    "demaskierend": "demaskieren",
    "demaskierende": "demaskierend",
    "demaskierendem": "demaskierend",
    "demaskierenden": "demaskierend",
    "demaskierender": "demaskierend",
    "demaskierendes": "demaskierend",
    "demaskierest": "demaskieren",
    "demaskieret": "demaskieren",
    "demaskierst": "demaskieren",
    "demaskiert": "demaskieren",
    "demaskierte": "demaskieren",
    "demaskiertem": "demaskiert",
    "demaskierten": "demaskieren",
    "demaskierter": "demaskiert",
    "demaskiertes": "demaskiert",
    "demaskiertest": "demaskieren",
    "demaskiertet": "demaskieren",
    "demathematisiere": "demathematisieren",
    "demathematisierend": "demathematisieren",
    "demathematisierende": "demathematisierend",
    "demathematisierendem": "demathematisierend",
    "demathematisierenden": "demathematisierend",
    "demathematisierender": "demathematisierend",
    "demathematisierendes": "demathematisierend",
    "demathematisierest": "demathematisieren",
    "demathematisieret": "demathematisieren",
    "demathematisierst": "demathematisieren",
    "demathematisiert": "demathematisieren",
    "demathematisierte": "demathematisieren",
    "demathematisiertem": "demathematisiert",
    "demathematisierten": "demathematisieren",
    "demathematisierter": "demathematisiert",
    "demathematisiertes": "demathematisiert",
    "demathematisiertest": "demathematisieren",
    "demathematisiertet": "demathematisieren",
    "dementiere": "dementieren",
    "dementierend": "dementieren",
    "dementierende": "dementierend",
    "dementierendem": "dementierend",
    "dementierenden": "dementierend",
    "dementierender": "dementierend",
    "dementierendere": "dementierend",
    "dementierenderem": "dementierend",
    "dementierenderen": "dementierend",
    "dementierenderer": "dementierend",
    "dementierenderes": "dementierend",
    "dementierendes": "dementierend",
    "dementierendste": "dementierend",
    "dementierendstem": "dementierend",
    "dementierendsten": "dementierend",
    "dementierendster": "dementierend",
    "dementierendstes": "dementierend",
    "dementierest": "dementieren",
    "dementieret": "dementieren",
    "dementierst": "dementieren",
    "dementiert": "dementieren",
    "dementierte": "dementieren",
    "dementiertem": "dementiert",
    "dementierten": "dementieren",
    "dementierter": "dementiert",
    "dementiertere": "dementiert",
    "dementierterem": "dementiert",
    "dementierteren": "dementiert",
    "dementierterer": "dementiert",
    "dementierteres": "dementiert",
    "dementiertes": "dementiert",
    "dementiertest": "dementieren",
    "dementierteste": "dementiert",
    "dementiertestem": "dementiert",
    "dementiertesten": "dementiert",
    "dementiertester": "dementiert",
    "dementiertestes": "dementiert",
    "dementiertet": "dementieren",
    "dementsprechendem": "dementsprechend",
    "dementsprechenden": "dementsprechend",
    "dementsprechender": "dementsprechend",
    "dementsprechendes": "dementsprechend",
    "demilitarisiere": "demilitarisieren",
    "demilitarisierend": "demilitarisieren",
    "demilitarisierende": "demilitarisierend",
    "demilitarisierendem": "demilitarisierend",
    "demilitarisierenden": "demilitarisierend",
    "demilitarisierender": "demilitarisierend",
    "demilitarisierendere": "demilitarisierend",
    "demilitarisierenderem": "demilitarisierend",
    "demilitarisierenderen": "demilitarisierend",
    "demilitarisierenderer": "demilitarisierend",
    "demilitarisierenderes": "demilitarisierend",
    "demilitarisierendes": "demilitarisierend",
    "demilitarisierendste": "demilitarisierend",
    "demilitarisierendstem": "demilitarisierend",
    "demilitarisierendsten": "demilitarisierend",
    "demilitarisierendster": "demilitarisierend",
    "demilitarisierendstes": "demilitarisierend",
    "demilitarisierest": "demilitarisieren",
    "demilitarisieret": "demilitarisieren",
    "demilitarisierst": "demilitarisieren",
    "demilitarisiert": "demilitarisieren",
    "demilitarisierte": "demilitarisieren",
    "demilitarisiertem": "demilitarisiert",
    "demilitarisierten": "demilitarisieren",
    "demilitarisierter": "demilitarisiert",
    "demilitarisiertere": "demilitarisiert",
    "demilitarisierterem": "demilitarisiert",
    "demilitarisierteren": "demilitarisiert",
    "demilitarisierterer": "demilitarisiert",
    "demilitarisierteres": "demilitarisiert",
    "demilitarisiertes": "demilitarisiert",
    "demilitarisiertest": "demilitarisieren",
    "demilitarisierteste": "demilitarisiert",
    "demilitarisiertestem": "demilitarisiert",
    "demilitarisiertesten": "demilitarisiert",
    "demilitarisiertester": "demilitarisiert",
    "demilitarisiertestes": "demilitarisiert",
    "demilitarisiertet": "demilitarisieren",
    "deminutive": "deminutiv",
    "deminutivem": "deminutiv",
    "deminutiven": "deminutiv",
    "deminutiver": "deminutiv",
    "deminutives": "deminutiv",
    "demissioniere": "demissionieren",
    "demissionierend": "demissionieren",
    "demissionierende": "demissionierend",
    "demissionierendem": "demissionierend",
    "demissionierenden": "demissionierend",
    "demissionierender": "demissionierend",
    "demissionierendere": "demissionierend",
    "demissionierenderem": "demissionierend",
    "demissionierenderen": "demissionierend",
    "demissionierenderer": "demissionierend",
    "demissionierenderes": "demissionierend",
    "demissionierendes": "demissionierend",
    "demissionierendste": "demissionierend",
    "demissionierendstem": "demissionierend",
    "demissionierendsten": "demissionierend",
    "demissionierendster": "demissionierend",
    "demissionierendstes": "demissionierend",
    "demissionierest": "demissionieren",
    "demissionieret": "demissionieren",
    "demissionierst": "demissionieren",
    "demissioniert": "demissionieren",
    "demissionierte": "demissionieren",
    "demissioniertem": "demissioniert",
    "demissionierten": "demissionieren",
    "demissionierter": "demissioniert",
    "demissioniertere": "demissioniert",
    "demissionierterem": "demissioniert",
    "demissionierteren": "demissioniert",
    "demissionierterer": "demissioniert",
    "demissionierteres": "demissioniert",
    "demissioniertes": "demissioniert",
    "demissioniertest": "demissionieren",
    "demissioniertestem": "demissioniert",
    "demissioniertesten": "demissioniert",
    "demissioniertester": "demissioniert",
    "demissioniertestes": "demissioniert",
    "demissioniertet": "demissionieren",
    "demjenigen": "derjenige",
    "demoduliere": "demodulieren",
    "demodulierend": "demodulieren",
    "demodulierende": "demodulierend",
    "demodulierendem": "demodulierend",
    "demodulierenden": "demodulierend",
    "demodulierender": "demodulierend",
    "demodulierendes": "demodulierend",
    "demodulierest": "demodulieren",
    "demodulieret": "demodulieren",
    "demodulierst": "demodulieren",
    "demoduliert": "demodulieren",
    "demodulierte": "demodulieren",
    "demoduliertem": "demoduliert",
    "demodulierten": "demodulieren",
    "demodulierter": "demoduliert",
    "demoduliertes": "demoduliert",
    "demoduliertest": "demodulieren",
    "demoduliertet": "demodulieren",
    "demographischem": "demographisch",
    "demographischen": "demographisch",
    "demographischer": "demographisch",
    "demographisches": "demographisch",
    "demokratischem": "demokratisch",
    "demokratischen": "demokratisch",
    "demokratischer": "demokratisch",
    "demokratischere": "demokratisch",
    "demokratischerem": "demokratisch",
    "demokratischeren": "demokratisch",
    "demokratischerer": "demokratisch",
    "demokratischeres": "demokratisch",
    "demokratisches": "demokratisch",
    "demokratischste": "demokratisch",
    "demokratischstem": "demokratisch",
    "demokratischsten": "demokratisch",
    "demokratischster": "demokratisch",
    "demokratischstes": "demokratisch",
    "demokratisiere": "demokratisieren",
    "demokratisierend": "demokratisieren",
    "demokratisierende": "demokratisierend",
    "demokratisierendem": "demokratisierend",
    "demokratisierenden": "demokratisierend",
    "demokratisierender": "demokratisierend",
    "demokratisierendes": "demokratisierend",
    "demokratisierest": "demokratisieren",
    "demokratisieret": "demokratisieren",
    "demokratisierst": "demokratisieren",
    "demokratisiert": "demokratisieren",
    "demokratisierte": "demokratisieren",
    "demokratisiertem": "demokratisiert",
    "demokratisierten": "demokratisieren",
    "demokratisierter": "demokratisiert",
    "demokratisiertere": "demokratisiert",
    "demokratisierterem": "demokratisiert",
    "demokratisierteren": "demokratisiert",
    "demokratisierterer": "demokratisiert",
    "demokratisierteres": "demokratisiert",
    "demokratisiertes": "demokratisiert",
    "demokratisiertest": "demokratisieren",
    "demokratisierteste": "demokratisiert",
    "demokratisiertestem": "demokratisiert",
    "demokratisiertesten": "demokratisiert",
    "demokratisiertester": "demokratisiert",
    "demokratisiertestes": "demokratisiert",
    "demokratisiertet": "demokratisieren",
    "demoliere": "demolieren",
    "demolierend": "demolieren",
    "demolierende": "demolierend",
    "demolierendem": "demolierend",
    "demolierenden": "demolierend",
    "demolierender": "demolierend",
    "demolierendere": "demolierend",
    "demolierenderem": "demolierend",
    "demolierenderen": "demolierend",
    "demolierenderer": "demolierend",
    "demolierenderes": "demolierend",
    "demolierendes": "demolierend",
    "demolierendste": "demolierend",
    "demolierendstem": "demolierend",
    "demolierendsten": "demolierend",
    "demolierendster": "demolierend",
    "demolierendstes": "demolierend",
    "demolierest": "demolieren",
    "demolieret": "demolieren",
    "demolierst": "demolieren",
    "demoliert": "demolieren",
    "demolierte": "demolieren",
    "demoliertem": "demoliert",
    "demolierten": "demolieren",
    "demolierter": "demoliert",
    "demoliertere": "demoliert",
    "demolierterem": "demoliert",
    "demolierteren": "demoliert",
    "demolierterer": "demoliert",
    "demolierteres": "demoliert",
    "demoliertes": "demoliert",
    "demoliertest": "demolieren",
    "demolierteste": "demoliert",
    "demoliertestem": "demoliert",
    "demoliertesten": "demoliert",
    "demoliertester": "demoliert",
    "demoliertestes": "demoliert",
    "demoliertet": "demolieren",
    "demonstrativem": "demonstrativ",
    "demonstrativen": "demonstrativ",
    "demonstrativer": "demonstrativ",
    "demonstrativere": "demonstrativ",
    "demonstrativerem": "demonstrativ",
    "demonstrativeren": "demonstrativ",
    "demonstrativerer": "demonstrativ",
    "demonstrativeres": "demonstrativ",
    "demonstratives": "demonstrativ",
    "demonstrativste": "demonstrativ",
    "demonstrativstem": "demonstrativ",
    "demonstrativsten": "demonstrativ",
    "demonstrativster": "demonstrativ",
    "demonstrativstes": "demonstrativ",
    "demonstriere": "demonstrieren",
    "demonstrierend": "demonstrieren",
    "demonstrierende": "demonstrierend",
    "demonstrierendem": "demonstrierend",
    "demonstrierenden": "demonstrierend",
    "demonstrierender": "demonstrierend",
    "demonstrierendere": "demonstrierend",
    "demonstrierenderem": "demonstrierend",
    "demonstrierenderen": "demonstrierend",
    "demonstrierenderer": "demonstrierend",
    "demonstrierenderes": "demonstrierend",
    "demonstrierendes": "demonstrierend",
    "demonstrierendste": "demonstrierend",
    "demonstrierendstem": "demonstrierend",
    "demonstrierendsten": "demonstrierend",
    "demonstrierendster": "demonstrierend",
    "demonstrierendstes": "demonstrierend",
    "demonstrierest": "demonstrieren",
    "demonstrieret": "demonstrieren",
    "demonstrierst": "demonstrieren",
    "demonstriert": "demonstrieren",
    "demonstrierte": "demonstrieren",
    "demonstriertem": "demonstriert",
    "demonstrierten": "demonstrieren",
    "demonstrierter": "demonstriert",
    "demonstriertes": "demonstriert",
    "demonstriertest": "demonstrieren",
    "demonstriertet": "demonstrieren",
    "demontiere": "demontieren",
    "demontierend": "demontieren",
    "demontierende": "demontierend",
    "demontierendem": "demontierend",
    "demontierenden": "demontierend",
    "demontierender": "demontierend",
    "demontierendere": "demontierend",
    "demontierenderem": "demontierend",
    "demontierenderen": "demontierend",
    "demontierenderer": "demontierend",
    "demontierenderes": "demontierend",
    "demontierendes": "demontierend",
    "demontierendste": "demontierend",
    "demontierendstem": "demontierend",
    "demontierendsten": "demontierend",
    "demontierendster": "demontierend",
    "demontierendstes": "demontierend",
    "demontierest": "demontieren",
    "demontieret": "demontieren",
    "demontierst": "demontieren",
    "demontiert": "demontieren",
    "demontierte": "demontieren",
    "demontiertem": "demontiert",
    "demontierten": "demontieren",
    "demontierter": "demontiert",
    "demontiertere": "demontiert",
    "demontierterem": "demontiert",
    "demontierteren": "demontiert",
    "demontierterer": "demontiert",
    "demontierteres": "demontiert",
    "demontiertes": "demontiert",
    "demontiertest": "demontieren",
    "demontierteste": "demontiert",
    "demontiertestem": "demontiert",
    "demontiertesten": "demontiert",
    "demontiertester": "demontiert",
    "demontiertestes": "demontiert",
    "demontiertet": "demontieren",
    "demoralisiere": "demoralisieren",
    "demoralisierend": "demoralisieren",
    "demoralisierende": "demoralisierend",
    "demoralisierendem": "demoralisierend",
    "demoralisierenden": "demoralisierend",
    "demoralisierender": "demoralisierend",
    "demoralisierendere": "demoralisierend",
    "demoralisierenderem": "demoralisierend",
    "demoralisierenderen": "demoralisierend",
    "demoralisierenderer": "demoralisierend",
    "demoralisierenderes": "demoralisierend",
    "demoralisierendes": "demoralisierend",
    "demoralisierendste": "demoralisierend",
    "demoralisierendstem": "demoralisierend",
    "demoralisierendsten": "demoralisierend",
    "demoralisierendster": "demoralisierend",
    "demoralisierendstes": "demoralisierend",
    "demoralisierest": "demoralisieren",
    "demoralisieret": "demoralisieren",
    "demoralisierst": "demoralisieren",
    "demoralisiert": "demoralisieren",
    "demoralisierte": "demoralisieren",
    "demoralisiertem": "demoralisiert",
    "demoralisierten": "demoralisieren",
    "demoralisierter": "demoralisiert",
    "demoralisiertere": "demoralisiert",
    "demoralisierterem": "demoralisiert",
    "demoralisierteren": "demoralisiert",
    "demoralisierterer": "demoralisiert",
    "demoralisierteres": "demoralisiert",
    "demoralisiertes": "demoralisiert",
    "demoralisiertest": "demoralisieren",
    "demoralisiertestem": "demoralisiert",
    "demoralisiertesten": "demoralisiert",
    "demoralisiertester": "demoralisiert",
    "demoralisiertestes": "demoralisiert",
    "demoralisiertet": "demoralisieren",
    "demselben": "derselbe",
    "demütige": "demütigen",
    "demütigend": "demütigen",
    "demütigende": "demütigend",
    "demütigendem": "demütigend",
    "demütigenden": "demütigend",
    "demütigender": "demütigend",
    "demütigendere": "demütigend",
    "demütigenderem": "demütigend",
    "demütigenderen": "demütigend",
    "demütigenderer": "demütigend",
    "demütigenderes": "demütigend",
    "demütigendes": "demütigend",
    "demütigendste": "demütigend",
    "demütigendstem": "demütigend",
    "demütigendsten": "demütigend",
    "demütigendster": "demütigend",
    "demütigendstes": "demütigend",
    "demütigest": "demütigen",
    "demütiget": "demütigen",
    "demütigst": "demütigen",
    "demütigt": "demütigen",
    "demütigte": "demütigen",
    "demütigten": "demütigen",
    "demütigtest": "demütigen",
    "demütigtet": "demütigen",
    "den": "der",
    "denazifiziere": "denazifizieren",
    "denazifizierend": "denazifizieren",
    "denazifizierende": "denazifizierend",
    "denazifizierendem": "denazifizierend",
    "denazifizierenden": "denazifizierend",
    "denazifizierender": "denazifizierend",
    "denazifizierendes": "denazifizierend",
    "denazifizierest": "denazifizieren",
    "denazifizieret": "denazifizieren",
    "denazifizierst": "denazifizieren",
    "denazifiziert": "denazifizieren",
    "denazifizierte": "denazifizieren",
    "denazifiziertem": "denazifiziert",
    "denazifizierten": "denazifizieren",
    "denazifizierter": "denazifiziert",
    "denazifiziertes": "denazifiziert",
    "denazifiziertest": "denazifizieren",
    "denazifiziertet": "denazifizieren",
    "denen": "der",
    "denjenigen": "derjenige",
    "denkbarem": "denkbar",
    "denkbaren": "denkbar",
    "denkbarer": "denkbar",
    "denkbarere": "denkbar",
    "denkbarerem": "denkbar",
    "denkbareren": "denkbar",
    "denkbarerer": "denkbar",
    "denkbareres": "denkbar",
    "denkbares": "denkbar",
    "denkbarste": "denkbar",
    "denkbarstem": "denkbar",
    "denkbarsten": "denkbar",
    "denkbarster": "denkbar",
    "denkbarstes": "denkbar",
    "denke": "denken",
    "denkend": "denken",
    "denkende": "denkend",
    "denkendem": "denkend",
    "denkenden": "denkend",
    "denkender": "denkend",
    "denkendere": "denkend",
    "denkenderem": "denkend",
    "denkenderen": "denkend",
    "denkenderer": "denkend",
    "denkenderes": "denkend",
    "denkendes": "denkend",
    "denkendste": "denkend",
    "denkendstem": "denkend",
    "denkendsten": "denkend",
    "denkendster": "denkend",
    "denkendstes": "denkend",
    "denkest": "denken",
    "denket": "denken",
    "denkfaule": "denkfaul",
    "denkfaulem": "denkfaul",
    "denkfaulen": "denkfaul",
    "denkfauler": "denkfaul",
    "denkfaulere": "denkfaul",
    "denkfaulerem": "denkfaul",
    "denkfauleren": "denkfaul",
    "denkfaulerer": "denkfaul",
    "denkfauleres": "denkfaul",
    "denkfaules": "denkfaul",
    "denkfaulste": "denkfaul",
    "denkfaulstem": "denkfaul",
    "denkfaulsten": "denkfaul",
    "denkfaulster": "denkfaul",
    "denkfaulstes": "denkfaul",
    "denkfähige": "denkfähig",
    "denkfähigem": "denkfähig",
    "denkfähigen": "denkfähig",
    "denkfähiger": "denkfähig",
    "denkfähigere": "denkfähig",
    "denkfähigerem": "denkfähig",
    "denkfähigeren": "denkfähig",
    "denkfähigerer": "denkfähig",
    "denkfähigeres": "denkfähig",
    "denkfähiges": "denkfähig",
    "denkfähigstem": "denkfähig",
    "denkfähigsten": "denkfähig",
    "denkfähigster": "denkfähig",
    "denkfähigstes": "denkfähig",
    "denkschwachem": "denkschwach",
    "denkschwachen": "denkschwach",
    "denkschwacher": "denkschwach",
    "denkschwaches": "denkschwach",
    "denkschwächer": "denkschwach",
    "denkschwächere": "denkschwach",
    "denkschwächerem": "denkschwach",
    "denkschwächeren": "denkschwach",
    "denkschwächerer": "denkschwach",
    "denkschwächeres": "denkschwach",
    "denkschwächste": "denkschwach",
    "denkschwächstem": "denkschwach",
    "denkschwächsten": "denkschwach",
    "denkschwächster": "denkschwach",
    "denkschwächstes": "denkschwach",
    "denkst": "denken",
    "denkt": "denken",
    "denkwürdigem": "denkwürdig",
    "denkwürdigen": "denkwürdig",
    "denkwürdiger": "denkwürdig",
    "denkwürdigere": "denkwürdig",
    "denkwürdigerem": "denkwürdig",
    "denkwürdigeren": "denkwürdig",
    "denkwürdigerer": "denkwürdig",
    "denkwürdigeres": "denkwürdig",
    "denkwürdiges": "denkwürdig",
    "denkwürdigstem": "denkwürdig",
    "denkwürdigsten": "denkwürdig",
    "denkwürdigster": "denkwürdig",
    "denkwürdigstes": "denkwürdig",
    "denselben": "derselbe",
    "dentale": "dental",
    "dentalem": "dental",
    "dentalen": "dental",
    "dentaler": "dental",
    "dentales": "dental",
    "denunziere": "denunzieren",
    "denunzierend": "denunzieren",
    "denunzierende": "denunzierend",
    "denunzierendem": "denunzierend",
    "denunzierenden": "denunzierend",
    "denunzierender": "denunzierend",
    "denunzierendes": "denunzierend",
    "denunzierest": "denunzieren",
    "denunzieret": "denunzieren",
    "denunzierst": "denunzieren",
    "denunziert": "denunzieren",
    "denunzierte": "denunzieren",
    "denunziertem": "denunziert",
    "denunzierten": "denunzieren",
    "denunzierter": "denunziert",
    "denunziertes": "denunziert",
    "denunziertest": "denunzieren",
    "denunziertet": "denunzieren",
    "deplaziere": "deplazieren",
    "deplazierend": "deplazieren",
    "deplazierende": "deplazierend",
    "deplazierendem": "deplazierend",
    "deplazierenden": "deplazierend",
    "deplazierender": "deplazierend",
    "deplazierendes": "deplazierend",
    "deplazierest": "deplazieren",
    "deplazieret": "deplazieren",
    "deplazierst": "deplazieren",
    "deplaziert": "deplazieren",
    "deplazierte": "deplazieren",
    "deplaziertem": "deplaziert",
    "deplazierten": "deplazieren",
    "deplazierter": "deplaziert",
    "deplaziertere": "deplaziert",
    "deplazierterem": "deplaziert",
    "deplazierteren": "deplaziert",
    "deplazierterer": "deplaziert",
    "deplazierteres": "deplaziert",
    "deplaziertes": "deplaziert",
    "deplaziertest": "deplazieren",
    "deplazierteste": "deplaziert",
    "deplaziertestem": "deplaziert",
    "deplaziertesten": "deplaziert",
    "deplaziertester": "deplaziert",
    "deplaziertestes": "deplaziert",
    "deplaziertet": "deplazieren",
    "deponiere": "deponieren",
    "deponierend": "deponieren",
    "deponierende": "deponierend",
    "deponierendem": "deponierend",
    "deponierenden": "deponierend",
    "deponierender": "deponierend",
    "deponierendes": "deponierend",
    "deponierest": "deponieren",
    "deponieret": "deponieren",
    "deponierst": "deponieren",
    "deponiert": "deponieren",
    "deponierte": "deponieren",
    "deponiertem": "deponiert",
    "deponierten": "deponieren",
    "deponierter": "deponiert",
    "deponiertes": "deponiert",
    "deponiertest": "deponieren",
    "deponiertet": "deponieren",
    "deportiere": "deportieren",
    "deportierend": "deportieren",
    "deportierende": "deportierend",
    "deportierendem": "deportierend",
    "deportierenden": "deportierend",
    "deportierender": "deportierend",
    "deportierendes": "deportierend",
    "deportierest": "deportieren",
    "deportieret": "deportieren",
    "deportierst": "deportieren",
    "deportiert": "deportieren",
    "deportierte": "deportieren",
    "deportiertem": "deportiert",
    "deportierten": "deportieren",
    "deportierter": "deportiert",
    "deportiertes": "deportiert",
    "deportiertest": "deportieren",
    "deportiertet": "deportieren",
    "depressivem": "depressiv",
    "depressiven": "depressiv",
    "depressiver": "depressiv",
    "depressivere": "depressiv",
    "depressiverem": "depressiv",
    "depressiveren": "depressiv",
    "depressiverer": "depressiv",
    "depressiveres": "depressiv",
    "depressives": "depressiv",
    "depressivste": "depressiv",
    "depressivstem": "depressiv",
    "depressivsten": "depressiv",
    "depressivster": "depressiv",
    "depressivstes": "depressiv",
    "deprimiere": "deprimieren",
    "deprimierend": "deprimieren",
    "deprimierende": "deprimierend",
    "deprimierendem": "deprimierend",
    "deprimierenden": "deprimierend",
    "deprimierender": "deprimierend",
    "deprimierendere": "deprimierend",
    "deprimierenderem": "deprimierend",
    "deprimierenderen": "deprimierend",
    "deprimierenderer": "deprimierend",
    "deprimierenderes": "deprimierend",
    "deprimierendes": "deprimierend",
    "deprimierendste": "deprimierend",
    "deprimierendstem": "deprimierend",
    "deprimierendsten": "deprimierend",
    "deprimierendster": "deprimierend",
    "deprimierendstes": "deprimierend",
    "deprimierest": "deprimieren",
    "deprimieret": "deprimieren",
    "deprimierst": "deprimieren",
    "deprimiert": "deprimieren",
    "deprimierte": "deprimieren",
    "deprimiertem": "deprimiert",
    "deprimierten": "deprimieren",
    "deprimierter": "deprimiert",
    "deprimiertere": "deprimiert",
    "deprimierterem": "deprimiert",
    "deprimierteren": "deprimiert",
    "deprimierterer": "deprimiert",
    "deprimierteres": "deprimiert",
    "deprimiertes": "deprimiert",
    "deprimiertest": "deprimieren",
    "deprimierteste": "deprimiert",
    "deprimiertestem": "deprimiert",
    "deprimiertesten": "deprimiert",
    "deprimiertester": "deprimiert",
    "deprimiertestes": "deprimiert",
    "deprimiertet": "deprimieren",
    "deputiere": "deputieren",
    "deputierend": "deputieren",
    "deputierende": "deputierend",
    "deputierendem": "deputierend",
    "deputierenden": "deputierend",
    "deputierender": "deputierend",
    "deputierendes": "deputierend",
    "deputierest": "deputieren",
    "deputieret": "deputieren",
    "deputierst": "deputieren",
    "deputiert": "deputieren",
    "deputierte": "deputieren",
    "deputiertem": "deputiert",
    "deputierten": "deputieren",
    "deputierter": "deputiert",
    "deputiertes": "deputiert",
    "deputiertest": "deputieren",
    "deputiertet": "deputieren",
    "derartige": "derartig",
    "derartigem": "derartig",
    "derartigen": "derartig",
    "derartiger": "derartig",
    "derartiges": "derartig",
    "derbe": "derb",
    "derbem": "derb",
    "derben": "derb",
    "derber": "derb",
    "derbere": "derb",
    "derberem": "derb",
    "derberen": "derb",
    "derberer": "derb",
    "derberes": "derb",
    "derbes": "derb",
    "derbste": "derb",
    "derbstem": "derb",
    "derbsten": "derb",
    "derbster": "derb",
    "derbstes": "derb",
    "dereinstigem": "dereinstig",
    "dereinstigen": "dereinstig",
    "dereinstiger": "dereinstig",
    "dereinstiges": "dereinstig",
    "deren": "der",
    "derjenigen": "derjenige",
    "dermatologischem": "dermatologisch",
    "dermatologischen": "dermatologisch",
    "dermatologischer": "dermatologisch",
    "dermatologisches": "dermatologisch",
    "derselben": "derselbe",
    "derzeitige": "derzeitig",
    "derzeitigem": "derzeitig",
    "derzeitigen": "derzeitig",
    "derzeitiger": "derzeitig",
    "derzeitiges": "derzeitig",
    "des": "der",
    "desertiere": "desertieren",
    "desertierend": "desertieren",
    "desertierende": "desertierend",
    "desertierendem": "desertierend",
    "desertierenden": "desertierend",
    "desertierender": "desertierend",
    "desertierendes": "desertierend",
    "desertierest": "desertieren",
    "desertieret": "desertieren",
    "desertierst": "desertieren",
    "desertiert": "desertieren",
    "desertierte": "desertieren",
    "desertiertem": "desertiert",
    "desertierten": "desertieren",
    "desertierter": "desertiert",
    "desertiertes": "desertiert",
    "desertiertest": "desertieren",
    "desertiertet": "desertieren",
    "desillusioniere": "desillusionieren",
    "desillusionierend": "desillusionieren",
    "desillusionierende": "desillusionierend",
    "desillusionierendem": "desillusionierend",
    "desillusionierenden": "desillusionierend",
    "desillusionierender": "desillusionierend",
    "desillusionierendere": "desillusionierend",
    "desillusionierenderem": "desillusionierend",
    "desillusionierenderen": "desillusionierend",
    "desillusionierenderer": "desillusionierend",
    "desillusionierenderes": "desillusionierend",
    "desillusionierendes": "desillusionierend",
    "desillusionierendste": "desillusionierend",
    "desillusionierendstem": "desillusionierend",
    "desillusionierendsten": "desillusionierend",
    "desillusionierendster": "desillusionierend",
    "desillusionierendstes": "desillusionierend",
    "desillusionierest": "desillusionieren",
    "desillusionieret": "desillusionieren",
    "desillusionierst": "desillusionieren",
    "desillusioniert": "desillusionieren",
    "desillusionierte": "desillusionieren",
    "desillusioniertem": "desillusioniert",
    "desillusionierten": "desillusionieren",
    "desillusionierter": "desillusioniert",
    "desillusioniertere": "desillusioniert",
    "desillusionierterem": "desillusioniert",
    "desillusionierteren": "desillusioniert",
    "desillusionierterer": "desillusioniert",
    "desillusionierteres": "desillusioniert",
    "desillusioniertes": "desillusioniert",
    "desillusioniertest": "desillusionieren",
    "desillusionierteste": "desillusioniert",
    "desillusioniertestem": "desillusioniert",
    "desillusioniertesten": "desillusioniert",
    "desillusioniertester": "desillusioniert",
    "desillusioniertestes": "desillusioniert",
    "desillusioniertet": "desillusionieren",
    "desinfizierend": "desinfizieren",
    "desinfizierende": "desinfizierend",
    "desinfizierendem": "desinfizierend",
    "desinfizierenden": "desinfizierend",
    "desinfizierender": "desinfizierend",
    "desinfizierendere": "desinfizierend",
    "desinfizierenderem": "desinfizierend",
    "desinfizierenderen": "desinfizierend",
    "desinfizierenderer": "desinfizierend",
    "desinfizierenderes": "desinfizierend",
    "desinfizierendes": "desinfizierend",
    "desinfizierendste": "desinfizierend",
    "desinfizierendstem": "desinfizierend",
    "desinfizierendsten": "desinfizierend",
    "desinfizierendster": "desinfizierend",
    "desinfizierendstes": "desinfizierend",
    "desinfizierest": "desinfizieren",
    "desinfizieret": "desinfizieren",
    "desinfizierst": "desinfizieren",
    "desinfiziert": "desinfizieren",
    "desinfizierte": "desinfizieren",
    "desinfiziertem": "desinfiziert",
    "desinfizierten": "desinfizieren",
    "desinfizierter": "desinfiziert",
    "desinfiziertere": "desinfiziert",
    "desinfizierterem": "desinfiziert",
    "desinfizierteren": "desinfiziert",
    "desinfizierterer": "desinfiziert",
    "desinfizierteres": "desinfiziert",
    "desinfiziertes": "desinfiziert",
    "desinfiziertest": "desinfizieren",
    "desinfizierteste": "desinfiziert",
    "desinfiziertestem": "desinfiziert",
    "desinfiziertesten": "desinfiziert",
    "desinfiziertester": "desinfiziert",
    "desinfiziertestes": "desinfiziert",
    "desinfiziertet": "desinfizieren",
    "desjenigen": "derjenige",
    "desolate": "desolat",
    "desolatem": "desolat",
    "desolaten": "desolat",
    "desolater": "desolat",
    "desolatere": "desolat",
    "desolaterem": "desolat",
    "desolateren": "desolat",
    "desolaterer": "desolat",
    "desolateres": "desolat",
    "desolates": "desolat",
    "desolateste": "desolat",
    "desolatestem": "desolat",
    "desolatesten": "desolat",
    "desolatester": "desolat",
    "desolatestes": "desolat",
    "desselben": "derselbe",
    "dessen": "der",
    "determinierend": "determinieren",
    "determinierende": "determinierend",
    "determinierendem": "determinierend",
    "determinierenden": "determinierend",
    "determinierender": "determinierend",
    "determinierendere": "determinierend",
    "determinierenderem": "determinierend",
    "determinierenderen": "determinierend",
    "determinierenderer": "determinierend",
    "determinierenderes": "determinierend",
    "determinierendes": "determinierend",
    "determinierendste": "determinierend",
    "determinierendstem": "determinierend",
    "determinierendsten": "determinierend",
    "determinierendster": "determinierend",
    "determinierendstes": "determinierend",
    "determinierest": "determinieren",
    "determinieret": "determinieren",
    "determinierst": "determinieren",
    "determiniert": "determinieren",
    "determinierte": "determinieren",
    "determiniertem": "determiniert",
    "determinierten": "determinieren",
    "determinierter": "determiniert",
    "determiniertes": "determiniert",
    "determiniertest": "determinieren",
    "determiniertet": "determinieren",
    "deterministischem": "deterministisch",
    "deterministischen": "deterministisch",
    "deterministischer": "deterministisch",
    "deterministisches": "deterministisch",
    "detoniere": "detonieren",
    "detonierend": "detonieren",
    "detonierende": "detonierend",
    "detonierendem": "detonierend",
    "detonierenden": "detonierend",
    "detonierender": "detonierend",
    "detonierendere": "detonierend",
    "detonierenderem": "detonierend",
    "detonierenderen": "detonierend",
    "detonierenderer": "detonierend",
    "detonierenderes": "detonierend",
    "detonierendes": "detonierend",
    "detonierendste": "detonierend",
    "detonierendstem": "detonierend",
    "detonierendsten": "detonierend",
    "detonierendster": "detonierend",
    "detonierendstes": "detonierend",
    "detonierest": "detonieren",
    "detonieret": "detonieren",
    "detonierst": "detonieren",
    "detoniert": "detonieren",
    "detonierte": "detonieren",
    "detoniertem": "detoniert",
    "detonierten": "detonieren",
    "detonierter": "detoniert",
    "detoniertere": "detoniert",
    "detonierterem": "detoniert",
    "detonierteren": "detoniert",
    "detonierterer": "detoniert",
    "detonierteres": "detoniert",
    "detoniertes": "detoniert",
    "detoniertest": "detonieren",
    "detonierteste": "detoniert",
    "detoniertestem": "detoniert",
    "detoniertesten": "detoniert",
    "detoniertester": "detoniert",
    "detoniertestes": "detoniert",
    "detoniertet": "detonieren",
    "deuche": "dünken",
    "deuchte": "dünken",
    "deuchten": "dünken",
    "deuchtest": "dünken",
    "deuchtet": "dünken",
    "deute": "deuten",
    "deutele": "deuteln",
    "deutelnd": "deuteln",
    "deutelnde": "deutelnd",
    "deutelndem": "deutelnd",
    "deutelnden": "deutelnd",
    "deutelnder": "deutelnd",
    "deutelndes": "deutelnd",
    "deutelst": "deuteln",
    "deutelt": "deuteln",
    "deutelte": "deuteln",
    "deutelten": "deuteln",
    "deuteltest": "deuteln",
    "deuteltet": "deuteln",
    "deutend": "deuten",
    "deutende": "deutend",
    "deutendem": "deutend",
    "deutenden": "deutend",
    "deutender": "deutend",
    "deutendes": "deutend",
    "deutest": "deuten",
    "deutet": "deuten",
    "deutete": "deuten",
    "deuteten": "deuten",
    "deutetest": "deuten",
    "deutetet": "deuten",
    "deutle": "deuteln",
    "deutliche": "deutlich",
    "deutlichem": "deutlich",
    "deutlichen": "deutlich",
    "deutlicher": "deutlich",
    "deutlichere": "deutlich",
    "deutlicherem": "deutlich",
    "deutlicheren": "deutlich",
    "deutlicherer": "deutlich",
    "deutlicheres": "deutlich",
    "deutliches": "deutlich",
    "deutlichste": "deutlich",
    "deutlichstem": "deutlich",
    "deutlichsten": "deutlich",
    "deutlichster": "deutlich",
    "deutlichstes": "deutlich",
    "deutsch": "deutschen",
    "deutschamerikanische": "deutschamerikanisch",
    "deutschamerikanischem": "deutschamerikanisch",
    "deutschamerikanischen": "deutschamerikanisch",
    "deutschamerikanischer": "deutschamerikanisch",
    "deutschamerikanisches": "deutschamerikanisch",
    "deutsche": "deutsch",
    "deutschem": "deutsch",
    "deutschen": "deutsch",
    "deutschend": "deutschen",
    "deutschende": "deutschend",
    "deutschendem": "deutschend",
    "deutschenden": "deutschend",
    "deutschender": "deutschend",
    "deutschendes": "deutschend",
    "deutscher": "deutsch",
    "deutsches": "deutsch",
    "deutschest": "deutschen",
    "deutschet": "deutschen",
    "deutschfeindliche": "deutschfeindlich",
    "deutschfeindlichem": "deutschfeindlich",
    "deutschfeindlichen": "deutschfeindlich",
    "deutschfeindlicher": "deutschfeindlich",
    "deutschfeindliches": "deutschfeindlich",
    "deutschfreundliche": "deutschfreundlich",
    "deutschfreundlichem": "deutschfreundlich",
    "deutschfreundlichen": "deutschfreundlich",
    "deutschfreundlicher": "deutschfreundlich",
    "deutschfreundliches": "deutschfreundlich",
    "deutschlandpolitische": "deutschlandpolitisch",
    "deutschlandpolitischem": "deutschlandpolitisch",
    "deutschlandpolitischen": "deutschlandpolitisch",
    "deutschlandpolitischer": "deutschlandpolitisch",
    "deutschlandpolitisches": "deutschlandpolitisch",
    "deutschschweizerischem": "deutschschweizerisch",
    "deutschschweizerischen": "deutschschweizerisch",
    "deutschschweizerischer": "deutschschweizerisch",
    "deutschschweizerisches": "deutschschweizerisch",
    "deutschsprachige": "deutschsprachig",
    "deutschsprachigem": "deutschsprachig",
    "deutschsprachigen": "deutschsprachig",
    "deutschsprachiger": "deutschsprachig",
    "deutschsprachiges": "deutschsprachig",
    "deutschsprachliche": "deutschsprachlich",
    "deutschsprachlichem": "deutschsprachlich",
    "deutschsprachlichen": "deutschsprachlich",
    "deutschsprachlicher": "deutschsprachlich",
    "deutschsprachliches": "deutschsprachlich",
    "deutschsprechende": "deutschsprechend",
    "deutschsprechendem": "deutschsprechend",
    "deutschsprechenden": "deutschsprechend",
    "deutschsprechender": "deutschsprechend",
    "deutschsprechendes": "deutschsprechend",
    "deutschst": "deutschen",
    "deutscht": "deutschen",
    "deutschte": "deutschen",
    "deutschten": "deutschen",
    "deutschtest": "deutschen",
    "deutschtet": "deutschen",
    "dezentem": "dezent",
    "dezenten": "dezent",
    "dezenter": "dezent",
    "dezentere": "dezent",
    "dezenterem": "dezent",
    "dezenteren": "dezent",
    "dezenterer": "dezent",
    "dezenteres": "dezent",
    "dezentes": "dezent",
    "dezenteste": "dezent",
    "dezentestem": "dezent",
    "dezentesten": "dezent",
    "dezentester": "dezent",
    "dezentestes": "dezent",
    "dezentralisiere": "dezentralisieren",
    "dezentralisierend": "dezentralisieren",
    "dezentralisierende": "dezentralisierend",
    "dezentralisierendem": "dezentralisierend",
    "dezentralisierenden": "dezentralisierend",
    "dezentralisierender": "dezentralisierend",
    "dezentralisierendere": "dezentralisierend",
    "dezentralisierenderem": "dezentralisierend",
    "dezentralisierenderen": "dezentralisierend",
    "dezentralisierenderer": "dezentralisierend",
    "dezentralisierenderes": "dezentralisierend",
    "dezentralisierendes": "dezentralisierend",
    "dezentralisierendste": "dezentralisierend",
    "dezentralisierendstem": "dezentralisierend",
    "dezentralisierendsten": "dezentralisierend",
    "dezentralisierendster": "dezentralisierend",
    "dezentralisierendstes": "dezentralisierend",
    "dezentralisierest": "dezentralisieren",
    "dezentralisieret": "dezentralisieren",
    "dezentralisierst": "dezentralisieren",
    "dezentralisiert": "dezentralisieren",
    "dezentralisierte": "dezentralisieren",
    "dezentralisiertem": "dezentralisiert",
    "dezentralisierten": "dezentralisieren",
    "dezentralisierter": "dezentralisiert",
    "dezentralisiertere": "dezentralisiert",
    "dezentralisierterem": "dezentralisiert",
    "dezentralisierteren": "dezentralisiert",
    "dezentralisierterer": "dezentralisiert",
    "dezentralisierteres": "dezentralisiert",
    "dezentralisiertes": "dezentralisiert",
    "dezentralisiertest": "dezentralisieren",
    "dezentralisierteste": "dezentralisiert",
    "dezentralisiertestem": "dezentralisiert",
    "dezentralisiertesten": "dezentralisiert",
    "dezentralisiertester": "dezentralisiert",
    "dezentralisiertestes": "dezentralisiert",
    "dezentralisiertet": "dezentralisieren",
    "dezidiere": "dezidieren",
    "dezidierend": "dezidieren",
    "dezidierende": "dezidierend",
    "dezidierendem": "dezidierend",
    "dezidierenden": "dezidierend",
    "dezidierender": "dezidierend",
    "dezidierendes": "dezidierend",
    "dezidierest": "dezidieren",
    "dezidieret": "dezidieren",
    "dezidierst": "dezidieren",
    "dezidiert": "dezidieren",
    "dezidierte": "dezidieren",
    "dezidiertem": "dezidiert",
    "dezidierten": "dezidieren",
    "dezidierter": "dezidiert",
    "dezidiertes": "dezidiert",
    "dezidiertest": "dezidieren",
    "dezidiertet": "dezidieren",
    "dezimale": "dezimal",
    "dezimalem": "dezimal",
    "dezimalen": "dezimal",
    "dezimaler": "dezimal",
    "dezimales": "dezimal",
    "dezimalisiere": "dezimalisieren",
    "dezimalisierend": "dezimalisieren",
    "dezimalisierende": "dezimalisierend",
    "dezimalisierendem": "dezimalisierend",
    "dezimalisierenden": "dezimalisierend",
    "dezimalisierender": "dezimalisierend",
    "dezimalisierendes": "dezimalisierend",
    "dezimalisierest": "dezimalisieren",
    "dezimalisieret": "dezimalisieren",
    "dezimalisierst": "dezimalisieren",
    "dezimalisiert": "dezimalisieren",
    "dezimalisierte": "dezimalisieren",
    "dezimalisiertem": "dezimalisiert",
    "dezimalisierten": "dezimalisieren",
    "dezimalisierter": "dezimalisiert",
    "dezimalisiertes": "dezimalisiert",
    "dezimalisiertest": "dezimalisieren",
    "dezimalisiertet": "dezimalisieren",
    "dezimiere": "dezimieren",
    "dezimierend": "dezimieren",
    "dezimierende": "dezimierend",
    "dezimierendem": "dezimierend",
    "dezimierenden": "dezimierend",
    "dezimierender": "dezimierend",
    "dezimierendere": "dezimierend",
    "dezimierenderem": "dezimierend",
    "dezimierenderen": "dezimierend",
    "dezimierenderer": "dezimierend",
    "dezimierenderes": "dezimierend",
    "dezimierendes": "dezimierend",
    "dezimierendste": "dezimierend",
    "dezimierendstem": "dezimierend",
    "dezimierendsten": "dezimierend",
    "dezimierendster": "dezimierend",
    "dezimierendstes": "dezimierend",
    "dezimierest": "dezimieren",
    "dezimieret": "dezimieren",
    "dezimierst": "dezimieren",
    "dezimiert": "dezimieren",
    "dezimierte": "dezimieren",
    "dezimiertem": "dezimiert",
    "dezimierten": "dezimieren",
    "dezimierter": "dezimiert",
    "dezimiertere": "dezimiert",
    "dezimierterem": "dezimiert",
    "dezimierteren": "dezimiert",
    "dezimierterer": "dezimiert",
    "dezimierteres": "dezimiert",
    "dezimiertes": "dezimiert",
    "dezimiertest": "dezimieren",
    "dezimierteste": "dezimiert",
    "dezimiertestem": "dezimiert",
    "dezimiertesten": "dezimiert",
    "dezimiertester": "dezimiert",
    "dezimiertestes": "dezimiert",
    "dezimiertet": "dezimieren",
    "diabolischem": "diabolisch",
    "diabolischen": "diabolisch",
    "diabolischer": "diabolisch",
    "diabolischere": "diabolisch",
    "diabolischerem": "diabolisch",
    "diabolischeren": "diabolisch",
    "diabolischerer": "diabolisch",
    "diabolischeres": "diabolisch",
    "diabolisches": "diabolisch",
    "diabolischste": "diabolisch",
    "diabolischstem": "diabolisch",
    "diabolischsten": "diabolisch",
    "diabolischster": "diabolisch",
    "diabolischstes": "diabolisch",
    "diagnostischem": "diagnostisch",
    "diagnostischen": "diagnostisch",
    "diagnostischer": "diagnostisch",
    "diagnostisches": "diagnostisch",
    "diagnostiziere": "diagnostizieren",
    "diagnostizierend": "diagnostizieren",
    "diagnostizierende": "diagnostizierend",
    "diagnostizierendem": "diagnostizierend",
    "diagnostizierenden": "diagnostizierend",
    "diagnostizierender": "diagnostizierend",
    "diagnostizierendes": "diagnostizierend",
    "diagnostizierest": "diagnostizieren",
    "diagnostizieret": "diagnostizieren",
    "diagnostizierst": "diagnostizieren",
    "diagnostiziert": "diagnostizieren",
    "diagnostizierte": "diagnostizieren",
    "diagnostiziertem": "diagnostiziert",
    "diagnostizierten": "diagnostizieren",
    "diagnostizierter": "diagnostiziert",
    "diagnostiziertes": "diagnostiziert",
    "diagnostiziertest": "diagnostizieren",
    "diagnostiziertet": "diagnostizieren",
    "diagonale": "diagonal",
    "diagonalem": "diagonal",
    "diagonalen": "diagonal",
    "diagonaler": "diagonal",
    "diagonales": "diagonal",
    "diakonischem": "diakonisch",
    "diakonischen": "diakonisch",
    "diakonischer": "diakonisch",
    "diakonischere": "diakonisch",
    "diakonischerem": "diakonisch",
    "diakonischeren": "diakonisch",
    "diakonischerer": "diakonisch",
    "diakonischeres": "diakonisch",
    "diakonisches": "diakonisch",
    "diakonischste": "diakonisch",
    "diakonischstem": "diakonisch",
    "diakonischsten": "diakonisch",
    "diakonischster": "diakonisch",
    "diakonischstes": "diakonisch",
    "dialektfreiem": "dialektfrei",
    "dialektfreien": "dialektfrei",
    "dialektfreier": "dialektfrei",
    "dialektfreiere": "dialektfrei",
    "dialektfreierem": "dialektfrei",
    "dialektfreieren": "dialektfrei",
    "dialektfreierer": "dialektfrei",
    "dialektfreieres": "dialektfrei",
    "dialektfreies": "dialektfrei",
    "dialektfreiste": "dialektfrei",
    "dialektfreistem": "dialektfrei",
    "dialektfreisten": "dialektfrei",
    "dialektfreister": "dialektfrei",
    "dialektfreistes": "dialektfrei",
    "dialektischem": "dialektisch",
    "dialektischen": "dialektisch",
    "dialektischer": "dialektisch",
    "dialektisches": "dialektisch",
    "dialogisiere": "dialogisieren",
    "dialogisierend": "dialogisieren",
    "dialogisierende": "dialogisierend",
    "dialogisierendem": "dialogisierend",
    "dialogisierenden": "dialogisierend",
    "dialogisierender": "dialogisierend",
    "dialogisierendes": "dialogisierend",
    "dialogisierest": "dialogisieren",
    "dialogisieret": "dialogisieren",
    "dialogisierst": "dialogisieren",
    "dialogisiert": "dialogisieren",
    "dialogisierte": "dialogisieren",
    "dialogisiertem": "dialogisiert",
    "dialogisierten": "dialogisieren",
    "dialogisierter": "dialogisiert",
    "dialogisiertes": "dialogisiert",
    "dialogisiertest": "dialogisieren",
    "dialogisiertet": "dialogisieren",
    "dialysiere": "dialysieren",
    "dialysierend": "dialysieren",
    "dialysierende": "dialysierend",
    "dialysierendem": "dialysierend",
    "dialysierenden": "dialysierend",
    "dialysierender": "dialysierend",
    "dialysierendes": "dialysierend",
    "dialysierest": "dialysieren",
    "dialysieret": "dialysieren",
    "dialysierst": "dialysieren",
    "dialysiert": "dialysieren",
    "dialysierte": "dialysieren",
    "dialysiertem": "dialysiert",
    "dialysierten": "dialysieren",
    "dialysierter": "dialysiert",
    "dialysiertes": "dialysiert",
    "dialysiertest": "dialysieren",
    "dialysiertet": "dialysieren",
    "diamantenem": "diamanten",
    "diamantenen": "diamanten",
    "diamantener": "diamanten",
    "diamantenes": "diamanten",
    "dich": "sich",
    "dichte": "dichten",
    "dichtem": "dicht",
    "dichten": "dicht",
    "dichtend": "dichten",
    "dichtende": "dichtend",
    "dichtendem": "dichtend",
    "dichtenden": "dichtend",
    "dichtender": "dichtend",
    "dichtendes": "dichtend",
    "dichtere": "dicht",
    "dichterem": "dicht",
    "dichteren": "dicht",
    "dichterer": "dicht",
    "dichteres": "dicht",
    "dichterischem": "dichterisch",
    "dichterischen": "dichterisch",
    "dichterischer": "dichterisch",
    "dichterisches": "dichterisch",
    "dichtes": "dicht",
    "dichtest": "dichten",
    "dichteste": "dicht",
    "dichtestem": "dicht",
    "dichtesten": "dicht",
    "dichtester": "dicht",
    "dichtestes": "dicht",
    "dichtet": "dichten",
    "dichtete": "dichten",
    "dichteten": "dichten",
    "dichtetest": "dichten",
    "dichtetet": "dichten",
    "dichtgedrängte": "dichtgedrängt",
    "dichtgedrängtem": "dichtgedrängt",
    "dichtgedrängten": "dichtgedrängt",
    "dichtgedrängter": "dichtgedrängt",
    "dichtgedrängtere": "dichtgedrängt",
    "dichtgedrängterem": "dichtgedrängt",
    "dichtgedrängteren": "dichtgedrängt",
    "dichtgedrängterer": "dichtgedrängt",
    "dichtgedrängteres": "dichtgedrängt",
    "dichtgedrängtes": "dichtgedrängt",
    "dichtgedrängteste": "dichtgedrängt",
    "dichtgedrängtestem": "dichtgedrängt",
    "dichtgedrängtesten": "dichtgedrängt",
    "dichtgedrängtester": "dichtgedrängt",
    "dichtgedrängtestes": "dichtgedrängt",
    "dichtgemacht": "dichtmachen",
    "dichtgemachte": "dichtgemacht",
    "dichtgemachtem": "dichtgemacht",
    "dichtgemachten": "dichtgemacht",
    "dichtgemachter": "dichtgemacht",
    "dichtgemachtes": "dichtgemacht",
    "dichtmache": "dichtmachen",
    "dichtmachend": "dichtmachen",
    "dichtmachende": "dichtmachend",
    "dichtmachendem": "dichtmachend",
    "dichtmachenden": "dichtmachend",
    "dichtmachender": "dichtmachend",
    "dichtmachendes": "dichtmachend",
    "dichtmachest": "dichtmachen",
    "dichtmachet": "dichtmachen",
    "dichtmachst": "dichtmachen",
    "dichtmacht": "dichtmachen",
    "dichtmachte": "dichtmachen",
    "dichtmachten": "dichtmachen",
    "dichtmachtest": "dichtmachen",
    "dichtmachtet": "dichtmachen",
    "dichtzumachen": "dichtmachen",
    "dickbäuchigem": "dickbäuchig",
    "dickbäuchigen": "dickbäuchig",
    "dickbäuchiger": "dickbäuchig",
    "dickbäuchigere": "dickbäuchig",
    "dickbäuchigerem": "dickbäuchig",
    "dickbäuchigeren": "dickbäuchig",
    "dickbäuchigerer": "dickbäuchig",
    "dickbäuchigeres": "dickbäuchig",
    "dickbäuchiges": "dickbäuchig",
    "dickbäuchigste": "dickbäuchig",
    "dickbäuchigstem": "dickbäuchig",
    "dickbäuchigsten": "dickbäuchig",
    "dickbäuchigster": "dickbäuchig",
    "dickbäuchigstes": "dickbäuchig",
    "dickem": "dick",
    "dicken": "dick",
    "dicker": "dick",
    "dickere": "dick",
    "dickerem": "dick",
    "dickeren": "dick",
    "dickerer": "dick",
    "dickeres": "dick",
    "dickes": "dick",
    "dickfellige": "dickfellig",
    "dickfelligem": "dickfellig",
    "dickfelligen": "dickfellig",
    "dickfelliger": "dickfellig",
    "dickfelligere": "dickfellig",
    "dickfelligerem": "dickfellig",
    "dickfelligeren": "dickfellig",
    "dickfelligerer": "dickfellig",
    "dickfelligeres": "dickfellig",
    "dickfelliges": "dickfellig",
    "dickfelligste": "dickfellig",
    "dickfelligstem": "dickfellig",
    "dickfelligsten": "dickfellig",
    "dickfelligster": "dickfellig",
    "dickfelligstes": "dickfellig",
    "dickflüssige": "dickflüssig",
    "dickflüssigem": "dickflüssig",
    "dickflüssigen": "dickflüssig",
    "dickflüssiger": "dickflüssig",
    "dickflüssigere": "dickflüssig",
    "dickflüssigerem": "dickflüssig",
    "dickflüssigeren": "dickflüssig",
    "dickflüssigerer": "dickflüssig",
    "dickflüssigeres": "dickflüssig",
    "dickflüssiges": "dickflüssig",
    "dickflüssigste": "dickflüssig",
    "dickflüssigstem": "dickflüssig",
    "dickflüssigsten": "dickflüssig",
    "dickflüssigster": "dickflüssig",
    "dickflüssigstes": "dickflüssig",
    "dickköpfigem": "dickköpfig",
    "dickköpfigen": "dickköpfig",
    "dickköpfiger": "dickköpfig",
    "dickköpfigere": "dickköpfig",
    "dickköpfigerem": "dickköpfig",
    "dickköpfigeren": "dickköpfig",
    "dickköpfigerer": "dickköpfig",
    "dickköpfigeres": "dickköpfig",
    "dickköpfiges": "dickköpfig",
    "dickköpfigste": "dickköpfig",
    "dickköpfigstem": "dickköpfig",
    "dickköpfigsten": "dickköpfig",
    "dickköpfigster": "dickköpfig",
    "dickköpfigstes": "dickköpfig",
    "dickleibigem": "dickleibig",
    "dickleibigen": "dickleibig",
    "dickleibiger": "dickleibig",
    "dickleibigere": "dickleibig",
    "dickleibigerem": "dickleibig",
    "dickleibigeren": "dickleibig",
    "dickleibigerer": "dickleibig",
    "dickleibigeres": "dickleibig",
    "dickleibiges": "dickleibig",
    "dickleibigste": "dickleibig",
    "dickleibigstem": "dickleibig",
    "dickleibigsten": "dickleibig",
    "dickleibigster": "dickleibig",
    "dickleibigstes": "dickleibig",
    "dickliche": "dicklich",
    "dicklichem": "dicklich",
    "dicklichen": "dicklich",
    "dicklicher": "dicklich",
    "dicklichere": "dicklich",
    "dicklicherem": "dicklich",
    "dicklicheren": "dicklich",
    "dicklicherer": "dicklich",
    "dicklicheres": "dicklich",
    "dickliches": "dicklich",
    "dicklichste": "dicklich",
    "dicklichstem": "dicklich",
    "dicklichsten": "dicklich",
    "dicklichster": "dicklich",
    "dicklichstes": "dicklich",
    "dickstem": "dick",
    "dicksten": "dick",
    "dickster": "dick",
    "dickstes": "dick",
    "dickwandige": "dickwandig",
    "dickwandigem": "dickwandig",
    "dickwandigen": "dickwandig",
    "dickwandiger": "dickwandig",
    "dickwandigere": "dickwandig",
    "dickwandigerem": "dickwandig",
    "dickwandigeren": "dickwandig",
    "dickwandigerer": "dickwandig",
    "dickwandigeres": "dickwandig",
    "dickwandiges": "dickwandig",
    "dickwandigste": "dickwandig",
    "dickwandigstem": "dickwandig",
    "dickwandigsten": "dickwandig",
    "dickwandigster": "dickwandig",
    "dickwandigstes": "dickwandig",
    "didaktischem": "didaktisch",
    "didaktischen": "didaktisch",
    "didaktischer": "didaktisch",
    "didaktisches": "didaktisch",
    "die": "der",
    "diejenige": "derjenige",
    "diejenigen": "derjenige",
    "diene": "dienen",
    "dienend": "dienen",
    "dienende": "dienend",
    "dienendem": "dienend",
    "dienenden": "dienend",
    "dienender": "dienend",
    "dienendes": "dienend",
    "dienest": "dienen",
    "dienet": "dienen",
    "dienliche": "dienlich",
    "dienlichem": "dienlich",
    "dienlichen": "dienlich",
    "dienlicher": "dienlich",
    "dienlichere": "dienlich",
    "dienlicherem": "dienlich",
    "dienlicheren": "dienlich",
    "dienlicherer": "dienlich",
    "dienlicheres": "dienlich",
    "dienliches": "dienlich",
    "dienlichste": "dienlich",
    "dienlichstem": "dienlich",
    "dienlichsten": "dienlich",
    "dienlichster": "dienlich",
    "dienlichstes": "dienlich",
    "dienst": "dienen",
    "dienstbarem": "dienstbar",
    "dienstbaren": "dienstbar",
    "dienstbarer": "dienstbar",
    "dienstbares": "dienstbar",
    "dienstbereite": "dienstbereit",
    "dienstbereitem": "dienstbereit",
    "dienstbereiten": "dienstbereit",
    "dienstbereiter": "dienstbereit",
    "dienstbereitere": "dienstbereit",
    "dienstbereiterem": "dienstbereit",
    "dienstbereiteren": "dienstbereit",
    "dienstbereiterer": "dienstbereit",
    "dienstbereiteres": "dienstbereit",
    "dienstbereites": "dienstbereit",
    "dienstbereiteste": "dienstbereit",
    "dienstbereitestem": "dienstbereit",
    "dienstbereitesten": "dienstbereit",
    "dienstbereitester": "dienstbereit",
    "dienstbereitestes": "dienstbereit",
    "diensteifrigem": "diensteifrig",
    "diensteifrigen": "diensteifrig",
    "diensteifriger": "diensteifrig",
    "diensteifrigere": "diensteifrig",
    "diensteifrigerem": "diensteifrig",
    "diensteifrigeren": "diensteifrig",
    "diensteifrigerer": "diensteifrig",
    "diensteifrigeres": "diensteifrig",
    "diensteifriges": "diensteifrig",
    "diensteifrigste": "diensteifrig",
    "diensteifrigstem": "diensteifrig",
    "diensteifrigsten": "diensteifrig",
    "diensteifrigster": "diensteifrig",
    "diensteifrigstes": "diensteifrig",
    "dienstfähigem": "dienstfähig",
    "dienstfähigen": "dienstfähig",
    "dienstfähiger": "dienstfähig",
    "dienstfähigere": "dienstfähig",
    "dienstfähigerem": "dienstfähig",
    "dienstfähigeren": "dienstfähig",
    "dienstfähigerer": "dienstfähig",
    "dienstfähigeres": "dienstfähig",
    "dienstfähiges": "dienstfähig",
    "dienstfähigste": "dienstfähig",
    "dienstfähigstem": "dienstfähig",
    "dienstfähigsten": "dienstfähig",
    "dienstfähigster": "dienstfähig",
    "dienstfähigstes": "dienstfähig",
    "diensthabende": "diensthabend",
    "diensthabendem": "diensthabend",
    "diensthabenden": "diensthabend",
    "diensthabender": "diensthabend",
    "diensthabendes": "diensthabend",
    "dienstliche": "dienstlich",
    "dienstlichem": "dienstlich",
    "dienstlichen": "dienstlich",
    "dienstlicher": "dienstlich",
    "dienstliches": "dienstlich",
    "diensttauglichem": "diensttauglich",
    "diensttauglichen": "diensttauglich",
    "diensttauglicher": "diensttauglich",
    "diensttauglichere": "diensttauglich",
    "diensttauglicherem": "diensttauglich",
    "diensttauglicheren": "diensttauglich",
    "diensttauglicherer": "diensttauglich",
    "diensttauglicheres": "diensttauglich",
    "diensttaugliches": "diensttauglich",
    "diensttauglichste": "diensttauglich",
    "diensttauglichstem": "diensttauglich",
    "diensttauglichsten": "diensttauglich",
    "diensttauglichster": "diensttauglich",
    "diensttauglichstes": "diensttauglich",
    "diensttuende": "diensttuend",
    "diensttuendem": "diensttuend",
    "diensttuenden": "diensttuend",
    "diensttuender": "diensttuend",
    "diensttuendes": "diensttuend",
    "dienstunfähige": "dienstunfähig",
    "dienstunfähigem": "dienstunfähig",
    "dienstunfähigen": "dienstunfähig",
    "dienstunfähiger": "dienstunfähig",
    "dienstunfähigere": "dienstunfähig",
    "dienstunfähigerem": "dienstunfähig",
    "dienstunfähigeren": "dienstunfähig",
    "dienstunfähigerer": "dienstunfähig",
    "dienstunfähigeres": "dienstunfähig",
    "dienstunfähiges": "dienstunfähig",
    "dienstunfähigste": "dienstunfähig",
    "dienstunfähigstem": "dienstunfähig",
    "dienstunfähigsten": "dienstunfähig",
    "dienstunfähigster": "dienstunfähig",
    "dienstunfähigstes": "dienstunfähig",
    "dienstuntaugliche": "dienstuntauglich",
    "dienstuntauglichem": "dienstuntauglich",
    "dienstuntauglichen": "dienstuntauglich",
    "dienstuntauglicher": "dienstuntauglich",
    "dienstuntauglichere": "dienstuntauglich",
    "dienstuntauglicherem": "dienstuntauglich",
    "dienstuntauglicheren": "dienstuntauglich",
    "dienstuntauglicherer": "dienstuntauglich",
    "dienstuntauglicheres": "dienstuntauglich",
    "dienstuntaugliches": "dienstuntauglich",
    "dienstuntauglichste": "dienstuntauglich",
    "dienstuntauglichstem": "dienstuntauglich",
    "dienstuntauglichsten": "dienstuntauglich",
    "dienstuntauglichster": "dienstuntauglich",
    "dienstuntauglichstes": "dienstuntauglich",
    "dienstwilligem": "dienstwillig",
    "dienstwilligen": "dienstwillig",
    "dienstwilliger": "dienstwillig",
    "dienstwilligere": "dienstwillig",
    "dienstwilligerem": "dienstwillig",
    "dienstwilligeren": "dienstwillig",
    "dienstwilligerer": "dienstwillig",
    "dienstwilligeres": "dienstwillig",
    "dienstwilliges": "dienstwillig",
    "dienstwilligste": "dienstwillig",
    "dienstwilligstem": "dienstwillig",
    "dienstwilligsten": "dienstwillig",
    "dienstwilligster": "dienstwillig",
    "dienstwilligstes": "dienstwillig",
    "dient": "dienen",
    "diente": "dienen",
    "dienten": "dienen",
    "dientest": "dienen",
    "dientet": "dienen",
    "diesbezüglichem": "diesbezüglich",
    "diesbezüglichen": "diesbezüglich",
    "diesbezüglicher": "diesbezüglich",
    "diesbezügliches": "diesbezüglich",
    "diese": "dies",
    "dieselbe": "derselbe",
    "dieselben": "derselbe",
    "diesem": "dies",
    "diesen": "dies",
    "dieser": "dies",
    "dieses": "dies",
    "diesige": "diesig",
    "diesigem": "diesig",
    "diesigen": "diesig",
    "diesiger": "diesig",
    "diesigere": "diesig",
    "diesigerem": "diesig",
    "diesigeren": "diesig",
    "diesigerer": "diesig",
    "diesigeres": "diesig",
    "diesiges": "diesig",
    "diesigste": "diesig",
    "diesigstem": "diesig",
    "diesigsten": "diesig",
    "diesigster": "diesig",
    "diesigstes": "diesig",
    "diesjährige": "diesjährig",
    "diesjährigem": "diesjährig",
    "diesjährigen": "diesjährig",
    "diesjähriger": "diesjährig",
    "diesjähriges": "diesjährig",
    "diesmalige": "diesmalig",
    "diesmaligem": "diesmalig",
    "diesmaligen": "diesmalig",
    "diesmaliger": "diesmalig",
    "diesmaliges": "diesmalig",
    "diesseitige": "diesseitig",
    "diesseitigem": "diesseitig",
    "diesseitigen": "diesseitig",
    "diesseitiger": "diesseitig",
    "diesseitiges": "diesseitig",
    "diffamiere": "diffamieren",
    "diffamierend": "diffamieren",
    "diffamierende": "diffamierend",
    "diffamierendem": "diffamierend",
    "diffamierenden": "diffamierend",
    "diffamierender": "diffamierend",
    "diffamierendere": "diffamierend",
    "diffamierenderem": "diffamierend",
    "diffamierenderen": "diffamierend",
    "diffamierenderer": "diffamierend",
    "diffamierenderes": "diffamierend",
    "diffamierendes": "diffamierend",
    "diffamierendste": "diffamierend",
    "diffamierendstem": "diffamierend",
    "diffamierendsten": "diffamierend",
    "diffamierendster": "diffamierend",
    "diffamierendstes": "diffamierend",
    "diffamierest": "diffamieren",
    "diffamieret": "diffamieren",
    "diffamierst": "diffamieren",
    "diffamiert": "diffamieren",
    "diffamierte": "diffamieren",
    "diffamiertem": "diffamiert",
    "diffamierten": "diffamieren",
    "diffamierter": "diffamiert",
    "diffamiertere": "diffamiert",
    "diffamierterem": "diffamiert",
    "diffamierteren": "diffamiert",
    "diffamierterer": "diffamiert",
    "diffamierteres": "diffamiert",
    "diffamiertes": "diffamiert",
    "diffamiertest": "diffamieren",
    "diffamierteste": "diffamiert",
    "diffamiertestem": "diffamiert",
    "diffamiertesten": "diffamiert",
    "diffamiertester": "diffamiert",
    "diffamiertestes": "diffamiert",
    "diffamiertet": "diffamieren",
    "differentiellem": "differentiell",
    "differentiellen": "differentiell",
    "differentieller": "differentiell",
    "differentielles": "differentiell",
    "differenzierbarem": "differenzierbar",
    "differenzierbaren": "differenzierbar",
    "differenzierbarer": "differenzierbar",
    "differenzierbares": "differenzierbar",
    "differenziere": "differenzieren",
    "differenzierend": "differenzieren",
    "differenzierende": "differenzierend",
    "differenzierendem": "differenzierend",
    "differenzierenden": "differenzierend",
    "differenzierender": "differenzierend",
    "differenzierendes": "differenzierend",
    "differenzierest": "differenzieren",
    "differenzieret": "differenzieren",
    "differenzierst": "differenzieren",
    "differenziert": "differenzieren",
    "differenzierte": "differenzieren",
    "differenziertem": "differenziert",
    "differenzierten": "differenzieren",
    "differenzierter": "differenziert",
    "differenziertere": "differenziert",
    "differenzierterem": "differenziert",
    "differenzierteren": "differenziert",
    "differenzierterer": "differenziert",
    "differenzierteres": "differenziert",
    "differenziertes": "differenziert",
    "differenziertest": "differenzieren",
    "differenziertestem": "differenziert",
    "differenziertesten": "differenziert",
    "differenziertester": "differenziert",
    "differenziertestes": "differenziert",
    "differenziertet": "differenzieren",
    "differiere": "differieren",
    "differierend": "differieren",
    "differierende": "differierend",
    "differierendem": "differierend",
    "differierenden": "differierend",
    "differierender": "differierend",
    "differierendere": "differierend",
    "differierenderem": "differierend",
    "differierenderen": "differierend",
    "differierenderer": "differierend",
    "differierenderes": "differierend",
    "differierendes": "differierend",
    "differierendste": "differierend",
    "differierendstem": "differierend",
    "differierendsten": "differierend",
    "differierendster": "differierend",
    "differierendstes": "differierend",
    "differierest": "differieren",
    "differieret": "differieren",
    "differierst": "differieren",
    "differiert": "differieren",
    "differierte": "differieren",
    "differiertem": "differiert",
    "differierten": "differieren",
    "differierter": "differiert",
    "differiertes": "differiert",
    "differiertest": "differieren",
    "differiertet": "differieren",
    "diffizile": "diffizil",
    "diffizilem": "diffizil",
    "diffizilen": "diffizil",
    "diffiziler": "diffizil",
    "diffizilere": "diffizil",
    "diffizilerem": "diffizil",
    "diffizileren": "diffizil",
    "diffizilerer": "diffizil",
    "diffizileres": "diffizil",
    "diffiziles": "diffizil",
    "diffizilste": "diffizil",
    "diffizilstem": "diffizil",
    "diffizilsten": "diffizil",
    "diffizilster": "diffizil",
    "diffizilstes": "diffizil",
    "diffundiere": "diffundieren",
    "diffundierend": "diffundieren",
    "diffundierende": "diffundierend",
    "diffundierendem": "diffundierend",
    "diffundierenden": "diffundierend",
    "diffundierender": "diffundierend",
    "diffundierendes": "diffundierend",
    "diffundierest": "diffundieren",
    "diffundieret": "diffundieren",
    "diffundierst": "diffundieren",
    "diffundiert": "diffundieren",
    "diffundierte": "diffundieren",
    "diffundiertem": "diffundiert",
    "diffundierten": "diffundieren",
    "diffundierter": "diffundiert",
    "diffundiertes": "diffundiert",
    "diffundiertest": "diffundieren",
    "diffundiertet": "diffundieren",
    "diffuse": "diffus",
    "diffusem": "diffus",
    "diffusen": "diffus",
    "diffuser": "diffus",
    "diffusere": "diffus",
    "diffuserem": "diffus",
    "diffuseren": "diffus",
    "diffuserer": "diffus",
    "diffuseres": "diffus",
    "diffuses": "diffus",
    "diffuseste": "diffus",
    "diffusestem": "diffus",
    "diffusesten": "diffus",
    "diffusester": "diffus",
    "diffusestes": "diffus",
    "digitalem": "digital",
    "digitalen": "digital",
    "digitaler": "digital",
    "digitales": "digital",
    "diktatorischem": "diktatorisch",
    "diktatorischen": "diktatorisch",
    "diktatorischer": "diktatorisch",
    "diktatorisches": "diktatorisch",
    "diktiere": "diktieren",
    "diktierend": "diktieren",
    "diktierende": "diktierend",
    "diktierendem": "diktierend",
    "diktierenden": "diktierend",
    "diktierender": "diktierend",
    "diktierendes": "diktierend",
    "diktierest": "diktieren",
    "diktieret": "diktieren",
    "diktierst": "diktieren",
    "diktiert": "diktieren",
    "diktierte": "diktieren",
    "diktiertem": "diktiert",
    "diktierten": "diktieren",
    "diktierter": "diktiert",
    "diktiertes": "diktiert",
    "diktiertest": "diktieren",
    "diktiertet": "diktieren",
    "dilettantischem": "dilettantisch",
    "dilettantischen": "dilettantisch",
    "dilettantischer": "dilettantisch",
    "dilettantischere": "dilettantisch",
    "dilettantischerem": "dilettantisch",
    "dilettantischeren": "dilettantisch",
    "dilettantischerer": "dilettantisch",
    "dilettantischeres": "dilettantisch",
    "dilettantisches": "dilettantisch",
    "dilettantischste": "dilettantisch",
    "dilettantischstem": "dilettantisch",
    "dilettantischsten": "dilettantisch",
    "dilettantischster": "dilettantisch",
    "dilettantischstes": "dilettantisch",
    "dimensionale": "dimensional",
    "dimensionalem": "dimensional",
    "dimensionalen": "dimensional",
    "dimensionaler": "dimensional",
    "dimensionales": "dimensional",
    "dimensioniere": "dimensionieren",
    "dimensionierend": "dimensionieren",
    "dimensionierende": "dimensionierend",
    "dimensionierendem": "dimensionierend",
    "dimensionierenden": "dimensionierend",
    "dimensionierender": "dimensionierend",
    "dimensionierendes": "dimensionierend",
    "dimensionierest": "dimensionieren",
    "dimensionieret": "dimensionieren",
    "dimensionierst": "dimensionieren",
    "dimensioniert": "dimensionieren",
    "dimensionierte": "dimensionieren",
    "dimensioniertem": "dimensioniert",
    "dimensionierten": "dimensionieren",
    "dimensionierter": "dimensioniert",
    "dimensioniertes": "dimensioniert",
    "dimensioniertest": "dimensionieren",
    "dimensioniertet": "dimensionieren",
    "dingend": "dingen",
    "dingende": "dingend",
    "dingendem": "dingend",
    "dingenden": "dingend",
    "dingender": "dingend",
    "dingendes": "dingend",
    "dingest": "dingen",
    "dinget": "dingen",
    "dingst": "dingen",
    "dingt": "dingen",
    "diniere": "dinieren",
    "dinierend": "dinieren",
    "dinierende": "dinierend",
    "dinierendem": "dinierend",
    "dinierenden": "dinierend",
    "dinierender": "dinierend",
    "dinierendes": "dinierend",
    "dinierest": "dinieren",
    "dinieret": "dinieren",
    "dinierst": "dinieren",
    "diniert": "dinieren",
    "dinierte": "dinieren",
    "diniertem": "diniert",
    "dinierten": "dinieren",
    "dinierter": "diniert",
    "diniertes": "diniert",
    "diniertest": "dinieren",
    "diniertet": "dinieren",
    "diophantischem": "diophantisch",
    "diophantischen": "diophantisch",
    "diophantischer": "diophantisch",
    "diophantisches": "diophantisch",
    "diplomatischem": "diplomatisch",
    "diplomatischen": "diplomatisch",
    "diplomatischer": "diplomatisch",
    "diplomatischere": "diplomatisch",
    "diplomatischerem": "diplomatisch",
    "diplomatischeren": "diplomatisch",
    "diplomatischerer": "diplomatisch",
    "diplomatischeres": "diplomatisch",
    "diplomatisches": "diplomatisch",
    "diplomatischste": "diplomatisch",
    "diplomatischstem": "diplomatisch",
    "diplomatischsten": "diplomatisch",
    "diplomatischster": "diplomatisch",
    "diplomatischstes": "diplomatisch",
    "diplomatisiere": "diplomatisieren",
    "diplomatisierend": "diplomatisieren",
    "diplomatisierende": "diplomatisierend",
    "diplomatisierendem": "diplomatisierend",
    "diplomatisierenden": "diplomatisierend",
    "diplomatisierender": "diplomatisierend",
    "diplomatisierendes": "diplomatisierend",
    "diplomatisierest": "diplomatisieren",
    "diplomatisieret": "diplomatisieren",
    "diplomatisierst": "diplomatisieren",
    "diplomatisiert": "diplomatisieren",
    "diplomatisierte": "diplomatisieren",
    "diplomatisiertem": "diplomatisiert",
    "diplomatisierten": "diplomatisieren",
    "diplomatisierter": "diplomatisiert",
    "diplomatisiertes": "diplomatisiert",
    "diplomatisiertest": "diplomatisieren",
    "diplomatisiertet": "diplomatisieren",
    "diplomiere": "diplomieren",
    "diplomierend": "diplomieren",
    "diplomierende": "diplomierend",
    "diplomierendem": "diplomierend",
    "diplomierenden": "diplomierend",
    "diplomierender": "diplomierend",
    "diplomierendes": "diplomierend",
    "diplomierest": "diplomieren",
    "diplomieret": "diplomieren",
    "diplomierst": "diplomieren",
    "diplomiert": "diplomieren",
    "diplomierte": "diplomieren",
    "diplomiertem": "diplomiert",
    "diplomierten": "diplomieren",
    "diplomierter": "diplomiert",
    "diplomiertes": "diplomiert",
    "diplomiertest": "diplomieren",
    "diplomiertet": "diplomieren",
    "dippe": "dippen",
    "dippend": "dippen",
    "dippende": "dippend",
    "dippendem": "dippend",
    "dippenden": "dippend",
    "dippender": "dippend",
    "dippendes": "dippend",
    "dippest": "dippen",
    "dippet": "dippen",
    "dippst": "dippen",
    "dippt": "dippen",
    "dippte": "dippen",
    "dippten": "dippen",
    "dipptest": "dippen",
    "dipptet": "dippen",
    "dir": "sich",
    "direkte": "direkt",
    "direktem": "direkt",
    "direkten": "direkt",
    "direkter": "direkt",
    "direktere": "direkt",
    "direkterem": "direkt",
    "direkteren": "direkt",
    "direkterer": "direkt",
    "direkteres": "direkt",
    "direktes": "direkt",
    "direkteste": "direkt",
    "direktestem": "direkt",
    "direktesten": "direkt",
    "direktester": "direkt",
    "direktestes": "direkt",
    "direktivem": "direktiv",
    "direktiven": "direktiv",
    "direktiver": "direktiv",
    "direktives": "direktiv",
    "dirigiere": "dirigieren",
    "dirigierend": "dirigieren",
    "dirigierende": "dirigierend",
    "dirigierendem": "dirigierend",
    "dirigierenden": "dirigierend",
    "dirigierender": "dirigierend",
    "dirigierendes": "dirigierend",
    "dirigierest": "dirigieren",
    "dirigieret": "dirigieren",
    "dirigierst": "dirigieren",
    "dirigiert": "dirigieren",
    "dirigierte": "dirigieren",
    "dirigiertem": "dirigiert",
    "dirigierten": "dirigieren",
    "dirigierter": "dirigiert",
    "dirigiertes": "dirigiert",
    "dirigiertest": "dirigieren",
    "dirigiertet": "dirigieren",
    "dirigistische": "dirigistisch",
    "dirigistischem": "dirigistisch",
    "dirigistischen": "dirigistisch",
    "dirigistischer": "dirigistisch",
    "dirigistisches": "dirigistisch",
    "diskreditiere": "diskreditieren",
    "diskreditierend": "diskreditieren",
    "diskreditierende": "diskreditierend",
    "diskreditierendem": "diskreditierend",
    "diskreditierenden": "diskreditierend",
    "diskreditierender": "diskreditierend",
    "diskreditierendes": "diskreditierend",
    "diskreditierest": "diskreditieren",
    "diskreditieret": "diskreditieren",
    "diskreditierst": "diskreditieren",
    "diskreditiert": "diskreditieren",
    "diskreditierte": "diskreditieren",
    "diskreditiertem": "diskreditiert",
    "diskreditierten": "diskreditieren",
    "diskreditierter": "diskreditiert",
    "diskreditiertes": "diskreditiert",
    "diskreditiertest": "diskreditieren",
    "diskreditiertet": "diskreditieren",
    "diskretem": "diskret",
    "diskreten": "diskret",
    "diskreter": "diskret",
    "diskretes": "diskret",
    "diskriminiere": "diskriminieren",
    "diskriminierend": "diskriminieren",
    "diskriminierende": "diskriminierend",
    "diskriminierendem": "diskriminierend",
    "diskriminierenden": "diskriminierend",
    "diskriminierender": "diskriminierend",
    "diskriminierendere": "diskriminierend",
    "diskriminierenderem": "diskriminierend",
    "diskriminierenderen": "diskriminierend",
    "diskriminierenderer": "diskriminierend",
    "diskriminierenderes": "diskriminierend",
    "diskriminierendes": "diskriminierend",
    "diskriminierendste": "diskriminierend",
    "diskriminierendstem": "diskriminierend",
    "diskriminierendsten": "diskriminierend",
    "diskriminierendster": "diskriminierend",
    "diskriminierendstes": "diskriminierend",
    "diskriminierest": "diskriminieren",
    "diskriminieret": "diskriminieren",
    "diskriminierst": "diskriminieren",
    "diskriminiert": "diskriminieren",
    "diskriminierte": "diskriminieren",
    "diskriminiertem": "diskriminiert",
    "diskriminierten": "diskriminieren",
    "diskriminierter": "diskriminiert",
    "diskriminiertere": "diskriminiert",
    "diskriminierterem": "diskriminiert",
    "diskriminierteren": "diskriminiert",
    "diskriminierterer": "diskriminiert",
    "diskriminierteres": "diskriminiert",
    "diskriminiertes": "diskriminiert",
    "diskriminiertest": "diskriminieren",
    "diskriminiertestem": "diskriminiert",
    "diskriminiertesten": "diskriminiert",
    "diskriminiertester": "diskriminiert",
    "diskriminiertestes": "diskriminiert",
    "diskriminiertet": "diskriminieren",
    "diskutiere": "diskutieren",
    "diskutierend": "diskutieren",
    "diskutierende": "diskutierend",
    "diskutierendem": "diskutierend",
    "diskutierenden": "diskutierend",
    "diskutierender": "diskutierend",
    "diskutierendes": "diskutierend",
    "diskutierest": "diskutieren",
    "diskutieret": "diskutieren",
    "diskutierst": "diskutieren",
    "diskutiert": "diskutieren",
    "diskutierte": "diskutieren",
    "diskutiertem": "diskutiert",
    "diskutierten": "diskutieren",
    "diskutierter": "diskutiert",
    "diskutiertere": "diskutiert",
    "diskutierterem": "diskutiert",
    "diskutierteren": "diskutiert",
    "diskutierterer": "diskutiert",
    "diskutierteres": "diskutiert",
    "diskutiertes": "diskutiert",
    "diskutiertest": "diskutieren",
    "diskutierteste": "diskutiert",
    "diskutiertestem": "diskutiert",
    "diskutiertesten": "diskutiert",
    "diskutiertester": "diskutiert",
    "diskutiertestes": "diskutiert",
    "diskutiertet": "diskutieren",
    "disponiere": "disponieren",
    "disponierend": "disponieren",
    "disponierende": "disponierend",
    "disponierendem": "disponierend",
    "disponierenden": "disponierend",
    "disponierender": "disponierend",
    "disponierendes": "disponierend",
    "disponierest": "disponieren",
    "disponieret": "disponieren",
    "disponierst": "disponieren",
    "disponiert": "disponieren",
    "disponierte": "disponieren",
    "disponiertem": "disponiert",
    "disponierten": "disponieren",
    "disponierter": "disponiert",
    "disponiertes": "disponiert",
    "disponiertest": "disponieren",
    "disponiertet": "disponieren",
    "dispositionsfähigem": "dispositionsfähig",
    "dispositionsfähigen": "dispositionsfähig",
    "dispositionsfähiger": "dispositionsfähig",
    "dispositionsfähiges": "dispositionsfähig",
    "disqualifiziere": "disqualifizieren",
    "disqualifizierend": "disqualifizieren",
    "disqualifizierende": "disqualifizierend",
    "disqualifizierendem": "disqualifizierend",
    "disqualifizierenden": "disqualifizierend",
    "disqualifizierender": "disqualifizierend",
    "disqualifizierendes": "disqualifizierend",
    "disqualifizierest": "disqualifizieren",
    "disqualifizieret": "disqualifizieren",
    "disqualifizierst": "disqualifizieren",
    "disqualifiziert": "disqualifizieren",
    "disqualifizierte": "disqualifizieren",
    "disqualifiziertem": "disqualifiziert",
    "disqualifizierten": "disqualifizieren",
    "disqualifizierter": "disqualifiziert",
    "disqualifiziertes": "disqualifiziert",
    "disqualifiziertest": "disqualifizieren",
    "disqualifiziertet": "disqualifizieren",
    "dissertiere": "dissertieren",
    "dissertierend": "dissertieren",
    "dissertierende": "dissertierend",
    "dissertierendem": "dissertierend",
    "dissertierenden": "dissertierend",
    "dissertierender": "dissertierend",
    "dissertierendes": "dissertierend",
    "dissertierest": "dissertieren",
    "dissertieret": "dissertieren",
    "dissertierst": "dissertieren",
    "dissertiert": "dissertieren",
    "dissertierte": "dissertieren",
    "dissertiertem": "dissertiert",
    "dissertierten": "dissertieren",
    "dissertierter": "dissertiert",
    "dissertiertes": "dissertiert",
    "dissertiertest": "dissertieren",
    "dissertiertet": "dissertieren",
    "dissidiere": "dissidieren",
    "dissidierend": "dissidieren",
    "dissidierende": "dissidierend",
    "dissidierendem": "dissidierend",
    "dissidierenden": "dissidierend",
    "dissidierender": "dissidierend",
    "dissidierendes": "dissidierend",
    "dissidierest": "dissidieren",
    "dissidieret": "dissidieren",
    "dissidierst": "dissidieren",
    "dissidiert": "dissidieren",
    "dissidierte": "dissidieren",
    "dissidiertem": "dissidiert",
    "dissidierten": "dissidieren",
    "dissidierter": "dissidiert",
    "dissidiertes": "dissidiert",
    "dissidiertest": "dissidieren",
    "dissidiertet": "dissidieren",
    "dissonantem": "dissonant",
    "dissonanten": "dissonant",
    "dissonanter": "dissonant",
    "dissonantes": "dissonant",
    "distanziere": "distanzieren",
    "distanzierend": "distanzieren",
    "distanzierende": "distanzierend",
    "distanzierendem": "distanzierend",
    "distanzierenden": "distanzierend",
    "distanzierender": "distanzierend",
    "distanzierendere": "distanzierend",
    "distanzierenderem": "distanzierend",
    "distanzierenderen": "distanzierend",
    "distanzierenderer": "distanzierend",
    "distanzierenderes": "distanzierend",
    "distanzierendes": "distanzierend",
    "distanzierendste": "distanzierend",
    "distanzierendstem": "distanzierend",
    "distanzierendsten": "distanzierend",
    "distanzierendster": "distanzierend",
    "distanzierendstes": "distanzierend",
    "distanzierest": "distanzieren",
    "distanzieret": "distanzieren",
    "distanzierst": "distanzieren",
    "distanziert": "distanzieren",
    "distanzierte": "distanzieren",
    "distanziertem": "distanziert",
    "distanzierten": "distanzieren",
    "distanzierter": "distanziert",
    "distanziertere": "distanziert",
    "distanzierterem": "distanziert",
    "distanzierteren": "distanziert",
    "distanzierterer": "distanziert",
    "distanzierteres": "distanziert",
    "distanziertes": "distanziert",
    "distanziertest": "distanzieren",
    "distanzierteste": "distanziert",
    "distanziertestem": "distanziert",
    "distanziertesten": "distanziert",
    "distanziertester": "distanziert",
    "distanziertestes": "distanziert",
    "distanziertet": "distanzieren",
    "disziplinarischem": "disziplinarisch",
    "disziplinarischen": "disziplinarisch",
    "disziplinarischer": "disziplinarisch",
    "disziplinarischere": "disziplinarisch",
    "disziplinarischerem": "disziplinarisch",
    "disziplinarischeren": "disziplinarisch",
    "disziplinarischerer": "disziplinarisch",
    "disziplinarischeres": "disziplinarisch",
    "disziplinarisches": "disziplinarisch",
    "disziplinarischste": "disziplinarisch",
    "disziplinarischstem": "disziplinarisch",
    "disziplinarischsten": "disziplinarisch",
    "disziplinarischster": "disziplinarisch",
    "disziplinarischstes": "disziplinarisch",
    "diszipliniertem": "diszipliniert",
    "disziplinierten": "diszipliniert",
    "disziplinierter": "diszipliniert",
    "diszipliniertere": "diszipliniert",
    "disziplinierterem": "diszipliniert",
    "disziplinierteren": "diszipliniert",
    "disziplinierterer": "diszipliniert",
    "disziplinierteres": "diszipliniert",
    "diszipliniertes": "diszipliniert",
    "disziplinierteste": "diszipliniert",
    "diszipliniertestem": "diszipliniert",
    "diszipliniertesten": "diszipliniert",
    "diszipliniertester": "diszipliniert",
    "diszipliniertestes": "diszipliniert",
    "disziplinlose": "disziplinlos",
    "disziplinlosem": "disziplinlos",
    "disziplinlosen": "disziplinlos",
    "disziplinloser": "disziplinlos",
    "disziplinlosere": "disziplinlos",
    "disziplinloserem": "disziplinlos",
    "disziplinloseren": "disziplinlos",
    "disziplinloserer": "disziplinlos",
    "disziplinloseres": "disziplinlos",
    "disziplinloses": "disziplinlos",
    "disziplinloseste": "disziplinlos",
    "disziplinlosestem": "disziplinlos",
    "disziplinlosesten": "disziplinlos",
    "disziplinlosester": "disziplinlos",
    "disziplinlosestes": "disziplinlos",
    "disziplinärem": "disziplinär",
    "disziplinären": "disziplinär",
    "disziplinärer": "disziplinär",
    "disziplinäres": "disziplinär",
    "divergentem": "divergent",
    "divergenten": "divergent",
    "divergenter": "divergent",
    "divergentere": "divergent",
    "divergenterem": "divergent",
    "divergenteren": "divergent",
    "divergenterer": "divergent",
    "divergenteres": "divergent",
    "divergentes": "divergent",
    "divergenteste": "divergent",
    "divergentestem": "divergent",
    "divergentesten": "divergent",
    "divergentester": "divergent",
    "divergentestes": "divergent",
    "diverse": "divers",
    "diversem": "divers",
    "diversen": "divers",
    "diverser": "divers",
    "diverses": "divers",
    "docke": "docken",
    "dockend": "docken",
    "dockende": "dockend",
    "dockendem": "dockend",
    "dockenden": "dockend",
    "dockender": "dockend",
    "dockendes": "dockend",
    "dockest": "docken",
    "docket": "docken",
    "dockst": "docken",
    "dockt": "docken",
    "dockte": "docken",
    "dockten": "docken",
    "docktest": "docken",
    "docktet": "docken",
    "dogmatischem": "dogmatisch",
    "dogmatischen": "dogmatisch",
    "dogmatischer": "dogmatisch",
    "dogmatischere": "dogmatisch",
    "dogmatischerem": "dogmatisch",
    "dogmatischeren": "dogmatisch",
    "dogmatischerer": "dogmatisch",
    "dogmatischeres": "dogmatisch",
    "dogmatisches": "dogmatisch",
    "dogmatischste": "dogmatisch",
    "dogmatischstem": "dogmatisch",
    "dogmatischsten": "dogmatisch",
    "dogmatischster": "dogmatisch",
    "dogmatischstes": "dogmatisch",
    "dogmatisiere": "dogmatisieren",
    "dogmatisierend": "dogmatisieren",
    "dogmatisierende": "dogmatisierend",
    "dogmatisierendem": "dogmatisierend",
    "dogmatisierenden": "dogmatisierend",
    "dogmatisierender": "dogmatisierend",
    "dogmatisierendes": "dogmatisierend",
    "dogmatisierest": "dogmatisieren",
    "dogmatisieret": "dogmatisieren",
    "dogmatisierst": "dogmatisieren",
    "dogmatisiert": "dogmatisieren",
    "dogmatisierte": "dogmatisieren",
    "dogmatisiertem": "dogmatisiert",
    "dogmatisierten": "dogmatisieren",
    "dogmatisierter": "dogmatisiert",
    "dogmatisiertes": "dogmatisiert",
    "dogmatisiertest": "dogmatisieren",
    "dogmatisiertet": "dogmatisieren",
    "doktere": "doktern",
    "dokternd": "doktern",
    "dokternde": "dokternd",
    "dokterndem": "dokternd",
    "dokternden": "dokternd",
    "dokternder": "dokternd",
    "dokterndere": "dokternd",
    "dokternderem": "dokternd",
    "dokternderen": "dokternd",
    "dokternderer": "dokternd",
    "dokternderes": "dokternd",
    "dokterndes": "dokternd",
    "dokterndste": "dokternd",
    "dokterndstem": "dokternd",
    "dokterndsten": "dokternd",
    "dokterndster": "dokternd",
    "dokterndstes": "dokternd",
    "dokterst": "doktern",
    "doktert": "doktern",
    "dokterte": "doktern",
    "dokterten": "doktern",
    "doktertest": "doktern",
    "doktertet": "doktern",
    "doktoriere": "doktorieren",
    "doktorierend": "doktorieren",
    "doktorierende": "doktorierend",
    "doktorierendem": "doktorierend",
    "doktorierenden": "doktorierend",
    "doktorierender": "doktorierend",
    "doktorierendes": "doktorierend",
    "doktorierest": "doktorieren",
    "doktorieret": "doktorieren",
    "doktorierst": "doktorieren",
    "doktoriert": "doktorieren",
    "doktorierte": "doktorieren",
    "doktoriertem": "doktoriert",
    "doktorierten": "doktorieren",
    "doktorierter": "doktoriert",
    "doktoriertes": "doktoriert",
    "doktoriertest": "doktorieren",
    "doktoriertet": "doktorieren",
    "dokumentarischem": "dokumentarisch",
    "dokumentarischen": "dokumentarisch",
    "dokumentarischer": "dokumentarisch",
    "dokumentarisches": "dokumentarisch",
    "dokumentiere": "dokumentieren",
    "dokumentierend": "dokumentieren",
    "dokumentierende": "dokumentierend",
    "dokumentierendem": "dokumentierend",
    "dokumentierenden": "dokumentierend",
    "dokumentierender": "dokumentierend",
    "dokumentierendes": "dokumentierend",
    "dokumentierest": "dokumentieren",
    "dokumentieret": "dokumentieren",
    "dokumentierst": "dokumentieren",
    "dokumentiert": "dokumentieren",
    "dokumentierte": "dokumentieren",
    "dokumentiertem": "dokumentiert",
    "dokumentierten": "dokumentieren",
    "dokumentierter": "dokumentiert",
    "dokumentiertere": "dokumentiert",
    "dokumentierterem": "dokumentiert",
    "dokumentierteren": "dokumentiert",
    "dokumentierterer": "dokumentiert",
    "dokumentierteres": "dokumentiert",
    "dokumentiertes": "dokumentiert",
    "dokumentiertest": "dokumentieren",
    "dokumentierteste": "dokumentiert",
    "dokumentiertestem": "dokumentiert",
    "dokumentiertesten": "dokumentiert",
    "dokumentiertester": "dokumentiert",
    "dokumentiertestes": "dokumentiert",
    "dokumentiertet": "dokumentieren",
    "dollem": "doll",
    "dollen": "doll",
    "doller": "doll",
    "dollere": "doll",
    "dollerem": "doll",
    "dolleren": "doll",
    "dollerer": "doll",
    "dolleres": "doll",
    "dolles": "doll",
    "dollstem": "doll",
    "dollsten": "doll",
    "dollster": "doll",
    "dollstes": "doll",
    "dolmetsche": "dolmetschen",
    "dolmetschend": "dolmetschen",
    "dolmetschende": "dolmetschend",
    "dolmetschendem": "dolmetschend",
    "dolmetschenden": "dolmetschend",
    "dolmetschender": "dolmetschend",
    "dolmetschendes": "dolmetschend",
    "dolmetschest": "dolmetschen",
    "dolmetschet": "dolmetschen",
    "dolmetschst": "dolmetschen",
    "dolmetscht": "dolmetschen",
    "dolmetschte": "dolmetschen",
    "dolmetschten": "dolmetschen",
    "dolmetschtest": "dolmetschen",
    "dolmetschtet": "dolmetschen",
    "domestiziere": "domestizieren",
    "domestizierend": "domestizieren",
    "domestizierende": "domestizierend",
    "domestizierendem": "domestizierend",
    "domestizierenden": "domestizierend",
    "domestizierender": "domestizierend",
    "domestizierendes": "domestizierend",
    "domestizierest": "domestizieren",
    "domestizieret": "domestizieren",
    "domestizierst": "domestizieren",
    "domestiziert": "domestizieren",
    "domestizierte": "domestizieren",
    "domestiziertem": "domestiziert",
    "domestizierten": "domestizieren",
    "domestizierter": "domestiziert",
    "domestiziertes": "domestiziert",
    "domestiziertest": "domestizieren",
    "domestiziertet": "domestizieren",
    "dominante": "dominant",
    "dominantem": "dominant",
    "dominanten": "dominant",
    "dominanter": "dominant",
    "dominantere": "dominant",
    "dominanterem": "dominant",
    "dominanteren": "dominant",
    "dominanterer": "dominant",
    "dominanteres": "dominant",
    "dominantes": "dominant",
    "dominanteste": "dominant",
    "dominantestem": "dominant",
    "dominantesten": "dominant",
    "dominantester": "dominant",
    "dominantestes": "dominant",
    "dominiere": "dominieren",
    "dominierend": "dominieren",
    "dominierende": "dominierend",
    "dominierendem": "dominierend",
    "dominierenden": "dominierend",
    "dominierender": "dominierend",
    "dominierendere": "dominierend",
    "dominierenderem": "dominierend",
    "dominierenderen": "dominierend",
    "dominierenderer": "dominierend",
    "dominierenderes": "dominierend",
    "dominierendes": "dominierend",
    "dominierendste": "dominierend",
    "dominierendstem": "dominierend",
    "dominierendsten": "dominierend",
    "dominierendster": "dominierend",
    "dominierendstes": "dominierend",
    "dominierest": "dominieren",
    "dominieret": "dominieren",
    "dominierst": "dominieren",
    "dominiert": "dominieren",
    "dominierte": "dominieren",
    "dominiertem": "dominiert",
    "dominierten": "dominieren",
    "dominierter": "dominiert",
    "dominiertere": "dominiert",
    "dominierterem": "dominiert",
    "dominierteren": "dominiert",
    "dominierterer": "dominiert",
    "dominierteres": "dominiert",
    "dominiertes": "dominiert",
    "dominiertest": "dominieren",
    "dominierteste": "dominiert",
    "dominiertestem": "dominiert",
    "dominiertesten": "dominiert",
    "dominiertester": "dominiert",
    "dominiertestes": "dominiert",
    "dominiertet": "dominieren",
    "donnere": "donnern",
    "donnernd": "donnern",
    "donnernde": "donnernd",
    "donnerndem": "donnernd",
    "donnernden": "donnernd",
    "donnernder": "donnernd",
    "donnerndere": "donnernd",
    "donnernderem": "donnernd",
    "donnernderen": "donnernd",
    "donnernderer": "donnernd",
    "donnernderes": "donnernd",
    "donnerndes": "donnernd",
    "donnerndste": "donnernd",
    "donnerndstem": "donnernd",
    "donnerndsten": "donnernd",
    "donnerndster": "donnernd",
    "donnerndstes": "donnernd",
    "donnerst": "donnern",
    "donnert": "donnern",
    "donnerte": "donnern",
    "donnerten": "donnern",
    "donnertest": "donnern",
    "donnertet": "donnern",
    "doofem": "doof",
    "doofen": "doof",
    "doofer": "doof",
    "doofere": "doof",
    "dooferem": "doof",
    "dooferen": "doof",
    "dooferer": "doof",
    "dooferes": "doof",
    "doofes": "doof",
    "doofste": "doof",
    "doofstem": "doof",
    "doofsten": "doof",
    "doofster": "doof",
    "doofstes": "doof",
    "dope": "dopen",
    "dopend": "dopen",
    "dopende": "dopend",
    "dopendem": "dopend",
    "dopenden": "dopend",
    "dopender": "dopend",
    "dopendes": "dopend",
    "dopest": "dopen",
    "dopet": "dopen",
    "doppeldeutigem": "doppeldeutig",
    "doppeldeutigen": "doppeldeutig",
    "doppeldeutiger": "doppeldeutig",
    "doppeldeutigere": "doppeldeutig",
    "doppeldeutigerem": "doppeldeutig",
    "doppeldeutigeren": "doppeldeutig",
    "doppeldeutigerer": "doppeldeutig",
    "doppeldeutigeres": "doppeldeutig",
    "doppeldeutiges": "doppeldeutig",
    "doppeldeutigstem": "doppeldeutig",
    "doppeldeutigsten": "doppeldeutig",
    "doppeldeutigster": "doppeldeutig",
    "doppeldeutigstes": "doppeldeutig",
    "doppele": "doppeln",
    "doppelläufigem": "doppelläufig",
    "doppelläufigen": "doppelläufig",
    "doppelläufiger": "doppelläufig",
    "doppelläufiges": "doppelläufig",
    "doppelnd": "doppeln",
    "doppelnde": "doppelnd",
    "doppelndem": "doppelnd",
    "doppelnden": "doppelnd",
    "doppelnder": "doppelnd",
    "doppelndere": "doppelnd",
    "doppelnderem": "doppelnd",
    "doppelnderen": "doppelnd",
    "doppelnderer": "doppelnd",
    "doppelnderes": "doppelnd",
    "doppelndes": "doppelnd",
    "doppelndste": "doppelnd",
    "doppelndstem": "doppelnd",
    "doppelndsten": "doppelnd",
    "doppelndster": "doppelnd",
    "doppelndstes": "doppelnd",
    "doppelseitigem": "doppelseitig",
    "doppelseitigen": "doppelseitig",
    "doppelseitiger": "doppelseitig",
    "doppelseitiges": "doppelseitig",
    "doppelsinnige": "doppelsinnig",
    "doppelsinnigem": "doppelsinnig",
    "doppelsinnigen": "doppelsinnig",
    "doppelsinniger": "doppelsinnig",
    "doppelsinniges": "doppelsinnig",
    "doppelst": "doppeln",
    "doppelt": "doppeln",
    "doppelte": "doppeln",
    "doppeltem": "doppelt",
    "doppelten": "doppeln",
    "doppelter": "doppelt",
    "doppeltere": "doppelt",
    "doppelterem": "doppelt",
    "doppelteren": "doppelt",
    "doppelterer": "doppelt",
    "doppelteres": "doppelt",
    "doppeltes": "doppelt",
    "doppeltest": "doppeln",
    "doppelteste": "doppelt",
    "doppeltestem": "doppelt",
    "doppeltesten": "doppelt",
    "doppeltester": "doppelt",
    "doppeltestes": "doppelt",
    "doppeltet": "doppeln",
    "doppelwandige": "doppelwandig",
    "doppelwandigem": "doppelwandig",
    "doppelwandigen": "doppelwandig",
    "doppelwandiger": "doppelwandig",
    "doppelwandiges": "doppelwandig",
    "doppelzüngigem": "doppelzüngig",
    "doppelzüngigen": "doppelzüngig",
    "doppelzüngiger": "doppelzüngig",
    "doppelzüngigere": "doppelzüngig",
    "doppelzüngigerem": "doppelzüngig",
    "doppelzüngigeren": "doppelzüngig",
    "doppelzüngigerer": "doppelzüngig",
    "doppelzüngigeres": "doppelzüngig",
    "doppelzüngiges": "doppelzüngig",
    "doppelzüngigste": "doppelzüngig",
    "doppelzüngigstem": "doppelzüngig",
    "doppelzüngigsten": "doppelzüngig",
    "doppelzüngigster": "doppelzüngig",
    "doppelzüngigstes": "doppelzüngig",
    "dopple": "doppeln",
    "dopst": "dopen",
    "dopt": "dopen",
    "dopte": "dopen",
    "dopten": "dopen",
    "doptest": "dopen",
    "doptet": "dopen",
    "dornigem": "dornig",
    "dornigen": "dornig",
    "dorniger": "dornig",
    "dornigere": "dornig",
    "dornigerem": "dornig",
    "dornigeren": "dornig",
    "dornigerer": "dornig",
    "dornigeres": "dornig",
    "dorniges": "dornig",
    "dornigstem": "dornig",
    "dornigsten": "dornig",
    "dornigster": "dornig",
    "dornigstes": "dornig",
    "dortige": "dortig",
    "dortigem": "dortig",
    "dortigen": "dortig",
    "dortiger": "dortig",
    "dortiges": "dortig",
    "dosend": "dosen",
    "dosende": "dosend",
    "dosendem": "dosend",
    "dosenden": "dosend",
    "dosender": "dosend",
    "dosendes": "dosend",
    "dosest": "dosen",
    "doset": "dosen",
    "dosiere": "dosieren",
    "dosierend": "dosieren",
    "dosierende": "dosierend",
    "dosierendem": "dosierend",
    "dosierenden": "dosierend",
    "dosierender": "dosierend",
    "dosierendere": "dosierend",
    "dosierenderem": "dosierend",
    "dosierenderen": "dosierend",
    "dosierenderer": "dosierend",
    "dosierenderes": "dosierend",
    "dosierendes": "dosierend",
    "dosierendste": "dosierend",
    "dosierendstem": "dosierend",
    "dosierendsten": "dosierend",
    "dosierendster": "dosierend",
    "dosierendstes": "dosierend",
    "dosierest": "dosieren",
    "dosieret": "dosieren",
    "dosierst": "dosieren",
    "dosiert": "dosieren",
    "dosierte": "dosieren",
    "dosiertem": "dosiert",
    "dosierten": "dosieren",
    "dosierter": "dosiert",
    "dosiertere": "dosiert",
    "dosierterem": "dosiert",
    "dosierteren": "dosiert",
    "dosierterer": "dosiert",
    "dosierteres": "dosiert",
    "dosiertes": "dosiert",
    "dosiertest": "dosieren",
    "dosierteste": "dosiert",
    "dosiertestem": "dosiert",
    "dosiertesten": "dosiert",
    "dosiertester": "dosiert",
    "dosiertestes": "dosiert",
    "dosiertet": "dosieren",
    "dost": "dosen",
    "doste": "dosen",
    "dosten": "dosen",
    "dostest": "dosen",
    "dostet": "dosen",
    "dotiere": "dotieren",
    "dotierend": "dotieren",
    "dotierende": "dotierend",
    "dotierendem": "dotierend",
    "dotierenden": "dotierend",
    "dotierender": "dotierend",
    "dotierendes": "dotierend",
    "dotierest": "dotieren",
    "dotieret": "dotieren",
    "dotierst": "dotieren",
    "dotiert": "dotieren",
    "dotierte": "dotieren",
    "dotiertem": "dotiert",
    "dotierten": "dotieren",
    "dotierter": "dotiert",
    "dotiertes": "dotiert",
    "dotiertest": "dotieren",
    "dotiertet": "dotieren",
    "doubele": "doubeln",
    "doubelnd": "doubeln",
    "doubelnde": "doubelnd",
    "doubelndem": "doubelnd",
    "doubelnden": "doubelnd",
    "doubelnder": "doubelnd",
    "doubelndes": "doubelnd",
    "doubelst": "doubeln",
    "doubelt": "doubeln",
    "doubelte": "doubeln",
    "doubelten": "doubeln",
    "doubeltest": "doubeln",
    "doubeltet": "doubeln",
    "double": "doubeln",
    "doziere": "dozieren",
    "dozierend": "dozieren",
    "dozierende": "dozierend",
    "dozierendem": "dozierend",
    "dozierenden": "dozierend",
    "dozierender": "dozierend",
    "dozierendes": "dozierend",
    "dozierest": "dozieren",
    "dozieret": "dozieren",
    "dozierst": "dozieren",
    "doziert": "dozieren",
    "dozierte": "dozieren",
    "doziertem": "doziert",
    "dozierten": "dozieren",
    "dozierter": "doziert",
    "doziertes": "doziert",
    "doziertest": "dozieren",
    "doziertet": "dozieren",
    "drahtend": "drahten",
    "drahtende": "drahtend",
    "drahtendem": "drahtend",
    "drahtenden": "drahtend",
    "drahtender": "drahtend",
    "drahtendes": "drahtend",
    "drahtest": "drahten",
    "drahtet": "drahten",
    "drahtete": "drahten",
    "drahteten": "drahten",
    "drahtetest": "drahten",
    "drahtetet": "drahten",
    "drahtige": "drahtig",
    "drahtigem": "drahtig",
    "drahtigen": "drahtig",
    "drahtiger": "drahtig",
    "drahtigere": "drahtig",
    "drahtigerem": "drahtig",
    "drahtigeren": "drahtig",
    "drahtigerer": "drahtig",
    "drahtigeres": "drahtig",
    "drahtiges": "drahtig",
    "drahtigste": "drahtig",
    "drahtigstem": "drahtig",
    "drahtigsten": "drahtig",
    "drahtigster": "drahtig",
    "drahtigstes": "drahtig",
    "drahtlosem": "drahtlos",
    "drahtlosen": "drahtlos",
    "drahtloser": "drahtlos",
    "drahtlosere": "drahtlos",
    "drahtloserem": "drahtlos",
    "drahtloseren": "drahtlos",
    "drahtloserer": "drahtlos",
    "drahtloseres": "drahtlos",
    "drahtloses": "drahtlos",
    "drahtloseste": "drahtlos",
    "drahtlosestem": "drahtlos",
    "drahtlosesten": "drahtlos",
    "drahtlosester": "drahtlos",
    "drahtlosestes": "drahtlos",
    "dramatischem": "dramatisch",
    "dramatischen": "dramatisch",
    "dramatischer": "dramatisch",
    "dramatischere": "dramatisch",
    "dramatischerem": "dramatisch",
    "dramatischeren": "dramatisch",
    "dramatischerer": "dramatisch",
    "dramatischeres": "dramatisch",
    "dramatisches": "dramatisch",
    "dramatischste": "dramatisch",
    "dramatischstem": "dramatisch",
    "dramatischsten": "dramatisch",
    "dramatischster": "dramatisch",
    "dramatischstes": "dramatisch",
    "dramatisiere": "dramatisieren",
    "dramatisierend": "dramatisieren",
    "dramatisierende": "dramatisierend",
    "dramatisierendem": "dramatisierend",
    "dramatisierenden": "dramatisierend",
    "dramatisierender": "dramatisierend",
    "dramatisierendere": "dramatisierend",
    "dramatisierenderem": "dramatisierend",
    "dramatisierenderen": "dramatisierend",
    "dramatisierenderer": "dramatisierend",
    "dramatisierenderes": "dramatisierend",
    "dramatisierendes": "dramatisierend",
    "dramatisierendste": "dramatisierend",
    "dramatisierendstem": "dramatisierend",
    "dramatisierendsten": "dramatisierend",
    "dramatisierendster": "dramatisierend",
    "dramatisierendstes": "dramatisierend",
    "dramatisierest": "dramatisieren",
    "dramatisieret": "dramatisieren",
    "dramatisierst": "dramatisieren",
    "dramatisiert": "dramatisieren",
    "dramatisierte": "dramatisieren",
    "dramatisiertem": "dramatisiert",
    "dramatisierten": "dramatisieren",
    "dramatisierter": "dramatisiert",
    "dramatisiertere": "dramatisiert",
    "dramatisierterem": "dramatisiert",
    "dramatisierteren": "dramatisiert",
    "dramatisierterer": "dramatisiert",
    "dramatisierteres": "dramatisiert",
    "dramatisiertes": "dramatisiert",
    "dramatisiertest": "dramatisieren",
    "dramatisierteste": "dramatisiert",
    "dramatisiertestem": "dramatisiert",
    "dramatisiertesten": "dramatisiert",
    "dramatisiertester": "dramatisiert",
    "dramatisiertestes": "dramatisiert",
    "dramatisiertet": "dramatisieren",
    "dranbleibe": "dranbleiben",
    "dranbleibend": "dranbleiben",
    "dranbleibende": "dranbleibend",
    "dranbleibendem": "dranbleibend",
    "dranbleibenden": "dranbleibend",
    "dranbleibender": "dranbleibend",
    "dranbleibendes": "dranbleibend",
    "dranbleibest": "dranbleiben",
    "dranbleibet": "dranbleiben",
    "dranbleibst": "dranbleiben",
    "dranbleibt": "dranbleiben",
    "dranblieb": "dranbleiben",
    "dranbliebe": "dranbleiben",
    "dranblieben": "dranbleiben",
    "dranbliebest": "dranbleiben",
    "dranbliebet": "dranbleiben",
    "dranbliebst": "dranbleiben",
    "dranbliebt": "dranbleiben",
    "drang": "dringen",
    "drangab": "drangeben",
    "drangaben": "drangeben",
    "drangabst": "drangeben",
    "drangabt": "drangeben",
    "drangebe": "drangeben",
    "drangebend": "drangeben",
    "drangebende": "drangebend",
    "drangebendem": "drangebend",
    "drangebenden": "drangebend",
    "drangebender": "drangebend",
    "drangebendes": "drangebend",
    "drangebest": "drangeben",
    "drangebet": "drangeben",
    "drangeblieben": "dranbleiben",
    "drangebliebene": "drangeblieben",
    "drangebliebenem": "drangeblieben",
    "drangebliebenen": "drangeblieben",
    "drangebliebener": "drangeblieben",
    "drangebliebenes": "drangeblieben",
    "drangebt": "drangeben",
    "drangegeben": "drangeben",
    "drangegebene": "drangegeben",
    "drangegebenem": "drangegeben",
    "drangegebenen": "drangegeben",
    "drangegebener": "drangegeben",
    "drangegebenes": "drangegeben",
    "drangeklebt": "drankleben",
    "drangeklebte": "drangeklebt",
    "drangeklebtem": "drangeklebt",
    "drangeklebten": "drangeklebt",
    "drangeklebter": "drangeklebt",
    "drangeklebtes": "drangeklebt",
    "drangekommen": "drankommen",
    "drangekommene": "drangekommen",
    "drangekommenem": "drangekommen",
    "drangekommenen": "drangekommen",
    "drangekommener": "drangekommen",
    "drangekommenes": "drangekommen",
    "drangekriegt": "drankriegen",
    "drangekriegte": "drangekriegt",
    "drangekriegtem": "drangekriegt",
    "drangekriegten": "drangekriegt",
    "drangekriegter": "drangekriegt",
    "drangekriegtes": "drangekriegt",
    "drangemacht": "dranmachen",
    "drangemachte": "drangemacht",
    "drangemachtem": "drangemacht",
    "drangemachten": "drangemacht",
    "drangemachter": "drangemacht",
    "drangemachtes": "drangemacht",
    "drangen": "dringen",
    "drangenommen": "drannehmen",
    "drangenommene": "drangenommen",
    "drangenommenem": "drangenommen",
    "drangenommenen": "drangenommen",
    "drangenommener": "drangenommen",
    "drangenommenes": "drangenommen",
    "drangesetzt": "dransetzen",
    "drangesetzte": "drangesetzt",
    "drangesetztem": "drangesetzt",
    "drangesetzten": "drangesetzt",
    "drangesetzter": "drangesetzt",
    "drangesetztes": "drangesetzt",
    "drangibst": "drangeben",
    "drangibt": "drangeben",
    "drangsalierend": "drangsalieren",
    "drangsalierende": "drangsalierend",
    "drangsalierendem": "drangsalierend",
    "drangsalierenden": "drangsalierend",
    "drangsalierender": "drangsalierend",
    "drangsalierendere": "drangsalierend",
    "drangsalierenderem": "drangsalierend",
    "drangsalierenderen": "drangsalierend",
    "drangsalierenderer": "drangsalierend",
    "drangsalierenderes": "drangsalierend",
    "drangsalierendes": "drangsalierend",
    "drangsalierendste": "drangsalierend",
    "drangsalierendstem": "drangsalierend",
    "drangsalierendsten": "drangsalierend",
    "drangsalierendster": "drangsalierend",
    "drangsalierendstes": "drangsalierend",
    "drangsalierest": "drangsalieren",
    "drangsalieret": "drangsalieren",
    "drangsalierst": "drangsalieren",
    "drangsaliert": "drangsalieren",
    "drangsalierte": "drangsalieren",
    "drangsaliertem": "drangsaliert",
    "drangsalierten": "drangsalieren",
    "drangsalierter": "drangsaliert",
    "drangsaliertere": "drangsaliert",
    "drangsalierterem": "drangsaliert",
    "drangsalierteren": "drangsaliert",
    "drangsalierterer": "drangsaliert",
    "drangsalierteres": "drangsaliert",
    "drangsaliertes": "drangsaliert",
    "drangsaliertest": "drangsalieren",
    "drangsalierteste": "drangsaliert",
    "drangsaliertestem": "drangsaliert",
    "drangsaliertesten": "drangsaliert",
    "drangsaliertester": "drangsaliert",
    "drangsaliertestes": "drangsaliert",
    "drangsaliertet": "drangsalieren",
    "drangst": "dringen",
    "drangt": "dringen",
    "drangvolle": "drangvoll",
    "drangvollem": "drangvoll",
    "drangvollen": "drangvoll",
    "drangvoller": "drangvoll",
    "drangvollere": "drangvoll",
    "drangvollerem": "drangvoll",
    "drangvolleren": "drangvoll",
    "drangvollerer": "drangvoll",
    "drangvolleres": "drangvoll",
    "drangvolles": "drangvoll",
    "drangvollste": "drangvoll",
    "drangvollstem": "drangvoll",
    "drangvollsten": "drangvoll",
    "drangvollster": "drangvoll",
    "drangvollstes": "drangvoll",
    "drangäbe": "drangeben",
    "drangäben": "drangeben",
    "drangäbest": "drangeben",
    "drangäbet": "drangeben",
    "drankam": "drankommen",
    "drankamen": "drankommen",
    "drankamst": "drankommen",
    "drankamt": "drankommen",
    "dranklebe": "drankleben",
    "dranklebend": "drankleben",
    "dranklebende": "dranklebend",
    "dranklebendem": "dranklebend",
    "dranklebenden": "dranklebend",
    "dranklebender": "dranklebend",
    "dranklebendere": "dranklebend",
    "dranklebenderem": "dranklebend",
    "dranklebenderen": "dranklebend",
    "dranklebenderer": "dranklebend",
    "dranklebenderes": "dranklebend",
    "dranklebendes": "dranklebend",
    "dranklebendste": "dranklebend",
    "dranklebendstem": "dranklebend",
    "dranklebendsten": "dranklebend",
    "dranklebendster": "dranklebend",
    "dranklebendstes": "dranklebend",
    "dranklebest": "drankleben",
    "dranklebet": "drankleben",
    "dranklebst": "drankleben",
    "dranklebt": "drankleben",
    "dranklebte": "drankleben",
    "dranklebten": "drankleben",
    "dranklebtest": "drankleben",
    "dranklebtet": "drankleben",
    "drankomme": "drankommen",
    "drankommend": "drankommen",
    "drankommende": "drankommend",
    "drankommendem": "drankommend",
    "drankommenden": "drankommend",
    "drankommender": "drankommend",
    "drankommendes": "drankommend",
    "drankommest": "drankommen",
    "drankommet": "drankommen",
    "drankommst": "drankommen",
    "drankommt": "drankommen",
    "drankriege": "drankriegen",
    "drankriegend": "drankriegen",
    "drankriegende": "drankriegend",
    "drankriegendem": "drankriegend",
    "drankriegenden": "drankriegend",
    "drankriegender": "drankriegend",
    "drankriegendes": "drankriegend",
    "drankriegest": "drankriegen",
    "drankrieget": "drankriegen",
    "drankriegst": "drankriegen",
    "drankriegt": "drankriegen",
    "drankriegte": "drankriegen",
    "drankriegten": "drankriegen",
    "drankriegtest": "drankriegen",
    "drankriegtet": "drankriegen",
    "drankäme": "drankommen",
    "drankämen": "drankommen",
    "drankämest": "drankommen",
    "drankämet": "drankommen",
    "dranmache": "dranmachen",
    "dranmachend": "dranmachen",
    "dranmachende": "dranmachend",
    "dranmachendem": "dranmachend",
    "dranmachenden": "dranmachend",
    "dranmachender": "dranmachend",
    "dranmachendes": "dranmachend",
    "dranmachest": "dranmachen",
    "dranmachet": "dranmachen",
    "dranmachst": "dranmachen",
    "dranmacht": "dranmachen",
    "dranmachte": "dranmachen",
    "dranmachten": "dranmachen",
    "dranmachtest": "dranmachen",
    "dranmachtet": "dranmachen",
    "drannahm": "drannehmen",
    "drannahmen": "drannehmen",
    "drannahmst": "drannehmen",
    "drannahmt": "drannehmen",
    "drannehme": "drannehmen",
    "drannehmend": "drannehmen",
    "drannehmende": "drannehmend",
    "drannehmendem": "drannehmend",
    "drannehmenden": "drannehmend",
    "drannehmender": "drannehmend",
    "drannehmendes": "drannehmend",
    "drannehmest": "drannehmen",
    "drannehmet": "drannehmen",
    "drannehmt": "drannehmen",
    "drannimmst": "drannehmen",
    "drannimmt": "drannehmen",
    "drannähme": "drannehmen",
    "drannähmen": "drannehmen",
    "drannähmest": "drannehmen",
    "drannähmet": "drannehmen",
    "dransetze": "dransetzen",
    "dransetzend": "dransetzen",
    "dransetzende": "dransetzend",
    "dransetzendem": "dransetzend",
    "dransetzenden": "dransetzend",
    "dransetzender": "dransetzend",
    "dransetzendes": "dransetzend",
    "dransetzest": "dransetzen",
    "dransetzet": "dransetzen",
    "dransetzt": "dransetzen",
    "dransetzte": "dransetzen",
    "dransetzten": "dransetzen",
    "dransetztest": "dransetzen",
    "dransetztet": "dransetzen",
    "dranzubleiben": "dranbleiben",
    "dranzugeben": "drangeben",
    "dranzukleben": "drankleben",
    "dranzukommen": "drankommen",
    "dranzukriegen": "drankriegen",
    "dranzumachen": "dranmachen",
    "dranzunehmen": "drannehmen",
    "dranzusetzen": "dransetzen",
    "drastische": "drastisch",
    "drastischem": "drastisch",
    "drastischen": "drastisch",
    "drastischer": "drastisch",
    "drastischere": "drastisch",
    "drastischerem": "drastisch",
    "drastischeren": "drastisch",
    "drastischerer": "drastisch",
    "drastischeres": "drastisch",
    "drastisches": "drastisch",
    "drastischste": "drastisch",
    "drastischstem": "drastisch",
    "drastischsten": "drastisch",
    "drastischster": "drastisch",
    "drastischstes": "drastisch",
    "draufgab": "draufgeben",
    "draufgaben": "draufgeben",
    "draufgabst": "draufgeben",
    "draufgabt": "draufgeben",
    "draufgebe": "draufgeben",
    "draufgebend": "draufgeben",
    "draufgebende": "draufgebend",
    "draufgebendem": "draufgebend",
    "draufgebenden": "draufgebend",
    "draufgebender": "draufgebend",
    "draufgebendes": "draufgebend",
    "draufgebest": "draufgeben",
    "draufgebet": "draufgeben",
    "draufgebt": "draufgeben",
    "draufgegeben": "draufgeben",
    "draufgegebene": "draufgegeben",
    "draufgegebenem": "draufgegeben",
    "draufgegebenen": "draufgegeben",
    "draufgegebener": "draufgegeben",
    "draufgegebenes": "draufgegeben",
    "draufgelegt": "drauflegen",
    "draufgelegte": "draufgelegt",
    "draufgelegtem": "draufgelegt",
    "draufgelegten": "draufgelegt",
    "draufgelegter": "draufgelegt",
    "draufgelegtes": "draufgelegt",
    "draufgemacht": "draufmachen",
    "draufgemachte": "draufgemacht",
    "draufgemachtem": "draufgemacht",
    "draufgemachten": "draufgemacht",
    "draufgemachter": "draufgemacht",
    "draufgemachtes": "draufgemacht",
    "draufgezahlt": "draufzahlen",
    "draufgezahlte": "draufgezahlt",
    "draufgezahltem": "draufgezahlt",
    "draufgezahlten": "draufgezahlt",
    "draufgezahlter": "draufgezahlt",
    "draufgezahltes": "draufgezahlt",
    "draufgibst": "draufgeben",
    "draufgibt": "draufgeben",
    "draufgäbe": "draufgeben",
    "draufgäben": "draufgeben",
    "draufgäbest": "draufgeben",
    "draufgäbet": "draufgeben",
    "draufgängerische": "draufgängerisch",
    "draufgängerischem": "draufgängerisch",
    "draufgängerischen": "draufgängerisch",
    "draufgängerischer": "draufgängerisch",
    "draufgängerischere": "draufgängerisch",
    "draufgängerischerem": "draufgängerisch",
    "draufgängerischeren": "draufgängerisch",
    "draufgängerischerer": "draufgängerisch",
    "draufgängerischeres": "draufgängerisch",
    "draufgängerisches": "draufgängerisch",
    "draufgängerischste": "draufgängerisch",
    "draufgängerischstem": "draufgängerisch",
    "draufgängerischsten": "draufgängerisch",
    "draufgängerischster": "draufgängerisch",
    "draufgängerischstes": "draufgängerisch",
    "drauflege": "drauflegen",
    "drauflegend": "drauflegen",
    "drauflegende": "drauflegend",
    "drauflegendem": "drauflegend",
    "drauflegenden": "drauflegend",
    "drauflegender": "drauflegend",
    "drauflegendes": "drauflegend",
    "drauflegest": "drauflegen",
    "draufleget": "drauflegen",
    "drauflegst": "drauflegen",
    "drauflegt": "drauflegen",
    "drauflegte": "drauflegen",
    "drauflegten": "drauflegen",
    "drauflegtest": "drauflegen",
    "drauflegtet": "drauflegen",
    "drauflosarbeite": "drauflosarbeiten",
    "drauflosarbeitend": "drauflosarbeiten",
    "drauflosarbeitende": "drauflosarbeitend",
    "drauflosarbeitendem": "drauflosarbeitend",
    "drauflosarbeitenden": "drauflosarbeitend",
    "drauflosarbeitender": "drauflosarbeitend",
    "drauflosarbeitendes": "drauflosarbeitend",
    "drauflosarbeitest": "drauflosarbeiten",
    "drauflosarbeitet": "drauflosarbeiten",
    "drauflosarbeitete": "drauflosarbeiten",
    "drauflosarbeiteten": "drauflosarbeiten",
    "drauflosarbeitetest": "drauflosarbeiten",
    "drauflosarbeitetet": "drauflosarbeiten",
    "drauflosgearbeitet": "drauflosarbeiten",
    "drauflosgearbeitete": "drauflosgearbeitet",
    "drauflosgearbeitetem": "drauflosgearbeitet",
    "drauflosgearbeiteten": "drauflosgearbeitet",
    "drauflosgearbeiteter": "drauflosgearbeitet",
    "drauflosgearbeitetes": "drauflosgearbeitet",
    "drauflosgelaufen": "draufloslaufen",
    "drauflosgelaufene": "drauflosgelaufen",
    "drauflosgelaufenem": "drauflosgelaufen",
    "drauflosgelaufenen": "drauflosgelaufen",
    "drauflosgelaufener": "drauflosgelaufen",
    "drauflosgelaufenes": "drauflosgelaufen",
    "draufloslaufe": "draufloslaufen",
    "draufloslaufend": "draufloslaufen",
    "draufloslaufende": "draufloslaufend",
    "draufloslaufendem": "draufloslaufend",
    "draufloslaufenden": "draufloslaufend",
    "draufloslaufender": "draufloslaufend",
    "draufloslaufendes": "draufloslaufend",
    "draufloslaufest": "draufloslaufen",
    "draufloslaufet": "draufloslaufen",
    "draufloslauft": "draufloslaufen",
    "draufloslief": "draufloslaufen",
    "drauflosliefe": "draufloslaufen",
    "drauflosliefen": "draufloslaufen",
    "drauflosliefest": "draufloslaufen",
    "drauflosliefet": "draufloslaufen",
    "drauflosliefst": "draufloslaufen",
    "draufloslieft": "draufloslaufen",
    "drauflosläufst": "draufloslaufen",
    "drauflosläuft": "draufloslaufen",
    "draufloszuarbeiten": "drauflosarbeiten",
    "draufloszulaufen": "draufloslaufen",
    "draufmache": "draufmachen",
    "draufmachend": "draufmachen",
    "draufmachende": "draufmachend",
    "draufmachendem": "draufmachend",
    "draufmachenden": "draufmachend",
    "draufmachender": "draufmachend",
    "draufmachendes": "draufmachend",
    "draufmachest": "draufmachen",
    "draufmachet": "draufmachen",
    "draufmachst": "draufmachen",
    "draufmacht": "draufmachen",
    "draufmachte": "draufmachen",
    "draufmachten": "draufmachen",
    "draufmachtest": "draufmachen",
    "draufmachtet": "draufmachen",
    "draufzahle": "draufzahlen",
    "draufzahlend": "draufzahlen",
    "draufzahlende": "draufzahlend",
    "draufzahlendem": "draufzahlend",
    "draufzahlenden": "draufzahlend",
    "draufzahlender": "draufzahlend",
    "draufzahlendes": "draufzahlend",
    "draufzahlest": "draufzahlen",
    "draufzahlet": "draufzahlen",
    "draufzahlst": "draufzahlen",
    "draufzahlt": "draufzahlen",
    "draufzahlte": "draufzahlen",
    "draufzahlten": "draufzahlen",
    "draufzahltest": "draufzahlen",
    "draufzahltet": "draufzahlen",
    "draufzugeben": "draufgeben",
    "draufzulegen": "drauflegen",
    "draufzumachen": "draufmachen",
    "draufzuzahlen": "draufzahlen",
    "dreckigem": "dreckig",
    "dreckigen": "dreckig",
    "dreckiger": "dreckig",
    "dreckigere": "dreckig",
    "dreckigerem": "dreckig",
    "dreckigeren": "dreckig",
    "dreckigerer": "dreckig",
    "dreckigeres": "dreckig",
    "dreckiges": "dreckig",
    "dreckigste": "dreckig",
    "dreckigstem": "dreckig",
    "dreckigsten": "dreckig",
    "dreckigster": "dreckig",
    "dreckigstes": "dreckig",
    "drehbarem": "drehbar",
    "drehbaren": "drehbar",
    "drehbarer": "drehbar",
    "drehbares": "drehbar",
    "drehe": "drehen",
    "drehend": "drehen",
    "drehende": "drehend",
    "drehendem": "drehend",
    "drehenden": "drehend",
    "drehender": "drehend",
    "drehendere": "drehend",
    "drehenderem": "drehend",
    "drehenderen": "drehend",
    "drehenderer": "drehend",
    "drehenderes": "drehend",
    "drehendes": "drehend",
    "drehendste": "drehend",
    "drehendstem": "drehend",
    "drehendsten": "drehend",
    "drehendster": "drehend",
    "drehendstes": "drehend",
    "drehest": "drehen",
    "drehet": "drehen",
    "drehst": "drehen",
    "dreht": "drehen",
    "drehte": "drehen",
    "drehten": "drehen",
    "drehtest": "drehen",
    "drehtet": "drehen",
    "drehzahlarmem": "drehzahlarm",
    "drehzahlarmen": "drehzahlarm",
    "drehzahlarmer": "drehzahlarm",
    "drehzahlarmes": "drehzahlarm",
    "drehzahlärmer": "drehzahlarm",
    "drehzahlärmere": "drehzahlarm",
    "drehzahlärmerem": "drehzahlarm",
    "drehzahlärmeren": "drehzahlarm",
    "drehzahlärmerer": "drehzahlarm",
    "drehzahlärmeres": "drehzahlarm",
    "drehzahlärmsten": "drehzahlarm",
    "dreiarmigem": "dreiarmig",
    "dreiarmigen": "dreiarmig",
    "dreiarmiger": "dreiarmig",
    "dreiarmiges": "dreiarmig",
    "dreibeinigem": "dreibeinig",
    "dreibeinigen": "dreibeinig",
    "dreibeiniger": "dreibeinig",
    "dreibeiniges": "dreibeinig",
    "dreidimensionalem": "dreidimensional",
    "dreidimensionalen": "dreidimensional",
    "dreidimensionaler": "dreidimensional",
    "dreidimensionales": "dreidimensional",
    "dreieinigem": "dreieinig",
    "dreieinigen": "dreieinig",
    "dreieiniger": "dreieinig",
    "dreieiniges": "dreieinig",
    "dreifachem": "dreifach",
    "dreifachen": "dreifach",
    "dreifacher": "dreifach",
    "dreifaches": "dreifach",
    "dreiflammigem": "dreiflammig",
    "dreiflammigen": "dreiflammig",
    "dreiflammiger": "dreiflammig",
    "dreiflammiges": "dreiflammig",
    "dreifüßige": "dreifüßig",
    "dreifüßigem": "dreifüßig",
    "dreifüßigen": "dreifüßig",
    "dreifüßiger": "dreifüßig",
    "dreifüßiges": "dreifüßig",
    "dreimaligem": "dreimalig",
    "dreimaligen": "dreimalig",
    "dreimaliger": "dreimalig",
    "dreimaliges": "dreimalig",
    "dreimonatigem": "dreimonatig",
    "dreimonatigen": "dreimonatig",
    "dreimonatiger": "dreimonatig",
    "dreimonatiges": "dreimonatig",
    "dreinfand": "dreinfinden",
    "dreinfanden": "dreinfinden",
    "dreinfandest": "dreinfinden",
    "dreinfandet": "dreinfinden",
    "dreinfinde": "dreinfinden",
    "dreinfindend": "dreinfinden",
    "dreinfindende": "dreinfindend",
    "dreinfindendem": "dreinfindend",
    "dreinfindenden": "dreinfindend",
    "dreinfindender": "dreinfindend",
    "dreinfindendes": "dreinfindend",
    "dreinfindest": "dreinfinden",
    "dreinfindet": "dreinfinden",
    "dreinfände": "dreinfinden",
    "dreinfänden": "dreinfinden",
    "dreinfändest": "dreinfinden",
    "dreinfändet": "dreinfinden",
    "dreingefunden": "dreinfinden",
    "dreingefundene": "dreingefunden",
    "dreingefundenem": "dreingefunden",
    "dreingefundenen": "dreingefunden",
    "dreingefundener": "dreingefunden",
    "dreingefundenes": "dreingefunden",
    "dreingeredet": "dreinreden",
    "dreingeredete": "dreingeredet",
    "dreingeredetem": "dreingeredet",
    "dreingeredeten": "dreingeredet",
    "dreingeredeter": "dreingeredet",
    "dreingeredetes": "dreingeredet",
    "dreingeschaut": "dreinschauen",
    "dreingeschaute": "dreingeschaut",
    "dreingeschautem": "dreingeschaut",
    "dreingeschauten": "dreingeschaut",
    "dreingeschauter": "dreingeschaut",
    "dreingeschautes": "dreingeschaut",
    "dreinrede": "dreinreden",
    "dreinredend": "dreinreden",
    "dreinredende": "dreinredend",
    "dreinredendem": "dreinredend",
    "dreinredenden": "dreinredend",
    "dreinredender": "dreinredend",
    "dreinredendere": "dreinredend",
    "dreinredenderem": "dreinredend",
    "dreinredenderen": "dreinredend",
    "dreinredenderer": "dreinredend",
    "dreinredenderes": "dreinredend",
    "dreinredendes": "dreinredend",
    "dreinredendste": "dreinredend",
    "dreinredendstem": "dreinredend",
    "dreinredendsten": "dreinredend",
    "dreinredendster": "dreinredend",
    "dreinredendstes": "dreinredend",
    "dreinredest": "dreinreden",
    "dreinredet": "dreinreden",
    "dreinredete": "dreinreden",
    "dreinredeten": "dreinreden",
    "dreinredetest": "dreinreden",
    "dreinredetet": "dreinreden",
    "dreinschaue": "dreinschauen",
    "dreinschauend": "dreinschauen",
    "dreinschauende": "dreinschauend",
    "dreinschauendem": "dreinschauend",
    "dreinschauenden": "dreinschauend",
    "dreinschauender": "dreinschauend",
    "dreinschauendes": "dreinschauend",
    "dreinschauest": "dreinschauen",
    "dreinschauet": "dreinschauen",
    "dreinschaust": "dreinschauen",
    "dreinschaut": "dreinschauen",
    "dreinschaute": "dreinschauen",
    "dreinschauten": "dreinschauen",
    "dreinschautest": "dreinschauen",
    "dreinschautet": "dreinschauen",
    "dreinzufinden": "dreinfinden",
    "dreinzureden": "dreinreden",
    "dreinzuschauen": "dreinschauen",
    "dreispaltigem": "dreispaltig",
    "dreispaltigen": "dreispaltig",
    "dreispaltiger": "dreispaltig",
    "dreispaltiges": "dreispaltig",
    "dreisprachige": "dreisprachig",
    "dreisprachigem": "dreisprachig",
    "dreisprachigen": "dreisprachig",
    "dreisprachiger": "dreisprachig",
    "dreisprachiges": "dreisprachig",
    "dreiste": "dreist",
    "dreistem": "dreist",
    "dreisten": "dreist",
    "dreister": "dreist",
    "dreistere": "dreist",
    "dreisterem": "dreist",
    "dreisteren": "dreist",
    "dreisterer": "dreist",
    "dreisteres": "dreist",
    "dreistes": "dreist",
    "dreisteste": "dreist",
    "dreistestem": "dreist",
    "dreistesten": "dreist",
    "dreistester": "dreist",
    "dreistestes": "dreist",
    "dreiteilige": "dreiteilig",
    "dreiteiligem": "dreiteilig",
    "dreiteiligen": "dreiteilig",
    "dreiteiliger": "dreiteilig",
    "dreiteiliges": "dreiteilig",
    "dreitägigem": "dreitägig",
    "dreitägigen": "dreitägig",
    "dreitägiger": "dreitägig",
    "dreitägiges": "dreitägig",
    "dreißigjährigem": "dreißigjährig",
    "dreißigjährigen": "dreißigjährig",
    "dreißigjähriger": "dreißigjährig",
    "dreißigjähriges": "dreißigjährig",
    "dreschend": "dreschen",
    "dreschende": "dreschend",
    "dreschendem": "dreschend",
    "dreschenden": "dreschend",
    "dreschender": "dreschend",
    "dreschendere": "dreschend",
    "dreschenderem": "dreschend",
    "dreschenderen": "dreschend",
    "dreschenderer": "dreschend",
    "dreschenderes": "dreschend",
    "dreschendes": "dreschend",
    "dreschendste": "dreschend",
    "dreschendstem": "dreschend",
    "dreschendsten": "dreschend",
    "dreschendster": "dreschend",
    "dreschendstes": "dreschend",
    "dreschest": "dreschen",
    "dreschet": "dreschen",
    "drescht": "dreschen",
    "dressiere": "dressieren",
    "dressierend": "dressieren",
    "dressierende": "dressierend",
    "dressierendem": "dressierend",
    "dressierenden": "dressierend",
    "dressierender": "dressierend",
    "dressierendere": "dressierend",
    "dressierenderem": "dressierend",
    "dressierenderen": "dressierend",
    "dressierenderer": "dressierend",
    "dressierenderes": "dressierend",
    "dressierendes": "dressierend",
    "dressierendste": "dressierend",
    "dressierendstem": "dressierend",
    "dressierendsten": "dressierend",
    "dressierendster": "dressierend",
    "dressierendstes": "dressierend",
    "dressierest": "dressieren",
    "dressieret": "dressieren",
    "dressierst": "dressieren",
    "dressiert": "dressieren",
    "dressierte": "dressieren",
    "dressiertem": "dressiert",
    "dressierten": "dressieren",
    "dressierter": "dressiert",
    "dressiertere": "dressiert",
    "dressierterem": "dressiert",
    "dressierteren": "dressiert",
    "dressierterer": "dressiert",
    "dressierteres": "dressiert",
    "dressiertes": "dressiert",
    "dressiertest": "dressieren",
    "dressierteste": "dressiert",
    "dressiertestem": "dressiert",
    "dressiertesten": "dressiert",
    "dressiertester": "dressiert",
    "dressiertestes": "dressiert",
    "dressiertet": "dressieren",
    "dribbele": "dribbeln",
    "dribbelnd": "dribbeln",
    "dribbelnde": "dribbelnd",
    "dribbelndem": "dribbelnd",
    "dribbelnden": "dribbelnd",
    "dribbelnder": "dribbelnd",
    "dribbelndes": "dribbelnd",
    "dribbelst": "dribbeln",
    "dribbelt": "dribbeln",
    "dribbelte": "dribbeln",
    "dribbelten": "dribbeln",
    "dribbeltest": "dribbeln",
    "dribbeltet": "dribbeln",
    "dribble": "dribbeln",
    "drifte": "driften",
    "driftend": "driften",
    "driftende": "driftend",
    "driftendem": "driftend",
    "driftenden": "driftend",
    "driftender": "driftend",
    "driftendes": "driftend",
    "driftest": "driften",
    "driftet": "driften",
    "driftete": "driften",
    "drifteten": "driften",
    "driftetest": "driften",
    "driftetet": "driften",
    "drille": "drillen",
    "drillend": "drillen",
    "drillende": "drillend",
    "drillendem": "drillend",
    "drillenden": "drillend",
    "drillender": "drillend",
    "drillendere": "drillend",
    "drillenderem": "drillend",
    "drillenderen": "drillend",
    "drillenderer": "drillend",
    "drillenderes": "drillend",
    "drillendes": "drillend",
    "drillendste": "drillend",
    "drillendstem": "drillend",
    "drillendsten": "drillend",
    "drillendster": "drillend",
    "drillendstes": "drillend",
    "drillest": "drillen",
    "drillet": "drillen",
    "drillst": "drillen",
    "drillt": "drillen",
    "drillte": "drillen",
    "drillten": "drillen",
    "drilltest": "drillen",
    "drilltet": "drillen",
    "drinbleibe": "drinbleiben",
    "drinbleibend": "drinbleiben",
    "drinbleibende": "drinbleibend",
    "drinbleibendem": "drinbleibend",
    "drinbleibenden": "drinbleibend",
    "drinbleibender": "drinbleibend",
    "drinbleibendes": "drinbleibend",
    "drinbleibest": "drinbleiben",
    "drinbleibet": "drinbleiben",
    "drinbleibst": "drinbleiben",
    "drinbleibt": "drinbleiben",
    "drinblieb": "drinbleiben",
    "drinbliebe": "drinbleiben",
    "drinblieben": "drinbleiben",
    "drinbliebest": "drinbleiben",
    "drinbliebet": "drinbleiben",
    "drinbliebst": "drinbleiben",
    "drinbliebt": "drinbleiben",
    "dringe": "dringen",
    "dringeblieben": "drinbleiben",
    "dringebliebene": "dringeblieben",
    "dringebliebenem": "dringeblieben",
    "dringebliebenen": "dringeblieben",
    "dringebliebener": "dringeblieben",
    "dringebliebenes": "dringeblieben",
    "dringend": "dringen",
    "dringende": "dringend",
    "dringendem": "dringend",
    "dringenden": "dringend",
    "dringender": "dringend",
    "dringendes": "dringend",
    "dringesessen": "drinsitzen",
    "dringesessene": "dringesessen",
    "dringesessenem": "dringesessen",
    "dringesessenen": "dringesessen",
    "dringesessener": "dringesessen",
    "dringesessenes": "dringesessen",
    "dringest": "dringen",
    "dringet": "dringen",
    "dringliche": "dringlich",
    "dringlichem": "dringlich",
    "dringlichen": "dringlich",
    "dringlicher": "dringlich",
    "dringlichere": "dringlich",
    "dringlicherem": "dringlich",
    "dringlicheren": "dringlich",
    "dringlicherer": "dringlich",
    "dringlicheres": "dringlich",
    "dringliches": "dringlich",
    "dringlichste": "dringlich",
    "dringlichstem": "dringlich",
    "dringlichsten": "dringlich",
    "dringlichster": "dringlich",
    "dringlichstes": "dringlich",
    "dringst": "dringen",
    "dringt": "dringen",
    "drinsaß": "drinsitzen",
    "drinsaßen": "drinsitzen",
    "drinsaßt": "drinsitzen",
    "drinsitze": "drinsitzen",
    "drinsitzend": "drinsitzen",
    "drinsitzende": "drinsitzend",
    "drinsitzendem": "drinsitzend",
    "drinsitzenden": "drinsitzend",
    "drinsitzender": "drinsitzend",
    "drinsitzendes": "drinsitzend",
    "drinsitzest": "drinsitzen",
    "drinsitzet": "drinsitzen",
    "drinsitzt": "drinsitzen",
    "drinsäße": "drinsitzen",
    "drinsäßen": "drinsitzen",
    "drinsäßest": "drinsitzen",
    "drinsäßet": "drinsitzen",
    "drinzubleiben": "drinbleiben",
    "drinzusitzen": "drinsitzen",
    "drisch": "dreschen",
    "drischst": "dreschen",
    "drischt": "dreschen",
    "dritte": "dritt",
    "drittele": "dritteln",
    "drittelnd": "dritteln",
    "drittelnde": "drittelnd",
    "drittelndem": "drittelnd",
    "drittelnden": "drittelnd",
    "drittelnder": "drittelnd",
    "drittelndere": "drittelnd",
    "drittelnderem": "drittelnd",
    "drittelnderen": "drittelnd",
    "drittelnderer": "drittelnd",
    "drittelnderes": "drittelnd",
    "drittelndes": "drittelnd",
    "drittelndste": "drittelnd",
    "drittelndstem": "drittelnd",
    "drittelndsten": "drittelnd",
    "drittelndster": "drittelnd",
    "drittelndstes": "drittelnd",
    "drittelst": "dritteln",
    "drittelt": "dritteln",
    "drittelte": "dritteln",
    "drittelten": "dritteln",
    "dritteltest": "dritteln",
    "dritteltet": "dritteln",
    "drittem": "dritt",
    "dritten": "dritt",
    "dritter": "dritt",
    "drittes": "dritt",
    "drittle": "dritteln",
    "drogenabhängige": "drogenabhängig",
    "drogenabhängigem": "drogenabhängig",
    "drogenabhängigen": "drogenabhängig",
    "drogenabhängiger": "drogenabhängig",
    "drogenabhängiges": "drogenabhängig",
    "drohe": "drohen",
    "drohend": "drohen",
    "drohende": "drohend",
    "drohendem": "drohend",
    "drohenden": "drohend",
    "drohender": "drohend",
    "drohendes": "drohend",
    "drohest": "drohen",
    "drohet": "drohen",
    "drohst": "drohen",
    "droht": "drohen",
    "drohte": "drohen",
    "drohten": "drohen",
    "drohtest": "drohen",
    "drohtet": "drohen",
    "drolligem": "drollig",
    "drolligen": "drollig",
    "drolliger": "drollig",
    "drolligere": "drollig",
    "drolligerem": "drollig",
    "drolligeren": "drollig",
    "drolligerer": "drollig",
    "drolligeres": "drollig",
    "drolliges": "drollig",
    "drolligste": "drollig",
    "drolligstem": "drollig",
    "drolligsten": "drollig",
    "drolligster": "drollig",
    "drolligstes": "drollig",
    "drosch": "dreschen",
    "droschen": "dreschen",
    "droschst": "dreschen",
    "droscht": "dreschen",
    "drossele": "drosseln",
    "drosselnd": "drosseln",
    "drosselnde": "drosselnd",
    "drosselndem": "drosselnd",
    "drosselnden": "drosselnd",
    "drosselnder": "drosselnd",
    "drosselndere": "drosselnd",
    "drosselnderem": "drosselnd",
    "drosselnderen": "drosselnd",
    "drosselnderer": "drosselnd",
    "drosselnderes": "drosselnd",
    "drosselndes": "drosselnd",
    "drosselndste": "drosselnd",
    "drosselndstem": "drosselnd",
    "drosselndsten": "drosselnd",
    "drosselndster": "drosselnd",
    "drosselndstes": "drosselnd",
    "drosselst": "drosseln",
    "drosselt": "drosseln",
    "drosselte": "drosseln",
    "drosselten": "drosseln",
    "drosseltest": "drosseln",
    "drosseltet": "drosseln",
    "drossle": "drosseln",
    "druckempfindliche": "druckempfindlich",
    "druckempfindlichem": "druckempfindlich",
    "druckempfindlichen": "druckempfindlich",
    "druckempfindlicher": "druckempfindlich",
    "druckempfindlichere": "druckempfindlich",
    "druckempfindlicherem": "druckempfindlich",
    "druckempfindlicheren": "druckempfindlich",
    "druckempfindlicherer": "druckempfindlich",
    "druckempfindlicheres": "druckempfindlich",
    "druckempfindliches": "druckempfindlich",
    "druckempfindlichste": "druckempfindlich",
    "druckempfindlichstem": "druckempfindlich",
    "druckempfindlichsten": "druckempfindlich",
    "druckempfindlichster": "druckempfindlich",
    "druckempfindlichstes": "druckempfindlich",
    "druckend": "drucken",
    "druckende": "druckend",
    "druckendem": "druckend",
    "druckenden": "druckend",
    "druckender": "druckend",
    "druckendes": "druckend",
    "druckest": "drucken",
    "drucket": "drucken",
    "druckfertigem": "druckfertig",
    "druckfertigen": "druckfertig",
    "druckfertiger": "druckfertig",
    "druckfertigere": "druckfertig",
    "druckfertigerem": "druckfertig",
    "druckfertigeren": "druckfertig",
    "druckfertigerer": "druckfertig",
    "druckfertigeres": "druckfertig",
    "druckfertiges": "druckfertig",
    "druckfertigste": "druckfertig",
    "druckfertigstem": "druckfertig",
    "druckfertigsten": "druckfertig",
    "druckfertigster": "druckfertig",
    "druckfertigstes": "druckfertig",
    "druckreifem": "druckreif",
    "druckreifen": "druckreif",
    "druckreifer": "druckreif",
    "druckreifere": "druckreif",
    "druckreiferem": "druckreif",
    "druckreiferen": "druckreif",
    "druckreiferer": "druckreif",
    "druckreiferes": "druckreif",
    "druckreifes": "druckreif",
    "druckreifste": "druckreif",
    "druckreifstem": "druckreif",
    "druckreifsten": "druckreif",
    "druckreifster": "druckreif",
    "druckreifstes": "druckreif",
    "druckse": "drucksen",
    "drucksend": "drucksen",
    "drucksende": "drucksend",
    "drucksendem": "drucksend",
    "drucksenden": "drucksend",
    "drucksender": "drucksend",
    "drucksendere": "drucksend",
    "drucksenderem": "drucksend",
    "drucksenderen": "drucksend",
    "drucksenderer": "drucksend",
    "drucksenderes": "drucksend",
    "drucksendes": "drucksend",
    "drucksendste": "drucksend",
    "drucksendstem": "drucksend",
    "drucksendsten": "drucksend",
    "drucksendster": "drucksend",
    "drucksendstes": "drucksend",
    "drucksest": "drucksen",
    "druckset": "drucksen",
    "druckst": "drucksen",
    "druckste": "drucksen",
    "drucksten": "drucksen",
    "druckstest": "drucksen",
    "druckstet": "drucksen",
    "druckt": "drucken",
    "druckte": "drucken",
    "drucktechnische": "drucktechnisch",
    "drucktechnischem": "drucktechnisch",
    "drucktechnischen": "drucktechnisch",
    "drucktechnischer": "drucktechnisch",
    "drucktechnisches": "drucktechnisch",
    "druckten": "drucken",
    "drucktest": "drucken",
    "drucktet": "drucken",
    "dränge": "dringen",
    "drängele": "drängeln",
    "drängelnd": "drängeln",
    "drängelnde": "drängelnd",
    "drängelndem": "drängelnd",
    "drängelnden": "drängelnd",
    "drängelnder": "drängelnd",
    "drängelndere": "drängelnd",
    "drängelnderem": "drängelnd",
    "drängelnderen": "drängelnd",
    "drängelnderer": "drängelnd",
    "drängelnderes": "drängelnd",
    "drängelndes": "drängelnd",
    "drängelndste": "drängelnd",
    "drängelndstem": "drängelnd",
    "drängelndsten": "drängelnd",
    "drängelndster": "drängelnd",
    "drängelndstes": "drängelnd",
    "drängelst": "drängeln",
    "drängelt": "drängeln",
    "drängelte": "drängeln",
    "drängelten": "drängeln",
    "drängeltest": "drängeln",
    "drängeltet": "drängeln",
    "drängen": "dringen",
    "drängend": "drängen",
    "drängende": "drängend",
    "drängendem": "drängend",
    "drängenden": "drängend",
    "drängender": "drängend",
    "drängendere": "drängend",
    "drängenderem": "drängend",
    "drängenderen": "drängend",
    "drängenderer": "drängend",
    "drängenderes": "drängend",
    "drängendes": "drängend",
    "drängendste": "drängend",
    "drängendstem": "drängend",
    "drängendsten": "drängend",
    "drängendster": "drängend",
    "drängendstes": "drängend",
    "drängest": "dringen",
    "dränget": "dringen",
    "drängle": "drängeln",
    "drängst": "drängen",
    "drängt": "drängen",
    "drängte": "drängen",
    "drängten": "drängen",
    "drängtest": "drängen",
    "drängtet": "drängen",
    "drögem": "dröge",
    "dröger": "dröge",
    "drögere": "dröge",
    "drögerem": "dröge",
    "drögeren": "dröge",
    "drögerer": "dröge",
    "drögeres": "dröge",
    "dröges": "dröge",
    "drögeste": "dröge",
    "drögestem": "dröge",
    "drögesten": "dröge",
    "drögester": "dröge",
    "drögestes": "dröge",
    "dröhne": "dröhnen",
    "dröhnend": "dröhnen",
    "dröhnende": "dröhnend",
    "dröhnendem": "dröhnend",
    "dröhnenden": "dröhnend",
    "dröhnender": "dröhnend",
    "dröhnendere": "dröhnend",
    "dröhnenderem": "dröhnend",
    "dröhnenderen": "dröhnend",
    "dröhnenderer": "dröhnend",
    "dröhnenderes": "dröhnend",
    "dröhnendes": "dröhnend",
    "dröhnendste": "dröhnend",
    "dröhnendstem": "dröhnend",
    "dröhnendsten": "dröhnend",
    "dröhnendster": "dröhnend",
    "dröhnendstes": "dröhnend",
    "dröhnest": "dröhnen",
    "dröhnet": "dröhnen",
    "dröhnst": "dröhnen",
    "dröhnt": "dröhnen",
    "dröhnte": "dröhnen",
    "dröhnten": "dröhnen",
    "dröhntest": "dröhnen",
    "dröhntet": "dröhnen",
    "drösche": "dreschen",
    "dröschen": "dreschen",
    "dröschest": "dreschen",
    "dröschet": "dreschen",
    "drösele": "dröseln",
    "dröselnd": "dröseln",
    "dröselnde": "dröselnd",
    "dröselndem": "dröselnd",
    "dröselnden": "dröselnd",
    "dröselnder": "dröselnd",
    "dröselndere": "dröselnd",
    "dröselnderem": "dröselnd",
    "dröselnderen": "dröselnd",
    "dröselnderer": "dröselnd",
    "dröselnderes": "dröselnd",
    "dröselndes": "dröselnd",
    "dröselndste": "dröselnd",
    "dröselndstem": "dröselnd",
    "dröselndsten": "dröselnd",
    "dröselndster": "dröselnd",
    "dröselndstes": "dröselnd",
    "dröselst": "dröseln",
    "dröselt": "dröseln",
    "dröselte": "dröseln",
    "dröselten": "dröseln",
    "dröseltest": "dröseln",
    "dröseltet": "dröseln",
    "drösle": "dröseln",
    "drücke": "drücken",
    "drückend": "drücken",
    "drückendem": "drückend",
    "drückender": "drückend",
    "drückendere": "drückend",
    "drückenderem": "drückend",
    "drückenderen": "drückend",
    "drückenderer": "drückend",
    "drückenderes": "drückend",
    "drückendes": "drückend",
    "drückendste": "drückend",
    "drückendstem": "drückend",
    "drückendsten": "drückend",
    "drückendster": "drückend",
    "drückendstes": "drückend",
    "drückest": "drücken",
    "drücket": "drücken",
    "drückst": "drücken",
    "drückt": "drücken",
    "drückte": "drücken",
    "drückten": "drücken",
    "drücktest": "drücken",
    "drücktet": "drücken",
    "duale": "dual",
    "dualem": "dual",
    "dualen": "dual",
    "dualer": "dual",
    "duales": "dual",
    "dubiose": "dubios",
    "dubiosem": "dubios",
    "dubiosen": "dubios",
    "dubioser": "dubios",
    "dubiosere": "dubios",
    "dubioserem": "dubios",
    "dubioseren": "dubios",
    "dubioserer": "dubios",
    "dubioseres": "dubios",
    "dubioses": "dubios",
    "dubioseste": "dubios",
    "dubiosestem": "dubios",
    "dubiosesten": "dubios",
    "dubiosester": "dubios",
    "dubiosestes": "dubios",
    "ducke": "ducken",
    "duckend": "ducken",
    "duckende": "duckend",
    "duckendem": "duckend",
    "duckenden": "duckend",
    "duckender": "duckend",
    "duckendere": "duckend",
    "duckenderem": "duckend",
    "duckenderen": "duckend",
    "duckenderer": "duckend",
    "duckenderes": "duckend",
    "duckendes": "duckend",
    "duckendste": "duckend",
    "duckendstem": "duckend",
    "duckendsten": "duckend",
    "duckendster": "duckend",
    "duckendstes": "duckend",
    "duckest": "ducken",
    "ducket": "ducken",
    "duckmäuserische": "duckmäuserisch",
    "duckmäuserischem": "duckmäuserisch",
    "duckmäuserischen": "duckmäuserisch",
    "duckmäuserischer": "duckmäuserisch",
    "duckmäuserischere": "duckmäuserisch",
    "duckmäuserischerem": "duckmäuserisch",
    "duckmäuserischeren": "duckmäuserisch",
    "duckmäuserischerer": "duckmäuserisch",
    "duckmäuserischeres": "duckmäuserisch",
    "duckmäuserisches": "duckmäuserisch",
    "duckmäuserischste": "duckmäuserisch",
    "duckmäuserischstem": "duckmäuserisch",
    "duckmäuserischsten": "duckmäuserisch",
    "duckmäuserischster": "duckmäuserisch",
    "duckmäuserischstes": "duckmäuserisch",
    "duckst": "ducken",
    "duckt": "ducken",
    "duckte": "ducken",
    "duckten": "ducken",
    "ducktest": "ducken",
    "ducktet": "ducken",
    "dudele": "dudeln",
    "dudelnd": "dudeln",
    "dudelnde": "dudelnd",
    "dudelndem": "dudelnd",
    "dudelnden": "dudelnd",
    "dudelnder": "dudelnd",
    "dudelndere": "dudelnd",
    "dudelnderem": "dudelnd",
    "dudelnderen": "dudelnd",
    "dudelnderer": "dudelnd",
    "dudelnderes": "dudelnd",
    "dudelndes": "dudelnd",
    "dudelndste": "dudelnd",
    "dudelndstem": "dudelnd",
    "dudelndsten": "dudelnd",
    "dudelndster": "dudelnd",
    "dudelndstes": "dudelnd",
    "dudelst": "dudeln",
    "dudelt": "dudeln",
    "dudelte": "dudeln",
    "dudelten": "dudeln",
    "dudeltest": "dudeln",
    "dudeltet": "dudeln",
    "dudle": "dudeln",
    "duelliere": "duellieren",
    "duellierend": "duellieren",
    "duellierende": "duellierend",
    "duellierendem": "duellierend",
    "duellierenden": "duellierend",
    "duellierender": "duellierend",
    "duellierendes": "duellierend",
    "duellierest": "duellieren",
    "duellieret": "duellieren",
    "duellierst": "duellieren",
    "duelliert": "duellieren",
    "duellierte": "duellieren",
    "duelliertem": "duelliert",
    "duellierten": "duellieren",
    "duellierter": "duelliert",
    "duelliertes": "duelliert",
    "duelliertest": "duellieren",
    "duelliertet": "duellieren",
    "duftend": "duften",
    "duftende": "duftend",
    "duftendem": "duftend",
    "duftenden": "duftend",
    "duftender": "duftend",
    "duftendere": "duftend",
    "duftenderem": "duftend",
    "duftenderen": "duftend",
    "duftenderer": "duftend",
    "duftenderes": "duftend",
    "duftendes": "duftend",
    "duftendste": "duftend",
    "duftendstem": "duftend",
    "duftendsten": "duftend",
    "duftendster": "duftend",
    "duftendstes": "duftend",
    "duftest": "duften",
    "duftet": "duften",
    "duftete": "duften",
    "dufteten": "duften",
    "duftetest": "duften",
    "duftetet": "duften",
    "duftige": "duftig",
    "duftigem": "duftig",
    "duftigen": "duftig",
    "duftiger": "duftig",
    "duftigere": "duftig",
    "duftigerem": "duftig",
    "duftigeren": "duftig",
    "duftigerer": "duftig",
    "duftigeres": "duftig",
    "duftiges": "duftig",
    "duftigste": "duftig",
    "duftigstem": "duftig",
    "duftigsten": "duftig",
    "duftigster": "duftig",
    "duftigstes": "duftig",
    "dulde": "dulden",
    "duldend": "dulden",
    "duldende": "duldend",
    "duldendem": "duldend",
    "duldenden": "duldend",
    "duldender": "duldend",
    "duldendere": "duldend",
    "duldenderem": "duldend",
    "duldenderen": "duldend",
    "duldenderer": "duldend",
    "duldenderes": "duldend",
    "duldendes": "duldend",
    "duldendste": "duldend",
    "duldendstem": "duldend",
    "duldendsten": "duldend",
    "duldendster": "duldend",
    "duldendstes": "duldend",
    "duldest": "dulden",
    "duldet": "dulden",
    "duldete": "dulden",
    "duldeten": "dulden",
    "duldetest": "dulden",
    "duldetet": "dulden",
    "duldsame": "duldsam",
    "duldsamem": "duldsam",
    "duldsamen": "duldsam",
    "duldsamer": "duldsam",
    "duldsamere": "duldsam",
    "duldsamerem": "duldsam",
    "duldsameren": "duldsam",
    "duldsamerer": "duldsam",
    "duldsameres": "duldsam",
    "duldsames": "duldsam",
    "duldsamste": "duldsam",
    "duldsamstem": "duldsam",
    "duldsamsten": "duldsam",
    "duldsamster": "duldsam",
    "duldsamstes": "duldsam",
    "dummem": "dumm",
    "dummen": "dumm",
    "dummer": "dumm",
    "dummes": "dumm",
    "dumpfe": "dumpf",
    "dumpfem": "dumpf",
    "dumpfen": "dumpf",
    "dumpfer": "dumpf",
    "dumpfere": "dumpf",
    "dumpferem": "dumpf",
    "dumpferen": "dumpf",
    "dumpferer": "dumpf",
    "dumpferes": "dumpf",
    "dumpfes": "dumpf",
    "dumpfste": "dumpf",
    "dumpfstem": "dumpf",
    "dumpfsten": "dumpf",
    "dumpfster": "dumpf",
    "dumpfstes": "dumpf",
    "dunkel": "dunkeln",
    "dunkele": "dunkeln",
    "dunkelnd": "dunkeln",
    "dunkelnde": "dunkelnd",
    "dunkelndem": "dunkelnd",
    "dunkelnden": "dunkelnd",
    "dunkelnder": "dunkelnd",
    "dunkelndere": "dunkelnd",
    "dunkelnderem": "dunkelnd",
    "dunkelnderen": "dunkelnd",
    "dunkelnderer": "dunkelnd",
    "dunkelnderes": "dunkelnd",
    "dunkelndes": "dunkelnd",
    "dunkelndste": "dunkelnd",
    "dunkelndstem": "dunkelnd",
    "dunkelndsten": "dunkelnd",
    "dunkelndster": "dunkelnd",
    "dunkelndstes": "dunkelnd",
    "dunkelst": "dunkeln",
    "dunkelste": "dunkel",
    "dunkelstem": "dunkel",
    "dunkelsten": "dunkel",
    "dunkelster": "dunkel",
    "dunkelstes": "dunkel",
    "dunkelt": "dunkeln",
    "dunkelte": "dunkeln",
    "dunkelten": "dunkeln",
    "dunkeltest": "dunkeln",
    "dunkeltet": "dunkeln",
    "dunkle": "dunkel",
    "dunklem": "dunkel",
    "dunklen": "dunkel",
    "dunkler": "dunkel",
    "dunklere": "dunkel",
    "dunklerem": "dunkel",
    "dunkleren": "dunkel",
    "dunklerer": "dunkel",
    "dunkleres": "dunkel",
    "dunkles": "dunkel",
    "dunstend": "dunsten",
    "dunstende": "dunstend",
    "dunstendem": "dunstend",
    "dunstenden": "dunstend",
    "dunstender": "dunstend",
    "dunstendere": "dunstend",
    "dunstenderem": "dunstend",
    "dunstenderen": "dunstend",
    "dunstenderer": "dunstend",
    "dunstenderes": "dunstend",
    "dunstendes": "dunstend",
    "dunstendste": "dunstend",
    "dunstendstem": "dunstend",
    "dunstendsten": "dunstend",
    "dunstendster": "dunstend",
    "dunstendstes": "dunstend",
    "dunstest": "dunsten",
    "dunstet": "dunsten",
    "dunstete": "dunsten",
    "dunsteten": "dunsten",
    "dunstetest": "dunsten",
    "dunstetet": "dunsten",
    "dunstige": "dunstig",
    "dunstigem": "dunstig",
    "dunstigen": "dunstig",
    "dunstiger": "dunstig",
    "dunstigere": "dunstig",
    "dunstigerem": "dunstig",
    "dunstigeren": "dunstig",
    "dunstigerer": "dunstig",
    "dunstigeres": "dunstig",
    "dunstiges": "dunstig",
    "dunstigste": "dunstig",
    "dunstigstem": "dunstig",
    "dunstigsten": "dunstig",
    "dunstigster": "dunstig",
    "dunstigstes": "dunstig",
    "durcharbeite": "durcharbeiten",
    "durcharbeitend": "durcharbeiten",
    "durcharbeitende": "durcharbeitend",
    "durcharbeitendem": "durcharbeitend",
    "durcharbeitenden": "durcharbeitend",
    "durcharbeitender": "durcharbeitend",
    "durcharbeitendes": "durcharbeitend",
    "durcharbeitest": "durcharbeiten",
    "durcharbeitet": "durcharbeiten",
    "durcharbeitete": "durcharbeiten",
    "durcharbeiteten": "durcharbeiten",
    "durcharbeitetest": "durcharbeiten",
    "durcharbeitetet": "durcharbeiten",
    "durchatme": "durchatmen",
    "durchatmend": "durchatmen",
    "durchatmende": "durchatmend",
    "durchatmendem": "durchatmend",
    "durchatmenden": "durchatmend",
    "durchatmender": "durchatmend",
    "durchatmendes": "durchatmend",
    "durchatmest": "durchatmen",
    "durchatmet": "durchatmen",
    "durchatmete": "durchatmen",
    "durchatmeten": "durchatmen",
    "durchatmetest": "durchatmen",
    "durchatmetet": "durchatmen",
    "durchaß": "durchessen",
    "durchaßen": "durchessen",
    "durchaßt": "durchessen",
    "durchbeiße": "durchbeißen",
    "durchbeißend": "durchbeißen",
    "durchbeißende": "durchbeißend",
    "durchbeißendem": "durchbeißend",
    "durchbeißenden": "durchbeißend",
    "durchbeißender": "durchbeißend",
    "durchbeißendes": "durchbeißend",
    "durchbeißest": "durchbeißen",
    "durchbeißet": "durchbeißen",
    "durchbeißt": "durchbeißen",
    "durchbekam": "durchbekommen",
    "durchbekamen": "durchbekommen",
    "durchbekamst": "durchbekommen",
    "durchbekamt": "durchbekommen",
    "durchbekomme": "durchbekommen",
    "durchbekommend": "durchbekommen",
    "durchbekommende": "durchbekommend",
    "durchbekommendem": "durchbekommend",
    "durchbekommenden": "durchbekommend",
    "durchbekommender": "durchbekommend",
    "durchbekommendes": "durchbekommend",
    "durchbekommene": "durchbekommen",
    "durchbekommenem": "durchbekommen",
    "durchbekommenen": "durchbekommen",
    "durchbekommener": "durchbekommen",
    "durchbekommenes": "durchbekommen",
    "durchbekommest": "durchbekommen",
    "durchbekommet": "durchbekommen",
    "durchbekommst": "durchbekommen",
    "durchbekommt": "durchbekommen",
    "durchbekäme": "durchbekommen",
    "durchbekämen": "durchbekommen",
    "durchbekämest": "durchbekommen",
    "durchbekämet": "durchbekommen",
    "durchbettele": "durchbetteln",
    "durchbettelnd": "durchbetteln",
    "durchbettelnde": "durchbettelnd",
    "durchbettelndem": "durchbettelnd",
    "durchbettelnden": "durchbettelnd",
    "durchbettelnder": "durchbettelnd",
    "durchbettelndes": "durchbettelnd",
    "durchbettelst": "durchbetteln",
    "durchbettelt": "durchbetteln",
    "durchbettelte": "durchbetteln",
    "durchbettelten": "durchbetteln",
    "durchbetteltest": "durchbetteln",
    "durchbetteltet": "durchbetteln",
    "durchbettle": "durchbetteln",
    "durchbeutele": "durchbeuteln",
    "durchbeutelnd": "durchbeuteln",
    "durchbeutelnde": "durchbeutelnd",
    "durchbeutelndem": "durchbeutelnd",
    "durchbeutelnden": "durchbeutelnd",
    "durchbeutelnder": "durchbeutelnd",
    "durchbeutelndes": "durchbeutelnd",
    "durchbeutelst": "durchbeuteln",
    "durchbeutelt": "durchbeuteln",
    "durchbeutelte": "durchbeuteln",
    "durchbeutelten": "durchbeuteln",
    "durchbeuteltest": "durchbeuteln",
    "durchbeuteltet": "durchbeuteln",
    "durchbeutle": "durchbeuteln",
    "durchbiege": "durchbiegen",
    "durchbiegend": "durchbiegen",
    "durchbiegende": "durchbiegend",
    "durchbiegendem": "durchbiegend",
    "durchbiegenden": "durchbiegend",
    "durchbiegender": "durchbiegend",
    "durchbiegendere": "durchbiegend",
    "durchbiegenderem": "durchbiegend",
    "durchbiegenderen": "durchbiegend",
    "durchbiegenderer": "durchbiegend",
    "durchbiegenderes": "durchbiegend",
    "durchbiegendes": "durchbiegend",
    "durchbiegendste": "durchbiegend",
    "durchbiegendstem": "durchbiegend",
    "durchbiegendsten": "durchbiegend",
    "durchbiegendster": "durchbiegend",
    "durchbiegendstes": "durchbiegend",
    "durchbiegest": "durchbiegen",
    "durchbieget": "durchbiegen",
    "durchbiegst": "durchbiegen",
    "durchbiegt": "durchbiegen",
    "durchbilde": "durchbilden",
    "durchbildend": "durchbilden",
    "durchbildende": "durchbildend",
    "durchbildendem": "durchbildend",
    "durchbildenden": "durchbildend",
    "durchbildender": "durchbildend",
    "durchbildendes": "durchbildend",
    "durchbildest": "durchbilden",
    "durchbildet": "durchbilden",
    "durchbildete": "durchbilden",
    "durchbildeten": "durchbilden",
    "durchbildetest": "durchbilden",
    "durchbildetet": "durchbilden",
    "durchbisse": "durchbeißen",
    "durchbissen": "durchbeißen",
    "durchbissest": "durchbeißen",
    "durchbisset": "durchbeißen",
    "durchbiß": "durchbeißen",
    "durchbißt": "durchbeißen",
    "durchblase": "durchblasen",
    "durchblasend": "durchblasen",
    "durchblasende": "durchblasend",
    "durchblasendem": "durchblasend",
    "durchblasenden": "durchblasend",
    "durchblasender": "durchblasend",
    "durchblasendes": "durchblasend",
    "durchblasest": "durchblasen",
    "durchblaset": "durchblasen",
    "durchblast": "durchblasen",
    "durchbleue": "durchbleuen",
    "durchbleuend": "durchbleuen",
    "durchbleuende": "durchbleuend",
    "durchbleuendem": "durchbleuend",
    "durchbleuenden": "durchbleuend",
    "durchbleuender": "durchbleuend",
    "durchbleuendes": "durchbleuend",
    "durchbleuest": "durchbleuen",
    "durchbleuet": "durchbleuen",
    "durchbleust": "durchbleuen",
    "durchbleut": "durchbleuen",
    "durchbleute": "durchbleuen",
    "durchbleuten": "durchbleuen",
    "durchbleutest": "durchbleuen",
    "durchbleutet": "durchbleuen",
    "durchblies": "durchblasen",
    "durchbliese": "durchblasen",
    "durchbliesen": "durchblasen",
    "durchbliesest": "durchblasen",
    "durchblieset": "durchblasen",
    "durchbliest": "durchblasen",
    "durchblute": "durchbluten",
    "durchblutend": "durchbluten",
    "durchblutende": "durchblutend",
    "durchblutendem": "durchblutend",
    "durchblutenden": "durchblutend",
    "durchblutender": "durchblutend",
    "durchblutendere": "durchblutend",
    "durchblutenderem": "durchblutend",
    "durchblutenderen": "durchblutend",
    "durchblutenderer": "durchblutend",
    "durchblutenderes": "durchblutend",
    "durchblutendes": "durchblutend",
    "durchblutendste": "durchblutend",
    "durchblutendstem": "durchblutend",
    "durchblutendsten": "durchblutend",
    "durchblutendster": "durchblutend",
    "durchblutendstes": "durchblutend",
    "durchblutest": "durchbluten",
    "durchblutet": "durchbluten",
    "durchblutete": "durchbluten",
    "durchblutetem": "durchblutet",
    "durchbluteten": "durchbluten",
    "durchbluteter": "durchblutet",
    "durchblutetere": "durchblutet",
    "durchbluteterem": "durchblutet",
    "durchbluteteren": "durchblutet",
    "durchbluteterer": "durchblutet",
    "durchbluteteres": "durchblutet",
    "durchblutetes": "durchblutet",
    "durchblutetest": "durchbluten",
    "durchbluteteste": "durchblutet",
    "durchblutetestem": "durchblutet",
    "durchblutetesten": "durchblutet",
    "durchblutetester": "durchblutet",
    "durchblutetestes": "durchblutet",
    "durchblutetet": "durchbluten",
    "durchbläst": "durchblasen",
    "durchblättere": "durchblättern",
    "durchblätternd": "durchblättern",
    "durchblätternde": "durchblätternd",
    "durchblätterndem": "durchblätternd",
    "durchblätternden": "durchblätternd",
    "durchblätternder": "durchblätternd",
    "durchblätterndes": "durchblätternd",
    "durchblätterst": "durchblättern",
    "durchblättert": "durchblättern",
    "durchblätterte": "durchblättern",
    "durchblätterten": "durchblättern",
    "durchblättertest": "durchblättern",
    "durchblättertet": "durchblättern",
    "durchbläue": "durchbläuen",
    "durchbläuend": "durchbläuen",
    "durchbläuende": "durchbläuend",
    "durchbläuendem": "durchbläuend",
    "durchbläuenden": "durchbläuend",
    "durchbläuender": "durchbläuend",
    "durchbläuendere": "durchbläuend",
    "durchbläuenderem": "durchbläuend",
    "durchbläuenderen": "durchbläuend",
    "durchbläuenderer": "durchbläuend",
    "durchbläuenderes": "durchbläuend",
    "durchbläuendes": "durchbläuend",
    "durchbläuendste": "durchbläuend",
    "durchbläuendstem": "durchbläuend",
    "durchbläuendsten": "durchbläuend",
    "durchbläuendster": "durchbläuend",
    "durchbläuendstes": "durchbläuend",
    "durchbläuest": "durchbläuen",
    "durchbläuet": "durchbläuen",
    "durchbläust": "durchbläuen",
    "durchbläut": "durchbläuen",
    "durchbläute": "durchbläuen",
    "durchbläuten": "durchbläuen",
    "durchbläutest": "durchbläuen",
    "durchbläutet": "durchbläuen",
    "durchbog": "durchbiegen",
    "durchbogen": "durchbiegen",
    "durchbogst": "durchbiegen",
    "durchbogt": "durchbiegen",
    "durchbohre": "durchbohren",
    "durchbohrend": "durchbohren",
    "durchbohrende": "durchbohrend",
    "durchbohrendem": "durchbohrend",
    "durchbohrenden": "durchbohrend",
    "durchbohrender": "durchbohrend",
    "durchbohrendere": "durchbohrend",
    "durchbohrenderem": "durchbohrend",
    "durchbohrenderen": "durchbohrend",
    "durchbohrenderer": "durchbohrend",
    "durchbohrenderes": "durchbohrend",
    "durchbohrendes": "durchbohrend",
    "durchbohrendste": "durchbohrend",
    "durchbohrendstem": "durchbohrend",
    "durchbohrendsten": "durchbohrend",
    "durchbohrendster": "durchbohrend",
    "durchbohrendstes": "durchbohrend",
    "durchbohrest": "durchbohren",
    "durchbohret": "durchbohren",
    "durchbohrst": "durchbohren",
    "durchbohrt": "durchbohren",
    "durchbohrte": "durchbohren",
    "durchbohrtem": "durchbohrt",
    "durchbohrten": "durchbohren",
    "durchbohrter": "durchbohrt",
    "durchbohrtere": "durchbohrt",
    "durchbohrterem": "durchbohrt",
    "durchbohrteren": "durchbohrt",
    "durchbohrterer": "durchbohrt",
    "durchbohrteres": "durchbohrt",
    "durchbohrtes": "durchbohrt",
    "durchbohrtest": "durchbohren",
    "durchbohrteste": "durchbohrt",
    "durchbohrtestem": "durchbohrt",
    "durchbohrtesten": "durchbohrt",
    "durchbohrtester": "durchbohrt",
    "durchbohrtestes": "durchbohrt",
    "durchbohrtet": "durchbohren",
    "durchboxe": "durchboxen",
    "durchboxend": "durchboxen",
    "durchboxende": "durchboxend",
    "durchboxendem": "durchboxend",
    "durchboxenden": "durchboxend",
    "durchboxender": "durchboxend",
    "durchboxendes": "durchboxend",
    "durchboxest": "durchboxen",
    "durchboxet": "durchboxen",
    "durchboxt": "durchboxen",
    "durchboxte": "durchboxen",
    "durchboxten": "durchboxen",
    "durchboxtest": "durchboxen",
    "durchboxtet": "durchboxen",
    "durchbrach": "durchbrechen",
    "durchbrachen": "durchbrechen",
    "durchbrachst": "durchbrechen",
    "durchbracht": "durchbrechen",
    "durchbrachte": "durchbringen",
    "durchbrachten": "durchbringen",
    "durchbrachtest": "durchbringen",
    "durchbrachtet": "durchbringen",
    "durchbrannte": "durchbrennen",
    "durchbrannten": "durchbrennen",
    "durchbranntest": "durchbrennen",
    "durchbranntet": "durchbrennen",
    "durchbrate": "durchbraten",
    "durchbratend": "durchbraten",
    "durchbratende": "durchbratend",
    "durchbratendem": "durchbratend",
    "durchbratenden": "durchbratend",
    "durchbratender": "durchbratend",
    "durchbratendes": "durchbratend",
    "durchbratest": "durchbraten",
    "durchbratet": "durchbraten",
    "durchbrause": "durchbrausen",
    "durchbrausend": "durchbrausen",
    "durchbrausende": "durchbrausend",
    "durchbrausendem": "durchbrausend",
    "durchbrausenden": "durchbrausend",
    "durchbrausender": "durchbrausend",
    "durchbrausendere": "durchbrausend",
    "durchbrausenderem": "durchbrausend",
    "durchbrausenderen": "durchbrausend",
    "durchbrausenderer": "durchbrausend",
    "durchbrausenderes": "durchbrausend",
    "durchbrausendes": "durchbrausend",
    "durchbrausendste": "durchbrausend",
    "durchbrausendstem": "durchbrausend",
    "durchbrausendsten": "durchbrausend",
    "durchbrausendster": "durchbrausend",
    "durchbrausendstes": "durchbrausend",
    "durchbrausest": "durchbrausen",
    "durchbrauset": "durchbrausen",
    "durchbraust": "durchbrausen",
    "durchbrauste": "durchbrausen",
    "durchbraustem": "durchbraust",
    "durchbrausten": "durchbrausen",
    "durchbrauster": "durchbraust",
    "durchbraustere": "durchbraust",
    "durchbrausterem": "durchbraust",
    "durchbrausteren": "durchbraust",
    "durchbrausterer": "durchbraust",
    "durchbrausteres": "durchbraust",
    "durchbraustes": "durchbraust",
    "durchbraustest": "durchbrausen",
    "durchbrausteste": "durchbraust",
    "durchbraustestem": "durchbraust",
    "durchbraustesten": "durchbraust",
    "durchbraustester": "durchbraust",
    "durchbraustestes": "durchbraust",
    "durchbraustet": "durchbrausen",
    "durchbreche": "durchbrechen",
    "durchbrechend": "durchbrechen",
    "durchbrechende": "durchbrechend",
    "durchbrechendem": "durchbrechend",
    "durchbrechenden": "durchbrechend",
    "durchbrechender": "durchbrechend",
    "durchbrechendere": "durchbrechend",
    "durchbrechenderem": "durchbrechend",
    "durchbrechenderen": "durchbrechend",
    "durchbrechenderer": "durchbrechend",
    "durchbrechenderes": "durchbrechend",
    "durchbrechendes": "durchbrechend",
    "durchbrechendste": "durchbrechend",
    "durchbrechendstem": "durchbrechend",
    "durchbrechendsten": "durchbrechend",
    "durchbrechendster": "durchbrechend",
    "durchbrechendstes": "durchbrechend",
    "durchbrechest": "durchbrechen",
    "durchbrechet": "durchbrechen",
    "durchbrecht": "durchbrechen",
    "durchbrenne": "durchbrennen",
    "durchbrennend": "durchbrennen",
    "durchbrennende": "durchbrennend",
    "durchbrennendem": "durchbrennend",
    "durchbrennenden": "durchbrennend",
    "durchbrennender": "durchbrennend",
    "durchbrennendes": "durchbrennend",
    "durchbrennest": "durchbrennen",
    "durchbrennet": "durchbrennen",
    "durchbrennst": "durchbrennen",
    "durchbrennt": "durchbrennen",
    "durchbrich": "durchbrechen",
    "durchbrichst": "durchbrechen",
    "durchbricht": "durchbrechen",
    "durchbriet": "durchbraten",
    "durchbriete": "durchbraten",
    "durchbrieten": "durchbraten",
    "durchbrietest": "durchbraten",
    "durchbrietet": "durchbraten",
    "durchbringe": "durchbringen",
    "durchbringend": "durchbringen",
    "durchbringende": "durchbringend",
    "durchbringendem": "durchbringend",
    "durchbringenden": "durchbringend",
    "durchbringender": "durchbringend",
    "durchbringendes": "durchbringend",
    "durchbringest": "durchbringen",
    "durchbringet": "durchbringen",
    "durchbringst": "durchbringen",
    "durchbringt": "durchbringen",
    "durchbrochen": "durchbrechen",
    "durchbrochene": "durchbrochen",
    "durchbrochenem": "durchbrochen",
    "durchbrochenen": "durchbrochen",
    "durchbrochener": "durchbrochen",
    "durchbrochenes": "durchbrochen",
    "durchbräche": "durchbrechen",
    "durchbrächen": "durchbrechen",
    "durchbrächest": "durchbrechen",
    "durchbrächet": "durchbrechen",
    "durchbrächte": "durchbringen",
    "durchbrächten": "durchbringen",
    "durchbrächtest": "durchbringen",
    "durchbrächtet": "durchbringen",
    "durchbrät": "durchbraten",
    "durchbrätst": "durchbraten",
    "durchböge": "durchbiegen",
    "durchbögen": "durchbiegen",
    "durchbögest": "durchbiegen",
    "durchböget": "durchbiegen",
    "durchbürste": "durchbürsten",
    "durchbürstend": "durchbürsten",
    "durchbürstende": "durchbürstend",
    "durchbürstendem": "durchbürstend",
    "durchbürstenden": "durchbürstend",
    "durchbürstender": "durchbürstend",
    "durchbürstendes": "durchbürstend",
    "durchbürstest": "durchbürsten",
    "durchbürstet": "durchbürsten",
    "durchbürstete": "durchbürsten",
    "durchbürsteten": "durchbürsten",
    "durchbürstetest": "durchbürsten",
    "durchbürstetet": "durchbürsten",
    "durchdachte": "durchdenken",
    "durchdachten": "durchdenken",
    "durchdachtest": "durchdenken",
    "durchdachtet": "durchdenken",
    "durchdenke": "durchdenken",
    "durchdenkend": "durchdenken",
    "durchdenkende": "durchdenkend",
    "durchdenkendem": "durchdenkend",
    "durchdenkenden": "durchdenkend",
    "durchdenkender": "durchdenkend",
    "durchdenkendes": "durchdenkend",
    "durchdenkest": "durchdenken",
    "durchdenket": "durchdenken",
    "durchdenkst": "durchdenken",
    "durchdenkt": "durchdenken",
    "durchdiskutiere": "durchdiskutieren",
    "durchdiskutierend": "durchdiskutieren",
    "durchdiskutierende": "durchdiskutierend",
    "durchdiskutierendem": "durchdiskutierend",
    "durchdiskutierenden": "durchdiskutierend",
    "durchdiskutierender": "durchdiskutierend",
    "durchdiskutierendes": "durchdiskutierend",
    "durchdiskutierest": "durchdiskutieren",
    "durchdiskutieret": "durchdiskutieren",
    "durchdiskutierst": "durchdiskutieren",
    "durchdiskutiert": "durchdiskutieren",
    "durchdiskutierte": "durchdiskutieren",
    "durchdiskutiertem": "durchdiskutiert",
    "durchdiskutierten": "durchdiskutieren",
    "durchdiskutierter": "durchdiskutiert",
    "durchdiskutiertes": "durchdiskutiert",
    "durchdiskutiertest": "durchdiskutieren",
    "durchdiskutiertet": "durchdiskutieren",
    "durchdrang": "durchdringen",
    "durchdrangen": "durchdringen",
    "durchdrangst": "durchdringen",
    "durchdrangt": "durchdringen",
    "durchdrehe": "durchdrehen",
    "durchdrehend": "durchdrehen",
    "durchdrehende": "durchdrehend",
    "durchdrehendem": "durchdrehend",
    "durchdrehenden": "durchdrehend",
    "durchdrehender": "durchdrehend",
    "durchdrehendere": "durchdrehend",
    "durchdrehenderem": "durchdrehend",
    "durchdrehenderen": "durchdrehend",
    "durchdrehenderer": "durchdrehend",
    "durchdrehenderes": "durchdrehend",
    "durchdrehendes": "durchdrehend",
    "durchdrehendste": "durchdrehend",
    "durchdrehendstem": "durchdrehend",
    "durchdrehendsten": "durchdrehend",
    "durchdrehendster": "durchdrehend",
    "durchdrehendstes": "durchdrehend",
    "durchdrehest": "durchdrehen",
    "durchdrehet": "durchdrehen",
    "durchdrehst": "durchdrehen",
    "durchdreht": "durchdrehen",
    "durchdrehte": "durchdrehen",
    "durchdrehten": "durchdrehen",
    "durchdrehtest": "durchdrehen",
    "durchdrehtet": "durchdrehen",
    "durchdringe": "durchdringen",
    "durchdringend": "durchdringen",
    "durchdringende": "durchdringend",
    "durchdringendem": "durchdringend",
    "durchdringenden": "durchdringend",
    "durchdringender": "durchdringend",
    "durchdringendere": "durchdringend",
    "durchdringenderem": "durchdringend",
    "durchdringenderen": "durchdringend",
    "durchdringenderer": "durchdringend",
    "durchdringenderes": "durchdringend",
    "durchdringendes": "durchdringend",
    "durchdringendste": "durchdringend",
    "durchdringendstem": "durchdringend",
    "durchdringendsten": "durchdringend",
    "durchdringendster": "durchdringend",
    "durchdringendstes": "durchdringend",
    "durchdringest": "durchdringen",
    "durchdringet": "durchdringen",
    "durchdringst": "durchdringen",
    "durchdringt": "durchdringen",
    "durchdrungen": "durchdringen",
    "durchdrungene": "durchdrungen",
    "durchdrungenem": "durchdrungen",
    "durchdrungenen": "durchdrungen",
    "durchdrungener": "durchdrungen",
    "durchdrungenere": "durchdrungen",
    "durchdrungenerem": "durchdrungen",
    "durchdrungeneren": "durchdrungen",
    "durchdrungenerer": "durchdrungen",
    "durchdrungeneres": "durchdrungen",
    "durchdrungenes": "durchdrungen",
    "durchdrungenste": "durchdrungen",
    "durchdrungenstem": "durchdrungen",
    "durchdrungensten": "durchdrungen",
    "durchdrungenster": "durchdrungen",
    "durchdrungenstes": "durchdrungen",
    "durchdränge": "durchdringen",
    "durchdrängen": "durchdringen",
    "durchdrängend": "durchdrängen",
    "durchdrängende": "durchdrängend",
    "durchdrängendem": "durchdrängend",
    "durchdrängenden": "durchdrängend",
    "durchdrängender": "durchdrängend",
    "durchdrängendere": "durchdrängend",
    "durchdrängenderem": "durchdrängend",
    "durchdrängenderen": "durchdrängend",
    "durchdrängenderer": "durchdrängend",
    "durchdrängenderes": "durchdrängend",
    "durchdrängendes": "durchdrängend",
    "durchdrängendste": "durchdrängend",
    "durchdrängendstem": "durchdrängend",
    "durchdrängendsten": "durchdrängend",
    "durchdrängendster": "durchdrängend",
    "durchdrängendstes": "durchdrängend",
    "durchdrängest": "durchdringen",
    "durchdränget": "durchdringen",
    "durchdrängst": "durchdrängen",
    "durchdrängt": "durchdrängen",
    "durchdrängte": "durchdrängen",
    "durchdrängten": "durchdrängen",
    "durchdrängtest": "durchdrängen",
    "durchdrängtet": "durchdrängen",
    "durchdrücke": "durchdrücken",
    "durchdrückend": "durchdrücken",
    "durchdrückende": "durchdrückend",
    "durchdrückendem": "durchdrückend",
    "durchdrückenden": "durchdrückend",
    "durchdrückender": "durchdrückend",
    "durchdrückendes": "durchdrückend",
    "durchdrückest": "durchdrücken",
    "durchdrücket": "durchdrücken",
    "durchdrückst": "durchdrücken",
    "durchdrückt": "durchdrücken",
    "durchdrückte": "durchdrücken",
    "durchdrückten": "durchdrücken",
    "durchdrücktest": "durchdrücken",
    "durchdrücktet": "durchdrücken",
    "durchdächte": "durchdenken",
    "durchdächten": "durchdenken",
    "durchdächtest": "durchdenken",
    "durchdächtet": "durchdenken",
    "durcheile": "durcheilen",
    "durcheilend": "durcheilen",
    "durcheilende": "durcheilend",
    "durcheilendem": "durcheilend",
    "durcheilenden": "durcheilend",
    "durcheilender": "durcheilend",
    "durcheilendes": "durcheilend",
    "durcheilest": "durcheilen",
    "durcheilet": "durcheilen",
    "durcheilst": "durcheilen",
    "durcheilt": "durcheilen",
    "durcheilte": "durcheilen",
    "durcheiltem": "durcheilt",
    "durcheilten": "durcheilen",
    "durcheilter": "durcheilt",
    "durcheiltes": "durcheilt",
    "durcheiltest": "durcheilen",
    "durcheiltet": "durcheilen",
    "durchesse": "durchessen",
    "durchessend": "durchessen",
    "durchessende": "durchessend",
    "durchessendem": "durchessend",
    "durchessenden": "durchessend",
    "durchessender": "durchessend",
    "durchessendes": "durchessend",
    "durchessest": "durchessen",
    "durchesset": "durchessen",
    "durcheßt": "durchessen",
    "durchfahre": "durchfahren",
    "durchfahrend": "durchfahren",
    "durchfahrende": "durchfahrend",
    "durchfahrendem": "durchfahrend",
    "durchfahrenden": "durchfahrend",
    "durchfahrender": "durchfahrend",
    "durchfahrendes": "durchfahrend",
    "durchfahrene": "durchfahren",
    "durchfahrenem": "durchfahren",
    "durchfahrenen": "durchfahren",
    "durchfahrener": "durchfahren",
    "durchfahrenes": "durchfahren",
    "durchfahrest": "durchfahren",
    "durchfahret": "durchfahren",
    "durchfahrt": "durchfahren",
    "durchfallend": "durchfallen",
    "durchfallende": "durchfallend",
    "durchfallendem": "durchfallend",
    "durchfallenden": "durchfallend",
    "durchfallender": "durchfallend",
    "durchfallendes": "durchfallend",
    "durchfallest": "durchfallen",
    "durchfallet": "durchfallen",
    "durchfallt": "durchfallen",
    "durchfand": "durchfinden",
    "durchfanden": "durchfinden",
    "durchfandest": "durchfinden",
    "durchfandet": "durchfinden",
    "durchfechte": "durchfechten",
    "durchfechtend": "durchfechten",
    "durchfechtende": "durchfechtend",
    "durchfechtendem": "durchfechtend",
    "durchfechtenden": "durchfechtend",
    "durchfechtender": "durchfechtend",
    "durchfechtendes": "durchfechtend",
    "durchfechtest": "durchfechten",
    "durchfechtet": "durchfechten",
    "durchfedere": "durchfedern",
    "durchfedernd": "durchfedern",
    "durchfedernde": "durchfedernd",
    "durchfederndem": "durchfedernd",
    "durchfedernden": "durchfedernd",
    "durchfedernder": "durchfedernd",
    "durchfederndes": "durchfedernd",
    "durchfederst": "durchfedern",
    "durchfedert": "durchfedern",
    "durchfederte": "durchfedern",
    "durchfederten": "durchfedern",
    "durchfedertest": "durchfedern",
    "durchfedertet": "durchfedern",
    "durchfeiere": "durchfeiern",
    "durchfeiernd": "durchfeiern",
    "durchfeiernde": "durchfeiernd",
    "durchfeierndem": "durchfeiernd",
    "durchfeiernden": "durchfeiernd",
    "durchfeiernder": "durchfeiernd",
    "durchfeierndes": "durchfeiernd",
    "durchfeierst": "durchfeiern",
    "durchfeiert": "durchfeiern",
    "durchfeierte": "durchfeiern",
    "durchfeierten": "durchfeiern",
    "durchfeiertest": "durchfeiern",
    "durchfeiertet": "durchfeiern",
    "durchfeile": "durchfeilen",
    "durchfeilend": "durchfeilen",
    "durchfeilende": "durchfeilend",
    "durchfeilendem": "durchfeilend",
    "durchfeilenden": "durchfeilend",
    "durchfeilender": "durchfeilend",
    "durchfeilendes": "durchfeilend",
    "durchfeilest": "durchfeilen",
    "durchfeilet": "durchfeilen",
    "durchfeilst": "durchfeilen",
    "durchfeilt": "durchfeilen",
    "durchfeilte": "durchfeilen",
    "durchfeilten": "durchfeilen",
    "durchfeiltest": "durchfeilen",
    "durchfeiltet": "durchfeilen",
    "durchficht": "durchfechten",
    "durchfichtst": "durchfechten",
    "durchfiel": "durchfallen",
    "durchfiele": "durchfallen",
    "durchfielen": "durchfallen",
    "durchfielest": "durchfallen",
    "durchfielet": "durchfallen",
    "durchfielst": "durchfallen",
    "durchfielt": "durchfallen",
    "durchfinde": "durchfinden",
    "durchfindend": "durchfinden",
    "durchfindende": "durchfindend",
    "durchfindendem": "durchfindend",
    "durchfindenden": "durchfindend",
    "durchfindender": "durchfindend",
    "durchfindendes": "durchfindend",
    "durchfindest": "durchfinden",
    "durchfindet": "durchfinden",
    "durchflechte": "durchflechten",
    "durchflechtend": "durchflechten",
    "durchflechtende": "durchflechtend",
    "durchflechtendem": "durchflechtend",
    "durchflechtenden": "durchflechtend",
    "durchflechtender": "durchflechtend",
    "durchflechtendes": "durchflechtend",
    "durchflechtest": "durchflechten",
    "durchflechtet": "durchflechten",
    "durchflich": "durchflechten",
    "durchflicht": "durchflechten",
    "durchflichtst": "durchflechten",
    "durchfliege": "durchfliegen",
    "durchfliegend": "durchfliegen",
    "durchfliegende": "durchfliegend",
    "durchfliegendem": "durchfliegend",
    "durchfliegenden": "durchfliegend",
    "durchfliegender": "durchfliegend",
    "durchfliegendes": "durchfliegend",
    "durchfliegest": "durchfliegen",
    "durchflieget": "durchfliegen",
    "durchfliegst": "durchfliegen",
    "durchfliegt": "durchfliegen",
    "durchfließe": "durchfließen",
    "durchfließend": "durchfließen",
    "durchfließende": "durchfließend",
    "durchfließendem": "durchfließend",
    "durchfließenden": "durchfließend",
    "durchfließender": "durchfließend",
    "durchfließendes": "durchfließend",
    "durchfließest": "durchfließen",
    "durchfließet": "durchfließen",
    "durchfließt": "durchfließen",
    "durchflocht": "durchflechten",
    "durchflochten": "durchflechten",
    "durchflochtene": "durchflochten",
    "durchflochtenem": "durchflochten",
    "durchflochtenen": "durchflochten",
    "durchflochtener": "durchflochten",
    "durchflochtenere": "durchflochten",
    "durchflochtenerem": "durchflochten",
    "durchflochteneren": "durchflochten",
    "durchflochtenerer": "durchflochten",
    "durchflochteneres": "durchflochten",
    "durchflochtenes": "durchflochten",
    "durchflochtenste": "durchflochten",
    "durchflochtenstem": "durchflochten",
    "durchflochtensten": "durchflochten",
    "durchflochtenster": "durchflochten",
    "durchflochtenstes": "durchflochten",
    "durchflochtest": "durchflechten",
    "durchflochtet": "durchflechten",
    "durchflog": "durchfliegen",
    "durchflogen": "durchfliegen",
    "durchflogene": "durchflogen",
    "durchflogenem": "durchflogen",
    "durchflogenen": "durchflogen",
    "durchflogener": "durchflogen",
    "durchflogenes": "durchflogen",
    "durchflogst": "durchfliegen",
    "durchflogt": "durchfliegen",
    "durchflossen": "durchfließen",
    "durchflossene": "durchflossen",
    "durchflossenem": "durchflossen",
    "durchflossenen": "durchflossen",
    "durchflossener": "durchflossen",
    "durchflossenes": "durchflossen",
    "durchfloß": "durchfließen",
    "durchfloßt": "durchfließen",
    "durchflute": "durchfluten",
    "durchflutend": "durchfluten",
    "durchflutende": "durchflutend",
    "durchflutendem": "durchflutend",
    "durchflutenden": "durchflutend",
    "durchflutender": "durchflutend",
    "durchflutendere": "durchflutend",
    "durchflutenderem": "durchflutend",
    "durchflutenderen": "durchflutend",
    "durchflutenderer": "durchflutend",
    "durchflutenderes": "durchflutend",
    "durchflutendes": "durchflutend",
    "durchflutendste": "durchflutend",
    "durchflutendstem": "durchflutend",
    "durchflutendsten": "durchflutend",
    "durchflutendster": "durchflutend",
    "durchflutendstes": "durchflutend",
    "durchflutest": "durchfluten",
    "durchflutet": "durchfluten",
    "durchflutete": "durchfluten",
    "durchflutetem": "durchflutet",
    "durchfluteten": "durchfluten",
    "durchfluteter": "durchflutet",
    "durchflutetere": "durchflutet",
    "durchfluteterem": "durchflutet",
    "durchfluteteren": "durchflutet",
    "durchfluteterer": "durchflutet",
    "durchfluteteres": "durchflutet",
    "durchflutetes": "durchflutet",
    "durchflutetest": "durchfluten",
    "durchfluteteste": "durchflutet",
    "durchflutetestem": "durchflutet",
    "durchflutetesten": "durchflutet",
    "durchflutetester": "durchflutet",
    "durchflutetestes": "durchflutet",
    "durchflutetet": "durchfluten",
    "durchflutsche": "durchflutschen",
    "durchflutschend": "durchflutschen",
    "durchflutschende": "durchflutschend",
    "durchflutschendem": "durchflutschend",
    "durchflutschenden": "durchflutschend",
    "durchflutschender": "durchflutschend",
    "durchflutschendere": "durchflutschend",
    "durchflutschenderem": "durchflutschend",
    "durchflutschenderen": "durchflutschend",
    "durchflutschenderer": "durchflutschend",
    "durchflutschenderes": "durchflutschend",
    "durchflutschendes": "durchflutschend",
    "durchflutschendste": "durchflutschend",
    "durchflutschendstem": "durchflutschend",
    "durchflutschendsten": "durchflutschend",
    "durchflutschendster": "durchflutschend",
    "durchflutschendstes": "durchflutschend",
    "durchflutschest": "durchflutschen",
    "durchflutschet": "durchflutschen",
    "durchflutschst": "durchflutschen",
    "durchflutscht": "durchflutschen",
    "durchflutschte": "durchflutschen",
    "durchflutschten": "durchflutschen",
    "durchflutschtest": "durchflutschen",
    "durchflutschtet": "durchflutschen",
    "durchflöchte": "durchflechten",
    "durchflöchten": "durchflechten",
    "durchflöchtest": "durchflechten",
    "durchflöchtet": "durchflechten",
    "durchflöge": "durchfliegen",
    "durchflögen": "durchfliegen",
    "durchflögest": "durchfliegen",
    "durchflöget": "durchfliegen",
    "durchflösse": "durchfließen",
    "durchflössen": "durchfließen",
    "durchflössest": "durchfließen",
    "durchflösset": "durchfließen",
    "durchfocht": "durchfechten",
    "durchfochten": "durchfechten",
    "durchfochtest": "durchfechten",
    "durchfochtet": "durchfechten",
    "durchforme": "durchformen",
    "durchformend": "durchformen",
    "durchformende": "durchformend",
    "durchformendem": "durchformend",
    "durchformenden": "durchformend",
    "durchformender": "durchformend",
    "durchformendes": "durchformend",
    "durchformest": "durchformen",
    "durchformet": "durchformen",
    "durchformst": "durchformen",
    "durchformt": "durchformen",
    "durchformte": "durchformen",
    "durchformten": "durchformen",
    "durchformtest": "durchformen",
    "durchformtet": "durchformen",
    "durchformulierte": "durchformuliert",
    "durchformuliertem": "durchformuliert",
    "durchformulierten": "durchformuliert",
    "durchformulierter": "durchformuliert",
    "durchformuliertere": "durchformuliert",
    "durchformulierterem": "durchformuliert",
    "durchformulierteren": "durchformuliert",
    "durchformulierterer": "durchformuliert",
    "durchformulierteres": "durchformuliert",
    "durchformuliertes": "durchformuliert",
    "durchformulierteste": "durchformuliert",
    "durchformuliertestem": "durchformuliert",
    "durchformuliertesten": "durchformuliert",
    "durchformuliertester": "durchformuliert",
    "durchformuliertestes": "durchformuliert",
    "durchforste": "durchforsten",
    "durchforstend": "durchforsten",
    "durchforstende": "durchforstend",
    "durchforstendem": "durchforstend",
    "durchforstenden": "durchforstend",
    "durchforstender": "durchforstend",
    "durchforstendes": "durchforstend",
    "durchforstest": "durchforsten",
    "durchforstet": "durchforsten",
    "durchforstete": "durchforsten",
    "durchforsteten": "durchforsten",
    "durchforstetest": "durchforsten",
    "durchforstetet": "durchforsten",
    "durchfrage": "durchfragen",
    "durchfragend": "durchfragen",
    "durchfragende": "durchfragend",
    "durchfragendem": "durchfragend",
    "durchfragenden": "durchfragend",
    "durchfragender": "durchfragend",
    "durchfragendes": "durchfragend",
    "durchfragest": "durchfragen",
    "durchfraget": "durchfragen",
    "durchfragst": "durchfragen",
    "durchfragt": "durchfragen",
    "durchfragte": "durchfragen",
    "durchfragten": "durchfragen",
    "durchfragtest": "durchfragen",
    "durchfragtet": "durchfragen",
    "durchfraß": "durchfressen",
    "durchfraßen": "durchfressen",
    "durchfraßt": "durchfressen",
    "durchfresse": "durchfressen",
    "durchfressend": "durchfressen",
    "durchfressende": "durchfressend",
    "durchfressendem": "durchfressend",
    "durchfressenden": "durchfressend",
    "durchfressender": "durchfressend",
    "durchfressendere": "durchfressend",
    "durchfressenderem": "durchfressend",
    "durchfressenderen": "durchfressend",
    "durchfressenderer": "durchfressend",
    "durchfressenderes": "durchfressend",
    "durchfressendes": "durchfressend",
    "durchfressendste": "durchfressend",
    "durchfressendstem": "durchfressend",
    "durchfressendsten": "durchfressend",
    "durchfressendster": "durchfressend",
    "durchfressendstes": "durchfressend",
    "durchfressest": "durchfressen",
    "durchfresset": "durchfressen",
    "durchfreßt": "durchfressen",
    "durchfriere": "durchfrieren",
    "durchfrierend": "durchfrieren",
    "durchfrierende": "durchfrierend",
    "durchfrierendem": "durchfrierend",
    "durchfrierenden": "durchfrierend",
    "durchfrierender": "durchfrierend",
    "durchfrierendere": "durchfrierend",
    "durchfrierenderem": "durchfrierend",
    "durchfrierenderen": "durchfrierend",
    "durchfrierenderer": "durchfrierend",
    "durchfrierenderes": "durchfrierend",
    "durchfrierendes": "durchfrierend",
    "durchfrierendste": "durchfrierend",
    "durchfrierendstem": "durchfrierend",
    "durchfrierendsten": "durchfrierend",
    "durchfrierendster": "durchfrierend",
    "durchfrierendstes": "durchfrierend",
    "durchfrierest": "durchfrieren",
    "durchfrieret": "durchfrieren",
    "durchfrierst": "durchfrieren",
    "durchfriert": "durchfrieren",
    "durchfrißt": "durchfressen",
    "durchfror": "durchfrieren",
    "durchfroren": "durchfrieren",
    "durchfrorst": "durchfrieren",
    "durchfrort": "durchfrieren",
    "durchfräße": "durchfressen",
    "durchfräßen": "durchfressen",
    "durchfräßest": "durchfressen",
    "durchfräßet": "durchfressen",
    "durchfröre": "durchfrieren",
    "durchfrören": "durchfrieren",
    "durchfrörest": "durchfrieren",
    "durchfröret": "durchfrieren",
    "durchfuhr": "durchfahren",
    "durchfuhren": "durchfahren",
    "durchfuhrst": "durchfahren",
    "durchfuhrt": "durchfahren",
    "durchfuttere": "durchfuttern",
    "durchfutternd": "durchfuttern",
    "durchfutternde": "durchfutternd",
    "durchfutterndem": "durchfutternd",
    "durchfutternden": "durchfutternd",
    "durchfutternder": "durchfutternd",
    "durchfutterndes": "durchfutternd",
    "durchfutterst": "durchfuttern",
    "durchfuttert": "durchfuttern",
    "durchfutterte": "durchfuttern",
    "durchfutterten": "durchfuttern",
    "durchfuttertest": "durchfuttern",
    "durchfuttertet": "durchfuttern",
    "durchfährst": "durchfahren",
    "durchfährt": "durchfahren",
    "durchfällst": "durchfallen",
    "durchfällt": "durchfallen",
    "durchfände": "durchfinden",
    "durchfänden": "durchfinden",
    "durchfändest": "durchfinden",
    "durchfändet": "durchfinden",
    "durchföchte": "durchfechten",
    "durchföchten": "durchfechten",
    "durchföchtest": "durchfechten",
    "durchföchtet": "durchfechten",
    "durchfühle": "durchfühlen",
    "durchfühlend": "durchfühlen",
    "durchfühlende": "durchfühlend",
    "durchfühlendem": "durchfühlend",
    "durchfühlenden": "durchfühlend",
    "durchfühlender": "durchfühlend",
    "durchfühlendes": "durchfühlend",
    "durchfühlest": "durchfühlen",
    "durchfühlet": "durchfühlen",
    "durchfühlst": "durchfühlen",
    "durchfühlt": "durchfühlen",
    "durchfühlte": "durchfühlen",
    "durchfühlten": "durchfühlen",
    "durchfühltest": "durchfühlen",
    "durchfühltet": "durchfühlen",
    "durchführbare": "durchführbar",
    "durchführbarem": "durchführbar",
    "durchführbaren": "durchführbar",
    "durchführbarer": "durchführbar",
    "durchführbarere": "durchführbar",
    "durchführbarerem": "durchführbar",
    "durchführbareren": "durchführbar",
    "durchführbarerer": "durchführbar",
    "durchführbareres": "durchführbar",
    "durchführbares": "durchführbar",
    "durchführbarste": "durchführbar",
    "durchführbarstem": "durchführbar",
    "durchführbarsten": "durchführbar",
    "durchführbarster": "durchführbar",
    "durchführbarstes": "durchführbar",
    "durchführe": "durchführen",
    "durchführen": "durchfahren",
    "durchführend": "durchführen",
    "durchführende": "durchführend",
    "durchführendem": "durchführend",
    "durchführenden": "durchführend",
    "durchführender": "durchführend",
    "durchführendes": "durchführend",
    "durchführest": "durchführen",
    "durchführet": "durchführen",
    "durchführst": "durchführen",
    "durchführt": "durchführen",
    "durchführte": "durchführen",
    "durchführten": "durchführen",
    "durchführtest": "durchführen",
    "durchführtet": "durchführen",
    "durchfüttere": "durchfüttern",
    "durchfütternd": "durchfüttern",
    "durchfütterndem": "durchfütternd",
    "durchfütternder": "durchfütternd",
    "durchfütterndes": "durchfütternd",
    "durchfütterst": "durchfüttern",
    "durchfüttert": "durchfüttern",
    "durchfütterte": "durchfüttern",
    "durchfütterten": "durchfüttern",
    "durchfüttertest": "durchfüttern",
    "durchfüttertet": "durchfüttern",
    "durchgab": "durchgeben",
    "durchgaben": "durchgeben",
    "durchgabst": "durchgeben",
    "durchgabt": "durchgeben",
    "durchgearbeitet": "durcharbeiten",
    "durchgearbeitete": "durchgearbeitet",
    "durchgearbeitetem": "durchgearbeitet",
    "durchgearbeiteten": "durchgearbeitet",
    "durchgearbeiteter": "durchgearbeitet",
    "durchgearbeitetes": "durchgearbeitet",
    "durchgeatmet": "durchatmen",
    "durchgeatmete": "durchgeatmet",
    "durchgeatmetem": "durchgeatmet",
    "durchgeatmeten": "durchgeatmet",
    "durchgeatmeter": "durchgeatmet",
    "durchgeatmetes": "durchgeatmet",
    "durchgebe": "durchgeben",
    "durchgebend": "durchgeben",
    "durchgebende": "durchgebend",
    "durchgebendem": "durchgebend",
    "durchgebenden": "durchgebend",
    "durchgebender": "durchgebend",
    "durchgebendes": "durchgebend",
    "durchgebest": "durchgeben",
    "durchgebet": "durchgeben",
    "durchgebettelt": "durchbetteln",
    "durchgebettelte": "durchgebettelt",
    "durchgebetteltem": "durchgebettelt",
    "durchgebettelten": "durchgebettelt",
    "durchgebettelter": "durchgebettelt",
    "durchgebetteltes": "durchgebettelt",
    "durchgebeutelt": "durchbeuteln",
    "durchgebeutelte": "durchgebeutelt",
    "durchgebeuteltem": "durchgebeutelt",
    "durchgebeutelten": "durchgebeutelt",
    "durchgebeutelter": "durchgebeutelt",
    "durchgebeuteltes": "durchgebeutelt",
    "durchgebildet": "durchbilden",
    "durchgebildete": "durchgebildet",
    "durchgebildetem": "durchgebildet",
    "durchgebildeten": "durchgebildet",
    "durchgebildeter": "durchgebildet",
    "durchgebildetes": "durchgebildet",
    "durchgebissen": "durchbeißen",
    "durchgebissene": "durchgebissen",
    "durchgebissenem": "durchgebissen",
    "durchgebissenen": "durchgebissen",
    "durchgebissener": "durchgebissen",
    "durchgebissenere": "durchgebissen",
    "durchgebissenerem": "durchgebissen",
    "durchgebisseneren": "durchgebissen",
    "durchgebissenerer": "durchgebissen",
    "durchgebisseneres": "durchgebissen",
    "durchgebissenes": "durchgebissen",
    "durchgebissenste": "durchgebissen",
    "durchgebissenstem": "durchgebissen",
    "durchgebissensten": "durchgebissen",
    "durchgebissenster": "durchgebissen",
    "durchgebissenstes": "durchgebissen",
    "durchgeblasen": "durchblasen",
    "durchgeblasene": "durchgeblasen",
    "durchgeblasenem": "durchgeblasen",
    "durchgeblasenen": "durchgeblasen",
    "durchgeblasener": "durchgeblasen",
    "durchgeblasenes": "durchgeblasen",
    "durchgebleut": "durchbleuen",
    "durchgebleute": "durchgebleut",
    "durchgebleutem": "durchgebleut",
    "durchgebleuten": "durchgebleut",
    "durchgebleuter": "durchgebleut",
    "durchgebleutes": "durchgebleut",
    "durchgeblättert": "durchblättern",
    "durchgeblätterte": "durchgeblättert",
    "durchgeblättertem": "durchgeblättert",
    "durchgeblätterten": "durchgeblättert",
    "durchgeblätterter": "durchgeblättert",
    "durchgeblättertes": "durchgeblättert",
    "durchgebläut": "durchbläuen",
    "durchgebläute": "durchgebläut",
    "durchgebläutem": "durchgebläut",
    "durchgebläuten": "durchgebläut",
    "durchgebläuter": "durchgebläut",
    "durchgebläutere": "durchgebläut",
    "durchgebläuterem": "durchgebläut",
    "durchgebläuteren": "durchgebläut",
    "durchgebläuterer": "durchgebläut",
    "durchgebläuteres": "durchgebläut",
    "durchgebläutes": "durchgebläut",
    "durchgebläuteste": "durchgebläut",
    "durchgebläutestem": "durchgebläut",
    "durchgebläutesten": "durchgebläut",
    "durchgebläutester": "durchgebläut",
    "durchgebläutestes": "durchgebläut",
    "durchgebogen": "durchbiegen",
    "durchgebogene": "durchgebogen",
    "durchgebogenem": "durchgebogen",
    "durchgebogenen": "durchgebogen",
    "durchgebogener": "durchgebogen",
    "durchgebogenere": "durchgebogen",
    "durchgebogenerem": "durchgebogen",
    "durchgebogeneren": "durchgebogen",
    "durchgebogenerer": "durchgebogen",
    "durchgebogeneres": "durchgebogen",
    "durchgebogenes": "durchgebogen",
    "durchgebogenste": "durchgebogen",
    "durchgebogenstem": "durchgebogen",
    "durchgebogensten": "durchgebogen",
    "durchgebogenster": "durchgebogen",
    "durchgebogenstes": "durchgebogen",
    "durchgebohrt": "durchbohren",
    "durchgebohrte": "durchgebohrt",
    "durchgebohrtem": "durchgebohrt",
    "durchgebohrten": "durchgebohrt",
    "durchgebohrter": "durchgebohrt",
    "durchgebohrtere": "durchgebohrt",
    "durchgebohrterem": "durchgebohrt",
    "durchgebohrteren": "durchgebohrt",
    "durchgebohrterer": "durchgebohrt",
    "durchgebohrteres": "durchgebohrt",
    "durchgebohrtes": "durchgebohrt",
    "durchgebohrteste": "durchgebohrt",
    "durchgebohrtestem": "durchgebohrt",
    "durchgebohrtesten": "durchgebohrt",
    "durchgebohrtester": "durchgebohrt",
    "durchgebohrtestes": "durchgebohrt",
    "durchgeboxt": "durchboxen",
    "durchgeboxte": "durchgeboxt",
    "durchgeboxtem": "durchgeboxt",
    "durchgeboxten": "durchgeboxt",
    "durchgeboxter": "durchgeboxt",
    "durchgeboxtes": "durchgeboxt",
    "durchgebracht": "durchbringen",
    "durchgebrachte": "durchgebracht",
    "durchgebrachtem": "durchgebracht",
    "durchgebrachten": "durchgebracht",
    "durchgebrachter": "durchgebracht",
    "durchgebrachtes": "durchgebracht",
    "durchgebrannt": "durchbrennen",
    "durchgebrannte": "durchgebrannt",
    "durchgebranntem": "durchgebrannt",
    "durchgebrannten": "durchgebrannt",
    "durchgebrannter": "durchgebrannt",
    "durchgebranntere": "durchgebrannt",
    "durchgebrannterem": "durchgebrannt",
    "durchgebrannteren": "durchgebrannt",
    "durchgebrannterer": "durchgebrannt",
    "durchgebrannteres": "durchgebrannt",
    "durchgebranntes": "durchgebrannt",
    "durchgebrannteste": "durchgebrannt",
    "durchgebranntestem": "durchgebrannt",
    "durchgebranntesten": "durchgebrannt",
    "durchgebranntester": "durchgebrannt",
    "durchgebranntestes": "durchgebrannt",
    "durchgebraten": "durchbraten",
    "durchgebratene": "durchgebraten",
    "durchgebratenem": "durchgebraten",
    "durchgebratenen": "durchgebraten",
    "durchgebratener": "durchgebraten",
    "durchgebratenere": "durchgebraten",
    "durchgebratenerem": "durchgebraten",
    "durchgebrateneren": "durchgebraten",
    "durchgebratenerer": "durchgebraten",
    "durchgebrateneres": "durchgebraten",
    "durchgebratenes": "durchgebraten",
    "durchgebratenste": "durchgebraten",
    "durchgebratenstem": "durchgebraten",
    "durchgebratensten": "durchgebraten",
    "durchgebratenster": "durchgebraten",
    "durchgebratenstes": "durchgebraten",
    "durchgebraust": "durchbrausen",
    "durchgebrauste": "durchgebraust",
    "durchgebraustem": "durchgebraust",
    "durchgebrausten": "durchgebraust",
    "durchgebrauster": "durchgebraust",
    "durchgebraustes": "durchgebraust",
    "durchgebrochen": "durchbrechen",
    "durchgebrochene": "durchgebrochen",
    "durchgebrochenem": "durchgebrochen",
    "durchgebrochenen": "durchgebrochen",
    "durchgebrochener": "durchgebrochen",
    "durchgebrochenere": "durchgebrochen",
    "durchgebrochenerem": "durchgebrochen",
    "durchgebrocheneren": "durchgebrochen",
    "durchgebrochenerer": "durchgebrochen",
    "durchgebrocheneres": "durchgebrochen",
    "durchgebrochenes": "durchgebrochen",
    "durchgebrochenste": "durchgebrochen",
    "durchgebrochenstem": "durchgebrochen",
    "durchgebrochensten": "durchgebrochen",
    "durchgebrochenster": "durchgebrochen",
    "durchgebrochenstes": "durchgebrochen",
    "durchgebt": "durchgeben",
    "durchgebürstet": "durchbürsten",
    "durchgebürstete": "durchgebürstet",
    "durchgebürstetem": "durchgebürstet",
    "durchgebürsteten": "durchgebürstet",
    "durchgebürsteter": "durchgebürstet",
    "durchgebürstetes": "durchgebürstet",
    "durchgedacht": "durchdenken",
    "durchgedachte": "durchgedacht",
    "durchgedachtem": "durchgedacht",
    "durchgedachten": "durchgedacht",
    "durchgedachter": "durchgedacht",
    "durchgedachtere": "durchgedacht",
    "durchgedachterem": "durchgedacht",
    "durchgedachteren": "durchgedacht",
    "durchgedachterer": "durchgedacht",
    "durchgedachteres": "durchgedacht",
    "durchgedachtes": "durchgedacht",
    "durchgedachteste": "durchgedacht",
    "durchgedachtestem": "durchgedacht",
    "durchgedachtesten": "durchgedacht",
    "durchgedachtester": "durchgedacht",
    "durchgedachtestes": "durchgedacht",
    "durchgedreht": "durchdrehen",
    "durchgedrehte": "durchgedreht",
    "durchgedrehtem": "durchgedreht",
    "durchgedrehten": "durchgedreht",
    "durchgedrehter": "durchgedreht",
    "durchgedrehtere": "durchgedreht",
    "durchgedrehterem": "durchgedreht",
    "durchgedrehteren": "durchgedreht",
    "durchgedrehterer": "durchgedreht",
    "durchgedrehteres": "durchgedreht",
    "durchgedrehtes": "durchgedreht",
    "durchgedrehteste": "durchgedreht",
    "durchgedrehtestem": "durchgedreht",
    "durchgedrehtesten": "durchgedreht",
    "durchgedrehtester": "durchgedreht",
    "durchgedrehtestes": "durchgedreht",
    "durchgedrungen": "durchdringen",
    "durchgedrungene": "durchgedrungen",
    "durchgedrungenem": "durchgedrungen",
    "durchgedrungenen": "durchgedrungen",
    "durchgedrungener": "durchgedrungen",
    "durchgedrungenes": "durchgedrungen",
    "durchgedrängt": "durchdrängen",
    "durchgedrängte": "durchgedrängt",
    "durchgedrängtem": "durchgedrängt",
    "durchgedrängten": "durchgedrängt",
    "durchgedrängter": "durchgedrängt",
    "durchgedrängtere": "durchgedrängt",
    "durchgedrängterem": "durchgedrängt",
    "durchgedrängteren": "durchgedrängt",
    "durchgedrängterer": "durchgedrängt",
    "durchgedrängteres": "durchgedrängt",
    "durchgedrängtes": "durchgedrängt",
    "durchgedrängteste": "durchgedrängt",
    "durchgedrängtestem": "durchgedrängt",
    "durchgedrängtesten": "durchgedrängt",
    "durchgedrängtester": "durchgedrängt",
    "durchgedrängtestes": "durchgedrängt",
    "durchgedrückt": "durchdrücken",
    "durchgedrückte": "durchgedrückt",
    "durchgedrücktem": "durchgedrückt",
    "durchgedrückten": "durchgedrückt",
    "durchgedrückter": "durchgedrückt",
    "durchgedrücktes": "durchgedrückt",
    "durchgefahren": "durchfahren",
    "durchgefahrene": "durchgefahren",
    "durchgefahrenem": "durchgefahren",
    "durchgefahrenen": "durchgefahren",
    "durchgefahrener": "durchgefahren",
    "durchgefahrenes": "durchgefahren",
    "durchgefallen": "durchfallen",
    "durchgefallene": "durchgefallen",
    "durchgefallenem": "durchgefallen",
    "durchgefallenen": "durchgefallen",
    "durchgefallener": "durchgefallen",
    "durchgefallenes": "durchgefallen",
    "durchgefedert": "durchfedern",
    "durchgefederte": "durchgefedert",
    "durchgefedertem": "durchgefedert",
    "durchgefederten": "durchgefedert",
    "durchgefederter": "durchgefedert",
    "durchgefedertes": "durchgefedert",
    "durchgefeiert": "durchfeiern",
    "durchgefeierte": "durchgefeiert",
    "durchgefeiertem": "durchgefeiert",
    "durchgefeierten": "durchgefeiert",
    "durchgefeierter": "durchgefeiert",
    "durchgefeiertes": "durchgefeiert",
    "durchgefeilt": "durchfeilen",
    "durchgefeilte": "durchgefeilt",
    "durchgefeiltem": "durchgefeilt",
    "durchgefeilten": "durchgefeilt",
    "durchgefeilter": "durchgefeilt",
    "durchgefeiltes": "durchgefeilt",
    "durchgeflogen": "durchfliegen",
    "durchgeflogene": "durchgeflogen",
    "durchgeflogenem": "durchgeflogen",
    "durchgeflogenen": "durchgeflogen",
    "durchgeflogener": "durchgeflogen",
    "durchgeflogenes": "durchgeflogen",
    "durchgeflossen": "durchfließen",
    "durchgeflossene": "durchgeflossen",
    "durchgeflossenem": "durchgeflossen",
    "durchgeflossenen": "durchgeflossen",
    "durchgeflossener": "durchgeflossen",
    "durchgeflossenes": "durchgeflossen",
    "durchgeflutscht": "durchflutschen",
    "durchgeflutschte": "durchgeflutscht",
    "durchgeflutschtem": "durchgeflutscht",
    "durchgeflutschten": "durchgeflutscht",
    "durchgeflutschter": "durchgeflutscht",
    "durchgeflutschtere": "durchgeflutscht",
    "durchgeflutschterem": "durchgeflutscht",
    "durchgeflutschteren": "durchgeflutscht",
    "durchgeflutschterer": "durchgeflutscht",
    "durchgeflutschteres": "durchgeflutscht",
    "durchgeflutschtes": "durchgeflutscht",
    "durchgeflutschteste": "durchgeflutscht",
    "durchgeflutschtestem": "durchgeflutscht",
    "durchgeflutschtesten": "durchgeflutscht",
    "durchgeflutschtester": "durchgeflutscht",
    "durchgeflutschtestes": "durchgeflutscht",
    "durchgefochten": "durchfechten",
    "durchgefochtene": "durchgefochten",
    "durchgefochtenem": "durchgefochten",
    "durchgefochtenen": "durchgefochten",
    "durchgefochtener": "durchgefochten",
    "durchgefochtenes": "durchgefochten",
    "durchgeformt": "durchformen",
    "durchgeformte": "durchgeformt",
    "durchgeformtem": "durchgeformt",
    "durchgeformten": "durchgeformt",
    "durchgeformter": "durchgeformt",
    "durchgeformtes": "durchgeformt",
    "durchgeforstet": "durchforsten",
    "durchgeforstete": "durchgeforstet",
    "durchgeforstetem": "durchgeforstet",
    "durchgeforsteten": "durchgeforstet",
    "durchgeforsteter": "durchgeforstet",
    "durchgeforstetes": "durchgeforstet",
    "durchgefragt": "durchfragen",
    "durchgefragte": "durchgefragt",
    "durchgefragtem": "durchgefragt",
    "durchgefragten": "durchgefragt",
    "durchgefragter": "durchgefragt",
    "durchgefragtes": "durchgefragt",
    "durchgefressen": "durchfressen",
    "durchgefressene": "durchgefressen",
    "durchgefressenem": "durchgefressen",
    "durchgefressenen": "durchgefressen",
    "durchgefressener": "durchgefressen",
    "durchgefressenere": "durchgefressen",
    "durchgefressenerem": "durchgefressen",
    "durchgefresseneren": "durchgefressen",
    "durchgefressenerer": "durchgefressen",
    "durchgefresseneres": "durchgefressen",
    "durchgefressenes": "durchgefressen",
    "durchgefressenste": "durchgefressen",
    "durchgefressenstem": "durchgefressen",
    "durchgefressensten": "durchgefressen",
    "durchgefressenster": "durchgefressen",
    "durchgefressenstes": "durchgefressen",
    "durchgefroren": "durchfrieren",
    "durchgefrorene": "durchgefroren",
    "durchgefrorenem": "durchgefroren",
    "durchgefrorenen": "durchgefroren",
    "durchgefrorener": "durchgefroren",
    "durchgefrorenere": "durchgefroren",
    "durchgefrorenerem": "durchgefroren",
    "durchgefroreneren": "durchgefroren",
    "durchgefrorenerer": "durchgefroren",
    "durchgefroreneres": "durchgefroren",
    "durchgefrorenes": "durchgefroren",
    "durchgefrorenste": "durchgefroren",
    "durchgefrorenstem": "durchgefroren",
    "durchgefrorensten": "durchgefroren",
    "durchgefrorenster": "durchgefroren",
    "durchgefrorenstes": "durchgefroren",
    "durchgefunden": "durchfinden",
    "durchgefundene": "durchgefunden",
    "durchgefundenem": "durchgefunden",
    "durchgefundenen": "durchgefunden",
    "durchgefundener": "durchgefunden",
    "durchgefundenes": "durchgefunden",
    "durchgefuttert": "durchfuttern",
    "durchgefutterte": "durchgefuttert",
    "durchgefuttertem": "durchgefuttert",
    "durchgefutterten": "durchgefuttert",
    "durchgefutterter": "durchgefuttert",
    "durchgefuttertes": "durchgefuttert",
    "durchgefühlt": "durchfühlen",
    "durchgefühlte": "durchgefühlt",
    "durchgefühltem": "durchgefühlt",
    "durchgefühlten": "durchgefühlt",
    "durchgefühlter": "durchgefühlt",
    "durchgefühltes": "durchgefühlt",
    "durchgeführt": "durchführen",
    "durchgeführte": "durchgeführt",
    "durchgeführtem": "durchgeführt",
    "durchgeführten": "durchgeführt",
    "durchgeführter": "durchgeführt",
    "durchgeführtes": "durchgeführt",
    "durchgefüttert": "durchfüttern",
    "durchgefüttertem": "durchgefüttert",
    "durchgefütterter": "durchgefüttert",
    "durchgefüttertes": "durchgefüttert",
    "durchgegangen": "durchgehen",
    "durchgegangene": "durchgegangen",
    "durchgegangenem": "durchgegangen",
    "durchgegangenen": "durchgegangen",
    "durchgegangener": "durchgegangen",
    "durchgegangenes": "durchgegangen",
    "durchgegeben": "durchgeben",
    "durchgegebene": "durchgegeben",
    "durchgegebenem": "durchgegeben",
    "durchgegebenen": "durchgegeben",
    "durchgegebener": "durchgegeben",
    "durchgegebenes": "durchgegeben",
    "durchgegessen": "durchessen",
    "durchgegessene": "durchgegessen",
    "durchgegessenem": "durchgegessen",
    "durchgegessenen": "durchgegessen",
    "durchgegessener": "durchgegessen",
    "durchgegessenes": "durchgegessen",
    "durchgegliedert": "durchgliedern",
    "durchgegliederte": "durchgegliedert",
    "durchgegliedertem": "durchgegliedert",
    "durchgegliederten": "durchgegliedert",
    "durchgegliederter": "durchgegliedert",
    "durchgegliedertes": "durchgegliedert",
    "durchgeglüht": "durchglühen",
    "durchgeglühte": "durchgeglüht",
    "durchgeglühtem": "durchgeglüht",
    "durchgeglühten": "durchgeglüht",
    "durchgeglühter": "durchgeglüht",
    "durchgeglühtere": "durchgeglüht",
    "durchgeglühterem": "durchgeglüht",
    "durchgeglühteren": "durchgeglüht",
    "durchgeglühterer": "durchgeglüht",
    "durchgeglühteres": "durchgeglüht",
    "durchgeglühtes": "durchgeglüht",
    "durchgeglühteste": "durchgeglüht",
    "durchgeglühtestem": "durchgeglüht",
    "durchgeglühtesten": "durchgeglüht",
    "durchgeglühtester": "durchgeglüht",
    "durchgeglühtestes": "durchgeglüht",
    "durchgegriffen": "durchgreifen",
    "durchgegriffene": "durchgegriffen",
    "durchgegriffenem": "durchgegriffen",
    "durchgegriffenen": "durchgegriffen",
    "durchgegriffener": "durchgegriffen",
    "durchgegriffenes": "durchgegriffen",
    "durchgehalten": "durchhalten",
    "durchgehaltene": "durchgehalten",
    "durchgehaltenem": "durchgehalten",
    "durchgehaltenen": "durchgehalten",
    "durchgehaltener": "durchgehalten",
    "durchgehaltenes": "durchgehalten",
    "durchgehangen": "durchhängen",
    "durchgehangene": "durchgehangen",
    "durchgehangenem": "durchgehangen",
    "durchgehangenen": "durchgehangen",
    "durchgehangener": "durchgehangen",
    "durchgehangenes": "durchgehangen",
    "durchgehaucht": "durchhauchen",
    "durchgehauchte": "durchgehaucht",
    "durchgehauchtem": "durchgehaucht",
    "durchgehauchten": "durchgehaucht",
    "durchgehauchter": "durchgehaucht",
    "durchgehauchtes": "durchgehaucht",
    "durchgehauen": "durchhauen",
    "durchgehauene": "durchgehauen",
    "durchgehauenem": "durchgehauen",
    "durchgehauenen": "durchgehauen",
    "durchgehauener": "durchgehauen",
    "durchgehauenes": "durchgehauen",
    "durchgehe": "durchgehen",
    "durchgehechelt": "durchhecheln",
    "durchgehechelte": "durchgehechelt",
    "durchgehecheltem": "durchgehechelt",
    "durchgehechelten": "durchgehechelt",
    "durchgehechelter": "durchgehechelt",
    "durchgehecheltere": "durchgehechelt",
    "durchgehechelterem": "durchgehechelt",
    "durchgehechelteren": "durchgehechelt",
    "durchgehechelterer": "durchgehechelt",
    "durchgehechelteres": "durchgehechelt",
    "durchgehecheltes": "durchgehechelt",
    "durchgehechelteste": "durchgehechelt",
    "durchgehecheltestem": "durchgehechelt",
    "durchgehecheltesten": "durchgehechelt",
    "durchgehecheltester": "durchgehechelt",
    "durchgehecheltestes": "durchgehechelt",
    "durchgeheizt": "durchheizen",
    "durchgeheizte": "durchgeheizt",
    "durchgeheiztem": "durchgeheizt",
    "durchgeheizten": "durchgeheizt",
    "durchgeheizter": "durchgeheizt",
    "durchgeheiztere": "durchgeheizt",
    "durchgeheizterem": "durchgeheizt",
    "durchgeheizteren": "durchgeheizt",
    "durchgeheizterer": "durchgeheizt",
    "durchgeheizteres": "durchgeheizt",
    "durchgeheiztes": "durchgeheizt",
    "durchgeheizteste": "durchgeheizt",
    "durchgeheiztestem": "durchgeheizt",
    "durchgeheiztesten": "durchgeheizt",
    "durchgeheiztester": "durchgeheizt",
    "durchgeheiztestes": "durchgeheizt",
    "durchgehend": "durchgehen",
    "durchgehende": "durchgehend",
    "durchgehendem": "durchgehend",
    "durchgehenden": "durchgehend",
    "durchgehender": "durchgehend",
    "durchgehendes": "durchgehend",
    "durchgehest": "durchgehen",
    "durchgehet": "durchgehen",
    "durchgeholfen": "durchhelfen",
    "durchgeholfene": "durchgeholfen",
    "durchgeholfenem": "durchgeholfen",
    "durchgeholfenen": "durchgeholfen",
    "durchgeholfener": "durchgeholfen",
    "durchgeholfenes": "durchgeholfen",
    "durchgeholt": "durchholen",
    "durchgeholte": "durchgeholt",
    "durchgeholtem": "durchgeholt",
    "durchgeholten": "durchgeholt",
    "durchgeholter": "durchgeholt",
    "durchgeholtes": "durchgeholt",
    "durchgehst": "durchgehen",
    "durchgeht": "durchgehen",
    "durchgehungert": "durchhungern",
    "durchgehungerte": "durchgehungert",
    "durchgehungertem": "durchgehungert",
    "durchgehungerten": "durchgehungert",
    "durchgehungerter": "durchgehungert",
    "durchgehungertere": "durchgehungert",
    "durchgehungerterem": "durchgehungert",
    "durchgehungerteren": "durchgehungert",
    "durchgehungerterer": "durchgehungert",
    "durchgehungerteres": "durchgehungert",
    "durchgehungertes": "durchgehungert",
    "durchgehungerteste": "durchgehungert",
    "durchgehungertestem": "durchgehungert",
    "durchgehungertesten": "durchgehungert",
    "durchgehungertester": "durchgehungert",
    "durchgehungertestes": "durchgehungert",
    "durchgehängt": "durchhängen",
    "durchgehängte": "durchgehängt",
    "durchgehängtem": "durchgehängt",
    "durchgehängten": "durchgehängt",
    "durchgehängter": "durchgehängt",
    "durchgehängtes": "durchgehängt",
    "durchgehört": "durchhören",
    "durchgehörte": "durchgehört",
    "durchgehörtem": "durchgehört",
    "durchgehörten": "durchgehört",
    "durchgehörter": "durchgehört",
    "durchgehörtes": "durchgehört",
    "durchgejagt": "durchjagen",
    "durchgejagte": "durchgejagt",
    "durchgejagtem": "durchgejagt",
    "durchgejagten": "durchgejagt",
    "durchgejagter": "durchgejagt",
    "durchgejagtes": "durchgejagt",
    "durchgekaut": "durchkauen",
    "durchgekaute": "durchgekaut",
    "durchgekautem": "durchgekaut",
    "durchgekauten": "durchgekaut",
    "durchgekauter": "durchgekaut",
    "durchgekautere": "durchgekaut",
    "durchgekauterem": "durchgekaut",
    "durchgekauteren": "durchgekaut",
    "durchgekauterer": "durchgekaut",
    "durchgekauteres": "durchgekaut",
    "durchgekautes": "durchgekaut",
    "durchgekauteste": "durchgekaut",
    "durchgekautestem": "durchgekaut",
    "durchgekautesten": "durchgekaut",
    "durchgekautester": "durchgekaut",
    "durchgekautestes": "durchgekaut",
    "durchgeklungen": "durchklingen",
    "durchgeklungene": "durchgeklungen",
    "durchgeklungenem": "durchgeklungen",
    "durchgeklungenen": "durchgeklungen",
    "durchgeklungener": "durchgeklungen",
    "durchgeklungenes": "durchgeklungen",
    "durchgeknetet": "durchkneten",
    "durchgeknetete": "durchgeknetet",
    "durchgeknetetem": "durchgeknetet",
    "durchgekneteten": "durchgeknetet",
    "durchgekneteter": "durchgeknetet",
    "durchgeknetetere": "durchgeknetet",
    "durchgekneteterem": "durchgeknetet",
    "durchgekneteteren": "durchgeknetet",
    "durchgekneteterer": "durchgeknetet",
    "durchgekneteteres": "durchgeknetet",
    "durchgeknetetes": "durchgeknetet",
    "durchgekneteteste": "durchgeknetet",
    "durchgeknetetestem": "durchgeknetet",
    "durchgeknetetesten": "durchgeknetet",
    "durchgeknetetester": "durchgeknetet",
    "durchgeknetetestes": "durchgeknetet",
    "durchgekniffen": "durchkneifen",
    "durchgekniffene": "durchgekniffen",
    "durchgekniffenem": "durchgekniffen",
    "durchgekniffenen": "durchgekniffen",
    "durchgekniffener": "durchgekniffen",
    "durchgekniffenere": "durchgekniffen",
    "durchgekniffenerem": "durchgekniffen",
    "durchgekniffeneren": "durchgekniffen",
    "durchgekniffenerer": "durchgekniffen",
    "durchgekniffeneres": "durchgekniffen",
    "durchgekniffenes": "durchgekniffen",
    "durchgekniffenste": "durchgekniffen",
    "durchgekniffenstem": "durchgekniffen",
    "durchgekniffensten": "durchgekniffen",
    "durchgekniffenster": "durchgekniffen",
    "durchgekniffenstes": "durchgekniffen",
    "durchgeknöpft": "durchknöpfen",
    "durchgeknöpfte": "durchgeknöpft",
    "durchgeknöpftem": "durchgeknöpft",
    "durchgeknöpften": "durchgeknöpft",
    "durchgeknöpfter": "durchgeknöpft",
    "durchgeknöpftes": "durchgeknöpft",
    "durchgekommen": "durchkommen",
    "durchgekommene": "durchgekommen",
    "durchgekommenem": "durchgekommen",
    "durchgekommenen": "durchgekommen",
    "durchgekommener": "durchgekommen",
    "durchgekommenes": "durchgekommen",
    "durchgekostet": "durchkosten",
    "durchgekostete": "durchgekostet",
    "durchgekostetem": "durchgekostet",
    "durchgekosteten": "durchgekostet",
    "durchgekosteter": "durchgekostet",
    "durchgekostetes": "durchgekostet",
    "durchgekreuzt": "durchkreuzen",
    "durchgekreuzte": "durchgekreuzt",
    "durchgekreuztem": "durchgekreuzt",
    "durchgekreuzten": "durchgekreuzt",
    "durchgekreuzter": "durchgekreuzt",
    "durchgekreuztes": "durchgekreuzt",
    "durchgekriegt": "durchkriegen",
    "durchgekriegte": "durchgekriegt",
    "durchgekriegtem": "durchgekriegt",
    "durchgekriegten": "durchgekriegt",
    "durchgekriegter": "durchgekriegt",
    "durchgekriegtes": "durchgekriegt",
    "durchgekrochen": "durchkriechen",
    "durchgekrochene": "durchgekrochen",
    "durchgekrochenem": "durchgekrochen",
    "durchgekrochenen": "durchgekrochen",
    "durchgekrochener": "durchgekrochen",
    "durchgekrochenes": "durchgekrochen",
    "durchgekämmt": "durchkämmen",
    "durchgekämmte": "durchgekämmt",
    "durchgekämmtem": "durchgekämmt",
    "durchgekämmten": "durchgekämmt",
    "durchgekämmter": "durchgekämmt",
    "durchgekämmtes": "durchgekämmt",
    "durchgekämpft": "durchkämpfen",
    "durchgekämpfte": "durchgekämpft",
    "durchgekämpftem": "durchgekämpft",
    "durchgekämpften": "durchgekämpft",
    "durchgekämpfter": "durchgekämpft",
    "durchgekämpftes": "durchgekämpft",
    "durchgeladen": "durchladen",
    "durchgeladene": "durchgeladen",
    "durchgeladenem": "durchgeladen",
    "durchgeladenen": "durchgeladen",
    "durchgeladener": "durchgeladen",
    "durchgeladenes": "durchgeladen",
    "durchgelangt": "durchlangen",
    "durchgelangte": "durchgelangt",
    "durchgelangtem": "durchgelangt",
    "durchgelangten": "durchgelangt",
    "durchgelangter": "durchgelangt",
    "durchgelangtes": "durchgelangt",
    "durchgelassen": "durchlassen",
    "durchgelassene": "durchgelassen",
    "durchgelassenem": "durchgelassen",
    "durchgelassenen": "durchgelassen",
    "durchgelassener": "durchgelassen",
    "durchgelassenes": "durchgelassen",
    "durchgelaufen": "durchlaufen",
    "durchgelaufene": "durchgelaufen",
    "durchgelaufenem": "durchgelaufen",
    "durchgelaufenen": "durchgelaufen",
    "durchgelaufener": "durchgelaufen",
    "durchgelaufenes": "durchgelaufen",
    "durchgelegen": "durchliegen",
    "durchgelegene": "durchgelegen",
    "durchgelegenem": "durchgelegen",
    "durchgelegenen": "durchgelegen",
    "durchgelegener": "durchgelegen",
    "durchgelegenere": "durchgelegen",
    "durchgelegenerem": "durchgelegen",
    "durchgelegeneren": "durchgelegen",
    "durchgelegenerer": "durchgelegen",
    "durchgelegeneres": "durchgelegen",
    "durchgelegenes": "durchgelegen",
    "durchgelegenste": "durchgelegen",
    "durchgelegenstem": "durchgelegen",
    "durchgelegensten": "durchgelegen",
    "durchgelegenster": "durchgelegen",
    "durchgelegenstes": "durchgelegen",
    "durchgelesen": "durchlesen",
    "durchgelesene": "durchgelesen",
    "durchgelesenem": "durchgelesen",
    "durchgelesenen": "durchgelesen",
    "durchgelesener": "durchgelesen",
    "durchgelesenes": "durchgelesen",
    "durchgeleuchtet": "durchleuchten",
    "durchgeleuchtete": "durchgeleuchtet",
    "durchgeleuchtetem": "durchgeleuchtet",
    "durchgeleuchteten": "durchgeleuchtet",
    "durchgeleuchteter": "durchgeleuchtet",
    "durchgeleuchtetes": "durchgeleuchtet",
    "durchgelogen": "durchlügen",
    "durchgelogene": "durchgelogen",
    "durchgelogenem": "durchgelogen",
    "durchgelogenen": "durchgelogen",
    "durchgelogener": "durchgelogen",
    "durchgelogenere": "durchgelogen",
    "durchgelogenerem": "durchgelogen",
    "durchgelogeneren": "durchgelogen",
    "durchgelogenerer": "durchgelogen",
    "durchgelogeneres": "durchgelogen",
    "durchgelogenes": "durchgelogen",
    "durchgelogenste": "durchgelogen",
    "durchgelogenstem": "durchgelogen",
    "durchgelogensten": "durchgelogen",
    "durchgelogenster": "durchgelogen",
    "durchgelogenstes": "durchgelogen",
    "durchgelüftet": "durchlüften",
    "durchgelüftete": "durchgelüftet",
    "durchgelüftetem": "durchgelüftet",
    "durchgelüfteten": "durchgelüftet",
    "durchgelüfteter": "durchgelüftet",
    "durchgelüftetere": "durchgelüftet",
    "durchgelüfteterem": "durchgelüftet",
    "durchgelüfteteren": "durchgelüftet",
    "durchgelüfteterer": "durchgelüftet",
    "durchgelüfteteres": "durchgelüftet",
    "durchgelüftetes": "durchgelüftet",
    "durchgelüfteteste": "durchgelüftet",
    "durchgelüftetestem": "durchgelüftet",
    "durchgelüftetesten": "durchgelüftet",
    "durchgelüftetester": "durchgelüftet",
    "durchgelüftetestes": "durchgelüftet",
    "durchgemacht": "durchmachen",
    "durchgemachte": "durchgemacht",
    "durchgemachtem": "durchgemacht",
    "durchgemachten": "durchgemacht",
    "durchgemachter": "durchgemacht",
    "durchgemachtes": "durchgemacht",
    "durchgemessen": "durchmessen",
    "durchgemessene": "durchgemessen",
    "durchgemessenem": "durchgemessen",
    "durchgemessenen": "durchgemessen",
    "durchgemessener": "durchgemessen",
    "durchgemessenes": "durchgemessen",
    "durchgenagt": "durchnagen",
    "durchgenagte": "durchgenagt",
    "durchgenagtem": "durchgenagt",
    "durchgenagten": "durchgenagt",
    "durchgenagter": "durchgenagt",
    "durchgenagtere": "durchgenagt",
    "durchgenagterem": "durchgenagt",
    "durchgenagteren": "durchgenagt",
    "durchgenagterer": "durchgenagt",
    "durchgenagteres": "durchgenagt",
    "durchgenagtes": "durchgenagt",
    "durchgenagteste": "durchgenagt",
    "durchgenagtestem": "durchgenagt",
    "durchgenagtesten": "durchgenagt",
    "durchgenagtester": "durchgenagt",
    "durchgenagtestes": "durchgenagt",
    "durchgenommen": "durchnehmen",
    "durchgenommene": "durchgenommen",
    "durchgenommenem": "durchgenommen",
    "durchgenommenen": "durchgenommen",
    "durchgenommener": "durchgenommen",
    "durchgenommenes": "durchgenommen",
    "durchgepaukt": "durchpauken",
    "durchgepaukte": "durchgepaukt",
    "durchgepauktem": "durchgepaukt",
    "durchgepaukten": "durchgepaukt",
    "durchgepaukter": "durchgepaukt",
    "durchgepauktes": "durchgepaukt",
    "durchgepaust": "durchpausen",
    "durchgepauste": "durchgepaust",
    "durchgepaustem": "durchgepaust",
    "durchgepausten": "durchgepaust",
    "durchgepauster": "durchgepaust",
    "durchgepaustes": "durchgepaust",
    "durchgepeitscht": "durchpeitschen",
    "durchgepeitschte": "durchgepeitscht",
    "durchgepeitschtem": "durchgepeitscht",
    "durchgepeitschten": "durchgepeitscht",
    "durchgepeitschter": "durchgepeitscht",
    "durchgepeitschtere": "durchgepeitscht",
    "durchgepeitschterem": "durchgepeitscht",
    "durchgepeitschteren": "durchgepeitscht",
    "durchgepeitschterer": "durchgepeitscht",
    "durchgepeitschteres": "durchgepeitscht",
    "durchgepeitschtes": "durchgepeitscht",
    "durchgepeitschteste": "durchgepeitscht",
    "durchgepeitschtestem": "durchgepeitscht",
    "durchgepeitschtesten": "durchgepeitscht",
    "durchgepeitschtester": "durchgepeitscht",
    "durchgepeitschtestes": "durchgepeitscht",
    "durchgeplumpst": "durchplumpsen",
    "durchgeplumpste": "durchgeplumpst",
    "durchgeplumpstem": "durchgeplumpst",
    "durchgeplumpsten": "durchgeplumpst",
    "durchgeplumpster": "durchgeplumpst",
    "durchgeplumpstes": "durchgeplumpst",
    "durchgepreßt": "durchpressen",
    "durchgepreßte": "durchgepreßt",
    "durchgepreßtem": "durchgepreßt",
    "durchgepreßten": "durchgepreßt",
    "durchgepreßter": "durchgepreßt",
    "durchgepreßtes": "durchgepreßt",
    "durchgeprobt": "durchproben",
    "durchgeprobte": "durchgeprobt",
    "durchgeprobtem": "durchgeprobt",
    "durchgeprobten": "durchgeprobt",
    "durchgeprobter": "durchgeprobt",
    "durchgeprobtes": "durchgeprobt",
    "durchgeprüft": "durchprüfen",
    "durchgeprüfte": "durchgeprüft",
    "durchgeprüftem": "durchgeprüft",
    "durchgeprüften": "durchgeprüft",
    "durchgeprüfter": "durchgeprüft",
    "durchgeprüftes": "durchgeprüft",
    "durchgeprügelt": "durchprügeln",
    "durchgeprügelte": "durchgeprügelt",
    "durchgeprügeltem": "durchgeprügelt",
    "durchgeprügelten": "durchgeprügelt",
    "durchgeprügelter": "durchgeprügelt",
    "durchgeprügeltes": "durchgeprügelt",
    "durchgerannt": "durchrennen",
    "durchgerannte": "durchgerannt",
    "durchgeranntem": "durchgerannt",
    "durchgerannten": "durchgerannt",
    "durchgerannter": "durchgerannt",
    "durchgeranntes": "durchgerannt",
    "durchgerasselt": "durchrasseln",
    "durchgerasselte": "durchgerasselt",
    "durchgerasseltem": "durchgerasselt",
    "durchgerasselten": "durchgerasselt",
    "durchgerasselter": "durchgerasselt",
    "durchgerasseltes": "durchgerasselt",
    "durchgerast": "durchrasen",
    "durchgeraste": "durchgerast",
    "durchgerastem": "durchgerast",
    "durchgerasten": "durchgerast",
    "durchgeraster": "durchgerast",
    "durchgerastes": "durchgerast",
    "durchgerauscht": "durchrauschen",
    "durchgerauschte": "durchgerauscht",
    "durchgerauschtem": "durchgerauscht",
    "durchgerauschten": "durchgerauscht",
    "durchgerauschter": "durchgerauscht",
    "durchgerauschtere": "durchgerauscht",
    "durchgerauschterem": "durchgerauscht",
    "durchgerauschteren": "durchgerauscht",
    "durchgerauschterer": "durchgerauscht",
    "durchgerauschteres": "durchgerauscht",
    "durchgerauschtes": "durchgerauscht",
    "durchgerauschteste": "durchgerauscht",
    "durchgerauschtestem": "durchgerauscht",
    "durchgerauschtesten": "durchgerauscht",
    "durchgerauschtester": "durchgerauscht",
    "durchgerauschtestes": "durchgerauscht",
    "durchgerechnet": "durchrechnen",
    "durchgerechnete": "durchgerechnet",
    "durchgerechnetem": "durchgerechnet",
    "durchgerechneten": "durchgerechnet",
    "durchgerechneter": "durchgerechnet",
    "durchgerechnetes": "durchgerechnet",
    "durchgeregnet": "durchregnen",
    "durchgeregnete": "durchgeregnet",
    "durchgeregnetem": "durchgeregnet",
    "durchgeregneten": "durchgeregnet",
    "durchgeregneter": "durchgeregnet",
    "durchgeregnetes": "durchgeregnet",
    "durchgereicht": "durchreichen",
    "durchgereichte": "durchgereicht",
    "durchgereichtem": "durchgereicht",
    "durchgereichten": "durchgereicht",
    "durchgereichter": "durchgereicht",
    "durchgereichtes": "durchgereicht",
    "durchgereist": "durchreisen",
    "durchgereiste": "durchgereist",
    "durchgereistem": "durchgereist",
    "durchgereisten": "durchgereist",
    "durchgereister": "durchgereist",
    "durchgereistes": "durchgereist",
    "durchgerieben": "durchreiben",
    "durchgeriebene": "durchgerieben",
    "durchgeriebenem": "durchgerieben",
    "durchgeriebenen": "durchgerieben",
    "durchgeriebener": "durchgerieben",
    "durchgeriebenes": "durchgerieben",
    "durchgerieselt": "durchrieseln",
    "durchgerieselte": "durchgerieselt",
    "durchgerieseltem": "durchgerieselt",
    "durchgerieselten": "durchgerieselt",
    "durchgerieselter": "durchgerieselt",
    "durchgerieseltes": "durchgerieselt",
    "durchgerissen": "durchreißen",
    "durchgerissene": "durchgerissen",
    "durchgerissenem": "durchgerissen",
    "durchgerissenen": "durchgerissen",
    "durchgerissener": "durchgerissen",
    "durchgerissenere": "durchgerissen",
    "durchgerissenerem": "durchgerissen",
    "durchgerisseneren": "durchgerissen",
    "durchgerissenerer": "durchgerissen",
    "durchgerisseneres": "durchgerissen",
    "durchgerissenes": "durchgerissen",
    "durchgerissenste": "durchgerissen",
    "durchgerissenstem": "durchgerissen",
    "durchgerissensten": "durchgerissen",
    "durchgerissenster": "durchgerissen",
    "durchgerissenstes": "durchgerissen",
    "durchgeritten": "durchreiten",
    "durchgerittene": "durchgeritten",
    "durchgerittenem": "durchgeritten",
    "durchgerittenen": "durchgeritten",
    "durchgerittener": "durchgeritten",
    "durchgerittenes": "durchgeritten",
    "durchgerostet": "durchrosten",
    "durchgerostete": "durchgerostet",
    "durchgerostetem": "durchgerostet",
    "durchgerosteten": "durchgerostet",
    "durchgerosteter": "durchgerostet",
    "durchgerostetere": "durchgerostet",
    "durchgerosteterem": "durchgerostet",
    "durchgerosteteren": "durchgerostet",
    "durchgerosteterer": "durchgerostet",
    "durchgerosteteres": "durchgerostet",
    "durchgerostetes": "durchgerostet",
    "durchgerosteteste": "durchgerostet",
    "durchgerostetestem": "durchgerostet",
    "durchgerostetesten": "durchgerostet",
    "durchgerostetester": "durchgerostet",
    "durchgerostetestes": "durchgerostet",
    "durchgerufen": "durchrufen",
    "durchgerufene": "durchgerufen",
    "durchgerufenem": "durchgerufen",
    "durchgerufenen": "durchgerufen",
    "durchgerufener": "durchgerufen",
    "durchgerufenes": "durchgerufen",
    "durchgerungen": "durchringen",
    "durchgerungene": "durchgerungen",
    "durchgerungenem": "durchgerungen",
    "durchgerungenen": "durchgerungen",
    "durchgerungener": "durchgerungen",
    "durchgerungenes": "durchgerungen",
    "durchgerutscht": "durchrutschen",
    "durchgerutschte": "durchgerutscht",
    "durchgerutschtem": "durchgerutscht",
    "durchgerutschten": "durchgerutscht",
    "durchgerutschter": "durchgerutscht",
    "durchgerutschtes": "durchgerutscht",
    "durchgerührt": "durchrühren",
    "durchgerührte": "durchgerührt",
    "durchgerührtem": "durchgerührt",
    "durchgerührten": "durchgerührt",
    "durchgerührter": "durchgerührt",
    "durchgerührtere": "durchgerührt",
    "durchgerührterem": "durchgerührt",
    "durchgerührteren": "durchgerührt",
    "durchgerührterer": "durchgerührt",
    "durchgerührteres": "durchgerührt",
    "durchgerührtes": "durchgerührt",
    "durchgerührteste": "durchgerührt",
    "durchgerührtestem": "durchgerührt",
    "durchgerührtesten": "durchgerührt",
    "durchgerührtester": "durchgerührt",
    "durchgerührtestes": "durchgerührt",
    "durchgerüttelt": "durchrütteln",
    "durchgerüttelte": "durchgerüttelt",
    "durchgerütteltem": "durchgerüttelt",
    "durchgerüttelten": "durchgerüttelt",
    "durchgerüttelter": "durchgerüttelt",
    "durchgerütteltere": "durchgerüttelt",
    "durchgerüttelterem": "durchgerüttelt",
    "durchgerüttelteren": "durchgerüttelt",
    "durchgerüttelterer": "durchgerüttelt",
    "durchgerüttelteres": "durchgerüttelt",
    "durchgerütteltes": "durchgerüttelt",
    "durchgerüttelteste": "durchgerüttelt",
    "durchgerütteltestem": "durchgerüttelt",
    "durchgerütteltesten": "durchgerüttelt",
    "durchgerütteltester": "durchgerüttelt",
    "durchgerütteltestes": "durchgerüttelt",
    "durchgesagt": "durchsagen",
    "durchgesagte": "durchgesagt",
    "durchgesagtem": "durchgesagt",
    "durchgesagten": "durchgesagt",
    "durchgesagter": "durchgesagt",
    "durchgesagtes": "durchgesagt",
    "durchgesaugt": "durchsaugen",
    "durchgesaugte": "durchgesaugt",
    "durchgesaugtem": "durchgesaugt",
    "durchgesaugten": "durchgesaugt",
    "durchgesaugter": "durchgesaugt",
    "durchgesaugtes": "durchgesaugt",
    "durchgesaust": "durchsausen",
    "durchgesauste": "durchgesaust",
    "durchgesaustem": "durchgesaust",
    "durchgesausten": "durchgesaust",
    "durchgesauster": "durchgesaust",
    "durchgesaustes": "durchgesaust",
    "durchgeschabt": "durchschaben",
    "durchgeschabte": "durchgeschabt",
    "durchgeschabtem": "durchgeschabt",
    "durchgeschabten": "durchgeschabt",
    "durchgeschabter": "durchgeschabt",
    "durchgeschabtere": "durchgeschabt",
    "durchgeschabterem": "durchgeschabt",
    "durchgeschabteren": "durchgeschabt",
    "durchgeschabterer": "durchgeschabt",
    "durchgeschabteres": "durchgeschabt",
    "durchgeschabtes": "durchgeschabt",
    "durchgeschabteste": "durchgeschabt",
    "durchgeschabtestem": "durchgeschabt",
    "durchgeschabtesten": "durchgeschabt",
    "durchgeschabtester": "durchgeschabt",
    "durchgeschabtestes": "durchgeschabt",
    "durchgeschallt": "durchschallen",
    "durchgeschallte": "durchgeschallt",
    "durchgeschalltem": "durchgeschallt",
    "durchgeschallten": "durchgeschallt",
    "durchgeschallter": "durchgeschallt",
    "durchgeschalltes": "durchgeschallt",
    "durchgeschaute": "durchgeschaut",
    "durchgeschautem": "durchgeschaut",
    "durchgeschauten": "durchgeschaut",
    "durchgeschauter": "durchgeschaut",
    "durchgeschautes": "durchgeschaut",
    "durchgescheuert": "durchscheuern",
    "durchgescheuerte": "durchgescheuert",
    "durchgescheuertem": "durchgescheuert",
    "durchgescheuerten": "durchgescheuert",
    "durchgescheuerter": "durchgescheuert",
    "durchgescheuertere": "durchgescheuert",
    "durchgescheuerterem": "durchgescheuert",
    "durchgescheuerteren": "durchgescheuert",
    "durchgescheuerterer": "durchgescheuert",
    "durchgescheuerteres": "durchgescheuert",
    "durchgescheuertes": "durchgescheuert",
    "durchgescheuerteste": "durchgescheuert",
    "durchgescheuertestem": "durchgescheuert",
    "durchgescheuertesten": "durchgescheuert",
    "durchgescheuertester": "durchgescheuert",
    "durchgescheuertestes": "durchgescheuert",
    "durchgeschienen": "durchscheinen",
    "durchgeschienene": "durchgeschienen",
    "durchgeschienenem": "durchgeschienen",
    "durchgeschienenen": "durchgeschienen",
    "durchgeschienener": "durchgeschienen",
    "durchgeschienenes": "durchgeschienen",
    "durchgeschimmert": "durchschimmern",
    "durchgeschimmerte": "durchgeschimmert",
    "durchgeschimmertem": "durchgeschimmert",
    "durchgeschimmerten": "durchgeschimmert",
    "durchgeschimmerter": "durchgeschimmert",
    "durchgeschimmertere": "durchgeschimmert",
    "durchgeschimmerterem": "durchgeschimmert",
    "durchgeschimmerteren": "durchgeschimmert",
    "durchgeschimmerterer": "durchgeschimmert",
    "durchgeschimmerteres": "durchgeschimmert",
    "durchgeschimmertes": "durchgeschimmert",
    "durchgeschimmerteste": "durchgeschimmert",
    "durchgeschimmertestem": "durchgeschimmert",
    "durchgeschimmertesten": "durchgeschimmert",
    "durchgeschimmertester": "durchgeschimmert",
    "durchgeschimmertestes": "durchgeschimmert",
    "durchgeschlafen": "durchschlafen",
    "durchgeschlafene": "durchgeschlafen",
    "durchgeschlafenem": "durchgeschlafen",
    "durchgeschlafenen": "durchgeschlafen",
    "durchgeschlafener": "durchgeschlafen",
    "durchgeschlafenes": "durchgeschlafen",
    "durchgeschlagen": "durchschlagen",
    "durchgeschlagene": "durchgeschlagen",
    "durchgeschlagenem": "durchgeschlagen",
    "durchgeschlagenen": "durchgeschlagen",
    "durchgeschlagener": "durchgeschlagen",
    "durchgeschlagenes": "durchgeschlagen",
    "durchgeschleppt": "durchschleppen",
    "durchgeschleppte": "durchgeschleppt",
    "durchgeschlepptem": "durchgeschleppt",
    "durchgeschleppten": "durchgeschleppt",
    "durchgeschleppter": "durchgeschleppt",
    "durchgeschlepptes": "durchgeschleppt",
    "durchgeschleust": "durchschleusen",
    "durchgeschleuste": "durchgeschleust",
    "durchgeschleustem": "durchgeschleust",
    "durchgeschleusten": "durchgeschleust",
    "durchgeschleuster": "durchgeschleust",
    "durchgeschleustes": "durchgeschleust",
    "durchgeschlichen": "durchschleichen",
    "durchgeschlichene": "durchgeschlichen",
    "durchgeschlichenem": "durchgeschlichen",
    "durchgeschlichenen": "durchgeschlichen",
    "durchgeschlichener": "durchgeschlichen",
    "durchgeschlichenes": "durchgeschlichen",
    "durchgeschlungen": "durchschlingen",
    "durchgeschlungene": "durchgeschlungen",
    "durchgeschlungenem": "durchgeschlungen",
    "durchgeschlungenen": "durchgeschlungen",
    "durchgeschlungener": "durchgeschlungen",
    "durchgeschlungenes": "durchgeschlungen",
    "durchgeschlängelt": "durchschlängeln",
    "durchgeschlängelte": "durchgeschlängelt",
    "durchgeschlängeltem": "durchgeschlängelt",
    "durchgeschlängelten": "durchgeschlängelt",
    "durchgeschlängelter": "durchgeschlängelt",
    "durchgeschlängeltes": "durchgeschlängelt",
    "durchgeschlüpft": "durchschlüpfen",
    "durchgeschlüpfte": "durchgeschlüpft",
    "durchgeschlüpftem": "durchgeschlüpft",
    "durchgeschlüpften": "durchgeschlüpft",
    "durchgeschlüpfter": "durchgeschlüpft",
    "durchgeschlüpftes": "durchgeschlüpft",
    "durchgeschmolzen": "durchschmelzen",
    "durchgeschmolzene": "durchgeschmolzen",
    "durchgeschmolzenem": "durchgeschmolzen",
    "durchgeschmolzenen": "durchgeschmolzen",
    "durchgeschmolzener": "durchgeschmolzen",
    "durchgeschmolzenes": "durchgeschmolzen",
    "durchgeschmuggelt": "durchschmuggeln",
    "durchgeschmuggelte": "durchgeschmuggelt",
    "durchgeschmuggeltem": "durchgeschmuggelt",
    "durchgeschmuggelten": "durchgeschmuggelt",
    "durchgeschmuggelter": "durchgeschmuggelt",
    "durchgeschmuggeltes": "durchgeschmuggelt",
    "durchgeschnitten": "durchschneiden",
    "durchgeschnittene": "durchgeschnitten",
    "durchgeschnittenem": "durchgeschnitten",
    "durchgeschnittenen": "durchgeschnitten",
    "durchgeschnittener": "durchgeschnitten",
    "durchgeschnittenere": "durchgeschnitten",
    "durchgeschnittenerem": "durchgeschnitten",
    "durchgeschnitteneren": "durchgeschnitten",
    "durchgeschnittenerer": "durchgeschnitten",
    "durchgeschnitteneres": "durchgeschnitten",
    "durchgeschnittenes": "durchgeschnitten",
    "durchgeschnittenste": "durchgeschnitten",
    "durchgeschnittenstem": "durchgeschnitten",
    "durchgeschnittensten": "durchgeschnitten",
    "durchgeschnittenster": "durchgeschnitten",
    "durchgeschnittenstes": "durchgeschnitten",
    "durchgeschoben": "durchschieben",
    "durchgeschobene": "durchgeschoben",
    "durchgeschobenem": "durchgeschoben",
    "durchgeschobenen": "durchgeschoben",
    "durchgeschobener": "durchgeschoben",
    "durchgeschobenes": "durchgeschoben",
    "durchgeschossen": "durchschießen",
    "durchgeschossene": "durchgeschossen",
    "durchgeschossenem": "durchgeschossen",
    "durchgeschossenen": "durchgeschossen",
    "durchgeschossener": "durchgeschossen",
    "durchgeschossenere": "durchgeschossen",
    "durchgeschossenerem": "durchgeschossen",
    "durchgeschosseneren": "durchgeschossen",
    "durchgeschossenerer": "durchgeschossen",
    "durchgeschosseneres": "durchgeschossen",
    "durchgeschossenes": "durchgeschossen",
    "durchgeschossenste": "durchgeschossen",
    "durchgeschossenstem": "durchgeschossen",
    "durchgeschossensten": "durchgeschossen",
    "durchgeschossenster": "durchgeschossen",
    "durchgeschossenstes": "durchgeschossen",
    "durchgeschrieben": "durchschreiben",
    "durchgeschriebene": "durchgeschrieben",
    "durchgeschriebenem": "durchgeschrieben",
    "durchgeschriebenen": "durchgeschrieben",
    "durchgeschriebener": "durchgeschrieben",
    "durchgeschriebenes": "durchgeschrieben",
    "durchgeschwindelt": "durchschwindeln",
    "durchgeschwindelte": "durchgeschwindelt",
    "durchgeschwindeltem": "durchgeschwindelt",
    "durchgeschwindelten": "durchgeschwindelt",
    "durchgeschwindelter": "durchgeschwindelt",
    "durchgeschwindeltes": "durchgeschwindelt",
    "durchgeschwitzt": "durchschwitzen",
    "durchgeschwitzte": "durchgeschwitzt",
    "durchgeschwitztem": "durchgeschwitzt",
    "durchgeschwitzten": "durchgeschwitzt",
    "durchgeschwitzter": "durchgeschwitzt",
    "durchgeschwitztere": "durchgeschwitzt",
    "durchgeschwitzterem": "durchgeschwitzt",
    "durchgeschwitzteren": "durchgeschwitzt",
    "durchgeschwitzterer": "durchgeschwitzt",
    "durchgeschwitzteres": "durchgeschwitzt",
    "durchgeschwitztes": "durchgeschwitzt",
    "durchgeschwitzteste": "durchgeschwitzt",
    "durchgeschwitztestem": "durchgeschwitzt",
    "durchgeschwitztesten": "durchgeschwitzt",
    "durchgeschwitztester": "durchgeschwitzt",
    "durchgeschwitztestes": "durchgeschwitzt",
    "durchgeschwommen": "durchschwimmen",
    "durchgeschwommene": "durchgeschwommen",
    "durchgeschwommenem": "durchgeschwommen",
    "durchgeschwommenen": "durchgeschwommen",
    "durchgeschwommener": "durchgeschwommen",
    "durchgeschwommenes": "durchgeschwommen",
    "durchgeschüttelt": "durchschütteln",
    "durchgeschüttelte": "durchgeschüttelt",
    "durchgeschütteltem": "durchgeschüttelt",
    "durchgeschüttelten": "durchgeschüttelt",
    "durchgeschüttelter": "durchgeschüttelt",
    "durchgeschütteltere": "durchgeschüttelt",
    "durchgeschüttelterem": "durchgeschüttelt",
    "durchgeschüttelteren": "durchgeschüttelt",
    "durchgeschüttelterer": "durchgeschüttelt",
    "durchgeschüttelteres": "durchgeschüttelt",
    "durchgeschütteltes": "durchgeschüttelt",
    "durchgeschüttelteste": "durchgeschüttelt",
    "durchgeschütteltestem": "durchgeschüttelt",
    "durchgeschütteltesten": "durchgeschüttelt",
    "durchgeschütteltester": "durchgeschüttelt",
    "durchgeschütteltestes": "durchgeschüttelt",
    "durchgesehen": "durchsehen",
    "durchgesehene": "durchgesehen",
    "durchgesehenem": "durchgesehen",
    "durchgesehenen": "durchgesehen",
    "durchgesehener": "durchgesehen",
    "durchgesehenes": "durchgesehen",
    "durchgesessen": "durchsitzen",
    "durchgesessene": "durchgesessen",
    "durchgesessenem": "durchgesessen",
    "durchgesessenen": "durchgesessen",
    "durchgesessener": "durchgesessen",
    "durchgesessenere": "durchgesessen",
    "durchgesessenerem": "durchgesessen",
    "durchgesesseneren": "durchgesessen",
    "durchgesessenerer": "durchgesessen",
    "durchgesesseneres": "durchgesessen",
    "durchgesessenes": "durchgesessen",
    "durchgesessenste": "durchgesessen",
    "durchgesessenstem": "durchgesessen",
    "durchgesessensten": "durchgesessen",
    "durchgesessenster": "durchgesessen",
    "durchgesessenstes": "durchgesessen",
    "durchgesetzt": "durchsetzen",
    "durchgesetzte": "durchgesetzt",
    "durchgesetztem": "durchgesetzt",
    "durchgesetzten": "durchgesetzt",
    "durchgesetzter": "durchgesetzt",
    "durchgesetztes": "durchgesetzt",
    "durchgesiebt": "durchsieben",
    "durchgesiebte": "durchgesiebt",
    "durchgesiebtem": "durchgesiebt",
    "durchgesiebten": "durchgesiebt",
    "durchgesiebter": "durchgesiebt",
    "durchgesiebtere": "durchgesiebt",
    "durchgesiebterem": "durchgesiebt",
    "durchgesiebteren": "durchgesiebt",
    "durchgesiebterer": "durchgesiebt",
    "durchgesiebteres": "durchgesiebt",
    "durchgesiebtes": "durchgesiebt",
    "durchgesiebteste": "durchgesiebt",
    "durchgesiebtestem": "durchgesiebt",
    "durchgesiebtesten": "durchgesiebt",
    "durchgesiebtester": "durchgesiebt",
    "durchgesiebtestes": "durchgesiebt",
    "durchgesoffen": "durchsaufen",
    "durchgesoffene": "durchgesoffen",
    "durchgesoffenem": "durchgesoffen",
    "durchgesoffenen": "durchgesoffen",
    "durchgesoffener": "durchgesoffen",
    "durchgesoffenes": "durchgesoffen",
    "durchgesogen": "durchsaugen",
    "durchgesogene": "durchgesogen",
    "durchgesogenem": "durchgesogen",
    "durchgesogenen": "durchgesogen",
    "durchgesogener": "durchgesogen",
    "durchgesogenes": "durchgesogen",
    "durchgespielt": "durchspielen",
    "durchgespielte": "durchgespielt",
    "durchgespieltem": "durchgespielt",
    "durchgespielten": "durchgespielt",
    "durchgespielter": "durchgespielt",
    "durchgespieltes": "durchgespielt",
    "durchgesprochen": "durchsprechen",
    "durchgesprochene": "durchgesprochen",
    "durchgesprochenem": "durchgesprochen",
    "durchgesprochenen": "durchgesprochen",
    "durchgesprochener": "durchgesprochen",
    "durchgesprochenere": "durchgesprochen",
    "durchgesprochenerem": "durchgesprochen",
    "durchgesprocheneren": "durchgesprochen",
    "durchgesprochenerer": "durchgesprochen",
    "durchgesprocheneres": "durchgesprochen",
    "durchgesprochenes": "durchgesprochen",
    "durchgesprochenste": "durchgesprochen",
    "durchgesprochenstem": "durchgesprochen",
    "durchgesprochensten": "durchgesprochen",
    "durchgesprochenster": "durchgesprochen",
    "durchgesprochenstes": "durchgesprochen",
    "durchgesprungen": "durchspringen",
    "durchgesprungene": "durchgesprungen",
    "durchgesprungenem": "durchgesprungen",
    "durchgesprungenen": "durchgesprungen",
    "durchgesprungener": "durchgesprungen",
    "durchgesprungenes": "durchgesprungen",
    "durchgespült": "durchspülen",
    "durchgespülte": "durchgespült",
    "durchgespültem": "durchgespült",
    "durchgespülten": "durchgespült",
    "durchgespülter": "durchgespült",
    "durchgespültes": "durchgespült",
    "durchgestanden": "durchstehen",
    "durchgestandene": "durchgestanden",
    "durchgestandenem": "durchgestanden",
    "durchgestandenen": "durchgestanden",
    "durchgestandener": "durchgestanden",
    "durchgestandenes": "durchgestanden",
    "durchgestartet": "durchstarten",
    "durchgestartete": "durchgestartet",
    "durchgestartetem": "durchgestartet",
    "durchgestarteten": "durchgestartet",
    "durchgestarteter": "durchgestartet",
    "durchgestartetes": "durchgestartet",
    "durchgestellt": "durchstellen",
    "durchgestellte": "durchgestellt",
    "durchgestelltem": "durchgestellt",
    "durchgestellten": "durchgestellt",
    "durchgestellter": "durchgestellt",
    "durchgestelltes": "durchgestellt",
    "durchgestiegen": "durchsteigen",
    "durchgestiegene": "durchgestiegen",
    "durchgestiegenem": "durchgestiegen",
    "durchgestiegenen": "durchgestiegen",
    "durchgestiegener": "durchgestiegen",
    "durchgestiegenes": "durchgestiegen",
    "durchgestimmt": "durchstimmen",
    "durchgestimmte": "durchgestimmt",
    "durchgestimmtem": "durchgestimmt",
    "durchgestimmten": "durchgestimmt",
    "durchgestimmter": "durchgestimmt",
    "durchgestimmtere": "durchgestimmt",
    "durchgestimmterem": "durchgestimmt",
    "durchgestimmteren": "durchgestimmt",
    "durchgestimmterer": "durchgestimmt",
    "durchgestimmteres": "durchgestimmt",
    "durchgestimmtes": "durchgestimmt",
    "durchgestimmteste": "durchgestimmt",
    "durchgestimmtestem": "durchgestimmt",
    "durchgestimmtesten": "durchgestimmt",
    "durchgestimmtester": "durchgestimmt",
    "durchgestimmtestes": "durchgestimmt",
    "durchgestochen": "durchstechen",
    "durchgestochene": "durchgestochen",
    "durchgestochenem": "durchgestochen",
    "durchgestochenen": "durchgestochen",
    "durchgestochener": "durchgestochen",
    "durchgestochenes": "durchgestochen",
    "durchgestoßen": "durchstoßen",
    "durchgestoßene": "durchgestoßen",
    "durchgestoßenem": "durchgestoßen",
    "durchgestoßenen": "durchgestoßen",
    "durchgestoßener": "durchgestoßen",
    "durchgestoßenes": "durchgestoßen",
    "durchgestrichen": "durchstreichen",
    "durchgestrichene": "durchgestrichen",
    "durchgestrichenem": "durchgestrichen",
    "durchgestrichenen": "durchgestrichen",
    "durchgestrichener": "durchgestrichen",
    "durchgestrichenes": "durchgestrichen",
    "durchgestürmt": "durchstürmen",
    "durchgestürmte": "durchgestürmt",
    "durchgestürmtem": "durchgestürmt",
    "durchgestürmten": "durchgestürmt",
    "durchgestürmter": "durchgestürmt",
    "durchgestürmtes": "durchgestürmt",
    "durchgesucht": "durchsuchen",
    "durchgesuchte": "durchgesucht",
    "durchgesuchtem": "durchgesucht",
    "durchgesuchten": "durchgesucht",
    "durchgesuchter": "durchgesucht",
    "durchgesuchtes": "durchgesucht",
    "durchgesungen": "durchsingen",
    "durchgesungene": "durchgesungen",
    "durchgesungenem": "durchgesungen",
    "durchgesungenen": "durchgesungen",
    "durchgesungener": "durchgesungen",
    "durchgesungenes": "durchgesungen",
    "durchgesunken": "durchsinken",
    "durchgesunkene": "durchgesunken",
    "durchgesunkenem": "durchgesunken",
    "durchgesunkenen": "durchgesunken",
    "durchgesunkener": "durchgesunken",
    "durchgesunkenes": "durchgesunken",
    "durchgesägt": "durchsägen",
    "durchgesägtem": "durchgesägt",
    "durchgesägter": "durchgesägt",
    "durchgesägtes": "durchgesägt",
    "durchgetanzt": "durchtanzen",
    "durchgetanzte": "durchgetanzt",
    "durchgetanztem": "durchgetanzt",
    "durchgetanzten": "durchgetanzt",
    "durchgetanzter": "durchgetanzt",
    "durchgetanztes": "durchgetanzt",
    "durchgetestet": "durchtesten",
    "durchgetestete": "durchgetestet",
    "durchgetestetem": "durchgetestet",
    "durchgetesteten": "durchgetestet",
    "durchgetesteter": "durchgetestet",
    "durchgetestetere": "durchgetestet",
    "durchgetesteterem": "durchgetestet",
    "durchgetesteteren": "durchgetestet",
    "durchgetesteterer": "durchgetestet",
    "durchgetesteteres": "durchgetestet",
    "durchgetestetes": "durchgetestet",
    "durchgetesteteste": "durchgetestet",
    "durchgetestetestem": "durchgetestet",
    "durchgetestetesten": "durchgetestet",
    "durchgetestetester": "durchgetestet",
    "durchgetestetestes": "durchgetestet",
    "durchgetrennt": "durchtrennen",
    "durchgetrennte": "durchgetrennt",
    "durchgetrenntem": "durchgetrennt",
    "durchgetrennten": "durchgetrennt",
    "durchgetrennter": "durchgetrennt",
    "durchgetrenntes": "durchgetrennt",
    "durchgetreten": "durchtreten",
    "durchgetretene": "durchgetreten",
    "durchgetretenem": "durchgetreten",
    "durchgetretenen": "durchgetreten",
    "durchgetretener": "durchgetreten",
    "durchgetretenes": "durchgetreten",
    "durchgetrieben": "durchtreiben",
    "durchgetriebene": "durchgetrieben",
    "durchgetriebenem": "durchgetrieben",
    "durchgetriebenen": "durchgetrieben",
    "durchgetriebener": "durchgetrieben",
    "durchgetriebenes": "durchgetrieben",
    "durchgewandert": "durchwandern",
    "durchgewanderte": "durchgewandert",
    "durchgewandertem": "durchgewandert",
    "durchgewanderten": "durchgewandert",
    "durchgewanderter": "durchgewandert",
    "durchgewandertes": "durchgewandert",
    "durchgewaschen": "durchwaschen",
    "durchgewaschene": "durchgewaschen",
    "durchgewaschenem": "durchgewaschen",
    "durchgewaschenen": "durchgewaschen",
    "durchgewaschener": "durchgewaschen",
    "durchgewaschenes": "durchgewaschen",
    "durchgewebt": "durchweben",
    "durchgewebte": "durchgewebt",
    "durchgewebtem": "durchgewebt",
    "durchgewebten": "durchgewebt",
    "durchgewebter": "durchgewebt",
    "durchgewebtes": "durchgewebt",
    "durchgeweicht": "durchweichen",
    "durchgeweichte": "durchgeweicht",
    "durchgeweichtem": "durchgeweicht",
    "durchgeweichten": "durchgeweicht",
    "durchgeweichter": "durchgeweicht",
    "durchgeweichtere": "durchgeweicht",
    "durchgeweichterem": "durchgeweicht",
    "durchgeweichteren": "durchgeweicht",
    "durchgeweichterer": "durchgeweicht",
    "durchgeweichteres": "durchgeweicht",
    "durchgeweichtes": "durchgeweicht",
    "durchgeweichteste": "durchgeweicht",
    "durchgeweichtestem": "durchgeweicht",
    "durchgeweichtesten": "durchgeweicht",
    "durchgeweichtester": "durchgeweicht",
    "durchgeweichtestes": "durchgeweicht",
    "durchgewetzt": "durchwetzen",
    "durchgewetzte": "durchgewetzt",
    "durchgewetztem": "durchgewetzt",
    "durchgewetzten": "durchgewetzt",
    "durchgewetzter": "durchgewetzt",
    "durchgewetztere": "durchgewetzt",
    "durchgewetzterem": "durchgewetzt",
    "durchgewetzteren": "durchgewetzt",
    "durchgewetzterer": "durchgewetzt",
    "durchgewetzteres": "durchgewetzt",
    "durchgewetztes": "durchgewetzt",
    "durchgewetzteste": "durchgewetzt",
    "durchgewetztestem": "durchgewetzt",
    "durchgewetztesten": "durchgewetzt",
    "durchgewetztester": "durchgewetzt",
    "durchgewetztestes": "durchgewetzt",
    "durchgewichen": "durchweichen",
    "durchgewichene": "durchgewichen",
    "durchgewichenem": "durchgewichen",
    "durchgewichenen": "durchgewichen",
    "durchgewichener": "durchgewichen",
    "durchgewichenere": "durchgewichen",
    "durchgewichenerem": "durchgewichen",
    "durchgewicheneren": "durchgewichen",
    "durchgewichenerer": "durchgewichen",
    "durchgewicheneres": "durchgewichen",
    "durchgewichenes": "durchgewichen",
    "durchgewichenste": "durchgewichen",
    "durchgewichenstem": "durchgewichen",
    "durchgewichensten": "durchgewichen",
    "durchgewichenster": "durchgewichen",
    "durchgewichenstes": "durchgewichen",
    "durchgewirkt": "durchwirken",
    "durchgewirkte": "durchgewirkt",
    "durchgewirktem": "durchgewirkt",
    "durchgewirkten": "durchgewirkt",
    "durchgewirkter": "durchgewirkt",
    "durchgewirktes": "durchgewirkt",
    "durchgewischt": "durchwischen",
    "durchgewischte": "durchgewischt",
    "durchgewischtem": "durchgewischt",
    "durchgewischten": "durchgewischt",
    "durchgewischter": "durchgewischt",
    "durchgewischtes": "durchgewischt",
    "durchgewoben": "durchweben",
    "durchgewobene": "durchgewoben",
    "durchgewobenem": "durchgewoben",
    "durchgewobenen": "durchgewoben",
    "durchgewobener": "durchgewoben",
    "durchgewobenes": "durchgewoben",
    "durchgewunden": "durchwinden",
    "durchgewundene": "durchgewunden",
    "durchgewundenem": "durchgewunden",
    "durchgewundenen": "durchgewunden",
    "durchgewundener": "durchgewunden",
    "durchgewundenes": "durchgewunden",
    "durchgewurstelt": "durchwursteln",
    "durchgewurstelte": "durchgewurstelt",
    "durchgewursteltem": "durchgewurstelt",
    "durchgewurstelten": "durchgewurstelt",
    "durchgewurstelter": "durchgewurstelt",
    "durchgewursteltere": "durchgewurstelt",
    "durchgewurstelterem": "durchgewurstelt",
    "durchgewurstelteren": "durchgewurstelt",
    "durchgewurstelterer": "durchgewurstelt",
    "durchgewurstelteres": "durchgewurstelt",
    "durchgewursteltes": "durchgewurstelt",
    "durchgewurstelteste": "durchgewurstelt",
    "durchgewursteltestem": "durchgewurstelt",
    "durchgewursteltesten": "durchgewurstelt",
    "durchgewursteltester": "durchgewurstelt",
    "durchgewursteltestes": "durchgewurstelt",
    "durchgewählt": "durchwählen",
    "durchgewählte": "durchgewählt",
    "durchgewähltem": "durchgewählt",
    "durchgewählten": "durchgewählt",
    "durchgewählter": "durchgewählt",
    "durchgewähltes": "durchgewählt",
    "durchgewärmt": "durchwärmen",
    "durchgewärmte": "durchgewärmt",
    "durchgewärmtem": "durchgewärmt",
    "durchgewärmten": "durchgewärmt",
    "durchgewärmter": "durchgewärmt",
    "durchgewärmtere": "durchgewärmt",
    "durchgewärmterem": "durchgewärmt",
    "durchgewärmteren": "durchgewärmt",
    "durchgewärmterer": "durchgewärmt",
    "durchgewärmteres": "durchgewärmt",
    "durchgewärmtes": "durchgewärmt",
    "durchgewärmteste": "durchgewärmt",
    "durchgewärmtestem": "durchgewärmt",
    "durchgewärmtesten": "durchgewärmt",
    "durchgewärmtester": "durchgewärmt",
    "durchgewärmtestes": "durchgewärmt",
    "durchgewühlt": "durchwühlen",
    "durchgewühlte": "durchgewühlt",
    "durchgewühltem": "durchgewühlt",
    "durchgewühlten": "durchgewühlt",
    "durchgewühlter": "durchgewühlt",
    "durchgewühltere": "durchgewühlt",
    "durchgewühlterem": "durchgewühlt",
    "durchgewühlteren": "durchgewühlt",
    "durchgewühlterer": "durchgewühlt",
    "durchgewühlteres": "durchgewühlt",
    "durchgewühltes": "durchgewühlt",
    "durchgewühlteste": "durchgewühlt",
    "durchgewühltestem": "durchgewühlt",
    "durchgewühltesten": "durchgewühlt",
    "durchgewühltester": "durchgewühlt",
    "durchgewühltestes": "durchgewühlt",
    "durchgezecht": "durchzechen",
    "durchgezechte": "durchgezecht",
    "durchgezechtem": "durchgezecht",
    "durchgezechten": "durchgezecht",
    "durchgezechter": "durchgezecht",
    "durchgezechtere": "durchgezecht",
    "durchgezechterem": "durchgezecht",
    "durchgezechteren": "durchgezecht",
    "durchgezechterer": "durchgezecht",
    "durchgezechteres": "durchgezecht",
    "durchgezechtes": "durchgezecht",
    "durchgezechteste": "durchgezecht",
    "durchgezechtestem": "durchgezecht",
    "durchgezechtesten": "durchgezecht",
    "durchgezechtester": "durchgezecht",
    "durchgezechtestes": "durchgezecht",
    "durchgezeichnet": "durchzeichnen",
    "durchgezeichnete": "durchgezeichnet",
    "durchgezeichnetem": "durchgezeichnet",
    "durchgezeichneten": "durchgezeichnet",
    "durchgezeichneter": "durchgezeichnet",
    "durchgezeichnetes": "durchgezeichnet",
    "durchgezogen": "durchziehen",
    "durchgezogene": "durchgezogen",
    "durchgezogenem": "durchgezogen",
    "durchgezogenen": "durchgezogen",
    "durchgezogener": "durchgezogen",
    "durchgezogenere": "durchgezogen",
    "durchgezogenerem": "durchgezogen",
    "durchgezogeneren": "durchgezogen",
    "durchgezogenerer": "durchgezogen",
    "durchgezogeneres": "durchgezogen",
    "durchgezogenes": "durchgezogen",
    "durchgezogenste": "durchgezogen",
    "durchgezogenstem": "durchgezogen",
    "durchgezogensten": "durchgezogen",
    "durchgezogenster": "durchgezogen",
    "durchgezogenstes": "durchgezogen",
    "durchgezwängt": "durchzwängen",
    "durchgezwängte": "durchgezwängt",
    "durchgezwängtem": "durchgezwängt",
    "durchgezwängten": "durchgezwängt",
    "durchgezwängter": "durchgezwängt",
    "durchgezwängtes": "durchgezwängt",
    "durchgezählt": "durchzählen",
    "durchgezählte": "durchgezählt",
    "durchgezähltem": "durchgezählt",
    "durchgezählten": "durchgezählt",
    "durchgezählter": "durchgezählt",
    "durchgezähltes": "durchgezählt",
    "durchgibst": "durchgeben",
    "durchgibt": "durchgeben",
    "durchging": "durchgehen",
    "durchginge": "durchgehen",
    "durchgingen": "durchgehen",
    "durchgingest": "durchgehen",
    "durchginget": "durchgehen",
    "durchgingst": "durchgehen",
    "durchgingt": "durchgehen",
    "durchgliedere": "durchgliedern",
    "durchgliedernd": "durchgliedern",
    "durchgliedernde": "durchgliedernd",
    "durchgliederndem": "durchgliedernd",
    "durchgliedernden": "durchgliedernd",
    "durchgliedernder": "durchgliedernd",
    "durchgliederndes": "durchgliedernd",
    "durchgliederst": "durchgliedern",
    "durchgliedert": "durchgliedern",
    "durchgliederte": "durchgliedern",
    "durchgliederten": "durchgliedern",
    "durchgliedertest": "durchgliedern",
    "durchgliedertet": "durchgliedern",
    "durchglühe": "durchglühen",
    "durchglühend": "durchglühen",
    "durchglühende": "durchglühend",
    "durchglühendem": "durchglühend",
    "durchglühenden": "durchglühend",
    "durchglühender": "durchglühend",
    "durchglühendere": "durchglühend",
    "durchglühenderem": "durchglühend",
    "durchglühenderen": "durchglühend",
    "durchglühenderer": "durchglühend",
    "durchglühenderes": "durchglühend",
    "durchglühendes": "durchglühend",
    "durchglühendste": "durchglühend",
    "durchglühendstem": "durchglühend",
    "durchglühendsten": "durchglühend",
    "durchglühendster": "durchglühend",
    "durchglühendstes": "durchglühend",
    "durchglühest": "durchglühen",
    "durchglühet": "durchglühen",
    "durchglühst": "durchglühen",
    "durchglüht": "durchglühen",
    "durchglühte": "durchglühen",
    "durchglühten": "durchglühen",
    "durchglühtest": "durchglühen",
    "durchglühtet": "durchglühen",
    "durchgreife": "durchgreifen",
    "durchgreifend": "durchgreifen",
    "durchgreifende": "durchgreifend",
    "durchgreifendem": "durchgreifend",
    "durchgreifenden": "durchgreifend",
    "durchgreifender": "durchgreifend",
    "durchgreifendes": "durchgreifend",
    "durchgreifest": "durchgreifen",
    "durchgreifet": "durchgreifen",
    "durchgreifst": "durchgreifen",
    "durchgreift": "durchgreifen",
    "durchgriff": "durchgreifen",
    "durchgriffe": "durchgreifen",
    "durchgriffen": "durchgreifen",
    "durchgriffest": "durchgreifen",
    "durchgriffet": "durchgreifen",
    "durchgriffst": "durchgreifen",
    "durchgrifft": "durchgreifen",
    "durchgäbe": "durchgeben",
    "durchgäben": "durchgeben",
    "durchgäbest": "durchgeben",
    "durchgäbet": "durchgeben",
    "durchgängigem": "durchgängig",
    "durchgängigen": "durchgängig",
    "durchgängiger": "durchgängig",
    "durchgängigere": "durchgängig",
    "durchgängigerem": "durchgängig",
    "durchgängigeren": "durchgängig",
    "durchgängigerer": "durchgängig",
    "durchgängigeres": "durchgängig",
    "durchgängiges": "durchgängig",
    "durchgängigste": "durchgängig",
    "durchgängigstem": "durchgängig",
    "durchgängigsten": "durchgängig",
    "durchgängigster": "durchgängig",
    "durchgängigstes": "durchgängig",
    "durchhalf": "durchhelfen",
    "durchhalfen": "durchhelfen",
    "durchhalfst": "durchhelfen",
    "durchhalft": "durchhelfen",
    "durchhalte": "durchhalten",
    "durchhaltend": "durchhalten",
    "durchhaltende": "durchhaltend",
    "durchhaltendem": "durchhaltend",
    "durchhaltenden": "durchhaltend",
    "durchhaltender": "durchhaltend",
    "durchhaltendes": "durchhaltend",
    "durchhaltest": "durchhalten",
    "durchhaltet": "durchhalten",
    "durchhauche": "durchhauchen",
    "durchhauchend": "durchhauchen",
    "durchhauchende": "durchhauchend",
    "durchhauchendem": "durchhauchend",
    "durchhauchenden": "durchhauchend",
    "durchhauchender": "durchhauchend",
    "durchhauchendes": "durchhauchend",
    "durchhauchest": "durchhauchen",
    "durchhauchet": "durchhauchen",
    "durchhauchst": "durchhauchen",
    "durchhaucht": "durchhauchen",
    "durchhauchte": "durchhauchen",
    "durchhauchten": "durchhauchen",
    "durchhauchtest": "durchhauchen",
    "durchhauchtet": "durchhauchen",
    "durchhaue": "durchhauen",
    "durchhauend": "durchhauen",
    "durchhauende": "durchhauend",
    "durchhauendem": "durchhauend",
    "durchhauenden": "durchhauend",
    "durchhauender": "durchhauend",
    "durchhauendes": "durchhauend",
    "durchhauest": "durchhauen",
    "durchhauet": "durchhauen",
    "durchhaust": "durchhauen",
    "durchhaut": "durchhauen",
    "durchhaute": "durchhauen",
    "durchhauten": "durchhauen",
    "durchhautest": "durchhauen",
    "durchhautet": "durchhauen",
    "durchhechele": "durchhecheln",
    "durchhechelnd": "durchhecheln",
    "durchhechelnde": "durchhechelnd",
    "durchhechelndem": "durchhechelnd",
    "durchhechelnden": "durchhechelnd",
    "durchhechelnder": "durchhechelnd",
    "durchhechelndere": "durchhechelnd",
    "durchhechelnderem": "durchhechelnd",
    "durchhechelnderen": "durchhechelnd",
    "durchhechelnderer": "durchhechelnd",
    "durchhechelnderes": "durchhechelnd",
    "durchhechelndes": "durchhechelnd",
    "durchhechelndste": "durchhechelnd",
    "durchhechelndstem": "durchhechelnd",
    "durchhechelndsten": "durchhechelnd",
    "durchhechelndster": "durchhechelnd",
    "durchhechelndstes": "durchhechelnd",
    "durchhechelst": "durchhecheln",
    "durchhechelt": "durchhecheln",
    "durchhechelte": "durchhecheln",
    "durchhechelten": "durchhecheln",
    "durchhecheltest": "durchhecheln",
    "durchhecheltet": "durchhecheln",
    "durchhechle": "durchhecheln",
    "durchheize": "durchheizen",
    "durchheizend": "durchheizen",
    "durchheizende": "durchheizend",
    "durchheizendem": "durchheizend",
    "durchheizenden": "durchheizend",
    "durchheizender": "durchheizend",
    "durchheizendere": "durchheizend",
    "durchheizenderem": "durchheizend",
    "durchheizenderen": "durchheizend",
    "durchheizenderer": "durchheizend",
    "durchheizenderes": "durchheizend",
    "durchheizendes": "durchheizend",
    "durchheizendste": "durchheizend",
    "durchheizendstem": "durchheizend",
    "durchheizendsten": "durchheizend",
    "durchheizendster": "durchheizend",
    "durchheizendstes": "durchheizend",
    "durchheizest": "durchheizen",
    "durchheizet": "durchheizen",
    "durchheizt": "durchheizen",
    "durchheizte": "durchheizen",
    "durchheizten": "durchheizen",
    "durchheiztest": "durchheizen",
    "durchheiztet": "durchheizen",
    "durchhelfe": "durchhelfen",
    "durchhelfend": "durchhelfen",
    "durchhelfende": "durchhelfend",
    "durchhelfendem": "durchhelfend",
    "durchhelfenden": "durchhelfend",
    "durchhelfender": "durchhelfend",
    "durchhelfendes": "durchhelfend",
    "durchhelfest": "durchhelfen",
    "durchhelfet": "durchhelfen",
    "durchhelft": "durchhelfen",
    "durchhielt": "durchhalten",
    "durchhielte": "durchhalten",
    "durchhielten": "durchhalten",
    "durchhieltest": "durchhalten",
    "durchhieltet": "durchhalten",
    "durchhilfst": "durchhelfen",
    "durchhilft": "durchhelfen",
    "durchhing": "durchhängen",
    "durchhinge": "durchhängen",
    "durchhingen": "durchhängen",
    "durchhingest": "durchhängen",
    "durchhinget": "durchhängen",
    "durchhingst": "durchhängen",
    "durchhingt": "durchhängen",
    "durchhole": "durchholen",
    "durchholend": "durchholen",
    "durchholende": "durchholend",
    "durchholendem": "durchholend",
    "durchholenden": "durchholend",
    "durchholender": "durchholend",
    "durchholendes": "durchholend",
    "durchholest": "durchholen",
    "durchholet": "durchholen",
    "durchholst": "durchholen",
    "durchholt": "durchholen",
    "durchholte": "durchholen",
    "durchholten": "durchholen",
    "durchholtest": "durchholen",
    "durchholtet": "durchholen",
    "durchhungere": "durchhungern",
    "durchhungernd": "durchhungern",
    "durchhungernde": "durchhungernd",
    "durchhungerndem": "durchhungernd",
    "durchhungernden": "durchhungernd",
    "durchhungernder": "durchhungernd",
    "durchhungerndere": "durchhungernd",
    "durchhungernderem": "durchhungernd",
    "durchhungernderen": "durchhungernd",
    "durchhungernderer": "durchhungernd",
    "durchhungernderes": "durchhungernd",
    "durchhungerndes": "durchhungernd",
    "durchhungerndste": "durchhungernd",
    "durchhungerndstem": "durchhungernd",
    "durchhungerndsten": "durchhungernd",
    "durchhungerndster": "durchhungernd",
    "durchhungerndstes": "durchhungernd",
    "durchhungerst": "durchhungern",
    "durchhungert": "durchhungern",
    "durchhungerte": "durchhungern",
    "durchhungerten": "durchhungern",
    "durchhungertest": "durchhungern",
    "durchhungertet": "durchhungern",
    "durchhälfe": "durchhelfen",
    "durchhälfen": "durchhelfen",
    "durchhälfest": "durchhelfen",
    "durchhälfet": "durchhelfen",
    "durchhält": "durchhalten",
    "durchhältst": "durchhalten",
    "durchhänge": "durchhängen",
    "durchhängend": "durchhängen",
    "durchhängende": "durchhängend",
    "durchhängendem": "durchhängend",
    "durchhängenden": "durchhängend",
    "durchhängender": "durchhängend",
    "durchhängendere": "durchhängend",
    "durchhängenderem": "durchhängend",
    "durchhängenderen": "durchhängend",
    "durchhängenderer": "durchhängend",
    "durchhängenderes": "durchhängend",
    "durchhängendes": "durchhängend",
    "durchhängendste": "durchhängend",
    "durchhängendstem": "durchhängend",
    "durchhängendsten": "durchhängend",
    "durchhängendster": "durchhängend",
    "durchhängendstes": "durchhängend",
    "durchhängest": "durchhängen",
    "durchhänget": "durchhängen",
    "durchhängst": "durchhängen",
    "durchhängt": "durchhängen",
    "durchhängte": "durchhängen",
    "durchhängten": "durchhängen",
    "durchhängtest": "durchhängen",
    "durchhängtet": "durchhängen",
    "durchhöre": "durchhören",
    "durchhörend": "durchhören",
    "durchhörende": "durchhörend",
    "durchhörendem": "durchhörend",
    "durchhörenden": "durchhörend",
    "durchhörender": "durchhörend",
    "durchhörendes": "durchhörend",
    "durchhörest": "durchhören",
    "durchhöret": "durchhören",
    "durchhörst": "durchhören",
    "durchhört": "durchhören",
    "durchhörte": "durchhören",
    "durchhörten": "durchhören",
    "durchhörtest": "durchhören",
    "durchhörtet": "durchhören",
    "durchißt": "durchessen",
    "durchjage": "durchjagen",
    "durchjagend": "durchjagen",
    "durchjagende": "durchjagend",
    "durchjagendem": "durchjagend",
    "durchjagenden": "durchjagend",
    "durchjagender": "durchjagend",
    "durchjagendes": "durchjagend",
    "durchjagest": "durchjagen",
    "durchjaget": "durchjagen",
    "durchjagst": "durchjagen",
    "durchjagt": "durchjagen",
    "durchjagte": "durchjagen",
    "durchjagten": "durchjagen",
    "durchjagtest": "durchjagen",
    "durchjagtet": "durchjagen",
    "durchkam": "durchkommen",
    "durchkamen": "durchkommen",
    "durchkamst": "durchkommen",
    "durchkamt": "durchkommen",
    "durchkaue": "durchkauen",
    "durchkauend": "durchkauen",
    "durchkauende": "durchkauend",
    "durchkauendem": "durchkauend",
    "durchkauenden": "durchkauend",
    "durchkauender": "durchkauend",
    "durchkauendere": "durchkauend",
    "durchkauenderem": "durchkauend",
    "durchkauenderen": "durchkauend",
    "durchkauenderer": "durchkauend",
    "durchkauenderes": "durchkauend",
    "durchkauendes": "durchkauend",
    "durchkauendste": "durchkauend",
    "durchkauendstem": "durchkauend",
    "durchkauendsten": "durchkauend",
    "durchkauendster": "durchkauend",
    "durchkauendstes": "durchkauend",
    "durchkauest": "durchkauen",
    "durchkauet": "durchkauen",
    "durchkaust": "durchkauen",
    "durchkaut": "durchkauen",
    "durchkaute": "durchkauen",
    "durchkauten": "durchkauen",
    "durchkautest": "durchkauen",
    "durchkautet": "durchkauen",
    "durchklang": "durchklingen",
    "durchklangen": "durchklingen",
    "durchklangst": "durchklingen",
    "durchklangt": "durchklingen",
    "durchklinge": "durchklingen",
    "durchklingend": "durchklingen",
    "durchklingende": "durchklingend",
    "durchklingendem": "durchklingend",
    "durchklingenden": "durchklingend",
    "durchklingender": "durchklingend",
    "durchklingendes": "durchklingend",
    "durchklingest": "durchklingen",
    "durchklinget": "durchklingen",
    "durchklingst": "durchklingen",
    "durchklingt": "durchklingen",
    "durchklänge": "durchklingen",
    "durchklängen": "durchklingen",
    "durchklängest": "durchklingen",
    "durchklänget": "durchklingen",
    "durchkneife": "durchkneifen",
    "durchkneifend": "durchkneifen",
    "durchkneifende": "durchkneifend",
    "durchkneifendem": "durchkneifend",
    "durchkneifenden": "durchkneifend",
    "durchkneifender": "durchkneifend",
    "durchkneifendes": "durchkneifend",
    "durchkneifest": "durchkneifen",
    "durchkneifet": "durchkneifen",
    "durchkneifst": "durchkneifen",
    "durchkneift": "durchkneifen",
    "durchknete": "durchkneten",
    "durchknetend": "durchkneten",
    "durchknetende": "durchknetend",
    "durchknetendem": "durchknetend",
    "durchknetenden": "durchknetend",
    "durchknetender": "durchknetend",
    "durchknetendere": "durchknetend",
    "durchknetenderem": "durchknetend",
    "durchknetenderen": "durchknetend",
    "durchknetenderer": "durchknetend",
    "durchknetenderes": "durchknetend",
    "durchknetendes": "durchknetend",
    "durchknetendste": "durchknetend",
    "durchknetendstem": "durchknetend",
    "durchknetendsten": "durchknetend",
    "durchknetendster": "durchknetend",
    "durchknetendstes": "durchknetend",
    "durchknetest": "durchkneten",
    "durchknetet": "durchkneten",
    "durchknetete": "durchkneten",
    "durchkneteten": "durchkneten",
    "durchknetetest": "durchkneten",
    "durchknetetet": "durchkneten",
    "durchkniff": "durchkneifen",
    "durchkniffe": "durchkneifen",
    "durchkniffen": "durchkneifen",
    "durchkniffest": "durchkneifen",
    "durchkniffet": "durchkneifen",
    "durchkniffst": "durchkneifen",
    "durchknifft": "durchkneifen",
    "durchknöpfe": "durchknöpfen",
    "durchknöpfend": "durchknöpfen",
    "durchknöpfende": "durchknöpfend",
    "durchknöpfendem": "durchknöpfend",
    "durchknöpfenden": "durchknöpfend",
    "durchknöpfender": "durchknöpfend",
    "durchknöpfendes": "durchknöpfend",
    "durchknöpfest": "durchknöpfen",
    "durchknöpfet": "durchknöpfen",
    "durchknöpfst": "durchknöpfen",
    "durchknöpft": "durchknöpfen",
    "durchknöpfte": "durchknöpfen",
    "durchknöpften": "durchknöpfen",
    "durchknöpftest": "durchknöpfen",
    "durchknöpftet": "durchknöpfen",
    "durchkomme": "durchkommen",
    "durchkommend": "durchkommen",
    "durchkommende": "durchkommend",
    "durchkommendem": "durchkommend",
    "durchkommenden": "durchkommend",
    "durchkommender": "durchkommend",
    "durchkommendes": "durchkommend",
    "durchkommest": "durchkommen",
    "durchkommet": "durchkommen",
    "durchkommst": "durchkommen",
    "durchkommt": "durchkommen",
    "durchkomponiere": "durchkomponieren",
    "durchkomponierend": "durchkomponieren",
    "durchkomponierende": "durchkomponierend",
    "durchkomponierendem": "durchkomponierend",
    "durchkomponierenden": "durchkomponierend",
    "durchkomponierender": "durchkomponierend",
    "durchkomponierendes": "durchkomponierend",
    "durchkomponierest": "durchkomponieren",
    "durchkomponieret": "durchkomponieren",
    "durchkomponierst": "durchkomponieren",
    "durchkomponiert": "durchkomponieren",
    "durchkomponierte": "durchkomponieren",
    "durchkomponiertem": "durchkomponiert",
    "durchkomponierten": "durchkomponieren",
    "durchkomponierter": "durchkomponiert",
    "durchkomponiertes": "durchkomponiert",
    "durchkomponiertest": "durchkomponieren",
    "durchkomponiertet": "durchkomponieren",
    "durchkoste": "durchkosten",
    "durchkostend": "durchkosten",
    "durchkostende": "durchkostend",
    "durchkostendem": "durchkostend",
    "durchkostenden": "durchkostend",
    "durchkostender": "durchkostend",
    "durchkostendes": "durchkostend",
    "durchkostest": "durchkosten",
    "durchkostet": "durchkosten",
    "durchkostete": "durchkosten",
    "durchkosteten": "durchkosten",
    "durchkostetest": "durchkosten",
    "durchkostetet": "durchkosten",
    "durchkreuze": "durchkreuzen",
    "durchkreuzend": "durchkreuzen",
    "durchkreuzende": "durchkreuzend",
    "durchkreuzendem": "durchkreuzend",
    "durchkreuzenden": "durchkreuzend",
    "durchkreuzender": "durchkreuzend",
    "durchkreuzendes": "durchkreuzend",
    "durchkreuzest": "durchkreuzen",
    "durchkreuzet": "durchkreuzen",
    "durchkreuzt": "durchkreuzen",
    "durchkreuzte": "durchkreuzen",
    "durchkreuztem": "durchkreuzt",
    "durchkreuzten": "durchkreuzen",
    "durchkreuzter": "durchkreuzt",
    "durchkreuztes": "durchkreuzt",
    "durchkreuztest": "durchkreuzen",
    "durchkreuztet": "durchkreuzen",
    "durchkrieche": "durchkriechen",
    "durchkriechend": "durchkriechen",
    "durchkriechende": "durchkriechend",
    "durchkriechendem": "durchkriechend",
    "durchkriechenden": "durchkriechend",
    "durchkriechender": "durchkriechend",
    "durchkriechendes": "durchkriechend",
    "durchkriechest": "durchkriechen",
    "durchkriechet": "durchkriechen",
    "durchkriechst": "durchkriechen",
    "durchkriecht": "durchkriechen",
    "durchkriege": "durchkriegen",
    "durchkriegend": "durchkriegen",
    "durchkriegende": "durchkriegend",
    "durchkriegendem": "durchkriegend",
    "durchkriegenden": "durchkriegend",
    "durchkriegender": "durchkriegend",
    "durchkriegendes": "durchkriegend",
    "durchkriegest": "durchkriegen",
    "durchkrieget": "durchkriegen",
    "durchkriegst": "durchkriegen",
    "durchkriegt": "durchkriegen",
    "durchkriegte": "durchkriegen",
    "durchkriegten": "durchkriegen",
    "durchkriegtest": "durchkriegen",
    "durchkriegtet": "durchkriegen",
    "durchkroch": "durchkriechen",
    "durchkrochen": "durchkriechen",
    "durchkrochst": "durchkriechen",
    "durchkrocht": "durchkriechen",
    "durchkröche": "durchkriechen",
    "durchkröchen": "durchkriechen",
    "durchkröchest": "durchkriechen",
    "durchkröchet": "durchkriechen",
    "durchkäme": "durchkommen",
    "durchkämen": "durchkommen",
    "durchkämest": "durchkommen",
    "durchkämet": "durchkommen",
    "durchkämme": "durchkämmen",
    "durchkämmend": "durchkämmen",
    "durchkämmende": "durchkämmend",
    "durchkämmendem": "durchkämmend",
    "durchkämmenden": "durchkämmend",
    "durchkämmender": "durchkämmend",
    "durchkämmendes": "durchkämmend",
    "durchkämmest": "durchkämmen",
    "durchkämmet": "durchkämmen",
    "durchkämmst": "durchkämmen",
    "durchkämmt": "durchkämmen",
    "durchkämmte": "durchkämmen",
    "durchkämmtem": "durchkämmt",
    "durchkämmten": "durchkämmen",
    "durchkämmter": "durchkämmt",
    "durchkämmtere": "durchkämmt",
    "durchkämmterem": "durchkämmt",
    "durchkämmteren": "durchkämmt",
    "durchkämmterer": "durchkämmt",
    "durchkämmteres": "durchkämmt",
    "durchkämmtes": "durchkämmt",
    "durchkämmtest": "durchkämmen",
    "durchkämmteste": "durchkämmt",
    "durchkämmtestem": "durchkämmt",
    "durchkämmtesten": "durchkämmt",
    "durchkämmtester": "durchkämmt",
    "durchkämmtestes": "durchkämmt",
    "durchkämmtet": "durchkämmen",
    "durchkämpfe": "durchkämpfen",
    "durchkämpfend": "durchkämpfen",
    "durchkämpfende": "durchkämpfend",
    "durchkämpfendem": "durchkämpfend",
    "durchkämpfenden": "durchkämpfend",
    "durchkämpfender": "durchkämpfend",
    "durchkämpfendes": "durchkämpfend",
    "durchkämpfest": "durchkämpfen",
    "durchkämpfet": "durchkämpfen",
    "durchkämpfst": "durchkämpfen",
    "durchkämpft": "durchkämpfen",
    "durchkämpfte": "durchkämpfen",
    "durchkämpften": "durchkämpfen",
    "durchkämpftest": "durchkämpfen",
    "durchkämpftet": "durchkämpfen",
    "durchlade": "durchladen",
    "durchladend": "durchladen",
    "durchladende": "durchladend",
    "durchladendem": "durchladend",
    "durchladenden": "durchladend",
    "durchladender": "durchladend",
    "durchladendes": "durchladend",
    "durchladest": "durchladen",
    "durchladet": "durchladen",
    "durchlag": "durchliegen",
    "durchlagen": "durchliegen",
    "durchlagst": "durchliegen",
    "durchlagt": "durchliegen",
    "durchlange": "durchlangen",
    "durchlangend": "durchlangen",
    "durchlangende": "durchlangend",
    "durchlangendem": "durchlangend",
    "durchlangenden": "durchlangend",
    "durchlangender": "durchlangend",
    "durchlangendes": "durchlangend",
    "durchlangest": "durchlangen",
    "durchlanget": "durchlangen",
    "durchlangst": "durchlangen",
    "durchlangt": "durchlangen",
    "durchlangte": "durchlangen",
    "durchlangten": "durchlangen",
    "durchlangtest": "durchlangen",
    "durchlangtet": "durchlangen",
    "durchlas": "durchlesen",
    "durchlasen": "durchlesen",
    "durchlasse": "durchlassen",
    "durchlassend": "durchlassen",
    "durchlassende": "durchlassend",
    "durchlassendem": "durchlassend",
    "durchlassenden": "durchlassend",
    "durchlassender": "durchlassend",
    "durchlassendes": "durchlassend",
    "durchlassest": "durchlassen",
    "durchlasset": "durchlassen",
    "durchlast": "durchlesen",
    "durchlaufend": "durchlaufen",
    "durchlaufende": "durchlaufend",
    "durchlaufendem": "durchlaufend",
    "durchlaufenden": "durchlaufend",
    "durchlaufender": "durchlaufend",
    "durchlaufendes": "durchlaufend",
    "durchlaufene": "durchlaufen",
    "durchlaufenem": "durchlaufen",
    "durchlaufenen": "durchlaufen",
    "durchlaufener": "durchlaufen",
    "durchlaufenes": "durchlaufen",
    "durchlaufest": "durchlaufen",
    "durchlaufet": "durchlaufen",
    "durchlauft": "durchlaufen",
    "durchlaßt": "durchlassen",
    "durchlebe": "durchleben",
    "durchlebend": "durchleben",
    "durchlebende": "durchlebend",
    "durchlebendem": "durchlebend",
    "durchlebenden": "durchlebend",
    "durchlebender": "durchlebend",
    "durchlebendes": "durchlebend",
    "durchlebest": "durchleben",
    "durchlebet": "durchleben",
    "durchlebst": "durchleben",
    "durchlebt": "durchleben",
    "durchlebte": "durchleben",
    "durchlebtem": "durchlebt",
    "durchlebten": "durchleben",
    "durchlebter": "durchlebt",
    "durchlebtes": "durchlebt",
    "durchlebtest": "durchleben",
    "durchlebtet": "durchleben",
    "durchlese": "durchlesen",
    "durchlesend": "durchlesen",
    "durchlesende": "durchlesend",
    "durchlesendem": "durchlesend",
    "durchlesenden": "durchlesend",
    "durchlesender": "durchlesend",
    "durchlesendes": "durchlesend",
    "durchlesest": "durchlesen",
    "durchleset": "durchlesen",
    "durchlest": "durchlesen",
    "durchleuchte": "durchleuchten",
    "durchleuchtend": "durchleuchten",
    "durchleuchtende": "durchleuchtend",
    "durchleuchtendem": "durchleuchtend",
    "durchleuchtenden": "durchleuchtend",
    "durchleuchtender": "durchleuchtend",
    "durchleuchtendere": "durchleuchtend",
    "durchleuchtenderem": "durchleuchtend",
    "durchleuchtenderen": "durchleuchtend",
    "durchleuchtenderer": "durchleuchtend",
    "durchleuchtenderes": "durchleuchtend",
    "durchleuchtendes": "durchleuchtend",
    "durchleuchtendste": "durchleuchtend",
    "durchleuchtendstem": "durchleuchtend",
    "durchleuchtendsten": "durchleuchtend",
    "durchleuchtendster": "durchleuchtend",
    "durchleuchtendstes": "durchleuchtend",
    "durchleuchtest": "durchleuchten",
    "durchleuchtet": "durchleuchten",
    "durchleuchtete": "durchleuchten",
    "durchleuchtetem": "durchleuchtet",
    "durchleuchteten": "durchleuchten",
    "durchleuchteter": "durchleuchtet",
    "durchleuchtetere": "durchleuchtet",
    "durchleuchteterem": "durchleuchtet",
    "durchleuchteteren": "durchleuchtet",
    "durchleuchteterer": "durchleuchtet",
    "durchleuchteteres": "durchleuchtet",
    "durchleuchtetes": "durchleuchtet",
    "durchleuchtetest": "durchleuchten",
    "durchleuchtetestem": "durchleuchtet",
    "durchleuchtetesten": "durchleuchtet",
    "durchleuchtetester": "durchleuchtet",
    "durchleuchtetestes": "durchleuchtet",
    "durchleuchtetet": "durchleuchten",
    "durchlief": "durchlaufen",
    "durchliefe": "durchlaufen",
    "durchliefen": "durchlaufen",
    "durchliefest": "durchlaufen",
    "durchliefet": "durchlaufen",
    "durchliefst": "durchlaufen",
    "durchlieft": "durchlaufen",
    "durchliege": "durchliegen",
    "durchliegend": "durchliegen",
    "durchliegende": "durchliegend",
    "durchliegendem": "durchliegend",
    "durchliegenden": "durchliegend",
    "durchliegender": "durchliegend",
    "durchliegendes": "durchliegend",
    "durchliegest": "durchliegen",
    "durchlieget": "durchliegen",
    "durchliegst": "durchliegen",
    "durchliegt": "durchliegen",
    "durchliest": "durchlesen",
    "durchließ": "durchlassen",
    "durchließe": "durchlassen",
    "durchließen": "durchlassen",
    "durchließest": "durchlassen",
    "durchließet": "durchlassen",
    "durchließt": "durchlassen",
    "durchlog": "durchlügen",
    "durchlogen": "durchlügen",
    "durchlogst": "durchlügen",
    "durchlogt": "durchlügen",
    "durchlud": "durchladen",
    "durchluden": "durchladen",
    "durchludest": "durchladen",
    "durchludet": "durchladen",
    "durchlädst": "durchladen",
    "durchlädt": "durchladen",
    "durchläge": "durchliegen",
    "durchlägen": "durchliegen",
    "durchlägest": "durchliegen",
    "durchläget": "durchliegen",
    "durchläse": "durchlesen",
    "durchläsen": "durchlesen",
    "durchläsest": "durchlesen",
    "durchläset": "durchlesen",
    "durchlässige": "durchlässig",
    "durchlässigem": "durchlässig",
    "durchlässigen": "durchlässig",
    "durchlässiger": "durchlässig",
    "durchlässigere": "durchlässig",
    "durchlässigerem": "durchlässig",
    "durchlässigeren": "durchlässig",
    "durchlässigerer": "durchlässig",
    "durchlässigeres": "durchlässig",
    "durchlässiges": "durchlässig",
    "durchlässigste": "durchlässig",
    "durchlässigstem": "durchlässig",
    "durchlässigsten": "durchlässig",
    "durchlässigster": "durchlässig",
    "durchlässigstes": "durchlässig",
    "durchläufst": "durchlaufen",
    "durchläuft": "durchlaufen",
    "durchläßt": "durchlassen",
    "durchlöchere": "durchlöchern",
    "durchlöchernd": "durchlöchern",
    "durchlöchernde": "durchlöchernd",
    "durchlöcherndem": "durchlöchernd",
    "durchlöchernden": "durchlöchernd",
    "durchlöchernder": "durchlöchernd",
    "durchlöcherndere": "durchlöchernd",
    "durchlöchernderem": "durchlöchernd",
    "durchlöchernderen": "durchlöchernd",
    "durchlöchernderer": "durchlöchernd",
    "durchlöchernderes": "durchlöchernd",
    "durchlöcherndes": "durchlöchernd",
    "durchlöcherndste": "durchlöchernd",
    "durchlöcherndstem": "durchlöchernd",
    "durchlöcherndsten": "durchlöchernd",
    "durchlöcherndster": "durchlöchernd",
    "durchlöcherndstes": "durchlöchernd",
    "durchlöcherst": "durchlöchern",
    "durchlöchert": "durchlöchern",
    "durchlöcherte": "durchlöchern",
    "durchlöchertem": "durchlöchert",
    "durchlöcherten": "durchlöchern",
    "durchlöcherter": "durchlöchert",
    "durchlöchertere": "durchlöchert",
    "durchlöcherterem": "durchlöchert",
    "durchlöcherteren": "durchlöchert",
    "durchlöcherterer": "durchlöchert",
    "durchlöcherteres": "durchlöchert",
    "durchlöchertes": "durchlöchert",
    "durchlöchertest": "durchlöchern",
    "durchlöcherteste": "durchlöchert",
    "durchlöchertestem": "durchlöchert",
    "durchlöchertesten": "durchlöchert",
    "durchlöchertester": "durchlöchert",
    "durchlöchertestes": "durchlöchert",
    "durchlöchertet": "durchlöchern",
    "durchlöge": "durchlügen",
    "durchlögen": "durchlügen",
    "durchlögest": "durchlügen",
    "durchlöget": "durchlügen",
    "durchlüde": "durchladen",
    "durchlüden": "durchladen",
    "durchlüdest": "durchladen",
    "durchlüdet": "durchladen",
    "durchlüfte": "durchlüften",
    "durchlüftend": "durchlüften",
    "durchlüftende": "durchlüftend",
    "durchlüftendem": "durchlüftend",
    "durchlüftenden": "durchlüftend",
    "durchlüftender": "durchlüftend",
    "durchlüftendere": "durchlüftend",
    "durchlüftenderem": "durchlüftend",
    "durchlüftenderen": "durchlüftend",
    "durchlüftenderer": "durchlüftend",
    "durchlüftenderes": "durchlüftend",
    "durchlüftendes": "durchlüftend",
    "durchlüftendste": "durchlüftend",
    "durchlüftendstem": "durchlüftend",
    "durchlüftendsten": "durchlüftend",
    "durchlüftendster": "durchlüftend",
    "durchlüftendstes": "durchlüftend",
    "durchlüftest": "durchlüften",
    "durchlüftet": "durchlüften",
    "durchlüftete": "durchlüften",
    "durchlüfteten": "durchlüften",
    "durchlüftetest": "durchlüften",
    "durchlüftetet": "durchlüften",
    "durchlüge": "durchlügen",
    "durchlügend": "durchlügen",
    "durchlügende": "durchlügend",
    "durchlügendem": "durchlügend",
    "durchlügenden": "durchlügend",
    "durchlügender": "durchlügend",
    "durchlügendere": "durchlügend",
    "durchlügenderem": "durchlügend",
    "durchlügenderen": "durchlügend",
    "durchlügenderer": "durchlügend",
    "durchlügenderes": "durchlügend",
    "durchlügendes": "durchlügend",
    "durchlügendste": "durchlügend",
    "durchlügendstem": "durchlügend",
    "durchlügendsten": "durchlügend",
    "durchlügendster": "durchlügend",
    "durchlügendstes": "durchlügend",
    "durchlügest": "durchlügen",
    "durchlüget": "durchlügen",
    "durchlügst": "durchlügen",
    "durchlügt": "durchlügen",
    "durchmache": "durchmachen",
    "durchmachend": "durchmachen",
    "durchmachende": "durchmachend",
    "durchmachendem": "durchmachend",
    "durchmachenden": "durchmachend",
    "durchmachender": "durchmachend",
    "durchmachendes": "durchmachend",
    "durchmachest": "durchmachen",
    "durchmachet": "durchmachen",
    "durchmachst": "durchmachen",
    "durchmacht": "durchmachen",
    "durchmachte": "durchmachen",
    "durchmachten": "durchmachen",
    "durchmachtest": "durchmachen",
    "durchmachtet": "durchmachen",
    "durchmarschiere": "durchmarschieren",
    "durchmarschierend": "durchmarschieren",
    "durchmarschierende": "durchmarschierend",
    "durchmarschierendem": "durchmarschierend",
    "durchmarschierenden": "durchmarschierend",
    "durchmarschierender": "durchmarschierend",
    "durchmarschierendes": "durchmarschierend",
    "durchmarschierest": "durchmarschieren",
    "durchmarschieret": "durchmarschieren",
    "durchmarschierst": "durchmarschieren",
    "durchmarschiert": "durchmarschieren",
    "durchmarschierte": "durchmarschieren",
    "durchmarschiertem": "durchmarschiert",
    "durchmarschierten": "durchmarschieren",
    "durchmarschierter": "durchmarschiert",
    "durchmarschiertes": "durchmarschiert",
    "durchmarschiertest": "durchmarschieren",
    "durchmarschiertet": "durchmarschieren",
    "durchmaß": "durchmessen",
    "durchmaßen": "durchmessen",
    "durchmaßt": "durchmessen",
    "durchmesse": "durchmessen",
    "durchmessend": "durchmessen",
    "durchmessende": "durchmessend",
    "durchmessendem": "durchmessend",
    "durchmessenden": "durchmessend",
    "durchmessender": "durchmessend",
    "durchmessendes": "durchmessend",
    "durchmessest": "durchmessen",
    "durchmesset": "durchmessen",
    "durchmeßt": "durchmessen",
    "durchmißt": "durchmessen",
    "durchmäße": "durchmessen",
    "durchmäßen": "durchmessen",
    "durchmäßest": "durchmessen",
    "durchmäßet": "durchmessen",
    "durchnage": "durchnagen",
    "durchnagend": "durchnagen",
    "durchnagende": "durchnagend",
    "durchnagendem": "durchnagend",
    "durchnagenden": "durchnagend",
    "durchnagender": "durchnagend",
    "durchnagendere": "durchnagend",
    "durchnagenderem": "durchnagend",
    "durchnagenderen": "durchnagend",
    "durchnagenderer": "durchnagend",
    "durchnagenderes": "durchnagend",
    "durchnagendes": "durchnagend",
    "durchnagendste": "durchnagend",
    "durchnagendstem": "durchnagend",
    "durchnagendsten": "durchnagend",
    "durchnagendster": "durchnagend",
    "durchnagendstes": "durchnagend",
    "durchnagest": "durchnagen",
    "durchnaget": "durchnagen",
    "durchnagst": "durchnagen",
    "durchnagt": "durchnagen",
    "durchnagte": "durchnagen",
    "durchnagten": "durchnagen",
    "durchnagtest": "durchnagen",
    "durchnagtet": "durchnagen",
    "durchnahm": "durchnehmen",
    "durchnahmen": "durchnehmen",
    "durchnahmst": "durchnehmen",
    "durchnahmt": "durchnehmen",
    "durchnehme": "durchnehmen",
    "durchnehmend": "durchnehmen",
    "durchnehmende": "durchnehmend",
    "durchnehmendem": "durchnehmend",
    "durchnehmenden": "durchnehmend",
    "durchnehmender": "durchnehmend",
    "durchnehmendes": "durchnehmend",
    "durchnehmest": "durchnehmen",
    "durchnehmet": "durchnehmen",
    "durchnehmt": "durchnehmen",
    "durchnimmst": "durchnehmen",
    "durchnimmt": "durchnehmen",
    "durchnumeriere": "durchnumerieren",
    "durchnumerierend": "durchnumerieren",
    "durchnumerierende": "durchnumerierend",
    "durchnumerierendem": "durchnumerierend",
    "durchnumerierenden": "durchnumerierend",
    "durchnumerierender": "durchnumerierend",
    "durchnumerierendes": "durchnumerierend",
    "durchnumerierest": "durchnumerieren",
    "durchnumerieret": "durchnumerieren",
    "durchnumerierst": "durchnumerieren",
    "durchnumeriert": "durchnumerieren",
    "durchnumerierte": "durchnumerieren",
    "durchnumeriertem": "durchnumeriert",
    "durchnumerierten": "durchnumerieren",
    "durchnumerierter": "durchnumeriert",
    "durchnumeriertes": "durchnumeriert",
    "durchnumeriertest": "durchnumerieren",
    "durchnumeriertet": "durchnumerieren",
    "durchnähme": "durchnehmen",
    "durchnähmen": "durchnehmen",
    "durchnähmest": "durchnehmen",
    "durchnähmet": "durchnehmen",
    "durchorganisiere": "durchorganisieren",
    "durchorganisierend": "durchorganisieren",
    "durchorganisierende": "durchorganisierend",
    "durchorganisierendem": "durchorganisierend",
    "durchorganisierenden": "durchorganisierend",
    "durchorganisierender": "durchorganisierend",
    "durchorganisierendere": "durchorganisierend",
    "durchorganisierenderem": "durchorganisierend",
    "durchorganisierenderen": "durchorganisierend",
    "durchorganisierenderer": "durchorganisierend",
    "durchorganisierenderes": "durchorganisierend",
    "durchorganisierendes": "durchorganisierend",
    "durchorganisierendste": "durchorganisierend",
    "durchorganisierendstem": "durchorganisierend",
    "durchorganisierendsten": "durchorganisierend",
    "durchorganisierendster": "durchorganisierend",
    "durchorganisierendstes": "durchorganisierend",
    "durchorganisierest": "durchorganisieren",
    "durchorganisieret": "durchorganisieren",
    "durchorganisierst": "durchorganisieren",
    "durchorganisiert": "durchorganisieren",
    "durchorganisierte": "durchorganisieren",
    "durchorganisiertem": "durchorganisiert",
    "durchorganisierten": "durchorganisieren",
    "durchorganisierter": "durchorganisiert",
    "durchorganisiertere": "durchorganisiert",
    "durchorganisierterem": "durchorganisiert",
    "durchorganisierteren": "durchorganisiert",
    "durchorganisierterer": "durchorganisiert",
    "durchorganisierteres": "durchorganisiert",
    "durchorganisiertes": "durchorganisiert",
    "durchorganisiertest": "durchorganisieren",
    "durchorganisierteste": "durchorganisiert",
    "durchorganisiertestem": "durchorganisiert",
    "durchorganisiertesten": "durchorganisiert",
    "durchorganisiertester": "durchorganisiert",
    "durchorganisiertestes": "durchorganisiert",
    "durchorganisiertet": "durchorganisieren",
    "durchpauke": "durchpauken",
    "durchpaukend": "durchpauken",
    "durchpaukende": "durchpaukend",
    "durchpaukendem": "durchpaukend",
    "durchpaukenden": "durchpaukend",
    "durchpaukender": "durchpaukend",
    "durchpaukendes": "durchpaukend",
    "durchpaukest": "durchpauken",
    "durchpauket": "durchpauken",
    "durchpaukst": "durchpauken",
    "durchpaukt": "durchpauken",
    "durchpaukte": "durchpauken",
    "durchpaukten": "durchpauken",
    "durchpauktest": "durchpauken",
    "durchpauktet": "durchpauken",
    "durchpause": "durchpausen",
    "durchpausend": "durchpausen",
    "durchpausende": "durchpausend",
    "durchpausendem": "durchpausend",
    "durchpausenden": "durchpausend",
    "durchpausender": "durchpausend",
    "durchpausendes": "durchpausend",
    "durchpausest": "durchpausen",
    "durchpauset": "durchpausen",
    "durchpaust": "durchpausen",
    "durchpauste": "durchpausen",
    "durchpausten": "durchpausen",
    "durchpaustest": "durchpausen",
    "durchpaustet": "durchpausen",
    "durchpeitsche": "durchpeitschen",
    "durchpeitschend": "durchpeitschen",
    "durchpeitschende": "durchpeitschend",
    "durchpeitschendem": "durchpeitschend",
    "durchpeitschenden": "durchpeitschend",
    "durchpeitschender": "durchpeitschend",
    "durchpeitschendere": "durchpeitschend",
    "durchpeitschenderem": "durchpeitschend",
    "durchpeitschenderen": "durchpeitschend",
    "durchpeitschenderer": "durchpeitschend",
    "durchpeitschenderes": "durchpeitschend",
    "durchpeitschendes": "durchpeitschend",
    "durchpeitschendste": "durchpeitschend",
    "durchpeitschendstem": "durchpeitschend",
    "durchpeitschendsten": "durchpeitschend",
    "durchpeitschendster": "durchpeitschend",
    "durchpeitschendstes": "durchpeitschend",
    "durchpeitschest": "durchpeitschen",
    "durchpeitschet": "durchpeitschen",
    "durchpeitschst": "durchpeitschen",
    "durchpeitscht": "durchpeitschen",
    "durchpeitschte": "durchpeitschen",
    "durchpeitschten": "durchpeitschen",
    "durchpeitschtest": "durchpeitschen",
    "durchpeitschtet": "durchpeitschen",
    "durchplumpse": "durchplumpsen",
    "durchplumpsend": "durchplumpsen",
    "durchplumpsende": "durchplumpsend",
    "durchplumpsendem": "durchplumpsend",
    "durchplumpsenden": "durchplumpsend",
    "durchplumpsender": "durchplumpsend",
    "durchplumpsendes": "durchplumpsend",
    "durchplumpsest": "durchplumpsen",
    "durchplumpset": "durchplumpsen",
    "durchplumpst": "durchplumpsen",
    "durchplumpste": "durchplumpsen",
    "durchplumpsten": "durchplumpsen",
    "durchplumpstest": "durchplumpsen",
    "durchplumpstet": "durchplumpsen",
    "durchpresse": "durchpressen",
    "durchpressend": "durchpressen",
    "durchpressende": "durchpressend",
    "durchpressendem": "durchpressend",
    "durchpressenden": "durchpressend",
    "durchpressender": "durchpressend",
    "durchpressendes": "durchpressend",
    "durchpressest": "durchpressen",
    "durchpresset": "durchpressen",
    "durchpreßt": "durchpressen",
    "durchpreßte": "durchpressen",
    "durchpreßten": "durchpressen",
    "durchpreßtest": "durchpressen",
    "durchpreßtet": "durchpressen",
    "durchprobe": "durchproben",
    "durchprobend": "durchproben",
    "durchprobende": "durchprobend",
    "durchprobendem": "durchprobend",
    "durchprobenden": "durchprobend",
    "durchprobender": "durchprobend",
    "durchprobendes": "durchprobend",
    "durchprobest": "durchproben",
    "durchprobet": "durchproben",
    "durchprobiere": "durchprobieren",
    "durchprobierend": "durchprobieren",
    "durchprobierende": "durchprobierend",
    "durchprobierendem": "durchprobierend",
    "durchprobierenden": "durchprobierend",
    "durchprobierender": "durchprobierend",
    "durchprobierendes": "durchprobierend",
    "durchprobierest": "durchprobieren",
    "durchprobieret": "durchprobieren",
    "durchprobierst": "durchprobieren",
    "durchprobiert": "durchprobieren",
    "durchprobierte": "durchprobieren",
    "durchprobiertem": "durchprobiert",
    "durchprobierten": "durchprobieren",
    "durchprobierter": "durchprobiert",
    "durchprobiertes": "durchprobiert",
    "durchprobiertest": "durchprobieren",
    "durchprobiertet": "durchprobieren",
    "durchprobst": "durchproben",
    "durchprobt": "durchproben",
    "durchprobte": "durchproben",
    "durchprobten": "durchproben",
    "durchprobtest": "durchproben",
    "durchprobtet": "durchproben",
    "durchprüfe": "durchprüfen",
    "durchprüfend": "durchprüfen",
    "durchprüfende": "durchprüfend",
    "durchprüfendem": "durchprüfend",
    "durchprüfenden": "durchprüfend",
    "durchprüfender": "durchprüfend",
    "durchprüfendes": "durchprüfend",
    "durchprüfest": "durchprüfen",
    "durchprüfet": "durchprüfen",
    "durchprüfst": "durchprüfen",
    "durchprüft": "durchprüfen",
    "durchprüfte": "durchprüfen",
    "durchprüften": "durchprüfen",
    "durchprüftest": "durchprüfen",
    "durchprüftet": "durchprüfen",
    "durchprügele": "durchprügeln",
    "durchprügelnd": "durchprügeln",
    "durchprügelnde": "durchprügelnd",
    "durchprügelndem": "durchprügelnd",
    "durchprügelnden": "durchprügelnd",
    "durchprügelnder": "durchprügelnd",
    "durchprügelndes": "durchprügelnd",
    "durchprügelst": "durchprügeln",
    "durchprügelt": "durchprügeln",
    "durchprügelte": "durchprügeln",
    "durchprügelten": "durchprügeln",
    "durchprügeltest": "durchprügeln",
    "durchprügeltet": "durchprügeln",
    "durchprügle": "durchprügeln",
    "durchquere": "durchqueren",
    "durchquerend": "durchqueren",
    "durchquerende": "durchquerend",
    "durchquerendem": "durchquerend",
    "durchquerenden": "durchquerend",
    "durchquerender": "durchquerend",
    "durchquerendes": "durchquerend",
    "durchquerest": "durchqueren",
    "durchqueret": "durchqueren",
    "durchquerst": "durchqueren",
    "durchquert": "durchqueren",
    "durchquerte": "durchqueren",
    "durchquertem": "durchquert",
    "durchquerten": "durchqueren",
    "durchquerter": "durchquert",
    "durchquertes": "durchquert",
    "durchquertest": "durchqueren",
    "durchquertet": "durchqueren",
    "durchrang": "durchringen",
    "durchrangen": "durchringen",
    "durchrangst": "durchringen",
    "durchrangt": "durchringen",
    "durchrannte": "durchrennen",
    "durchrannten": "durchrennen",
    "durchranntest": "durchrennen",
    "durchranntet": "durchrennen",
    "durchrase": "durchrasen",
    "durchrasend": "durchrasen",
    "durchrasende": "durchrasend",
    "durchrasendem": "durchrasend",
    "durchrasenden": "durchrasend",
    "durchrasender": "durchrasend",
    "durchrasendes": "durchrasend",
    "durchrasest": "durchrasen",
    "durchraset": "durchrasen",
    "durchrassele": "durchrasseln",
    "durchrasselnd": "durchrasseln",
    "durchrasselnde": "durchrasselnd",
    "durchrasselndem": "durchrasselnd",
    "durchrasselnden": "durchrasselnd",
    "durchrasselnder": "durchrasselnd",
    "durchrasselndes": "durchrasselnd",
    "durchrasselst": "durchrasseln",
    "durchrasselt": "durchrasseln",
    "durchrasselte": "durchrasseln",
    "durchrasselten": "durchrasseln",
    "durchrasseltest": "durchrasseln",
    "durchrasseltet": "durchrasseln",
    "durchrassle": "durchrasseln",
    "durchrast": "durchrasen",
    "durchraste": "durchrasen",
    "durchrasten": "durchrasen",
    "durchrastest": "durchrasen",
    "durchrastet": "durchrasen",
    "durchrausche": "durchrauschen",
    "durchrauschend": "durchrauschen",
    "durchrauschende": "durchrauschend",
    "durchrauschendem": "durchrauschend",
    "durchrauschenden": "durchrauschend",
    "durchrauschender": "durchrauschend",
    "durchrauschendere": "durchrauschend",
    "durchrauschenderem": "durchrauschend",
    "durchrauschenderen": "durchrauschend",
    "durchrauschenderer": "durchrauschend",
    "durchrauschenderes": "durchrauschend",
    "durchrauschendes": "durchrauschend",
    "durchrauschendste": "durchrauschend",
    "durchrauschendstem": "durchrauschend",
    "durchrauschendsten": "durchrauschend",
    "durchrauschendster": "durchrauschend",
    "durchrauschendstes": "durchrauschend",
    "durchrauschest": "durchrauschen",
    "durchrauschet": "durchrauschen",
    "durchrauschst": "durchrauschen",
    "durchrauscht": "durchrauschen",
    "durchrauschte": "durchrauschen",
    "durchrauschten": "durchrauschen",
    "durchrauschtest": "durchrauschen",
    "durchrauschtet": "durchrauschen",
    "durchrechne": "durchrechnen",
    "durchrechnend": "durchrechnen",
    "durchrechnende": "durchrechnend",
    "durchrechnendem": "durchrechnend",
    "durchrechnenden": "durchrechnend",
    "durchrechnender": "durchrechnend",
    "durchrechnendes": "durchrechnend",
    "durchrechnest": "durchrechnen",
    "durchrechnet": "durchrechnen",
    "durchrechnete": "durchrechnen",
    "durchrechneten": "durchrechnen",
    "durchrechnetest": "durchrechnen",
    "durchrechnetet": "durchrechnen",
    "durchregne": "durchregnen",
    "durchregnend": "durchregnen",
    "durchregnende": "durchregnend",
    "durchregnendem": "durchregnend",
    "durchregnenden": "durchregnend",
    "durchregnender": "durchregnend",
    "durchregnendes": "durchregnend",
    "durchregnest": "durchregnen",
    "durchregnet": "durchregnen",
    "durchregnete": "durchregnen",
    "durchregneten": "durchregnen",
    "durchregnetest": "durchregnen",
    "durchregnetet": "durchregnen",
    "durchreibe": "durchreiben",
    "durchreibend": "durchreiben",
    "durchreibende": "durchreibend",
    "durchreibendem": "durchreibend",
    "durchreibenden": "durchreibend",
    "durchreibender": "durchreibend",
    "durchreibendes": "durchreibend",
    "durchreibest": "durchreiben",
    "durchreibet": "durchreiben",
    "durchreibst": "durchreiben",
    "durchreibt": "durchreiben",
    "durchreiche": "durchreichen",
    "durchreichend": "durchreichen",
    "durchreichende": "durchreichend",
    "durchreichendem": "durchreichend",
    "durchreichenden": "durchreichend",
    "durchreichender": "durchreichend",
    "durchreichendes": "durchreichend",
    "durchreichest": "durchreichen",
    "durchreichet": "durchreichen",
    "durchreichst": "durchreichen",
    "durchreicht": "durchreichen",
    "durchreichte": "durchreichen",
    "durchreichten": "durchreichen",
    "durchreichtest": "durchreichen",
    "durchreichtet": "durchreichen",
    "durchreise": "durchreisen",
    "durchreisend": "durchreisen",
    "durchreisende": "durchreisend",
    "durchreisendem": "durchreisend",
    "durchreisenden": "durchreisend",
    "durchreisender": "durchreisend",
    "durchreisendes": "durchreisend",
    "durchreisest": "durchreisen",
    "durchreiset": "durchreisen",
    "durchreist": "durchreisen",
    "durchreiste": "durchreisen",
    "durchreistem": "durchreist",
    "durchreisten": "durchreisen",
    "durchreister": "durchreist",
    "durchreistes": "durchreist",
    "durchreistest": "durchreisen",
    "durchreistet": "durchreisen",
    "durchreite": "durchreiten",
    "durchreitend": "durchreiten",
    "durchreitende": "durchreitend",
    "durchreitendem": "durchreitend",
    "durchreitenden": "durchreitend",
    "durchreitender": "durchreitend",
    "durchreitendes": "durchreitend",
    "durchreitest": "durchreiten",
    "durchreitet": "durchreiten",
    "durchreiße": "durchreißen",
    "durchreißend": "durchreißen",
    "durchreißende": "durchreißend",
    "durchreißendem": "durchreißend",
    "durchreißenden": "durchreißend",
    "durchreißender": "durchreißend",
    "durchreißendes": "durchreißend",
    "durchreißest": "durchreißen",
    "durchreißet": "durchreißen",
    "durchreißt": "durchreißen",
    "durchrenne": "durchrennen",
    "durchrennend": "durchrennen",
    "durchrennende": "durchrennend",
    "durchrennendem": "durchrennend",
    "durchrennenden": "durchrennend",
    "durchrennender": "durchrennend",
    "durchrennendes": "durchrennend",
    "durchrennest": "durchrennen",
    "durchrennet": "durchrennen",
    "durchrennst": "durchrennen",
    "durchrennt": "durchrennen",
    "durchrieb": "durchreiben",
    "durchriebe": "durchreiben",
    "durchrieben": "durchreiben",
    "durchriebest": "durchreiben",
    "durchriebet": "durchreiben",
    "durchriebst": "durchreiben",
    "durchriebt": "durchreiben",
    "durchrief": "durchrufen",
    "durchriefe": "durchrufen",
    "durchriefen": "durchrufen",
    "durchriefest": "durchrufen",
    "durchriefet": "durchrufen",
    "durchriefst": "durchrufen",
    "durchrieft": "durchrufen",
    "durchriesele": "durchrieseln",
    "durchrieselnd": "durchrieseln",
    "durchrieselnde": "durchrieselnd",
    "durchrieselndem": "durchrieselnd",
    "durchrieselnden": "durchrieselnd",
    "durchrieselnder": "durchrieselnd",
    "durchrieselndes": "durchrieselnd",
    "durchrieselst": "durchrieseln",
    "durchrieselt": "durchrieseln",
    "durchrieselte": "durchrieseln",
    "durchrieselten": "durchrieseln",
    "durchrieseltest": "durchrieseln",
    "durchrieseltet": "durchrieseln",
    "durchriesle": "durchrieseln",
    "durchringe": "durchringen",
    "durchringend": "durchringen",
    "durchringende": "durchringend",
    "durchringendem": "durchringend",
    "durchringenden": "durchringend",
    "durchringender": "durchringend",
    "durchringendes": "durchringend",
    "durchringest": "durchringen",
    "durchringet": "durchringen",
    "durchringst": "durchringen",
    "durchringt": "durchringen",
    "durchrisse": "durchreißen",
    "durchrissen": "durchreißen",
    "durchrissest": "durchreißen",
    "durchrisset": "durchreißen",
    "durchritt": "durchreiten",
    "durchritte": "durchreiten",
    "durchritten": "durchreiten",
    "durchrittest": "durchreiten",
    "durchrittet": "durchreiten",
    "durchriß": "durchreißen",
    "durchrißt": "durchreißen",
    "durchroste": "durchrosten",
    "durchrostend": "durchrosten",
    "durchrostende": "durchrostend",
    "durchrostendem": "durchrostend",
    "durchrostenden": "durchrostend",
    "durchrostender": "durchrostend",
    "durchrostendere": "durchrostend",
    "durchrostenderem": "durchrostend",
    "durchrostenderen": "durchrostend",
    "durchrostenderer": "durchrostend",
    "durchrostenderes": "durchrostend",
    "durchrostendes": "durchrostend",
    "durchrostendste": "durchrostend",
    "durchrostendstem": "durchrostend",
    "durchrostendsten": "durchrostend",
    "durchrostendster": "durchrostend",
    "durchrostendstes": "durchrostend",
    "durchrostest": "durchrosten",
    "durchrostet": "durchrosten",
    "durchrostete": "durchrosten",
    "durchrosteten": "durchrosten",
    "durchrostetest": "durchrosten",
    "durchrostetet": "durchrosten",
    "durchrufe": "durchrufen",
    "durchrufend": "durchrufen",
    "durchrufende": "durchrufend",
    "durchrufendem": "durchrufend",
    "durchrufenden": "durchrufend",
    "durchrufender": "durchrufend",
    "durchrufendes": "durchrufend",
    "durchrufest": "durchrufen",
    "durchrufet": "durchrufen",
    "durchrufst": "durchrufen",
    "durchruft": "durchrufen",
    "durchrutsche": "durchrutschen",
    "durchrutschend": "durchrutschen",
    "durchrutschende": "durchrutschend",
    "durchrutschendem": "durchrutschend",
    "durchrutschenden": "durchrutschend",
    "durchrutschender": "durchrutschend",
    "durchrutschendes": "durchrutschend",
    "durchrutschest": "durchrutschen",
    "durchrutschet": "durchrutschen",
    "durchrutschst": "durchrutschen",
    "durchrutscht": "durchrutschen",
    "durchrutschte": "durchrutschen",
    "durchrutschten": "durchrutschen",
    "durchrutschtest": "durchrutschen",
    "durchrutschtet": "durchrutschen",
    "durchränge": "durchringen",
    "durchrängen": "durchringen",
    "durchrängest": "durchringen",
    "durchränget": "durchringen",
    "durchrühre": "durchrühren",
    "durchrührend": "durchrühren",
    "durchrührende": "durchrührend",
    "durchrührendem": "durchrührend",
    "durchrührenden": "durchrührend",
    "durchrührender": "durchrührend",
    "durchrührendere": "durchrührend",
    "durchrührenderem": "durchrührend",
    "durchrührenderen": "durchrührend",
    "durchrührenderer": "durchrührend",
    "durchrührenderes": "durchrührend",
    "durchrührendes": "durchrührend",
    "durchrührendste": "durchrührend",
    "durchrührendstem": "durchrührend",
    "durchrührendsten": "durchrührend",
    "durchrührendster": "durchrührend",
    "durchrührendstes": "durchrührend",
    "durchrührest": "durchrühren",
    "durchrühret": "durchrühren",
    "durchrührst": "durchrühren",
    "durchrührt": "durchrühren",
    "durchrührte": "durchrühren",
    "durchrührten": "durchrühren",
    "durchrührtest": "durchrühren",
    "durchrührtet": "durchrühren",
    "durchrüttele": "durchrütteln",
    "durchrüttelnd": "durchrütteln",
    "durchrüttelnde": "durchrüttelnd",
    "durchrüttelndem": "durchrüttelnd",
    "durchrüttelnden": "durchrüttelnd",
    "durchrüttelnder": "durchrüttelnd",
    "durchrüttelndere": "durchrüttelnd",
    "durchrüttelnderem": "durchrüttelnd",
    "durchrüttelnderen": "durchrüttelnd",
    "durchrüttelnderer": "durchrüttelnd",
    "durchrüttelnderes": "durchrüttelnd",
    "durchrüttelndes": "durchrüttelnd",
    "durchrüttelndste": "durchrüttelnd",
    "durchrüttelndstem": "durchrüttelnd",
    "durchrüttelndsten": "durchrüttelnd",
    "durchrüttelndster": "durchrüttelnd",
    "durchrüttelndstes": "durchrüttelnd",
    "durchrüttelst": "durchrütteln",
    "durchrüttelt": "durchrütteln",
    "durchrüttelte": "durchrütteln",
    "durchrüttelten": "durchrütteln",
    "durchrütteltest": "durchrütteln",
    "durchrütteltet": "durchrütteln",
    "durchrüttle": "durchrütteln",
    "durchsage": "durchsagen",
    "durchsagend": "durchsagen",
    "durchsagende": "durchsagend",
    "durchsagendem": "durchsagend",
    "durchsagenden": "durchsagend",
    "durchsagender": "durchsagend",
    "durchsagendes": "durchsagend",
    "durchsagest": "durchsagen",
    "durchsaget": "durchsagen",
    "durchsagst": "durchsagen",
    "durchsagt": "durchsagen",
    "durchsagte": "durchsagen",
    "durchsagten": "durchsagen",
    "durchsagtest": "durchsagen",
    "durchsagtet": "durchsagen",
    "durchsah": "durchsehen",
    "durchsahen": "durchsehen",
    "durchsahst": "durchsehen",
    "durchsaht": "durchsehen",
    "durchsang": "durchsingen",
    "durchsangen": "durchsingen",
    "durchsangst": "durchsingen",
    "durchsangt": "durchsingen",
    "durchsank": "durchsinken",
    "durchsanken": "durchsinken",
    "durchsankst": "durchsinken",
    "durchsankt": "durchsinken",
    "durchsaufe": "durchsaufen",
    "durchsaufend": "durchsaufen",
    "durchsaufende": "durchsaufend",
    "durchsaufendem": "durchsaufend",
    "durchsaufenden": "durchsaufend",
    "durchsaufender": "durchsaufend",
    "durchsaufendes": "durchsaufend",
    "durchsaufest": "durchsaufen",
    "durchsaufet": "durchsaufen",
    "durchsauft": "durchsaufen",
    "durchsauge": "durchsaugen",
    "durchsaugend": "durchsaugen",
    "durchsaugende": "durchsaugend",
    "durchsaugendem": "durchsaugend",
    "durchsaugenden": "durchsaugend",
    "durchsaugender": "durchsaugend",
    "durchsaugendes": "durchsaugend",
    "durchsaugest": "durchsaugen",
    "durchsauget": "durchsaugen",
    "durchsaugst": "durchsaugen",
    "durchsaugt": "durchsaugen",
    "durchsaugte": "durchsaugen",
    "durchsaugten": "durchsaugen",
    "durchsaugtest": "durchsaugen",
    "durchsaugtet": "durchsaugen",
    "durchsause": "durchsausen",
    "durchsausend": "durchsausen",
    "durchsausende": "durchsausend",
    "durchsausendem": "durchsausend",
    "durchsausenden": "durchsausend",
    "durchsausender": "durchsausend",
    "durchsausendes": "durchsausend",
    "durchsausest": "durchsausen",
    "durchsauset": "durchsausen",
    "durchsaust": "durchsausen",
    "durchsauste": "durchsausen",
    "durchsausten": "durchsausen",
    "durchsaustest": "durchsausen",
    "durchsaustet": "durchsausen",
    "durchsaß": "durchsitzen",
    "durchsaßen": "durchsitzen",
    "durchsaßt": "durchsitzen",
    "durchschabe": "durchschaben",
    "durchschabend": "durchschaben",
    "durchschabende": "durchschabend",
    "durchschabendem": "durchschabend",
    "durchschabenden": "durchschabend",
    "durchschabender": "durchschabend",
    "durchschabendere": "durchschabend",
    "durchschabenderem": "durchschabend",
    "durchschabenderen": "durchschabend",
    "durchschabenderer": "durchschabend",
    "durchschabenderes": "durchschabend",
    "durchschabendes": "durchschabend",
    "durchschabendste": "durchschabend",
    "durchschabendstem": "durchschabend",
    "durchschabendsten": "durchschabend",
    "durchschabendster": "durchschabend",
    "durchschabendstes": "durchschabend",
    "durchschabest": "durchschaben",
    "durchschabet": "durchschaben",
    "durchschabst": "durchschaben",
    "durchschabt": "durchschaben",
    "durchschabte": "durchschaben",
    "durchschabten": "durchschaben",
    "durchschabtest": "durchschaben",
    "durchschabtet": "durchschaben",
    "durchschalle": "durchschallen",
    "durchschallend": "durchschallen",
    "durchschallende": "durchschallend",
    "durchschallendem": "durchschallend",
    "durchschallenden": "durchschallend",
    "durchschallender": "durchschallend",
    "durchschallendes": "durchschallend",
    "durchschallest": "durchschallen",
    "durchschallet": "durchschallen",
    "durchschallst": "durchschallen",
    "durchschallt": "durchschallen",
    "durchschallte": "durchschallen",
    "durchschallten": "durchschallen",
    "durchschalltest": "durchschallen",
    "durchschalltet": "durchschallen",
    "durchschaue": "durchschauen",
    "durchschauend": "durchschauen",
    "durchschauende": "durchschauend",
    "durchschauendem": "durchschauend",
    "durchschauenden": "durchschauend",
    "durchschauender": "durchschauend",
    "durchschauendes": "durchschauend",
    "durchschauest": "durchschauen",
    "durchschauet": "durchschauen",
    "durchschaust": "durchschauen",
    "durchschaut": "durchschauen",
    "durchschaute": "durchschauen",
    "durchschautem": "durchschaut",
    "durchschauten": "durchschauen",
    "durchschauter": "durchschaut",
    "durchschautes": "durchschaut",
    "durchschautest": "durchschauen",
    "durchschautet": "durchschauen",
    "durchscheine": "durchscheinen",
    "durchscheinend": "durchscheinen",
    "durchscheinende": "durchscheinend",
    "durchscheinendem": "durchscheinend",
    "durchscheinenden": "durchscheinend",
    "durchscheinender": "durchscheinend",
    "durchscheinendes": "durchscheinend",
    "durchscheinest": "durchscheinen",
    "durchscheinet": "durchscheinen",
    "durchscheinst": "durchscheinen",
    "durchscheint": "durchscheinen",
    "durchscheuere": "durchscheuern",
    "durchscheuernd": "durchscheuern",
    "durchscheuernde": "durchscheuernd",
    "durchscheuerndem": "durchscheuernd",
    "durchscheuernden": "durchscheuernd",
    "durchscheuernder": "durchscheuernd",
    "durchscheuerndere": "durchscheuernd",
    "durchscheuernderem": "durchscheuernd",
    "durchscheuernderen": "durchscheuernd",
    "durchscheuernderer": "durchscheuernd",
    "durchscheuernderes": "durchscheuernd",
    "durchscheuerndes": "durchscheuernd",
    "durchscheuerndste": "durchscheuernd",
    "durchscheuerndstem": "durchscheuernd",
    "durchscheuerndsten": "durchscheuernd",
    "durchscheuerndster": "durchscheuernd",
    "durchscheuerndstes": "durchscheuernd",
    "durchscheuerst": "durchscheuern",
    "durchscheuert": "durchscheuern",
    "durchscheuerte": "durchscheuern",
    "durchscheuerten": "durchscheuern",
    "durchscheuertest": "durchscheuern",
    "durchscheuertet": "durchscheuern",
    "durchschiebe": "durchschieben",
    "durchschiebend": "durchschieben",
    "durchschiebende": "durchschiebend",
    "durchschiebendem": "durchschiebend",
    "durchschiebenden": "durchschiebend",
    "durchschiebender": "durchschiebend",
    "durchschiebendes": "durchschiebend",
    "durchschiebest": "durchschieben",
    "durchschiebet": "durchschieben",
    "durchschiebst": "durchschieben",
    "durchschiebt": "durchschieben",
    "durchschien": "durchscheinen",
    "durchschiene": "durchscheinen",
    "durchschienen": "durchscheinen",
    "durchschienest": "durchscheinen",
    "durchschienet": "durchscheinen",
    "durchschienst": "durchscheinen",
    "durchschient": "durchscheinen",
    "durchschieße": "durchschießen",
    "durchschießend": "durchschießen",
    "durchschießende": "durchschießend",
    "durchschießendem": "durchschießend",
    "durchschießenden": "durchschießend",
    "durchschießender": "durchschießend",
    "durchschießendes": "durchschießend",
    "durchschießest": "durchschießen",
    "durchschießet": "durchschießen",
    "durchschießt": "durchschießen",
    "durchschimmere": "durchschimmern",
    "durchschimmernd": "durchschimmern",
    "durchschimmernde": "durchschimmernd",
    "durchschimmerndem": "durchschimmernd",
    "durchschimmernden": "durchschimmernd",
    "durchschimmernder": "durchschimmernd",
    "durchschimmerndere": "durchschimmernd",
    "durchschimmernderem": "durchschimmernd",
    "durchschimmernderen": "durchschimmernd",
    "durchschimmernderer": "durchschimmernd",
    "durchschimmernderes": "durchschimmernd",
    "durchschimmerndes": "durchschimmernd",
    "durchschimmerndste": "durchschimmernd",
    "durchschimmerndstem": "durchschimmernd",
    "durchschimmerndsten": "durchschimmernd",
    "durchschimmerndster": "durchschimmernd",
    "durchschimmerndstes": "durchschimmernd",
    "durchschimmerst": "durchschimmern",
    "durchschimmert": "durchschimmern",
    "durchschimmerte": "durchschimmern",
    "durchschimmerten": "durchschimmern",
    "durchschimmertest": "durchschimmern",
    "durchschimmertet": "durchschimmern",
    "durchschlafe": "durchschlafen",
    "durchschlafend": "durchschlafen",
    "durchschlafende": "durchschlafend",
    "durchschlafendem": "durchschlafend",
    "durchschlafenden": "durchschlafend",
    "durchschlafender": "durchschlafend",
    "durchschlafendes": "durchschlafend",
    "durchschlafest": "durchschlafen",
    "durchschlafet": "durchschlafen",
    "durchschlaft": "durchschlafen",
    "durchschlagend": "durchschlagen",
    "durchschlagende": "durchschlagend",
    "durchschlagendem": "durchschlagend",
    "durchschlagenden": "durchschlagend",
    "durchschlagender": "durchschlagend",
    "durchschlagendes": "durchschlagend",
    "durchschlagest": "durchschlagen",
    "durchschlaget": "durchschlagen",
    "durchschlagt": "durchschlagen",
    "durchschlang": "durchschlingen",
    "durchschlangen": "durchschlingen",
    "durchschlangst": "durchschlingen",
    "durchschlangt": "durchschlingen",
    "durchschleiche": "durchschleichen",
    "durchschleichend": "durchschleichen",
    "durchschleichende": "durchschleichend",
    "durchschleichendem": "durchschleichend",
    "durchschleichenden": "durchschleichend",
    "durchschleichender": "durchschleichend",
    "durchschleichendes": "durchschleichend",
    "durchschleichest": "durchschleichen",
    "durchschleichet": "durchschleichen",
    "durchschleichst": "durchschleichen",
    "durchschleicht": "durchschleichen",
    "durchschleppe": "durchschleppen",
    "durchschleppend": "durchschleppen",
    "durchschleppende": "durchschleppend",
    "durchschleppendem": "durchschleppend",
    "durchschleppenden": "durchschleppend",
    "durchschleppender": "durchschleppend",
    "durchschleppendes": "durchschleppend",
    "durchschleppest": "durchschleppen",
    "durchschleppet": "durchschleppen",
    "durchschleppst": "durchschleppen",
    "durchschleppt": "durchschleppen",
    "durchschleppte": "durchschleppen",
    "durchschleppten": "durchschleppen",
    "durchschlepptest": "durchschleppen",
    "durchschlepptet": "durchschleppen",
    "durchschleuse": "durchschleusen",
    "durchschleusend": "durchschleusen",
    "durchschleusende": "durchschleusend",
    "durchschleusendem": "durchschleusend",
    "durchschleusenden": "durchschleusend",
    "durchschleusender": "durchschleusend",
    "durchschleusendes": "durchschleusend",
    "durchschleusest": "durchschleusen",
    "durchschleuset": "durchschleusen",
    "durchschleust": "durchschleusen",
    "durchschleuste": "durchschleusen",
    "durchschleusten": "durchschleusen",
    "durchschleustest": "durchschleusen",
    "durchschleustet": "durchschleusen",
    "durchschlich": "durchschleichen",
    "durchschliche": "durchschleichen",
    "durchschlichen": "durchschleichen",
    "durchschlichest": "durchschleichen",
    "durchschlichet": "durchschleichen",
    "durchschlichst": "durchschleichen",
    "durchschlicht": "durchschleichen",
    "durchschlief": "durchschlafen",
    "durchschliefe": "durchschlafen",
    "durchschliefen": "durchschlafen",
    "durchschliefest": "durchschlafen",
    "durchschliefet": "durchschlafen",
    "durchschliefst": "durchschlafen",
    "durchschlieft": "durchschlafen",
    "durchschlinge": "durchschlingen",
    "durchschlingend": "durchschlingen",
    "durchschlingende": "durchschlingend",
    "durchschlingendem": "durchschlingend",
    "durchschlingenden": "durchschlingend",
    "durchschlingender": "durchschlingend",
    "durchschlingendes": "durchschlingend",
    "durchschlingest": "durchschlingen",
    "durchschlinget": "durchschlingen",
    "durchschlingst": "durchschlingen",
    "durchschlingt": "durchschlingen",
    "durchschlug": "durchschlagen",
    "durchschlugen": "durchschlagen",
    "durchschlugst": "durchschlagen",
    "durchschlugt": "durchschlagen",
    "durchschläfst": "durchschlafen",
    "durchschläft": "durchschlafen",
    "durchschlägst": "durchschlagen",
    "durchschlägt": "durchschlagen",
    "durchschlänge": "durchschlingen",
    "durchschlängele": "durchschlängeln",
    "durchschlängelnd": "durchschlängeln",
    "durchschlängelnde": "durchschlängelnd",
    "durchschlängelndem": "durchschlängelnd",
    "durchschlängelnden": "durchschlängelnd",
    "durchschlängelnder": "durchschlängelnd",
    "durchschlängelndes": "durchschlängelnd",
    "durchschlängelst": "durchschlängeln",
    "durchschlängelt": "durchschlängeln",
    "durchschlängelte": "durchschlängeln",
    "durchschlängelten": "durchschlängeln",
    "durchschlängeltest": "durchschlängeln",
    "durchschlängeltet": "durchschlängeln",
    "durchschlängen": "durchschlingen",
    "durchschlängest": "durchschlingen",
    "durchschlänget": "durchschlingen",
    "durchschlängle": "durchschlängeln",
    "durchschlüge": "durchschlagen",
    "durchschlügen": "durchschlagen",
    "durchschlügest": "durchschlagen",
    "durchschlüget": "durchschlagen",
    "durchschlüpfe": "durchschlüpfen",
    "durchschlüpfend": "durchschlüpfen",
    "durchschlüpfende": "durchschlüpfend",
    "durchschlüpfendem": "durchschlüpfend",
    "durchschlüpfenden": "durchschlüpfend",
    "durchschlüpfender": "durchschlüpfend",
    "durchschlüpfendes": "durchschlüpfend",
    "durchschlüpfest": "durchschlüpfen",
    "durchschlüpfet": "durchschlüpfen",
    "durchschlüpfst": "durchschlüpfen",
    "durchschlüpft": "durchschlüpfen",
    "durchschlüpfte": "durchschlüpfen",
    "durchschlüpften": "durchschlüpfen",
    "durchschlüpftest": "durchschlüpfen",
    "durchschlüpftet": "durchschlüpfen",
    "durchschmelze": "durchschmelzen",
    "durchschmelzend": "durchschmelzen",
    "durchschmelzende": "durchschmelzend",
    "durchschmelzendem": "durchschmelzend",
    "durchschmelzenden": "durchschmelzend",
    "durchschmelzender": "durchschmelzend",
    "durchschmelzendes": "durchschmelzend",
    "durchschmelzest": "durchschmelzen",
    "durchschmelzet": "durchschmelzen",
    "durchschmelzt": "durchschmelzen",
    "durchschmilzt": "durchschmelzen",
    "durchschmolz": "durchschmelzen",
    "durchschmolzen": "durchschmelzen",
    "durchschmolzst": "durchschmelzen",
    "durchschmolzt": "durchschmelzen",
    "durchschmuggele": "durchschmuggeln",
    "durchschmuggelnd": "durchschmuggeln",
    "durchschmuggelnde": "durchschmuggelnd",
    "durchschmuggelndem": "durchschmuggelnd",
    "durchschmuggelnden": "durchschmuggelnd",
    "durchschmuggelnder": "durchschmuggelnd",
    "durchschmuggelndes": "durchschmuggelnd",
    "durchschmuggelst": "durchschmuggeln",
    "durchschmuggelt": "durchschmuggeln",
    "durchschmuggelte": "durchschmuggeln",
    "durchschmuggelten": "durchschmuggeln",
    "durchschmuggeltest": "durchschmuggeln",
    "durchschmuggeltet": "durchschmuggeln",
    "durchschmuggle": "durchschmuggeln",
    "durchschmölze": "durchschmelzen",
    "durchschmölzen": "durchschmelzen",
    "durchschmölzest": "durchschmelzen",
    "durchschmölzet": "durchschmelzen",
    "durchschneide": "durchschneiden",
    "durchschneidend": "durchschneiden",
    "durchschneidende": "durchschneidend",
    "durchschneidendem": "durchschneidend",
    "durchschneidenden": "durchschneidend",
    "durchschneidender": "durchschneidend",
    "durchschneidendes": "durchschneidend",
    "durchschneidest": "durchschneiden",
    "durchschneidet": "durchschneiden",
    "durchschnitt": "durchschneiden",
    "durchschnittest": "durchschneiden",
    "durchschnittet": "durchschneiden",
    "durchschnittliche": "durchschnittlich",
    "durchschnittlichem": "durchschnittlich",
    "durchschnittlichen": "durchschnittlich",
    "durchschnittlicher": "durchschnittlich",
    "durchschnittlichere": "durchschnittlich",
    "durchschnittlicherem": "durchschnittlich",
    "durchschnittlicheren": "durchschnittlich",
    "durchschnittlicherer": "durchschnittlich",
    "durchschnittlicheres": "durchschnittlich",
    "durchschnittliches": "durchschnittlich",
    "durchschnittlichste": "durchschnittlich",
    "durchschnittlichstem": "durchschnittlich",
    "durchschnittlichsten": "durchschnittlich",
    "durchschnittlichster": "durchschnittlich",
    "durchschnittlichstes": "durchschnittlich",
    "durchschob": "durchschieben",
    "durchschoben": "durchschieben",
    "durchschobst": "durchschieben",
    "durchschobt": "durchschieben",
    "durchschossen": "durchschießen",
    "durchschoß": "durchschießen",
    "durchschoßt": "durchschießen",
    "durchschreibe": "durchschreiben",
    "durchschreibend": "durchschreiben",
    "durchschreibende": "durchschreibend",
    "durchschreibendem": "durchschreibend",
    "durchschreibenden": "durchschreibend",
    "durchschreibender": "durchschreibend",
    "durchschreibendes": "durchschreibend",
    "durchschreibest": "durchschreiben",
    "durchschreibet": "durchschreiben",
    "durchschreibst": "durchschreiben",
    "durchschreibt": "durchschreiben",
    "durchschreite": "durchschreiten",
    "durchschreitend": "durchschreiten",
    "durchschreitende": "durchschreitend",
    "durchschreitendem": "durchschreitend",
    "durchschreitenden": "durchschreitend",
    "durchschreitender": "durchschreitend",
    "durchschreitendes": "durchschreitend",
    "durchschreitest": "durchschreiten",
    "durchschreitet": "durchschreiten",
    "durchschrieb": "durchschreiben",
    "durchschriebe": "durchschreiben",
    "durchschrieben": "durchschreiben",
    "durchschriebest": "durchschreiben",
    "durchschriebet": "durchschreiben",
    "durchschriebst": "durchschreiben",
    "durchschriebt": "durchschreiben",
    "durchschritt": "durchschreiten",
    "durchschritte": "durchschreiten",
    "durchschritten": "durchschreiten",
    "durchschrittene": "durchschritten",
    "durchschrittenem": "durchschritten",
    "durchschrittenen": "durchschritten",
    "durchschrittener": "durchschritten",
    "durchschrittenes": "durchschritten",
    "durchschrittest": "durchschreiten",
    "durchschrittet": "durchschreiten",
    "durchschwamm": "durchschwimmen",
    "durchschwammen": "durchschwimmen",
    "durchschwammst": "durchschwimmen",
    "durchschwammt": "durchschwimmen",
    "durchschwimme": "durchschwimmen",
    "durchschwimmend": "durchschwimmen",
    "durchschwimmende": "durchschwimmend",
    "durchschwimmendem": "durchschwimmend",
    "durchschwimmenden": "durchschwimmend",
    "durchschwimmender": "durchschwimmend",
    "durchschwimmendes": "durchschwimmend",
    "durchschwimmest": "durchschwimmen",
    "durchschwimmet": "durchschwimmen",
    "durchschwimmst": "durchschwimmen",
    "durchschwimmt": "durchschwimmen",
    "durchschwindele": "durchschwindeln",
    "durchschwindelnd": "durchschwindeln",
    "durchschwindelnde": "durchschwindelnd",
    "durchschwindelndem": "durchschwindelnd",
    "durchschwindelnden": "durchschwindelnd",
    "durchschwindelnder": "durchschwindelnd",
    "durchschwindelndes": "durchschwindelnd",
    "durchschwindelst": "durchschwindeln",
    "durchschwindelt": "durchschwindeln",
    "durchschwindelte": "durchschwindeln",
    "durchschwindelten": "durchschwindeln",
    "durchschwindeltest": "durchschwindeln",
    "durchschwindeltet": "durchschwindeln",
    "durchschwindle": "durchschwindeln",
    "durchschwitze": "durchschwitzen",
    "durchschwitzend": "durchschwitzen",
    "durchschwitzende": "durchschwitzend",
    "durchschwitzendem": "durchschwitzend",
    "durchschwitzenden": "durchschwitzend",
    "durchschwitzender": "durchschwitzend",
    "durchschwitzendere": "durchschwitzend",
    "durchschwitzenderem": "durchschwitzend",
    "durchschwitzenderen": "durchschwitzend",
    "durchschwitzenderer": "durchschwitzend",
    "durchschwitzenderes": "durchschwitzend",
    "durchschwitzendes": "durchschwitzend",
    "durchschwitzendste": "durchschwitzend",
    "durchschwitzendstem": "durchschwitzend",
    "durchschwitzendsten": "durchschwitzend",
    "durchschwitzendster": "durchschwitzend",
    "durchschwitzendstes": "durchschwitzend",
    "durchschwitzest": "durchschwitzen",
    "durchschwitzet": "durchschwitzen",
    "durchschwitzt": "durchschwitzen",
    "durchschwitzte": "durchschwitzen",
    "durchschwitzten": "durchschwitzen",
    "durchschwitztest": "durchschwitzen",
    "durchschwitztet": "durchschwitzen",
    "durchschwommen": "durchschwimmen",
    "durchschwommene": "durchschwommen",
    "durchschwommenem": "durchschwommen",
    "durchschwommenen": "durchschwommen",
    "durchschwommener": "durchschwommen",
    "durchschwommenes": "durchschwommen",
    "durchschwämme": "durchschwimmen",
    "durchschwämmen": "durchschwimmen",
    "durchschwämmest": "durchschwimmen",
    "durchschwämmet": "durchschwimmen",
    "durchschöbe": "durchschieben",
    "durchschöben": "durchschieben",
    "durchschöbest": "durchschieben",
    "durchschöbet": "durchschieben",
    "durchschösse": "durchschießen",
    "durchschössen": "durchschießen",
    "durchschössest": "durchschießen",
    "durchschösset": "durchschießen",
    "durchschüttele": "durchschütteln",
    "durchschüttelnd": "durchschütteln",
    "durchschüttelnde": "durchschüttelnd",
    "durchschüttelndem": "durchschüttelnd",
    "durchschüttelnden": "durchschüttelnd",
    "durchschüttelnder": "durchschüttelnd",
    "durchschüttelndere": "durchschüttelnd",
    "durchschüttelnderem": "durchschüttelnd",
    "durchschüttelnderen": "durchschüttelnd",
    "durchschüttelnderer": "durchschüttelnd",
    "durchschüttelnderes": "durchschüttelnd",
    "durchschüttelndes": "durchschüttelnd",
    "durchschüttelndste": "durchschüttelnd",
    "durchschüttelndstem": "durchschüttelnd",
    "durchschüttelndsten": "durchschüttelnd",
    "durchschüttelndster": "durchschüttelnd",
    "durchschüttelndstes": "durchschüttelnd",
    "durchschüttelst": "durchschütteln",
    "durchschüttelt": "durchschütteln",
    "durchschüttelte": "durchschütteln",
    "durchschüttelten": "durchschütteln",
    "durchschütteltest": "durchschütteln",
    "durchschütteltet": "durchschütteln",
    "durchschüttle": "durchschütteln",
    "durchsegele": "durchsegeln",
    "durchsegelnd": "durchsegeln",
    "durchsegelnde": "durchsegelnd",
    "durchsegelndem": "durchsegelnd",
    "durchsegelnden": "durchsegelnd",
    "durchsegelnder": "durchsegelnd",
    "durchsegelndes": "durchsegelnd",
    "durchsegelst": "durchsegeln",
    "durchsegelt": "durchsegeln",
    "durchsegelte": "durchsegeln",
    "durchsegeltem": "durchsegelt",
    "durchsegelten": "durchsegeln",
    "durchsegelter": "durchsegelt",
    "durchsegeltes": "durchsegelt",
    "durchsegeltest": "durchsegeln",
    "durchsegeltet": "durchsegeln",
    "durchsegle": "durchsegeln",
    "durchsehe": "durchsehen",
    "durchsehend": "durchsehen",
    "durchsehende": "durchsehend",
    "durchsehendem": "durchsehend",
    "durchsehenden": "durchsehend",
    "durchsehender": "durchsehend",
    "durchsehendes": "durchsehend",
    "durchsehest": "durchsehen",
    "durchsehet": "durchsehen",
    "durchseht": "durchsehen",
    "durchsetzbare": "durchsetzbar",
    "durchsetzbarem": "durchsetzbar",
    "durchsetzbaren": "durchsetzbar",
    "durchsetzbarer": "durchsetzbar",
    "durchsetzbarere": "durchsetzbar",
    "durchsetzbarerem": "durchsetzbar",
    "durchsetzbareren": "durchsetzbar",
    "durchsetzbarerer": "durchsetzbar",
    "durchsetzbareres": "durchsetzbar",
    "durchsetzbares": "durchsetzbar",
    "durchsetzbarste": "durchsetzbar",
    "durchsetzbarstem": "durchsetzbar",
    "durchsetzbarsten": "durchsetzbar",
    "durchsetzbarster": "durchsetzbar",
    "durchsetzbarstes": "durchsetzbar",
    "durchsetze": "durchsetzen",
    "durchsetzend": "durchsetzen",
    "durchsetzende": "durchsetzend",
    "durchsetzendem": "durchsetzend",
    "durchsetzenden": "durchsetzend",
    "durchsetzender": "durchsetzend",
    "durchsetzendere": "durchsetzend",
    "durchsetzenderem": "durchsetzend",
    "durchsetzenderen": "durchsetzend",
    "durchsetzenderer": "durchsetzend",
    "durchsetzenderes": "durchsetzend",
    "durchsetzendes": "durchsetzend",
    "durchsetzendste": "durchsetzend",
    "durchsetzendstem": "durchsetzend",
    "durchsetzendsten": "durchsetzend",
    "durchsetzendster": "durchsetzend",
    "durchsetzendstes": "durchsetzend",
    "durchsetzest": "durchsetzen",
    "durchsetzet": "durchsetzen",
    "durchsetzt": "durchsetzen",
    "durchsetzte": "durchsetzen",
    "durchsetzten": "durchsetzen",
    "durchsetztest": "durchsetzen",
    "durchsetztet": "durchsetzen",
    "durchsichtigem": "durchsichtig",
    "durchsichtigen": "durchsichtig",
    "durchsichtiger": "durchsichtig",
    "durchsichtigere": "durchsichtig",
    "durchsichtigerem": "durchsichtig",
    "durchsichtigeren": "durchsichtig",
    "durchsichtigerer": "durchsichtig",
    "durchsichtigeres": "durchsichtig",
    "durchsichtiges": "durchsichtig",
    "durchsichtigste": "durchsichtig",
    "durchsichtigstem": "durchsichtig",
    "durchsichtigsten": "durchsichtig",
    "durchsichtigster": "durchsichtig",
    "durchsichtigstes": "durchsichtig",
    "durchsiebe": "durchsieben",
    "durchsiebend": "durchsieben",
    "durchsiebende": "durchsiebend",
    "durchsiebendem": "durchsiebend",
    "durchsiebenden": "durchsiebend",
    "durchsiebender": "durchsiebend",
    "durchsiebendere": "durchsiebend",
    "durchsiebenderem": "durchsiebend",
    "durchsiebenderen": "durchsiebend",
    "durchsiebenderer": "durchsiebend",
    "durchsiebenderes": "durchsiebend",
    "durchsiebendes": "durchsiebend",
    "durchsiebendste": "durchsiebend",
    "durchsiebendstem": "durchsiebend",
    "durchsiebendsten": "durchsiebend",
    "durchsiebendster": "durchsiebend",
    "durchsiebendstes": "durchsiebend",
    "durchsiebest": "durchsieben",
    "durchsiebet": "durchsieben",
    "durchsiebst": "durchsieben",
    "durchsiebt": "durchsieben",
    "durchsiebte": "durchsieben",
    "durchsiebten": "durchsieben",
    "durchsiebtest": "durchsieben",
    "durchsiebtet": "durchsieben",
    "durchsiehst": "durchsehen",
    "durchsieht": "durchsehen",
    "durchsinge": "durchsingen",
    "durchsingend": "durchsingen",
    "durchsingende": "durchsingend",
    "durchsingendem": "durchsingend",
    "durchsingenden": "durchsingend",
    "durchsingender": "durchsingend",
    "durchsingendes": "durchsingend",
    "durchsingest": "durchsingen",
    "durchsinget": "durchsingen",
    "durchsingst": "durchsingen",
    "durchsingt": "durchsingen",
    "durchsinke": "durchsinken",
    "durchsinkend": "durchsinken",
    "durchsinkende": "durchsinkend",
    "durchsinkendem": "durchsinkend",
    "durchsinkenden": "durchsinkend",
    "durchsinkender": "durchsinkend",
    "durchsinkendes": "durchsinkend",
    "durchsinkest": "durchsinken",
    "durchsinket": "durchsinken",
    "durchsinkst": "durchsinken",
    "durchsinkt": "durchsinken",
    "durchsitze": "durchsitzen",
    "durchsitzend": "durchsitzen",
    "durchsitzende": "durchsitzend",
    "durchsitzendem": "durchsitzend",
    "durchsitzenden": "durchsitzend",
    "durchsitzender": "durchsitzend",
    "durchsitzendes": "durchsitzend",
    "durchsitzest": "durchsitzen",
    "durchsitzet": "durchsitzen",
    "durchsitzt": "durchsitzen",
    "durchsoff": "durchsaufen",
    "durchsoffen": "durchsaufen",
    "durchsoffst": "durchsaufen",
    "durchsofft": "durchsaufen",
    "durchsog": "durchsaugen",
    "durchsogen": "durchsaugen",
    "durchsogst": "durchsaugen",
    "durchsogt": "durchsaugen",
    "durchspiele": "durchspielen",
    "durchspielend": "durchspielen",
    "durchspielende": "durchspielend",
    "durchspielendem": "durchspielend",
    "durchspielenden": "durchspielend",
    "durchspielender": "durchspielend",
    "durchspielendes": "durchspielend",
    "durchspielest": "durchspielen",
    "durchspielet": "durchspielen",
    "durchspielst": "durchspielen",
    "durchspielt": "durchspielen",
    "durchspielte": "durchspielen",
    "durchspielten": "durchspielen",
    "durchspieltest": "durchspielen",
    "durchspieltet": "durchspielen",
    "durchsprach": "durchsprechen",
    "durchsprachen": "durchsprechen",
    "durchsprachst": "durchsprechen",
    "durchspracht": "durchsprechen",
    "durchsprang": "durchspringen",
    "durchsprangen": "durchspringen",
    "durchsprangst": "durchspringen",
    "durchsprangt": "durchspringen",
    "durchspreche": "durchsprechen",
    "durchsprechend": "durchsprechen",
    "durchsprechende": "durchsprechend",
    "durchsprechendem": "durchsprechend",
    "durchsprechenden": "durchsprechend",
    "durchsprechender": "durchsprechend",
    "durchsprechendes": "durchsprechend",
    "durchsprechest": "durchsprechen",
    "durchsprechet": "durchsprechen",
    "durchsprecht": "durchsprechen",
    "durchsprichst": "durchsprechen",
    "durchspricht": "durchsprechen",
    "durchspringe": "durchspringen",
    "durchspringend": "durchspringen",
    "durchspringende": "durchspringend",
    "durchspringendem": "durchspringend",
    "durchspringenden": "durchspringend",
    "durchspringender": "durchspringend",
    "durchspringendes": "durchspringend",
    "durchspringest": "durchspringen",
    "durchspringet": "durchspringen",
    "durchspringst": "durchspringen",
    "durchspringt": "durchspringen",
    "durchspräche": "durchsprechen",
    "durchsprächen": "durchsprechen",
    "durchsprächest": "durchsprechen",
    "durchsprächet": "durchsprechen",
    "durchspränge": "durchspringen",
    "durchsprängen": "durchspringen",
    "durchsprängest": "durchspringen",
    "durchspränget": "durchspringen",
    "durchspüle": "durchspülen",
    "durchspülend": "durchspülen",
    "durchspülende": "durchspülend",
    "durchspülendem": "durchspülend",
    "durchspülenden": "durchspülend",
    "durchspülender": "durchspülend",
    "durchspülendes": "durchspülend",
    "durchspülest": "durchspülen",
    "durchspület": "durchspülen",
    "durchspülst": "durchspülen",
    "durchspült": "durchspülen",
    "durchspülte": "durchspülen",
    "durchspülten": "durchspülen",
    "durchspültest": "durchspülen",
    "durchspültet": "durchspülen",
    "durchstach": "durchstechen",
    "durchstachen": "durchstechen",
    "durchstachst": "durchstechen",
    "durchstacht": "durchstechen",
    "durchstand": "durchstehen",
    "durchstanden": "durchstehen",
    "durchstandest": "durchstehen",
    "durchstandet": "durchstehen",
    "durchstarte": "durchstarten",
    "durchstartend": "durchstarten",
    "durchstartende": "durchstartend",
    "durchstartendem": "durchstartend",
    "durchstartenden": "durchstartend",
    "durchstartender": "durchstartend",
    "durchstartendes": "durchstartend",
    "durchstartest": "durchstarten",
    "durchstartet": "durchstarten",
    "durchstartete": "durchstarten",
    "durchstarteten": "durchstarten",
    "durchstartetest": "durchstarten",
    "durchstartetet": "durchstarten",
    "durchsteche": "durchstechen",
    "durchstechend": "durchstechen",
    "durchstechende": "durchstechend",
    "durchstechendem": "durchstechend",
    "durchstechenden": "durchstechend",
    "durchstechender": "durchstechend",
    "durchstechendere": "durchstechend",
    "durchstechenderem": "durchstechend",
    "durchstechenderen": "durchstechend",
    "durchstechenderer": "durchstechend",
    "durchstechenderes": "durchstechend",
    "durchstechendes": "durchstechend",
    "durchstechendste": "durchstechend",
    "durchstechendstem": "durchstechend",
    "durchstechendsten": "durchstechend",
    "durchstechendster": "durchstechend",
    "durchstechendstes": "durchstechend",
    "durchstechest": "durchstechen",
    "durchstechet": "durchstechen",
    "durchstecht": "durchstechen",
    "durchstehe": "durchstehen",
    "durchstehend": "durchstehen",
    "durchstehende": "durchstehend",
    "durchstehendem": "durchstehend",
    "durchstehenden": "durchstehend",
    "durchstehender": "durchstehend",
    "durchstehendes": "durchstehend",
    "durchstehest": "durchstehen",
    "durchstehet": "durchstehen",
    "durchstehst": "durchstehen",
    "durchsteht": "durchstehen",
    "durchsteige": "durchsteigen",
    "durchsteigend": "durchsteigen",
    "durchsteigende": "durchsteigend",
    "durchsteigendem": "durchsteigend",
    "durchsteigenden": "durchsteigend",
    "durchsteigender": "durchsteigend",
    "durchsteigendere": "durchsteigend",
    "durchsteigenderem": "durchsteigend",
    "durchsteigenderen": "durchsteigend",
    "durchsteigenderer": "durchsteigend",
    "durchsteigenderes": "durchsteigend",
    "durchsteigendes": "durchsteigend",
    "durchsteigendste": "durchsteigend",
    "durchsteigendstem": "durchsteigend",
    "durchsteigendsten": "durchsteigend",
    "durchsteigendster": "durchsteigend",
    "durchsteigendstes": "durchsteigend",
    "durchsteigest": "durchsteigen",
    "durchsteiget": "durchsteigen",
    "durchsteigst": "durchsteigen",
    "durchsteigt": "durchsteigen",
    "durchstelle": "durchstellen",
    "durchstellend": "durchstellen",
    "durchstellende": "durchstellend",
    "durchstellendem": "durchstellend",
    "durchstellenden": "durchstellend",
    "durchstellender": "durchstellend",
    "durchstellendes": "durchstellend",
    "durchstellest": "durchstellen",
    "durchstellet": "durchstellen",
    "durchstellst": "durchstellen",
    "durchstellt": "durchstellen",
    "durchstellte": "durchstellen",
    "durchstellten": "durchstellen",
    "durchstelltest": "durchstellen",
    "durchstelltet": "durchstellen",
    "durchstich": "durchstechen",
    "durchstichst": "durchstechen",
    "durchsticht": "durchstechen",
    "durchstieg": "durchsteigen",
    "durchstiege": "durchsteigen",
    "durchstiegen": "durchsteigen",
    "durchstiegest": "durchsteigen",
    "durchstieget": "durchsteigen",
    "durchstiegst": "durchsteigen",
    "durchstiegt": "durchsteigen",
    "durchstieß": "durchstoßen",
    "durchstieße": "durchstoßen",
    "durchstießen": "durchstoßen",
    "durchstießest": "durchstoßen",
    "durchstießet": "durchstoßen",
    "durchstießt": "durchstoßen",
    "durchstimme": "durchstimmen",
    "durchstimmend": "durchstimmen",
    "durchstimmende": "durchstimmend",
    "durchstimmendem": "durchstimmend",
    "durchstimmenden": "durchstimmend",
    "durchstimmender": "durchstimmend",
    "durchstimmendes": "durchstimmend",
    "durchstimmest": "durchstimmen",
    "durchstimmet": "durchstimmen",
    "durchstimmst": "durchstimmen",
    "durchstimmt": "durchstimmen",
    "durchstimmte": "durchstimmen",
    "durchstimmten": "durchstimmen",
    "durchstimmtest": "durchstimmen",
    "durchstimmtet": "durchstimmen",
    "durchstoch": "durchstechen",
    "durchstochen": "durchstechen",
    "durchstochene": "durchstochen",
    "durchstochenem": "durchstochen",
    "durchstochenen": "durchstochen",
    "durchstochener": "durchstochen",
    "durchstochenere": "durchstochen",
    "durchstochenerem": "durchstochen",
    "durchstocheneren": "durchstochen",
    "durchstochenerer": "durchstochen",
    "durchstocheneres": "durchstochen",
    "durchstochenes": "durchstochen",
    "durchstochenste": "durchstochen",
    "durchstochenstem": "durchstochen",
    "durchstochensten": "durchstochen",
    "durchstochenster": "durchstochen",
    "durchstochenstes": "durchstochen",
    "durchstochst": "durchstechen",
    "durchstocht": "durchstechen",
    "durchstoße": "durchstoßen",
    "durchstoßend": "durchstoßen",
    "durchstoßende": "durchstoßend",
    "durchstoßendem": "durchstoßend",
    "durchstoßenden": "durchstoßend",
    "durchstoßender": "durchstoßend",
    "durchstoßendes": "durchstoßend",
    "durchstoßest": "durchstoßen",
    "durchstoßet": "durchstoßen",
    "durchstoßt": "durchstoßen",
    "durchstreiche": "durchstreichen",
    "durchstreichend": "durchstreichen",
    "durchstreichende": "durchstreichend",
    "durchstreichendem": "durchstreichend",
    "durchstreichenden": "durchstreichend",
    "durchstreichender": "durchstreichend",
    "durchstreichendes": "durchstreichend",
    "durchstreichest": "durchstreichen",
    "durchstreichet": "durchstreichen",
    "durchstreichst": "durchstreichen",
    "durchstreicht": "durchstreichen",
    "durchstreife": "durchstreifen",
    "durchstreifend": "durchstreifen",
    "durchstreifende": "durchstreifend",
    "durchstreifendem": "durchstreifend",
    "durchstreifenden": "durchstreifend",
    "durchstreifender": "durchstreifend",
    "durchstreifendes": "durchstreifend",
    "durchstreifest": "durchstreifen",
    "durchstreifet": "durchstreifen",
    "durchstreifst": "durchstreifen",
    "durchstreift": "durchstreifen",
    "durchstreifte": "durchstreifen",
    "durchstreiftem": "durchstreift",
    "durchstreiften": "durchstreifen",
    "durchstreifter": "durchstreift",
    "durchstreiftes": "durchstreift",
    "durchstreiftest": "durchstreifen",
    "durchstreiftet": "durchstreifen",
    "durchstrich": "durchstreichen",
    "durchstriche": "durchstreichen",
    "durchstrichen": "durchstreichen",
    "durchstrichest": "durchstreichen",
    "durchstrichet": "durchstreichen",
    "durchstrichst": "durchstreichen",
    "durchstricht": "durchstreichen",
    "durchstrukturieren": "durchstrukturiere",
    "durchstrukturierend": "durchstrukturiere",
    "durchstrukturierende": "durchstrukturierend",
    "durchstrukturierendem": "durchstrukturierend",
    "durchstrukturierenden": "durchstrukturierend",
    "durchstrukturierender": "durchstrukturierend",
    "durchstrukturierendere": "durchstrukturierend",
    "durchstrukturierenderem": "durchstrukturierend",
    "durchstrukturierenderen": "durchstrukturierend",
    "durchstrukturierenderer": "durchstrukturierend",
    "durchstrukturierenderes": "durchstrukturierend",
    "durchstrukturierendes": "durchstrukturierend",
    "durchstrukturierendste": "durchstrukturierend",
    "durchstrukturierendstem": "durchstrukturierend",
    "durchstrukturierendsten": "durchstrukturierend",
    "durchstrukturierendster": "durchstrukturierend",
    "durchstrukturierendstes": "durchstrukturierend",
    "durchstrukturierest": "durchstrukturiere",
    "durchstrukturieret": "durchstrukturiere",
    "durchstrukturierst": "durchstrukturiere",
    "durchstrukturiert": "durchstrukturiere",
    "durchstrukturierte": "durchstrukturiere",
    "durchstrukturiertem": "durchstrukturiert",
    "durchstrukturierten": "durchstrukturiere",
    "durchstrukturierter": "durchstrukturiert",
    "durchstrukturiertere": "durchstrukturiert",
    "durchstrukturierterem": "durchstrukturiert",
    "durchstrukturierteren": "durchstrukturiert",
    "durchstrukturierterer": "durchstrukturiert",
    "durchstrukturierteres": "durchstrukturiert",
    "durchstrukturiertes": "durchstrukturiert",
    "durchstrukturiertest": "durchstrukturiere",
    "durchstrukturierteste": "durchstrukturiert",
    "durchstrukturiertestem": "durchstrukturiert",
    "durchstrukturiertesten": "durchstrukturiert",
    "durchstrukturiertester": "durchstrukturiert",
    "durchstrukturiertestes": "durchstrukturiert",
    "durchstrukturiertet": "durchstrukturiere",
    "durchströme": "durchströmen",
    "durchströmend": "durchströmen",
    "durchströmende": "durchströmend",
    "durchströmendem": "durchströmend",
    "durchströmenden": "durchströmend",
    "durchströmender": "durchströmend",
    "durchströmendes": "durchströmend",
    "durchströmest": "durchströmen",
    "durchströmet": "durchströmen",
    "durchströmst": "durchströmen",
    "durchströmt": "durchströmen",
    "durchströmte": "durchströmen",
    "durchströmtem": "durchströmt",
    "durchströmten": "durchströmen",
    "durchströmter": "durchströmt",
    "durchströmtes": "durchströmt",
    "durchströmtest": "durchströmen",
    "durchströmtet": "durchströmen",
    "durchstäche": "durchstechen",
    "durchstächen": "durchstechen",
    "durchstächest": "durchstechen",
    "durchstächet": "durchstechen",
    "durchstöbere": "durchstöbern",
    "durchstöbernd": "durchstöbern",
    "durchstöbernde": "durchstöbernd",
    "durchstöberndem": "durchstöbernd",
    "durchstöbernden": "durchstöbernd",
    "durchstöbernder": "durchstöbernd",
    "durchstöberndere": "durchstöbernd",
    "durchstöbernderem": "durchstöbernd",
    "durchstöbernderen": "durchstöbernd",
    "durchstöbernderer": "durchstöbernd",
    "durchstöbernderes": "durchstöbernd",
    "durchstöberndes": "durchstöbernd",
    "durchstöberndste": "durchstöbernd",
    "durchstöberndstem": "durchstöbernd",
    "durchstöberndsten": "durchstöbernd",
    "durchstöberndster": "durchstöbernd",
    "durchstöberndstes": "durchstöbernd",
    "durchstöberst": "durchstöbern",
    "durchstöbert": "durchstöbern",
    "durchstöberte": "durchstöbern",
    "durchstöbertem": "durchstöbert",
    "durchstöberten": "durchstöbern",
    "durchstöberter": "durchstöbert",
    "durchstöbertere": "durchstöbert",
    "durchstöberterem": "durchstöbert",
    "durchstöberteren": "durchstöbert",
    "durchstöberterer": "durchstöbert",
    "durchstöberteres": "durchstöbert",
    "durchstöbertes": "durchstöbert",
    "durchstöbertest": "durchstöbern",
    "durchstöberteste": "durchstöbert",
    "durchstöbertestem": "durchstöbert",
    "durchstöbertesten": "durchstöbert",
    "durchstöbertester": "durchstöbert",
    "durchstöbertestes": "durchstöbert",
    "durchstöbertet": "durchstöbern",
    "durchstöche": "durchstechen",
    "durchstöchen": "durchstechen",
    "durchstöchest": "durchstechen",
    "durchstöchet": "durchstechen",
    "durchstößt": "durchstoßen",
    "durchstünde": "durchstehen",
    "durchstünden": "durchstehen",
    "durchstündest": "durchstehen",
    "durchstündet": "durchstehen",
    "durchstürme": "durchstürmen",
    "durchstürmend": "durchstürmen",
    "durchstürmende": "durchstürmend",
    "durchstürmendem": "durchstürmend",
    "durchstürmenden": "durchstürmend",
    "durchstürmender": "durchstürmend",
    "durchstürmendes": "durchstürmend",
    "durchstürmest": "durchstürmen",
    "durchstürmet": "durchstürmen",
    "durchstürmst": "durchstürmen",
    "durchstürmt": "durchstürmen",
    "durchstürmte": "durchstürmen",
    "durchstürmten": "durchstürmen",
    "durchstürmtest": "durchstürmen",
    "durchstürmtet": "durchstürmen",
    "durchsuche": "durchsuchen",
    "durchsuchend": "durchsuchen",
    "durchsuchende": "durchsuchend",
    "durchsuchendem": "durchsuchend",
    "durchsuchenden": "durchsuchend",
    "durchsuchender": "durchsuchend",
    "durchsuchendes": "durchsuchend",
    "durchsuchest": "durchsuchen",
    "durchsuchet": "durchsuchen",
    "durchsuchst": "durchsuchen",
    "durchsucht": "durchsuchen",
    "durchsuchte": "durchsuchen",
    "durchsuchtem": "durchsucht",
    "durchsuchten": "durchsuchen",
    "durchsuchter": "durchsucht",
    "durchsuchtere": "durchsucht",
    "durchsuchterem": "durchsucht",
    "durchsuchteren": "durchsucht",
    "durchsuchterer": "durchsucht",
    "durchsuchteres": "durchsucht",
    "durchsuchtes": "durchsucht",
    "durchsuchtest": "durchsuchen",
    "durchsuchteste": "durchsucht",
    "durchsuchtestem": "durchsucht",
    "durchsuchtesten": "durchsucht",
    "durchsuchtester": "durchsucht",
    "durchsuchtestes": "durchsucht",
    "durchsuchtet": "durchsuchen",
    "durchsäge": "durchsägen",
    "durchsägend": "durchsägen",
    "durchsägendem": "durchsägend",
    "durchsägender": "durchsägend",
    "durchsägendes": "durchsägend",
    "durchsägest": "durchsägen",
    "durchsäget": "durchsägen",
    "durchsägst": "durchsägen",
    "durchsägt": "durchsägen",
    "durchsägte": "durchsägen",
    "durchsägten": "durchsägen",
    "durchsägtest": "durchsägen",
    "durchsägtet": "durchsägen",
    "durchsähe": "durchsehen",
    "durchsähen": "durchsehen",
    "durchsähest": "durchsehen",
    "durchsähet": "durchsehen",
    "durchsänge": "durchsingen",
    "durchsängen": "durchsingen",
    "durchsängest": "durchsingen",
    "durchsänget": "durchsingen",
    "durchsänke": "durchsinken",
    "durchsänken": "durchsinken",
    "durchsänkest": "durchsinken",
    "durchsänket": "durchsinken",
    "durchsäufst": "durchsaufen",
    "durchsäuft": "durchsaufen",
    "durchsäße": "durchsitzen",
    "durchsäßen": "durchsitzen",
    "durchsäßest": "durchsitzen",
    "durchsäßet": "durchsitzen",
    "durchsöffe": "durchsaufen",
    "durchsöffen": "durchsaufen",
    "durchsöffest": "durchsaufen",
    "durchsöffet": "durchsaufen",
    "durchsöge": "durchsaugen",
    "durchsögen": "durchsaugen",
    "durchsögest": "durchsaugen",
    "durchsöget": "durchsaugen",
    "durchtanze": "durchtanzen",
    "durchtanzend": "durchtanzen",
    "durchtanzende": "durchtanzend",
    "durchtanzendem": "durchtanzend",
    "durchtanzenden": "durchtanzend",
    "durchtanzender": "durchtanzend",
    "durchtanzendes": "durchtanzend",
    "durchtanzest": "durchtanzen",
    "durchtanzet": "durchtanzen",
    "durchtanzt": "durchtanzen",
    "durchtanzte": "durchtanzen",
    "durchtanzten": "durchtanzen",
    "durchtanztest": "durchtanzen",
    "durchtanztet": "durchtanzen",
    "durchteste": "durchtesten",
    "durchtestend": "durchtesten",
    "durchtestende": "durchtestend",
    "durchtestendem": "durchtestend",
    "durchtestenden": "durchtestend",
    "durchtestender": "durchtestend",
    "durchtestendes": "durchtestend",
    "durchtestest": "durchtesten",
    "durchtestet": "durchtesten",
    "durchtestete": "durchtesten",
    "durchtesteten": "durchtesten",
    "durchtestetest": "durchtesten",
    "durchtestetet": "durchtesten",
    "durchtrat": "durchtreten",
    "durchtraten": "durchtreten",
    "durchtratest": "durchtreten",
    "durchtratet": "durchtreten",
    "durchtreibe": "durchtreiben",
    "durchtreibend": "durchtreiben",
    "durchtreibende": "durchtreibend",
    "durchtreibendem": "durchtreibend",
    "durchtreibenden": "durchtreibend",
    "durchtreibender": "durchtreibend",
    "durchtreibendes": "durchtreibend",
    "durchtreibest": "durchtreiben",
    "durchtreibet": "durchtreiben",
    "durchtreibst": "durchtreiben",
    "durchtreibt": "durchtreiben",
    "durchtrenne": "durchtrennen",
    "durchtrennend": "durchtrennen",
    "durchtrennende": "durchtrennend",
    "durchtrennendem": "durchtrennend",
    "durchtrennenden": "durchtrennend",
    "durchtrennender": "durchtrennend",
    "durchtrennendes": "durchtrennend",
    "durchtrennest": "durchtrennen",
    "durchtrennet": "durchtrennen",
    "durchtrennst": "durchtrennen",
    "durchtrennt": "durchtrennen",
    "durchtrennte": "durchtrennen",
    "durchtrenntem": "durchtrennt",
    "durchtrennten": "durchtrennen",
    "durchtrennter": "durchtrennt",
    "durchtrenntes": "durchtrennt",
    "durchtrenntest": "durchtrennen",
    "durchtrenntet": "durchtrennen",
    "durchtrete": "durchtreten",
    "durchtretend": "durchtreten",
    "durchtretende": "durchtretend",
    "durchtretendem": "durchtretend",
    "durchtretenden": "durchtretend",
    "durchtretender": "durchtretend",
    "durchtretendes": "durchtretend",
    "durchtretest": "durchtreten",
    "durchtretet": "durchtreten",
    "durchtrieb": "durchtreiben",
    "durchtriebe": "durchtreiben",
    "durchtrieben": "durchtreiben",
    "durchtriebest": "durchtreiben",
    "durchtriebet": "durchtreiben",
    "durchtriebst": "durchtreiben",
    "durchtriebt": "durchtreiben",
    "durchtritt": "durchtreten",
    "durchtrittst": "durchtreten",
    "durchträte": "durchtreten",
    "durchträten": "durchtreten",
    "durchträtest": "durchtreten",
    "durchträtet": "durchtreten",
    "durchwand": "durchwinden",
    "durchwanden": "durchwinden",
    "durchwandere": "durchwandern",
    "durchwandernd": "durchwandern",
    "durchwandernde": "durchwandernd",
    "durchwanderndem": "durchwandernd",
    "durchwandernden": "durchwandernd",
    "durchwandernder": "durchwandernd",
    "durchwanderndere": "durchwandernd",
    "durchwandernderem": "durchwandernd",
    "durchwandernderen": "durchwandernd",
    "durchwandernderer": "durchwandernd",
    "durchwandernderes": "durchwandernd",
    "durchwanderndes": "durchwandernd",
    "durchwanderndste": "durchwandernd",
    "durchwanderndstem": "durchwandernd",
    "durchwanderndsten": "durchwandernd",
    "durchwanderndster": "durchwandernd",
    "durchwanderndstes": "durchwandernd",
    "durchwanderst": "durchwandern",
    "durchwandert": "durchwandern",
    "durchwanderte": "durchwandern",
    "durchwandertem": "durchwandert",
    "durchwanderten": "durchwandern",
    "durchwanderter": "durchwandert",
    "durchwandertere": "durchwandert",
    "durchwanderterem": "durchwandert",
    "durchwanderteren": "durchwandert",
    "durchwanderterer": "durchwandert",
    "durchwanderteres": "durchwandert",
    "durchwandertes": "durchwandert",
    "durchwandertest": "durchwandern",
    "durchwanderteste": "durchwandert",
    "durchwandertestem": "durchwandert",
    "durchwandertesten": "durchwandert",
    "durchwandertester": "durchwandert",
    "durchwandertestes": "durchwandert",
    "durchwandertet": "durchwandern",
    "durchwandest": "durchwinden",
    "durchwandet": "durchwinden",
    "durchwasche": "durchwaschen",
    "durchwaschend": "durchwaschen",
    "durchwaschende": "durchwaschend",
    "durchwaschendem": "durchwaschend",
    "durchwaschenden": "durchwaschend",
    "durchwaschender": "durchwaschend",
    "durchwaschendes": "durchwaschend",
    "durchwaschest": "durchwaschen",
    "durchwaschet": "durchwaschen",
    "durchwascht": "durchwaschen",
    "durchwebe": "durchweben",
    "durchwebend": "durchweben",
    "durchwebende": "durchwebend",
    "durchwebendem": "durchwebend",
    "durchwebenden": "durchwebend",
    "durchwebender": "durchwebend",
    "durchwebendes": "durchwebend",
    "durchwebest": "durchweben",
    "durchwebet": "durchweben",
    "durchwebst": "durchweben",
    "durchwebt": "durchweben",
    "durchwebte": "durchweben",
    "durchwebten": "durchweben",
    "durchwebtest": "durchweben",
    "durchwebtet": "durchweben",
    "durchweiche": "durchweichen",
    "durchweichend": "durchweichen",
    "durchweichende": "durchweichend",
    "durchweichendem": "durchweichend",
    "durchweichenden": "durchweichend",
    "durchweichender": "durchweichend",
    "durchweichendere": "durchweichend",
    "durchweichenderem": "durchweichend",
    "durchweichenderen": "durchweichend",
    "durchweichenderer": "durchweichend",
    "durchweichenderes": "durchweichend",
    "durchweichendes": "durchweichend",
    "durchweichendste": "durchweichend",
    "durchweichendstem": "durchweichend",
    "durchweichendsten": "durchweichend",
    "durchweichendster": "durchweichend",
    "durchweichendstes": "durchweichend",
    "durchweichest": "durchweichen",
    "durchweichet": "durchweichen",
    "durchweichst": "durchweichen",
    "durchweicht": "durchweichen",
    "durchweichte": "durchweichen",
    "durchweichten": "durchweichen",
    "durchweichtest": "durchweichen",
    "durchweichtet": "durchweichen",
    "durchwetze": "durchwetzen",
    "durchwetzend": "durchwetzen",
    "durchwetzende": "durchwetzend",
    "durchwetzendem": "durchwetzend",
    "durchwetzenden": "durchwetzend",
    "durchwetzender": "durchwetzend",
    "durchwetzendere": "durchwetzend",
    "durchwetzenderem": "durchwetzend",
    "durchwetzenderen": "durchwetzend",
    "durchwetzenderer": "durchwetzend",
    "durchwetzenderes": "durchwetzend",
    "durchwetzendes": "durchwetzend",
    "durchwetzendste": "durchwetzend",
    "durchwetzendstem": "durchwetzend",
    "durchwetzendsten": "durchwetzend",
    "durchwetzendster": "durchwetzend",
    "durchwetzendstes": "durchwetzend",
    "durchwetzest": "durchwetzen",
    "durchwetzet": "durchwetzen",
    "durchwetzt": "durchwetzen",
    "durchwetzte": "durchwetzen",
    "durchwetzten": "durchwetzen",
    "durchwetztest": "durchwetzen",
    "durchwetztet": "durchwetzen",
    "durchwich": "durchweichen",
    "durchwiche": "durchweichen",
    "durchwichen": "durchweichen",
    "durchwichest": "durchweichen",
    "durchwichet": "durchweichen",
    "durchwichst": "durchweichen",
    "durchwicht": "durchweichen",
    "durchwinde": "durchwinden",
    "durchwindend": "durchwinden",
    "durchwindende": "durchwindend",
    "durchwindendem": "durchwindend",
    "durchwindenden": "durchwindend",
    "durchwindender": "durchwindend",
    "durchwindendes": "durchwindend",
    "durchwindest": "durchwinden",
    "durchwindet": "durchwinden",
    "durchwirke": "durchwirken",
    "durchwirkend": "durchwirken",
    "durchwirkende": "durchwirkend",
    "durchwirkendem": "durchwirkend",
    "durchwirkenden": "durchwirkend",
    "durchwirkender": "durchwirkend",
    "durchwirkendes": "durchwirkend",
    "durchwirkest": "durchwirken",
    "durchwirket": "durchwirken",
    "durchwirkst": "durchwirken",
    "durchwirkt": "durchwirken",
    "durchwirkte": "durchwirken",
    "durchwirkten": "durchwirken",
    "durchwirktest": "durchwirken",
    "durchwirktet": "durchwirken",
    "durchwische": "durchwischen",
    "durchwischend": "durchwischen",
    "durchwischende": "durchwischend",
    "durchwischendem": "durchwischend",
    "durchwischenden": "durchwischend",
    "durchwischender": "durchwischend",
    "durchwischendes": "durchwischend",
    "durchwischest": "durchwischen",
    "durchwischet": "durchwischen",
    "durchwischst": "durchwischen",
    "durchwischt": "durchwischen",
    "durchwischte": "durchwischen",
    "durchwischten": "durchwischen",
    "durchwischtest": "durchwischen",
    "durchwischtet": "durchwischen",
    "durchwob": "durchweben",
    "durchwoben": "durchweben",
    "durchwobst": "durchweben",
    "durchwobt": "durchweben",
    "durchwurstele": "durchwursteln",
    "durchwurstelnd": "durchwursteln",
    "durchwurstelnde": "durchwurstelnd",
    "durchwurstelndem": "durchwurstelnd",
    "durchwurstelnden": "durchwurstelnd",
    "durchwurstelnder": "durchwurstelnd",
    "durchwurstelndere": "durchwurstelnd",
    "durchwurstelnderem": "durchwurstelnd",
    "durchwurstelnderen": "durchwurstelnd",
    "durchwurstelnderer": "durchwurstelnd",
    "durchwurstelnderes": "durchwurstelnd",
    "durchwurstelndes": "durchwurstelnd",
    "durchwurstelndste": "durchwurstelnd",
    "durchwurstelndstem": "durchwurstelnd",
    "durchwurstelndsten": "durchwurstelnd",
    "durchwurstelndster": "durchwurstelnd",
    "durchwurstelndstes": "durchwurstelnd",
    "durchwurstelst": "durchwursteln",
    "durchwurstelt": "durchwursteln",
    "durchwurstelte": "durchwursteln",
    "durchwurstelten": "durchwursteln",
    "durchwursteltest": "durchwursteln",
    "durchwursteltet": "durchwursteln",
    "durchwurstle": "durchwursteln",
    "durchwusch": "durchwaschen",
    "durchwuschen": "durchwaschen",
    "durchwuschst": "durchwaschen",
    "durchwuscht": "durchwaschen",
    "durchwähle": "durchwählen",
    "durchwählend": "durchwählen",
    "durchwählende": "durchwählend",
    "durchwählendem": "durchwählend",
    "durchwählenden": "durchwählend",
    "durchwählender": "durchwählend",
    "durchwählendes": "durchwählend",
    "durchwählest": "durchwählen",
    "durchwählet": "durchwählen",
    "durchwählst": "durchwählen",
    "durchwählt": "durchwählen",
    "durchwählte": "durchwählen",
    "durchwählten": "durchwählen",
    "durchwähltest": "durchwählen",
    "durchwähltet": "durchwählen",
    "durchwände": "durchwinden",
    "durchwänden": "durchwinden",
    "durchwändest": "durchwinden",
    "durchwändet": "durchwinden",
    "durchwärme": "durchwärmen",
    "durchwärmend": "durchwärmen",
    "durchwärmende": "durchwärmend",
    "durchwärmendem": "durchwärmend",
    "durchwärmenden": "durchwärmend",
    "durchwärmender": "durchwärmend",
    "durchwärmendere": "durchwärmend",
    "durchwärmenderem": "durchwärmend",
    "durchwärmenderen": "durchwärmend",
    "durchwärmenderer": "durchwärmend",
    "durchwärmenderes": "durchwärmend",
    "durchwärmendes": "durchwärmend",
    "durchwärmendste": "durchwärmend",
    "durchwärmendstem": "durchwärmend",
    "durchwärmendsten": "durchwärmend",
    "durchwärmendster": "durchwärmend",
    "durchwärmendstes": "durchwärmend",
    "durchwärmest": "durchwärmen",
    "durchwärmet": "durchwärmen",
    "durchwärmst": "durchwärmen",
    "durchwärmt": "durchwärmen",
    "durchwärmte": "durchwärmen",
    "durchwärmten": "durchwärmen",
    "durchwärmtest": "durchwärmen",
    "durchwärmtet": "durchwärmen",
    "durchwäschst": "durchwaschen",
    "durchwäscht": "durchwaschen",
    "durchwöbe": "durchweben",
    "durchwöben": "durchweben",
    "durchwöbest": "durchweben",
    "durchwöbet": "durchweben",
    "durchwühle": "durchwühlen",
    "durchwühlend": "durchwühlen",
    "durchwühlende": "durchwühlend",
    "durchwühlendem": "durchwühlend",
    "durchwühlenden": "durchwühlend",
    "durchwühlender": "durchwühlend",
    "durchwühlendere": "durchwühlend",
    "durchwühlenderem": "durchwühlend",
    "durchwühlenderen": "durchwühlend",
    "durchwühlenderer": "durchwühlend",
    "durchwühlenderes": "durchwühlend",
    "durchwühlendes": "durchwühlend",
    "durchwühlendste": "durchwühlend",
    "durchwühlendstem": "durchwühlend",
    "durchwühlendsten": "durchwühlend",
    "durchwühlendster": "durchwühlend",
    "durchwühlendstes": "durchwühlend",
    "durchwühlest": "durchwühlen",
    "durchwühlet": "durchwühlen",
    "durchwühlst": "durchwühlen",
    "durchwühlt": "durchwühlen",
    "durchwühlte": "durchwühlen",
    "durchwühltem": "durchwühlt",
    "durchwühlten": "durchwühlen",
    "durchwühlter": "durchwühlt",
    "durchwühltere": "durchwühlt",
    "durchwühlterem": "durchwühlt",
    "durchwühlteren": "durchwühlt",
    "durchwühlterer": "durchwühlt",
    "durchwühlteres": "durchwühlt",
    "durchwühltes": "durchwühlt",
    "durchwühltest": "durchwühlen",
    "durchwühlteste": "durchwühlt",
    "durchwühltestem": "durchwühlt",
    "durchwühltesten": "durchwühlt",
    "durchwühltester": "durchwühlt",
    "durchwühltestes": "durchwühlt",
    "durchwühltet": "durchwühlen",
    "durchwüsche": "durchwaschen",
    "durchwüschen": "durchwaschen",
    "durchwüschest": "durchwaschen",
    "durchwüschet": "durchwaschen",
    "durchzeche": "durchzechen",
    "durchzechend": "durchzechen",
    "durchzechende": "durchzechend",
    "durchzechendem": "durchzechend",
    "durchzechenden": "durchzechend",
    "durchzechender": "durchzechend",
    "durchzechendes": "durchzechend",
    "durchzechest": "durchzechen",
    "durchzechet": "durchzechen",
    "durchzechst": "durchzechen",
    "durchzecht": "durchzechen",
    "durchzechte": "durchzechen",
    "durchzechtem": "durchzecht",
    "durchzechten": "durchzechen",
    "durchzechter": "durchzecht",
    "durchzechtes": "durchzecht",
    "durchzechtest": "durchzechen",
    "durchzechtet": "durchzechen",
    "durchzeichne": "durchzeichnen",
    "durchzeichnend": "durchzeichnen",
    "durchzeichnende": "durchzeichnend",
    "durchzeichnendem": "durchzeichnend",
    "durchzeichnenden": "durchzeichnend",
    "durchzeichnender": "durchzeichnend",
    "durchzeichnendes": "durchzeichnend",
    "durchzeichnest": "durchzeichnen",
    "durchzeichnet": "durchzeichnen",
    "durchzeichnete": "durchzeichnen",
    "durchzeichneten": "durchzeichnen",
    "durchzeichnetest": "durchzeichnen",
    "durchzeichnetet": "durchzeichnen",
    "durchziehe": "durchziehen",
    "durchziehend": "durchziehen",
    "durchziehende": "durchziehend",
    "durchziehendem": "durchziehend",
    "durchziehenden": "durchziehend",
    "durchziehender": "durchziehend",
    "durchziehendes": "durchziehend",
    "durchziehest": "durchziehen",
    "durchziehet": "durchziehen",
    "durchziehst": "durchziehen",
    "durchzieht": "durchziehen",
    "durchzog": "durchziehen",
    "durchzogen": "durchziehen",
    "durchzogst": "durchziehen",
    "durchzogt": "durchziehen",
    "durchzuarbeiten": "durcharbeiten",
    "durchzuatmen": "durchatmen",
    "durchzubeißen": "durchbeißen",
    "durchzubekommen": "durchbekommen",
    "durchzubetteln": "durchbetteln",
    "durchzubeuteln": "durchbeuteln",
    "durchzubiegen": "durchbiegen",
    "durchzubilden": "durchbilden",
    "durchzublasen": "durchblasen",
    "durchzubleuen": "durchbleuen",
    "durchzublättern": "durchblättern",
    "durchzubläuen": "durchbläuen",
    "durchzubohren": "durchbohren",
    "durchzuboxen": "durchboxen",
    "durchzubraten": "durchbraten",
    "durchzubrausen": "durchbrausen",
    "durchzubrechen": "durchbrechen",
    "durchzubrennen": "durchbrennen",
    "durchzubringen": "durchbringen",
    "durchzubürsten": "durchbürsten",
    "durchzudenken": "durchdenken",
    "durchzudiskutieren": "durchdiskutieren",
    "durchzudrehen": "durchdrehen",
    "durchzudringen": "durchdringen",
    "durchzudrängen": "durchdrängen",
    "durchzudrücken": "durchdrücken",
    "durchzuessen": "durchessen",
    "durchzufahren": "durchfahren",
    "durchzufallen": "durchfallen",
    "durchzufechten": "durchfechten",
    "durchzufedern": "durchfedern",
    "durchzufeiern": "durchfeiern",
    "durchzufeilen": "durchfeilen",
    "durchzufinden": "durchfinden",
    "durchzufliegen": "durchfliegen",
    "durchzufließen": "durchfließen",
    "durchzuflutschen": "durchflutschen",
    "durchzuformen": "durchformen",
    "durchzuforsten": "durchforsten",
    "durchzufragen": "durchfragen",
    "durchzufressen": "durchfressen",
    "durchzufrieren": "durchfrieren",
    "durchzufuttern": "durchfuttern",
    "durchzufühlen": "durchfühlen",
    "durchzuführen": "durchführen",
    "durchzufüttern": "durchfüttern",
    "durchzugeben": "durchgeben",
    "durchzugehen": "durchgehen",
    "durchzugliedern": "durchgliedern",
    "durchzuglühen": "durchglühen",
    "durchzugreifen": "durchgreifen",
    "durchzuhalten": "durchhalten",
    "durchzuhauchen": "durchhauchen",
    "durchzuhauen": "durchhauen",
    "durchzuhecheln": "durchhecheln",
    "durchzuheizen": "durchheizen",
    "durchzuhelfen": "durchhelfen",
    "durchzuholen": "durchholen",
    "durchzuhungern": "durchhungern",
    "durchzuhängen": "durchhängen",
    "durchzuhören": "durchhören",
    "durchzujagen": "durchjagen",
    "durchzukauen": "durchkauen",
    "durchzuklingen": "durchklingen",
    "durchzukneifen": "durchkneifen",
    "durchzukneten": "durchkneten",
    "durchzuknöpfen": "durchknöpfen",
    "durchzukommen": "durchkommen",
    "durchzukomponieren": "durchkomponieren",
    "durchzukosten": "durchkosten",
    "durchzukreuzen": "durchkreuzen",
    "durchzukriechen": "durchkriechen",
    "durchzukriegen": "durchkriegen",
    "durchzukämmen": "durchkämmen",
    "durchzukämpfen": "durchkämpfen",
    "durchzuladen": "durchladen",
    "durchzulangen": "durchlangen",
    "durchzulassen": "durchlassen",
    "durchzulaufen": "durchlaufen",
    "durchzulesen": "durchlesen",
    "durchzuleuchten": "durchleuchten",
    "durchzuliegen": "durchliegen",
    "durchzulüften": "durchlüften",
    "durchzulügen": "durchlügen",
    "durchzumachen": "durchmachen",
    "durchzumarschieren": "durchmarschieren",
    "durchzumessen": "durchmessen",
    "durchzunagen": "durchnagen",
    "durchzunehmen": "durchnehmen",
    "durchzunumerieren": "durchnumerieren",
    "durchzuorganisieren": "durchorganisieren",
    "durchzupauken": "durchpauken",
    "durchzupausen": "durchpausen",
    "durchzupeitschen": "durchpeitschen",
    "durchzuplumpsen": "durchplumpsen",
    "durchzupressen": "durchpressen",
    "durchzuproben": "durchproben",
    "durchzuprobieren": "durchprobieren",
    "durchzuprüfen": "durchprüfen",
    "durchzuprügeln": "durchprügeln",
    "durchzurasen": "durchrasen",
    "durchzurasseln": "durchrasseln",
    "durchzurauschen": "durchrauschen",
    "durchzurechnen": "durchrechnen",
    "durchzuregnen": "durchregnen",
    "durchzureiben": "durchreiben",
    "durchzureichen": "durchreichen",
    "durchzureisen": "durchreisen",
    "durchzureiten": "durchreiten",
    "durchzureißen": "durchreißen",
    "durchzurennen": "durchrennen",
    "durchzurieseln": "durchrieseln",
    "durchzuringen": "durchringen",
    "durchzurosten": "durchrosten",
    "durchzurufen": "durchrufen",
    "durchzurutschen": "durchrutschen",
    "durchzurühren": "durchrühren",
    "durchzurütteln": "durchrütteln",
    "durchzusagen": "durchsagen",
    "durchzusaufen": "durchsaufen",
    "durchzusaugen": "durchsaugen",
    "durchzusausen": "durchsausen",
    "durchzuschaben": "durchschaben",
    "durchzuschallen": "durchschallen",
    "durchzuscheinen": "durchscheinen",
    "durchzuscheuern": "durchscheuern",
    "durchzuschieben": "durchschieben",
    "durchzuschießen": "durchschießen",
    "durchzuschimmern": "durchschimmern",
    "durchzuschlafen": "durchschlafen",
    "durchzuschlagen": "durchschlagen",
    "durchzuschleichen": "durchschleichen",
    "durchzuschleppen": "durchschleppen",
    "durchzuschleusen": "durchschleusen",
    "durchzuschlingen": "durchschlingen",
    "durchzuschlängeln": "durchschlängeln",
    "durchzuschlüpfen": "durchschlüpfen",
    "durchzuschmelzen": "durchschmelzen",
    "durchzuschmuggeln": "durchschmuggeln",
    "durchzuschneiden": "durchschneiden",
    "durchzuschreiben": "durchschreiben",
    "durchzuschwimmen": "durchschwimmen",
    "durchzuschwindeln": "durchschwindeln",
    "durchzuschwitzen": "durchschwitzen",
    "durchzuschütteln": "durchschütteln",
    "durchzusehen": "durchsehen",
    "durchzusetzen": "durchsetzen",
    "durchzusieben": "durchsieben",
    "durchzusingen": "durchsingen",
    "durchzusinken": "durchsinken",
    "durchzusitzen": "durchsitzen",
    "durchzuspielen": "durchspielen",
    "durchzusprechen": "durchsprechen",
    "durchzuspringen": "durchspringen",
    "durchzuspülen": "durchspülen",
    "durchzustarten": "durchstarten",
    "durchzustechen": "durchstechen",
    "durchzustehen": "durchstehen",
    "durchzusteigen": "durchsteigen",
    "durchzustellen": "durchstellen",
    "durchzustimmen": "durchstimmen",
    "durchzustoßen": "durchstoßen",
    "durchzustreichen": "durchstreichen",
    "durchzustrukturieren": "durchstrukturiere",
    "durchzustürmen": "durchstürmen",
    "durchzusuchen": "durchsuchen",
    "durchzusägen": "durchsägen",
    "durchzutanzen": "durchtanzen",
    "durchzutesten": "durchtesten",
    "durchzutreiben": "durchtreiben",
    "durchzutrennen": "durchtrennen",
    "durchzutreten": "durchtreten",
    "durchzuwandern": "durchwandern",
    "durchzuwaschen": "durchwaschen",
    "durchzuweben": "durchweben",
    "durchzuweichen": "durchweichen",
    "durchzuwetzen": "durchwetzen",
    "durchzuwinden": "durchwinden",
    "durchzuwirken": "durchwirken",
    "durchzuwischen": "durchwischen",
    "durchzuwursteln": "durchwursteln",
    "durchzuwählen": "durchwählen",
    "durchzuwärmen": "durchwärmen",
    "durchzuwühlen": "durchwühlen",
    "durchzuzechen": "durchzechen",
    "durchzuzeichnen": "durchzeichnen",
    "durchzuziehen": "durchziehen",
    "durchzuzwängen": "durchzwängen",
    "durchzuzählen": "durchzählen",
    "durchzwänge": "durchzwängen",
    "durchzwängend": "durchzwängen",
    "durchzwängende": "durchzwängend",
    "durchzwängendem": "durchzwängend",
    "durchzwängenden": "durchzwängend",
    "durchzwängender": "durchzwängend",
    "durchzwängendes": "durchzwängend",
    "durchzwängest": "durchzwängen",
    "durchzwänget": "durchzwängen",
    "durchzwängst": "durchzwängen",
    "durchzwängt": "durchzwängen",
    "durchzwängte": "durchzwängen",
    "durchzwängten": "durchzwängen",
    "durchzwängtest": "durchzwängen",
    "durchzwängtet": "durchzwängen",
    "durchzähle": "durchzählen",
    "durchzählend": "durchzählen",
    "durchzählende": "durchzählend",
    "durchzählendem": "durchzählend",
    "durchzählenden": "durchzählend",
    "durchzählender": "durchzählend",
    "durchzählendes": "durchzählend",
    "durchzählest": "durchzählen",
    "durchzählet": "durchzählen",
    "durchzählst": "durchzählen",
    "durchzählt": "durchzählen",
    "durchzählte": "durchzählen",
    "durchzählten": "durchzählen",
    "durchzähltest": "durchzählen",
    "durchzähltet": "durchzählen",
    "durchzöge": "durchziehen",
    "durchzögen": "durchziehen",
    "durchzögest": "durchziehen",
    "durchzöget": "durchziehen",
    "durchäße": "durchessen",
    "durchäßen": "durchessen",
    "durchäßest": "durchessen",
    "durchäßet": "durchessen",
    "durfte": "dürfen",
    "durften": "dürfen",
    "durftest": "dürfen",
    "durftet": "dürfen",
    "durste": "dursten",
    "durstend": "dursten",
    "durstende": "durstend",
    "durstendem": "durstend",
    "durstenden": "durstend",
    "durstender": "durstend",
    "durstendere": "durstend",
    "durstenderem": "durstend",
    "durstenderen": "durstend",
    "durstenderer": "durstend",
    "durstenderes": "durstend",
    "durstendes": "durstend",
    "durstendste": "durstend",
    "durstendstem": "durstend",
    "durstendsten": "durstend",
    "durstendster": "durstend",
    "durstendstes": "durstend",
    "durstest": "dursten",
    "durstet": "dursten",
    "durstete": "dursten",
    "dursteten": "dursten",
    "durstetest": "dursten",
    "durstetet": "dursten",
    "durstige": "durstig",
    "durstigem": "durstig",
    "durstigen": "durstig",
    "durstiger": "durstig",
    "durstigere": "durstig",
    "durstigerem": "durstig",
    "durstigeren": "durstig",
    "durstigerer": "durstig",
    "durstigeres": "durstig",
    "durstiges": "durstig",
    "durstigste": "durstig",
    "durstigstem": "durstig",
    "durstigsten": "durstig",
    "durstigster": "durstig",
    "durstigstes": "durstig",
    "duschend": "duschen",
    "duschende": "duschend",
    "duschendem": "duschend",
    "duschenden": "duschend",
    "duschender": "duschend",
    "duschendes": "duschend",
    "duschest": "duschen",
    "duschet": "duschen",
    "duschst": "duschen",
    "duscht": "duschen",
    "duschte": "duschen",
    "duschten": "duschen",
    "duschtest": "duschen",
    "duschtet": "duschen",
    "dusele": "duseln",
    "duselnd": "duseln",
    "duselnde": "duselnd",
    "duselndem": "duselnd",
    "duselnden": "duselnd",
    "duselnder": "duselnd",
    "duselndere": "duselnd",
    "duselnderem": "duselnd",
    "duselnderen": "duselnd",
    "duselnderer": "duselnd",
    "duselnderes": "duselnd",
    "duselndes": "duselnd",
    "duselndste": "duselnd",
    "duselndstem": "duselnd",
    "duselndsten": "duselnd",
    "duselndster": "duselnd",
    "duselndstes": "duselnd",
    "duselst": "duseln",
    "duselt": "duseln",
    "duselte": "duseln",
    "duselten": "duseln",
    "duseltest": "duseln",
    "duseltet": "duseln",
    "dusle": "duseln",
    "dusseligem": "dusselig",
    "dusseligen": "dusselig",
    "dusseliger": "dusselig",
    "dusseligere": "dusselig",
    "dusseligerem": "dusselig",
    "dusseligeren": "dusselig",
    "dusseligerer": "dusselig",
    "dusseligeres": "dusselig",
    "dusseliges": "dusselig",
    "dusseligste": "dusselig",
    "dusseligstem": "dusselig",
    "dusseligsten": "dusselig",
    "dusseligster": "dusselig",
    "dusseligstes": "dusselig",
    "duze": "duzen",
    "duzend": "duzen",
    "duzende": "duzend",
    "duzendem": "duzend",
    "duzenden": "duzend",
    "duzender": "duzend",
    "duzendes": "duzend",
    "duzest": "duzen",
    "duzet": "duzen",
    "duzt": "duzen",
    "duzte": "duzen",
    "duzten": "duzen",
    "duztest": "duzen",
    "duztet": "duzen",
    "dynamische": "dynamisch",
    "dynamischem": "dynamisch",
    "dynamischen": "dynamisch",
    "dynamischer": "dynamisch",
    "dynamischere": "dynamisch",
    "dynamischerem": "dynamisch",
    "dynamischeren": "dynamisch",
    "dynamischerer": "dynamisch",
    "dynamischeres": "dynamisch",
    "dynamisches": "dynamisch",
    "dynamischste": "dynamisch",
    "dynamischstem": "dynamisch",
    "dynamischsten": "dynamisch",
    "dynamischster": "dynamisch",
    "dynamischstes": "dynamisch",
    "dynamisiere": "dynamisieren",
    "dynamisierend": "dynamisieren",
    "dynamisierende": "dynamisierend",
    "dynamisierendem": "dynamisierend",
    "dynamisierenden": "dynamisierend",
    "dynamisierender": "dynamisierend",
    "dynamisierendes": "dynamisierend",
    "dynamisierest": "dynamisieren",
    "dynamisieret": "dynamisieren",
    "dynamisierst": "dynamisieren",
    "dynamisiert": "dynamisieren",
    "dynamisierte": "dynamisieren",
    "dynamisiertem": "dynamisiert",
    "dynamisierten": "dynamisieren",
    "dynamisierter": "dynamisiert",
    "dynamisiertes": "dynamisiert",
    "dynamisiertest": "dynamisieren",
    "dynamisiertet": "dynamisieren",
    "dynastischem": "dynastisch",
    "dynastischen": "dynastisch",
    "dynastischer": "dynastisch",
    "dynastisches": "dynastisch",
    "dächte": "denken",
    "dächten": "denken",
    "dächtest": "denken",
    "dächtet": "denken",
    "dämliche": "dämlich",
    "dämlichem": "dämlich",
    "dämlichen": "dämlich",
    "dämlicher": "dämlich",
    "dämlichere": "dämlich",
    "dämlicherem": "dämlich",
    "dämlicheren": "dämlich",
    "dämlicherer": "dämlich",
    "dämlicheres": "dämlich",
    "dämliches": "dämlich",
    "dämlichste": "dämlich",
    "dämlichstem": "dämlich",
    "dämlichsten": "dämlich",
    "dämlichster": "dämlich",
    "dämlichstes": "dämlich",
    "dämmend": "dämmen",
    "dämmende": "dämmend",
    "dämmendem": "dämmend",
    "dämmenden": "dämmend",
    "dämmender": "dämmend",
    "dämmendere": "dämmend",
    "dämmenderem": "dämmend",
    "dämmenderen": "dämmend",
    "dämmenderer": "dämmend",
    "dämmenderes": "dämmend",
    "dämmendes": "dämmend",
    "dämmendste": "dämmend",
    "dämmendstem": "dämmend",
    "dämmendsten": "dämmend",
    "dämmendster": "dämmend",
    "dämmendstes": "dämmend",
    "dämmere": "dämmern",
    "dämmerige": "dämmerig",
    "dämmerigem": "dämmerig",
    "dämmerigen": "dämmerig",
    "dämmeriger": "dämmerig",
    "dämmerigere": "dämmerig",
    "dämmerigerem": "dämmerig",
    "dämmerigeren": "dämmerig",
    "dämmerigerer": "dämmerig",
    "dämmerigeres": "dämmerig",
    "dämmeriges": "dämmerig",
    "dämmerigste": "dämmerig",
    "dämmerigstem": "dämmerig",
    "dämmerigsten": "dämmerig",
    "dämmerigster": "dämmerig",
    "dämmerigstes": "dämmerig",
    "dämmernd": "dämmern",
    "dämmernde": "dämmernd",
    "dämmerndem": "dämmernd",
    "dämmernden": "dämmernd",
    "dämmernder": "dämmernd",
    "dämmerndere": "dämmernd",
    "dämmernderem": "dämmernd",
    "dämmernderen": "dämmernd",
    "dämmernderer": "dämmernd",
    "dämmernderes": "dämmernd",
    "dämmerndes": "dämmernd",
    "dämmerndste": "dämmernd",
    "dämmerndstem": "dämmernd",
    "dämmerndsten": "dämmernd",
    "dämmerndster": "dämmernd",
    "dämmerndstes": "dämmernd",
    "dämmerst": "dämmern",
    "dämmert": "dämmern",
    "dämmerte": "dämmern",
    "dämmerten": "dämmern",
    "dämmertest": "dämmern",
    "dämmertet": "dämmern",
    "dämmest": "dämmen",
    "dämmet": "dämmen",
    "dämmrige": "dämmrig",
    "dämmrigem": "dämmrig",
    "dämmrigen": "dämmrig",
    "dämmriger": "dämmrig",
    "dämmrigere": "dämmrig",
    "dämmrigerem": "dämmrig",
    "dämmrigeren": "dämmrig",
    "dämmrigerer": "dämmrig",
    "dämmrigeres": "dämmrig",
    "dämmriges": "dämmrig",
    "dämmrigste": "dämmrig",
    "dämmrigstem": "dämmrig",
    "dämmrigsten": "dämmrig",
    "dämmrigster": "dämmrig",
    "dämmrigstes": "dämmrig",
    "dämmst": "dämmen",
    "dämmt": "dämmen",
    "dämmte": "dämmen",
    "dämmten": "dämmen",
    "dämmtest": "dämmen",
    "dämmtet": "dämmen",
    "dämonenhafte": "dämonenhaft",
    "dämonenhaftem": "dämonenhaft",
    "dämonenhaften": "dämonenhaft",
    "dämonenhafter": "dämonenhaft",
    "dämonenhaftere": "dämonenhaft",
    "dämonenhafterem": "dämonenhaft",
    "dämonenhafteren": "dämonenhaft",
    "dämonenhafterer": "dämonenhaft",
    "dämonenhafteres": "dämonenhaft",
    "dämonenhaftes": "dämonenhaft",
    "dämonenhafteste": "dämonenhaft",
    "dämonenhaftestem": "dämonenhaft",
    "dämonenhaftesten": "dämonenhaft",
    "dämonenhaftester": "dämonenhaft",
    "dämonenhaftestes": "dämonenhaft",
    "dämpfend": "dämpfen",
    "dämpfendem": "dämpfend",
    "dämpfender": "dämpfend",
    "dämpfendes": "dämpfend",
    "dämpfest": "dämpfen",
    "dämpfet": "dämpfen",
    "dämpfst": "dämpfen",
    "dämpft": "dämpfen",
    "dämpfte": "dämpfen",
    "dämpften": "dämpfen",
    "dämpftest": "dämpfen",
    "dämpftet": "dämpfen",
    "dänge": "dingen",
    "dängen": "dingen",
    "dängest": "dingen",
    "dänget": "dingen",
    "dänischem": "dänisch",
    "dänischen": "dänisch",
    "dänischer": "dänisch",
    "dänisches": "dänisch",
    "dörfischem": "dörfisch",
    "dörfischen": "dörfisch",
    "dörfischer": "dörfisch",
    "dörfischere": "dörfisch",
    "dörfischerem": "dörfisch",
    "dörfischeren": "dörfisch",
    "dörfischerer": "dörfisch",
    "dörfischeres": "dörfisch",
    "dörfisches": "dörfisch",
    "dörfischste": "dörfisch",
    "dörfischstem": "dörfisch",
    "dörfischsten": "dörfisch",
    "dörfischster": "dörfisch",
    "dörfischstes": "dörfisch",
    "dörflichem": "dörflich",
    "dörflichen": "dörflich",
    "dörflicher": "dörflich",
    "dörflichere": "dörflich",
    "dörflicherem": "dörflich",
    "dörflicheren": "dörflich",
    "dörflicherer": "dörflich",
    "dörflicheres": "dörflich",
    "dörfliches": "dörflich",
    "dörflichste": "dörflich",
    "dörflichstem": "dörflich",
    "dörflichsten": "dörflich",
    "dörflichster": "dörflich",
    "dörflichstes": "dörflich",
    "dörre": "dörren",
    "dörrend": "dörren",
    "dörrende": "dörrend",
    "dörrendem": "dörrend",
    "dörrenden": "dörrend",
    "dörrender": "dörrend",
    "dörrendes": "dörrend",
    "dörrest": "dörren",
    "dörret": "dörren",
    "dörrst": "dörren",
    "dörrt": "dörren",
    "dörrte": "dörren",
    "dörrten": "dörren",
    "dörrtest": "dörren",
    "dörrtet": "dörren",
    "döse": "dösen",
    "dösend": "dösen",
    "dösendem": "dösend",
    "dösender": "dösend",
    "dösendere": "dösend",
    "dösenderem": "dösend",
    "dösenderen": "dösend",
    "dösenderer": "dösend",
    "dösenderes": "dösend",
    "dösendes": "dösend",
    "dösendste": "dösend",
    "dösendstem": "dösend",
    "dösendsten": "dösend",
    "dösendster": "dösend",
    "dösendstes": "dösend",
    "dösest": "dösen",
    "döset": "dösen",
    "döst": "dösen",
    "döste": "dösen",
    "dösten": "dösen",
    "döstest": "dösen",
    "döstet": "dösen",
    "dübele": "dübeln",
    "dübelnd": "dübeln",
    "dübelnde": "dübelnd",
    "dübelndem": "dübelnd",
    "dübelnden": "dübelnd",
    "dübelnder": "dübelnd",
    "dübelndes": "dübelnd",
    "dübelst": "dübeln",
    "dübelt": "dübeln",
    "dübelte": "dübeln",
    "dübelten": "dübeln",
    "dübeltest": "dübeln",
    "dübeltet": "dübeln",
    "düble": "dübeln",
    "dümmer": "dumm",
    "dümmerem": "dumm",
    "dümmeren": "dumm",
    "dümmerer": "dumm",
    "dümmeres": "dumm",
    "dümmlichem": "dümmlich",
    "dümmlichen": "dümmlich",
    "dümmlicher": "dümmlich",
    "dümmlichere": "dümmlich",
    "dümmlicherem": "dümmlich",
    "dümmlicheren": "dümmlich",
    "dümmlicherer": "dümmlich",
    "dümmlicheres": "dümmlich",
    "dümmliches": "dümmlich",
    "dümmlichste": "dümmlich",
    "dümmlichstem": "dümmlich",
    "dümmlichsten": "dümmlich",
    "dümmlichster": "dümmlich",
    "dümmlichstes": "dümmlich",
    "dümmste": "dumm",
    "dümmstem": "dumm",
    "dümmsten": "dumm",
    "dümmster": "dumm",
    "dümmstes": "dumm",
    "dümpele": "dümpeln",
    "dümpelnd": "dümpeln",
    "dümpelnde": "dümpelnd",
    "dümpelndem": "dümpelnd",
    "dümpelnden": "dümpelnd",
    "dümpelnder": "dümpelnd",
    "dümpelndes": "dümpelnd",
    "dümpelst": "dümpeln",
    "dümpelt": "dümpeln",
    "dümpelte": "dümpeln",
    "dümpelten": "dümpeln",
    "dümpeltest": "dümpeln",
    "dümpeltet": "dümpeln",
    "dümple": "dümpeln",
    "dünge": "düngen",
    "düngend": "düngen",
    "düngende": "düngend",
    "düngendem": "düngend",
    "düngenden": "düngend",
    "düngender": "düngend",
    "düngendes": "düngend",
    "düngest": "düngen",
    "dünget": "düngen",
    "düngst": "düngen",
    "düngt": "düngen",
    "düngte": "düngen",
    "düngten": "düngen",
    "düngtest": "düngen",
    "düngtet": "düngen",
    "dünke": "dünken",
    "dünkend": "dünken",
    "dünkende": "dünkend",
    "dünkendem": "dünkend",
    "dünkenden": "dünkend",
    "dünkender": "dünkend",
    "dünkendes": "dünkend",
    "dünkest": "dünken",
    "dünket": "dünken",
    "dünkst": "dünken",
    "dünkt": "dünken",
    "dünkte": "dünken",
    "dünkten": "dünken",
    "dünktest": "dünken",
    "dünktet": "dünken",
    "dünn": "dünnen",
    "dünne": "dünn",
    "dünnem": "dünn",
    "dünnen": "dünn",
    "dünnend": "dünnen",
    "dünnende": "dünnend",
    "dünnendem": "dünnend",
    "dünnenden": "dünnend",
    "dünnender": "dünnend",
    "dünnendere": "dünnend",
    "dünnenderem": "dünnend",
    "dünnenderen": "dünnend",
    "dünnenderer": "dünnend",
    "dünnenderes": "dünnend",
    "dünnendes": "dünnend",
    "dünnendste": "dünnend",
    "dünnendstem": "dünnend",
    "dünnendsten": "dünnend",
    "dünnendster": "dünnend",
    "dünnendstes": "dünnend",
    "dünner": "dünn",
    "dünnere": "dünn",
    "dünnerem": "dünn",
    "dünneren": "dünn",
    "dünnerer": "dünn",
    "dünneres": "dünn",
    "dünnes": "dünn",
    "dünnest": "dünnen",
    "dünnet": "dünnen",
    "dünnflüssige": "dünnflüssig",
    "dünnflüssigem": "dünnflüssig",
    "dünnflüssigen": "dünnflüssig",
    "dünnflüssiger": "dünnflüssig",
    "dünnflüssigere": "dünnflüssig",
    "dünnflüssigerem": "dünnflüssig",
    "dünnflüssigeren": "dünnflüssig",
    "dünnflüssigerer": "dünnflüssig",
    "dünnflüssigeres": "dünnflüssig",
    "dünnflüssiges": "dünnflüssig",
    "dünnflüssigste": "dünnflüssig",
    "dünnflüssigstem": "dünnflüssig",
    "dünnflüssigsten": "dünnflüssig",
    "dünnflüssigster": "dünnflüssig",
    "dünnflüssigstes": "dünnflüssig",
    "dünnst": "dünnen",
    "dünnste": "dünn",
    "dünnstem": "dünn",
    "dünnsten": "dünn",
    "dünnster": "dünn",
    "dünnstes": "dünn",
    "dünnt": "dünnen",
    "dünnte": "dünnen",
    "dünnten": "dünnen",
    "dünntest": "dünnen",
    "dünntet": "dünnen",
    "dünnwandige": "dünnwandig",
    "dünnwandigem": "dünnwandig",
    "dünnwandigen": "dünnwandig",
    "dünnwandiger": "dünnwandig",
    "dünnwandigere": "dünnwandig",
    "dünnwandigerem": "dünnwandig",
    "dünnwandigeren": "dünnwandig",
    "dünnwandigerer": "dünnwandig",
    "dünnwandigeres": "dünnwandig",
    "dünnwandiges": "dünnwandig",
    "dünnwandigste": "dünnwandig",
    "dünnwandigstem": "dünnwandig",
    "dünnwandigsten": "dünnwandig",
    "dünnwandigster": "dünnwandig",
    "dünnwandigstes": "dünnwandig",
    "dünstend": "dünsten",
    "dünstendem": "dünstend",
    "dünstender": "dünstend",
    "dünstenderem": "dünstend",
    "dünstenderer": "dünstend",
    "dünstenderes": "dünstend",
    "dünstendes": "dünstend",
    "dünstendstem": "dünstend",
    "dünstendster": "dünstend",
    "dünstendstes": "dünstend",
    "dünstest": "dünsten",
    "dünstet": "dünsten",
    "dünstete": "dünsten",
    "dünsteten": "dünsten",
    "dünstetest": "dünsten",
    "dünstetet": "dünsten",
    "düpiere": "düpieren",
    "düpierend": "düpieren",
    "düpierende": "düpierend",
    "düpierendem": "düpierend",
    "düpierenden": "düpierend",
    "düpierender": "düpierend",
    "düpierendes": "düpierend",
    "düpierest": "düpieren",
    "düpieret": "düpieren",
    "düpierst": "düpieren",
    "düpiert": "düpieren",
    "düpierte": "düpieren",
    "düpiertem": "düpiert",
    "düpierten": "düpieren",
    "düpierter": "düpiert",
    "düpiertere": "düpiert",
    "düpierterem": "düpiert",
    "düpierteren": "düpiert",
    "düpierterer": "düpiert",
    "düpierteres": "düpiert",
    "düpiertes": "düpiert",
    "düpiertest": "düpieren",
    "düpierteste": "düpiert",
    "düpiertestem": "düpiert",
    "düpiertesten": "düpiert",
    "düpiertester": "düpiert",
    "düpiertestes": "düpiert",
    "düpiertet": "düpieren",
    "dürfe": "dürfen",
    "dürfest": "dürfen",
    "dürfet": "dürfen",
    "dürft": "dürfen",
    "dürfte": "dürfen",
    "dürften": "dürfen",
    "dürftest": "dürfen",
    "dürftet": "dürfen",
    "dürftige": "dürftig",
    "dürftigem": "dürftig",
    "dürftigen": "dürftig",
    "dürftiger": "dürftig",
    "dürftigere": "dürftig",
    "dürftigerem": "dürftig",
    "dürftigeren": "dürftig",
    "dürftigerer": "dürftig",
    "dürftigeres": "dürftig",
    "dürftiges": "dürftig",
    "dürftigste": "dürftig",
    "dürftigstem": "dürftig",
    "dürftigsten": "dürftig",
    "dürftigster": "dürftig",
    "dürftigstes": "dürftig",
    "dürre": "dürr",
    "dürrem": "dürr",
    "dürren": "dürr",
    "dürrer": "dürr",
    "dürrere": "dürr",
    "dürrerem": "dürr",
    "dürreren": "dürr",
    "dürrerer": "dürr",
    "dürreres": "dürr",
    "dürres": "dürr",
    "dürrste": "dürr",
    "dürrstem": "dürr",
    "dürrsten": "dürr",
    "dürrster": "dürr",
    "dürrstes": "dürr",
    "dürste": "dürsten",
    "dürstend": "dürsten",
    "dürstendem": "dürstend",
    "dürstender": "dürstend",
    "dürstenderem": "dürstend",
    "dürstenderer": "dürstend",
    "dürstenderes": "dürstend",
    "dürstendes": "dürstend",
    "dürstendstem": "dürstend",
    "dürstendster": "dürstend",
    "dürstendstes": "dürstend",
    "dürstest": "dürsten",
    "dürstet": "dürsten",
    "dürstete": "dürsten",
    "dürsteten": "dürsten",
    "dürstetest": "dürsten",
    "dürstetet": "dürsten",
    "düse": "düsen",
    "düsend": "düsen",
    "düsende": "düsend",
    "düsendem": "düsend",
    "düsenden": "düsend",
    "düsender": "düsend",
    "düsendes": "düsend",
    "düsest": "düsen",
    "düset": "düsen",
    "düst": "düsen",
    "düste": "düsen",
    "düsten": "düsen",
    "düstere": "düster",
    "düsterem": "düster",
    "düsteren": "düster",
    "düsterer": "düster",
    "düsterere": "düster",
    "düstererem": "düster",
    "düstereren": "düster",
    "düstererer": "düster",
    "düstereres": "düster",
    "düsteres": "düster",
    "düsterste": "düster",
    "düsterstem": "düster",
    "düstersten": "düster",
    "düsterster": "düster",
    "düsterstes": "düster",
    "düstest": "düsen",
    "düstet": "düsen",
    "ebbend": "ebben",
    "ebbende": "ebbend",
    "ebbendem": "ebbend",
    "ebbenden": "ebbend",
    "ebbender": "ebbend",
    "ebbendes": "ebbend",
    "ebbest": "ebben",
    "ebbet": "ebben",
    "ebbst": "ebben",
    "ebbt": "ebben",
    "ebbte": "ebben",
    "ebbten": "ebben",
    "ebbtest": "ebben",
    "ebbtet": "ebben",
    "ebenbürtigem": "ebenbürtig",
    "ebenbürtigen": "ebenbürtig",
    "ebenbürtiger": "ebenbürtig",
    "ebenbürtigere": "ebenbürtig",
    "ebenbürtigerem": "ebenbürtig",
    "ebenbürtigeren": "ebenbürtig",
    "ebenbürtigerer": "ebenbürtig",
    "ebenbürtigeres": "ebenbürtig",
    "ebenbürtiges": "ebenbürtig",
    "ebenbürtigste": "ebenbürtig",
    "ebenbürtigstem": "ebenbürtig",
    "ebenbürtigsten": "ebenbürtig",
    "ebenbürtigster": "ebenbürtig",
    "ebenbürtigstes": "ebenbürtig",
    "ebene": "eben",
    "ebenem": "eben",
    "ebenen": "eben",
    "ebener": "eben",
    "ebenerdige": "ebenerdig",
    "ebenerdigem": "ebenerdig",
    "ebenerdigen": "ebenerdig",
    "ebenerdiger": "ebenerdig",
    "ebenerdigere": "ebenerdig",
    "ebenerdigerem": "ebenerdig",
    "ebenerdigeren": "ebenerdig",
    "ebenerdigerer": "ebenerdig",
    "ebenerdigeres": "ebenerdig",
    "ebenerdiges": "ebenerdig",
    "ebenerdigste": "ebenerdig",
    "ebenerdigstem": "ebenerdig",
    "ebenerdigsten": "ebenerdig",
    "ebenerdigster": "ebenerdig",
    "ebenerdigstes": "ebenerdig",
    "ebenere": "eben",
    "ebenerem": "eben",
    "ebeneren": "eben",
    "ebenerer": "eben",
    "ebeneres": "eben",
    "ebenes": "eben",
    "ebenstem": "eben",
    "ebensten": "eben",
    "ebenster": "eben",
    "ebenstes": "eben",
    "ebne": "ebnen",
    "ebnend": "ebnen",
    "ebnende": "ebnend",
    "ebnendem": "ebnend",
    "ebnenden": "ebnend",
    "ebnender": "ebnend",
    "ebnendes": "ebnend",
    "ebnest": "ebnen",
    "ebnet": "ebnen",
    "ebnete": "ebnen",
    "ebneten": "ebnen",
    "ebnetest": "ebnen",
    "ebnetet": "ebnen",
    "echtem": "echt",
    "echten": "echt",
    "echter": "echt",
    "echtere": "echt",
    "echterem": "echt",
    "echteren": "echt",
    "echterer": "echt",
    "echteres": "echt",
    "echtes": "echt",
    "echteste": "echt",
    "echtestem": "echt",
    "echtesten": "echt",
    "echtester": "echt",
    "echtestes": "echt",
    "eckigem": "eckig",
    "eckigen": "eckig",
    "eckiger": "eckig",
    "eckigere": "eckig",
    "eckigerem": "eckig",
    "eckigeren": "eckig",
    "eckigerer": "eckig",
    "eckigeres": "eckig",
    "eckiges": "eckig",
    "eckigste": "eckig",
    "eckigstem": "eckig",
    "eckigsten": "eckig",
    "eckigster": "eckig",
    "eckigstes": "eckig",
    "edelmütigem": "edelmütig",
    "edelmütigen": "edelmütig",
    "edelmütiger": "edelmütig",
    "edelmütigere": "edelmütig",
    "edelmütigerem": "edelmütig",
    "edelmütigeren": "edelmütig",
    "edelmütigerer": "edelmütig",
    "edelmütigeres": "edelmütig",
    "edelmütiges": "edelmütig",
    "edelmütigste": "edelmütig",
    "edelmütigstem": "edelmütig",
    "edelmütigsten": "edelmütig",
    "edelmütigster": "edelmütig",
    "edelmütigstes": "edelmütig",
    "edelstem": "edel",
    "edelsten": "edel",
    "edelster": "edel",
    "edelstes": "edel",
    "editorischem": "editorisch",
    "editorischen": "editorisch",
    "editorischer": "editorisch",
    "editorisches": "editorisch",
    "edle": "edel",
    "edlem": "edel",
    "edlen": "edel",
    "edler": "edel",
    "edlere": "edel",
    "edlerem": "edel",
    "edleren": "edel",
    "edlerer": "edel",
    "edleres": "edel",
    "edles": "edel",
    "effektivem": "effektiv",
    "effektiven": "effektiv",
    "effektiver": "effektiv",
    "effektivere": "effektiv",
    "effektiverem": "effektiv",
    "effektiveren": "effektiv",
    "effektiverer": "effektiv",
    "effektiveres": "effektiv",
    "effektives": "effektiv",
    "effektivstem": "effektiv",
    "effektivsten": "effektiv",
    "effektivster": "effektiv",
    "effektivstes": "effektiv",
    "effektvollem": "effektvoll",
    "effektvollen": "effektvoll",
    "effektvoller": "effektvoll",
    "effektvollere": "effektvoll",
    "effektvollerem": "effektvoll",
    "effektvolleren": "effektvoll",
    "effektvollerer": "effektvoll",
    "effektvolleres": "effektvoll",
    "effektvolles": "effektvoll",
    "effektvollste": "effektvoll",
    "effektvollstem": "effektvoll",
    "effektvollsten": "effektvoll",
    "effektvollster": "effektvoll",
    "effektvollstes": "effektvoll",
    "effizientem": "effizient",
    "effizienten": "effizient",
    "effizienter": "effizient",
    "effizientere": "effizient",
    "effizienterem": "effizient",
    "effizienteren": "effizient",
    "effizienterer": "effizient",
    "effizienteres": "effizient",
    "effizientes": "effizient",
    "effizienteste": "effizient",
    "effizientestem": "effizient",
    "effizientesten": "effizient",
    "effizientester": "effizient",
    "effizientestes": "effizient",
    "egalisiere": "egalisieren",
    "egalisierend": "egalisieren",
    "egalisierende": "egalisierend",
    "egalisierendem": "egalisierend",
    "egalisierenden": "egalisierend",
    "egalisierender": "egalisierend",
    "egalisierendes": "egalisierend",
    "egalisierest": "egalisieren",
    "egalisieret": "egalisieren",
    "egalisierst": "egalisieren",
    "egalisiert": "egalisieren",
    "egalisierte": "egalisieren",
    "egalisiertem": "egalisiert",
    "egalisierten": "egalisieren",
    "egalisierter": "egalisiert",
    "egalisiertes": "egalisiert",
    "egalisiertest": "egalisieren",
    "egalisiertet": "egalisieren",
    "ehebrecherischem": "ehebrecherisch",
    "ehebrecherischen": "ehebrecherisch",
    "ehebrecherischer": "ehebrecherisch",
    "ehebrecherisches": "ehebrecherisch",
    "ehefähigem": "ehefähig",
    "ehefähigen": "ehefähig",
    "ehefähiger": "ehefähig",
    "ehefähigere": "ehefähig",
    "ehefähigerem": "ehefähig",
    "ehefähigeren": "ehefähig",
    "ehefähigerer": "ehefähig",
    "ehefähigeres": "ehefähig",
    "ehefähiges": "ehefähig",
    "ehefähigste": "ehefähig",
    "ehefähigstem": "ehefähig",
    "ehefähigsten": "ehefähig",
    "ehefähigster": "ehefähig",
    "ehefähigstes": "ehefähig",
    "eheliche": "ehelichen",
    "ehelichend": "ehelichen",
    "ehelichende": "ehelichend",
    "ehelichendem": "ehelichend",
    "ehelichenden": "ehelichend",
    "ehelichender": "ehelichend",
    "ehelichendes": "ehelichend",
    "ehelichest": "ehelichen",
    "ehelichet": "ehelichen",
    "ehelichst": "ehelichen",
    "ehelicht": "ehelichen",
    "ehelichte": "ehelichen",
    "ehelichten": "ehelichen",
    "ehelichtest": "ehelichen",
    "ehelichtet": "ehelichen",
    "ehelose": "ehelos",
    "ehelosem": "ehelos",
    "ehelosen": "ehelos",
    "eheloser": "ehelos",
    "eheloses": "ehelos",
    "ehemalige": "ehemalig",
    "ehemaligem": "ehemalig",
    "ehemaligen": "ehemalig",
    "ehemaliger": "ehemalig",
    "ehemaliges": "ehemalig",
    "ehescheuem": "ehescheu",
    "ehescheuen": "ehescheu",
    "ehescheuer": "ehescheu",
    "ehescheuere": "ehescheu",
    "ehescheuerem": "ehescheu",
    "ehescheueren": "ehescheu",
    "ehescheuerer": "ehescheu",
    "ehescheueres": "ehescheu",
    "ehescheues": "ehescheu",
    "ehescheuste": "ehescheu",
    "ehescheustem": "ehescheu",
    "ehescheusten": "ehescheu",
    "ehescheuster": "ehescheu",
    "ehescheustes": "ehescheu",
    "ehrbarem": "ehrbar",
    "ehrbaren": "ehrbar",
    "ehrbarer": "ehrbar",
    "ehrbarere": "ehrbar",
    "ehrbarerem": "ehrbar",
    "ehrbareren": "ehrbar",
    "ehrbarerer": "ehrbar",
    "ehrbareres": "ehrbar",
    "ehrbares": "ehrbar",
    "ehrbarste": "ehrbar",
    "ehrbarstem": "ehrbar",
    "ehrbarsten": "ehrbar",
    "ehrbarster": "ehrbar",
    "ehrbarstes": "ehrbar",
    "ehre": "ehren",
    "ehrenamtlichem": "ehrenamtlich",
    "ehrenamtlichen": "ehrenamtlich",
    "ehrenamtlicher": "ehrenamtlich",
    "ehrenamtliches": "ehrenamtlich",
    "ehrend": "ehren",
    "ehrende": "ehrend",
    "ehrendem": "ehrend",
    "ehrenden": "ehrend",
    "ehrender": "ehrend",
    "ehrendes": "ehrend",
    "ehrenhafte": "ehrenhaft",
    "ehrenhaftem": "ehrenhaft",
    "ehrenhaften": "ehrenhaft",
    "ehrenhafter": "ehrenhaft",
    "ehrenhaftere": "ehrenhaft",
    "ehrenhafterem": "ehrenhaft",
    "ehrenhafteren": "ehrenhaft",
    "ehrenhafterer": "ehrenhaft",
    "ehrenhafteres": "ehrenhaft",
    "ehrenhaftes": "ehrenhaft",
    "ehrenhafteste": "ehrenhaft",
    "ehrenhaftestem": "ehrenhaft",
    "ehrenhaftesten": "ehrenhaft",
    "ehrenhaftester": "ehrenhaft",
    "ehrenhaftestes": "ehrenhaft",
    "ehrenvollem": "ehrenvoll",
    "ehrenvollen": "ehrenvoll",
    "ehrenvoller": "ehrenvoll",
    "ehrenvollere": "ehrenvoll",
    "ehrenvollerem": "ehrenvoll",
    "ehrenvolleren": "ehrenvoll",
    "ehrenvollerer": "ehrenvoll",
    "ehrenvolleres": "ehrenvoll",
    "ehrenvolles": "ehrenvoll",
    "ehrenvollste": "ehrenvoll",
    "ehrenvollstem": "ehrenvoll",
    "ehrenvollsten": "ehrenvoll",
    "ehrenvollster": "ehrenvoll",
    "ehrenvollstes": "ehrenvoll",
    "ehrenwertem": "ehrenwert",
    "ehrenwerten": "ehrenwert",
    "ehrenwerter": "ehrenwert",
    "ehrenwertere": "ehrenwert",
    "ehrenwerterem": "ehrenwert",
    "ehrenwerteren": "ehrenwert",
    "ehrenwerterer": "ehrenwert",
    "ehrenwerteres": "ehrenwert",
    "ehrenwertes": "ehrenwert",
    "ehrenwerteste": "ehrenwert",
    "ehrenwertestem": "ehrenwert",
    "ehrenwertesten": "ehrenwert",
    "ehrenwertester": "ehrenwert",
    "ehrenwertestes": "ehrenwert",
    "ehrerbietige": "ehrerbietig",
    "ehrerbietigem": "ehrerbietig",
    "ehrerbietigen": "ehrerbietig",
    "ehrerbietiger": "ehrerbietig",
    "ehrerbietigere": "ehrerbietig",
    "ehrerbietigerem": "ehrerbietig",
    "ehrerbietigeren": "ehrerbietig",
    "ehrerbietigerer": "ehrerbietig",
    "ehrerbietigeres": "ehrerbietig",
    "ehrerbietiges": "ehrerbietig",
    "ehrerbietigste": "ehrerbietig",
    "ehrerbietigstem": "ehrerbietig",
    "ehrerbietigsten": "ehrerbietig",
    "ehrerbietigster": "ehrerbietig",
    "ehrerbietigstes": "ehrerbietig",
    "ehrest": "ehren",
    "ehret": "ehren",
    "ehrfürchtige": "ehrfürchtig",
    "ehrfürchtigem": "ehrfürchtig",
    "ehrfürchtigen": "ehrfürchtig",
    "ehrfürchtiger": "ehrfürchtig",
    "ehrfürchtigere": "ehrfürchtig",
    "ehrfürchtigerem": "ehrfürchtig",
    "ehrfürchtigeren": "ehrfürchtig",
    "ehrfürchtigerer": "ehrfürchtig",
    "ehrfürchtigeres": "ehrfürchtig",
    "ehrfürchtiges": "ehrfürchtig",
    "ehrfürchtigste": "ehrfürchtig",
    "ehrfürchtigstem": "ehrfürchtig",
    "ehrfürchtigsten": "ehrfürchtig",
    "ehrfürchtigster": "ehrfürchtig",
    "ehrfürchtigstes": "ehrfürchtig",
    "ehrgeizigem": "ehrgeizig",
    "ehrgeizigen": "ehrgeizig",
    "ehrgeiziger": "ehrgeizig",
    "ehrgeizigere": "ehrgeizig",
    "ehrgeizigerem": "ehrgeizig",
    "ehrgeizigeren": "ehrgeizig",
    "ehrgeizigerer": "ehrgeizig",
    "ehrgeizigeres": "ehrgeizig",
    "ehrgeiziges": "ehrgeizig",
    "ehrgeizigste": "ehrgeizig",
    "ehrgeizigstem": "ehrgeizig",
    "ehrgeizigsten": "ehrgeizig",
    "ehrgeizigster": "ehrgeizig",
    "ehrgeizigstes": "ehrgeizig",
    "ehrliche": "ehrlich",
    "ehrlichem": "ehrlich",
    "ehrlichen": "ehrlich",
    "ehrlicher": "ehrlich",
    "ehrlichere": "ehrlich",
    "ehrlicherem": "ehrlich",
    "ehrlicheren": "ehrlich",
    "ehrlicherer": "ehrlich",
    "ehrlicheres": "ehrlich",
    "ehrliches": "ehrlich",
    "ehrlichste": "ehrlich",
    "ehrlichstem": "ehrlich",
    "ehrlichsten": "ehrlich",
    "ehrlichster": "ehrlich",
    "ehrlichstes": "ehrlich",
    "ehrliebende": "ehrliebend",
    "ehrliebendem": "ehrliebend",
    "ehrliebenden": "ehrliebend",
    "ehrliebender": "ehrliebend",
    "ehrliebendere": "ehrliebend",
    "ehrliebenderem": "ehrliebend",
    "ehrliebenderen": "ehrliebend",
    "ehrliebenderer": "ehrliebend",
    "ehrliebenderes": "ehrliebend",
    "ehrliebendes": "ehrliebend",
    "ehrliebendste": "ehrliebend",
    "ehrliebendstem": "ehrliebend",
    "ehrliebendsten": "ehrliebend",
    "ehrliebendster": "ehrliebend",
    "ehrliebendstes": "ehrliebend",
    "ehrlose": "ehrlos",
    "ehrlosem": "ehrlos",
    "ehrlosen": "ehrlos",
    "ehrloser": "ehrlos",
    "ehrlosere": "ehrlos",
    "ehrloserem": "ehrlos",
    "ehrloseren": "ehrlos",
    "ehrloserer": "ehrlos",
    "ehrloseres": "ehrlos",
    "ehrloses": "ehrlos",
    "ehrloseste": "ehrlos",
    "ehrlosestem": "ehrlos",
    "ehrlosesten": "ehrlos",
    "ehrlosester": "ehrlos",
    "ehrlosestes": "ehrlos",
    "ehrst": "ehren",
    "ehrt": "ehren",
    "ehrte": "ehren",
    "ehrten": "ehren",
    "ehrtest": "ehren",
    "ehrtet": "ehren",
    "ehrwürdigem": "ehrwürdig",
    "ehrwürdigen": "ehrwürdig",
    "ehrwürdiger": "ehrwürdig",
    "ehrwürdigere": "ehrwürdig",
    "ehrwürdigerem": "ehrwürdig",
    "ehrwürdigeren": "ehrwürdig",
    "ehrwürdigerer": "ehrwürdig",
    "ehrwürdigeres": "ehrwürdig",
    "ehrwürdiges": "ehrwürdig",
    "ehrwürdigste": "ehrwürdig",
    "ehrwürdigstem": "ehrwürdig",
    "ehrwürdigsten": "ehrwürdig",
    "ehrwürdigster": "ehrwürdig",
    "ehrwürdigstes": "ehrwürdig",
    "eichend": "eichen",
    "eichende": "eichend",
    "eichendem": "eichend",
    "eichenden": "eichend",
    "eichender": "eichend",
    "eichendere": "eichend",
    "eichenderem": "eichend",
    "eichenderen": "eichend",
    "eichenderer": "eichend",
    "eichenderes": "eichend",
    "eichendes": "eichend",
    "eichendste": "eichend",
    "eichendstem": "eichend",
    "eichendsten": "eichend",
    "eichendster": "eichend",
    "eichendstes": "eichend",
    "eichest": "eichen",
    "eichet": "eichen",
    "eichst": "eichen",
    "eicht": "eichen",
    "eichte": "eichen",
    "eichten": "eichen",
    "eichtest": "eichen",
    "eichtet": "eichen",
    "eidbrüchigem": "eidbrüchig",
    "eidbrüchigen": "eidbrüchig",
    "eidbrüchiger": "eidbrüchig",
    "eidbrüchigere": "eidbrüchig",
    "eidbrüchigerem": "eidbrüchig",
    "eidbrüchigeren": "eidbrüchig",
    "eidbrüchigerer": "eidbrüchig",
    "eidbrüchigeres": "eidbrüchig",
    "eidbrüchiges": "eidbrüchig",
    "eidbrüchigste": "eidbrüchig",
    "eidbrüchigstem": "eidbrüchig",
    "eidbrüchigsten": "eidbrüchig",
    "eidbrüchigster": "eidbrüchig",
    "eidbrüchigstes": "eidbrüchig",
    "eidespflichtigem": "eidespflichtig",
    "eidespflichtigen": "eidespflichtig",
    "eidespflichtiger": "eidespflichtig",
    "eidespflichtigere": "eidespflichtig",
    "eidespflichtigerem": "eidespflichtig",
    "eidespflichtigeren": "eidespflichtig",
    "eidespflichtigerer": "eidespflichtig",
    "eidespflichtigeres": "eidespflichtig",
    "eidespflichtiges": "eidespflichtig",
    "eidespflichtigste": "eidespflichtig",
    "eidespflichtigstem": "eidespflichtig",
    "eidespflichtigsten": "eidespflichtig",
    "eidespflichtigster": "eidespflichtig",
    "eidespflichtigstes": "eidespflichtig",
    "eidesstattliche": "eidesstattlich",
    "eidesstattlichem": "eidesstattlich",
    "eidesstattlichen": "eidesstattlich",
    "eidesstattlicher": "eidesstattlich",
    "eidesstattliches": "eidesstattlich",
    "eidgenössischem": "eidgenössisch",
    "eidgenössischen": "eidgenössisch",
    "eidgenössischer": "eidgenössisch",
    "eidgenössisches": "eidgenössisch",
    "eiere": "eiern",
    "eiernd": "eiern",
    "eiernde": "eiernd",
    "eierndem": "eiernd",
    "eiernden": "eiernd",
    "eiernder": "eiernd",
    "eierndere": "eiernd",
    "eiernderem": "eiernd",
    "eiernderen": "eiernd",
    "eiernderer": "eiernd",
    "eiernderes": "eiernd",
    "eierndes": "eiernd",
    "eierndste": "eiernd",
    "eierndstem": "eiernd",
    "eierndsten": "eiernd",
    "eierndster": "eiernd",
    "eierndstes": "eiernd",
    "eierst": "eiern",
    "eiert": "eiern",
    "eierte": "eiern",
    "eierten": "eiern",
    "eiertest": "eiern",
    "eiertet": "eiern",
    "eifere": "eifern",
    "eifernd": "eifern",
    "eifernde": "eifernd",
    "eiferndem": "eifernd",
    "eifernden": "eifernd",
    "eifernder": "eifernd",
    "eiferndere": "eifernd",
    "eifernderem": "eifernd",
    "eifernderen": "eifernd",
    "eifernderer": "eifernd",
    "eifernderes": "eifernd",
    "eiferndes": "eifernd",
    "eiferndste": "eifernd",
    "eiferndstem": "eifernd",
    "eiferndsten": "eifernd",
    "eiferndster": "eifernd",
    "eiferndstes": "eifernd",
    "eiferst": "eifern",
    "eifersüchtige": "eifersüchtig",
    "eifersüchtigem": "eifersüchtig",
    "eifersüchtigen": "eifersüchtig",
    "eifersüchtiger": "eifersüchtig",
    "eifersüchtigere": "eifersüchtig",
    "eifersüchtigerem": "eifersüchtig",
    "eifersüchtigeren": "eifersüchtig",
    "eifersüchtigerer": "eifersüchtig",
    "eifersüchtigeres": "eifersüchtig",
    "eifersüchtiges": "eifersüchtig",
    "eifersüchtigste": "eifersüchtig",
    "eifersüchtigstem": "eifersüchtig",
    "eifersüchtigsten": "eifersüchtig",
    "eifersüchtigster": "eifersüchtig",
    "eifersüchtigstes": "eifersüchtig",
    "eifert": "eifern",
    "eiferte": "eifern",
    "eiferten": "eifern",
    "eifertest": "eifern",
    "eifertet": "eifern",
    "eifrige": "eifrig",
    "eifrigem": "eifrig",
    "eifrigen": "eifrig",
    "eifriger": "eifrig",
    "eifrigere": "eifrig",
    "eifrigerem": "eifrig",
    "eifrigeren": "eifrig",
    "eifrigerer": "eifrig",
    "eifrigeres": "eifrig",
    "eifriges": "eifrig",
    "eifrigste": "eifrig",
    "eifrigstem": "eifrig",
    "eifrigsten": "eifrig",
    "eifrigster": "eifrig",
    "eifrigstes": "eifrig",
    "eiförmige": "eiförmig",
    "eiförmigem": "eiförmig",
    "eiförmigen": "eiförmig",
    "eiförmiger": "eiförmig",
    "eiförmigere": "eiförmig",
    "eiförmigerem": "eiförmig",
    "eiförmigeren": "eiförmig",
    "eiförmigerer": "eiförmig",
    "eiförmigeres": "eiförmig",
    "eiförmiges": "eiförmig",
    "eiförmigste": "eiförmig",
    "eiförmigstem": "eiförmig",
    "eiförmigsten": "eiförmig",
    "eiförmigster": "eiförmig",
    "eiförmigstes": "eiförmig",
    "eigenartige": "eigenartig",
    "eigenartigem": "eigenartig",
    "eigenartigen": "eigenartig",
    "eigenartiger": "eigenartig",
    "eigenartigere": "eigenartig",
    "eigenartigerem": "eigenartig",
    "eigenartigeren": "eigenartig",
    "eigenartigerer": "eigenartig",
    "eigenartigeres": "eigenartig",
    "eigenartiges": "eigenartig",
    "eigenartigste": "eigenartig",
    "eigenartigstem": "eigenartig",
    "eigenartigsten": "eigenartig",
    "eigenartigster": "eigenartig",
    "eigenartigstes": "eigenartig",
    "eigenbrötlerischem": "eigenbrötlerisch",
    "eigenbrötlerischen": "eigenbrötlerisch",
    "eigenbrötlerischer": "eigenbrötlerisch",
    "eigenbrötlerischere": "eigenbrötlerisch",
    "eigenbrötlerischerem": "eigenbrötlerisch",
    "eigenbrötlerischeren": "eigenbrötlerisch",
    "eigenbrötlerischerer": "eigenbrötlerisch",
    "eigenbrötlerischeres": "eigenbrötlerisch",
    "eigenbrötlerisches": "eigenbrötlerisch",
    "eigenbrötlerischste": "eigenbrötlerisch",
    "eigenbrötlerischstem": "eigenbrötlerisch",
    "eigenbrötlerischsten": "eigenbrötlerisch",
    "eigenbrötlerischster": "eigenbrötlerisch",
    "eigenbrötlerischstes": "eigenbrötlerisch",
    "eigenem": "eigen",
    "eigenen": "eigen",
    "eigener": "eigen",
    "eigenere": "eigen",
    "eigenerem": "eigen",
    "eigeneren": "eigen",
    "eigenerer": "eigen",
    "eigeneres": "eigen",
    "eigenes": "eigen",
    "eigenhändigem": "eigenhändig",
    "eigenhändigen": "eigenhändig",
    "eigenhändiger": "eigenhändig",
    "eigenhändiges": "eigenhändig",
    "eigenmächtigem": "eigenmächtig",
    "eigenmächtigen": "eigenmächtig",
    "eigenmächtiger": "eigenmächtig",
    "eigenmächtigere": "eigenmächtig",
    "eigenmächtigerem": "eigenmächtig",
    "eigenmächtigeren": "eigenmächtig",
    "eigenmächtigerer": "eigenmächtig",
    "eigenmächtigeres": "eigenmächtig",
    "eigenmächtiges": "eigenmächtig",
    "eigenmächtigstem": "eigenmächtig",
    "eigenmächtigsten": "eigenmächtig",
    "eigenmächtigster": "eigenmächtig",
    "eigenmächtigstes": "eigenmächtig",
    "eigennützigem": "eigennützig",
    "eigennützigen": "eigennützig",
    "eigennütziger": "eigennützig",
    "eigennützigere": "eigennützig",
    "eigennützigerem": "eigennützig",
    "eigennützigeren": "eigennützig",
    "eigennützigerer": "eigennützig",
    "eigennützigeres": "eigennützig",
    "eigennütziges": "eigennützig",
    "eigennützigste": "eigennützig",
    "eigennützigstem": "eigennützig",
    "eigennützigsten": "eigennützig",
    "eigennützigster": "eigennützig",
    "eigennützigstes": "eigennützig",
    "eigensinnigem": "eigensinnig",
    "eigensinnigen": "eigensinnig",
    "eigensinniger": "eigensinnig",
    "eigensinnigere": "eigensinnig",
    "eigensinnigerem": "eigensinnig",
    "eigensinnigeren": "eigensinnig",
    "eigensinnigerer": "eigensinnig",
    "eigensinnigeres": "eigensinnig",
    "eigensinniges": "eigensinnig",
    "eigensinnigste": "eigensinnig",
    "eigensinnigstem": "eigensinnig",
    "eigensinnigsten": "eigensinnig",
    "eigensinnigster": "eigensinnig",
    "eigensinnigstes": "eigensinnig",
    "eigenste": "eigen",
    "eigenstem": "eigen",
    "eigensten": "eigen",
    "eigenster": "eigen",
    "eigenstes": "eigen",
    "eigenständigem": "eigenständig",
    "eigenständigen": "eigenständig",
    "eigenständiger": "eigenständig",
    "eigenständigere": "eigenständig",
    "eigenständigerem": "eigenständig",
    "eigenständigeren": "eigenständig",
    "eigenständigerer": "eigenständig",
    "eigenständigeres": "eigenständig",
    "eigenständiges": "eigenständig",
    "eigenständigste": "eigenständig",
    "eigenständigstem": "eigenständig",
    "eigenständigsten": "eigenständig",
    "eigenständigster": "eigenständig",
    "eigenständigstes": "eigenständig",
    "eigentliche": "eigentlich",
    "eigentlichem": "eigentlich",
    "eigentlichen": "eigentlich",
    "eigentlicher": "eigentlich",
    "eigentliches": "eigentlich",
    "eigentümlichem": "eigentümlich",
    "eigentümlichen": "eigentümlich",
    "eigentümlicher": "eigentümlich",
    "eigentümlichere": "eigentümlich",
    "eigentümlicherem": "eigentümlich",
    "eigentümlicheren": "eigentümlich",
    "eigentümlicherer": "eigentümlich",
    "eigentümlicheres": "eigentümlich",
    "eigentümliches": "eigentümlich",
    "eigentümlichste": "eigentümlich",
    "eigentümlichstem": "eigentümlich",
    "eigentümlichsten": "eigentümlich",
    "eigentümlichster": "eigentümlich",
    "eigentümlichstes": "eigentümlich",
    "eigenverantwortlichem": "eigenverantwortlich",
    "eigenverantwortlichen": "eigenverantwortlich",
    "eigenverantwortlicher": "eigenverantwortlich",
    "eigenverantwortlichere": "eigenverantwortlich",
    "eigenverantwortlicherem": "eigenverantwortlich",
    "eigenverantwortlicheren": "eigenverantwortlich",
    "eigenverantwortlicherer": "eigenverantwortlich",
    "eigenverantwortlicheres": "eigenverantwortlich",
    "eigenverantwortliches": "eigenverantwortlich",
    "eigenverantwortlichste": "eigenverantwortlich",
    "eigenverantwortlichstem": "eigenverantwortlich",
    "eigenverantwortlichsten": "eigenverantwortlich",
    "eigenverantwortlichster": "eigenverantwortlich",
    "eigenverantwortlichstes": "eigenverantwortlich",
    "eigenwilligem": "eigenwillig",
    "eigenwilligen": "eigenwillig",
    "eigenwilliger": "eigenwillig",
    "eigenwilligere": "eigenwillig",
    "eigenwilligerem": "eigenwillig",
    "eigenwilligeren": "eigenwillig",
    "eigenwilligerer": "eigenwillig",
    "eigenwilligeres": "eigenwillig",
    "eigenwilliges": "eigenwillig",
    "eigenwilligstem": "eigenwillig",
    "eigenwilligsten": "eigenwillig",
    "eigenwilligster": "eigenwillig",
    "eigenwilligstes": "eigenwillig",
    "eigne": "eignen",
    "eignend": "eignen",
    "eignende": "eignend",
    "eignendem": "eignend",
    "eignenden": "eignend",
    "eignender": "eignend",
    "eignendes": "eignend",
    "eignest": "eignen",
    "eignet": "eignen",
    "eignete": "eignen",
    "eigneten": "eignen",
    "eignetest": "eignen",
    "eignetet": "eignen",
    "eilend": "eilen",
    "eilende": "eilend",
    "eilendem": "eilend",
    "eilenden": "eilend",
    "eilender": "eilend",
    "eilendere": "eilend",
    "eilenderem": "eilend",
    "eilenderen": "eilend",
    "eilenderer": "eilend",
    "eilenderes": "eilend",
    "eilendes": "eilend",
    "eilendste": "eilend",
    "eilendstem": "eilend",
    "eilendsten": "eilend",
    "eilendster": "eilend",
    "eilendstes": "eilend",
    "eilest": "eilen",
    "eilet": "eilen",
    "eilige": "eilig",
    "eiligem": "eilig",
    "eiligen": "eilig",
    "eiliger": "eilig",
    "eiligere": "eilig",
    "eiligerem": "eilig",
    "eiligeren": "eilig",
    "eiligerer": "eilig",
    "eiligeres": "eilig",
    "eiliges": "eilig",
    "eiligste": "eilig",
    "eiligstem": "eilig",
    "eiligsten": "eilig",
    "eiligster": "eilig",
    "eiligstes": "eilig",
    "eilst": "eilen",
    "eilt": "eilen",
    "eilte": "eilen",
    "eilten": "eilen",
    "eiltest": "eilen",
    "eiltet": "eilen",
    "ein": "einen",
    "einarbeite": "einarbeiten",
    "einarbeitend": "einarbeiten",
    "einarbeitende": "einarbeitend",
    "einarbeitendem": "einarbeitend",
    "einarbeitenden": "einarbeitend",
    "einarbeitender": "einarbeitend",
    "einarbeitendes": "einarbeitend",
    "einarbeitest": "einarbeiten",
    "einarbeitet": "einarbeiten",
    "einarbeitete": "einarbeiten",
    "einarbeiteten": "einarbeiten",
    "einarbeitetest": "einarbeiten",
    "einarbeitetet": "einarbeiten",
    "einarmige": "einarmig",
    "einarmigem": "einarmig",
    "einarmigen": "einarmig",
    "einarmiger": "einarmig",
    "einarmiges": "einarmig",
    "einatme": "einatmen",
    "einatmend": "einatmen",
    "einatmende": "einatmend",
    "einatmendem": "einatmend",
    "einatmenden": "einatmend",
    "einatmender": "einatmend",
    "einatmendes": "einatmend",
    "einatmest": "einatmen",
    "einatmet": "einatmen",
    "einatmete": "einatmen",
    "einatmeten": "einatmen",
    "einatmetest": "einatmen",
    "einatmetet": "einatmen",
    "einbalsamiere": "einbalsamieren",
    "einbalsamierend": "einbalsamieren",
    "einbalsamierende": "einbalsamierend",
    "einbalsamierendem": "einbalsamierend",
    "einbalsamierenden": "einbalsamierend",
    "einbalsamierender": "einbalsamierend",
    "einbalsamierendes": "einbalsamierend",
    "einbalsamierest": "einbalsamieren",
    "einbalsamieret": "einbalsamieren",
    "einbalsamierst": "einbalsamieren",
    "einbalsamiert": "einbalsamieren",
    "einbalsamierte": "einbalsamieren",
    "einbalsamiertem": "einbalsamiert",
    "einbalsamierten": "einbalsamieren",
    "einbalsamierter": "einbalsamiert",
    "einbalsamiertes": "einbalsamiert",
    "einbalsamiertest": "einbalsamieren",
    "einbalsamiertet": "einbalsamieren",
    "einband": "einbinden",
    "einbanden": "einbinden",
    "einbandest": "einbinden",
    "einbandet": "einbinden",
    "einbaue": "einbauen",
    "einbauend": "einbauen",
    "einbauende": "einbauend",
    "einbauendem": "einbauend",
    "einbauenden": "einbauend",
    "einbauender": "einbauend",
    "einbauendes": "einbauend",
    "einbauest": "einbauen",
    "einbauet": "einbauen",
    "einbaust": "einbauen",
    "einbaut": "einbauen",
    "einbaute": "einbauen",
    "einbauten": "einbauen",
    "einbautest": "einbauen",
    "einbautet": "einbauen",
    "einbehalte": "einbehalten",
    "einbehaltend": "einbehalten",
    "einbehaltende": "einbehaltend",
    "einbehaltendem": "einbehaltend",
    "einbehaltenden": "einbehaltend",
    "einbehaltender": "einbehaltend",
    "einbehaltendes": "einbehaltend",
    "einbehaltene": "einbehalten",
    "einbehaltenem": "einbehalten",
    "einbehaltenen": "einbehalten",
    "einbehaltener": "einbehalten",
    "einbehaltenes": "einbehalten",
    "einbehaltest": "einbehalten",
    "einbehaltet": "einbehalten",
    "einbehielt": "einbehalten",
    "einbehielte": "einbehalten",
    "einbehielten": "einbehalten",
    "einbehieltest": "einbehalten",
    "einbehieltet": "einbehalten",
    "einbehält": "einbehalten",
    "einbehältst": "einbehalten",
    "einbeinige": "einbeinig",
    "einbeinigem": "einbeinig",
    "einbeinigen": "einbeinig",
    "einbeiniger": "einbeinig",
    "einbeiniges": "einbeinig",
    "einbekannt": "einbekennen",
    "einbekannte": "einbekannt",
    "einbekanntem": "einbekannt",
    "einbekannten": "einbekannt",
    "einbekannter": "einbekannt",
    "einbekanntes": "einbekannt",
    "einbekanntest": "einbekennen",
    "einbekanntet": "einbekennen",
    "einbekenne": "einbekennen",
    "einbekennend": "einbekennen",
    "einbekennende": "einbekennend",
    "einbekennendem": "einbekennend",
    "einbekennenden": "einbekennend",
    "einbekennender": "einbekennend",
    "einbekennendes": "einbekennend",
    "einbekennest": "einbekennen",
    "einbekennet": "einbekennen",
    "einbekennst": "einbekennen",
    "einbekennt": "einbekennen",
    "einberief": "einberufen",
    "einberiefe": "einberufen",
    "einberiefen": "einberufen",
    "einberiefest": "einberufen",
    "einberiefet": "einberufen",
    "einberiefst": "einberufen",
    "einberieft": "einberufen",
    "einberufe": "einberufen",
    "einberufend": "einberufen",
    "einberufende": "einberufend",
    "einberufendem": "einberufend",
    "einberufenden": "einberufend",
    "einberufender": "einberufend",
    "einberufendes": "einberufend",
    "einberufene": "einberufen",
    "einberufenem": "einberufen",
    "einberufenen": "einberufen",
    "einberufener": "einberufen",
    "einberufenes": "einberufen",
    "einberufest": "einberufen",
    "einberufet": "einberufen",
    "einberufst": "einberufen",
    "einberuft": "einberufen",
    "einbestelle": "einbestellen",
    "einbestellend": "einbestellen",
    "einbestellende": "einbestellend",
    "einbestellendem": "einbestellend",
    "einbestellenden": "einbestellend",
    "einbestellender": "einbestellend",
    "einbestellendes": "einbestellend",
    "einbestellest": "einbestellen",
    "einbestellet": "einbestellen",
    "einbestellst": "einbestellen",
    "einbestellt": "einbestellen",
    "einbestellte": "einbestellen",
    "einbestelltem": "einbestellt",
    "einbestellten": "einbestellen",
    "einbestellter": "einbestellt",
    "einbestelltes": "einbestellt",
    "einbestelltest": "einbestellen",
    "einbestelltet": "einbestellen",
    "einbetoniere": "einbetonieren",
    "einbetonierend": "einbetonieren",
    "einbetonierende": "einbetonierend",
    "einbetonierendem": "einbetonierend",
    "einbetonierenden": "einbetonierend",
    "einbetonierender": "einbetonierend",
    "einbetonierendes": "einbetonierend",
    "einbetonierest": "einbetonieren",
    "einbetonieret": "einbetonieren",
    "einbetonierst": "einbetonieren",
    "einbetoniert": "einbetonieren",
    "einbetonierte": "einbetonieren",
    "einbetoniertem": "einbetoniert",
    "einbetonierten": "einbetonieren",
    "einbetonierter": "einbetoniert",
    "einbetoniertes": "einbetoniert",
    "einbetoniertest": "einbetonieren",
    "einbetoniertet": "einbetonieren",
    "einbette": "einbetten",
    "einbettend": "einbetten",
    "einbettende": "einbettend",
    "einbettendem": "einbettend",
    "einbettenden": "einbettend",
    "einbettender": "einbettend",
    "einbettendes": "einbettend",
    "einbettest": "einbetten",
    "einbettet": "einbetten",
    "einbettete": "einbetten",
    "einbetteten": "einbetten",
    "einbettetest": "einbetten",
    "einbettetet": "einbetten",
    "einbeziehe": "einbeziehen",
    "einbeziehend": "einbeziehen",
    "einbeziehende": "einbeziehend",
    "einbeziehendem": "einbeziehend",
    "einbeziehenden": "einbeziehend",
    "einbeziehender": "einbeziehend",
    "einbeziehendere": "einbeziehend",
    "einbeziehenderem": "einbeziehend",
    "einbeziehenderen": "einbeziehend",
    "einbeziehenderer": "einbeziehend",
    "einbeziehenderes": "einbeziehend",
    "einbeziehendes": "einbeziehend",
    "einbeziehendste": "einbeziehend",
    "einbeziehendstem": "einbeziehend",
    "einbeziehendsten": "einbeziehend",
    "einbeziehendster": "einbeziehend",
    "einbeziehendstes": "einbeziehend",
    "einbeziehest": "einbeziehen",
    "einbeziehet": "einbeziehen",
    "einbeziehst": "einbeziehen",
    "einbezieht": "einbeziehen",
    "einbezog": "einbeziehen",
    "einbezogen": "einbeziehen",
    "einbezogene": "einbezogen",
    "einbezogenem": "einbezogen",
    "einbezogenen": "einbezogen",
    "einbezogener": "einbezogen",
    "einbezogenere": "einbezogen",
    "einbezogenerem": "einbezogen",
    "einbezogeneren": "einbezogen",
    "einbezogenerer": "einbezogen",
    "einbezogeneres": "einbezogen",
    "einbezogenes": "einbezogen",
    "einbezogenste": "einbezogen",
    "einbezogenstem": "einbezogen",
    "einbezogensten": "einbezogen",
    "einbezogenster": "einbezogen",
    "einbezogenstes": "einbezogen",
    "einbezogst": "einbeziehen",
    "einbezogt": "einbeziehen",
    "einbezöge": "einbeziehen",
    "einbezögen": "einbeziehen",
    "einbezögest": "einbeziehen",
    "einbezöget": "einbeziehen",
    "einbiege": "einbiegen",
    "einbiegend": "einbiegen",
    "einbiegende": "einbiegend",
    "einbiegendem": "einbiegend",
    "einbiegenden": "einbiegend",
    "einbiegender": "einbiegend",
    "einbiegendes": "einbiegend",
    "einbiegest": "einbiegen",
    "einbieget": "einbiegen",
    "einbiegst": "einbiegen",
    "einbiegt": "einbiegen",
    "einbilde": "einbilden",
    "einbildend": "einbilden",
    "einbildende": "einbildend",
    "einbildendem": "einbildend",
    "einbildenden": "einbildend",
    "einbildender": "einbildend",
    "einbildendere": "einbildend",
    "einbildenderem": "einbildend",
    "einbildenderen": "einbildend",
    "einbildenderer": "einbildend",
    "einbildenderes": "einbildend",
    "einbildendes": "einbildend",
    "einbildendste": "einbildend",
    "einbildendstem": "einbildend",
    "einbildendsten": "einbildend",
    "einbildendster": "einbildend",
    "einbildendstes": "einbildend",
    "einbildest": "einbilden",
    "einbildet": "einbilden",
    "einbildete": "einbilden",
    "einbildeten": "einbilden",
    "einbildetest": "einbilden",
    "einbildetet": "einbilden",
    "einbinde": "einbinden",
    "einbindend": "einbinden",
    "einbindende": "einbindend",
    "einbindendem": "einbindend",
    "einbindenden": "einbindend",
    "einbindender": "einbindend",
    "einbindendes": "einbindend",
    "einbindest": "einbinden",
    "einbindet": "einbinden",
    "einblase": "einblasen",
    "einblasend": "einblasen",
    "einblasende": "einblasend",
    "einblasendem": "einblasend",
    "einblasenden": "einblasend",
    "einblasender": "einblasend",
    "einblasendes": "einblasend",
    "einblasest": "einblasen",
    "einblaset": "einblasen",
    "einblast": "einblasen",
    "einblende": "einblenden",
    "einblendend": "einblenden",
    "einblendende": "einblendend",
    "einblendendem": "einblendend",
    "einblendenden": "einblendend",
    "einblendender": "einblendend",
    "einblendendes": "einblendend",
    "einblendest": "einblenden",
    "einblendet": "einblenden",
    "einblendete": "einblenden",
    "einblendeten": "einblenden",
    "einblendetest": "einblenden",
    "einblendetet": "einblenden",
    "einbleue": "einbleuen",
    "einbleuend": "einbleuen",
    "einbleuende": "einbleuend",
    "einbleuendem": "einbleuend",
    "einbleuenden": "einbleuend",
    "einbleuender": "einbleuend",
    "einbleuendere": "einbleuend",
    "einbleuenderem": "einbleuend",
    "einbleuenderen": "einbleuend",
    "einbleuenderer": "einbleuend",
    "einbleuenderes": "einbleuend",
    "einbleuendes": "einbleuend",
    "einbleuendste": "einbleuend",
    "einbleuendstem": "einbleuend",
    "einbleuendsten": "einbleuend",
    "einbleuendster": "einbleuend",
    "einbleuendstes": "einbleuend",
    "einbleuest": "einbleuen",
    "einbleuet": "einbleuen",
    "einbleust": "einbleuen",
    "einbleut": "einbleuen",
    "einbleute": "einbleuen",
    "einbleuten": "einbleuen",
    "einbleutest": "einbleuen",
    "einbleutet": "einbleuen",
    "einblies": "einblasen",
    "einbliese": "einblasen",
    "einbliesen": "einblasen",
    "einbliesest": "einblasen",
    "einblieset": "einblasen",
    "einbliest": "einblasen",
    "einbläst": "einblasen",
    "einbläue": "einbläuen",
    "einbläuend": "einbläuen",
    "einbläuende": "einbläuend",
    "einbläuendem": "einbläuend",
    "einbläuenden": "einbläuend",
    "einbläuender": "einbläuend",
    "einbläuendere": "einbläuend",
    "einbläuenderem": "einbläuend",
    "einbläuenderen": "einbläuend",
    "einbläuenderer": "einbläuend",
    "einbläuenderes": "einbläuend",
    "einbläuendes": "einbläuend",
    "einbläuendste": "einbläuend",
    "einbläuendstem": "einbläuend",
    "einbläuendsten": "einbläuend",
    "einbläuendster": "einbläuend",
    "einbläuendstes": "einbläuend",
    "einbläuest": "einbläuen",
    "einbläuet": "einbläuen",
    "einbläust": "einbläuen",
    "einbläut": "einbläuen",
    "einbläute": "einbläuen",
    "einbläuten": "einbläuen",
    "einbläutest": "einbläuen",
    "einbläutet": "einbläuen",
    "einbog": "einbiegen",
    "einbogen": "einbiegen",
    "einbogst": "einbiegen",
    "einbogt": "einbiegen",
    "einboote": "einbooten",
    "einbootend": "einbooten",
    "einbootende": "einbootend",
    "einbootendem": "einbootend",
    "einbootenden": "einbootend",
    "einbootender": "einbootend",
    "einbootendes": "einbootend",
    "einbootest": "einbooten",
    "einbootet": "einbooten",
    "einbootete": "einbooten",
    "einbooteten": "einbooten",
    "einbootetest": "einbooten",
    "einbootetet": "einbooten",
    "einbrach": "einbrechen",
    "einbrachen": "einbrechen",
    "einbrachst": "einbrechen",
    "einbracht": "einbrechen",
    "einbrachte": "einbringen",
    "einbrachten": "einbringen",
    "einbrachtest": "einbringen",
    "einbrachtet": "einbringen",
    "einbrannte": "einbrennen",
    "einbrannten": "einbrennen",
    "einbranntest": "einbrennen",
    "einbranntet": "einbrennen",
    "einbreche": "einbrechen",
    "einbrechend": "einbrechen",
    "einbrechende": "einbrechend",
    "einbrechendem": "einbrechend",
    "einbrechenden": "einbrechend",
    "einbrechender": "einbrechend",
    "einbrechendes": "einbrechend",
    "einbrechest": "einbrechen",
    "einbrechet": "einbrechen",
    "einbrecht": "einbrechen",
    "einbrenne": "einbrennen",
    "einbrennend": "einbrennen",
    "einbrennende": "einbrennend",
    "einbrennendem": "einbrennend",
    "einbrennenden": "einbrennend",
    "einbrennender": "einbrennend",
    "einbrennendere": "einbrennend",
    "einbrennenderem": "einbrennend",
    "einbrennenderen": "einbrennend",
    "einbrennenderer": "einbrennend",
    "einbrennenderes": "einbrennend",
    "einbrennendes": "einbrennend",
    "einbrennendste": "einbrennend",
    "einbrennendstem": "einbrennend",
    "einbrennendsten": "einbrennend",
    "einbrennendster": "einbrennend",
    "einbrennendstes": "einbrennend",
    "einbrennest": "einbrennen",
    "einbrennet": "einbrennen",
    "einbrennst": "einbrennen",
    "einbrennt": "einbrennen",
    "einbrichst": "einbrechen",
    "einbricht": "einbrechen",
    "einbringe": "einbringen",
    "einbringend": "einbringen",
    "einbringende": "einbringend",
    "einbringendem": "einbringend",
    "einbringenden": "einbringend",
    "einbringender": "einbringend",
    "einbringendes": "einbringend",
    "einbringest": "einbringen",
    "einbringet": "einbringen",
    "einbringst": "einbringen",
    "einbringt": "einbringen",
    "einbräche": "einbrechen",
    "einbrächen": "einbrechen",
    "einbrächest": "einbrechen",
    "einbrächet": "einbrechen",
    "einbrächte": "einbringen",
    "einbrächten": "einbringen",
    "einbrächtest": "einbringen",
    "einbrächtet": "einbringen",
    "einbuchte": "einbuchten",
    "einbuchtend": "einbuchten",
    "einbuchtende": "einbuchtend",
    "einbuchtendem": "einbuchtend",
    "einbuchtenden": "einbuchtend",
    "einbuchtender": "einbuchtend",
    "einbuchtendes": "einbuchtend",
    "einbuchtest": "einbuchten",
    "einbuchtet": "einbuchten",
    "einbuchtete": "einbuchten",
    "einbuchteten": "einbuchten",
    "einbuchtetest": "einbuchten",
    "einbuchtetet": "einbuchten",
    "einbuddele": "einbuddeln",
    "einbuddelnd": "einbuddeln",
    "einbuddelnde": "einbuddelnd",
    "einbuddelndem": "einbuddelnd",
    "einbuddelnden": "einbuddelnd",
    "einbuddelnder": "einbuddelnd",
    "einbuddelndes": "einbuddelnd",
    "einbuddelst": "einbuddeln",
    "einbuddelt": "einbuddeln",
    "einbuddelte": "einbuddeln",
    "einbuddelten": "einbuddeln",
    "einbuddeltest": "einbuddeln",
    "einbuddeltet": "einbuddeln",
    "einbuddle": "einbuddeln",
    "einbunkere": "einbunkern",
    "einbunkernd": "einbunkern",
    "einbunkernde": "einbunkernd",
    "einbunkerndem": "einbunkernd",
    "einbunkernden": "einbunkernd",
    "einbunkernder": "einbunkernd",
    "einbunkerndes": "einbunkernd",
    "einbunkerst": "einbunkern",
    "einbunkert": "einbunkern",
    "einbunkerte": "einbunkern",
    "einbunkerten": "einbunkern",
    "einbunkertest": "einbunkern",
    "einbunkertet": "einbunkern",
    "einbändest": "einbinden",
    "einbändet": "einbinden",
    "einböge": "einbiegen",
    "einbögen": "einbiegen",
    "einbögest": "einbiegen",
    "einböget": "einbiegen",
    "einbürgere": "einbürgern",
    "einbürgernd": "einbürgern",
    "einbürgernde": "einbürgernd",
    "einbürgerndem": "einbürgernd",
    "einbürgernden": "einbürgernd",
    "einbürgernder": "einbürgernd",
    "einbürgerndes": "einbürgernd",
    "einbürgerst": "einbürgern",
    "einbürgert": "einbürgern",
    "einbürgerte": "einbürgern",
    "einbürgerten": "einbürgern",
    "einbürgertest": "einbürgern",
    "einbürgertet": "einbürgern",
    "einbüße": "einbüßen",
    "einbüßend": "einbüßen",
    "einbüßende": "einbüßend",
    "einbüßendem": "einbüßend",
    "einbüßenden": "einbüßend",
    "einbüßender": "einbüßend",
    "einbüßendes": "einbüßend",
    "einbüßest": "einbüßen",
    "einbüßet": "einbüßen",
    "einbüßt": "einbüßen",
    "einbüßte": "einbüßen",
    "einbüßten": "einbüßen",
    "einbüßtest": "einbüßen",
    "einbüßtet": "einbüßen",
    "einchecke": "einchecken",
    "eincheckend": "einchecken",
    "eincheckende": "eincheckend",
    "eincheckendem": "eincheckend",
    "eincheckenden": "eincheckend",
    "eincheckender": "eincheckend",
    "eincheckendes": "eincheckend",
    "eincheckest": "einchecken",
    "einchecket": "einchecken",
    "eincheckst": "einchecken",
    "eincheckt": "einchecken",
    "eincheckte": "einchecken",
    "eincheckten": "einchecken",
    "einchecktest": "einchecken",
    "einchecktet": "einchecken",
    "eincreme": "eincremen",
    "eincremend": "eincremen",
    "eincremende": "eincremend",
    "eincremendem": "eincremend",
    "eincremenden": "eincremend",
    "eincremender": "eincremend",
    "eincremendes": "eincremend",
    "eincremest": "eincremen",
    "eincremet": "eincremen",
    "eincremst": "eincremen",
    "eincremt": "eincremen",
    "eincremte": "eincremen",
    "eincremten": "eincremen",
    "eincremtest": "eincremen",
    "eincremtet": "eincremen",
    "eindampfe": "eindampfen",
    "eindampfend": "eindampfen",
    "eindampfende": "eindampfend",
    "eindampfendem": "eindampfend",
    "eindampfenden": "eindampfend",
    "eindampfender": "eindampfend",
    "eindampfendes": "eindampfend",
    "eindampfest": "eindampfen",
    "eindampfet": "eindampfen",
    "eindampfst": "eindampfen",
    "eindampft": "eindampfen",
    "eindampfte": "eindampfen",
    "eindampften": "eindampfen",
    "eindampftest": "eindampfen",
    "eindampftet": "eindampfen",
    "eindeiche": "eindeichen",
    "eindeichend": "eindeichen",
    "eindeichende": "eindeichend",
    "eindeichendem": "eindeichend",
    "eindeichenden": "eindeichend",
    "eindeichender": "eindeichend",
    "eindeichendes": "eindeichend",
    "eindeichest": "eindeichen",
    "eindeichet": "eindeichen",
    "eindeichst": "eindeichen",
    "eindeicht": "eindeichen",
    "eindeichte": "eindeichen",
    "eindeichten": "eindeichen",
    "eindeichtest": "eindeichen",
    "eindeichtet": "eindeichen",
    "eindelle": "eindellen",
    "eindellend": "eindellen",
    "eindellende": "eindellend",
    "eindellendem": "eindellend",
    "eindellenden": "eindellend",
    "eindellender": "eindellend",
    "eindellendere": "eindellend",
    "eindellenderem": "eindellend",
    "eindellenderen": "eindellend",
    "eindellenderer": "eindellend",
    "eindellenderes": "eindellend",
    "eindellendes": "eindellend",
    "eindellendste": "eindellend",
    "eindellendstem": "eindellend",
    "eindellendsten": "eindellend",
    "eindellendster": "eindellend",
    "eindellendstes": "eindellend",
    "eindellest": "eindellen",
    "eindellet": "eindellen",
    "eindellst": "eindellen",
    "eindellt": "eindellen",
    "eindellte": "eindellen",
    "eindellten": "eindellen",
    "eindelltest": "eindellen",
    "eindelltet": "eindellen",
    "eindeutige": "eindeutig",
    "eindeutigem": "eindeutig",
    "eindeutigen": "eindeutig",
    "eindeutiger": "eindeutig",
    "eindeutigere": "eindeutig",
    "eindeutigerem": "eindeutig",
    "eindeutigeren": "eindeutig",
    "eindeutigerer": "eindeutig",
    "eindeutigeres": "eindeutig",
    "eindeutiges": "eindeutig",
    "eindeutigstem": "eindeutig",
    "eindeutigsten": "eindeutig",
    "eindeutigster": "eindeutig",
    "eindeutigstes": "eindeutig",
    "eindeutsche": "eindeutschen",
    "eindeutschend": "eindeutschen",
    "eindeutschende": "eindeutschend",
    "eindeutschendem": "eindeutschend",
    "eindeutschenden": "eindeutschend",
    "eindeutschender": "eindeutschend",
    "eindeutschendes": "eindeutschend",
    "eindeutschest": "eindeutschen",
    "eindeutschet": "eindeutschen",
    "eindeutschst": "eindeutschen",
    "eindeutscht": "eindeutschen",
    "eindeutschte": "eindeutschen",
    "eindeutschten": "eindeutschen",
    "eindeutschtest": "eindeutschen",
    "eindeutschtet": "eindeutschen",
    "eindimensionale": "eindimensional",
    "eindimensionalem": "eindimensional",
    "eindimensionalen": "eindimensional",
    "eindimensionaler": "eindimensional",
    "eindimensionales": "eindimensional",
    "eindose": "eindosen",
    "eindosend": "eindosen",
    "eindosende": "eindosend",
    "eindosendem": "eindosend",
    "eindosenden": "eindosend",
    "eindosender": "eindosend",
    "eindosendes": "eindosend",
    "eindosest": "eindosen",
    "eindoset": "eindosen",
    "eindost": "eindosen",
    "eindoste": "eindosen",
    "eindosten": "eindosen",
    "eindostest": "eindosen",
    "eindostet": "eindosen",
    "eindrang": "eindringen",
    "eindrangen": "eindringen",
    "eindrangst": "eindringen",
    "eindrangt": "eindringen",
    "eindrehe": "eindrehen",
    "eindrehend": "eindrehen",
    "eindrehende": "eindrehend",
    "eindrehendem": "eindrehend",
    "eindrehenden": "eindrehend",
    "eindrehender": "eindrehend",
    "eindrehendes": "eindrehend",
    "eindrehest": "eindrehen",
    "eindrehet": "eindrehen",
    "eindrehst": "eindrehen",
    "eindreht": "eindrehen",
    "eindrehte": "eindrehen",
    "eindrehten": "eindrehen",
    "eindrehtest": "eindrehen",
    "eindrehtet": "eindrehen",
    "eindrille": "eindrillen",
    "eindrillend": "eindrillen",
    "eindrillende": "eindrillend",
    "eindrillendem": "eindrillend",
    "eindrillenden": "eindrillend",
    "eindrillender": "eindrillend",
    "eindrillendere": "eindrillend",
    "eindrillenderem": "eindrillend",
    "eindrillenderen": "eindrillend",
    "eindrillenderer": "eindrillend",
    "eindrillenderes": "eindrillend",
    "eindrillendes": "eindrillend",
    "eindrillendste": "eindrillend",
    "eindrillendstem": "eindrillend",
    "eindrillendsten": "eindrillend",
    "eindrillendster": "eindrillend",
    "eindrillendstes": "eindrillend",
    "eindrillest": "eindrillen",
    "eindrillet": "eindrillen",
    "eindrillst": "eindrillen",
    "eindrillt": "eindrillen",
    "eindrillte": "eindrillen",
    "eindrillten": "eindrillen",
    "eindrilltest": "eindrillen",
    "eindrilltet": "eindrillen",
    "eindringe": "eindringen",
    "eindringend": "eindringen",
    "eindringende": "eindringend",
    "eindringendem": "eindringend",
    "eindringenden": "eindringend",
    "eindringender": "eindringend",
    "eindringendes": "eindringend",
    "eindringest": "eindringen",
    "eindringet": "eindringen",
    "eindringliche": "eindringlich",
    "eindringlichem": "eindringlich",
    "eindringlichen": "eindringlich",
    "eindringlicher": "eindringlich",
    "eindringlichere": "eindringlich",
    "eindringlicherem": "eindringlich",
    "eindringlicheren": "eindringlich",
    "eindringlicherer": "eindringlich",
    "eindringlicheres": "eindringlich",
    "eindringliches": "eindringlich",
    "eindringlichstem": "eindringlich",
    "eindringlichsten": "eindringlich",
    "eindringlichster": "eindringlich",
    "eindringlichstes": "eindringlich",
    "eindringst": "eindringen",
    "eindringt": "eindringen",
    "eindruckslosem": "eindruckslos",
    "eindruckslosen": "eindruckslos",
    "eindrucksloser": "eindruckslos",
    "eindruckslosere": "eindruckslos",
    "eindrucksloserem": "eindruckslos",
    "eindrucksloseren": "eindruckslos",
    "eindrucksloserer": "eindruckslos",
    "eindrucksloseres": "eindruckslos",
    "eindrucksloses": "eindruckslos",
    "eindrucksloseste": "eindruckslos",
    "eindruckslosestem": "eindruckslos",
    "eindruckslosesten": "eindruckslos",
    "eindruckslosester": "eindruckslos",
    "eindruckslosestes": "eindruckslos",
    "eindrucksvolle": "eindrucksvoll",
    "eindrucksvollem": "eindrucksvoll",
    "eindrucksvollen": "eindrucksvoll",
    "eindrucksvoller": "eindrucksvoll",
    "eindrucksvollere": "eindrucksvoll",
    "eindrucksvollerem": "eindrucksvoll",
    "eindrucksvolleren": "eindrucksvoll",
    "eindrucksvollerer": "eindrucksvoll",
    "eindrucksvolleres": "eindrucksvoll",
    "eindrucksvolles": "eindrucksvoll",
    "eindrucksvollste": "eindrucksvoll",
    "eindrucksvollstem": "eindrucksvoll",
    "eindrucksvollsten": "eindrucksvoll",
    "eindrucksvollster": "eindrucksvoll",
    "eindrucksvollstes": "eindrucksvoll",
    "eindränge": "eindringen",
    "eindrängen": "eindringen",
    "eindrängest": "eindringen",
    "eindränget": "eindringen",
    "eindrücke": "eindrücken",
    "eindrückend": "eindrücken",
    "eindrückende": "eindrückend",
    "eindrückendem": "eindrückend",
    "eindrückenden": "eindrückend",
    "eindrückender": "eindrückend",
    "eindrückendes": "eindrückend",
    "eindrückest": "eindrücken",
    "eindrücket": "eindrücken",
    "eindrückliche": "eindrücklich",
    "eindrücklichem": "eindrücklich",
    "eindrücklichen": "eindrücklich",
    "eindrücklicher": "eindrücklich",
    "eindrückliches": "eindrücklich",
    "eindrückst": "eindrücken",
    "eindrückt": "eindrücken",
    "eindrückte": "eindrücken",
    "eindrückten": "eindrücken",
    "eindrücktest": "eindrücken",
    "eindrücktet": "eindrücken",
    "eindämme": "eindämmen",
    "eindämmend": "eindämmen",
    "eindämmende": "eindämmend",
    "eindämmendem": "eindämmend",
    "eindämmenden": "eindämmend",
    "eindämmender": "eindämmend",
    "eindämmendere": "eindämmend",
    "eindämmenderem": "eindämmend",
    "eindämmenderen": "eindämmend",
    "eindämmenderer": "eindämmend",
    "eindämmenderes": "eindämmend",
    "eindämmendes": "eindämmend",
    "eindämmendste": "eindämmend",
    "eindämmendstem": "eindämmend",
    "eindämmendsten": "eindämmend",
    "eindämmendster": "eindämmend",
    "eindämmendstes": "eindämmend",
    "eindämmest": "eindämmen",
    "eindämmet": "eindämmen",
    "eindämmst": "eindämmen",
    "eindämmt": "eindämmen",
    "eindämmte": "eindämmen",
    "eindämmten": "eindämmen",
    "eindämmtest": "eindämmen",
    "eindämmtet": "eindämmen",
    "eine": "einen",
    "einebne": "einebnen",
    "einebnend": "einebnen",
    "einebnende": "einebnend",
    "einebnendem": "einebnend",
    "einebnenden": "einebnend",
    "einebnender": "einebnend",
    "einebnendes": "einebnend",
    "einebnest": "einebnen",
    "einebnet": "einebnen",
    "einebnete": "einebnen",
    "einebneten": "einebnen",
    "einebnetest": "einebnen",
    "einebnetet": "einebnen",
    "eineindeutige": "eineindeutig",
    "eineindeutigem": "eineindeutig",
    "eineindeutigen": "eineindeutig",
    "eineindeutiger": "eineindeutig",
    "eineindeutiges": "eineindeutig",
    "einem": "einer",
    "einen": "ein",
    "einend": "einen",
    "einende": "einend",
    "einendem": "einend",
    "einenden": "einend",
    "einender": "einend",
    "einendes": "einend",
    "einenge": "einengen",
    "einengend": "einengen",
    "einengende": "einengend",
    "einengendem": "einengend",
    "einengenden": "einengend",
    "einengender": "einengend",
    "einengendere": "einengend",
    "einengenderem": "einengend",
    "einengenderen": "einengend",
    "einengenderer": "einengend",
    "einengenderes": "einengend",
    "einengendes": "einengend",
    "einengendste": "einengend",
    "einengendstem": "einengend",
    "einengendsten": "einengend",
    "einengendster": "einengend",
    "einengendstes": "einengend",
    "einengest": "einengen",
    "einenget": "einengen",
    "einengst": "einengen",
    "einengt": "einengen",
    "einengte": "einengen",
    "einengten": "einengen",
    "einengtest": "einengen",
    "einengtet": "einengen",
    "einernte": "einernten",
    "einerntend": "einernten",
    "einerntende": "einerntend",
    "einerntendem": "einerntend",
    "einerntenden": "einerntend",
    "einerntender": "einerntend",
    "einerntendes": "einerntend",
    "einerntest": "einernten",
    "einerntet": "einernten",
    "einerntete": "einernten",
    "einernteten": "einernten",
    "einerntetest": "einernten",
    "einerntetet": "einernten",
    "eines": "ein",
    "einest": "einen",
    "einet": "einen",
    "einfache": "einfach",
    "einfachem": "einfach",
    "einfachen": "einfach",
    "einfacher": "einfach",
    "einfachere": "einfach",
    "einfacherem": "einfach",
    "einfacheren": "einfach",
    "einfacherer": "einfach",
    "einfacheres": "einfach",
    "einfaches": "einfach",
    "einfachste": "einfach",
    "einfachstem": "einfach",
    "einfachsten": "einfach",
    "einfachster": "einfach",
    "einfachstes": "einfach",
    "einfahre": "einfahren",
    "einfahrend": "einfahren",
    "einfahrende": "einfahrend",
    "einfahrendem": "einfahrend",
    "einfahrenden": "einfahrend",
    "einfahrender": "einfahrend",
    "einfahrendes": "einfahrend",
    "einfahrest": "einfahren",
    "einfahret": "einfahren",
    "einfahrt": "einfahren",
    "einfallend": "einfallen",
    "einfallende": "einfallend",
    "einfallendem": "einfallend",
    "einfallenden": "einfallend",
    "einfallender": "einfallend",
    "einfallendes": "einfallend",
    "einfallest": "einfallen",
    "einfallet": "einfallen",
    "einfallslosem": "einfallslos",
    "einfallslosen": "einfallslos",
    "einfallsloser": "einfallslos",
    "einfallslosere": "einfallslos",
    "einfallsloserem": "einfallslos",
    "einfallsloseren": "einfallslos",
    "einfallsloserer": "einfallslos",
    "einfallsloseres": "einfallslos",
    "einfallsloses": "einfallslos",
    "einfallsloseste": "einfallslos",
    "einfallslosestem": "einfallslos",
    "einfallslosesten": "einfallslos",
    "einfallslosester": "einfallslos",
    "einfallslosestes": "einfallslos",
    "einfallsreiche": "einfallsreich",
    "einfallsreichem": "einfallsreich",
    "einfallsreichen": "einfallsreich",
    "einfallsreicher": "einfallsreich",
    "einfallsreichere": "einfallsreich",
    "einfallsreicherem": "einfallsreich",
    "einfallsreicheren": "einfallsreich",
    "einfallsreicherer": "einfallsreich",
    "einfallsreicheres": "einfallsreich",
    "einfallsreiches": "einfallsreich",
    "einfallsreichste": "einfallsreich",
    "einfallsreichstem": "einfallsreich",
    "einfallsreichsten": "einfallsreich",
    "einfallsreichster": "einfallsreich",
    "einfallsreichstes": "einfallsreich",
    "einfallt": "einfallen",
    "einfand": "einfinden",
    "einfanden": "einfinden",
    "einfandest": "einfinden",
    "einfandet": "einfinden",
    "einfange": "einfangen",
    "einfangend": "einfangen",
    "einfangende": "einfangend",
    "einfangendem": "einfangend",
    "einfangenden": "einfangend",
    "einfangender": "einfangend",
    "einfangendes": "einfangend",
    "einfangest": "einfangen",
    "einfanget": "einfangen",
    "einfangt": "einfangen",
    "einfarbige": "einfarbig",
    "einfarbigem": "einfarbig",
    "einfarbigen": "einfarbig",
    "einfarbiger": "einfarbig",
    "einfarbiges": "einfarbig",
    "einfasse": "einfassen",
    "einfassend": "einfassen",
    "einfassende": "einfassend",
    "einfassendem": "einfassend",
    "einfassenden": "einfassend",
    "einfassender": "einfassend",
    "einfassendes": "einfassend",
    "einfassest": "einfassen",
    "einfasset": "einfassen",
    "einfaßt": "einfassen",
    "einfaßte": "einfassen",
    "einfaßten": "einfassen",
    "einfaßtest": "einfassen",
    "einfaßtet": "einfassen",
    "einfette": "einfetten",
    "einfettend": "einfetten",
    "einfettende": "einfettend",
    "einfettendem": "einfettend",
    "einfettenden": "einfettend",
    "einfettender": "einfettend",
    "einfettendere": "einfettend",
    "einfettenderem": "einfettend",
    "einfettenderen": "einfettend",
    "einfettenderer": "einfettend",
    "einfettenderes": "einfettend",
    "einfettendes": "einfettend",
    "einfettendste": "einfettend",
    "einfettendstem": "einfettend",
    "einfettendsten": "einfettend",
    "einfettendster": "einfettend",
    "einfettendstes": "einfettend",
    "einfettest": "einfetten",
    "einfettet": "einfetten",
    "einfettete": "einfetten",
    "einfetteten": "einfetten",
    "einfettetest": "einfetten",
    "einfettetet": "einfetten",
    "einfeuere": "einfeuern",
    "einfeuernd": "einfeuern",
    "einfeuernde": "einfeuernd",
    "einfeuerndem": "einfeuernd",
    "einfeuernden": "einfeuernd",
    "einfeuernder": "einfeuernd",
    "einfeuerndes": "einfeuernd",
    "einfeuerst": "einfeuern",
    "einfeuert": "einfeuern",
    "einfeuerte": "einfeuern",
    "einfeuerten": "einfeuern",
    "einfeuertest": "einfeuern",
    "einfeuertet": "einfeuern",
    "einfiel": "einfallen",
    "einfiele": "einfallen",
    "einfielen": "einfallen",
    "einfielest": "einfallen",
    "einfielet": "einfallen",
    "einfielst": "einfallen",
    "einfielt": "einfallen",
    "einfinde": "einfinden",
    "einfindend": "einfinden",
    "einfindende": "einfindend",
    "einfindendem": "einfindend",
    "einfindenden": "einfindend",
    "einfindender": "einfindend",
    "einfindendes": "einfindend",
    "einfindest": "einfinden",
    "einfindet": "einfinden",
    "einfing": "einfangen",
    "einfinge": "einfangen",
    "einfingen": "einfangen",
    "einfingest": "einfangen",
    "einfinget": "einfangen",
    "einfingst": "einfangen",
    "einfingt": "einfangen",
    "einflechte": "einflechten",
    "einflechtend": "einflechten",
    "einflechtende": "einflechtend",
    "einflechtendem": "einflechtend",
    "einflechtenden": "einflechtend",
    "einflechtender": "einflechtend",
    "einflechtendes": "einflechtend",
    "einflechtest": "einflechten",
    "einflechtet": "einflechten",
    "einflicht": "einflechten",
    "einflichtst": "einflechten",
    "einfliege": "einfliegen",
    "einfliegend": "einfliegen",
    "einfliegende": "einfliegend",
    "einfliegendem": "einfliegend",
    "einfliegenden": "einfliegend",
    "einfliegender": "einfliegend",
    "einfliegendes": "einfliegend",
    "einfliegest": "einfliegen",
    "einflieget": "einfliegen",
    "einfliegst": "einfliegen",
    "einfliegt": "einfliegen",
    "einfließe": "einfließen",
    "einfließend": "einfließen",
    "einfließende": "einfließend",
    "einfließendem": "einfließend",
    "einfließenden": "einfließend",
    "einfließender": "einfließend",
    "einfließendes": "einfließend",
    "einfließest": "einfließen",
    "einfließet": "einfließen",
    "einfließt": "einfließen",
    "einflippe": "einflippen",
    "einflippend": "einflippen",
    "einflippende": "einflippend",
    "einflippendem": "einflippend",
    "einflippenden": "einflippend",
    "einflippender": "einflippend",
    "einflippendes": "einflippend",
    "einflippest": "einflippen",
    "einflippet": "einflippen",
    "einflippst": "einflippen",
    "einflippt": "einflippen",
    "einflippte": "einflippen",
    "einflippten": "einflippen",
    "einflipptest": "einflippen",
    "einflipptet": "einflippen",
    "einflocht": "einflechten",
    "einflochten": "einflechten",
    "einflochtest": "einflechten",
    "einflochtet": "einflechten",
    "einflog": "einfliegen",
    "einflogen": "einfliegen",
    "einflogst": "einfliegen",
    "einflogt": "einfliegen",
    "einflossen": "einfließen",
    "einfloß": "einfließen",
    "einfloßt": "einfließen",
    "einflußreichem": "einflußreich",
    "einflußreichen": "einflußreich",
    "einflußreicher": "einflußreich",
    "einflußreichere": "einflußreich",
    "einflußreicherem": "einflußreich",
    "einflußreicheren": "einflußreich",
    "einflußreicherer": "einflußreich",
    "einflußreicheres": "einflußreich",
    "einflußreiches": "einflußreich",
    "einflußreichste": "einflußreich",
    "einflußreichstem": "einflußreich",
    "einflußreichsten": "einflußreich",
    "einflußreichster": "einflußreich",
    "einflußreichstes": "einflußreich",
    "einflöchte": "einflechten",
    "einflöchten": "einflechten",
    "einflöchtest": "einflechten",
    "einflöchtet": "einflechten",
    "einflöge": "einfliegen",
    "einflögen": "einfliegen",
    "einflögest": "einfliegen",
    "einflöget": "einfliegen",
    "einflösse": "einfließen",
    "einflössen": "einfließen",
    "einflössest": "einfließen",
    "einflösset": "einfließen",
    "einflöße": "einflößen",
    "einflößend": "einflößen",
    "einflößende": "einflößend",
    "einflößendem": "einflößend",
    "einflößenden": "einflößend",
    "einflößender": "einflößend",
    "einflößendes": "einflößend",
    "einflößest": "einflößen",
    "einflößet": "einflößen",
    "einflößt": "einflößen",
    "einflößte": "einflößen",
    "einflößten": "einflößen",
    "einflößtest": "einflößen",
    "einflößtet": "einflößen",
    "einflüstere": "einflüstern",
    "einflüsternd": "einflüstern",
    "einflüsternde": "einflüsternd",
    "einflüsterndem": "einflüsternd",
    "einflüsternden": "einflüsternd",
    "einflüsternder": "einflüsternd",
    "einflüsterndes": "einflüsternd",
    "einflüsterst": "einflüstern",
    "einflüstert": "einflüstern",
    "einflüsterte": "einflüstern",
    "einflüsterten": "einflüstern",
    "einflüstertest": "einflüstern",
    "einflüstertet": "einflüstern",
    "einfordere": "einfordern",
    "einfordernd": "einfordern",
    "einfordernde": "einfordernd",
    "einforderndem": "einfordernd",
    "einfordernden": "einfordernd",
    "einfordernder": "einfordernd",
    "einforderndes": "einfordernd",
    "einforderst": "einfordern",
    "einfordert": "einfordern",
    "einforderte": "einfordern",
    "einforderten": "einfordern",
    "einfordertest": "einfordern",
    "einfordertet": "einfordern",
    "einfraß": "einfressen",
    "einfraßen": "einfressen",
    "einfraßt": "einfressen",
    "einfresse": "einfressen",
    "einfressend": "einfressen",
    "einfressende": "einfressend",
    "einfressendem": "einfressend",
    "einfressenden": "einfressend",
    "einfressender": "einfressend",
    "einfressendes": "einfressend",
    "einfressest": "einfressen",
    "einfresset": "einfressen",
    "einfreßt": "einfressen",
    "einfriere": "einfrieren",
    "einfrierend": "einfrieren",
    "einfrierende": "einfrierend",
    "einfrierendem": "einfrierend",
    "einfrierenden": "einfrierend",
    "einfrierender": "einfrierend",
    "einfrierendes": "einfrierend",
    "einfrierest": "einfrieren",
    "einfrieret": "einfrieren",
    "einfrierst": "einfrieren",
    "einfriert": "einfrieren",
    "einfrißt": "einfressen",
    "einfror": "einfrieren",
    "einfroren": "einfrieren",
    "einfrorst": "einfrieren",
    "einfrort": "einfrieren",
    "einfräße": "einfressen",
    "einfräßen": "einfressen",
    "einfräßest": "einfressen",
    "einfräßet": "einfressen",
    "einfröre": "einfrieren",
    "einfrören": "einfrieren",
    "einfrörest": "einfrieren",
    "einfröret": "einfrieren",
    "einfuhr": "einfahren",
    "einfuhren": "einfahren",
    "einfuhrst": "einfahren",
    "einfuhrt": "einfahren",
    "einfädele": "einfädeln",
    "einfädelnd": "einfädeln",
    "einfädelnde": "einfädelnd",
    "einfädelndem": "einfädelnd",
    "einfädelnden": "einfädelnd",
    "einfädelnder": "einfädelnd",
    "einfädelndes": "einfädelnd",
    "einfädelst": "einfädeln",
    "einfädelt": "einfädeln",
    "einfädelte": "einfädeln",
    "einfädelten": "einfädeln",
    "einfädeltest": "einfädeln",
    "einfädeltet": "einfädeln",
    "einfädle": "einfädeln",
    "einfährst": "einfahren",
    "einfährt": "einfahren",
    "einfällst": "einfallen",
    "einfällt": "einfallen",
    "einfältige": "einfältig",
    "einfältigem": "einfältig",
    "einfältigen": "einfältig",
    "einfältiger": "einfältig",
    "einfältigere": "einfältig",
    "einfältigerem": "einfältig",
    "einfältigeren": "einfältig",
    "einfältigerer": "einfältig",
    "einfältigeres": "einfältig",
    "einfältiges": "einfältig",
    "einfältigste": "einfältig",
    "einfältigstem": "einfältig",
    "einfältigsten": "einfältig",
    "einfältigster": "einfältig",
    "einfältigstes": "einfältig",
    "einfände": "einfinden",
    "einfänden": "einfinden",
    "einfändest": "einfinden",
    "einfändet": "einfinden",
    "einfängst": "einfangen",
    "einfängt": "einfangen",
    "einfärbe": "einfärben",
    "einfärbend": "einfärben",
    "einfärbende": "einfärbend",
    "einfärbendem": "einfärbend",
    "einfärbenden": "einfärbend",
    "einfärbender": "einfärbend",
    "einfärbendere": "einfärbend",
    "einfärbenderem": "einfärbend",
    "einfärbenderen": "einfärbend",
    "einfärbenderer": "einfärbend",
    "einfärbenderes": "einfärbend",
    "einfärbendes": "einfärbend",
    "einfärbendste": "einfärbend",
    "einfärbendstem": "einfärbend",
    "einfärbendsten": "einfärbend",
    "einfärbendster": "einfärbend",
    "einfärbendstes": "einfärbend",
    "einfärbest": "einfärben",
    "einfärbet": "einfärben",
    "einfärbst": "einfärben",
    "einfärbt": "einfärben",
    "einfärbte": "einfärben",
    "einfärbten": "einfärben",
    "einfärbtest": "einfärben",
    "einfärbtet": "einfärben",
    "einfüge": "einfügen",
    "einfügend": "einfügen",
    "einfügende": "einfügend",
    "einfügendem": "einfügend",
    "einfügenden": "einfügend",
    "einfügender": "einfügend",
    "einfügendes": "einfügend",
    "einfügest": "einfügen",
    "einfüget": "einfügen",
    "einfügst": "einfügen",
    "einfügt": "einfügen",
    "einfügte": "einfügen",
    "einfügten": "einfügen",
    "einfügtest": "einfügen",
    "einfügtet": "einfügen",
    "einfühle": "einfühlen",
    "einfühlend": "einfühlen",
    "einfühlende": "einfühlend",
    "einfühlendem": "einfühlend",
    "einfühlenden": "einfühlend",
    "einfühlender": "einfühlend",
    "einfühlendere": "einfühlend",
    "einfühlenderem": "einfühlend",
    "einfühlenderen": "einfühlend",
    "einfühlenderer": "einfühlend",
    "einfühlenderes": "einfühlend",
    "einfühlendes": "einfühlend",
    "einfühlendste": "einfühlend",
    "einfühlendstem": "einfühlend",
    "einfühlendsten": "einfühlend",
    "einfühlendster": "einfühlend",
    "einfühlendstes": "einfühlend",
    "einfühlest": "einfühlen",
    "einfühlet": "einfühlen",
    "einfühlsame": "einfühlsam",
    "einfühlsamem": "einfühlsam",
    "einfühlsamen": "einfühlsam",
    "einfühlsamer": "einfühlsam",
    "einfühlsamere": "einfühlsam",
    "einfühlsamerem": "einfühlsam",
    "einfühlsameren": "einfühlsam",
    "einfühlsamerer": "einfühlsam",
    "einfühlsameres": "einfühlsam",
    "einfühlsames": "einfühlsam",
    "einfühlsamste": "einfühlsam",
    "einfühlsamstem": "einfühlsam",
    "einfühlsamsten": "einfühlsam",
    "einfühlsamster": "einfühlsam",
    "einfühlsamstes": "einfühlsam",
    "einfühlst": "einfühlen",
    "einfühlt": "einfühlen",
    "einfühlte": "einfühlen",
    "einfühlten": "einfühlen",
    "einfühltest": "einfühlen",
    "einfühltet": "einfühlen",
    "einführe": "einführen",
    "einführen": "einfahren",
    "einführend": "einführen",
    "einführende": "einführend",
    "einführendem": "einführend",
    "einführenden": "einführend",
    "einführender": "einführend",
    "einführendes": "einführend",
    "einführest": "einführen",
    "einführet": "einführen",
    "einführst": "einführen",
    "einführt": "einführen",
    "einführte": "einführen",
    "einführten": "einführen",
    "einführtest": "einführen",
    "einführtet": "einführen",
    "einfülle": "einfüllen",
    "einfüllend": "einfüllen",
    "einfüllende": "einfüllend",
    "einfüllendem": "einfüllend",
    "einfüllenden": "einfüllend",
    "einfüllender": "einfüllend",
    "einfüllendes": "einfüllend",
    "einfüllest": "einfüllen",
    "einfüllet": "einfüllen",
    "einfüllst": "einfüllen",
    "einfüllt": "einfüllen",
    "einfüllte": "einfüllen",
    "einfüllten": "einfüllen",
    "einfülltest": "einfüllen",
    "einfülltet": "einfüllen",
    "eingab": "eingeben",
    "eingabst": "eingeben",
    "eingabt": "eingeben",
    "eingearbeitet": "einarbeiten",
    "eingearbeitete": "eingearbeitet",
    "eingearbeitetem": "eingearbeitet",
    "eingearbeiteten": "eingearbeitet",
    "eingearbeiteter": "eingearbeitet",
    "eingearbeitetere": "eingearbeitet",
    "eingearbeiteterem": "eingearbeitet",
    "eingearbeiteteren": "eingearbeitet",
    "eingearbeiteterer": "eingearbeitet",
    "eingearbeiteteres": "eingearbeitet",
    "eingearbeitetes": "eingearbeitet",
    "eingearbeiteteste": "eingearbeitet",
    "eingearbeitetestem": "eingearbeitet",
    "eingearbeitetesten": "eingearbeitet",
    "eingearbeitetester": "eingearbeitet",
    "eingearbeitetestes": "eingearbeitet",
    "eingeatmet": "einatmen",
    "eingeatmete": "eingeatmet",
    "eingeatmetem": "eingeatmet",
    "eingeatmeten": "eingeatmet",
    "eingeatmeter": "eingeatmet",
    "eingeatmetes": "eingeatmet",
    "eingebaut": "einbauen",
    "eingebaute": "eingebaut",
    "eingebautem": "eingebaut",
    "eingebauten": "eingebaut",
    "eingebauter": "eingebaut",
    "eingebautes": "eingebaut",
    "eingebe": "eingeben",
    "eingebend": "eingeben",
    "eingebende": "eingebend",
    "eingebendem": "eingebend",
    "eingebenden": "eingebend",
    "eingebender": "eingebend",
    "eingebendes": "eingebend",
    "eingebest": "eingeben",
    "eingebet": "eingeben",
    "eingebettet": "einbetten",
    "eingebettete": "eingebettet",
    "eingebettetem": "eingebettet",
    "eingebetteten": "eingebettet",
    "eingebetteter": "eingebettet",
    "eingebettetes": "eingebettet",
    "eingebildet": "einbilden",
    "eingebildete": "eingebildet",
    "eingebildetem": "eingebildet",
    "eingebildeten": "eingebildet",
    "eingebildeter": "eingebildet",
    "eingebildetere": "eingebildet",
    "eingebildeterem": "eingebildet",
    "eingebildeteren": "eingebildet",
    "eingebildeterer": "eingebildet",
    "eingebildeteres": "eingebildet",
    "eingebildetes": "eingebildet",
    "eingebildeteste": "eingebildet",
    "eingebildetestem": "eingebildet",
    "eingebildetesten": "eingebildet",
    "eingebildetester": "eingebildet",
    "eingebildetestes": "eingebildet",
    "eingeblasen": "einblasen",
    "eingeblasene": "eingeblasen",
    "eingeblasenem": "eingeblasen",
    "eingeblasenen": "eingeblasen",
    "eingeblasener": "eingeblasen",
    "eingeblasenes": "eingeblasen",
    "eingeblendet": "einblenden",
    "eingeblendete": "eingeblendet",
    "eingeblendetem": "eingeblendet",
    "eingeblendeten": "eingeblendet",
    "eingeblendeter": "eingeblendet",
    "eingeblendetes": "eingeblendet",
    "eingebleut": "einbleuen",
    "eingebleute": "eingebleut",
    "eingebleutem": "eingebleut",
    "eingebleuten": "eingebleut",
    "eingebleuter": "eingebleut",
    "eingebleutere": "eingebleut",
    "eingebleuterem": "eingebleut",
    "eingebleuteren": "eingebleut",
    "eingebleuterer": "eingebleut",
    "eingebleuteres": "eingebleut",
    "eingebleutes": "eingebleut",
    "eingebleuteste": "eingebleut",
    "eingebleutestem": "eingebleut",
    "eingebleutesten": "eingebleut",
    "eingebleutester": "eingebleut",
    "eingebleutestes": "eingebleut",
    "eingebläut": "einbläuen",
    "eingebläute": "eingebläut",
    "eingebläutem": "eingebläut",
    "eingebläuten": "eingebläut",
    "eingebläuter": "eingebläut",
    "eingebläutere": "eingebläut",
    "eingebläuterem": "eingebläut",
    "eingebläuteren": "eingebläut",
    "eingebläuterer": "eingebläut",
    "eingebläuteres": "eingebläut",
    "eingebläutes": "eingebläut",
    "eingebläuteste": "eingebläut",
    "eingebläutestem": "eingebläut",
    "eingebläutesten": "eingebläut",
    "eingebläutester": "eingebläut",
    "eingebläutestes": "eingebläut",
    "eingebogen": "einbiegen",
    "eingebogene": "eingebogen",
    "eingebogenem": "eingebogen",
    "eingebogenen": "eingebogen",
    "eingebogener": "eingebogen",
    "eingebogenes": "eingebogen",
    "eingebootet": "einbooten",
    "eingebootete": "eingebootet",
    "eingebootetem": "eingebootet",
    "eingebooteten": "eingebootet",
    "eingebooteter": "eingebootet",
    "eingebootetes": "eingebootet",
    "eingebracht": "einbringen",
    "eingebrachte": "eingebracht",
    "eingebrachtem": "eingebracht",
    "eingebrachten": "eingebracht",
    "eingebrachter": "eingebracht",
    "eingebrachtes": "eingebracht",
    "eingebrannt": "einbrennen",
    "eingebrannte": "eingebrannt",
    "eingebranntem": "eingebrannt",
    "eingebrannten": "eingebrannt",
    "eingebrannter": "eingebrannt",
    "eingebranntere": "eingebrannt",
    "eingebrannterem": "eingebrannt",
    "eingebrannteren": "eingebrannt",
    "eingebrannterer": "eingebrannt",
    "eingebrannteres": "eingebrannt",
    "eingebranntes": "eingebrannt",
    "eingebrannteste": "eingebrannt",
    "eingebranntestem": "eingebrannt",
    "eingebranntesten": "eingebrannt",
    "eingebranntester": "eingebrannt",
    "eingebranntestes": "eingebrannt",
    "eingebrochen": "einbrechen",
    "eingebrochene": "eingebrochen",
    "eingebrochenem": "eingebrochen",
    "eingebrochenen": "eingebrochen",
    "eingebrochener": "eingebrochen",
    "eingebrochenes": "eingebrochen",
    "eingebt": "eingeben",
    "eingebuchtet": "einbuchten",
    "eingebuchtete": "eingebuchtet",
    "eingebuchtetem": "eingebuchtet",
    "eingebuchteten": "eingebuchtet",
    "eingebuchteter": "eingebuchtet",
    "eingebuchtetes": "eingebuchtet",
    "eingebuddelt": "einbuddeln",
    "eingebuddelte": "eingebuddelt",
    "eingebuddeltem": "eingebuddelt",
    "eingebuddelten": "eingebuddelt",
    "eingebuddelter": "eingebuddelt",
    "eingebuddeltes": "eingebuddelt",
    "eingebunden": "einbinden",
    "eingebundene": "eingebunden",
    "eingebundenem": "eingebunden",
    "eingebundenen": "eingebunden",
    "eingebundener": "eingebunden",
    "eingebundenes": "eingebunden",
    "eingebunkert": "einbunkern",
    "eingebunkerte": "eingebunkert",
    "eingebunkertem": "eingebunkert",
    "eingebunkerten": "eingebunkert",
    "eingebunkerter": "eingebunkert",
    "eingebunkertes": "eingebunkert",
    "eingebürgert": "einbürgern",
    "eingebürgerte": "eingebürgert",
    "eingebürgertem": "eingebürgert",
    "eingebürgerten": "eingebürgert",
    "eingebürgerter": "eingebürgert",
    "eingebürgertes": "eingebürgert",
    "eingebüßt": "einbüßen",
    "eingebüßte": "eingebüßt",
    "eingebüßtem": "eingebüßt",
    "eingebüßten": "eingebüßt",
    "eingebüßter": "eingebüßt",
    "eingebüßtes": "eingebüßt",
    "eingecheckt": "einchecken",
    "eingecheckte": "eingecheckt",
    "eingechecktem": "eingecheckt",
    "eingecheckten": "eingecheckt",
    "eingecheckter": "eingecheckt",
    "eingechecktes": "eingecheckt",
    "eingecremt": "eincremen",
    "eingecremte": "eingecremt",
    "eingecremtem": "eingecremt",
    "eingecremten": "eingecremt",
    "eingecremter": "eingecremt",
    "eingecremtes": "eingecremt",
    "eingedampft": "eindampfen",
    "eingedampfte": "eingedampft",
    "eingedampftem": "eingedampft",
    "eingedampften": "eingedampft",
    "eingedampfter": "eingedampft",
    "eingedampftes": "eingedampft",
    "eingedeicht": "eindeichen",
    "eingedeichte": "eingedeicht",
    "eingedeichtem": "eingedeicht",
    "eingedeichten": "eingedeicht",
    "eingedeichter": "eingedeicht",
    "eingedeichtes": "eingedeicht",
    "eingedellt": "eindellen",
    "eingedellte": "eingedellt",
    "eingedelltem": "eingedellt",
    "eingedellten": "eingedellt",
    "eingedellter": "eingedellt",
    "eingedelltere": "eingedellt",
    "eingedellterem": "eingedellt",
    "eingedellteren": "eingedellt",
    "eingedellterer": "eingedellt",
    "eingedellteres": "eingedellt",
    "eingedelltes": "eingedellt",
    "eingedellteste": "eingedellt",
    "eingedelltestem": "eingedellt",
    "eingedelltesten": "eingedellt",
    "eingedelltester": "eingedellt",
    "eingedelltestes": "eingedellt",
    "eingedeutscht": "eindeutschen",
    "eingedeutschte": "eingedeutscht",
    "eingedeutschtem": "eingedeutscht",
    "eingedeutschten": "eingedeutscht",
    "eingedeutschter": "eingedeutscht",
    "eingedeutschtes": "eingedeutscht",
    "eingedost": "eindosen",
    "eingedoste": "eingedost",
    "eingedostem": "eingedost",
    "eingedosten": "eingedost",
    "eingedoster": "eingedost",
    "eingedostes": "eingedost",
    "eingedreht": "eindrehen",
    "eingedrehte": "eingedreht",
    "eingedrehtem": "eingedreht",
    "eingedrehten": "eingedreht",
    "eingedrehter": "eingedreht",
    "eingedrehtes": "eingedreht",
    "eingedrillt": "eindrillen",
    "eingedrillte": "eingedrillt",
    "eingedrilltem": "eingedrillt",
    "eingedrillten": "eingedrillt",
    "eingedrillter": "eingedrillt",
    "eingedrilltere": "eingedrillt",
    "eingedrillterem": "eingedrillt",
    "eingedrillteren": "eingedrillt",
    "eingedrillterer": "eingedrillt",
    "eingedrillteres": "eingedrillt",
    "eingedrilltes": "eingedrillt",
    "eingedrillteste": "eingedrillt",
    "eingedrilltestem": "eingedrillt",
    "eingedrilltesten": "eingedrillt",
    "eingedrilltester": "eingedrillt",
    "eingedrilltestes": "eingedrillt",
    "eingedrungen": "eindringen",
    "eingedrungene": "eingedrungen",
    "eingedrungenem": "eingedrungen",
    "eingedrungenen": "eingedrungen",
    "eingedrungener": "eingedrungen",
    "eingedrungenere": "eingedrungen",
    "eingedrungenerem": "eingedrungen",
    "eingedrungeneren": "eingedrungen",
    "eingedrungenerer": "eingedrungen",
    "eingedrungeneres": "eingedrungen",
    "eingedrungenes": "eingedrungen",
    "eingedrungenste": "eingedrungen",
    "eingedrungenstem": "eingedrungen",
    "eingedrungensten": "eingedrungen",
    "eingedrungenster": "eingedrungen",
    "eingedrungenstes": "eingedrungen",
    "eingedrückt": "eindrücken",
    "eingedrückte": "eingedrückt",
    "eingedrücktem": "eingedrückt",
    "eingedrückten": "eingedrückt",
    "eingedrückter": "eingedrückt",
    "eingedrücktere": "eingedrückt",
    "eingedrückterem": "eingedrückt",
    "eingedrückteren": "eingedrückt",
    "eingedrückterer": "eingedrückt",
    "eingedrückteres": "eingedrückt",
    "eingedrücktes": "eingedrückt",
    "eingedrückteste": "eingedrückt",
    "eingedrücktestem": "eingedrückt",
    "eingedrücktesten": "eingedrückt",
    "eingedrücktester": "eingedrückt",
    "eingedrücktestes": "eingedrückt",
    "eingedämmt": "eindämmen",
    "eingedämmte": "eingedämmt",
    "eingedämmtem": "eingedämmt",
    "eingedämmten": "eingedämmt",
    "eingedämmter": "eingedämmt",
    "eingedämmtere": "eingedämmt",
    "eingedämmterem": "eingedämmt",
    "eingedämmteren": "eingedämmt",
    "eingedämmterer": "eingedämmt",
    "eingedämmteres": "eingedämmt",
    "eingedämmtes": "eingedämmt",
    "eingedämmteste": "eingedämmt",
    "eingedämmtestem": "eingedämmt",
    "eingedämmtesten": "eingedämmt",
    "eingedämmtester": "eingedämmt",
    "eingedämmtestes": "eingedämmt",
    "eingeebnet": "einebnen",
    "eingeebnete": "eingeebnet",
    "eingeebnetem": "eingeebnet",
    "eingeebneten": "eingeebnet",
    "eingeebneter": "eingeebnet",
    "eingeebnetere": "eingeebnet",
    "eingeebneterem": "eingeebnet",
    "eingeebneteren": "eingeebnet",
    "eingeebneterer": "eingeebnet",
    "eingeebneteres": "eingeebnet",
    "eingeebnetes": "eingeebnet",
    "eingeebneteste": "eingeebnet",
    "eingeebnetestem": "eingeebnet",
    "eingeebnetesten": "eingeebnet",
    "eingeebnetester": "eingeebnet",
    "eingeebnetestes": "eingeebnet",
    "eingeengt": "einengen",
    "eingeengte": "eingeengt",
    "eingeengtem": "eingeengt",
    "eingeengten": "eingeengt",
    "eingeengter": "eingeengt",
    "eingeengtere": "eingeengt",
    "eingeengterem": "eingeengt",
    "eingeengteren": "eingeengt",
    "eingeengterer": "eingeengt",
    "eingeengteres": "eingeengt",
    "eingeengtes": "eingeengt",
    "eingeengteste": "eingeengt",
    "eingeengtestem": "eingeengt",
    "eingeengtesten": "eingeengt",
    "eingeengtester": "eingeengt",
    "eingeengtestes": "eingeengt",
    "eingeerntet": "einernten",
    "eingeerntete": "eingeerntet",
    "eingeerntetem": "eingeerntet",
    "eingeernteten": "eingeerntet",
    "eingeernteter": "eingeerntet",
    "eingeerntetes": "eingeerntet",
    "eingefahren": "einfahren",
    "eingefahrene": "eingefahren",
    "eingefahrenem": "eingefahren",
    "eingefahrenen": "eingefahren",
    "eingefahrener": "eingefahren",
    "eingefahrenes": "eingefahren",
    "eingefallen": "einfallen",
    "eingefallene": "eingefallen",
    "eingefallenem": "eingefallen",
    "eingefallenen": "eingefallen",
    "eingefallener": "eingefallen",
    "eingefallenes": "eingefallen",
    "eingefangen": "einfangen",
    "eingefangene": "eingefangen",
    "eingefangenem": "eingefangen",
    "eingefangenen": "eingefangen",
    "eingefangener": "eingefangen",
    "eingefangenes": "eingefangen",
    "eingefaßt": "einfassen",
    "eingefaßte": "eingefaßt",
    "eingefaßtem": "eingefaßt",
    "eingefaßten": "eingefaßt",
    "eingefaßter": "eingefaßt",
    "eingefaßtes": "eingefaßt",
    "eingefettet": "einfetten",
    "eingefettete": "eingefettet",
    "eingefettetem": "eingefettet",
    "eingefetteten": "eingefettet",
    "eingefetteter": "eingefettet",
    "eingefettetere": "eingefettet",
    "eingefetteterem": "eingefettet",
    "eingefetteteren": "eingefettet",
    "eingefetteterer": "eingefettet",
    "eingefetteteres": "eingefettet",
    "eingefettetes": "eingefettet",
    "eingefetteteste": "eingefettet",
    "eingefettetestem": "eingefettet",
    "eingefettetesten": "eingefettet",
    "eingefettetester": "eingefettet",
    "eingefettetestes": "eingefettet",
    "eingefeuert": "einfeuern",
    "eingefeuerte": "eingefeuert",
    "eingefeuertem": "eingefeuert",
    "eingefeuerten": "eingefeuert",
    "eingefeuerter": "eingefeuert",
    "eingefeuertes": "eingefeuert",
    "eingefleischte": "eingefleischt",
    "eingefleischtem": "eingefleischt",
    "eingefleischten": "eingefleischt",
    "eingefleischter": "eingefleischt",
    "eingefleischtere": "eingefleischt",
    "eingefleischterem": "eingefleischt",
    "eingefleischteren": "eingefleischt",
    "eingefleischterer": "eingefleischt",
    "eingefleischteres": "eingefleischt",
    "eingefleischtes": "eingefleischt",
    "eingefleischteste": "eingefleischt",
    "eingefleischtestem": "eingefleischt",
    "eingefleischtesten": "eingefleischt",
    "eingefleischtester": "eingefleischt",
    "eingefleischtestes": "eingefleischt",
    "eingeflippt": "einflippen",
    "eingeflippte": "eingeflippt",
    "eingeflipptem": "eingeflippt",
    "eingeflippten": "eingeflippt",
    "eingeflippter": "eingeflippt",
    "eingeflipptes": "eingeflippt",
    "eingeflochten": "einflechten",
    "eingeflochtene": "eingeflochten",
    "eingeflochtenem": "eingeflochten",
    "eingeflochtenen": "eingeflochten",
    "eingeflochtener": "eingeflochten",
    "eingeflochtenere": "eingeflochten",
    "eingeflochtenerem": "eingeflochten",
    "eingeflochteneren": "eingeflochten",
    "eingeflochtenerer": "eingeflochten",
    "eingeflochteneres": "eingeflochten",
    "eingeflochtenes": "eingeflochten",
    "eingeflochtenste": "eingeflochten",
    "eingeflochtenstem": "eingeflochten",
    "eingeflochtensten": "eingeflochten",
    "eingeflochtenster": "eingeflochten",
    "eingeflochtenstes": "eingeflochten",
    "eingeflogen": "einfliegen",
    "eingeflogene": "eingeflogen",
    "eingeflogenem": "eingeflogen",
    "eingeflogenen": "eingeflogen",
    "eingeflogener": "eingeflogen",
    "eingeflogenes": "eingeflogen",
    "eingeflossen": "einfließen",
    "eingeflossene": "eingeflossen",
    "eingeflossenem": "eingeflossen",
    "eingeflossenen": "eingeflossen",
    "eingeflossener": "eingeflossen",
    "eingeflossenes": "eingeflossen",
    "eingeflößt": "einflößen",
    "eingeflößte": "eingeflößt",
    "eingeflößtem": "eingeflößt",
    "eingeflößten": "eingeflößt",
    "eingeflößter": "eingeflößt",
    "eingeflößtes": "eingeflößt",
    "eingeflüstert": "einflüstern",
    "eingeflüsterte": "eingeflüstert",
    "eingeflüstertem": "eingeflüstert",
    "eingeflüsterten": "eingeflüstert",
    "eingeflüsterter": "eingeflüstert",
    "eingeflüstertes": "eingeflüstert",
    "eingefordert": "einfordern",
    "eingeforderte": "eingefordert",
    "eingefordertem": "eingefordert",
    "eingeforderten": "eingefordert",
    "eingeforderter": "eingefordert",
    "eingefordertes": "eingefordert",
    "eingefressen": "einfressen",
    "eingefressene": "eingefressen",
    "eingefressenem": "eingefressen",
    "eingefressenen": "eingefressen",
    "eingefressener": "eingefressen",
    "eingefressenes": "eingefressen",
    "eingefroren": "einfrieren",
    "eingefrorene": "eingefroren",
    "eingefrorenem": "eingefroren",
    "eingefrorenen": "eingefroren",
    "eingefrorener": "eingefroren",
    "eingefrorenes": "eingefroren",
    "eingefunden": "einfinden",
    "eingefundene": "eingefunden",
    "eingefundenem": "eingefunden",
    "eingefundenen": "eingefunden",
    "eingefundener": "eingefunden",
    "eingefundenes": "eingefunden",
    "eingefädelt": "einfädeln",
    "eingefädelte": "eingefädelt",
    "eingefädeltem": "eingefädelt",
    "eingefädelten": "eingefädelt",
    "eingefädelter": "eingefädelt",
    "eingefädeltes": "eingefädelt",
    "eingefärbt": "einfärben",
    "eingefärbte": "eingefärbt",
    "eingefärbtem": "eingefärbt",
    "eingefärbten": "eingefärbt",
    "eingefärbter": "eingefärbt",
    "eingefärbtere": "eingefärbt",
    "eingefärbterem": "eingefärbt",
    "eingefärbteren": "eingefärbt",
    "eingefärbterer": "eingefärbt",
    "eingefärbteres": "eingefärbt",
    "eingefärbtes": "eingefärbt",
    "eingefärbteste": "eingefärbt",
    "eingefärbtestem": "eingefärbt",
    "eingefärbtesten": "eingefärbt",
    "eingefärbtester": "eingefärbt",
    "eingefärbtestes": "eingefärbt",
    "eingefügt": "einfügen",
    "eingefügte": "eingefügt",
    "eingefügtem": "eingefügt",
    "eingefügten": "eingefügt",
    "eingefügter": "eingefügt",
    "eingefügtes": "eingefügt",
    "eingefühlt": "einfühlen",
    "eingefühlte": "eingefühlt",
    "eingefühltem": "eingefühlt",
    "eingefühlten": "eingefühlt",
    "eingefühlter": "eingefühlt",
    "eingefühltere": "eingefühlt",
    "eingefühlterem": "eingefühlt",
    "eingefühlteren": "eingefühlt",
    "eingefühlterer": "eingefühlt",
    "eingefühlteres": "eingefühlt",
    "eingefühltes": "eingefühlt",
    "eingefühlteste": "eingefühlt",
    "eingefühltestem": "eingefühlt",
    "eingefühltesten": "eingefühlt",
    "eingefühltester": "eingefühlt",
    "eingefühltestes": "eingefühlt",
    "eingeführt": "einführen",
    "eingeführte": "eingeführt",
    "eingeführtem": "eingeführt",
    "eingeführten": "eingeführt",
    "eingeführter": "eingeführt",
    "eingeführtes": "eingeführt",
    "eingefüllt": "einfüllen",
    "eingefüllte": "eingefüllt",
    "eingefülltem": "eingefüllt",
    "eingefüllten": "eingefüllt",
    "eingefüllter": "eingefüllt",
    "eingefülltes": "eingefüllt",
    "eingegangen": "eingehen",
    "eingegangene": "eingegangen",
    "eingegangenem": "eingegangen",
    "eingegangenen": "eingegangen",
    "eingegangener": "eingegangen",
    "eingegangenes": "eingegangen",
    "eingegeben": "eingeben",
    "eingegebene": "eingegeben",
    "eingegebenem": "eingegeben",
    "eingegebenen": "eingegeben",
    "eingegebener": "eingegeben",
    "eingegebenes": "eingegeben",
    "eingegipst": "eingipsen",
    "eingegipste": "eingegipst",
    "eingegipstem": "eingegipst",
    "eingegipsten": "eingegipst",
    "eingegipster": "eingegipst",
    "eingegipstes": "eingegipst",
    "eingegittert": "eingittern",
    "eingegitterte": "eingegittert",
    "eingegittertem": "eingegittert",
    "eingegitterten": "eingegittert",
    "eingegitterter": "eingegittert",
    "eingegittertes": "eingegittert",
    "eingeglast": "einglasen",
    "eingeglaste": "eingeglast",
    "eingeglastem": "eingeglast",
    "eingeglasten": "eingeglast",
    "eingeglaster": "eingeglast",
    "eingeglastes": "eingeglast",
    "eingegleist": "eingleisen",
    "eingegleiste": "eingegleist",
    "eingegleistem": "eingegleist",
    "eingegleisten": "eingegleist",
    "eingegleister": "eingegleist",
    "eingegleistes": "eingegleist",
    "eingegliedert": "eingliedern",
    "eingegliederte": "eingegliedert",
    "eingegliedertem": "eingegliedert",
    "eingegliederten": "eingegliedert",
    "eingegliederter": "eingegliedert",
    "eingegliedertes": "eingegliedert",
    "eingegossen": "eingießen",
    "eingegossene": "eingegossen",
    "eingegossenem": "eingegossen",
    "eingegossenen": "eingegossen",
    "eingegossener": "eingegossen",
    "eingegossenes": "eingegossen",
    "eingegraben": "eingraben",
    "eingegrabene": "eingegraben",
    "eingegrabenem": "eingegraben",
    "eingegrabenen": "eingegraben",
    "eingegrabener": "eingegraben",
    "eingegrabenes": "eingegraben",
    "eingegrenzt": "eingrenzen",
    "eingegrenzte": "eingegrenzt",
    "eingegrenztem": "eingegrenzt",
    "eingegrenzten": "eingegrenzt",
    "eingegrenzter": "eingegrenzt",
    "eingegrenztes": "eingegrenzt",
    "eingegriffen": "eingreifen",
    "eingegriffene": "eingegriffen",
    "eingegriffenem": "eingegriffen",
    "eingegriffenen": "eingegriffen",
    "eingegriffener": "eingegriffen",
    "eingegriffenes": "eingegriffen",
    "eingehakt": "einhaken",
    "eingehakte": "eingehakt",
    "eingehaktem": "eingehakt",
    "eingehakten": "eingehakt",
    "eingehakter": "eingehakt",
    "eingehaktes": "eingehakt",
    "eingehalten": "einhalten",
    "eingehaltene": "eingehalten",
    "eingehaltenem": "eingehalten",
    "eingehaltenen": "eingehalten",
    "eingehaltener": "eingehalten",
    "eingehaltenes": "eingehalten",
    "eingehandelt": "einhandeln",
    "eingehandelte": "eingehandelt",
    "eingehandeltem": "eingehandelt",
    "eingehandelten": "eingehandelt",
    "eingehandelter": "eingehandelt",
    "eingehandeltes": "eingehandelt",
    "eingehangen": "einhängen",
    "eingehangene": "eingehangen",
    "eingehangenem": "eingehangen",
    "eingehangenen": "eingehangen",
    "eingehangener": "eingehangen",
    "eingehangenes": "eingehangen",
    "eingehauen": "einhauen",
    "eingehauene": "eingehauen",
    "eingehauenem": "eingehauen",
    "eingehauenen": "eingehauen",
    "eingehauener": "eingehauen",
    "eingehauenes": "eingehauen",
    "eingehe": "eingehen",
    "eingeheftet": "einheften",
    "eingeheftete": "eingeheftet",
    "eingeheftetem": "eingeheftet",
    "eingehefteten": "eingeheftet",
    "eingehefteter": "eingeheftet",
    "eingeheftetes": "eingeheftet",
    "eingeheilt": "einheilen",
    "eingeheilte": "eingeheilt",
    "eingeheiltem": "eingeheilt",
    "eingeheilten": "eingeheilt",
    "eingeheilter": "eingeheilt",
    "eingeheiltes": "eingeheilt",
    "eingeheimst": "einheimsen",
    "eingeheimste": "eingeheimst",
    "eingeheimstem": "eingeheimst",
    "eingeheimsten": "eingeheimst",
    "eingeheimster": "eingeheimst",
    "eingeheimstere": "eingeheimst",
    "eingeheimsterem": "eingeheimst",
    "eingeheimsteren": "eingeheimst",
    "eingeheimsterer": "eingeheimst",
    "eingeheimsteres": "eingeheimst",
    "eingeheimstes": "eingeheimst",
    "eingeheimsteste": "eingeheimst",
    "eingeheimstestem": "eingeheimst",
    "eingeheimstesten": "eingeheimst",
    "eingeheimstester": "eingeheimst",
    "eingeheimstestes": "eingeheimst",
    "eingeheiratet": "einheiraten",
    "eingeheiratete": "eingeheiratet",
    "eingeheiratetem": "eingeheiratet",
    "eingeheirateten": "eingeheiratet",
    "eingeheirateter": "eingeheiratet",
    "eingeheiratetes": "eingeheiratet",
    "eingeheizt": "einheizen",
    "eingeheizte": "eingeheizt",
    "eingeheiztem": "eingeheizt",
    "eingeheizten": "eingeheizt",
    "eingeheizter": "eingeheizt",
    "eingeheiztere": "eingeheizt",
    "eingeheizterem": "eingeheizt",
    "eingeheizteren": "eingeheizt",
    "eingeheizterer": "eingeheizt",
    "eingeheizteres": "eingeheizt",
    "eingeheiztes": "eingeheizt",
    "eingeheizteste": "eingeheizt",
    "eingeheiztestem": "eingeheizt",
    "eingeheiztesten": "eingeheizt",
    "eingeheiztester": "eingeheizt",
    "eingeheiztestes": "eingeheizt",
    "eingehend": "eingehen",
    "eingehende": "eingehend",
    "eingehendem": "eingehend",
    "eingehenden": "eingehend",
    "eingehender": "eingehend",
    "eingehendes": "eingehend",
    "eingehest": "eingehen",
    "eingehet": "eingehen",
    "eingehievt": "einhieven",
    "eingehievte": "eingehievt",
    "eingehievtem": "eingehievt",
    "eingehievten": "eingehievt",
    "eingehievter": "eingehievt",
    "eingehievtes": "eingehievt",
    "eingehoben": "einheben",
    "eingehobene": "eingehoben",
    "eingehobenem": "eingehoben",
    "eingehobenen": "eingehoben",
    "eingehobener": "eingehoben",
    "eingehobenes": "eingehoben",
    "eingeholfen": "einhelfen",
    "eingeholfene": "eingeholfen",
    "eingeholfenem": "eingeholfen",
    "eingeholfenen": "eingeholfen",
    "eingeholfener": "eingeholfen",
    "eingeholfenes": "eingeholfen",
    "eingeholt": "einholen",
    "eingeholte": "eingeholt",
    "eingeholtem": "eingeholt",
    "eingeholten": "eingeholt",
    "eingeholter": "eingeholt",
    "eingeholtes": "eingeholt",
    "eingehst": "eingehen",
    "eingeht": "eingehen",
    "eingehändigt": "einhändigen",
    "eingehändigte": "eingehändigt",
    "eingehändigtem": "eingehändigt",
    "eingehändigten": "eingehändigt",
    "eingehändigter": "eingehändigt",
    "eingehändigtes": "eingehändigt",
    "eingehängt": "einhängen",
    "eingehängte": "eingehängt",
    "eingehängtem": "eingehängt",
    "eingehängten": "eingehängt",
    "eingehängter": "eingehängt",
    "eingehängtes": "eingehängt",
    "eingehüllt": "einhüllen",
    "eingehüllte": "eingehüllt",
    "eingehülltem": "eingehüllt",
    "eingehüllten": "eingehüllt",
    "eingehüllter": "eingehüllt",
    "eingehülltere": "eingehüllt",
    "eingehüllterem": "eingehüllt",
    "eingehüllteren": "eingehüllt",
    "eingehüllterer": "eingehüllt",
    "eingehüllteres": "eingehüllt",
    "eingehülltes": "eingehüllt",
    "eingehüllteste": "eingehüllt",
    "eingehülltestem": "eingehüllt",
    "eingehülltesten": "eingehüllt",
    "eingehülltester": "eingehüllt",
    "eingehülltestes": "eingehüllt",
    "eingehütet": "einhüten",
    "eingehütete": "eingehütet",
    "eingehütetem": "eingehütet",
    "eingehüteten": "eingehütet",
    "eingehüteter": "eingehütet",
    "eingehütetes": "eingehütet",
    "eingeigelt": "einigeln",
    "eingeigelte": "eingeigelt",
    "eingeigeltem": "eingeigelt",
    "eingeigelten": "eingeigelt",
    "eingeigelter": "eingeigelt",
    "eingeigeltere": "eingeigelt",
    "eingeigelterem": "eingeigelt",
    "eingeigelteren": "eingeigelt",
    "eingeigelterer": "eingeigelt",
    "eingeigelteres": "eingeigelt",
    "eingeigeltes": "eingeigelt",
    "eingeigelteste": "eingeigelt",
    "eingeigeltestem": "eingeigelt",
    "eingeigeltesten": "eingeigelt",
    "eingeigeltester": "eingeigelt",
    "eingeigeltestes": "eingeigelt",
    "eingeimpft": "einimpfen",
    "eingeimpfte": "eingeimpft",
    "eingeimpftem": "eingeimpft",
    "eingeimpften": "eingeimpft",
    "eingeimpfter": "eingeimpft",
    "eingeimpftes": "eingeimpft",
    "eingejagt": "einjagen",
    "eingejagte": "eingejagt",
    "eingejagtem": "eingejagt",
    "eingejagten": "eingejagt",
    "eingejagter": "eingejagt",
    "eingejagtes": "eingejagt",
    "eingekachelt": "einkacheln",
    "eingekachelte": "eingekachelt",
    "eingekacheltem": "eingekachelt",
    "eingekachelten": "eingekachelt",
    "eingekachelter": "eingekachelt",
    "eingekacheltes": "eingekachelt",
    "eingekapselt": "einkapseln",
    "eingekapselte": "eingekapselt",
    "eingekapseltem": "eingekapselt",
    "eingekapselten": "eingekapselt",
    "eingekapselter": "eingekapselt",
    "eingekapseltere": "eingekapselt",
    "eingekapselterem": "eingekapselt",
    "eingekapselteren": "eingekapselt",
    "eingekapselterer": "eingekapselt",
    "eingekapselteres": "eingekapselt",
    "eingekapseltes": "eingekapselt",
    "eingekapselteste": "eingekapselt",
    "eingekapseltestem": "eingekapselt",
    "eingekapseltesten": "eingekapselt",
    "eingekapseltester": "eingekapselt",
    "eingekapseltestes": "eingekapselt",
    "eingekauft": "einkaufen",
    "eingekaufte": "eingekauft",
    "eingekauftem": "eingekauft",
    "eingekauften": "eingekauft",
    "eingekaufter": "eingekauft",
    "eingekauftes": "eingekauft",
    "eingekehrt": "einkehren",
    "eingekehrte": "eingekehrt",
    "eingekehrtem": "eingekehrt",
    "eingekehrten": "eingekehrt",
    "eingekehrter": "eingekehrt",
    "eingekehrtes": "eingekehrt",
    "eingekeilt": "einkeilen",
    "eingekeilte": "eingekeilt",
    "eingekeiltem": "eingekeilt",
    "eingekeilten": "eingekeilt",
    "eingekeilter": "eingekeilt",
    "eingekeiltere": "eingekeilt",
    "eingekeilterem": "eingekeilt",
    "eingekeilteren": "eingekeilt",
    "eingekeilterer": "eingekeilt",
    "eingekeilteres": "eingekeilt",
    "eingekeiltes": "eingekeilt",
    "eingekeilteste": "eingekeilt",
    "eingekeiltestem": "eingekeilt",
    "eingekeiltesten": "eingekeilt",
    "eingekeiltester": "eingekeilt",
    "eingekeiltestes": "eingekeilt",
    "eingekellert": "einkellern",
    "eingekellerte": "eingekellert",
    "eingekellertem": "eingekellert",
    "eingekellerten": "eingekellert",
    "eingekellerter": "eingekellert",
    "eingekellertes": "eingekellert",
    "eingekerbt": "einkerben",
    "eingekerbte": "eingekerbt",
    "eingekerbtem": "eingekerbt",
    "eingekerbten": "eingekerbt",
    "eingekerbter": "eingekerbt",
    "eingekerbtes": "eingekerbt",
    "eingekerkert": "einkerkern",
    "eingekerkerte": "eingekerkert",
    "eingekerkertem": "eingekerkert",
    "eingekerkerten": "eingekerkert",
    "eingekerkerter": "eingekerkert",
    "eingekerkertes": "eingekerkert",
    "eingekesselt": "einkesseln",
    "eingekesselte": "eingekesselt",
    "eingekesseltem": "eingekesselt",
    "eingekesselten": "eingekesselt",
    "eingekesselter": "eingekesselt",
    "eingekesseltere": "eingekesselt",
    "eingekesselterem": "eingekesselt",
    "eingekesselteren": "eingekesselt",
    "eingekesselterer": "eingekesselt",
    "eingekesselteres": "eingekesselt",
    "eingekesseltes": "eingekesselt",
    "eingekesselteste": "eingekesselt",
    "eingekesseltestem": "eingekesselt",
    "eingekesseltesten": "eingekesselt",
    "eingekesseltester": "eingekesselt",
    "eingekesseltestes": "eingekesselt",
    "eingekittet": "einkitten",
    "eingekittete": "eingekittet",
    "eingekittetem": "eingekittet",
    "eingekitteten": "eingekittet",
    "eingekitteter": "eingekittet",
    "eingekittetes": "eingekittet",
    "eingeklagt": "einklagen",
    "eingeklagte": "eingeklagt",
    "eingeklagtem": "eingeklagt",
    "eingeklagten": "eingeklagt",
    "eingeklagter": "eingeklagt",
    "eingeklagtes": "eingeklagt",
    "eingeklammert": "einklammern",
    "eingeklammerte": "eingeklammert",
    "eingeklammertem": "eingeklammert",
    "eingeklammerten": "eingeklammert",
    "eingeklammerter": "eingeklammert",
    "eingeklammertes": "eingeklammert",
    "eingeklebt": "einkleben",
    "eingeklebte": "eingeklebt",
    "eingeklebtem": "eingeklebt",
    "eingeklebten": "eingeklebt",
    "eingeklebter": "eingeklebt",
    "eingeklebtes": "eingeklebt",
    "eingekleidet": "einkleiden",
    "eingekleidete": "eingekleidet",
    "eingekleidetem": "eingekleidet",
    "eingekleideten": "eingekleidet",
    "eingekleideter": "eingekleidet",
    "eingekleidetere": "eingekleidet",
    "eingekleideterem": "eingekleidet",
    "eingekleideteren": "eingekleidet",
    "eingekleideterer": "eingekleidet",
    "eingekleideteres": "eingekleidet",
    "eingekleidetes": "eingekleidet",
    "eingekleideteste": "eingekleidet",
    "eingekleidetestem": "eingekleidet",
    "eingekleidetesten": "eingekleidet",
    "eingekleidetester": "eingekleidet",
    "eingekleidetestes": "eingekleidet",
    "eingeklemmt": "einklemmen",
    "eingeklemmte": "eingeklemmt",
    "eingeklemmtem": "eingeklemmt",
    "eingeklemmten": "eingeklemmt",
    "eingeklemmter": "eingeklemmt",
    "eingeklemmtere": "eingeklemmt",
    "eingeklemmterem": "eingeklemmt",
    "eingeklemmteren": "eingeklemmt",
    "eingeklemmterer": "eingeklemmt",
    "eingeklemmteres": "eingeklemmt",
    "eingeklemmtes": "eingeklemmt",
    "eingeklemmteste": "eingeklemmt",
    "eingeklemmtestem": "eingeklemmt",
    "eingeklemmtesten": "eingeklemmt",
    "eingeklemmtester": "eingeklemmt",
    "eingeklemmtestes": "eingeklemmt",
    "eingeklinkt": "einklinken",
    "eingeklinkte": "eingeklinkt",
    "eingeklinktem": "eingeklinkt",
    "eingeklinkten": "eingeklinkt",
    "eingeklinkter": "eingeklinkt",
    "eingeklinktes": "eingeklinkt",
    "eingeklopft": "einklopfen",
    "eingeklopfte": "eingeklopft",
    "eingeklopftem": "eingeklopft",
    "eingeklopften": "eingeklopft",
    "eingeklopfter": "eingeklopft",
    "eingeklopftes": "eingeklopft",
    "eingeknickt": "einknicken",
    "eingeknickte": "eingeknickt",
    "eingeknicktem": "eingeknickt",
    "eingeknickten": "eingeknickt",
    "eingeknickter": "eingeknickt",
    "eingeknicktes": "eingeknickt",
    "eingekniffen": "einkneifen",
    "eingekniffene": "eingekniffen",
    "eingekniffenem": "eingekniffen",
    "eingekniffenen": "eingekniffen",
    "eingekniffener": "eingekniffen",
    "eingekniffenere": "eingekniffen",
    "eingekniffenerem": "eingekniffen",
    "eingekniffeneren": "eingekniffen",
    "eingekniffenerer": "eingekniffen",
    "eingekniffeneres": "eingekniffen",
    "eingekniffenes": "eingekniffen",
    "eingekniffenste": "eingekniffen",
    "eingekniffenstem": "eingekniffen",
    "eingekniffensten": "eingekniffen",
    "eingekniffenster": "eingekniffen",
    "eingekniffenstes": "eingekniffen",
    "eingeknotet": "einknoten",
    "eingeknotete": "eingeknotet",
    "eingeknotetem": "eingeknotet",
    "eingeknoteten": "eingeknotet",
    "eingeknoteter": "eingeknotet",
    "eingeknotetes": "eingeknotet",
    "eingeknöpft": "einknöpfen",
    "eingeknöpfte": "eingeknöpft",
    "eingeknöpftem": "eingeknöpft",
    "eingeknöpften": "eingeknöpft",
    "eingeknöpfter": "eingeknöpft",
    "eingeknöpftes": "eingeknöpft",
    "eingeknüpft": "einknüpfen",
    "eingeknüpfte": "eingeknüpft",
    "eingeknüpftem": "eingeknüpft",
    "eingeknüpften": "eingeknüpft",
    "eingeknüpfter": "eingeknüpft",
    "eingeknüpftes": "eingeknüpft",
    "eingekocht": "einkochen",
    "eingekochte": "eingekocht",
    "eingekochtem": "eingekocht",
    "eingekochten": "eingekocht",
    "eingekochter": "eingekocht",
    "eingekochtes": "eingekocht",
    "eingekratzt": "einkratzen",
    "eingekratzte": "eingekratzt",
    "eingekratztem": "eingekratzt",
    "eingekratzten": "eingekratzt",
    "eingekratzter": "eingekratzt",
    "eingekratztere": "eingekratzt",
    "eingekratzterem": "eingekratzt",
    "eingekratzteren": "eingekratzt",
    "eingekratzterer": "eingekratzt",
    "eingekratzteres": "eingekratzt",
    "eingekratztes": "eingekratzt",
    "eingekratzteste": "eingekratzt",
    "eingekratztestem": "eingekratzt",
    "eingekratztesten": "eingekratzt",
    "eingekratztester": "eingekratzt",
    "eingekratztestes": "eingekratzt",
    "eingekreist": "einkreisen",
    "eingekreiste": "eingekreist",
    "eingekreistem": "eingekreist",
    "eingekreisten": "eingekreist",
    "eingekreister": "eingekreist",
    "eingekreistes": "eingekreist",
    "eingekreuzt": "einkreuzen",
    "eingekreuzte": "eingekreuzt",
    "eingekreuztem": "eingekreuzt",
    "eingekreuzten": "eingekreuzt",
    "eingekreuzter": "eingekreuzt",
    "eingekreuztes": "eingekreuzt",
    "eingekriegt": "einkriegen",
    "eingekriegte": "eingekriegt",
    "eingekriegtem": "eingekriegt",
    "eingekriegten": "eingekriegt",
    "eingekriegter": "eingekriegt",
    "eingekriegtes": "eingekriegt",
    "eingeladen": "einladen",
    "eingeladene": "eingeladen",
    "eingeladenem": "eingeladen",
    "eingeladenen": "eingeladen",
    "eingeladener": "eingeladen",
    "eingeladenes": "eingeladen",
    "eingelagert": "einlagern",
    "eingelagerte": "eingelagert",
    "eingelagertem": "eingelagert",
    "eingelagerten": "eingelagert",
    "eingelagerter": "eingelagert",
    "eingelagertes": "eingelagert",
    "eingelangt": "einlangen",
    "eingelangte": "eingelangt",
    "eingelangtem": "eingelangt",
    "eingelangten": "eingelangt",
    "eingelangter": "eingelangt",
    "eingelangtes": "eingelangt",
    "eingelassen": "einlassen",
    "eingelassene": "eingelassen",
    "eingelassenem": "eingelassen",
    "eingelassenen": "eingelassen",
    "eingelassener": "eingelassen",
    "eingelassenes": "eingelassen",
    "eingelaufen": "einlaufen",
    "eingelaufene": "eingelaufen",
    "eingelaufenem": "eingelaufen",
    "eingelaufenen": "eingelaufen",
    "eingelaufener": "eingelaufen",
    "eingelaufenere": "eingelaufen",
    "eingelaufenerem": "eingelaufen",
    "eingelaufeneren": "eingelaufen",
    "eingelaufenerer": "eingelaufen",
    "eingelaufeneres": "eingelaufen",
    "eingelaufenes": "eingelaufen",
    "eingelaufenste": "eingelaufen",
    "eingelaufenstem": "eingelaufen",
    "eingelaufensten": "eingelaufen",
    "eingelaufenster": "eingelaufen",
    "eingelaufenstes": "eingelaufen",
    "eingelebt": "einleben",
    "eingelebte": "eingelebt",
    "eingelebtem": "eingelebt",
    "eingelebten": "eingelebt",
    "eingelebter": "eingelebt",
    "eingelebtere": "eingelebt",
    "eingelebterem": "eingelebt",
    "eingelebteren": "eingelebt",
    "eingelebterer": "eingelebt",
    "eingelebteres": "eingelebt",
    "eingelebtes": "eingelebt",
    "eingelebteste": "eingelebt",
    "eingelebtestem": "eingelebt",
    "eingelebtesten": "eingelebt",
    "eingelebtester": "eingelebt",
    "eingelebtestes": "eingelebt",
    "eingelegen": "einliegen",
    "eingelegene": "eingelegen",
    "eingelegenem": "eingelegen",
    "eingelegenen": "eingelegen",
    "eingelegener": "eingelegen",
    "eingelegenes": "eingelegen",
    "eingelegt": "einlegen",
    "eingelegte": "eingelegt",
    "eingelegtem": "eingelegt",
    "eingelegten": "eingelegt",
    "eingelegter": "eingelegt",
    "eingelegtes": "eingelegt",
    "eingeleitet": "einleiten",
    "eingeleitete": "eingeleitet",
    "eingeleitetem": "eingeleitet",
    "eingeleiteten": "eingeleitet",
    "eingeleiteter": "eingeleitet",
    "eingeleitetes": "eingeleitet",
    "eingelenkt": "einlenken",
    "eingelenkte": "eingelenkt",
    "eingelenktem": "eingelenkt",
    "eingelenkten": "eingelenkt",
    "eingelenkter": "eingelenkt",
    "eingelenktes": "eingelenkt",
    "eingelernt": "einlernen",
    "eingelernte": "eingelernt",
    "eingelerntem": "eingelernt",
    "eingelernten": "eingelernt",
    "eingelernter": "eingelernt",
    "eingelerntes": "eingelernt",
    "eingelesen": "einlesen",
    "eingelesene": "eingelesen",
    "eingelesenem": "eingelesen",
    "eingelesenen": "eingelesen",
    "eingelesener": "eingelesen",
    "eingelesenes": "eingelesen",
    "eingeleuchtet": "einleuchten",
    "eingeleuchtete": "eingeleuchtet",
    "eingeleuchtetem": "eingeleuchtet",
    "eingeleuchteten": "eingeleuchtet",
    "eingeleuchteter": "eingeleuchtet",
    "eingeleuchtetes": "eingeleuchtet",
    "eingeliefert": "einliefern",
    "eingelieferte": "eingeliefert",
    "eingeliefertem": "eingeliefert",
    "eingelieferten": "eingeliefert",
    "eingelieferter": "eingeliefert",
    "eingeliefertes": "eingeliefert",
    "eingelocht": "einlochen",
    "eingelochte": "eingelocht",
    "eingelochtem": "eingelocht",
    "eingelochten": "eingelocht",
    "eingelochter": "eingelocht",
    "eingelochtes": "eingelocht",
    "eingelullt": "einlullen",
    "eingelullte": "eingelullt",
    "eingelulltem": "eingelullt",
    "eingelullten": "eingelullt",
    "eingelullter": "eingelullt",
    "eingelulltere": "eingelullt",
    "eingelullterem": "eingelullt",
    "eingelullteren": "eingelullt",
    "eingelullterer": "eingelullt",
    "eingelullteres": "eingelullt",
    "eingelulltes": "eingelullt",
    "eingelullteste": "eingelullt",
    "eingelulltestem": "eingelullt",
    "eingelulltesten": "eingelullt",
    "eingelulltester": "eingelullt",
    "eingelulltestes": "eingelullt",
    "eingeläutet": "einläuten",
    "eingeläutete": "eingeläutet",
    "eingeläutetem": "eingeläutet",
    "eingeläuteten": "eingeläutet",
    "eingeläuteter": "eingeläutet",
    "eingeläutetes": "eingeläutet",
    "eingelöst": "einlösen",
    "eingelöste": "eingelöst",
    "eingelöstem": "eingelöst",
    "eingelösten": "eingelöst",
    "eingelöster": "eingelöst",
    "eingelöstes": "eingelöst",
    "eingelötet": "einlöten",
    "eingelötete": "eingelötet",
    "eingelötetem": "eingelötet",
    "eingelöteten": "eingelötet",
    "eingelöteter": "eingelötet",
    "eingelötetes": "eingelötet",
    "eingemacht": "einmachen",
    "eingemachte": "eingemacht",
    "eingemachtem": "eingemacht",
    "eingemachten": "eingemacht",
    "eingemachter": "eingemacht",
    "eingemachtes": "eingemacht",
    "eingemahnt": "einmahnen",
    "eingemahnte": "eingemahnt",
    "eingemahntem": "eingemahnt",
    "eingemahnten": "eingemahnt",
    "eingemahnter": "eingemahnt",
    "eingemahntes": "eingemahnt",
    "eingemauert": "einmauern",
    "eingemauerte": "eingemauert",
    "eingemauertem": "eingemauert",
    "eingemauerten": "eingemauert",
    "eingemauerter": "eingemauert",
    "eingemauertes": "eingemauert",
    "eingemeinde": "eingemeinden",
    "eingemeindend": "eingemeinden",
    "eingemeindende": "eingemeindend",
    "eingemeindendem": "eingemeindend",
    "eingemeindenden": "eingemeindend",
    "eingemeindender": "eingemeindend",
    "eingemeindendes": "eingemeindend",
    "eingemeindest": "eingemeinden",
    "eingemeindet": "eingemeinden",
    "eingemeindete": "eingemeinden",
    "eingemeindetem": "eingemeindet",
    "eingemeindeten": "eingemeinden",
    "eingemeindeter": "eingemeindet",
    "eingemeindetes": "eingemeindet",
    "eingemeindetest": "eingemeinden",
    "eingemeindetet": "eingemeinden",
    "eingemeißelt": "einmeißeln",
    "eingemeißelte": "eingemeißelt",
    "eingemeißeltem": "eingemeißelt",
    "eingemeißelten": "eingemeißelt",
    "eingemeißelter": "eingemeißelt",
    "eingemeißeltes": "eingemeißelt",
    "eingemengt": "einmengen",
    "eingemengte": "eingemengt",
    "eingemengtem": "eingemengt",
    "eingemengten": "eingemengt",
    "eingemengter": "eingemengt",
    "eingemengtes": "eingemengt",
    "eingemietet": "einmieten",
    "eingemietete": "eingemietet",
    "eingemietetem": "eingemietet",
    "eingemieteten": "eingemietet",
    "eingemieteter": "eingemietet",
    "eingemietetes": "eingemietet",
    "eingemischt": "einmischen",
    "eingemischte": "eingemischt",
    "eingemischtem": "eingemischt",
    "eingemischten": "eingemischt",
    "eingemischter": "eingemischt",
    "eingemischtes": "eingemischt",
    "eingemottet": "einmotten",
    "eingemottete": "eingemottet",
    "eingemottetem": "eingemottet",
    "eingemotteten": "eingemottet",
    "eingemotteter": "eingemottet",
    "eingemottetes": "eingemottet",
    "eingemümmelt": "einmümmeln",
    "eingemümmelte": "eingemümmelt",
    "eingemümmeltem": "eingemümmelt",
    "eingemümmelten": "eingemümmelt",
    "eingemümmelter": "eingemümmelt",
    "eingemümmeltere": "eingemümmelt",
    "eingemümmelterem": "eingemümmelt",
    "eingemümmelteren": "eingemümmelt",
    "eingemümmelterer": "eingemümmelt",
    "eingemümmelteres": "eingemümmelt",
    "eingemümmeltes": "eingemümmelt",
    "eingemümmelteste": "eingemümmelt",
    "eingemümmeltestem": "eingemümmelt",
    "eingemümmeltesten": "eingemümmelt",
    "eingemümmeltester": "eingemümmelt",
    "eingemümmeltestes": "eingemümmelt",
    "eingemündet": "einmünden",
    "eingemündete": "eingemündet",
    "eingemündetem": "eingemündet",
    "eingemündeten": "eingemündet",
    "eingemündeter": "eingemündet",
    "eingemündetes": "eingemündet",
    "eingenebelt": "einnebeln",
    "eingenebelte": "eingenebelt",
    "eingenebeltem": "eingenebelt",
    "eingenebelten": "eingenebelt",
    "eingenebelter": "eingenebelt",
    "eingenebeltere": "eingenebelt",
    "eingenebelterem": "eingenebelt",
    "eingenebelteren": "eingenebelt",
    "eingenebelterer": "eingenebelt",
    "eingenebelteres": "eingenebelt",
    "eingenebeltes": "eingenebelt",
    "eingenebelteste": "eingenebelt",
    "eingenebeltestem": "eingenebelt",
    "eingenebeltesten": "eingenebelt",
    "eingenebeltester": "eingenebelt",
    "eingenebeltestes": "eingenebelt",
    "eingenistet": "einnisten",
    "eingenistete": "eingenistet",
    "eingenistetem": "eingenistet",
    "eingenisteten": "eingenistet",
    "eingenisteter": "eingenistet",
    "eingenistetes": "eingenistet",
    "eingenommen": "einnehmen",
    "eingenommene": "eingenommen",
    "eingenommenem": "eingenommen",
    "eingenommenen": "eingenommen",
    "eingenommener": "eingenommen",
    "eingenommenes": "eingenommen",
    "eingenäht": "einnähen",
    "eingenähte": "eingenäht",
    "eingenähtem": "eingenäht",
    "eingenähten": "eingenäht",
    "eingenähter": "eingenäht",
    "eingenähtes": "eingenäht",
    "eingenäßt": "einnässen",
    "eingenäßte": "eingenäßt",
    "eingenäßtem": "eingenäßt",
    "eingenäßten": "eingenäßt",
    "eingenäßter": "eingenäßt",
    "eingenäßtere": "eingenäßt",
    "eingenäßterem": "eingenäßt",
    "eingenäßteren": "eingenäßt",
    "eingenäßterer": "eingenäßt",
    "eingenäßteres": "eingenäßt",
    "eingenäßtes": "eingenäßt",
    "eingenäßteste": "eingenäßt",
    "eingenäßtestem": "eingenäßt",
    "eingenäßtesten": "eingenäßt",
    "eingenäßtester": "eingenäßt",
    "eingenäßtestes": "eingenäßt",
    "eingeordnet": "einordnen",
    "eingeordnete": "eingeordnet",
    "eingeordnetem": "eingeordnet",
    "eingeordneten": "eingeordnet",
    "eingeordneter": "eingeordnet",
    "eingeordnetes": "eingeordnet",
    "eingepackt": "einpacken",
    "eingepackte": "eingepackt",
    "eingepacktem": "eingepackt",
    "eingepackten": "eingepackt",
    "eingepackter": "eingepackt",
    "eingepacktes": "eingepackt",
    "eingeparkt": "einparken",
    "eingeparkte": "eingeparkt",
    "eingeparktem": "eingeparkt",
    "eingeparkten": "eingeparkt",
    "eingeparkter": "eingeparkt",
    "eingeparktes": "eingeparkt",
    "eingepaukt": "einpauken",
    "eingepaukte": "eingepaukt",
    "eingepauktem": "eingepaukt",
    "eingepaukten": "eingepaukt",
    "eingepaukter": "eingepaukt",
    "eingepauktes": "eingepaukt",
    "eingepaßt": "einpassen",
    "eingepaßte": "eingepaßt",
    "eingepaßtem": "eingepaßt",
    "eingepaßten": "eingepaßt",
    "eingepaßter": "eingepaßt",
    "eingepaßtere": "eingepaßt",
    "eingepaßterem": "eingepaßt",
    "eingepaßteren": "eingepaßt",
    "eingepaßterer": "eingepaßt",
    "eingepaßteres": "eingepaßt",
    "eingepaßtes": "eingepaßt",
    "eingepaßteste": "eingepaßt",
    "eingepaßtestem": "eingepaßt",
    "eingepaßtesten": "eingepaßt",
    "eingepaßtester": "eingepaßt",
    "eingepaßtestes": "eingepaßt",
    "eingependelt": "einpendeln",
    "eingependelte": "eingependelt",
    "eingependeltem": "eingependelt",
    "eingependelten": "eingependelt",
    "eingependelter": "eingependelt",
    "eingependeltere": "eingependelt",
    "eingependelterem": "eingependelt",
    "eingependelteren": "eingependelt",
    "eingependelterer": "eingependelt",
    "eingependelteres": "eingependelt",
    "eingependeltes": "eingependelt",
    "eingependelteste": "eingependelt",
    "eingependeltestem": "eingependelt",
    "eingependeltesten": "eingependelt",
    "eingependeltester": "eingependelt",
    "eingependeltestes": "eingependelt",
    "eingepfercht": "einpferchen",
    "eingepferchte": "eingepfercht",
    "eingepferchtem": "eingepfercht",
    "eingepferchten": "eingepfercht",
    "eingepferchter": "eingepfercht",
    "eingepferchtere": "eingepfercht",
    "eingepferchterem": "eingepfercht",
    "eingepferchteren": "eingepfercht",
    "eingepferchterer": "eingepfercht",
    "eingepferchteres": "eingepfercht",
    "eingepferchtes": "eingepfercht",
    "eingepferchteste": "eingepfercht",
    "eingepferchtestem": "eingepfercht",
    "eingepferchtesten": "eingepfercht",
    "eingepferchtester": "eingepfercht",
    "eingepferchtestes": "eingepfercht",
    "eingepflanzt": "einpflanzen",
    "eingepflanzte": "eingepflanzt",
    "eingepflanztem": "eingepflanzt",
    "eingepflanzten": "eingepflanzt",
    "eingepflanzter": "eingepflanzt",
    "eingepflanztes": "eingepflanzt",
    "eingepfropft": "einpfropfen",
    "eingepfropfte": "eingepfropft",
    "eingepfropftem": "eingepfropft",
    "eingepfropften": "eingepfropft",
    "eingepfropfter": "eingepfropft",
    "eingepfropftere": "eingepfropft",
    "eingepfropfterem": "eingepfropft",
    "eingepfropfteren": "eingepfropft",
    "eingepfropfterer": "eingepfropft",
    "eingepfropfteres": "eingepfropft",
    "eingepfropftes": "eingepfropft",
    "eingepfropfteste": "eingepfropft",
    "eingepfropftestem": "eingepfropft",
    "eingepfropftesten": "eingepfropft",
    "eingepfropftester": "eingepfropft",
    "eingepfropftestes": "eingepfropft",
    "eingepinselt": "einpinseln",
    "eingepinselte": "eingepinselt",
    "eingepinseltem": "eingepinselt",
    "eingepinselten": "eingepinselt",
    "eingepinselter": "eingepinselt",
    "eingepinseltere": "eingepinselt",
    "eingepinselterem": "eingepinselt",
    "eingepinselteren": "eingepinselt",
    "eingepinselterer": "eingepinselt",
    "eingepinselteres": "eingepinselt",
    "eingepinseltes": "eingepinselt",
    "eingepinselteste": "eingepinselt",
    "eingepinseltestem": "eingepinselt",
    "eingepinseltesten": "eingepinselt",
    "eingepinseltester": "eingepinselt",
    "eingepinseltestes": "eingepinselt",
    "eingeplant": "einplanen",
    "eingeplante": "eingeplant",
    "eingeplantem": "eingeplant",
    "eingeplanten": "eingeplant",
    "eingeplanter": "eingeplant",
    "eingeplantes": "eingeplant",
    "eingepreßt": "einpressen",
    "eingepreßte": "eingepreßt",
    "eingepreßtem": "eingepreßt",
    "eingepreßten": "eingepreßt",
    "eingepreßter": "eingepreßt",
    "eingepreßtes": "eingepreßt",
    "eingeprägt": "einprägen",
    "eingeprägte": "eingeprägt",
    "eingeprägtem": "eingeprägt",
    "eingeprägten": "eingeprägt",
    "eingeprägter": "eingeprägt",
    "eingeprägtes": "eingeprägt",
    "eingepudert": "einpudern",
    "eingepuderte": "eingepudert",
    "eingepudertem": "eingepudert",
    "eingepuderten": "eingepudert",
    "eingepuderter": "eingepudert",
    "eingepudertere": "eingepudert",
    "eingepuderterem": "eingepudert",
    "eingepuderteren": "eingepudert",
    "eingepuderterer": "eingepudert",
    "eingepuderteres": "eingepudert",
    "eingepudertes": "eingepudert",
    "eingepuderteste": "eingepudert",
    "eingepudertestem": "eingepudert",
    "eingepudertesten": "eingepudert",
    "eingepudertester": "eingepudert",
    "eingepudertestes": "eingepudert",
    "eingepumpt": "einpumpen",
    "eingepumpte": "eingepumpt",
    "eingepumptem": "eingepumpt",
    "eingepumpten": "eingepumpt",
    "eingepumpter": "eingepumpt",
    "eingepumptes": "eingepumpt",
    "eingepökelt": "einpökeln",
    "eingepökelte": "eingepökelt",
    "eingepökeltem": "eingepökelt",
    "eingepökelten": "eingepökelt",
    "eingepökelter": "eingepökelt",
    "eingepökeltere": "eingepökelt",
    "eingepökelterem": "eingepökelt",
    "eingepökelteren": "eingepökelt",
    "eingepökelterer": "eingepökelt",
    "eingepökelteres": "eingepökelt",
    "eingepökeltes": "eingepökelt",
    "eingepökelteste": "eingepökelt",
    "eingepökeltestem": "eingepökelt",
    "eingepökeltesten": "eingepökelt",
    "eingepökeltester": "eingepökelt",
    "eingepökeltestes": "eingepökelt",
    "eingerahmt": "einrahmen",
    "eingerahmte": "eingerahmt",
    "eingerahmtem": "eingerahmt",
    "eingerahmten": "eingerahmt",
    "eingerahmter": "eingerahmt",
    "eingerahmtes": "eingerahmt",
    "eingerammt": "einrammen",
    "eingerammte": "eingerammt",
    "eingerammtem": "eingerammt",
    "eingerammten": "eingerammt",
    "eingerammter": "eingerammt",
    "eingerammtere": "eingerammt",
    "eingerammterem": "eingerammt",
    "eingerammteren": "eingerammt",
    "eingerammterer": "eingerammt",
    "eingerammteres": "eingerammt",
    "eingerammtes": "eingerammt",
    "eingerammteste": "eingerammt",
    "eingerammtestem": "eingerammt",
    "eingerammtesten": "eingerammt",
    "eingerammtester": "eingerammt",
    "eingerammtestes": "eingerammt",
    "eingerannt": "einrennen",
    "eingerannte": "eingerannt",
    "eingeranntem": "eingerannt",
    "eingerannten": "eingerannt",
    "eingerannter": "eingerannt",
    "eingeranntes": "eingerannt",
    "eingerastet": "einrasten",
    "eingerastete": "eingerastet",
    "eingerastetem": "eingerastet",
    "eingerasteten": "eingerastet",
    "eingerasteter": "eingerastet",
    "eingerastetere": "eingerastet",
    "eingerasteterem": "eingerastet",
    "eingerasteteren": "eingerastet",
    "eingerasteterer": "eingerastet",
    "eingerasteteres": "eingerastet",
    "eingerastetes": "eingerastet",
    "eingerasteteste": "eingerastet",
    "eingerastetestem": "eingerastet",
    "eingerastetesten": "eingerastet",
    "eingerastetester": "eingerastet",
    "eingerastetestes": "eingerastet",
    "eingerechnet": "einrechnen",
    "eingerechnete": "eingerechnet",
    "eingerechnetem": "eingerechnet",
    "eingerechneten": "eingerechnet",
    "eingerechneter": "eingerechnet",
    "eingerechnetes": "eingerechnet",
    "eingeredet": "einreden",
    "eingeredete": "eingeredet",
    "eingeredetem": "eingeredet",
    "eingeredeten": "eingeredet",
    "eingeredeter": "eingeredet",
    "eingeredetes": "eingeredet",
    "eingeregnet": "einregnen",
    "eingeregnete": "eingeregnet",
    "eingeregnetem": "eingeregnet",
    "eingeregneten": "eingeregnet",
    "eingeregneter": "eingeregnet",
    "eingeregnetes": "eingeregnet",
    "eingereicht": "einreichen",
    "eingereichte": "eingereicht",
    "eingereichtem": "eingereicht",
    "eingereichten": "eingereicht",
    "eingereichter": "eingereicht",
    "eingereichtes": "eingereicht",
    "eingereiht": "einreihen",
    "eingereihte": "eingereiht",
    "eingereihtem": "eingereiht",
    "eingereihten": "eingereiht",
    "eingereihter": "eingereiht",
    "eingereihtes": "eingereiht",
    "eingereist": "einreisen",
    "eingereiste": "eingereist",
    "eingereistem": "eingereist",
    "eingereisten": "eingereist",
    "eingereister": "eingereist",
    "eingereistes": "eingereist",
    "eingerenkt": "einrenken",
    "eingerenkte": "eingerenkt",
    "eingerenktem": "eingerenkt",
    "eingerenkten": "eingerenkt",
    "eingerenkter": "eingerenkt",
    "eingerenktes": "eingerenkt",
    "eingerichtet": "einrichten",
    "eingerichtete": "eingerichtet",
    "eingerichtetem": "eingerichtet",
    "eingerichteten": "eingerichtet",
    "eingerichteter": "eingerichtet",
    "eingerichtetes": "eingerichtet",
    "eingerieben": "einreiben",
    "eingeriebene": "eingerieben",
    "eingeriebenem": "eingerieben",
    "eingeriebenen": "eingerieben",
    "eingeriebener": "eingerieben",
    "eingeriebenes": "eingerieben",
    "eingeriegelt": "einriegeln",
    "eingeriegelte": "eingeriegelt",
    "eingeriegeltem": "eingeriegelt",
    "eingeriegelten": "eingeriegelt",
    "eingeriegelter": "eingeriegelt",
    "eingeriegeltes": "eingeriegelt",
    "eingerissen": "einreißen",
    "eingerissene": "eingerissen",
    "eingerissenem": "eingerissen",
    "eingerissenen": "eingerissen",
    "eingerissener": "eingerissen",
    "eingerissenere": "eingerissen",
    "eingerissenerem": "eingerissen",
    "eingerisseneren": "eingerissen",
    "eingerissenerer": "eingerissen",
    "eingerisseneres": "eingerissen",
    "eingerissenes": "eingerissen",
    "eingerissenste": "eingerissen",
    "eingerissenstem": "eingerissen",
    "eingerissensten": "eingerissen",
    "eingerissenster": "eingerissen",
    "eingerissenstes": "eingerissen",
    "eingeritten": "einreiten",
    "eingerittene": "eingeritten",
    "eingerittenem": "eingeritten",
    "eingerittenen": "eingeritten",
    "eingerittener": "eingeritten",
    "eingerittenes": "eingeritten",
    "eingeritzt": "einritzen",
    "eingeritzte": "eingeritzt",
    "eingeritztem": "eingeritzt",
    "eingeritzten": "eingeritzt",
    "eingeritzter": "eingeritzt",
    "eingeritztes": "eingeritzt",
    "eingerollt": "einrollen",
    "eingerollte": "eingerollt",
    "eingerolltem": "eingerollt",
    "eingerollten": "eingerollt",
    "eingerollter": "eingerollt",
    "eingerolltere": "eingerollt",
    "eingerollterem": "eingerollt",
    "eingerollteren": "eingerollt",
    "eingerollterer": "eingerollt",
    "eingerollteres": "eingerollt",
    "eingerolltes": "eingerollt",
    "eingerollteste": "eingerollt",
    "eingerolltestem": "eingerollt",
    "eingerolltesten": "eingerollt",
    "eingerolltester": "eingerollt",
    "eingerolltestes": "eingerollt",
    "eingerostet": "einrosten",
    "eingerostete": "eingerostet",
    "eingerostetem": "eingerostet",
    "eingerosteten": "eingerostet",
    "eingerosteter": "eingerostet",
    "eingerostetere": "eingerostet",
    "eingerosteterem": "eingerostet",
    "eingerosteteren": "eingerostet",
    "eingerosteterer": "eingerostet",
    "eingerosteteres": "eingerostet",
    "eingerostetes": "eingerostet",
    "eingerosteteste": "eingerostet",
    "eingerostetestem": "eingerostet",
    "eingerostetesten": "eingerostet",
    "eingerostetester": "eingerostet",
    "eingerostetestes": "eingerostet",
    "eingeräuchert": "einräuchern",
    "eingeräucherte": "eingeräuchert",
    "eingeräuchertem": "eingeräuchert",
    "eingeräucherten": "eingeräuchert",
    "eingeräucherter": "eingeräuchert",
    "eingeräuchertere": "eingeräuchert",
    "eingeräucherterem": "eingeräuchert",
    "eingeräucherteren": "eingeräuchert",
    "eingeräucherterer": "eingeräuchert",
    "eingeräucherteres": "eingeräuchert",
    "eingeräuchertes": "eingeräuchert",
    "eingeräucherteste": "eingeräuchert",
    "eingeräuchertestem": "eingeräuchert",
    "eingeräuchertesten": "eingeräuchert",
    "eingeräuchertester": "eingeräuchert",
    "eingeräuchertestes": "eingeräuchert",
    "eingeräumt": "einräumen",
    "eingeräumte": "eingeräumt",
    "eingeräumtem": "eingeräumt",
    "eingeräumten": "eingeräumt",
    "eingeräumter": "eingeräumt",
    "eingeräumtes": "eingeräumt",
    "eingerückt": "einrücken",
    "eingerückte": "eingerückt",
    "eingerücktem": "eingerückt",
    "eingerückten": "eingerückt",
    "eingerückter": "eingerückt",
    "eingerücktes": "eingerückt",
    "eingerührt": "einrühren",
    "eingerührte": "eingerührt",
    "eingerührtem": "eingerührt",
    "eingerührten": "eingerührt",
    "eingerührter": "eingerührt",
    "eingerührtes": "eingerührt",
    "eingerüstet": "einrüsten",
    "eingerüstete": "eingerüstet",
    "eingerüstetem": "eingerüstet",
    "eingerüsteten": "eingerüstet",
    "eingerüsteter": "eingerüstet",
    "eingerüstetes": "eingerüstet",
    "eingesagt": "einsagen",
    "eingesagte": "eingesagt",
    "eingesagtem": "eingesagt",
    "eingesagten": "eingesagt",
    "eingesagter": "eingesagt",
    "eingesagtes": "eingesagt",
    "eingesalbt": "einsalben",
    "eingesalbte": "eingesalbt",
    "eingesalbtem": "eingesalbt",
    "eingesalbten": "eingesalbt",
    "eingesalbter": "eingesalbt",
    "eingesalbtes": "eingesalbt",
    "eingesalzen": "einsalzen",
    "eingesalzene": "eingesalzen",
    "eingesalzenem": "eingesalzen",
    "eingesalzenen": "eingesalzen",
    "eingesalzener": "eingesalzen",
    "eingesalzenere": "eingesalzen",
    "eingesalzenerem": "eingesalzen",
    "eingesalzeneren": "eingesalzen",
    "eingesalzenerer": "eingesalzen",
    "eingesalzeneres": "eingesalzen",
    "eingesalzenes": "eingesalzen",
    "eingesalzenste": "eingesalzen",
    "eingesalzenstem": "eingesalzen",
    "eingesalzensten": "eingesalzen",
    "eingesalzenster": "eingesalzen",
    "eingesalzenstes": "eingesalzen",
    "eingesammelt": "einsammeln",
    "eingesammelte": "eingesammelt",
    "eingesammeltem": "eingesammelt",
    "eingesammelten": "eingesammelt",
    "eingesammelter": "eingesammelt",
    "eingesammeltes": "eingesammelt",
    "eingesandt": "einsenden",
    "eingesandte": "eingesandt",
    "eingesandtem": "eingesandt",
    "eingesandten": "eingesandt",
    "eingesandter": "eingesandt",
    "eingesandtes": "eingesandt",
    "eingesargt": "einsargen",
    "eingesargte": "eingesargt",
    "eingesargtem": "eingesargt",
    "eingesargten": "eingesargt",
    "eingesargter": "eingesargt",
    "eingesargtes": "eingesargt",
    "eingesaugt": "einsaugen",
    "eingesaugte": "eingesaugt",
    "eingesaugtem": "eingesaugt",
    "eingesaugten": "eingesaugt",
    "eingesaugter": "eingesaugt",
    "eingesaugtere": "eingesaugt",
    "eingesaugterem": "eingesaugt",
    "eingesaugteren": "eingesaugt",
    "eingesaugterer": "eingesaugt",
    "eingesaugteres": "eingesaugt",
    "eingesaugtes": "eingesaugt",
    "eingesaugteste": "eingesaugt",
    "eingesaugtestem": "eingesaugt",
    "eingesaugtesten": "eingesaugt",
    "eingesaugtester": "eingesaugt",
    "eingesaugtestes": "eingesaugt",
    "eingesaut": "einsauen",
    "eingesaute": "eingesaut",
    "eingesautem": "eingesaut",
    "eingesauten": "eingesaut",
    "eingesauter": "eingesaut",
    "eingesautere": "eingesaut",
    "eingesauterem": "eingesaut",
    "eingesauteren": "eingesaut",
    "eingesauterer": "eingesaut",
    "eingesauteres": "eingesaut",
    "eingesautes": "eingesaut",
    "eingesauteste": "eingesaut",
    "eingesautestem": "eingesaut",
    "eingesautesten": "eingesaut",
    "eingesautester": "eingesaut",
    "eingesautestes": "eingesaut",
    "eingeschachtelt": "einschachteln",
    "eingeschachtelte": "eingeschachtelt",
    "eingeschachteltem": "eingeschachtelt",
    "eingeschachtelten": "eingeschachtelt",
    "eingeschachtelter": "eingeschachtelt",
    "eingeschachteltere": "eingeschachtelt",
    "eingeschachtelterem": "eingeschachtelt",
    "eingeschachtelteren": "eingeschachtelt",
    "eingeschachtelterer": "eingeschachtelt",
    "eingeschachtelteres": "eingeschachtelt",
    "eingeschachteltes": "eingeschachtelt",
    "eingeschachtelteste": "eingeschachtelt",
    "eingeschachteltestem": "eingeschachtelt",
    "eingeschachteltesten": "eingeschachtelt",
    "eingeschachteltester": "eingeschachtelt",
    "eingeschachteltestes": "eingeschachtelt",
    "eingeschaltet": "einschalten",
    "eingeschaltete": "eingeschaltet",
    "eingeschaltetem": "eingeschaltet",
    "eingeschalteten": "eingeschaltet",
    "eingeschalteter": "eingeschaltet",
    "eingeschaltetes": "eingeschaltet",
    "eingescharrt": "einscharren",
    "eingescharrte": "eingescharrt",
    "eingescharrtem": "eingescharrt",
    "eingescharrten": "eingescharrt",
    "eingescharrter": "eingescharrt",
    "eingescharrtes": "eingescharrt",
    "eingeschenkt": "einschenken",
    "eingeschenkte": "eingeschenkt",
    "eingeschenktem": "eingeschenkt",
    "eingeschenkten": "eingeschenkt",
    "eingeschenkter": "eingeschenkt",
    "eingeschenktes": "eingeschenkt",
    "eingeschert": "einscheren",
    "eingescherte": "eingeschert",
    "eingeschertem": "eingeschert",
    "eingescherten": "eingeschert",
    "eingescherter": "eingeschert",
    "eingeschertes": "eingeschert",
    "eingeschifft": "einschiffen",
    "eingeschiffte": "eingeschifft",
    "eingeschifftem": "eingeschifft",
    "eingeschifften": "eingeschifft",
    "eingeschiffter": "eingeschifft",
    "eingeschifftes": "eingeschifft",
    "eingeschlafen": "einschlafen",
    "eingeschlafene": "eingeschlafen",
    "eingeschlafenem": "eingeschlafen",
    "eingeschlafenen": "eingeschlafen",
    "eingeschlafener": "eingeschlafen",
    "eingeschlafenes": "eingeschlafen",
    "eingeschlagen": "einschlagen",
    "eingeschlagene": "eingeschlagen",
    "eingeschlagenem": "eingeschlagen",
    "eingeschlagenen": "eingeschlagen",
    "eingeschlagener": "eingeschlagen",
    "eingeschlagenes": "eingeschlagen",
    "eingeschleift": "einschleifen",
    "eingeschleifte": "eingeschleift",
    "eingeschleiftem": "eingeschleift",
    "eingeschleiften": "eingeschleift",
    "eingeschleifter": "eingeschleift",
    "eingeschleiftes": "eingeschleift",
    "eingeschleimt": "einschleimen",
    "eingeschleimte": "eingeschleimt",
    "eingeschleimtem": "eingeschleimt",
    "eingeschleimten": "eingeschleimt",
    "eingeschleimter": "eingeschleimt",
    "eingeschleimtere": "eingeschleimt",
    "eingeschleimterem": "eingeschleimt",
    "eingeschleimteren": "eingeschleimt",
    "eingeschleimterer": "eingeschleimt",
    "eingeschleimteres": "eingeschleimt",
    "eingeschleimtes": "eingeschleimt",
    "eingeschleimteste": "eingeschleimt",
    "eingeschleimtestem": "eingeschleimt",
    "eingeschleimtesten": "eingeschleimt",
    "eingeschleimtester": "eingeschleimt",
    "eingeschleimtestes": "eingeschleimt",
    "eingeschleppt": "einschleppen",
    "eingeschleppte": "eingeschleppt",
    "eingeschlepptem": "eingeschleppt",
    "eingeschleppten": "eingeschleppt",
    "eingeschleppter": "eingeschleppt",
    "eingeschlepptes": "eingeschleppt",
    "eingeschleust": "einschleusen",
    "eingeschleuste": "eingeschleust",
    "eingeschleustem": "eingeschleust",
    "eingeschleusten": "eingeschleust",
    "eingeschleuster": "eingeschleust",
    "eingeschleustes": "eingeschleust",
    "eingeschlichen": "einschleichen",
    "eingeschlichene": "eingeschlichen",
    "eingeschlichenem": "eingeschlichen",
    "eingeschlichenen": "eingeschlichen",
    "eingeschlichener": "eingeschlichen",
    "eingeschlichenes": "eingeschlichen",
    "eingeschliffen": "einschleifen",
    "eingeschliffene": "eingeschliffen",
    "eingeschliffenem": "eingeschliffen",
    "eingeschliffenen": "eingeschliffen",
    "eingeschliffener": "eingeschliffen",
    "eingeschliffenes": "eingeschliffen",
    "eingeschlossen": "einschließen",
    "eingeschlossene": "eingeschlossen",
    "eingeschlossenem": "eingeschlossen",
    "eingeschlossenen": "eingeschlossen",
    "eingeschlossener": "eingeschlossen",
    "eingeschlossenes": "eingeschlossen",
    "eingeschlummert": "einschlummern",
    "eingeschlummerte": "eingeschlummert",
    "eingeschlummertem": "eingeschlummert",
    "eingeschlummerten": "eingeschlummert",
    "eingeschlummerter": "eingeschlummert",
    "eingeschlummertes": "eingeschlummert",
    "eingeschläfert": "einschläfern",
    "eingeschläferte": "eingeschläfert",
    "eingeschläfertem": "eingeschläfert",
    "eingeschläferten": "eingeschläfert",
    "eingeschläferter": "eingeschläfert",
    "eingeschläfertes": "eingeschläfert",
    "eingeschmeichelt": "einschmeicheln",
    "eingeschmeichelte": "eingeschmeichelt",
    "eingeschmeicheltem": "eingeschmeichelt",
    "eingeschmeichelten": "eingeschmeichelt",
    "eingeschmeichelter": "eingeschmeichelt",
    "eingeschmeicheltere": "eingeschmeichelt",
    "eingeschmeichelterem": "eingeschmeichelt",
    "eingeschmeichelteren": "eingeschmeichelt",
    "eingeschmeichelterer": "eingeschmeichelt",
    "eingeschmeichelteres": "eingeschmeichelt",
    "eingeschmeicheltes": "eingeschmeichelt",
    "eingeschmeichelteste": "eingeschmeichelt",
    "eingeschmeicheltestem": "eingeschmeichelt",
    "eingeschmeicheltesten": "eingeschmeichelt",
    "eingeschmeicheltester": "eingeschmeichelt",
    "eingeschmeicheltestes": "eingeschmeichelt",
    "eingeschmiert": "einschmieren",
    "eingeschmierte": "eingeschmiert",
    "eingeschmiertem": "eingeschmiert",
    "eingeschmierten": "eingeschmiert",
    "eingeschmierter": "eingeschmiert",
    "eingeschmiertes": "eingeschmiert",
    "eingeschmissen": "einschmeißen",
    "eingeschmissene": "eingeschmissen",
    "eingeschmissenem": "eingeschmissen",
    "eingeschmissenen": "eingeschmissen",
    "eingeschmissener": "eingeschmissen",
    "eingeschmissenes": "eingeschmissen",
    "eingeschmolzen": "einschmelzen",
    "eingeschmolzene": "eingeschmolzen",
    "eingeschmolzenem": "eingeschmolzen",
    "eingeschmolzenen": "eingeschmolzen",
    "eingeschmolzener": "eingeschmolzen",
    "eingeschmolzenes": "eingeschmolzen",
    "eingeschmuggelt": "einschmuggeln",
    "eingeschmuggelte": "eingeschmuggelt",
    "eingeschmuggeltem": "eingeschmuggelt",
    "eingeschmuggelten": "eingeschmuggelt",
    "eingeschmuggelter": "eingeschmuggelt",
    "eingeschmuggeltes": "eingeschmuggelt",
    "eingeschnappt": "einschnappen",
    "eingeschnappte": "eingeschnappt",
    "eingeschnapptem": "eingeschnappt",
    "eingeschnappten": "eingeschnappt",
    "eingeschnappter": "eingeschnappt",
    "eingeschnapptes": "eingeschnappt",
    "eingeschneit": "einschneien",
    "eingeschneite": "eingeschneit",
    "eingeschneitem": "eingeschneit",
    "eingeschneiten": "eingeschneit",
    "eingeschneiter": "eingeschneit",
    "eingeschneitere": "eingeschneit",
    "eingeschneiterem": "eingeschneit",
    "eingeschneiteren": "eingeschneit",
    "eingeschneiterer": "eingeschneit",
    "eingeschneiteres": "eingeschneit",
    "eingeschneites": "eingeschneit",
    "eingeschneiteste": "eingeschneit",
    "eingeschneitestem": "eingeschneit",
    "eingeschneitesten": "eingeschneit",
    "eingeschneitester": "eingeschneit",
    "eingeschneitestes": "eingeschneit",
    "eingeschnitten": "einschneiden",
    "eingeschnittene": "eingeschnitten",
    "eingeschnittenem": "eingeschnitten",
    "eingeschnittenen": "eingeschnitten",
    "eingeschnittener": "eingeschnitten",
    "eingeschnittenes": "eingeschnitten",
    "eingeschnitzt": "einschnitzen",
    "eingeschnitzte": "eingeschnitzt",
    "eingeschnitztem": "eingeschnitzt",
    "eingeschnitzten": "eingeschnitzt",
    "eingeschnitzter": "eingeschnitzt",
    "eingeschnitztes": "eingeschnitzt",
    "eingeschnürt": "einschnüren",
    "eingeschnürte": "eingeschnürt",
    "eingeschnürtem": "eingeschnürt",
    "eingeschnürten": "eingeschnürt",
    "eingeschnürter": "eingeschnürt",
    "eingeschnürtere": "eingeschnürt",
    "eingeschnürterem": "eingeschnürt",
    "eingeschnürteren": "eingeschnürt",
    "eingeschnürterer": "eingeschnürt",
    "eingeschnürteres": "eingeschnürt",
    "eingeschnürtes": "eingeschnürt",
    "eingeschnürteste": "eingeschnürt",
    "eingeschnürtestem": "eingeschnürt",
    "eingeschnürtesten": "eingeschnürt",
    "eingeschnürtester": "eingeschnürt",
    "eingeschnürtestes": "eingeschnürt",
    "eingeschoben": "einschieben",
    "eingeschobene": "eingeschoben",
    "eingeschobenem": "eingeschoben",
    "eingeschobenen": "eingeschoben",
    "eingeschobener": "eingeschoben",
    "eingeschobenes": "eingeschoben",
    "eingeschoren": "einscheren",
    "eingeschorene": "eingeschoren",
    "eingeschorenem": "eingeschoren",
    "eingeschorenen": "eingeschoren",
    "eingeschorener": "eingeschoren",
    "eingeschorenes": "eingeschoren",
    "eingeschossen": "einschießen",
    "eingeschossene": "eingeschossen",
    "eingeschossenem": "eingeschossen",
    "eingeschossenen": "eingeschossen",
    "eingeschossener": "eingeschossen",
    "eingeschossenere": "eingeschossen",
    "eingeschossenerem": "eingeschossen",
    "eingeschosseneren": "eingeschossen",
    "eingeschossenerer": "eingeschossen",
    "eingeschosseneres": "eingeschossen",
    "eingeschossenes": "eingeschossen",
    "eingeschossenste": "eingeschossen",
    "eingeschossenstem": "eingeschossen",
    "eingeschossensten": "eingeschossen",
    "eingeschossenster": "eingeschossen",
    "eingeschossenstes": "eingeschossen",
    "eingeschraubt": "einschrauben",
    "eingeschraubte": "eingeschraubt",
    "eingeschraubtem": "eingeschraubt",
    "eingeschraubten": "eingeschraubt",
    "eingeschraubter": "eingeschraubt",
    "eingeschraubtes": "eingeschraubt",
    "eingeschrieben": "einschreiben",
    "eingeschriebene": "eingeschrieben",
    "eingeschriebenem": "eingeschrieben",
    "eingeschriebenen": "eingeschrieben",
    "eingeschriebener": "eingeschrieben",
    "eingeschriebenes": "eingeschrieben",
    "eingeschritten": "einschreiten",
    "eingeschrittene": "eingeschritten",
    "eingeschrittenem": "eingeschritten",
    "eingeschrittenen": "eingeschritten",
    "eingeschrittener": "eingeschritten",
    "eingeschrittenes": "eingeschritten",
    "eingeschrumpft": "einschrumpfen",
    "eingeschrumpfte": "eingeschrumpft",
    "eingeschrumpftem": "eingeschrumpft",
    "eingeschrumpften": "eingeschrumpft",
    "eingeschrumpfter": "eingeschrumpft",
    "eingeschrumpftere": "eingeschrumpft",
    "eingeschrumpfterem": "eingeschrumpft",
    "eingeschrumpfteren": "eingeschrumpft",
    "eingeschrumpfterer": "eingeschrumpft",
    "eingeschrumpfteres": "eingeschrumpft",
    "eingeschrumpftes": "eingeschrumpft",
    "eingeschrumpfteste": "eingeschrumpft",
    "eingeschrumpftestem": "eingeschrumpft",
    "eingeschrumpftesten": "eingeschrumpft",
    "eingeschrumpftester": "eingeschrumpft",
    "eingeschrumpftestes": "eingeschrumpft",
    "eingeschränkt": "einschränken",
    "eingeschränkte": "eingeschränkt",
    "eingeschränktem": "eingeschränkt",
    "eingeschränkten": "eingeschränkt",
    "eingeschränkter": "eingeschränkt",
    "eingeschränktere": "eingeschränkt",
    "eingeschränkterem": "eingeschränkt",
    "eingeschränkteren": "eingeschränkt",
    "eingeschränkterer": "eingeschränkt",
    "eingeschränkteres": "eingeschränkt",
    "eingeschränktes": "eingeschränkt",
    "eingeschränkteste": "eingeschränkt",
    "eingeschränktestem": "eingeschränkt",
    "eingeschränktesten": "eingeschränkt",
    "eingeschränktester": "eingeschränkt",
    "eingeschränktestes": "eingeschränkt",
    "eingeschult": "einschulen",
    "eingeschulte": "eingeschult",
    "eingeschultem": "eingeschult",
    "eingeschulten": "eingeschult",
    "eingeschulter": "eingeschult",
    "eingeschultes": "eingeschult",
    "eingeschwebt": "einschweben",
    "eingeschwebte": "eingeschwebt",
    "eingeschwebtem": "eingeschwebt",
    "eingeschwebten": "eingeschwebt",
    "eingeschwebter": "eingeschwebt",
    "eingeschwebtes": "eingeschwebt",
    "eingeschwefelt": "einschwefeln",
    "eingeschwefelte": "eingeschwefelt",
    "eingeschwefeltem": "eingeschwefelt",
    "eingeschwefelten": "eingeschwefelt",
    "eingeschwefelter": "eingeschwefelt",
    "eingeschwefeltere": "eingeschwefelt",
    "eingeschwefelterem": "eingeschwefelt",
    "eingeschwefelteren": "eingeschwefelt",
    "eingeschwefelterer": "eingeschwefelt",
    "eingeschwefelteres": "eingeschwefelt",
    "eingeschwefeltes": "eingeschwefelt",
    "eingeschwefelteste": "eingeschwefelt",
    "eingeschwefeltestem": "eingeschwefelt",
    "eingeschwefeltesten": "eingeschwefelt",
    "eingeschwefeltester": "eingeschwefelt",
    "eingeschwefeltestes": "eingeschwefelt",
    "eingeschwenkt": "einschwenken",
    "eingeschwenkte": "eingeschwenkt",
    "eingeschwenktem": "eingeschwenkt",
    "eingeschwenkten": "eingeschwenkt",
    "eingeschwenkter": "eingeschwenkt",
    "eingeschwenktes": "eingeschwenkt",
    "eingeschwommen": "einschwimmen",
    "eingeschwommene": "eingeschwommen",
    "eingeschwommenem": "eingeschwommen",
    "eingeschwommenen": "eingeschwommen",
    "eingeschwommener": "eingeschwommen",
    "eingeschwommenere": "eingeschwommen",
    "eingeschwommenerem": "eingeschwommen",
    "eingeschwommeneren": "eingeschwommen",
    "eingeschwommenerer": "eingeschwommen",
    "eingeschwommeneres": "eingeschwommen",
    "eingeschwommenes": "eingeschwommen",
    "eingeschwommenste": "eingeschwommen",
    "eingeschwommenstem": "eingeschwommen",
    "eingeschwommensten": "eingeschwommen",
    "eingeschwommenster": "eingeschwommen",
    "eingeschwommenstes": "eingeschwommen",
    "eingeschworen": "einschwören",
    "eingeschworene": "eingeschworen",
    "eingeschworenem": "eingeschworen",
    "eingeschworenen": "eingeschworen",
    "eingeschworener": "eingeschworen",
    "eingeschworenere": "eingeschworen",
    "eingeschworenerem": "eingeschworen",
    "eingeschworeneren": "eingeschworen",
    "eingeschworenerer": "eingeschworen",
    "eingeschworeneres": "eingeschworen",
    "eingeschworenes": "eingeschworen",
    "eingeschworenste": "eingeschworen",
    "eingeschworenstem": "eingeschworen",
    "eingeschworensten": "eingeschworen",
    "eingeschworenster": "eingeschworen",
    "eingeschworenstes": "eingeschworen",
    "eingeschwungen": "einschwingen",
    "eingeschwungene": "eingeschwungen",
    "eingeschwungenem": "eingeschwungen",
    "eingeschwungenen": "eingeschwungen",
    "eingeschwungener": "eingeschwungen",
    "eingeschwungenes": "eingeschwungen",
    "eingeschwärzt": "einschwärzen",
    "eingeschwärzte": "eingeschwärzt",
    "eingeschwärztem": "eingeschwärzt",
    "eingeschwärzten": "eingeschwärzt",
    "eingeschwärzter": "eingeschwärzt",
    "eingeschwärztere": "eingeschwärzt",
    "eingeschwärzterem": "eingeschwärzt",
    "eingeschwärzteren": "eingeschwärzt",
    "eingeschwärzterer": "eingeschwärzt",
    "eingeschwärzteres": "eingeschwärzt",
    "eingeschwärztes": "eingeschwärzt",
    "eingeschwärzteste": "eingeschwärzt",
    "eingeschwärztestem": "eingeschwärzt",
    "eingeschwärztesten": "eingeschwärzt",
    "eingeschwärztester": "eingeschwärzt",
    "eingeschwärztestes": "eingeschwärzt",
    "eingeschärft": "einschärfen",
    "eingeschärfte": "eingeschärft",
    "eingeschärftem": "eingeschärft",
    "eingeschärften": "eingeschärft",
    "eingeschärfter": "eingeschärft",
    "eingeschärftes": "eingeschärft",
    "eingeschätzt": "einschätzen",
    "eingeschätzte": "eingeschätzt",
    "eingeschätztem": "eingeschätzt",
    "eingeschätzten": "eingeschätzt",
    "eingeschätzter": "eingeschätzt",
    "eingeschätztes": "eingeschätzt",
    "eingeschüttet": "einschütten",
    "eingeschüttete": "eingeschüttet",
    "eingeschüttetem": "eingeschüttet",
    "eingeschütteten": "eingeschüttet",
    "eingeschütteter": "eingeschüttet",
    "eingeschüttetes": "eingeschüttet",
    "eingesegnet": "einsegnen",
    "eingesegnete": "eingesegnet",
    "eingesegnetem": "eingesegnet",
    "eingesegneten": "eingesegnet",
    "eingesegneter": "eingesegnet",
    "eingesegnetes": "eingesegnet",
    "eingesehen": "einsehen",
    "eingesehene": "eingesehen",
    "eingesehenem": "eingesehen",
    "eingesehenen": "eingesehen",
    "eingesehener": "eingesehen",
    "eingesehenes": "eingesehen",
    "eingeseift": "einseifen",
    "eingeseifte": "eingeseift",
    "eingeseiftem": "eingeseift",
    "eingeseiften": "eingeseift",
    "eingeseifter": "eingeseift",
    "eingeseiftere": "eingeseift",
    "eingeseifterem": "eingeseift",
    "eingeseifteren": "eingeseift",
    "eingeseifterer": "eingeseift",
    "eingeseifteres": "eingeseift",
    "eingeseiftes": "eingeseift",
    "eingeseifteste": "eingeseift",
    "eingeseiftestem": "eingeseift",
    "eingeseiftesten": "eingeseift",
    "eingeseiftester": "eingeseift",
    "eingeseiftestes": "eingeseift",
    "eingesendet": "einsenden",
    "eingesendete": "eingesendet",
    "eingesendetem": "eingesendet",
    "eingesendeten": "eingesendet",
    "eingesendeter": "eingesendet",
    "eingesendetes": "eingesendet",
    "eingesengt": "einsengen",
    "eingesengte": "eingesengt",
    "eingesengtem": "eingesengt",
    "eingesengten": "eingesengt",
    "eingesengter": "eingesengt",
    "eingesengtere": "eingesengt",
    "eingesengterem": "eingesengt",
    "eingesengteren": "eingesengt",
    "eingesengterer": "eingesengt",
    "eingesengteres": "eingesengt",
    "eingesengtes": "eingesengt",
    "eingesengteste": "eingesengt",
    "eingesengtestem": "eingesengt",
    "eingesengtesten": "eingesengt",
    "eingesengtester": "eingesengt",
    "eingesengtestes": "eingesengt",
    "eingesessen": "einsitzen",
    "eingesessene": "eingesessen",
    "eingesessenem": "eingesessen",
    "eingesessenen": "eingesessen",
    "eingesessener": "eingesessen",
    "eingesessenere": "eingesessen",
    "eingesessenerem": "eingesessen",
    "eingesesseneren": "eingesessen",
    "eingesessenerer": "eingesessen",
    "eingesesseneres": "eingesessen",
    "eingesessenes": "eingesessen",
    "eingesessenste": "eingesessen",
    "eingesessenstem": "eingesessen",
    "eingesessensten": "eingesessen",
    "eingesessenster": "eingesessen",
    "eingesessenstes": "eingesessen",
    "eingesetzt": "einsetzen",
    "eingesetzte": "eingesetzt",
    "eingesetztem": "eingesetzt",
    "eingesetzten": "eingesetzt",
    "eingesetzter": "eingesetzt",
    "eingesetztes": "eingesetzt",
    "eingesogen": "einsaugen",
    "eingesogene": "eingesogen",
    "eingesogenem": "eingesogen",
    "eingesogenen": "eingesogen",
    "eingesogener": "eingesogen",
    "eingesogenere": "eingesogen",
    "eingesogenerem": "eingesogen",
    "eingesogeneren": "eingesogen",
    "eingesogenerer": "eingesogen",
    "eingesogeneres": "eingesogen",
    "eingesogenes": "eingesogen",
    "eingesogenste": "eingesogen",
    "eingesogenstem": "eingesogen",
    "eingesogensten": "eingesogen",
    "eingesogenster": "eingesogen",
    "eingesogenstes": "eingesogen",
    "eingespannt": "einspannen",
    "eingespannte": "eingespannt",
    "eingespanntem": "eingespannt",
    "eingespannten": "eingespannt",
    "eingespannter": "eingespannt",
    "eingespanntes": "eingespannt",
    "eingespart": "einsparen",
    "eingesparte": "eingespart",
    "eingespartem": "eingespart",
    "eingesparten": "eingespart",
    "eingesparter": "eingespart",
    "eingespartes": "eingespart",
    "eingespeichert": "einspeichern",
    "eingespeicherte": "eingespeichert",
    "eingespeichertem": "eingespeichert",
    "eingespeicherten": "eingespeichert",
    "eingespeicherter": "eingespeichert",
    "eingespeichertes": "eingespeichert",
    "eingesperrt": "einsperren",
    "eingesperrte": "eingesperrt",
    "eingesperrtem": "eingesperrt",
    "eingesperrten": "eingesperrt",
    "eingesperrter": "eingesperrt",
    "eingesperrtes": "eingesperrt",
    "eingespielt": "einspielen",
    "eingespielte": "eingespielt",
    "eingespieltem": "eingespielt",
    "eingespielten": "eingespielt",
    "eingespielter": "eingespielt",
    "eingespieltere": "eingespielt",
    "eingespielterem": "eingespielt",
    "eingespielteren": "eingespielt",
    "eingespielterer": "eingespielt",
    "eingespielteres": "eingespielt",
    "eingespieltes": "eingespielt",
    "eingespielteste": "eingespielt",
    "eingespieltestem": "eingespielt",
    "eingespieltesten": "eingespielt",
    "eingespieltester": "eingespielt",
    "eingespieltestes": "eingespielt",
    "eingesprengt": "einsprengen",
    "eingesprengte": "eingesprengt",
    "eingesprengtem": "eingesprengt",
    "eingesprengten": "eingesprengt",
    "eingesprengter": "eingesprengt",
    "eingesprengtes": "eingesprengt",
    "eingespritzt": "einspritzen",
    "eingespritzte": "eingespritzt",
    "eingespritztem": "eingespritzt",
    "eingespritzten": "eingespritzt",
    "eingespritzter": "eingespritzt",
    "eingespritztes": "eingespritzt",
    "eingesprochen": "einsprechen",
    "eingesprochene": "eingesprochen",
    "eingesprochenem": "eingesprochen",
    "eingesprochenen": "eingesprochen",
    "eingesprochener": "eingesprochen",
    "eingesprochenes": "eingesprochen",
    "eingesprungen": "einspringen",
    "eingesprungene": "eingesprungen",
    "eingesprungenem": "eingesprungen",
    "eingesprungenen": "eingesprungen",
    "eingesprungener": "eingesprungen",
    "eingesprungenes": "eingesprungen",
    "eingesprüht": "einsprühen",
    "eingesprühte": "eingesprüht",
    "eingesprühtem": "eingesprüht",
    "eingesprühten": "eingesprüht",
    "eingesprühter": "eingesprüht",
    "eingesprühtes": "eingesprüht",
    "eingestampft": "einstampfen",
    "eingestampfte": "eingestampft",
    "eingestampftem": "eingestampft",
    "eingestampften": "eingestampft",
    "eingestampfter": "eingestampft",
    "eingestampftes": "eingestampft",
    "eingestand": "eingestehen",
    "eingestanden": "einstehen",
    "eingestandene": "eingestanden",
    "eingestandenem": "eingestanden",
    "eingestandenen": "eingestanden",
    "eingestandener": "eingestanden",
    "eingestandenere": "eingestanden",
    "eingestandenerem": "eingestanden",
    "eingestandeneren": "eingestanden",
    "eingestandenerer": "eingestanden",
    "eingestandeneres": "eingestanden",
    "eingestandenes": "eingestanden",
    "eingestandenste": "eingestanden",
    "eingestandenstem": "eingestanden",
    "eingestandensten": "eingestanden",
    "eingestandenster": "eingestanden",
    "eingestandenstes": "eingestanden",
    "eingestandest": "eingestehen",
    "eingestandet": "eingestehen",
    "eingestaubt": "einstauben",
    "eingestaubte": "eingestaubt",
    "eingestaubtem": "eingestaubt",
    "eingestaubten": "eingestaubt",
    "eingestaubter": "eingestaubt",
    "eingestaubtere": "eingestaubt",
    "eingestaubterem": "eingestaubt",
    "eingestaubteren": "eingestaubt",
    "eingestaubterer": "eingestaubt",
    "eingestaubteres": "eingestaubt",
    "eingestaubtes": "eingestaubt",
    "eingestaubteste": "eingestaubt",
    "eingestaubtestem": "eingestaubt",
    "eingestaubtesten": "eingestaubt",
    "eingestaubtester": "eingestaubt",
    "eingestaubtestes": "eingestaubt",
    "eingesteckt": "einstecken",
    "eingesteckte": "eingesteckt",
    "eingestecktem": "eingesteckt",
    "eingesteckten": "eingesteckt",
    "eingesteckter": "eingesteckt",
    "eingestecktes": "eingesteckt",
    "eingestehe": "eingestehen",
    "eingestehend": "eingestehen",
    "eingestehende": "eingestehend",
    "eingestehendem": "eingestehend",
    "eingestehenden": "eingestehend",
    "eingestehender": "eingestehend",
    "eingestehendere": "eingestehend",
    "eingestehenderem": "eingestehend",
    "eingestehenderen": "eingestehend",
    "eingestehenderer": "eingestehend",
    "eingestehenderes": "eingestehend",
    "eingestehendes": "eingestehend",
    "eingestehendste": "eingestehend",
    "eingestehendstem": "eingestehend",
    "eingestehendsten": "eingestehend",
    "eingestehendster": "eingestehend",
    "eingestehendstes": "eingestehend",
    "eingestehest": "eingestehen",
    "eingestehet": "eingestehen",
    "eingestehst": "eingestehen",
    "eingesteht": "eingestehen",
    "eingestellt": "einstellen",
    "eingestellte": "eingestellt",
    "eingestelltem": "eingestellt",
    "eingestellten": "eingestellt",
    "eingestellter": "eingestellt",
    "eingestelltes": "eingestellt",
    "eingestiegen": "einsteigen",
    "eingestiegene": "eingestiegen",
    "eingestiegenem": "eingestiegen",
    "eingestiegenen": "eingestiegen",
    "eingestiegener": "eingestiegen",
    "eingestiegenes": "eingestiegen",
    "eingestimmt": "einstimmen",
    "eingestimmte": "eingestimmt",
    "eingestimmtem": "eingestimmt",
    "eingestimmten": "eingestimmt",
    "eingestimmter": "eingestimmt",
    "eingestimmtes": "eingestimmt",
    "eingestippt": "einstippen",
    "eingestippte": "eingestippt",
    "eingestipptem": "eingestippt",
    "eingestippten": "eingestippt",
    "eingestippter": "eingestippt",
    "eingestipptes": "eingestippt",
    "eingestochen": "einstechen",
    "eingestochene": "eingestochen",
    "eingestochenem": "eingestochen",
    "eingestochenen": "eingestochen",
    "eingestochener": "eingestochen",
    "eingestochenes": "eingestochen",
    "eingestrahlt": "einstrahlen",
    "eingestrahlte": "eingestrahlt",
    "eingestrahltem": "eingestrahlt",
    "eingestrahlten": "eingestrahlt",
    "eingestrahlter": "eingestrahlt",
    "eingestrahltes": "eingestrahlt",
    "eingestreut": "einstreuen",
    "eingestreute": "eingestreut",
    "eingestreutem": "eingestreut",
    "eingestreuten": "eingestreut",
    "eingestreuter": "eingestreut",
    "eingestreutes": "eingestreut",
    "eingestrichen": "einstreichen",
    "eingestrichene": "eingestrichen",
    "eingestrichenem": "eingestrichen",
    "eingestrichenen": "eingestrichen",
    "eingestrichener": "eingestrichen",
    "eingestrichenes": "eingestrichen",
    "eingeströmt": "einströmen",
    "eingeströmte": "eingeströmt",
    "eingeströmtem": "eingeströmt",
    "eingeströmten": "eingeströmt",
    "eingeströmter": "eingeströmt",
    "eingeströmtes": "eingeströmt",
    "eingestuft": "einstufen",
    "eingestufte": "eingestuft",
    "eingestuftem": "eingestuft",
    "eingestuften": "eingestuft",
    "eingestufter": "eingestuft",
    "eingestuftes": "eingestuft",
    "eingestände": "eingestehen",
    "eingeständen": "eingestehen",
    "eingeständest": "eingestehen",
    "eingeständet": "eingestehen",
    "eingestülpt": "einstülpen",
    "eingestülpte": "eingestülpt",
    "eingestülptem": "eingestülpt",
    "eingestülpten": "eingestülpt",
    "eingestülpter": "eingestülpt",
    "eingestülptes": "eingestülpt",
    "eingestürmt": "einstürmen",
    "eingestürmte": "eingestürmt",
    "eingestürmtem": "eingestürmt",
    "eingestürmten": "eingestürmt",
    "eingestürmter": "eingestürmt",
    "eingestürmtes": "eingestürmt",
    "eingestürzt": "einstürzen",
    "eingestürzte": "eingestürzt",
    "eingestürztem": "eingestürzt",
    "eingestürzten": "eingestürzt",
    "eingestürzter": "eingestürzt",
    "eingestürztere": "eingestürzt",
    "eingestürzterem": "eingestürzt",
    "eingestürzteren": "eingestürzt",
    "eingestürzterer": "eingestürzt",
    "eingestürzteres": "eingestürzt",
    "eingestürztes": "eingestürzt",
    "eingestürzteste": "eingestürzt",
    "eingestürztestem": "eingestürzt",
    "eingestürztesten": "eingestürzt",
    "eingestürztester": "eingestürzt",
    "eingestürztestes": "eingestürzt",
    "eingesungen": "einsingen",
    "eingesungene": "eingesungen",
    "eingesungenem": "eingesungen",
    "eingesungenen": "eingesungen",
    "eingesungener": "eingesungen",
    "eingesungenes": "eingesungen",
    "eingesunken": "einsinken",
    "eingesunkene": "eingesunken",
    "eingesunkenem": "eingesunken",
    "eingesunkenen": "eingesunken",
    "eingesunkener": "eingesunken",
    "eingesunkenes": "eingesunken",
    "eingesägt": "einsägen",
    "eingesägtem": "eingesägt",
    "eingesägter": "eingesägt",
    "eingesägtes": "eingesägt",
    "eingesäuert": "einsäuern",
    "eingesäuerte": "eingesäuert",
    "eingesäuertem": "eingesäuert",
    "eingesäuerten": "eingesäuert",
    "eingesäuerter": "eingesäuert",
    "eingesäuertere": "eingesäuert",
    "eingesäuerterem": "eingesäuert",
    "eingesäuerteren": "eingesäuert",
    "eingesäuerterer": "eingesäuert",
    "eingesäuerteres": "eingesäuert",
    "eingesäuertes": "eingesäuert",
    "eingesäuerteste": "eingesäuert",
    "eingesäuertestem": "eingesäuert",
    "eingesäuertesten": "eingesäuert",
    "eingesäuertester": "eingesäuert",
    "eingesäuertestes": "eingesäuert",
    "eingesäumt": "einsäumen",
    "eingesäumte": "eingesäumt",
    "eingesäumtem": "eingesäumt",
    "eingesäumten": "eingesäumt",
    "eingesäumter": "eingesäumt",
    "eingesäumtes": "eingesäumt",
    "eingetanzt": "eintanzen",
    "eingetanzte": "eingetanzt",
    "eingetanztem": "eingetanzt",
    "eingetanzten": "eingetanzt",
    "eingetanzter": "eingetanzt",
    "eingetanztes": "eingetanzt",
    "eingetaucht": "eintauchen",
    "eingetauchte": "eingetaucht",
    "eingetauchtem": "eingetaucht",
    "eingetauchten": "eingetaucht",
    "eingetauchter": "eingetaucht",
    "eingetauchtes": "eingetaucht",
    "eingetauscht": "eintauschen",
    "eingetauschte": "eingetauscht",
    "eingetauschtem": "eingetauscht",
    "eingetauschten": "eingetauscht",
    "eingetauschter": "eingetauscht",
    "eingetauschtes": "eingetauscht",
    "eingeteilt": "einteilen",
    "eingeteilte": "eingeteilt",
    "eingeteiltem": "eingeteilt",
    "eingeteilten": "eingeteilt",
    "eingeteilter": "eingeteilt",
    "eingeteiltes": "eingeteilt",
    "eingetopft": "eintopfen",
    "eingetopfte": "eingetopft",
    "eingetopftem": "eingetopft",
    "eingetopften": "eingetopft",
    "eingetopfter": "eingetopft",
    "eingetopftes": "eingetopft",
    "eingetragen": "eintragen",
    "eingetragene": "eingetragen",
    "eingetragenem": "eingetragen",
    "eingetragenen": "eingetragen",
    "eingetragener": "eingetragen",
    "eingetragenes": "eingetragen",
    "eingetreten": "eintreten",
    "eingetretene": "eingetreten",
    "eingetretenem": "eingetreten",
    "eingetretenen": "eingetreten",
    "eingetretener": "eingetreten",
    "eingetretenes": "eingetreten",
    "eingetrichtert": "eintrichtern",
    "eingetrichterte": "eingetrichtert",
    "eingetrichtertem": "eingetrichtert",
    "eingetrichterten": "eingetrichtert",
    "eingetrichterter": "eingetrichtert",
    "eingetrichtertes": "eingetrichtert",
    "eingetrieben": "eintreiben",
    "eingetriebene": "eingetrieben",
    "eingetriebenem": "eingetrieben",
    "eingetriebenen": "eingetrieben",
    "eingetriebener": "eingetrieben",
    "eingetriebenes": "eingetrieben",
    "eingetrocknet": "eintrocknen",
    "eingetrocknete": "eingetrocknet",
    "eingetrocknetem": "eingetrocknet",
    "eingetrockneten": "eingetrocknet",
    "eingetrockneter": "eingetrocknet",
    "eingetrocknetere": "eingetrocknet",
    "eingetrockneterem": "eingetrocknet",
    "eingetrockneteren": "eingetrocknet",
    "eingetrockneterer": "eingetrocknet",
    "eingetrockneteres": "eingetrocknet",
    "eingetrocknetes": "eingetrocknet",
    "eingetrockneteste": "eingetrocknet",
    "eingetrocknetestem": "eingetrocknet",
    "eingetrocknetesten": "eingetrocknet",
    "eingetrocknetester": "eingetrocknet",
    "eingetrocknetestes": "eingetrocknet",
    "eingetroffen": "eintreffen",
    "eingetroffene": "eingetroffen",
    "eingetroffenem": "eingetroffen",
    "eingetroffenen": "eingetroffen",
    "eingetroffener": "eingetroffen",
    "eingetroffenes": "eingetroffen",
    "eingetrudelt": "eintrudeln",
    "eingetrudelte": "eingetrudelt",
    "eingetrudeltem": "eingetrudelt",
    "eingetrudelten": "eingetrudelt",
    "eingetrudelter": "eingetrudelt",
    "eingetrudeltes": "eingetrudelt",
    "eingeträufelt": "einträufeln",
    "eingeträufelte": "eingeträufelt",
    "eingeträufeltem": "eingeträufelt",
    "eingeträufelten": "eingeträufelt",
    "eingeträufelter": "eingeträufelt",
    "eingeträufeltes": "eingeträufelt",
    "eingetrübt": "eintrüben",
    "eingetrübte": "eingetrübt",
    "eingetrübtem": "eingetrübt",
    "eingetrübten": "eingetrübt",
    "eingetrübter": "eingetrübt",
    "eingetrübtes": "eingetrübt",
    "eingetunkt": "eintunken",
    "eingetunkte": "eingetunkt",
    "eingetunktem": "eingetunkt",
    "eingetunkten": "eingetunkt",
    "eingetunkter": "eingetunkt",
    "eingetunktes": "eingetunkt",
    "eingetütet": "eintüten",
    "eingetütete": "eingetütet",
    "eingetütetem": "eingetütet",
    "eingetüteten": "eingetütet",
    "eingetüteter": "eingetütet",
    "eingetütetes": "eingetütet",
    "eingewachsen": "einwachsen",
    "eingewachsene": "eingewachsen",
    "eingewachsenem": "eingewachsen",
    "eingewachsenen": "eingewachsen",
    "eingewachsener": "eingewachsen",
    "eingewachsenes": "eingewachsen",
    "eingewachst": "einwachsen",
    "eingewachste": "eingewachst",
    "eingewachstem": "eingewachst",
    "eingewachsten": "eingewachst",
    "eingewachster": "eingewachst",
    "eingewachstes": "eingewachst",
    "eingewandert": "einwandern",
    "eingewanderte": "eingewandert",
    "eingewandertem": "eingewandert",
    "eingewanderten": "eingewandert",
    "eingewanderter": "eingewandert",
    "eingewandertes": "eingewandert",
    "eingewandt": "einwenden",
    "eingewandte": "eingewandt",
    "eingewandtem": "eingewandt",
    "eingewandten": "eingewandt",
    "eingewandter": "eingewandt",
    "eingewandtes": "eingewandt",
    "eingewebt": "einweben",
    "eingewebte": "eingewebt",
    "eingewebtem": "eingewebt",
    "eingewebten": "eingewebt",
    "eingewebter": "eingewebt",
    "eingewebtes": "eingewebt",
    "eingewechselt": "einwechseln",
    "eingewechselte": "eingewechselt",
    "eingewechseltem": "eingewechselt",
    "eingewechselten": "eingewechselt",
    "eingewechselter": "eingewechselt",
    "eingewechseltes": "eingewechselt",
    "eingeweicht": "einweichen",
    "eingeweichte": "eingeweicht",
    "eingeweichtem": "eingeweicht",
    "eingeweichten": "eingeweicht",
    "eingeweichter": "eingeweicht",
    "eingeweichtes": "eingeweicht",
    "eingeweiht": "einweihen",
    "eingeweihte": "eingeweiht",
    "eingeweihtem": "eingeweiht",
    "eingeweihten": "eingeweiht",
    "eingeweihter": "eingeweiht",
    "eingeweihtes": "eingeweiht",
    "eingewendet": "einwenden",
    "eingewendete": "eingewendet",
    "eingewendetem": "eingewendet",
    "eingewendeten": "eingewendet",
    "eingewendeter": "eingewendet",
    "eingewendetes": "eingewendet",
    "eingewickelt": "einwickeln",
    "eingewickelte": "eingewickelt",
    "eingewickeltem": "eingewickelt",
    "eingewickelten": "eingewickelt",
    "eingewickelter": "eingewickelt",
    "eingewickeltere": "eingewickelt",
    "eingewickelterem": "eingewickelt",
    "eingewickelteren": "eingewickelt",
    "eingewickelterer": "eingewickelt",
    "eingewickelteres": "eingewickelt",
    "eingewickeltes": "eingewickelt",
    "eingewickelteste": "eingewickelt",
    "eingewickeltestem": "eingewickelt",
    "eingewickeltesten": "eingewickelt",
    "eingewickeltester": "eingewickelt",
    "eingewickeltestes": "eingewickelt",
    "eingewiesen": "einweisen",
    "eingewiesene": "eingewiesen",
    "eingewiesenem": "eingewiesen",
    "eingewiesenen": "eingewiesen",
    "eingewiesener": "eingewiesen",
    "eingewiesenes": "eingewiesen",
    "eingewilligt": "einwilligen",
    "eingewilligte": "eingewilligt",
    "eingewilligtem": "eingewilligt",
    "eingewilligten": "eingewilligt",
    "eingewilligter": "eingewilligt",
    "eingewilligtes": "eingewilligt",
    "eingewinkt": "einwinken",
    "eingewinkte": "eingewinkt",
    "eingewinktem": "eingewinkt",
    "eingewinkten": "eingewinkt",
    "eingewinkter": "eingewinkt",
    "eingewinktes": "eingewinkt",
    "eingewirkt": "einwirken",
    "eingewirkte": "eingewirkt",
    "eingewirktem": "eingewirkt",
    "eingewirkten": "eingewirkt",
    "eingewirkter": "eingewirkt",
    "eingewirktes": "eingewirkt",
    "eingewoben": "einweben",
    "eingewobene": "eingewoben",
    "eingewobenem": "eingewoben",
    "eingewobenen": "eingewoben",
    "eingewobener": "eingewoben",
    "eingewobenes": "eingewoben",
    "eingewogen": "einwiegen",
    "eingewogene": "eingewogen",
    "eingewogenem": "eingewogen",
    "eingewogenen": "eingewogen",
    "eingewogener": "eingewogen",
    "eingewogenes": "eingewogen",
    "eingewohnt": "einwohnen",
    "eingewohnte": "eingewohnt",
    "eingewohntem": "eingewohnt",
    "eingewohnten": "eingewohnt",
    "eingewohnter": "eingewohnt",
    "eingewohntes": "eingewohnt",
    "eingeworfen": "einwerfen",
    "eingeworfene": "eingeworfen",
    "eingeworfenem": "eingeworfen",
    "eingeworfenen": "eingeworfen",
    "eingeworfener": "eingeworfen",
    "eingeworfenes": "eingeworfen",
    "eingewurzelt": "einwurzeln",
    "eingewurzelte": "eingewurzelt",
    "eingewurzeltem": "eingewurzelt",
    "eingewurzelten": "eingewurzelt",
    "eingewurzelter": "eingewurzelt",
    "eingewurzeltes": "eingewurzelt",
    "eingewöhne": "eingewöhnen",
    "eingewöhnend": "eingewöhnen",
    "eingewöhnende": "eingewöhnend",
    "eingewöhnendem": "eingewöhnend",
    "eingewöhnenden": "eingewöhnend",
    "eingewöhnender": "eingewöhnend",
    "eingewöhnendere": "eingewöhnend",
    "eingewöhnenderem": "eingewöhnend",
    "eingewöhnenderen": "eingewöhnend",
    "eingewöhnenderer": "eingewöhnend",
    "eingewöhnenderes": "eingewöhnend",
    "eingewöhnendes": "eingewöhnend",
    "eingewöhnendste": "eingewöhnend",
    "eingewöhnendstem": "eingewöhnend",
    "eingewöhnendsten": "eingewöhnend",
    "eingewöhnendster": "eingewöhnend",
    "eingewöhnendstes": "eingewöhnend",
    "eingewöhnest": "eingewöhnen",
    "eingewöhnet": "eingewöhnen",
    "eingewöhnst": "eingewöhnen",
    "eingewöhnt": "eingewöhnen",
    "eingewöhnte": "eingewöhnt",
    "eingewöhntem": "eingewöhnt",
    "eingewöhnten": "eingewöhnt",
    "eingewöhnter": "eingewöhnt",
    "eingewöhntere": "eingewöhnt",
    "eingewöhnterem": "eingewöhnt",
    "eingewöhnteren": "eingewöhnt",
    "eingewöhnterer": "eingewöhnt",
    "eingewöhnteres": "eingewöhnt",
    "eingewöhntes": "eingewöhnt",
    "eingewöhntest": "eingewöhnen",
    "eingewöhnteste": "eingewöhnt",
    "eingewöhntestem": "eingewöhnt",
    "eingewöhntesten": "eingewöhnt",
    "eingewöhntester": "eingewöhnt",
    "eingewöhntestes": "eingewöhnt",
    "eingewöhntet": "eingewöhnen",
    "eingezahlt": "einzahlen",
    "eingezahlte": "eingezahlt",
    "eingezahltem": "eingezahlt",
    "eingezahlten": "eingezahlt",
    "eingezahlter": "eingezahlt",
    "eingezahltes": "eingezahlt",
    "eingezeichnet": "einzeichnen",
    "eingezeichnete": "eingezeichnet",
    "eingezeichnetem": "eingezeichnet",
    "eingezeichneten": "eingezeichnet",
    "eingezeichneter": "eingezeichnet",
    "eingezeichnetes": "eingezeichnet",
    "eingezogen": "einziehen",
    "eingezogene": "eingezogen",
    "eingezogenem": "eingezogen",
    "eingezogenen": "eingezogen",
    "eingezogener": "eingezogen",
    "eingezogenes": "eingezogen",
    "eingezwängt": "einzwängen",
    "eingezwängte": "eingezwängt",
    "eingezwängtem": "eingezwängt",
    "eingezwängten": "eingezwängt",
    "eingezwängter": "eingezwängt",
    "eingezwängtes": "eingezwängt",
    "eingezäunt": "einzäunen",
    "eingezäunte": "eingezäunt",
    "eingezäuntem": "eingezäunt",
    "eingezäunten": "eingezäunt",
    "eingezäunter": "eingezäunt",
    "eingezäuntes": "eingezäunt",
    "eingeäschert": "einäschern",
    "eingeäscherte": "eingeäschert",
    "eingeäschertem": "eingeäschert",
    "eingeäscherten": "eingeäschert",
    "eingeäscherter": "eingeäschert",
    "eingeäschertes": "eingeäschert",
    "eingeölt": "einölen",
    "eingeölte": "eingeölt",
    "eingeöltem": "eingeölt",
    "eingeölten": "eingeölt",
    "eingeölter": "eingeölt",
    "eingeöltere": "eingeölt",
    "eingeölterem": "eingeölt",
    "eingeölteren": "eingeölt",
    "eingeölterer": "eingeölt",
    "eingeölteres": "eingeölt",
    "eingeöltes": "eingeölt",
    "eingeölteste": "eingeölt",
    "eingeöltestem": "eingeölt",
    "eingeöltesten": "eingeölt",
    "eingeöltester": "eingeölt",
    "eingeöltestes": "eingeölt",
    "eingeübt": "einüben",
    "eingeübte": "eingeübt",
    "eingeübtem": "eingeübt",
    "eingeübten": "eingeübt",
    "eingeübter": "eingeübt",
    "eingeübtere": "eingeübt",
    "eingeübterem": "eingeübt",
    "eingeübteren": "eingeübt",
    "eingeübterer": "eingeübt",
    "eingeübteres": "eingeübt",
    "eingeübtes": "eingeübt",
    "eingeübteste": "eingeübt",
    "eingeübtestem": "eingeübt",
    "eingeübtesten": "eingeübt",
    "eingeübtester": "eingeübt",
    "eingeübtestes": "eingeübt",
    "eingibst": "eingeben",
    "eingibt": "eingeben",
    "eingieße": "eingießen",
    "eingießend": "eingießen",
    "eingießende": "eingießend",
    "eingießendem": "eingießend",
    "eingießenden": "eingießend",
    "eingießender": "eingießend",
    "eingießendes": "eingießend",
    "eingießest": "eingießen",
    "eingießet": "eingießen",
    "eingießt": "eingießen",
    "einging": "eingehen",
    "einginge": "eingehen",
    "eingingen": "eingehen",
    "eingingest": "eingehen",
    "einginget": "eingehen",
    "eingingst": "eingehen",
    "eingingt": "eingehen",
    "eingipse": "eingipsen",
    "eingipsend": "eingipsen",
    "eingipsende": "eingipsend",
    "eingipsendem": "eingipsend",
    "eingipsenden": "eingipsend",
    "eingipsender": "eingipsend",
    "eingipsendes": "eingipsend",
    "eingipsest": "eingipsen",
    "eingipset": "eingipsen",
    "eingipst": "eingipsen",
    "eingipste": "eingipsen",
    "eingipsten": "eingipsen",
    "eingipstest": "eingipsen",
    "eingipstet": "eingipsen",
    "eingittere": "eingittern",
    "eingitternd": "eingittern",
    "eingitternde": "eingitternd",
    "eingitterndem": "eingitternd",
    "eingitternden": "eingitternd",
    "eingitternder": "eingitternd",
    "eingitterndes": "eingitternd",
    "eingitterst": "eingittern",
    "eingittert": "eingittern",
    "eingitterte": "eingittern",
    "eingitterten": "eingittern",
    "eingittertest": "eingittern",
    "eingittertet": "eingittern",
    "einglase": "einglasen",
    "einglasend": "einglasen",
    "einglasende": "einglasend",
    "einglasendem": "einglasend",
    "einglasenden": "einglasend",
    "einglasender": "einglasend",
    "einglasendes": "einglasend",
    "einglasest": "einglasen",
    "einglaset": "einglasen",
    "einglast": "einglasen",
    "einglaste": "einglasen",
    "einglasten": "einglasen",
    "einglastest": "einglasen",
    "einglastet": "einglasen",
    "eingleise": "eingleisen",
    "eingleisend": "eingleisen",
    "eingleisende": "eingleisend",
    "eingleisendem": "eingleisend",
    "eingleisenden": "eingleisend",
    "eingleisender": "eingleisend",
    "eingleisendes": "eingleisend",
    "eingleisest": "eingleisen",
    "eingleiset": "eingleisen",
    "eingleisige": "eingleisig",
    "eingleisigem": "eingleisig",
    "eingleisigen": "eingleisig",
    "eingleisiger": "eingleisig",
    "eingleisiges": "eingleisig",
    "eingleist": "eingleisen",
    "eingleiste": "eingleisen",
    "eingleisten": "eingleisen",
    "eingleistest": "eingleisen",
    "eingleistet": "eingleisen",
    "eingliedere": "eingliedern",
    "eingliedernd": "eingliedern",
    "eingliedernde": "eingliedernd",
    "eingliederndem": "eingliedernd",
    "eingliedernden": "eingliedernd",
    "eingliedernder": "eingliedernd",
    "eingliederndes": "eingliedernd",
    "eingliederst": "eingliedern",
    "eingliedert": "eingliedern",
    "eingliederte": "eingliedern",
    "eingliederten": "eingliedern",
    "eingliedertest": "eingliedern",
    "eingliedertet": "eingliedern",
    "eingossen": "eingießen",
    "eingoß": "eingießen",
    "eingoßt": "eingießen",
    "eingrabe": "eingraben",
    "eingrabend": "eingraben",
    "eingrabende": "eingrabend",
    "eingrabendem": "eingrabend",
    "eingrabenden": "eingrabend",
    "eingrabender": "eingrabend",
    "eingrabendes": "eingrabend",
    "eingrabest": "eingraben",
    "eingrabet": "eingraben",
    "eingrabt": "eingraben",
    "eingreife": "eingreifen",
    "eingreifend": "eingreifen",
    "eingreifende": "eingreifend",
    "eingreifendem": "eingreifend",
    "eingreifenden": "eingreifend",
    "eingreifender": "eingreifend",
    "eingreifendes": "eingreifend",
    "eingreifest": "eingreifen",
    "eingreifet": "eingreifen",
    "eingreifst": "eingreifen",
    "eingreift": "eingreifen",
    "eingrenze": "eingrenzen",
    "eingrenzend": "eingrenzen",
    "eingrenzende": "eingrenzend",
    "eingrenzendem": "eingrenzend",
    "eingrenzenden": "eingrenzend",
    "eingrenzender": "eingrenzend",
    "eingrenzendes": "eingrenzend",
    "eingrenzest": "eingrenzen",
    "eingrenzet": "eingrenzen",
    "eingrenzt": "eingrenzen",
    "eingrenzte": "eingrenzen",
    "eingrenzten": "eingrenzen",
    "eingrenztest": "eingrenzen",
    "eingrenztet": "eingrenzen",
    "eingriff": "eingreifen",
    "eingriffest": "eingreifen",
    "eingriffet": "eingreifen",
    "eingriffst": "eingreifen",
    "eingrifft": "eingreifen",
    "eingrub": "eingraben",
    "eingruben": "eingraben",
    "eingrubst": "eingraben",
    "eingrubt": "eingraben",
    "eingruppiere": "eingruppieren",
    "eingruppierend": "eingruppieren",
    "eingruppierende": "eingruppierend",
    "eingruppierendem": "eingruppierend",
    "eingruppierenden": "eingruppierend",
    "eingruppierender": "eingruppierend",
    "eingruppierendes": "eingruppierend",
    "eingruppierest": "eingruppieren",
    "eingruppieret": "eingruppieren",
    "eingruppierst": "eingruppieren",
    "eingruppiert": "eingruppieren",
    "eingruppierte": "eingruppieren",
    "eingruppiertem": "eingruppiert",
    "eingruppierten": "eingruppieren",
    "eingruppierter": "eingruppiert",
    "eingruppiertes": "eingruppiert",
    "eingruppiertest": "eingruppieren",
    "eingruppiertet": "eingruppieren",
    "eingräbst": "eingraben",
    "eingräbt": "eingraben",
    "eingrübe": "eingraben",
    "eingrüben": "eingraben",
    "eingrübest": "eingraben",
    "eingrübet": "eingraben",
    "eingäbe": "eingeben",
    "eingäben": "eingeben",
    "eingäbest": "eingeben",
    "eingäbet": "eingeben",
    "eingängigem": "eingängig",
    "eingängigen": "eingängig",
    "eingängiger": "eingängig",
    "eingängigere": "eingängig",
    "eingängigerem": "eingängig",
    "eingängigeren": "eingängig",
    "eingängigerer": "eingängig",
    "eingängigeres": "eingängig",
    "eingängiges": "eingängig",
    "eingängigste": "eingängig",
    "eingängigstem": "eingängig",
    "eingängigsten": "eingängig",
    "eingängigster": "eingängig",
    "eingängigstes": "eingängig",
    "eingösse": "eingießen",
    "eingössen": "eingießen",
    "eingössest": "eingießen",
    "eingösset": "eingießen",
    "einhake": "einhaken",
    "einhakend": "einhaken",
    "einhakende": "einhakend",
    "einhakendem": "einhakend",
    "einhakenden": "einhakend",
    "einhakender": "einhakend",
    "einhakendes": "einhakend",
    "einhakest": "einhaken",
    "einhaket": "einhaken",
    "einhakst": "einhaken",
    "einhakt": "einhaken",
    "einhakte": "einhaken",
    "einhakten": "einhaken",
    "einhaktest": "einhaken",
    "einhaktet": "einhaken",
    "einhalf": "einhelfen",
    "einhalfen": "einhelfen",
    "einhalfst": "einhelfen",
    "einhalft": "einhelfen",
    "einhalte": "einhalten",
    "einhaltend": "einhalten",
    "einhaltende": "einhaltend",
    "einhaltendem": "einhaltend",
    "einhaltenden": "einhaltend",
    "einhaltender": "einhaltend",
    "einhaltendes": "einhaltend",
    "einhaltest": "einhalten",
    "einhaltet": "einhalten",
    "einhandele": "einhandeln",
    "einhandelnd": "einhandeln",
    "einhandelnde": "einhandelnd",
    "einhandelndem": "einhandelnd",
    "einhandelnden": "einhandelnd",
    "einhandelnder": "einhandelnd",
    "einhandelndes": "einhandelnd",
    "einhandelst": "einhandeln",
    "einhandelt": "einhandeln",
    "einhandelte": "einhandeln",
    "einhandelten": "einhandeln",
    "einhandeltest": "einhandeln",
    "einhandeltet": "einhandeln",
    "einhandle": "einhandeln",
    "einhaue": "einhauen",
    "einhauend": "einhauen",
    "einhauende": "einhauend",
    "einhauendem": "einhauend",
    "einhauenden": "einhauend",
    "einhauender": "einhauend",
    "einhauendes": "einhauend",
    "einhauest": "einhauen",
    "einhauet": "einhauen",
    "einhaust": "einhauen",
    "einhaut": "einhauen",
    "einhaute": "einhauen",
    "einhauten": "einhauen",
    "einhautest": "einhauen",
    "einhautet": "einhauen",
    "einhebe": "einheben",
    "einhebend": "einheben",
    "einhebende": "einhebend",
    "einhebendem": "einhebend",
    "einhebenden": "einhebend",
    "einhebender": "einhebend",
    "einhebendes": "einhebend",
    "einhebest": "einheben",
    "einhebet": "einheben",
    "einhebst": "einheben",
    "einhebt": "einheben",
    "einhefte": "einheften",
    "einheftend": "einheften",
    "einheftende": "einheftend",
    "einheftendem": "einheftend",
    "einheftenden": "einheftend",
    "einheftender": "einheftend",
    "einheftendes": "einheftend",
    "einheftest": "einheften",
    "einheftet": "einheften",
    "einheftete": "einheften",
    "einhefteten": "einheften",
    "einheftetest": "einheften",
    "einheftetet": "einheften",
    "einheile": "einheilen",
    "einheilend": "einheilen",
    "einheilende": "einheilend",
    "einheilendem": "einheilend",
    "einheilenden": "einheilend",
    "einheilender": "einheilend",
    "einheilendes": "einheilend",
    "einheilest": "einheilen",
    "einheilet": "einheilen",
    "einheilst": "einheilen",
    "einheilt": "einheilen",
    "einheilte": "einheilen",
    "einheilten": "einheilen",
    "einheiltest": "einheilen",
    "einheiltet": "einheilen",
    "einheimische": "einheimisch",
    "einheimischem": "einheimisch",
    "einheimischen": "einheimisch",
    "einheimischer": "einheimisch",
    "einheimisches": "einheimisch",
    "einheimse": "einheimsen",
    "einheimsend": "einheimsen",
    "einheimsende": "einheimsend",
    "einheimsendem": "einheimsend",
    "einheimsenden": "einheimsend",
    "einheimsender": "einheimsend",
    "einheimsendere": "einheimsend",
    "einheimsenderem": "einheimsend",
    "einheimsenderen": "einheimsend",
    "einheimsenderer": "einheimsend",
    "einheimsenderes": "einheimsend",
    "einheimsendes": "einheimsend",
    "einheimsendste": "einheimsend",
    "einheimsendstem": "einheimsend",
    "einheimsendsten": "einheimsend",
    "einheimsendster": "einheimsend",
    "einheimsendstes": "einheimsend",
    "einheimsest": "einheimsen",
    "einheimset": "einheimsen",
    "einheimst": "einheimsen",
    "einheimste": "einheimsen",
    "einheimsten": "einheimsen",
    "einheimstest": "einheimsen",
    "einheimstet": "einheimsen",
    "einheirate": "einheiraten",
    "einheiratend": "einheiraten",
    "einheiratende": "einheiratend",
    "einheiratendem": "einheiratend",
    "einheiratenden": "einheiratend",
    "einheiratender": "einheiratend",
    "einheiratendes": "einheiratend",
    "einheiratest": "einheiraten",
    "einheiratet": "einheiraten",
    "einheiratete": "einheiraten",
    "einheirateten": "einheiraten",
    "einheiratetest": "einheiraten",
    "einheiratetet": "einheiraten",
    "einheitlichem": "einheitlich",
    "einheitlichen": "einheitlich",
    "einheitlicher": "einheitlich",
    "einheitlichere": "einheitlich",
    "einheitlicherem": "einheitlich",
    "einheitlicheren": "einheitlich",
    "einheitlicherer": "einheitlich",
    "einheitlicheres": "einheitlich",
    "einheitliches": "einheitlich",
    "einheitlichste": "einheitlich",
    "einheitlichstem": "einheitlich",
    "einheitlichsten": "einheitlich",
    "einheitlichster": "einheitlich",
    "einheitlichstes": "einheitlich",
    "einheize": "einheizen",
    "einheizend": "einheizen",
    "einheizende": "einheizend",
    "einheizendem": "einheizend",
    "einheizenden": "einheizend",
    "einheizender": "einheizend",
    "einheizendere": "einheizend",
    "einheizenderem": "einheizend",
    "einheizenderen": "einheizend",
    "einheizenderer": "einheizend",
    "einheizenderes": "einheizend",
    "einheizendes": "einheizend",
    "einheizendste": "einheizend",
    "einheizendstem": "einheizend",
    "einheizendsten": "einheizend",
    "einheizendster": "einheizend",
    "einheizendstes": "einheizend",
    "einheizest": "einheizen",
    "einheizet": "einheizen",
    "einheizt": "einheizen",
    "einheizte": "einheizen",
    "einheizten": "einheizen",
    "einheiztest": "einheizen",
    "einheiztet": "einheizen",
    "einhelfe": "einhelfen",
    "einhelfend": "einhelfen",
    "einhelfende": "einhelfend",
    "einhelfendem": "einhelfend",
    "einhelfenden": "einhelfend",
    "einhelfender": "einhelfend",
    "einhelfendes": "einhelfend",
    "einhelfest": "einhelfen",
    "einhelfet": "einhelfen",
    "einhelft": "einhelfen",
    "einhellige": "einhellig",
    "einhelligem": "einhellig",
    "einhelligen": "einhellig",
    "einhelliger": "einhellig",
    "einhelliges": "einhellig",
    "einherbrause": "einherbrausen",
    "einherbrausend": "einherbrausen",
    "einherbrausende": "einherbrausend",
    "einherbrausendem": "einherbrausend",
    "einherbrausenden": "einherbrausend",
    "einherbrausender": "einherbrausend",
    "einherbrausendes": "einherbrausend",
    "einherbrausest": "einherbrausen",
    "einherbrauset": "einherbrausen",
    "einherbraust": "einherbrausen",
    "einherbrauste": "einherbrausen",
    "einherbrausten": "einherbrausen",
    "einherbraustest": "einherbrausen",
    "einherbraustet": "einherbrausen",
    "einhergebraust": "einherbrausen",
    "einhergebrauste": "einhergebraust",
    "einhergebraustem": "einhergebraust",
    "einhergebrausten": "einhergebraust",
    "einhergebrauster": "einhergebraust",
    "einhergebraustes": "einhergebraust",
    "einhergegangen": "einhergehen",
    "einhergegangene": "einhergegangen",
    "einhergegangenem": "einhergegangen",
    "einhergegangenen": "einhergegangen",
    "einhergegangener": "einhergegangen",
    "einhergegangenes": "einhergegangen",
    "einhergehe": "einhergehen",
    "einhergehend": "einhergehen",
    "einhergehende": "einhergehend",
    "einhergehendem": "einhergehend",
    "einhergehenden": "einhergehend",
    "einhergehender": "einhergehend",
    "einhergehendes": "einhergehend",
    "einhergehest": "einhergehen",
    "einhergehet": "einhergehen",
    "einhergehst": "einhergehen",
    "einhergeht": "einhergehen",
    "einhergejagt": "einherjagen",
    "einhergejagte": "einhergejagt",
    "einhergejagtem": "einhergejagt",
    "einhergejagten": "einhergejagt",
    "einhergejagter": "einhergejagt",
    "einhergejagtes": "einhergejagt",
    "einhergeritten": "einherreiten",
    "einhergerittene": "einhergeritten",
    "einhergerittenem": "einhergeritten",
    "einhergerittenen": "einhergeritten",
    "einhergerittener": "einhergeritten",
    "einhergerittenes": "einhergeritten",
    "einhergeschlendert": "einherschlendern",
    "einhergeschlenderte": "einhergeschlendert",
    "einhergeschlendertem": "einhergeschlendert",
    "einhergeschlenderten": "einhergeschlendert",
    "einhergeschlenderter": "einhergeschlendert",
    "einhergeschlendertes": "einhergeschlendert",
    "einhergeschritten": "einherschreiten",
    "einhergeschrittene": "einhergeschritten",
    "einhergeschrittenem": "einhergeschritten",
    "einhergeschrittenen": "einhergeschritten",
    "einhergeschrittener": "einhergeschritten",
    "einhergeschrittenes": "einhergeschritten",
    "einherging": "einhergehen",
    "einherginge": "einhergehen",
    "einhergingen": "einhergehen",
    "einhergingest": "einhergehen",
    "einherginget": "einhergehen",
    "einhergingst": "einhergehen",
    "einhergingt": "einhergehen",
    "einherjage": "einherjagen",
    "einherjagend": "einherjagen",
    "einherjagende": "einherjagend",
    "einherjagendem": "einherjagend",
    "einherjagenden": "einherjagend",
    "einherjagender": "einherjagend",
    "einherjagendes": "einherjagend",
    "einherjagest": "einherjagen",
    "einherjaget": "einherjagen",
    "einherjagst": "einherjagen",
    "einherjagt": "einherjagen",
    "einherjagte": "einherjagen",
    "einherjagten": "einherjagen",
    "einherjagtest": "einherjagen",
    "einherjagtet": "einherjagen",
    "einherreite": "einherreiten",
    "einherreitend": "einherreiten",
    "einherreitende": "einherreitend",
    "einherreitendem": "einherreitend",
    "einherreitenden": "einherreitend",
    "einherreitender": "einherreitend",
    "einherreitendes": "einherreitend",
    "einherreitest": "einherreiten",
    "einherreitet": "einherreiten",
    "einherritt": "einherreiten",
    "einherritte": "einherreiten",
    "einherritten": "einherreiten",
    "einherrittest": "einherreiten",
    "einherrittet": "einherreiten",
    "einherschlendere": "einherschlendern",
    "einherschlendernd": "einherschlendern",
    "einherschlendernde": "einherschlendernd",
    "einherschlenderndem": "einherschlendernd",
    "einherschlendernden": "einherschlendernd",
    "einherschlendernder": "einherschlendernd",
    "einherschlenderndes": "einherschlendernd",
    "einherschlenderst": "einherschlendern",
    "einherschlendert": "einherschlendern",
    "einherschlenderte": "einherschlendern",
    "einherschlenderten": "einherschlendern",
    "einherschlendertest": "einherschlendern",
    "einherschlendertet": "einherschlendern",
    "einherschreitend": "einherschreiten",
    "einherschreitende": "einherschreitend",
    "einherschreitendem": "einherschreitend",
    "einherschreitenden": "einherschreitend",
    "einherschreitender": "einherschreitend",
    "einherschreitendes": "einherschreitend",
    "einherzubrausen": "einherbrausen",
    "einherzugehen": "einhergehen",
    "einherzujagen": "einherjagen",
    "einherzureiten": "einherreiten",
    "einherzuschlendern": "einherschlendern",
    "einhielt": "einhalten",
    "einhielte": "einhalten",
    "einhielten": "einhalten",
    "einhieltest": "einhalten",
    "einhieltet": "einhalten",
    "einhieve": "einhieven",
    "einhievend": "einhieven",
    "einhievende": "einhievend",
    "einhievendem": "einhievend",
    "einhievenden": "einhievend",
    "einhievender": "einhievend",
    "einhievendes": "einhievend",
    "einhievest": "einhieven",
    "einhievet": "einhieven",
    "einhievst": "einhieven",
    "einhievt": "einhieven",
    "einhievte": "einhieven",
    "einhievten": "einhieven",
    "einhievtest": "einhieven",
    "einhievtet": "einhieven",
    "einhilfst": "einhelfen",
    "einhilft": "einhelfen",
    "einhing": "einhängen",
    "einhinge": "einhängen",
    "einhingen": "einhängen",
    "einhingest": "einhängen",
    "einhinget": "einhängen",
    "einhingst": "einhängen",
    "einhingt": "einhängen",
    "einhob": "einheben",
    "einhoben": "einheben",
    "einhobst": "einheben",
    "einhobt": "einheben",
    "einhole": "einholen",
    "einholend": "einholen",
    "einholende": "einholend",
    "einholendem": "einholend",
    "einholenden": "einholend",
    "einholender": "einholend",
    "einholendes": "einholend",
    "einholest": "einholen",
    "einholet": "einholen",
    "einholst": "einholen",
    "einholt": "einholen",
    "einholte": "einholen",
    "einholten": "einholen",
    "einholtest": "einholen",
    "einholtet": "einholen",
    "einhälfe": "einhelfen",
    "einhälfen": "einhelfen",
    "einhälfest": "einhelfen",
    "einhälfet": "einhelfen",
    "einhält": "einhalten",
    "einhältst": "einhalten",
    "einhändige": "einhändig",
    "einhändigem": "einhändig",
    "einhändigen": "einhändig",
    "einhändigend": "einhändigen",
    "einhändigende": "einhändigend",
    "einhändigendem": "einhändigend",
    "einhändigenden": "einhändigend",
    "einhändigender": "einhändigend",
    "einhändigendes": "einhändigend",
    "einhändiger": "einhändig",
    "einhändiges": "einhändig",
    "einhändigest": "einhändigen",
    "einhändiget": "einhändigen",
    "einhändigst": "einhändigen",
    "einhändigt": "einhändigen",
    "einhändigte": "einhändigen",
    "einhändigten": "einhändigen",
    "einhändigtest": "einhändigen",
    "einhändigtet": "einhändigen",
    "einhänge": "einhängen",
    "einhängend": "einhängen",
    "einhängende": "einhängend",
    "einhängendem": "einhängend",
    "einhängenden": "einhängend",
    "einhängender": "einhängend",
    "einhängendes": "einhängend",
    "einhängest": "einhängen",
    "einhänget": "einhängen",
    "einhängst": "einhängen",
    "einhängt": "einhängen",
    "einhängte": "einhängen",
    "einhängten": "einhängen",
    "einhängtest": "einhängen",
    "einhängtet": "einhängen",
    "einhöbe": "einheben",
    "einhöben": "einheben",
    "einhöbest": "einheben",
    "einhöbet": "einheben",
    "einhülle": "einhüllen",
    "einhüllend": "einhüllen",
    "einhüllende": "einhüllend",
    "einhüllendem": "einhüllend",
    "einhüllenden": "einhüllend",
    "einhüllender": "einhüllend",
    "einhüllendere": "einhüllend",
    "einhüllenderem": "einhüllend",
    "einhüllenderen": "einhüllend",
    "einhüllenderer": "einhüllend",
    "einhüllenderes": "einhüllend",
    "einhüllendes": "einhüllend",
    "einhüllendste": "einhüllend",
    "einhüllendstem": "einhüllend",
    "einhüllendsten": "einhüllend",
    "einhüllendster": "einhüllend",
    "einhüllendstes": "einhüllend",
    "einhüllest": "einhüllen",
    "einhüllet": "einhüllen",
    "einhüllst": "einhüllen",
    "einhüllt": "einhüllen",
    "einhüllte": "einhüllen",
    "einhüllten": "einhüllen",
    "einhülltest": "einhüllen",
    "einhülltet": "einhüllen",
    "einhüte": "einhüten",
    "einhütend": "einhüten",
    "einhütende": "einhütend",
    "einhütendem": "einhütend",
    "einhütenden": "einhütend",
    "einhütender": "einhütend",
    "einhütendes": "einhütend",
    "einhütest": "einhüten",
    "einhütet": "einhüten",
    "einhütete": "einhüten",
    "einhüteten": "einhüten",
    "einhütetest": "einhüten",
    "einhütetet": "einhüten",
    "einig": "einigen",
    "einige": "einig",
    "einigele": "einigeln",
    "einigelnd": "einigeln",
    "einigelnde": "einigelnd",
    "einigelndem": "einigelnd",
    "einigelnden": "einigelnd",
    "einigelnder": "einigelnd",
    "einigelndere": "einigelnd",
    "einigelnderem": "einigelnd",
    "einigelnderen": "einigelnd",
    "einigelnderer": "einigelnd",
    "einigelnderes": "einigelnd",
    "einigelndes": "einigelnd",
    "einigelndste": "einigelnd",
    "einigelndstem": "einigelnd",
    "einigelndsten": "einigelnd",
    "einigelndster": "einigelnd",
    "einigelndstes": "einigelnd",
    "einigelst": "einigeln",
    "einigelt": "einigeln",
    "einigelte": "einigeln",
    "einigelten": "einigeln",
    "einigeltest": "einigeln",
    "einigeltet": "einigeln",
    "einigem": "einig",
    "einigen": "einig",
    "einigend": "einigen",
    "einigende": "einigend",
    "einigendem": "einigend",
    "einigenden": "einigend",
    "einigender": "einigend",
    "einigendes": "einigend",
    "einiger": "einig",
    "einiges": "einig",
    "einigest": "einigen",
    "einiget": "einigen",
    "einigle": "einigeln",
    "einigst": "einigen",
    "einigt": "einigen",
    "einigte": "einigen",
    "einigten": "einigen",
    "einigtest": "einigen",
    "einigtet": "einigen",
    "einimpfe": "einimpfen",
    "einimpfend": "einimpfen",
    "einimpfende": "einimpfend",
    "einimpfendem": "einimpfend",
    "einimpfenden": "einimpfend",
    "einimpfender": "einimpfend",
    "einimpfendes": "einimpfend",
    "einimpfest": "einimpfen",
    "einimpfet": "einimpfen",
    "einimpfst": "einimpfen",
    "einimpft": "einimpfen",
    "einimpfte": "einimpfen",
    "einimpften": "einimpfen",
    "einimpftest": "einimpfen",
    "einimpftet": "einimpfen",
    "einjage": "einjagen",
    "einjagend": "einjagen",
    "einjagende": "einjagend",
    "einjagendem": "einjagend",
    "einjagenden": "einjagend",
    "einjagender": "einjagend",
    "einjagendes": "einjagend",
    "einjagest": "einjagen",
    "einjaget": "einjagen",
    "einjagst": "einjagen",
    "einjagt": "einjagen",
    "einjagte": "einjagen",
    "einjagten": "einjagen",
    "einjagtest": "einjagen",
    "einjagtet": "einjagen",
    "einjährige": "einjährig",
    "einjährigem": "einjährig",
    "einjährigen": "einjährig",
    "einjähriger": "einjährig",
    "einjähriges": "einjährig",
    "einkachele": "einkacheln",
    "einkachelnd": "einkacheln",
    "einkachelnde": "einkachelnd",
    "einkachelndem": "einkachelnd",
    "einkachelnden": "einkachelnd",
    "einkachelnder": "einkachelnd",
    "einkachelndere": "einkachelnd",
    "einkachelnderem": "einkachelnd",
    "einkachelnderen": "einkachelnd",
    "einkachelnderer": "einkachelnd",
    "einkachelnderes": "einkachelnd",
    "einkachelndes": "einkachelnd",
    "einkachelndste": "einkachelnd",
    "einkachelndstem": "einkachelnd",
    "einkachelndsten": "einkachelnd",
    "einkachelndster": "einkachelnd",
    "einkachelndstes": "einkachelnd",
    "einkachelst": "einkacheln",
    "einkachelt": "einkacheln",
    "einkachelte": "einkacheln",
    "einkachelten": "einkacheln",
    "einkacheltest": "einkacheln",
    "einkacheltet": "einkacheln",
    "einkachle": "einkacheln",
    "einkalkuliere": "einkalkulieren",
    "einkalkulierend": "einkalkulieren",
    "einkalkulierende": "einkalkulierend",
    "einkalkulierendem": "einkalkulierend",
    "einkalkulierenden": "einkalkulierend",
    "einkalkulierender": "einkalkulierend",
    "einkalkulierendes": "einkalkulierend",
    "einkalkulierest": "einkalkulieren",
    "einkalkulieret": "einkalkulieren",
    "einkalkulierst": "einkalkulieren",
    "einkalkuliert": "einkalkulieren",
    "einkalkulierte": "einkalkulieren",
    "einkalkuliertem": "einkalkuliert",
    "einkalkulierten": "einkalkulieren",
    "einkalkulierter": "einkalkuliert",
    "einkalkuliertes": "einkalkuliert",
    "einkalkuliertest": "einkalkulieren",
    "einkalkuliertet": "einkalkulieren",
    "einkapsele": "einkapseln",
    "einkapselnd": "einkapseln",
    "einkapselnde": "einkapselnd",
    "einkapselndem": "einkapselnd",
    "einkapselnden": "einkapselnd",
    "einkapselnder": "einkapselnd",
    "einkapselndere": "einkapselnd",
    "einkapselnderem": "einkapselnd",
    "einkapselnderen": "einkapselnd",
    "einkapselnderer": "einkapselnd",
    "einkapselnderes": "einkapselnd",
    "einkapselndes": "einkapselnd",
    "einkapselndste": "einkapselnd",
    "einkapselndstem": "einkapselnd",
    "einkapselndsten": "einkapselnd",
    "einkapselndster": "einkapselnd",
    "einkapselndstes": "einkapselnd",
    "einkapselst": "einkapseln",
    "einkapselt": "einkapseln",
    "einkapselte": "einkapseln",
    "einkapselten": "einkapseln",
    "einkapseltest": "einkapseln",
    "einkapseltet": "einkapseln",
    "einkapsle": "einkapseln",
    "einkassiere": "einkassieren",
    "einkassierend": "einkassieren",
    "einkassierende": "einkassierend",
    "einkassierendem": "einkassierend",
    "einkassierenden": "einkassierend",
    "einkassierender": "einkassierend",
    "einkassierendere": "einkassierend",
    "einkassierenderem": "einkassierend",
    "einkassierenderen": "einkassierend",
    "einkassierenderer": "einkassierend",
    "einkassierenderes": "einkassierend",
    "einkassierendes": "einkassierend",
    "einkassierendste": "einkassierend",
    "einkassierendstem": "einkassierend",
    "einkassierendsten": "einkassierend",
    "einkassierendster": "einkassierend",
    "einkassierendstes": "einkassierend",
    "einkassierest": "einkassieren",
    "einkassieret": "einkassieren",
    "einkassierst": "einkassieren",
    "einkassiert": "einkassieren",
    "einkassierte": "einkassieren",
    "einkassiertem": "einkassiert",
    "einkassierten": "einkassieren",
    "einkassierter": "einkassiert",
    "einkassiertere": "einkassiert",
    "einkassierterem": "einkassiert",
    "einkassierteren": "einkassiert",
    "einkassierterer": "einkassiert",
    "einkassierteres": "einkassiert",
    "einkassiertes": "einkassiert",
    "einkassiertest": "einkassieren",
    "einkassierteste": "einkassiert",
    "einkassiertestem": "einkassiert",
    "einkassiertesten": "einkassiert",
    "einkassiertester": "einkassiert",
    "einkassiertestes": "einkassiert",
    "einkassiertet": "einkassieren",
    "einkaufend": "einkaufen",
    "einkaufende": "einkaufend",
    "einkaufendem": "einkaufend",
    "einkaufenden": "einkaufend",
    "einkaufender": "einkaufend",
    "einkaufendes": "einkaufend",
    "einkaufest": "einkaufen",
    "einkaufet": "einkaufen",
    "einkaufst": "einkaufen",
    "einkauft": "einkaufen",
    "einkaufte": "einkaufen",
    "einkauften": "einkaufen",
    "einkauftest": "einkaufen",
    "einkauftet": "einkaufen",
    "einkehre": "einkehren",
    "einkehrend": "einkehren",
    "einkehrende": "einkehrend",
    "einkehrendem": "einkehrend",
    "einkehrenden": "einkehrend",
    "einkehrender": "einkehrend",
    "einkehrendes": "einkehrend",
    "einkehrest": "einkehren",
    "einkehret": "einkehren",
    "einkehrst": "einkehren",
    "einkehrt": "einkehren",
    "einkehrte": "einkehren",
    "einkehrten": "einkehren",
    "einkehrtest": "einkehren",
    "einkehrtet": "einkehren",
    "einkeile": "einkeilen",
    "einkeilend": "einkeilen",
    "einkeilende": "einkeilend",
    "einkeilendem": "einkeilend",
    "einkeilenden": "einkeilend",
    "einkeilender": "einkeilend",
    "einkeilendere": "einkeilend",
    "einkeilenderem": "einkeilend",
    "einkeilenderen": "einkeilend",
    "einkeilenderer": "einkeilend",
    "einkeilenderes": "einkeilend",
    "einkeilendes": "einkeilend",
    "einkeilendste": "einkeilend",
    "einkeilendstem": "einkeilend",
    "einkeilendsten": "einkeilend",
    "einkeilendster": "einkeilend",
    "einkeilendstes": "einkeilend",
    "einkeilest": "einkeilen",
    "einkeilet": "einkeilen",
    "einkeilst": "einkeilen",
    "einkeilt": "einkeilen",
    "einkeilte": "einkeilen",
    "einkeilten": "einkeilen",
    "einkeiltest": "einkeilen",
    "einkeiltet": "einkeilen",
    "einkellere": "einkellern",
    "einkellernd": "einkellern",
    "einkellernde": "einkellernd",
    "einkellerndem": "einkellernd",
    "einkellernden": "einkellernd",
    "einkellernder": "einkellernd",
    "einkellerndere": "einkellernd",
    "einkellernderem": "einkellernd",
    "einkellernderen": "einkellernd",
    "einkellernderer": "einkellernd",
    "einkellernderes": "einkellernd",
    "einkellerndes": "einkellernd",
    "einkellerndste": "einkellernd",
    "einkellerndstem": "einkellernd",
    "einkellerndsten": "einkellernd",
    "einkellerndster": "einkellernd",
    "einkellerndstes": "einkellernd",
    "einkellerst": "einkellern",
    "einkellert": "einkellern",
    "einkellerte": "einkellern",
    "einkellerten": "einkellern",
    "einkellertest": "einkellern",
    "einkellertet": "einkellern",
    "einkerbe": "einkerben",
    "einkerbend": "einkerben",
    "einkerbende": "einkerbend",
    "einkerbendem": "einkerbend",
    "einkerbenden": "einkerbend",
    "einkerbender": "einkerbend",
    "einkerbendere": "einkerbend",
    "einkerbenderem": "einkerbend",
    "einkerbenderen": "einkerbend",
    "einkerbenderer": "einkerbend",
    "einkerbenderes": "einkerbend",
    "einkerbendes": "einkerbend",
    "einkerbendste": "einkerbend",
    "einkerbendstem": "einkerbend",
    "einkerbendsten": "einkerbend",
    "einkerbendster": "einkerbend",
    "einkerbendstes": "einkerbend",
    "einkerbest": "einkerben",
    "einkerbet": "einkerben",
    "einkerbst": "einkerben",
    "einkerbt": "einkerben",
    "einkerbte": "einkerben",
    "einkerbten": "einkerben",
    "einkerbtest": "einkerben",
    "einkerbtet": "einkerben",
    "einkerkere": "einkerkern",
    "einkerkernd": "einkerkern",
    "einkerkernde": "einkerkernd",
    "einkerkerndem": "einkerkernd",
    "einkerkernden": "einkerkernd",
    "einkerkernder": "einkerkernd",
    "einkerkerndes": "einkerkernd",
    "einkerkerst": "einkerkern",
    "einkerkert": "einkerkern",
    "einkerkerte": "einkerkern",
    "einkerkerten": "einkerkern",
    "einkerkertest": "einkerkern",
    "einkerkertet": "einkerkern",
    "einkessele": "einkesseln",
    "einkesselnd": "einkesseln",
    "einkesselnde": "einkesselnd",
    "einkesselndem": "einkesselnd",
    "einkesselnden": "einkesselnd",
    "einkesselnder": "einkesselnd",
    "einkesselndere": "einkesselnd",
    "einkesselnderem": "einkesselnd",
    "einkesselnderen": "einkesselnd",
    "einkesselnderer": "einkesselnd",
    "einkesselnderes": "einkesselnd",
    "einkesselndes": "einkesselnd",
    "einkesselndste": "einkesselnd",
    "einkesselndstem": "einkesselnd",
    "einkesselndsten": "einkesselnd",
    "einkesselndster": "einkesselnd",
    "einkesselndstes": "einkesselnd",
    "einkesselst": "einkesseln",
    "einkesselt": "einkesseln",
    "einkesselte": "einkesseln",
    "einkesselten": "einkesseln",
    "einkesseltest": "einkesseln",
    "einkesseltet": "einkesseln",
    "einkessle": "einkesseln",
    "einkitte": "einkitten",
    "einkittend": "einkitten",
    "einkittende": "einkittend",
    "einkittendem": "einkittend",
    "einkittenden": "einkittend",
    "einkittender": "einkittend",
    "einkittendes": "einkittend",
    "einkittest": "einkitten",
    "einkittet": "einkitten",
    "einkittete": "einkitten",
    "einkitteten": "einkitten",
    "einkittetest": "einkitten",
    "einkittetet": "einkitten",
    "einklagbare": "einklagbar",
    "einklagbarem": "einklagbar",
    "einklagbaren": "einklagbar",
    "einklagbarer": "einklagbar",
    "einklagbares": "einklagbar",
    "einklage": "einklagen",
    "einklagend": "einklagen",
    "einklagende": "einklagend",
    "einklagendem": "einklagend",
    "einklagenden": "einklagend",
    "einklagender": "einklagend",
    "einklagendes": "einklagend",
    "einklagest": "einklagen",
    "einklaget": "einklagen",
    "einklagst": "einklagen",
    "einklagt": "einklagen",
    "einklagte": "einklagen",
    "einklagten": "einklagen",
    "einklagtest": "einklagen",
    "einklagtet": "einklagen",
    "einklammere": "einklammern",
    "einklammernd": "einklammern",
    "einklammernde": "einklammernd",
    "einklammerndem": "einklammernd",
    "einklammernden": "einklammernd",
    "einklammernder": "einklammernd",
    "einklammerndes": "einklammernd",
    "einklammerst": "einklammern",
    "einklammert": "einklammern",
    "einklammerte": "einklammern",
    "einklammerten": "einklammern",
    "einklammertest": "einklammern",
    "einklammertet": "einklammern",
    "einklebe": "einkleben",
    "einklebend": "einkleben",
    "einklebende": "einklebend",
    "einklebendem": "einklebend",
    "einklebenden": "einklebend",
    "einklebender": "einklebend",
    "einklebendes": "einklebend",
    "einklebest": "einkleben",
    "einklebet": "einkleben",
    "einklebst": "einkleben",
    "einklebt": "einkleben",
    "einklebte": "einkleben",
    "einklebten": "einkleben",
    "einklebtest": "einkleben",
    "einklebtet": "einkleben",
    "einkleide": "einkleiden",
    "einkleidend": "einkleiden",
    "einkleidende": "einkleidend",
    "einkleidendem": "einkleidend",
    "einkleidenden": "einkleidend",
    "einkleidender": "einkleidend",
    "einkleidendere": "einkleidend",
    "einkleidenderem": "einkleidend",
    "einkleidenderen": "einkleidend",
    "einkleidenderer": "einkleidend",
    "einkleidenderes": "einkleidend",
    "einkleidendes": "einkleidend",
    "einkleidendste": "einkleidend",
    "einkleidendstem": "einkleidend",
    "einkleidendsten": "einkleidend",
    "einkleidendster": "einkleidend",
    "einkleidendstes": "einkleidend",
    "einkleidest": "einkleiden",
    "einkleidet": "einkleiden",
    "einkleidete": "einkleiden",
    "einkleideten": "einkleiden",
    "einkleidetest": "einkleiden",
    "einkleidetet": "einkleiden",
    "einklemme": "einklemmen",
    "einklemmend": "einklemmen",
    "einklemmende": "einklemmend",
    "einklemmendem": "einklemmend",
    "einklemmenden": "einklemmend",
    "einklemmender": "einklemmend",
    "einklemmendere": "einklemmend",
    "einklemmenderem": "einklemmend",
    "einklemmenderen": "einklemmend",
    "einklemmenderer": "einklemmend",
    "einklemmenderes": "einklemmend",
    "einklemmendes": "einklemmend",
    "einklemmendste": "einklemmend",
    "einklemmendstem": "einklemmend",
    "einklemmendsten": "einklemmend",
    "einklemmendster": "einklemmend",
    "einklemmendstes": "einklemmend",
    "einklemmest": "einklemmen",
    "einklemmet": "einklemmen",
    "einklemmst": "einklemmen",
    "einklemmt": "einklemmen",
    "einklemmte": "einklemmen",
    "einklemmten": "einklemmen",
    "einklemmtest": "einklemmen",
    "einklemmtet": "einklemmen",
    "einklinke": "einklinken",
    "einklinkend": "einklinken",
    "einklinkende": "einklinkend",
    "einklinkendem": "einklinkend",
    "einklinkenden": "einklinkend",
    "einklinkender": "einklinkend",
    "einklinkendes": "einklinkend",
    "einklinkest": "einklinken",
    "einklinket": "einklinken",
    "einklinkst": "einklinken",
    "einklinkt": "einklinken",
    "einklinkte": "einklinken",
    "einklinkten": "einklinken",
    "einklinktest": "einklinken",
    "einklinktet": "einklinken",
    "einklopfe": "einklopfen",
    "einklopfend": "einklopfen",
    "einklopfende": "einklopfend",
    "einklopfendem": "einklopfend",
    "einklopfenden": "einklopfend",
    "einklopfender": "einklopfend",
    "einklopfendes": "einklopfend",
    "einklopfest": "einklopfen",
    "einklopfet": "einklopfen",
    "einklopfst": "einklopfen",
    "einklopft": "einklopfen",
    "einklopfte": "einklopfen",
    "einklopften": "einklopfen",
    "einklopftest": "einklopfen",
    "einklopftet": "einklopfen",
    "einkneife": "einkneifen",
    "einkneifend": "einkneifen",
    "einkneifende": "einkneifend",
    "einkneifendem": "einkneifend",
    "einkneifenden": "einkneifend",
    "einkneifender": "einkneifend",
    "einkneifendere": "einkneifend",
    "einkneifenderem": "einkneifend",
    "einkneifenderen": "einkneifend",
    "einkneifenderer": "einkneifend",
    "einkneifenderes": "einkneifend",
    "einkneifendes": "einkneifend",
    "einkneifendste": "einkneifend",
    "einkneifendstem": "einkneifend",
    "einkneifendsten": "einkneifend",
    "einkneifendster": "einkneifend",
    "einkneifendstes": "einkneifend",
    "einkneifest": "einkneifen",
    "einkneifet": "einkneifen",
    "einkneifst": "einkneifen",
    "einkneift": "einkneifen",
    "einknicke": "einknicken",
    "einknickend": "einknicken",
    "einknickende": "einknickend",
    "einknickendem": "einknickend",
    "einknickenden": "einknickend",
    "einknickender": "einknickend",
    "einknickendes": "einknickend",
    "einknickest": "einknicken",
    "einknicket": "einknicken",
    "einknickst": "einknicken",
    "einknickt": "einknicken",
    "einknickte": "einknicken",
    "einknickten": "einknicken",
    "einknicktest": "einknicken",
    "einknicktet": "einknicken",
    "einkniff": "einkneifen",
    "einkniffe": "einkneifen",
    "einkniffen": "einkneifen",
    "einkniffest": "einkneifen",
    "einkniffet": "einkneifen",
    "einkniffst": "einkneifen",
    "einknifft": "einkneifen",
    "einknote": "einknoten",
    "einknotend": "einknoten",
    "einknotende": "einknotend",
    "einknotendem": "einknotend",
    "einknotenden": "einknotend",
    "einknotender": "einknotend",
    "einknotendes": "einknotend",
    "einknotest": "einknoten",
    "einknotet": "einknoten",
    "einknotete": "einknoten",
    "einknoteten": "einknoten",
    "einknotetest": "einknoten",
    "einknotetet": "einknoten",
    "einknöpfe": "einknöpfen",
    "einknöpfend": "einknöpfen",
    "einknöpfende": "einknöpfend",
    "einknöpfendem": "einknöpfend",
    "einknöpfenden": "einknöpfend",
    "einknöpfender": "einknöpfend",
    "einknöpfendes": "einknöpfend",
    "einknöpfest": "einknöpfen",
    "einknöpfet": "einknöpfen",
    "einknöpfst": "einknöpfen",
    "einknöpft": "einknöpfen",
    "einknöpfte": "einknöpfen",
    "einknöpften": "einknöpfen",
    "einknöpftest": "einknöpfen",
    "einknöpftet": "einknöpfen",
    "einknüpfe": "einknüpfen",
    "einknüpfend": "einknüpfen",
    "einknüpfende": "einknüpfend",
    "einknüpfendem": "einknüpfend",
    "einknüpfenden": "einknüpfend",
    "einknüpfender": "einknüpfend",
    "einknüpfendes": "einknüpfend",
    "einknüpfest": "einknüpfen",
    "einknüpfet": "einknüpfen",
    "einknüpfst": "einknüpfen",
    "einknüpft": "einknüpfen",
    "einknüpfte": "einknüpfen",
    "einknüpften": "einknüpfen",
    "einknüpftest": "einknüpfen",
    "einknüpftet": "einknüpfen",
    "einkoche": "einkochen",
    "einkochend": "einkochen",
    "einkochende": "einkochend",
    "einkochendem": "einkochend",
    "einkochenden": "einkochend",
    "einkochender": "einkochend",
    "einkochendes": "einkochend",
    "einkochest": "einkochen",
    "einkochet": "einkochen",
    "einkochst": "einkochen",
    "einkocht": "einkochen",
    "einkochte": "einkochen",
    "einkochten": "einkochen",
    "einkochtest": "einkochen",
    "einkochtet": "einkochen",
    "einkommensschwachem": "einkommensschwach",
    "einkommensschwachen": "einkommensschwach",
    "einkommensschwacher": "einkommensschwach",
    "einkommensschwaches": "einkommensschwach",
    "einkommensschwächer": "einkommensschwach",
    "einkommensschwächere": "einkommensschwach",
    "einkommensschwächerem": "einkommensschwach",
    "einkommensschwächeren": "einkommensschwach",
    "einkommensschwächerer": "einkommensschwach",
    "einkommensschwächeres": "einkommensschwach",
    "einkommensschwächsten": "einkommensschwach",
    "einkommensstarke": "einkommensstark",
    "einkommensstarkem": "einkommensstark",
    "einkommensstarken": "einkommensstark",
    "einkommensstarker": "einkommensstark",
    "einkommensstarkes": "einkommensstark",
    "einkommensstärker": "einkommensstark",
    "einkommensstärkere": "einkommensstark",
    "einkommensstärkerem": "einkommensstark",
    "einkommensstärkeren": "einkommensstark",
    "einkommensstärkerer": "einkommensstark",
    "einkommensstärkeres": "einkommensstark",
    "einkommensstärksten": "einkommensstark",
    "einkratze": "einkratzen",
    "einkratzend": "einkratzen",
    "einkratzende": "einkratzend",
    "einkratzendem": "einkratzend",
    "einkratzenden": "einkratzend",
    "einkratzender": "einkratzend",
    "einkratzendere": "einkratzend",
    "einkratzenderem": "einkratzend",
    "einkratzenderen": "einkratzend",
    "einkratzenderer": "einkratzend",
    "einkratzenderes": "einkratzend",
    "einkratzendes": "einkratzend",
    "einkratzendste": "einkratzend",
    "einkratzendstem": "einkratzend",
    "einkratzendsten": "einkratzend",
    "einkratzendster": "einkratzend",
    "einkratzendstes": "einkratzend",
    "einkratzest": "einkratzen",
    "einkratzet": "einkratzen",
    "einkratzt": "einkratzen",
    "einkratzte": "einkratzen",
    "einkratzten": "einkratzen",
    "einkratztest": "einkratzen",
    "einkratztet": "einkratzen",
    "einkreise": "einkreisen",
    "einkreisend": "einkreisen",
    "einkreisende": "einkreisend",
    "einkreisendem": "einkreisend",
    "einkreisenden": "einkreisend",
    "einkreisender": "einkreisend",
    "einkreisendes": "einkreisend",
    "einkreisest": "einkreisen",
    "einkreiset": "einkreisen",
    "einkreist": "einkreisen",
    "einkreiste": "einkreisen",
    "einkreisten": "einkreisen",
    "einkreistest": "einkreisen",
    "einkreistet": "einkreisen",
    "einkreuze": "einkreuzen",
    "einkreuzend": "einkreuzen",
    "einkreuzende": "einkreuzend",
    "einkreuzendem": "einkreuzend",
    "einkreuzenden": "einkreuzend",
    "einkreuzender": "einkreuzend",
    "einkreuzendes": "einkreuzend",
    "einkreuzest": "einkreuzen",
    "einkreuzet": "einkreuzen",
    "einkreuzt": "einkreuzen",
    "einkreuzte": "einkreuzen",
    "einkreuzten": "einkreuzen",
    "einkreuztest": "einkreuzen",
    "einkreuztet": "einkreuzen",
    "einkriege": "einkriegen",
    "einkriegend": "einkriegen",
    "einkriegende": "einkriegend",
    "einkriegendem": "einkriegend",
    "einkriegenden": "einkriegend",
    "einkriegender": "einkriegend",
    "einkriegendes": "einkriegend",
    "einkriegest": "einkriegen",
    "einkrieget": "einkriegen",
    "einkriegst": "einkriegen",
    "einkriegt": "einkriegen",
    "einkriegte": "einkriegen",
    "einkriegten": "einkriegen",
    "einkriegtest": "einkriegen",
    "einkriegtet": "einkriegen",
    "einlade": "einladen",
    "einladend": "einladen",
    "einladende": "einladend",
    "einladendem": "einladend",
    "einladenden": "einladend",
    "einladender": "einladend",
    "einladendes": "einladend",
    "einladest": "einladen",
    "einladet": "einladen",
    "einlag": "einliegen",
    "einlagere": "einlagern",
    "einlagernd": "einlagern",
    "einlagernde": "einlagernd",
    "einlagerndem": "einlagernd",
    "einlagernden": "einlagernd",
    "einlagernder": "einlagernd",
    "einlagerndes": "einlagernd",
    "einlagerst": "einlagern",
    "einlagert": "einlagern",
    "einlagerte": "einlagern",
    "einlagerten": "einlagern",
    "einlagertest": "einlagern",
    "einlagertet": "einlagern",
    "einlagst": "einliegen",
    "einlagt": "einliegen",
    "einlange": "einlangen",
    "einlangend": "einlangen",
    "einlangende": "einlangend",
    "einlangendem": "einlangend",
    "einlangenden": "einlangend",
    "einlangender": "einlangend",
    "einlangendes": "einlangend",
    "einlangest": "einlangen",
    "einlanget": "einlangen",
    "einlangst": "einlangen",
    "einlangt": "einlangen",
    "einlangte": "einlangen",
    "einlangten": "einlangen",
    "einlangtest": "einlangen",
    "einlangtet": "einlangen",
    "einlas": "einlesen",
    "einlasen": "einlesen",
    "einlasse": "einlassen",
    "einlassend": "einlassen",
    "einlassende": "einlassend",
    "einlassendem": "einlassend",
    "einlassenden": "einlassend",
    "einlassender": "einlassend",
    "einlassendes": "einlassend",
    "einlassest": "einlassen",
    "einlasset": "einlassen",
    "einlast": "einlesen",
    "einlaufend": "einlaufen",
    "einlaufende": "einlaufend",
    "einlaufendem": "einlaufend",
    "einlaufenden": "einlaufend",
    "einlaufender": "einlaufend",
    "einlaufendere": "einlaufend",
    "einlaufenderem": "einlaufend",
    "einlaufenderen": "einlaufend",
    "einlaufenderer": "einlaufend",
    "einlaufenderes": "einlaufend",
    "einlaufendes": "einlaufend",
    "einlaufendste": "einlaufend",
    "einlaufendstem": "einlaufend",
    "einlaufendsten": "einlaufend",
    "einlaufendster": "einlaufend",
    "einlaufendstes": "einlaufend",
    "einlaufest": "einlaufen",
    "einlaufet": "einlaufen",
    "einlauft": "einlaufen",
    "einlaßt": "einlassen",
    "einlebe": "einleben",
    "einlebend": "einleben",
    "einlebende": "einlebend",
    "einlebendem": "einlebend",
    "einlebenden": "einlebend",
    "einlebender": "einlebend",
    "einlebendes": "einlebend",
    "einlebest": "einleben",
    "einlebet": "einleben",
    "einlebst": "einleben",
    "einlebt": "einleben",
    "einlebte": "einleben",
    "einlebten": "einleben",
    "einlebtest": "einleben",
    "einlebtet": "einleben",
    "einlege": "einlegen",
    "einlegend": "einlegen",
    "einlegende": "einlegend",
    "einlegendem": "einlegend",
    "einlegenden": "einlegend",
    "einlegender": "einlegend",
    "einlegendes": "einlegend",
    "einlegest": "einlegen",
    "einleget": "einlegen",
    "einlegst": "einlegen",
    "einlegt": "einlegen",
    "einlegte": "einlegen",
    "einlegten": "einlegen",
    "einlegtest": "einlegen",
    "einlegtet": "einlegen",
    "einleite": "einleiten",
    "einleitend": "einleiten",
    "einleitende": "einleitend",
    "einleitendem": "einleitend",
    "einleitenden": "einleitend",
    "einleitender": "einleitend",
    "einleitendes": "einleitend",
    "einleitest": "einleiten",
    "einleitet": "einleiten",
    "einleitete": "einleiten",
    "einleiteten": "einleiten",
    "einleitetest": "einleiten",
    "einleitetet": "einleiten",
    "einlenke": "einlenken",
    "einlenkend": "einlenken",
    "einlenkende": "einlenkend",
    "einlenkendem": "einlenkend",
    "einlenkenden": "einlenkend",
    "einlenkender": "einlenkend",
    "einlenkendes": "einlenkend",
    "einlenkest": "einlenken",
    "einlenket": "einlenken",
    "einlenkst": "einlenken",
    "einlenkt": "einlenken",
    "einlenkte": "einlenken",
    "einlenkten": "einlenken",
    "einlenktest": "einlenken",
    "einlenktet": "einlenken",
    "einlerne": "einlernen",
    "einlernend": "einlernen",
    "einlernende": "einlernend",
    "einlernendem": "einlernend",
    "einlernenden": "einlernend",
    "einlernender": "einlernend",
    "einlernendes": "einlernend",
    "einlernest": "einlernen",
    "einlernet": "einlernen",
    "einlernst": "einlernen",
    "einlernt": "einlernen",
    "einlernte": "einlernen",
    "einlernten": "einlernen",
    "einlerntest": "einlernen",
    "einlerntet": "einlernen",
    "einlese": "einlesen",
    "einlesend": "einlesen",
    "einlesende": "einlesend",
    "einlesendem": "einlesend",
    "einlesenden": "einlesend",
    "einlesender": "einlesend",
    "einlesendes": "einlesend",
    "einlesest": "einlesen",
    "einleset": "einlesen",
    "einlest": "einlesen",
    "einleuchte": "einleuchten",
    "einleuchtend": "einleuchten",
    "einleuchtende": "einleuchtend",
    "einleuchtendem": "einleuchtend",
    "einleuchtenden": "einleuchtend",
    "einleuchtender": "einleuchtend",
    "einleuchtendes": "einleuchtend",
    "einleuchtest": "einleuchten",
    "einleuchtet": "einleuchten",
    "einleuchtete": "einleuchten",
    "einleuchteten": "einleuchten",
    "einleuchtetest": "einleuchten",
    "einleuchtetet": "einleuchten",
    "einlief": "einlaufen",
    "einliefe": "einlaufen",
    "einliefen": "einlaufen",
    "einliefere": "einliefern",
    "einliefernd": "einliefern",
    "einliefernde": "einliefernd",
    "einlieferndem": "einliefernd",
    "einliefernden": "einliefernd",
    "einliefernder": "einliefernd",
    "einlieferndes": "einliefernd",
    "einlieferst": "einliefern",
    "einliefert": "einliefern",
    "einlieferte": "einliefern",
    "einlieferten": "einliefern",
    "einliefertest": "einliefern",
    "einliefertet": "einliefern",
    "einliefest": "einlaufen",
    "einliefet": "einlaufen",
    "einliefst": "einlaufen",
    "einlieft": "einlaufen",
    "einliege": "einliegen",
    "einliegend": "einliegen",
    "einliegende": "einliegend",
    "einliegendem": "einliegend",
    "einliegenden": "einliegend",
    "einliegender": "einliegend",
    "einliegendes": "einliegend",
    "einliegest": "einliegen",
    "einlieget": "einliegen",
    "einliegst": "einliegen",
    "einliegt": "einliegen",
    "einliest": "einlesen",
    "einließ": "einlassen",
    "einließe": "einlassen",
    "einließen": "einlassen",
    "einließest": "einlassen",
    "einließet": "einlassen",
    "einließt": "einlassen",
    "einloche": "einlochen",
    "einlochend": "einlochen",
    "einlochende": "einlochend",
    "einlochendem": "einlochend",
    "einlochenden": "einlochend",
    "einlochender": "einlochend",
    "einlochendes": "einlochend",
    "einlochest": "einlochen",
    "einlochet": "einlochen",
    "einlochst": "einlochen",
    "einlocht": "einlochen",
    "einlochte": "einlochen",
    "einlochten": "einlochen",
    "einlochtest": "einlochen",
    "einlochtet": "einlochen",
    "einlud": "einladen",
    "einluden": "einladen",
    "einludest": "einladen",
    "einludet": "einladen",
    "einlulle": "einlullen",
    "einlullend": "einlullen",
    "einlullende": "einlullend",
    "einlullendem": "einlullend",
    "einlullenden": "einlullend",
    "einlullender": "einlullend",
    "einlullendere": "einlullend",
    "einlullenderem": "einlullend",
    "einlullenderen": "einlullend",
    "einlullenderer": "einlullend",
    "einlullenderes": "einlullend",
    "einlullendes": "einlullend",
    "einlullendste": "einlullend",
    "einlullendstem": "einlullend",
    "einlullendsten": "einlullend",
    "einlullendster": "einlullend",
    "einlullendstes": "einlullend",
    "einlullest": "einlullen",
    "einlullet": "einlullen",
    "einlullst": "einlullen",
    "einlullt": "einlullen",
    "einlullte": "einlullen",
    "einlullten": "einlullen",
    "einlulltest": "einlullen",
    "einlulltet": "einlullen",
    "einlädst": "einladen",
    "einlädt": "einladen",
    "einläge": "einliegen",
    "einlägen": "einliegen",
    "einlägest": "einliegen",
    "einläget": "einliegen",
    "einläse": "einlesen",
    "einläsen": "einlesen",
    "einläsest": "einlesen",
    "einläset": "einlesen",
    "einläufst": "einlaufen",
    "einläuft": "einlaufen",
    "einläute": "einläuten",
    "einläutend": "einläuten",
    "einläutende": "einläutend",
    "einläutendem": "einläutend",
    "einläutenden": "einläutend",
    "einläutender": "einläutend",
    "einläutendes": "einläutend",
    "einläutest": "einläuten",
    "einläutet": "einläuten",
    "einläutete": "einläuten",
    "einläuteten": "einläuten",
    "einläutetest": "einläuten",
    "einläutetet": "einläuten",
    "einläßt": "einlassen",
    "einlöse": "einlösen",
    "einlösend": "einlösen",
    "einlösende": "einlösend",
    "einlösendem": "einlösend",
    "einlösenden": "einlösend",
    "einlösender": "einlösend",
    "einlösendes": "einlösend",
    "einlösest": "einlösen",
    "einlöset": "einlösen",
    "einlöst": "einlösen",
    "einlöste": "einlösen",
    "einlösten": "einlösen",
    "einlöstest": "einlösen",
    "einlöstet": "einlösen",
    "einlöte": "einlöten",
    "einlötend": "einlöten",
    "einlötende": "einlötend",
    "einlötendem": "einlötend",
    "einlötenden": "einlötend",
    "einlötender": "einlötend",
    "einlötendes": "einlötend",
    "einlötest": "einlöten",
    "einlötet": "einlöten",
    "einlötete": "einlöten",
    "einlöteten": "einlöten",
    "einlötetest": "einlöten",
    "einlötetet": "einlöten",
    "einlüde": "einladen",
    "einlüden": "einladen",
    "einlüdest": "einladen",
    "einlüdet": "einladen",
    "einmache": "einmachen",
    "einmachend": "einmachen",
    "einmachende": "einmachend",
    "einmachendem": "einmachend",
    "einmachenden": "einmachend",
    "einmachender": "einmachend",
    "einmachendes": "einmachend",
    "einmachest": "einmachen",
    "einmachet": "einmachen",
    "einmachst": "einmachen",
    "einmacht": "einmachen",
    "einmachte": "einmachen",
    "einmachten": "einmachen",
    "einmachtest": "einmachen",
    "einmachtet": "einmachen",
    "einmahne": "einmahnen",
    "einmahnend": "einmahnen",
    "einmahnende": "einmahnend",
    "einmahnendem": "einmahnend",
    "einmahnenden": "einmahnend",
    "einmahnender": "einmahnend",
    "einmahnendes": "einmahnend",
    "einmahnest": "einmahnen",
    "einmahnet": "einmahnen",
    "einmahnst": "einmahnen",
    "einmahnt": "einmahnen",
    "einmahnte": "einmahnen",
    "einmahnten": "einmahnen",
    "einmahntest": "einmahnen",
    "einmahntet": "einmahnen",
    "einmalige": "einmalig",
    "einmaligem": "einmalig",
    "einmaligen": "einmalig",
    "einmaliger": "einmalig",
    "einmaliges": "einmalig",
    "einmarschiere": "einmarschieren",
    "einmarschierend": "einmarschieren",
    "einmarschierende": "einmarschierend",
    "einmarschierendem": "einmarschierend",
    "einmarschierenden": "einmarschierend",
    "einmarschierender": "einmarschierend",
    "einmarschierendes": "einmarschierend",
    "einmarschierest": "einmarschieren",
    "einmarschieret": "einmarschieren",
    "einmarschierst": "einmarschieren",
    "einmarschiert": "einmarschieren",
    "einmarschierte": "einmarschieren",
    "einmarschiertem": "einmarschiert",
    "einmarschierten": "einmarschieren",
    "einmarschierter": "einmarschiert",
    "einmarschiertes": "einmarschiert",
    "einmarschiertest": "einmarschieren",
    "einmarschiertet": "einmarschieren",
    "einmauere": "einmauern",
    "einmauernd": "einmauern",
    "einmauernde": "einmauernd",
    "einmauerndem": "einmauernd",
    "einmauernden": "einmauernd",
    "einmauernder": "einmauernd",
    "einmauerndes": "einmauernd",
    "einmauerst": "einmauern",
    "einmauert": "einmauern",
    "einmauerte": "einmauern",
    "einmauerten": "einmauern",
    "einmauertest": "einmauern",
    "einmauertet": "einmauern",
    "einmeißele": "einmeißeln",
    "einmeißelnd": "einmeißeln",
    "einmeißelnde": "einmeißelnd",
    "einmeißelndem": "einmeißelnd",
    "einmeißelnden": "einmeißelnd",
    "einmeißelnder": "einmeißelnd",
    "einmeißelndes": "einmeißelnd",
    "einmeißelst": "einmeißeln",
    "einmeißelt": "einmeißeln",
    "einmeißelte": "einmeißeln",
    "einmeißelten": "einmeißeln",
    "einmeißeltest": "einmeißeln",
    "einmeißeltet": "einmeißeln",
    "einmeißle": "einmeißeln",
    "einmenge": "einmengen",
    "einmengend": "einmengen",
    "einmengende": "einmengend",
    "einmengendem": "einmengend",
    "einmengenden": "einmengend",
    "einmengender": "einmengend",
    "einmengendes": "einmengend",
    "einmengest": "einmengen",
    "einmenget": "einmengen",
    "einmengst": "einmengen",
    "einmengt": "einmengen",
    "einmengte": "einmengen",
    "einmengten": "einmengen",
    "einmengtest": "einmengen",
    "einmengtet": "einmengen",
    "einmiete": "einmieten",
    "einmietend": "einmieten",
    "einmietende": "einmietend",
    "einmietendem": "einmietend",
    "einmietenden": "einmietend",
    "einmietender": "einmietend",
    "einmietendes": "einmietend",
    "einmietest": "einmieten",
    "einmietet": "einmieten",
    "einmietete": "einmieten",
    "einmieteten": "einmieten",
    "einmietetest": "einmieten",
    "einmietetet": "einmieten",
    "einmische": "einmischen",
    "einmischend": "einmischen",
    "einmischende": "einmischend",
    "einmischendem": "einmischend",
    "einmischenden": "einmischend",
    "einmischender": "einmischend",
    "einmischendes": "einmischend",
    "einmischest": "einmischen",
    "einmischet": "einmischen",
    "einmischst": "einmischen",
    "einmischt": "einmischen",
    "einmischte": "einmischen",
    "einmischten": "einmischen",
    "einmischtest": "einmischen",
    "einmischtet": "einmischen",
    "einmotorigem": "einmotorig",
    "einmotorigen": "einmotorig",
    "einmotoriger": "einmotorig",
    "einmotoriges": "einmotorig",
    "einmotte": "einmotten",
    "einmottend": "einmotten",
    "einmottende": "einmottend",
    "einmottendem": "einmottend",
    "einmottenden": "einmottend",
    "einmottender": "einmottend",
    "einmottendes": "einmottend",
    "einmottest": "einmotten",
    "einmottet": "einmotten",
    "einmottete": "einmotten",
    "einmotteten": "einmotten",
    "einmottetest": "einmotten",
    "einmottetet": "einmotten",
    "einmümmele": "einmümmeln",
    "einmümmelnd": "einmümmeln",
    "einmümmelnde": "einmümmelnd",
    "einmümmelndem": "einmümmelnd",
    "einmümmelnden": "einmümmelnd",
    "einmümmelnder": "einmümmelnd",
    "einmümmelndere": "einmümmelnd",
    "einmümmelnderem": "einmümmelnd",
    "einmümmelnderen": "einmümmelnd",
    "einmümmelnderer": "einmümmelnd",
    "einmümmelnderes": "einmümmelnd",
    "einmümmelndes": "einmümmelnd",
    "einmümmelndste": "einmümmelnd",
    "einmümmelndstem": "einmümmelnd",
    "einmümmelndsten": "einmümmelnd",
    "einmümmelndster": "einmümmelnd",
    "einmümmelndstes": "einmümmelnd",
    "einmümmelst": "einmümmeln",
    "einmümmelt": "einmümmeln",
    "einmümmelte": "einmümmeln",
    "einmümmelten": "einmümmeln",
    "einmümmeltest": "einmümmeln",
    "einmümmeltet": "einmümmeln",
    "einmümmle": "einmümmeln",
    "einmünde": "einmünden",
    "einmündend": "einmünden",
    "einmündende": "einmündend",
    "einmündendem": "einmündend",
    "einmündenden": "einmündend",
    "einmündender": "einmündend",
    "einmündendes": "einmündend",
    "einmündest": "einmünden",
    "einmündet": "einmünden",
    "einmündete": "einmünden",
    "einmündeten": "einmünden",
    "einmündetest": "einmünden",
    "einmündetet": "einmünden",
    "einmütigem": "einmütig",
    "einmütigen": "einmütig",
    "einmütiger": "einmütig",
    "einmütigere": "einmütig",
    "einmütigerem": "einmütig",
    "einmütigeren": "einmütig",
    "einmütigerer": "einmütig",
    "einmütigeres": "einmütig",
    "einmütiges": "einmütig",
    "einmütigste": "einmütig",
    "einmütigstem": "einmütig",
    "einmütigsten": "einmütig",
    "einmütigster": "einmütig",
    "einmütigstes": "einmütig",
    "einnahm": "einnehmen",
    "einnahmst": "einnehmen",
    "einnahmt": "einnehmen",
    "einnebele": "einnebeln",
    "einnebelnd": "einnebeln",
    "einnebelnde": "einnebelnd",
    "einnebelndem": "einnebelnd",
    "einnebelnden": "einnebelnd",
    "einnebelnder": "einnebelnd",
    "einnebelndere": "einnebelnd",
    "einnebelnderem": "einnebelnd",
    "einnebelnderen": "einnebelnd",
    "einnebelnderer": "einnebelnd",
    "einnebelnderes": "einnebelnd",
    "einnebelndes": "einnebelnd",
    "einnebelndste": "einnebelnd",
    "einnebelndstem": "einnebelnd",
    "einnebelndsten": "einnebelnd",
    "einnebelndster": "einnebelnd",
    "einnebelndstes": "einnebelnd",
    "einnebelst": "einnebeln",
    "einnebelt": "einnebeln",
    "einnebelte": "einnebeln",
    "einnebelten": "einnebeln",
    "einnebeltest": "einnebeln",
    "einnebeltet": "einnebeln",
    "einneble": "einnebeln",
    "einnehme": "einnehmen",
    "einnehmend": "einnehmen",
    "einnehmende": "einnehmend",
    "einnehmendem": "einnehmend",
    "einnehmenden": "einnehmend",
    "einnehmender": "einnehmend",
    "einnehmendes": "einnehmend",
    "einnehmest": "einnehmen",
    "einnehmet": "einnehmen",
    "einnehmt": "einnehmen",
    "einnimmst": "einnehmen",
    "einnimmt": "einnehmen",
    "einniste": "einnisten",
    "einnistend": "einnisten",
    "einnistende": "einnistend",
    "einnistendem": "einnistend",
    "einnistenden": "einnistend",
    "einnistender": "einnistend",
    "einnistendes": "einnistend",
    "einnistest": "einnisten",
    "einnistet": "einnisten",
    "einnistete": "einnisten",
    "einnisteten": "einnisten",
    "einnistetest": "einnisten",
    "einnistetet": "einnisten",
    "einnähe": "einnähen",
    "einnähend": "einnähen",
    "einnähende": "einnähend",
    "einnähendem": "einnähend",
    "einnähenden": "einnähend",
    "einnähender": "einnähend",
    "einnähendes": "einnähend",
    "einnähest": "einnähen",
    "einnähet": "einnähen",
    "einnähme": "einnehmen",
    "einnähmen": "einnehmen",
    "einnähmest": "einnehmen",
    "einnähmet": "einnehmen",
    "einnähst": "einnähen",
    "einnäht": "einnähen",
    "einnähte": "einnähen",
    "einnähten": "einnähen",
    "einnähtest": "einnähen",
    "einnähtet": "einnähen",
    "einnässe": "einnässen",
    "einnässend": "einnässen",
    "einnässende": "einnässend",
    "einnässendem": "einnässend",
    "einnässenden": "einnässend",
    "einnässender": "einnässend",
    "einnässendere": "einnässend",
    "einnässenderem": "einnässend",
    "einnässenderen": "einnässend",
    "einnässenderer": "einnässend",
    "einnässenderes": "einnässend",
    "einnässendes": "einnässend",
    "einnässendste": "einnässend",
    "einnässendstem": "einnässend",
    "einnässendsten": "einnässend",
    "einnässendster": "einnässend",
    "einnässendstes": "einnässend",
    "einnässest": "einnässen",
    "einnässet": "einnässen",
    "einnäßt": "einnässen",
    "einnäßte": "einnässen",
    "einnäßten": "einnässen",
    "einnäßtest": "einnässen",
    "einnäßtet": "einnässen",
    "einoperiere": "einoperieren",
    "einoperierend": "einoperieren",
    "einoperierende": "einoperierend",
    "einoperierendem": "einoperierend",
    "einoperierenden": "einoperierend",
    "einoperierender": "einoperierend",
    "einoperierendes": "einoperierend",
    "einoperierest": "einoperieren",
    "einoperieret": "einoperieren",
    "einoperierst": "einoperieren",
    "einoperiert": "einoperieren",
    "einoperierte": "einoperieren",
    "einoperiertem": "einoperiert",
    "einoperierten": "einoperieren",
    "einoperierter": "einoperiert",
    "einoperiertes": "einoperiert",
    "einoperiertest": "einoperieren",
    "einoperiertet": "einoperieren",
    "einordne": "einordnen",
    "einordnend": "einordnen",
    "einordnende": "einordnend",
    "einordnendem": "einordnend",
    "einordnenden": "einordnend",
    "einordnender": "einordnend",
    "einordnendere": "einordnend",
    "einordnenderem": "einordnend",
    "einordnenderen": "einordnend",
    "einordnenderer": "einordnend",
    "einordnenderes": "einordnend",
    "einordnendes": "einordnend",
    "einordnendste": "einordnend",
    "einordnendstem": "einordnend",
    "einordnendsten": "einordnend",
    "einordnendster": "einordnend",
    "einordnendstes": "einordnend",
    "einordnest": "einordnen",
    "einordnet": "einordnen",
    "einordnete": "einordnen",
    "einordneten": "einordnen",
    "einordnetest": "einordnen",
    "einordnetet": "einordnen",
    "einpacke": "einpacken",
    "einpackend": "einpacken",
    "einpackende": "einpackend",
    "einpackendem": "einpackend",
    "einpackenden": "einpackend",
    "einpackender": "einpackend",
    "einpackendes": "einpackend",
    "einpackest": "einpacken",
    "einpacket": "einpacken",
    "einpackst": "einpacken",
    "einpackt": "einpacken",
    "einpackte": "einpacken",
    "einpackten": "einpacken",
    "einpacktest": "einpacken",
    "einpacktet": "einpacken",
    "einparke": "einparken",
    "einparkend": "einparken",
    "einparkende": "einparkend",
    "einparkendem": "einparkend",
    "einparkenden": "einparkend",
    "einparkender": "einparkend",
    "einparkendes": "einparkend",
    "einparkest": "einparken",
    "einparket": "einparken",
    "einparkst": "einparken",
    "einparkt": "einparken",
    "einparkte": "einparken",
    "einparkten": "einparken",
    "einparktest": "einparken",
    "einparktet": "einparken",
    "einpasse": "einpassen",
    "einpassend": "einpassen",
    "einpassende": "einpassend",
    "einpassendem": "einpassend",
    "einpassenden": "einpassend",
    "einpassender": "einpassend",
    "einpassendere": "einpassend",
    "einpassenderem": "einpassend",
    "einpassenderen": "einpassend",
    "einpassenderer": "einpassend",
    "einpassenderes": "einpassend",
    "einpassendes": "einpassend",
    "einpassendste": "einpassend",
    "einpassendstem": "einpassend",
    "einpassendsten": "einpassend",
    "einpassendster": "einpassend",
    "einpassendstes": "einpassend",
    "einpassest": "einpassen",
    "einpasset": "einpassen",
    "einpauke": "einpauken",
    "einpaukend": "einpauken",
    "einpaukende": "einpaukend",
    "einpaukendem": "einpaukend",
    "einpaukenden": "einpaukend",
    "einpaukender": "einpaukend",
    "einpaukendes": "einpaukend",
    "einpaukest": "einpauken",
    "einpauket": "einpauken",
    "einpaukst": "einpauken",
    "einpaukt": "einpauken",
    "einpaukte": "einpauken",
    "einpaukten": "einpauken",
    "einpauktest": "einpauken",
    "einpauktet": "einpauken",
    "einpaßt": "einpassen",
    "einpaßte": "einpassen",
    "einpaßten": "einpassen",
    "einpaßtest": "einpassen",
    "einpaßtet": "einpassen",
    "einpendele": "einpendeln",
    "einpendelnd": "einpendeln",
    "einpendelnde": "einpendelnd",
    "einpendelndem": "einpendelnd",
    "einpendelnden": "einpendelnd",
    "einpendelnder": "einpendelnd",
    "einpendelndere": "einpendelnd",
    "einpendelnderem": "einpendelnd",
    "einpendelnderen": "einpendelnd",
    "einpendelnderer": "einpendelnd",
    "einpendelnderes": "einpendelnd",
    "einpendelndes": "einpendelnd",
    "einpendelndste": "einpendelnd",
    "einpendelndstem": "einpendelnd",
    "einpendelndsten": "einpendelnd",
    "einpendelndster": "einpendelnd",
    "einpendelndstes": "einpendelnd",
    "einpendelst": "einpendeln",
    "einpendelt": "einpendeln",
    "einpendelte": "einpendeln",
    "einpendelten": "einpendeln",
    "einpendeltest": "einpendeln",
    "einpendeltet": "einpendeln",
    "einpendle": "einpendeln",
    "einpferche": "einpferchen",
    "einpferchend": "einpferchen",
    "einpferchende": "einpferchend",
    "einpferchendem": "einpferchend",
    "einpferchenden": "einpferchend",
    "einpferchender": "einpferchend",
    "einpferchendere": "einpferchend",
    "einpferchenderem": "einpferchend",
    "einpferchenderen": "einpferchend",
    "einpferchenderer": "einpferchend",
    "einpferchenderes": "einpferchend",
    "einpferchendes": "einpferchend",
    "einpferchendste": "einpferchend",
    "einpferchendstem": "einpferchend",
    "einpferchendsten": "einpferchend",
    "einpferchendster": "einpferchend",
    "einpferchendstes": "einpferchend",
    "einpferchest": "einpferchen",
    "einpferchet": "einpferchen",
    "einpferchst": "einpferchen",
    "einpfercht": "einpferchen",
    "einpferchte": "einpferchen",
    "einpferchten": "einpferchen",
    "einpferchtest": "einpferchen",
    "einpferchtet": "einpferchen",
    "einpflanze": "einpflanzen",
    "einpflanzend": "einpflanzen",
    "einpflanzende": "einpflanzend",
    "einpflanzendem": "einpflanzend",
    "einpflanzenden": "einpflanzend",
    "einpflanzender": "einpflanzend",
    "einpflanzendes": "einpflanzend",
    "einpflanzest": "einpflanzen",
    "einpflanzet": "einpflanzen",
    "einpflanzt": "einpflanzen",
    "einpflanzte": "einpflanzen",
    "einpflanzten": "einpflanzen",
    "einpflanztest": "einpflanzen",
    "einpflanztet": "einpflanzen",
    "einpfropfe": "einpfropfen",
    "einpfropfend": "einpfropfen",
    "einpfropfende": "einpfropfend",
    "einpfropfendem": "einpfropfend",
    "einpfropfenden": "einpfropfend",
    "einpfropfender": "einpfropfend",
    "einpfropfendere": "einpfropfend",
    "einpfropfenderem": "einpfropfend",
    "einpfropfenderen": "einpfropfend",
    "einpfropfenderer": "einpfropfend",
    "einpfropfenderes": "einpfropfend",
    "einpfropfendes": "einpfropfend",
    "einpfropfendste": "einpfropfend",
    "einpfropfendstem": "einpfropfend",
    "einpfropfendsten": "einpfropfend",
    "einpfropfendster": "einpfropfend",
    "einpfropfendstes": "einpfropfend",
    "einpfropfest": "einpfropfen",
    "einpfropfet": "einpfropfen",
    "einpfropfst": "einpfropfen",
    "einpfropft": "einpfropfen",
    "einpfropfte": "einpfropfen",
    "einpfropften": "einpfropfen",
    "einpfropftest": "einpfropfen",
    "einpfropftet": "einpfropfen",
    "einpinsele": "einpinseln",
    "einpinselnd": "einpinseln",
    "einpinselnde": "einpinselnd",
    "einpinselndem": "einpinselnd",
    "einpinselnden": "einpinselnd",
    "einpinselnder": "einpinselnd",
    "einpinselndere": "einpinselnd",
    "einpinselnderem": "einpinselnd",
    "einpinselnderen": "einpinselnd",
    "einpinselnderer": "einpinselnd",
    "einpinselnderes": "einpinselnd",
    "einpinselndes": "einpinselnd",
    "einpinselndste": "einpinselnd",
    "einpinselndstem": "einpinselnd",
    "einpinselndsten": "einpinselnd",
    "einpinselndster": "einpinselnd",
    "einpinselndstes": "einpinselnd",
    "einpinselst": "einpinseln",
    "einpinselt": "einpinseln",
    "einpinselte": "einpinseln",
    "einpinselten": "einpinseln",
    "einpinseltest": "einpinseln",
    "einpinseltet": "einpinseln",
    "einpinsle": "einpinseln",
    "einplane": "einplanen",
    "einplanend": "einplanen",
    "einplanende": "einplanend",
    "einplanendem": "einplanend",
    "einplanenden": "einplanend",
    "einplanender": "einplanend",
    "einplanendes": "einplanend",
    "einplanest": "einplanen",
    "einplanet": "einplanen",
    "einplanst": "einplanen",
    "einplant": "einplanen",
    "einplante": "einplanen",
    "einplanten": "einplanen",
    "einplantest": "einplanen",
    "einplantet": "einplanen",
    "einpolige": "einpolig",
    "einpoligem": "einpolig",
    "einpoligen": "einpolig",
    "einpoliger": "einpolig",
    "einpoliges": "einpolig",
    "einpresse": "einpressen",
    "einpressend": "einpressen",
    "einpressende": "einpressend",
    "einpressendem": "einpressend",
    "einpressenden": "einpressend",
    "einpressender": "einpressend",
    "einpressendes": "einpressend",
    "einpressest": "einpressen",
    "einpresset": "einpressen",
    "einpreßt": "einpressen",
    "einpreßte": "einpressen",
    "einpreßten": "einpressen",
    "einpreßtest": "einpressen",
    "einpreßtet": "einpressen",
    "einprogrammiere": "einprogrammieren",
    "einprogrammierend": "einprogrammieren",
    "einprogrammierende": "einprogrammierend",
    "einprogrammierendem": "einprogrammierend",
    "einprogrammierenden": "einprogrammierend",
    "einprogrammierender": "einprogrammierend",
    "einprogrammierendes": "einprogrammierend",
    "einprogrammierest": "einprogrammieren",
    "einprogrammieret": "einprogrammieren",
    "einprogrammierst": "einprogrammieren",
    "einprogrammiert": "einprogrammieren",
    "einprogrammierte": "einprogrammieren",
    "einprogrammiertem": "einprogrammiert",
    "einprogrammierten": "einprogrammieren",
    "einprogrammierter": "einprogrammiert",
    "einprogrammiertes": "einprogrammiert",
    "einprogrammiertest": "einprogrammieren",
    "einprogrammiertet": "einprogrammieren",
    "einpräge": "einprägen",
    "einprägend": "einprägen",
    "einprägende": "einprägend",
    "einprägendem": "einprägend",
    "einprägenden": "einprägend",
    "einprägender": "einprägend",
    "einprägendere": "einprägend",
    "einprägenderem": "einprägend",
    "einprägenderen": "einprägend",
    "einprägenderer": "einprägend",
    "einprägenderes": "einprägend",
    "einprägendes": "einprägend",
    "einprägendste": "einprägend",
    "einprägendstem": "einprägend",
    "einprägendsten": "einprägend",
    "einprägendster": "einprägend",
    "einprägendstes": "einprägend",
    "einprägest": "einprägen",
    "einpräget": "einprägen",
    "einprägsame": "einprägsam",
    "einprägsamem": "einprägsam",
    "einprägsamen": "einprägsam",
    "einprägsamer": "einprägsam",
    "einprägsamere": "einprägsam",
    "einprägsamerem": "einprägsam",
    "einprägsameren": "einprägsam",
    "einprägsamerer": "einprägsam",
    "einprägsameres": "einprägsam",
    "einprägsames": "einprägsam",
    "einprägsamste": "einprägsam",
    "einprägsamstem": "einprägsam",
    "einprägsamsten": "einprägsam",
    "einprägsamster": "einprägsam",
    "einprägsamstes": "einprägsam",
    "einprägst": "einprägen",
    "einprägt": "einprägen",
    "einprägte": "einprägen",
    "einprägten": "einprägen",
    "einprägtest": "einprägen",
    "einprägtet": "einprägen",
    "einpudere": "einpudern",
    "einpudernd": "einpudern",
    "einpudernde": "einpudernd",
    "einpuderndem": "einpudernd",
    "einpudernden": "einpudernd",
    "einpudernder": "einpudernd",
    "einpuderndere": "einpudernd",
    "einpudernderem": "einpudernd",
    "einpudernderen": "einpudernd",
    "einpudernderer": "einpudernd",
    "einpudernderes": "einpudernd",
    "einpuderndes": "einpudernd",
    "einpuderndste": "einpudernd",
    "einpuderndstem": "einpudernd",
    "einpuderndsten": "einpudernd",
    "einpuderndster": "einpudernd",
    "einpuderndstes": "einpudernd",
    "einpuderst": "einpudern",
    "einpudert": "einpudern",
    "einpuderte": "einpudern",
    "einpuderten": "einpudern",
    "einpudertest": "einpudern",
    "einpudertet": "einpudern",
    "einpumpe": "einpumpen",
    "einpumpend": "einpumpen",
    "einpumpende": "einpumpend",
    "einpumpendem": "einpumpend",
    "einpumpenden": "einpumpend",
    "einpumpender": "einpumpend",
    "einpumpendes": "einpumpend",
    "einpumpest": "einpumpen",
    "einpumpet": "einpumpen",
    "einpumpst": "einpumpen",
    "einpumpt": "einpumpen",
    "einpumpte": "einpumpen",
    "einpumpten": "einpumpen",
    "einpumptest": "einpumpen",
    "einpumptet": "einpumpen",
    "einpökele": "einpökeln",
    "einpökelnd": "einpökeln",
    "einpökelnde": "einpökelnd",
    "einpökelndem": "einpökelnd",
    "einpökelnden": "einpökelnd",
    "einpökelnder": "einpökelnd",
    "einpökelndere": "einpökelnd",
    "einpökelnderem": "einpökelnd",
    "einpökelnderen": "einpökelnd",
    "einpökelnderer": "einpökelnd",
    "einpökelnderes": "einpökelnd",
    "einpökelndes": "einpökelnd",
    "einpökelndste": "einpökelnd",
    "einpökelndstem": "einpökelnd",
    "einpökelndsten": "einpökelnd",
    "einpökelndster": "einpökelnd",
    "einpökelndstes": "einpökelnd",
    "einpökelst": "einpökeln",
    "einpökelt": "einpökeln",
    "einpökelte": "einpökeln",
    "einpökelten": "einpökeln",
    "einpökeltest": "einpökeln",
    "einpökeltet": "einpökeln",
    "einpökle": "einpökeln",
    "einquartiere": "einquartieren",
    "einquartierend": "einquartieren",
    "einquartierende": "einquartierend",
    "einquartierendem": "einquartierend",
    "einquartierenden": "einquartierend",
    "einquartierender": "einquartierend",
    "einquartierendes": "einquartierend",
    "einquartierest": "einquartieren",
    "einquartieret": "einquartieren",
    "einquartierst": "einquartieren",
    "einquartiert": "einquartieren",
    "einquartierte": "einquartieren",
    "einquartiertem": "einquartiert",
    "einquartierten": "einquartieren",
    "einquartierter": "einquartiert",
    "einquartiertes": "einquartiert",
    "einquartiertest": "einquartieren",
    "einquartiertet": "einquartieren",
    "einrahme": "einrahmen",
    "einrahmend": "einrahmen",
    "einrahmende": "einrahmend",
    "einrahmendem": "einrahmend",
    "einrahmenden": "einrahmend",
    "einrahmender": "einrahmend",
    "einrahmendes": "einrahmend",
    "einrahmest": "einrahmen",
    "einrahmet": "einrahmen",
    "einrahmst": "einrahmen",
    "einrahmt": "einrahmen",
    "einrahmte": "einrahmen",
    "einrahmten": "einrahmen",
    "einrahmtest": "einrahmen",
    "einrahmtet": "einrahmen",
    "einramme": "einrammen",
    "einrammend": "einrammen",
    "einrammende": "einrammend",
    "einrammendem": "einrammend",
    "einrammenden": "einrammend",
    "einrammender": "einrammend",
    "einrammendere": "einrammend",
    "einrammenderem": "einrammend",
    "einrammenderen": "einrammend",
    "einrammenderer": "einrammend",
    "einrammenderes": "einrammend",
    "einrammendes": "einrammend",
    "einrammendste": "einrammend",
    "einrammendstem": "einrammend",
    "einrammendsten": "einrammend",
    "einrammendster": "einrammend",
    "einrammendstes": "einrammend",
    "einrammest": "einrammen",
    "einrammet": "einrammen",
    "einrammst": "einrammen",
    "einrammt": "einrammen",
    "einrammte": "einrammen",
    "einrammten": "einrammen",
    "einrammtest": "einrammen",
    "einrammtet": "einrammen",
    "einrannte": "einrennen",
    "einrannten": "einrennen",
    "einranntest": "einrennen",
    "einranntet": "einrennen",
    "einraste": "einrasten",
    "einrastend": "einrasten",
    "einrastende": "einrastend",
    "einrastendem": "einrastend",
    "einrastenden": "einrastend",
    "einrastender": "einrastend",
    "einrastendere": "einrastend",
    "einrastenderem": "einrastend",
    "einrastenderen": "einrastend",
    "einrastenderer": "einrastend",
    "einrastenderes": "einrastend",
    "einrastendes": "einrastend",
    "einrastendste": "einrastend",
    "einrastendstem": "einrastend",
    "einrastendsten": "einrastend",
    "einrastendster": "einrastend",
    "einrastendstes": "einrastend",
    "einrastest": "einrasten",
    "einrastet": "einrasten",
    "einrastete": "einrasten",
    "einrasteten": "einrasten",
    "einrastetest": "einrasten",
    "einrastetet": "einrasten",
    "einrechne": "einrechnen",
    "einrechnend": "einrechnen",
    "einrechnende": "einrechnend",
    "einrechnendem": "einrechnend",
    "einrechnenden": "einrechnend",
    "einrechnender": "einrechnend",
    "einrechnendes": "einrechnend",
    "einrechnest": "einrechnen",
    "einrechnet": "einrechnen",
    "einrechnete": "einrechnen",
    "einrechneten": "einrechnen",
    "einrechnetest": "einrechnen",
    "einrechnetet": "einrechnen",
    "einrede": "einreden",
    "einredend": "einreden",
    "einredende": "einredend",
    "einredendem": "einredend",
    "einredenden": "einredend",
    "einredender": "einredend",
    "einredendes": "einredend",
    "einredest": "einreden",
    "einredet": "einreden",
    "einredete": "einreden",
    "einredeten": "einreden",
    "einredetest": "einreden",
    "einredetet": "einreden",
    "einregne": "einregnen",
    "einregnend": "einregnen",
    "einregnende": "einregnend",
    "einregnendem": "einregnend",
    "einregnenden": "einregnend",
    "einregnender": "einregnend",
    "einregnendes": "einregnend",
    "einregnest": "einregnen",
    "einregnet": "einregnen",
    "einregnete": "einregnen",
    "einregneten": "einregnen",
    "einregnetest": "einregnen",
    "einregnetet": "einregnen",
    "einreibe": "einreiben",
    "einreibend": "einreiben",
    "einreibende": "einreibend",
    "einreibendem": "einreibend",
    "einreibenden": "einreibend",
    "einreibender": "einreibend",
    "einreibendes": "einreibend",
    "einreibest": "einreiben",
    "einreibet": "einreiben",
    "einreibst": "einreiben",
    "einreibt": "einreiben",
    "einreiche": "einreichen",
    "einreichend": "einreichen",
    "einreichende": "einreichend",
    "einreichendem": "einreichend",
    "einreichenden": "einreichend",
    "einreichender": "einreichend",
    "einreichendes": "einreichend",
    "einreichest": "einreichen",
    "einreichet": "einreichen",
    "einreichst": "einreichen",
    "einreicht": "einreichen",
    "einreichte": "einreichen",
    "einreichten": "einreichen",
    "einreichtest": "einreichen",
    "einreichtet": "einreichen",
    "einreihe": "einreihen",
    "einreihend": "einreihen",
    "einreihende": "einreihend",
    "einreihendem": "einreihend",
    "einreihenden": "einreihend",
    "einreihender": "einreihend",
    "einreihendes": "einreihend",
    "einreihest": "einreihen",
    "einreihet": "einreihen",
    "einreihst": "einreihen",
    "einreiht": "einreihen",
    "einreihte": "einreihen",
    "einreihten": "einreihen",
    "einreihtest": "einreihen",
    "einreihtet": "einreihen",
    "einreise": "einreisen",
    "einreisend": "einreisen",
    "einreisende": "einreisend",
    "einreisendem": "einreisend",
    "einreisenden": "einreisend",
    "einreisender": "einreisend",
    "einreisendes": "einreisend",
    "einreisest": "einreisen",
    "einreiset": "einreisen",
    "einreist": "einreisen",
    "einreiste": "einreisen",
    "einreisten": "einreisen",
    "einreistest": "einreisen",
    "einreistet": "einreisen",
    "einreite": "einreiten",
    "einreitend": "einreiten",
    "einreitende": "einreitend",
    "einreitendem": "einreitend",
    "einreitenden": "einreitend",
    "einreitender": "einreitend",
    "einreitendes": "einreitend",
    "einreitest": "einreiten",
    "einreitet": "einreiten",
    "einreiße": "einreißen",
    "einreißend": "einreißen",
    "einreißende": "einreißend",
    "einreißendem": "einreißend",
    "einreißenden": "einreißend",
    "einreißender": "einreißend",
    "einreißendere": "einreißend",
    "einreißenderem": "einreißend",
    "einreißenderen": "einreißend",
    "einreißenderer": "einreißend",
    "einreißenderes": "einreißend",
    "einreißendes": "einreißend",
    "einreißendste": "einreißend",
    "einreißendstem": "einreißend",
    "einreißendsten": "einreißend",
    "einreißendster": "einreißend",
    "einreißendstes": "einreißend",
    "einreißest": "einreißen",
    "einreißet": "einreißen",
    "einreißt": "einreißen",
    "einrenke": "einrenken",
    "einrenkend": "einrenken",
    "einrenkende": "einrenkend",
    "einrenkendem": "einrenkend",
    "einrenkenden": "einrenkend",
    "einrenkender": "einrenkend",
    "einrenkendes": "einrenkend",
    "einrenkest": "einrenken",
    "einrenket": "einrenken",
    "einrenkst": "einrenken",
    "einrenkt": "einrenken",
    "einrenkte": "einrenken",
    "einrenkten": "einrenken",
    "einrenktest": "einrenken",
    "einrenktet": "einrenken",
    "einrenne": "einrennen",
    "einrennend": "einrennen",
    "einrennende": "einrennend",
    "einrennendem": "einrennend",
    "einrennenden": "einrennend",
    "einrennender": "einrennend",
    "einrennendes": "einrennend",
    "einrennest": "einrennen",
    "einrennet": "einrennen",
    "einrennst": "einrennen",
    "einrennt": "einrennen",
    "einrichte": "einrichten",
    "einrichtend": "einrichten",
    "einrichtende": "einrichtend",
    "einrichtendem": "einrichtend",
    "einrichtenden": "einrichtend",
    "einrichtender": "einrichtend",
    "einrichtendes": "einrichtend",
    "einrichtest": "einrichten",
    "einrichtet": "einrichten",
    "einrichtete": "einrichten",
    "einrichteten": "einrichten",
    "einrichtetest": "einrichten",
    "einrichtetet": "einrichten",
    "einrieb": "einreiben",
    "einriebe": "einreiben",
    "einrieben": "einreiben",
    "einriebest": "einreiben",
    "einriebet": "einreiben",
    "einriebst": "einreiben",
    "einriebt": "einreiben",
    "einriegele": "einriegeln",
    "einriegelnd": "einriegeln",
    "einriegelnde": "einriegelnd",
    "einriegelndem": "einriegelnd",
    "einriegelnden": "einriegelnd",
    "einriegelnder": "einriegelnd",
    "einriegelndes": "einriegelnd",
    "einriegelst": "einriegeln",
    "einriegelt": "einriegeln",
    "einriegelte": "einriegeln",
    "einriegelten": "einriegeln",
    "einriegeltest": "einriegeln",
    "einriegeltet": "einriegeln",
    "einriegle": "einriegeln",
    "einrisse": "einreißen",
    "einrissen": "einreißen",
    "einrissest": "einreißen",
    "einrisset": "einreißen",
    "einritt": "einreiten",
    "einritte": "einreiten",
    "einritten": "einreiten",
    "einrittest": "einreiten",
    "einrittet": "einreiten",
    "einritze": "einritzen",
    "einritzend": "einritzen",
    "einritzende": "einritzend",
    "einritzendem": "einritzend",
    "einritzenden": "einritzend",
    "einritzender": "einritzend",
    "einritzendes": "einritzend",
    "einritzest": "einritzen",
    "einritzet": "einritzen",
    "einritzt": "einritzen",
    "einritzte": "einritzen",
    "einritzten": "einritzen",
    "einritztest": "einritzen",
    "einritztet": "einritzen",
    "einriß": "einreißen",
    "einrißt": "einreißen",
    "einrolle": "einrollen",
    "einrollend": "einrollen",
    "einrollende": "einrollend",
    "einrollendem": "einrollend",
    "einrollenden": "einrollend",
    "einrollender": "einrollend",
    "einrollendere": "einrollend",
    "einrollenderem": "einrollend",
    "einrollenderen": "einrollend",
    "einrollenderer": "einrollend",
    "einrollenderes": "einrollend",
    "einrollendes": "einrollend",
    "einrollendste": "einrollend",
    "einrollendstem": "einrollend",
    "einrollendsten": "einrollend",
    "einrollendster": "einrollend",
    "einrollendstes": "einrollend",
    "einrollest": "einrollen",
    "einrollet": "einrollen",
    "einrollst": "einrollen",
    "einrollt": "einrollen",
    "einrollte": "einrollen",
    "einrollten": "einrollen",
    "einrolltest": "einrollen",
    "einrolltet": "einrollen",
    "einroste": "einrosten",
    "einrostend": "einrosten",
    "einrostende": "einrostend",
    "einrostendem": "einrostend",
    "einrostenden": "einrostend",
    "einrostender": "einrostend",
    "einrostendere": "einrostend",
    "einrostenderem": "einrostend",
    "einrostenderen": "einrostend",
    "einrostenderer": "einrostend",
    "einrostenderes": "einrostend",
    "einrostendes": "einrostend",
    "einrostendste": "einrostend",
    "einrostendstem": "einrostend",
    "einrostendsten": "einrostend",
    "einrostendster": "einrostend",
    "einrostendstes": "einrostend",
    "einrostest": "einrosten",
    "einrostet": "einrosten",
    "einrostete": "einrosten",
    "einrosteten": "einrosten",
    "einrostetest": "einrosten",
    "einrostetet": "einrosten",
    "einräuchere": "einräuchern",
    "einräuchernd": "einräuchern",
    "einräuchernde": "einräuchernd",
    "einräucherndem": "einräuchernd",
    "einräuchernden": "einräuchernd",
    "einräuchernder": "einräuchernd",
    "einräucherndere": "einräuchernd",
    "einräuchernderem": "einräuchernd",
    "einräuchernderen": "einräuchernd",
    "einräuchernderer": "einräuchernd",
    "einräuchernderes": "einräuchernd",
    "einräucherndes": "einräuchernd",
    "einräucherndste": "einräuchernd",
    "einräucherndstem": "einräuchernd",
    "einräucherndsten": "einräuchernd",
    "einräucherndster": "einräuchernd",
    "einräucherndstes": "einräuchernd",
    "einräucherst": "einräuchern",
    "einräuchert": "einräuchern",
    "einräucherte": "einräuchern",
    "einräucherten": "einräuchern",
    "einräuchertest": "einräuchern",
    "einräuchertet": "einräuchern",
    "einräume": "einräumen",
    "einräumend": "einräumen",
    "einräumende": "einräumend",
    "einräumendem": "einräumend",
    "einräumenden": "einräumend",
    "einräumender": "einräumend",
    "einräumendere": "einräumend",
    "einräumenderem": "einräumend",
    "einräumenderen": "einräumend",
    "einräumenderer": "einräumend",
    "einräumenderes": "einräumend",
    "einräumendes": "einräumend",
    "einräumendste": "einräumend",
    "einräumendstem": "einräumend",
    "einräumendsten": "einräumend",
    "einräumendster": "einräumend",
    "einräumendstes": "einräumend",
    "einräumest": "einräumen",
    "einräumet": "einräumen",
    "einräumst": "einräumen",
    "einräumt": "einräumen",
    "einräumte": "einräumen",
    "einräumten": "einräumen",
    "einräumtest": "einräumen",
    "einräumtet": "einräumen",
    "einrücke": "einrücken",
    "einrückend": "einrücken",
    "einrückende": "einrückend",
    "einrückendem": "einrückend",
    "einrückenden": "einrückend",
    "einrückender": "einrückend",
    "einrückendes": "einrückend",
    "einrückest": "einrücken",
    "einrücket": "einrücken",
    "einrückst": "einrücken",
    "einrückt": "einrücken",
    "einrückte": "einrücken",
    "einrückten": "einrücken",
    "einrücktest": "einrücken",
    "einrücktet": "einrücken",
    "einrühre": "einrühren",
    "einrührend": "einrühren",
    "einrührende": "einrührend",
    "einrührendem": "einrührend",
    "einrührenden": "einrührend",
    "einrührender": "einrührend",
    "einrührendes": "einrührend",
    "einrührest": "einrühren",
    "einrühret": "einrühren",
    "einrührst": "einrühren",
    "einrührt": "einrühren",
    "einrührte": "einrühren",
    "einrührten": "einrühren",
    "einrührtest": "einrühren",
    "einrührtet": "einrühren",
    "einrüste": "einrüsten",
    "einrüstend": "einrüsten",
    "einrüstende": "einrüstend",
    "einrüstendem": "einrüstend",
    "einrüstenden": "einrüstend",
    "einrüstender": "einrüstend",
    "einrüstendes": "einrüstend",
    "einrüstest": "einrüsten",
    "einrüstet": "einrüsten",
    "einrüstete": "einrüsten",
    "einrüsteten": "einrüsten",
    "einrüstetest": "einrüsten",
    "einrüstetet": "einrüsten",
    "einsage": "einsagen",
    "einsagend": "einsagen",
    "einsagende": "einsagend",
    "einsagendem": "einsagend",
    "einsagenden": "einsagend",
    "einsagender": "einsagend",
    "einsagendes": "einsagend",
    "einsagest": "einsagen",
    "einsaget": "einsagen",
    "einsagst": "einsagen",
    "einsagt": "einsagen",
    "einsagte": "einsagen",
    "einsagten": "einsagen",
    "einsagtest": "einsagen",
    "einsagtet": "einsagen",
    "einsah": "einsehen",
    "einsahen": "einsehen",
    "einsahst": "einsehen",
    "einsaht": "einsehen",
    "einsalbe": "einsalben",
    "einsalbend": "einsalben",
    "einsalbende": "einsalbend",
    "einsalbendem": "einsalbend",
    "einsalbenden": "einsalbend",
    "einsalbender": "einsalbend",
    "einsalbendes": "einsalbend",
    "einsalbest": "einsalben",
    "einsalbet": "einsalben",
    "einsalbst": "einsalben",
    "einsalbt": "einsalben",
    "einsalbte": "einsalben",
    "einsalbten": "einsalben",
    "einsalbtest": "einsalben",
    "einsalbtet": "einsalben",
    "einsalze": "einsalzen",
    "einsalzend": "einsalzen",
    "einsalzende": "einsalzend",
    "einsalzendem": "einsalzend",
    "einsalzenden": "einsalzend",
    "einsalzender": "einsalzend",
    "einsalzendere": "einsalzend",
    "einsalzenderem": "einsalzend",
    "einsalzenderen": "einsalzend",
    "einsalzenderer": "einsalzend",
    "einsalzenderes": "einsalzend",
    "einsalzendes": "einsalzend",
    "einsalzendste": "einsalzend",
    "einsalzendstem": "einsalzend",
    "einsalzendsten": "einsalzend",
    "einsalzendster": "einsalzend",
    "einsalzendstes": "einsalzend",
    "einsalzest": "einsalzen",
    "einsalzet": "einsalzen",
    "einsalzt": "einsalzen",
    "einsalzte": "einsalzen",
    "einsalzten": "einsalzen",
    "einsalztest": "einsalzen",
    "einsalztet": "einsalzen",
    "einsame": "einsam",
    "einsamem": "einsam",
    "einsamen": "einsam",
    "einsamer": "einsam",
    "einsamere": "einsam",
    "einsamerem": "einsam",
    "einsameren": "einsam",
    "einsamerer": "einsam",
    "einsameres": "einsam",
    "einsames": "einsam",
    "einsammele": "einsammeln",
    "einsammelnd": "einsammeln",
    "einsammelnde": "einsammelnd",
    "einsammelndem": "einsammelnd",
    "einsammelnden": "einsammelnd",
    "einsammelnder": "einsammelnd",
    "einsammelndes": "einsammelnd",
    "einsammelst": "einsammeln",
    "einsammelt": "einsammeln",
    "einsammelte": "einsammeln",
    "einsammelten": "einsammeln",
    "einsammeltest": "einsammeln",
    "einsammeltet": "einsammeln",
    "einsammle": "einsammeln",
    "einsamste": "einsam",
    "einsamstem": "einsam",
    "einsamsten": "einsam",
    "einsamster": "einsam",
    "einsamstes": "einsam",
    "einsandte": "einsenden",
    "einsandten": "einsenden",
    "einsandtest": "einsenden",
    "einsandtet": "einsenden",
    "einsang": "einsingen",
    "einsangen": "einsingen",
    "einsangst": "einsingen",
    "einsangt": "einsingen",
    "einsank": "einsinken",
    "einsanken": "einsinken",
    "einsankst": "einsinken",
    "einsankt": "einsinken",
    "einsarge": "einsargen",
    "einsargend": "einsargen",
    "einsargende": "einsargend",
    "einsargendem": "einsargend",
    "einsargenden": "einsargend",
    "einsargender": "einsargend",
    "einsargendes": "einsargend",
    "einsargest": "einsargen",
    "einsarget": "einsargen",
    "einsargst": "einsargen",
    "einsargt": "einsargen",
    "einsargte": "einsargen",
    "einsargten": "einsargen",
    "einsargtest": "einsargen",
    "einsargtet": "einsargen",
    "einsatzbereite": "einsatzbereit",
    "einsatzbereitem": "einsatzbereit",
    "einsatzbereiten": "einsatzbereit",
    "einsatzbereiter": "einsatzbereit",
    "einsatzbereitere": "einsatzbereit",
    "einsatzbereiterem": "einsatzbereit",
    "einsatzbereiteren": "einsatzbereit",
    "einsatzbereiterer": "einsatzbereit",
    "einsatzbereiteres": "einsatzbereit",
    "einsatzbereites": "einsatzbereit",
    "einsatzbereiteste": "einsatzbereit",
    "einsatzbereitestem": "einsatzbereit",
    "einsatzbereitesten": "einsatzbereit",
    "einsatzbereitester": "einsatzbereit",
    "einsatzbereitestes": "einsatzbereit",
    "einsaue": "einsauen",
    "einsauend": "einsauen",
    "einsauende": "einsauend",
    "einsauendem": "einsauend",
    "einsauenden": "einsauend",
    "einsauender": "einsauend",
    "einsauendere": "einsauend",
    "einsauenderem": "einsauend",
    "einsauenderen": "einsauend",
    "einsauenderer": "einsauend",
    "einsauenderes": "einsauend",
    "einsauendes": "einsauend",
    "einsauendste": "einsauend",
    "einsauendstem": "einsauend",
    "einsauendsten": "einsauend",
    "einsauendster": "einsauend",
    "einsauendstes": "einsauend",
    "einsauest": "einsauen",
    "einsauet": "einsauen",
    "einsauge": "einsaugen",
    "einsaugend": "einsaugen",
    "einsaugende": "einsaugend",
    "einsaugendem": "einsaugend",
    "einsaugenden": "einsaugend",
    "einsaugender": "einsaugend",
    "einsaugendere": "einsaugend",
    "einsaugenderem": "einsaugend",
    "einsaugenderen": "einsaugend",
    "einsaugenderer": "einsaugend",
    "einsaugenderes": "einsaugend",
    "einsaugendes": "einsaugend",
    "einsaugendste": "einsaugend",
    "einsaugendstem": "einsaugend",
    "einsaugendsten": "einsaugend",
    "einsaugendster": "einsaugend",
    "einsaugendstes": "einsaugend",
    "einsaugest": "einsaugen",
    "einsauget": "einsaugen",
    "einsaugst": "einsaugen",
    "einsaugt": "einsaugen",
    "einsaugte": "einsaugen",
    "einsaugten": "einsaugen",
    "einsaugtest": "einsaugen",
    "einsaugtet": "einsaugen",
    "einsaust": "einsauen",
    "einsaut": "einsauen",
    "einsaute": "einsauen",
    "einsauten": "einsauen",
    "einsautest": "einsauen",
    "einsautet": "einsauen",
    "einsaß": "einsitzen",
    "einsaßen": "einsitzen",
    "einsaßt": "einsitzen",
    "einschachtele": "einschachteln",
    "einschachtelnd": "einschachteln",
    "einschachtelnde": "einschachtelnd",
    "einschachtelndem": "einschachtelnd",
    "einschachtelnden": "einschachtelnd",
    "einschachtelnder": "einschachtelnd",
    "einschachtelndere": "einschachtelnd",
    "einschachtelnderem": "einschachtelnd",
    "einschachtelnderen": "einschachtelnd",
    "einschachtelnderer": "einschachtelnd",
    "einschachtelnderes": "einschachtelnd",
    "einschachtelndes": "einschachtelnd",
    "einschachtelndste": "einschachtelnd",
    "einschachtelndstem": "einschachtelnd",
    "einschachtelndsten": "einschachtelnd",
    "einschachtelndster": "einschachtelnd",
    "einschachtelndstes": "einschachtelnd",
    "einschachtelst": "einschachteln",
    "einschachtelt": "einschachteln",
    "einschachtelte": "einschachteln",
    "einschachtelten": "einschachteln",
    "einschachteltest": "einschachteln",
    "einschachteltet": "einschachteln",
    "einschachtle": "einschachteln",
    "einschalte": "einschalten",
    "einschaltend": "einschalten",
    "einschaltende": "einschaltend",
    "einschaltendem": "einschaltend",
    "einschaltenden": "einschaltend",
    "einschaltender": "einschaltend",
    "einschaltendes": "einschaltend",
    "einschaltest": "einschalten",
    "einschaltet": "einschalten",
    "einschaltete": "einschalten",
    "einschalteten": "einschalten",
    "einschaltetest": "einschalten",
    "einschaltetet": "einschalten",
    "einscharre": "einscharren",
    "einscharrend": "einscharren",
    "einscharrende": "einscharrend",
    "einscharrendem": "einscharrend",
    "einscharrenden": "einscharrend",
    "einscharrender": "einscharrend",
    "einscharrendes": "einscharrend",
    "einscharrest": "einscharren",
    "einscharret": "einscharren",
    "einscharrst": "einscharren",
    "einscharrt": "einscharren",
    "einscharrte": "einscharren",
    "einscharrten": "einscharren",
    "einscharrtest": "einscharren",
    "einscharrtet": "einscharren",
    "einschenke": "einschenken",
    "einschenkend": "einschenken",
    "einschenkende": "einschenkend",
    "einschenkendem": "einschenkend",
    "einschenkenden": "einschenkend",
    "einschenkender": "einschenkend",
    "einschenkendes": "einschenkend",
    "einschenkest": "einschenken",
    "einschenket": "einschenken",
    "einschenkst": "einschenken",
    "einschenkt": "einschenken",
    "einschenkte": "einschenken",
    "einschenkten": "einschenken",
    "einschenktest": "einschenken",
    "einschenktet": "einschenken",
    "einschere": "einscheren",
    "einscherend": "einscheren",
    "einscherende": "einscherend",
    "einscherendem": "einscherend",
    "einscherenden": "einscherend",
    "einscherender": "einscherend",
    "einscherendes": "einscherend",
    "einscherest": "einscheren",
    "einscheret": "einscheren",
    "einscherst": "einscheren",
    "einschert": "einscheren",
    "einscherte": "einscheren",
    "einscherten": "einscheren",
    "einschertest": "einscheren",
    "einschertet": "einscheren",
    "einschiebe": "einschieben",
    "einschiebend": "einschieben",
    "einschiebende": "einschiebend",
    "einschiebendem": "einschiebend",
    "einschiebenden": "einschiebend",
    "einschiebender": "einschiebend",
    "einschiebendes": "einschiebend",
    "einschiebest": "einschieben",
    "einschiebet": "einschieben",
    "einschiebst": "einschieben",
    "einschiebt": "einschieben",
    "einschieße": "einschießen",
    "einschießend": "einschießen",
    "einschießende": "einschießend",
    "einschießendem": "einschießend",
    "einschießenden": "einschießend",
    "einschießender": "einschießend",
    "einschießendere": "einschießend",
    "einschießenderem": "einschießend",
    "einschießenderen": "einschießend",
    "einschießenderer": "einschießend",
    "einschießenderes": "einschießend",
    "einschießendes": "einschießend",
    "einschießendste": "einschießend",
    "einschießendstem": "einschießend",
    "einschießendsten": "einschießend",
    "einschießendster": "einschießend",
    "einschießendstes": "einschießend",
    "einschießest": "einschießen",
    "einschießet": "einschießen",
    "einschießt": "einschießen",
    "einschiffe": "einschiffen",
    "einschiffend": "einschiffen",
    "einschiffende": "einschiffend",
    "einschiffendem": "einschiffend",
    "einschiffenden": "einschiffend",
    "einschiffender": "einschiffend",
    "einschiffendes": "einschiffend",
    "einschiffest": "einschiffen",
    "einschiffet": "einschiffen",
    "einschiffst": "einschiffen",
    "einschifft": "einschiffen",
    "einschiffte": "einschiffen",
    "einschifften": "einschiffen",
    "einschifftest": "einschiffen",
    "einschifftet": "einschiffen",
    "einschlafe": "einschlafen",
    "einschlafend": "einschlafen",
    "einschlafende": "einschlafend",
    "einschlafendem": "einschlafend",
    "einschlafenden": "einschlafend",
    "einschlafender": "einschlafend",
    "einschlafendes": "einschlafend",
    "einschlafest": "einschlafen",
    "einschlafet": "einschlafen",
    "einschlaft": "einschlafen",
    "einschlage": "einschlagen",
    "einschlagend": "einschlagen",
    "einschlagende": "einschlagend",
    "einschlagendem": "einschlagend",
    "einschlagenden": "einschlagend",
    "einschlagender": "einschlagend",
    "einschlagendere": "einschlagend",
    "einschlagenderem": "einschlagend",
    "einschlagenderen": "einschlagend",
    "einschlagenderer": "einschlagend",
    "einschlagenderes": "einschlagend",
    "einschlagendes": "einschlagend",
    "einschlagendste": "einschlagend",
    "einschlagendstem": "einschlagend",
    "einschlagendsten": "einschlagend",
    "einschlagendster": "einschlagend",
    "einschlagendstes": "einschlagend",
    "einschlagest": "einschlagen",
    "einschlaget": "einschlagen",
    "einschlagt": "einschlagen",
    "einschleiche": "einschleichen",
    "einschleichend": "einschleichen",
    "einschleichende": "einschleichend",
    "einschleichendem": "einschleichend",
    "einschleichenden": "einschleichend",
    "einschleichender": "einschleichend",
    "einschleichendes": "einschleichend",
    "einschleichest": "einschleichen",
    "einschleichet": "einschleichen",
    "einschleichst": "einschleichen",
    "einschleicht": "einschleichen",
    "einschleife": "einschleifen",
    "einschleifend": "einschleifen",
    "einschleifende": "einschleifend",
    "einschleifendem": "einschleifend",
    "einschleifenden": "einschleifend",
    "einschleifender": "einschleifend",
    "einschleifendes": "einschleifend",
    "einschleifest": "einschleifen",
    "einschleifet": "einschleifen",
    "einschleifst": "einschleifen",
    "einschleift": "einschleifen",
    "einschleifte": "einschleifen",
    "einschleiften": "einschleifen",
    "einschleiftest": "einschleifen",
    "einschleiftet": "einschleifen",
    "einschleime": "einschleimen",
    "einschleimend": "einschleimen",
    "einschleimende": "einschleimend",
    "einschleimendem": "einschleimend",
    "einschleimenden": "einschleimend",
    "einschleimender": "einschleimend",
    "einschleimendere": "einschleimend",
    "einschleimenderem": "einschleimend",
    "einschleimenderen": "einschleimend",
    "einschleimenderer": "einschleimend",
    "einschleimenderes": "einschleimend",
    "einschleimendes": "einschleimend",
    "einschleimendste": "einschleimend",
    "einschleimendstem": "einschleimend",
    "einschleimendsten": "einschleimend",
    "einschleimendster": "einschleimend",
    "einschleimendstes": "einschleimend",
    "einschleimest": "einschleimen",
    "einschleimet": "einschleimen",
    "einschleimst": "einschleimen",
    "einschleimt": "einschleimen",
    "einschleimte": "einschleimen",
    "einschleimten": "einschleimen",
    "einschleimtest": "einschleimen",
    "einschleimtet": "einschleimen",
    "einschleppe": "einschleppen",
    "einschleppend": "einschleppen",
    "einschleppende": "einschleppend",
    "einschleppendem": "einschleppend",
    "einschleppenden": "einschleppend",
    "einschleppender": "einschleppend",
    "einschleppendes": "einschleppend",
    "einschleppest": "einschleppen",
    "einschleppet": "einschleppen",
    "einschleppst": "einschleppen",
    "einschleppt": "einschleppen",
    "einschleppte": "einschleppen",
    "einschleppten": "einschleppen",
    "einschlepptest": "einschleppen",
    "einschlepptet": "einschleppen",
    "einschleuse": "einschleusen",
    "einschleusend": "einschleusen",
    "einschleusende": "einschleusend",
    "einschleusendem": "einschleusend",
    "einschleusenden": "einschleusend",
    "einschleusender": "einschleusend",
    "einschleusendes": "einschleusend",
    "einschleusest": "einschleusen",
    "einschleuset": "einschleusen",
    "einschleust": "einschleusen",
    "einschleuste": "einschleusen",
    "einschleusten": "einschleusen",
    "einschleustest": "einschleusen",
    "einschleustet": "einschleusen",
    "einschlich": "einschleichen",
    "einschliche": "einschleichen",
    "einschlichen": "einschleichen",
    "einschlichest": "einschleichen",
    "einschlichet": "einschleichen",
    "einschlichst": "einschleichen",
    "einschlicht": "einschleichen",
    "einschlief": "einschlafen",
    "einschliefe": "einschlafen",
    "einschliefen": "einschlafen",
    "einschliefest": "einschlafen",
    "einschliefet": "einschlafen",
    "einschliefst": "einschlafen",
    "einschlieft": "einschlafen",
    "einschließe": "einschließen",
    "einschließend": "einschließen",
    "einschließende": "einschließend",
    "einschließendem": "einschließend",
    "einschließenden": "einschließend",
    "einschließender": "einschließend",
    "einschließendes": "einschließend",
    "einschließest": "einschließen",
    "einschließet": "einschließen",
    "einschließt": "einschließen",
    "einschliff": "einschleifen",
    "einschliffe": "einschleifen",
    "einschliffen": "einschleifen",
    "einschliffest": "einschleifen",
    "einschliffet": "einschleifen",
    "einschliffst": "einschleifen",
    "einschlifft": "einschleifen",
    "einschlossen": "einschließen",
    "einschloß": "einschließen",
    "einschloßt": "einschließen",
    "einschlug": "einschlagen",
    "einschlugen": "einschlagen",
    "einschlugst": "einschlagen",
    "einschlugt": "einschlagen",
    "einschlummere": "einschlummern",
    "einschlummernd": "einschlummern",
    "einschlummernde": "einschlummernd",
    "einschlummerndem": "einschlummernd",
    "einschlummernden": "einschlummernd",
    "einschlummernder": "einschlummernd",
    "einschlummerndes": "einschlummernd",
    "einschlummerst": "einschlummern",
    "einschlummert": "einschlummern",
    "einschlummerte": "einschlummern",
    "einschlummerten": "einschlummern",
    "einschlummertest": "einschlummern",
    "einschlummertet": "einschlummern",
    "einschläfere": "einschläfern",
    "einschläfernd": "einschläfern",
    "einschläfernde": "einschläfernd",
    "einschläferndem": "einschläfernd",
    "einschläfernden": "einschläfernd",
    "einschläfernder": "einschläfernd",
    "einschläferndes": "einschläfernd",
    "einschläferst": "einschläfern",
    "einschläfert": "einschläfern",
    "einschläferte": "einschläfern",
    "einschläferten": "einschläfern",
    "einschläfertest": "einschläfern",
    "einschläfertet": "einschläfern",
    "einschläfst": "einschlafen",
    "einschläft": "einschlafen",
    "einschlägige": "einschlägig",
    "einschlägigem": "einschlägig",
    "einschlägigen": "einschlägig",
    "einschlägiger": "einschlägig",
    "einschlägiges": "einschlägig",
    "einschlägst": "einschlagen",
    "einschlägt": "einschlagen",
    "einschlösse": "einschließen",
    "einschlössen": "einschließen",
    "einschlössest": "einschließen",
    "einschlösset": "einschließen",
    "einschlüge": "einschlagen",
    "einschlügen": "einschlagen",
    "einschlügest": "einschlagen",
    "einschlüget": "einschlagen",
    "einschmeichele": "einschmeicheln",
    "einschmeichelnd": "einschmeicheln",
    "einschmeichelnde": "einschmeichelnd",
    "einschmeichelndem": "einschmeichelnd",
    "einschmeichelnden": "einschmeichelnd",
    "einschmeichelnder": "einschmeichelnd",
    "einschmeichelndere": "einschmeichelnd",
    "einschmeichelnderem": "einschmeichelnd",
    "einschmeichelnderen": "einschmeichelnd",
    "einschmeichelnderer": "einschmeichelnd",
    "einschmeichelnderes": "einschmeichelnd",
    "einschmeichelndes": "einschmeichelnd",
    "einschmeichelndste": "einschmeichelnd",
    "einschmeichelndstem": "einschmeichelnd",
    "einschmeichelndsten": "einschmeichelnd",
    "einschmeichelndster": "einschmeichelnd",
    "einschmeichelndstes": "einschmeichelnd",
    "einschmeichelst": "einschmeicheln",
    "einschmeichelt": "einschmeicheln",
    "einschmeichelte": "einschmeicheln",
    "einschmeichelten": "einschmeicheln",
    "einschmeicheltest": "einschmeicheln",
    "einschmeicheltet": "einschmeicheln",
    "einschmeichle": "einschmeicheln",
    "einschmeiße": "einschmeißen",
    "einschmeißend": "einschmeißen",
    "einschmeißende": "einschmeißend",
    "einschmeißendem": "einschmeißend",
    "einschmeißenden": "einschmeißend",
    "einschmeißender": "einschmeißend",
    "einschmeißendes": "einschmeißend",
    "einschmeißest": "einschmeißen",
    "einschmeißet": "einschmeißen",
    "einschmeißt": "einschmeißen",
    "einschmelze": "einschmelzen",
    "einschmelzend": "einschmelzen",
    "einschmelzende": "einschmelzend",
    "einschmelzendem": "einschmelzend",
    "einschmelzenden": "einschmelzend",
    "einschmelzender": "einschmelzend",
    "einschmelzendes": "einschmelzend",
    "einschmelzest": "einschmelzen",
    "einschmelzet": "einschmelzen",
    "einschmelzt": "einschmelzen",
    "einschmiere": "einschmieren",
    "einschmierend": "einschmieren",
    "einschmierende": "einschmierend",
    "einschmierendem": "einschmierend",
    "einschmierenden": "einschmierend",
    "einschmierender": "einschmierend",
    "einschmierendes": "einschmierend",
    "einschmierest": "einschmieren",
    "einschmieret": "einschmieren",
    "einschmierst": "einschmieren",
    "einschmiert": "einschmieren",
    "einschmierte": "einschmieren",
    "einschmierten": "einschmieren",
    "einschmiertest": "einschmieren",
    "einschmiertet": "einschmieren",
    "einschmilzt": "einschmelzen",
    "einschmisse": "einschmeißen",
    "einschmissen": "einschmeißen",
    "einschmissest": "einschmeißen",
    "einschmisset": "einschmeißen",
    "einschmiß": "einschmeißen",
    "einschmißt": "einschmeißen",
    "einschmolz": "einschmelzen",
    "einschmolzen": "einschmelzen",
    "einschmolzst": "einschmelzen",
    "einschmolzt": "einschmelzen",
    "einschmuggele": "einschmuggeln",
    "einschmuggelnd": "einschmuggeln",
    "einschmuggelnde": "einschmuggelnd",
    "einschmuggelndem": "einschmuggelnd",
    "einschmuggelnden": "einschmuggelnd",
    "einschmuggelnder": "einschmuggelnd",
    "einschmuggelndes": "einschmuggelnd",
    "einschmuggelst": "einschmuggeln",
    "einschmuggelt": "einschmuggeln",
    "einschmuggelte": "einschmuggeln",
    "einschmuggelten": "einschmuggeln",
    "einschmuggeltest": "einschmuggeln",
    "einschmuggeltet": "einschmuggeln",
    "einschmuggle": "einschmuggeln",
    "einschmölze": "einschmelzen",
    "einschmölzen": "einschmelzen",
    "einschmölzest": "einschmelzen",
    "einschmölzet": "einschmelzen",
    "einschnappe": "einschnappen",
    "einschnappend": "einschnappen",
    "einschnappende": "einschnappend",
    "einschnappendem": "einschnappend",
    "einschnappenden": "einschnappend",
    "einschnappender": "einschnappend",
    "einschnappendes": "einschnappend",
    "einschnappest": "einschnappen",
    "einschnappet": "einschnappen",
    "einschnappst": "einschnappen",
    "einschnappt": "einschnappen",
    "einschnappte": "einschnappen",
    "einschnappten": "einschnappen",
    "einschnapptest": "einschnappen",
    "einschnapptet": "einschnappen",
    "einschneide": "einschneiden",
    "einschneidend": "einschneiden",
    "einschneidende": "einschneidend",
    "einschneidendem": "einschneidend",
    "einschneidenden": "einschneidend",
    "einschneidender": "einschneidend",
    "einschneidendere": "einschneidend",
    "einschneidenderem": "einschneidend",
    "einschneidenderen": "einschneidend",
    "einschneidenderer": "einschneidend",
    "einschneidenderes": "einschneidend",
    "einschneidendes": "einschneidend",
    "einschneidendste": "einschneidend",
    "einschneidendstem": "einschneidend",
    "einschneidendsten": "einschneidend",
    "einschneidendster": "einschneidend",
    "einschneidendstes": "einschneidend",
    "einschneidest": "einschneiden",
    "einschneidet": "einschneiden",
    "einschneie": "einschneien",
    "einschneiend": "einschneien",
    "einschneiende": "einschneiend",
    "einschneiendem": "einschneiend",
    "einschneienden": "einschneiend",
    "einschneiender": "einschneiend",
    "einschneiendere": "einschneiend",
    "einschneienderem": "einschneiend",
    "einschneienderen": "einschneiend",
    "einschneienderer": "einschneiend",
    "einschneienderes": "einschneiend",
    "einschneiendes": "einschneiend",
    "einschneiendste": "einschneiend",
    "einschneiendstem": "einschneiend",
    "einschneiendsten": "einschneiend",
    "einschneiendster": "einschneiend",
    "einschneiendstes": "einschneiend",
    "einschneiest": "einschneien",
    "einschneiet": "einschneien",
    "einschneist": "einschneien",
    "einschneit": "einschneien",
    "einschneite": "einschneien",
    "einschneiten": "einschneien",
    "einschneitest": "einschneien",
    "einschneitet": "einschneien",
    "einschnitt": "einschneiden",
    "einschnittest": "einschneiden",
    "einschnittet": "einschneiden",
    "einschnitze": "einschnitzen",
    "einschnitzend": "einschnitzen",
    "einschnitzende": "einschnitzend",
    "einschnitzendem": "einschnitzend",
    "einschnitzenden": "einschnitzend",
    "einschnitzender": "einschnitzend",
    "einschnitzendes": "einschnitzend",
    "einschnitzest": "einschnitzen",
    "einschnitzet": "einschnitzen",
    "einschnitzt": "einschnitzen",
    "einschnitzte": "einschnitzen",
    "einschnitzten": "einschnitzen",
    "einschnitztest": "einschnitzen",
    "einschnitztet": "einschnitzen",
    "einschnüre": "einschnüren",
    "einschnürend": "einschnüren",
    "einschnürende": "einschnürend",
    "einschnürendem": "einschnürend",
    "einschnürenden": "einschnürend",
    "einschnürender": "einschnürend",
    "einschnürendere": "einschnürend",
    "einschnürenderem": "einschnürend",
    "einschnürenderen": "einschnürend",
    "einschnürenderer": "einschnürend",
    "einschnürenderes": "einschnürend",
    "einschnürendes": "einschnürend",
    "einschnürendste": "einschnürend",
    "einschnürendstem": "einschnürend",
    "einschnürendsten": "einschnürend",
    "einschnürendster": "einschnürend",
    "einschnürendstes": "einschnürend",
    "einschnürest": "einschnüren",
    "einschnüret": "einschnüren",
    "einschnürst": "einschnüren",
    "einschnürt": "einschnüren",
    "einschnürte": "einschnüren",
    "einschnürten": "einschnüren",
    "einschnürtest": "einschnüren",
    "einschnürtet": "einschnüren",
    "einschob": "einschieben",
    "einschoben": "einschieben",
    "einschobst": "einschieben",
    "einschobt": "einschieben",
    "einschor": "einscheren",
    "einschoren": "einscheren",
    "einschorst": "einscheren",
    "einschort": "einscheren",
    "einschossen": "einschießen",
    "einschoß": "einschießen",
    "einschoßt": "einschießen",
    "einschraube": "einschrauben",
    "einschraubend": "einschrauben",
    "einschraubende": "einschraubend",
    "einschraubendem": "einschraubend",
    "einschraubenden": "einschraubend",
    "einschraubender": "einschraubend",
    "einschraubendes": "einschraubend",
    "einschraubest": "einschrauben",
    "einschraubet": "einschrauben",
    "einschraubst": "einschrauben",
    "einschraubt": "einschrauben",
    "einschraubte": "einschrauben",
    "einschraubten": "einschrauben",
    "einschraubtest": "einschrauben",
    "einschraubtet": "einschrauben",
    "einschreibe": "einschreiben",
    "einschreibend": "einschreiben",
    "einschreibende": "einschreibend",
    "einschreibendem": "einschreibend",
    "einschreibenden": "einschreibend",
    "einschreibender": "einschreibend",
    "einschreibendes": "einschreibend",
    "einschreibest": "einschreiben",
    "einschreibet": "einschreiben",
    "einschreibst": "einschreiben",
    "einschreibt": "einschreiben",
    "einschreitend": "einschreiten",
    "einschreitende": "einschreitend",
    "einschreitendem": "einschreitend",
    "einschreitenden": "einschreitend",
    "einschreitender": "einschreitend",
    "einschreitendes": "einschreitend",
    "einschrieb": "einschreiben",
    "einschriebe": "einschreiben",
    "einschrieben": "einschreiben",
    "einschriebest": "einschreiben",
    "einschriebet": "einschreiben",
    "einschriebst": "einschreiben",
    "einschriebt": "einschreiben",
    "einschrumpfe": "einschrumpfen",
    "einschrumpfend": "einschrumpfen",
    "einschrumpfende": "einschrumpfend",
    "einschrumpfendem": "einschrumpfend",
    "einschrumpfenden": "einschrumpfend",
    "einschrumpfender": "einschrumpfend",
    "einschrumpfendere": "einschrumpfend",
    "einschrumpfenderem": "einschrumpfend",
    "einschrumpfenderen": "einschrumpfend",
    "einschrumpfenderer": "einschrumpfend",
    "einschrumpfenderes": "einschrumpfend",
    "einschrumpfendes": "einschrumpfend",
    "einschrumpfendste": "einschrumpfend",
    "einschrumpfendstem": "einschrumpfend",
    "einschrumpfendsten": "einschrumpfend",
    "einschrumpfendster": "einschrumpfend",
    "einschrumpfendstes": "einschrumpfend",
    "einschrumpfest": "einschrumpfen",
    "einschrumpfet": "einschrumpfen",
    "einschrumpfst": "einschrumpfen",
    "einschrumpft": "einschrumpfen",
    "einschrumpfte": "einschrumpfen",
    "einschrumpften": "einschrumpfen",
    "einschrumpftest": "einschrumpfen",
    "einschrumpftet": "einschrumpfen",
    "einschränke": "einschränken",
    "einschränkend": "einschränken",
    "einschränkende": "einschränkend",
    "einschränkendem": "einschränkend",
    "einschränkenden": "einschränkend",
    "einschränkender": "einschränkend",
    "einschränkendere": "einschränkend",
    "einschränkenderem": "einschränkend",
    "einschränkenderen": "einschränkend",
    "einschränkenderer": "einschränkend",
    "einschränkenderes": "einschränkend",
    "einschränkendes": "einschränkend",
    "einschränkendste": "einschränkend",
    "einschränkendstem": "einschränkend",
    "einschränkendsten": "einschränkend",
    "einschränkendster": "einschränkend",
    "einschränkendstes": "einschränkend",
    "einschränkest": "einschränken",
    "einschränket": "einschränken",
    "einschränkst": "einschränken",
    "einschränkt": "einschränken",
    "einschränkte": "einschränken",
    "einschränkten": "einschränken",
    "einschränktest": "einschränken",
    "einschränktet": "einschränken",
    "einschule": "einschulen",
    "einschulend": "einschulen",
    "einschulende": "einschulend",
    "einschulendem": "einschulend",
    "einschulenden": "einschulend",
    "einschulender": "einschulend",
    "einschulendes": "einschulend",
    "einschulest": "einschulen",
    "einschulet": "einschulen",
    "einschulst": "einschulen",
    "einschult": "einschulen",
    "einschulte": "einschulen",
    "einschulten": "einschulen",
    "einschultest": "einschulen",
    "einschultet": "einschulen",
    "einschwamm": "einschwimmen",
    "einschwammen": "einschwimmen",
    "einschwammst": "einschwimmen",
    "einschwammt": "einschwimmen",
    "einschwang": "einschwingen",
    "einschwangen": "einschwingen",
    "einschwangst": "einschwingen",
    "einschwangt": "einschwingen",
    "einschwebe": "einschweben",
    "einschwebend": "einschweben",
    "einschwebende": "einschwebend",
    "einschwebendem": "einschwebend",
    "einschwebenden": "einschwebend",
    "einschwebender": "einschwebend",
    "einschwebendes": "einschwebend",
    "einschwebest": "einschweben",
    "einschwebet": "einschweben",
    "einschwebst": "einschweben",
    "einschwebt": "einschweben",
    "einschwebte": "einschweben",
    "einschwebten": "einschweben",
    "einschwebtest": "einschweben",
    "einschwebtet": "einschweben",
    "einschwefele": "einschwefeln",
    "einschwefelnd": "einschwefeln",
    "einschwefelnde": "einschwefelnd",
    "einschwefelndem": "einschwefelnd",
    "einschwefelnden": "einschwefelnd",
    "einschwefelnder": "einschwefelnd",
    "einschwefelndere": "einschwefelnd",
    "einschwefelnderem": "einschwefelnd",
    "einschwefelnderen": "einschwefelnd",
    "einschwefelnderer": "einschwefelnd",
    "einschwefelnderes": "einschwefelnd",
    "einschwefelndes": "einschwefelnd",
    "einschwefelndste": "einschwefelnd",
    "einschwefelndstem": "einschwefelnd",
    "einschwefelndsten": "einschwefelnd",
    "einschwefelndster": "einschwefelnd",
    "einschwefelndstes": "einschwefelnd",
    "einschwefelst": "einschwefeln",
    "einschwefelt": "einschwefeln",
    "einschwefelte": "einschwefeln",
    "einschwefelten": "einschwefeln",
    "einschwefeltest": "einschwefeln",
    "einschwefeltet": "einschwefeln",
    "einschwefle": "einschwefeln",
    "einschwenke": "einschwenken",
    "einschwenkend": "einschwenken",
    "einschwenkende": "einschwenkend",
    "einschwenkendem": "einschwenkend",
    "einschwenkenden": "einschwenkend",
    "einschwenkender": "einschwenkend",
    "einschwenkendes": "einschwenkend",
    "einschwenkest": "einschwenken",
    "einschwenket": "einschwenken",
    "einschwenkst": "einschwenken",
    "einschwenkt": "einschwenken",
    "einschwenkte": "einschwenken",
    "einschwenkten": "einschwenken",
    "einschwenktest": "einschwenken",
    "einschwenktet": "einschwenken",
    "einschwimme": "einschwimmen",
    "einschwimmend": "einschwimmen",
    "einschwimmende": "einschwimmend",
    "einschwimmendem": "einschwimmend",
    "einschwimmenden": "einschwimmend",
    "einschwimmender": "einschwimmend",
    "einschwimmendere": "einschwimmend",
    "einschwimmenderem": "einschwimmend",
    "einschwimmenderen": "einschwimmend",
    "einschwimmenderer": "einschwimmend",
    "einschwimmenderes": "einschwimmend",
    "einschwimmendes": "einschwimmend",
    "einschwimmendste": "einschwimmend",
    "einschwimmendstem": "einschwimmend",
    "einschwimmendsten": "einschwimmend",
    "einschwimmendster": "einschwimmend",
    "einschwimmendstes": "einschwimmend",
    "einschwimmest": "einschwimmen",
    "einschwimmet": "einschwimmen",
    "einschwimmst": "einschwimmen",
    "einschwimmt": "einschwimmen",
    "einschwinge": "einschwingen",
    "einschwingend": "einschwingen",
    "einschwingende": "einschwingend",
    "einschwingendem": "einschwingend",
    "einschwingenden": "einschwingend",
    "einschwingender": "einschwingend",
    "einschwingendes": "einschwingend",
    "einschwingest": "einschwingen",
    "einschwinget": "einschwingen",
    "einschwingst": "einschwingen",
    "einschwingt": "einschwingen",
    "einschwor": "einschwören",
    "einschworen": "einschwören",
    "einschworst": "einschwören",
    "einschwort": "einschwören",
    "einschwämme": "einschwimmen",
    "einschwämmen": "einschwimmen",
    "einschwämmest": "einschwimmen",
    "einschwämmet": "einschwimmen",
    "einschwänge": "einschwingen",
    "einschwängen": "einschwingen",
    "einschwängest": "einschwingen",
    "einschwänget": "einschwingen",
    "einschwärze": "einschwärzen",
    "einschwärzend": "einschwärzen",
    "einschwärzende": "einschwärzend",
    "einschwärzendem": "einschwärzend",
    "einschwärzenden": "einschwärzend",
    "einschwärzender": "einschwärzend",
    "einschwärzendere": "einschwärzend",
    "einschwärzenderem": "einschwärzend",
    "einschwärzenderen": "einschwärzend",
    "einschwärzenderer": "einschwärzend",
    "einschwärzenderes": "einschwärzend",
    "einschwärzendes": "einschwärzend",
    "einschwärzendste": "einschwärzend",
    "einschwärzendstem": "einschwärzend",
    "einschwärzendsten": "einschwärzend",
    "einschwärzendster": "einschwärzend",
    "einschwärzendstes": "einschwärzend",
    "einschwärzest": "einschwärzen",
    "einschwärzet": "einschwärzen",
    "einschwärzt": "einschwärzen",
    "einschwärzte": "einschwärzen",
    "einschwärzten": "einschwärzen",
    "einschwärztest": "einschwärzen",
    "einschwärztet": "einschwärzen",
    "einschwöre": "einschwören",
    "einschwörend": "einschwören",
    "einschwörende": "einschwörend",
    "einschwörendem": "einschwörend",
    "einschwörenden": "einschwörend",
    "einschwörender": "einschwörend",
    "einschwörendere": "einschwörend",
    "einschwörenderem": "einschwörend",
    "einschwörenderen": "einschwörend",
    "einschwörenderer": "einschwörend",
    "einschwörenderes": "einschwörend",
    "einschwörendes": "einschwörend",
    "einschwörendste": "einschwörend",
    "einschwörendstem": "einschwörend",
    "einschwörendsten": "einschwörend",
    "einschwörendster": "einschwörend",
    "einschwörendstes": "einschwörend",
    "einschwörest": "einschwören",
    "einschwöret": "einschwören",
    "einschwörst": "einschwören",
    "einschwört": "einschwören",
    "einschärfe": "einschärfen",
    "einschärfend": "einschärfen",
    "einschärfende": "einschärfend",
    "einschärfendem": "einschärfend",
    "einschärfenden": "einschärfend",
    "einschärfender": "einschärfend",
    "einschärfendes": "einschärfend",
    "einschärfest": "einschärfen",
    "einschärfet": "einschärfen",
    "einschärfst": "einschärfen",
    "einschärft": "einschärfen",
    "einschärfte": "einschärfen",
    "einschärften": "einschärfen",
    "einschärftest": "einschärfen",
    "einschärftet": "einschärfen",
    "einschätze": "einschätzen",
    "einschätzend": "einschätzen",
    "einschätzende": "einschätzend",
    "einschätzendem": "einschätzend",
    "einschätzenden": "einschätzend",
    "einschätzender": "einschätzend",
    "einschätzendes": "einschätzend",
    "einschätzest": "einschätzen",
    "einschätzet": "einschätzen",
    "einschätzt": "einschätzen",
    "einschätzte": "einschätzen",
    "einschätzten": "einschätzen",
    "einschätztest": "einschätzen",
    "einschätztet": "einschätzen",
    "einschöbe": "einschieben",
    "einschöben": "einschieben",
    "einschöbest": "einschieben",
    "einschöbet": "einschieben",
    "einschöre": "einscheren",
    "einschören": "einscheren",
    "einschörest": "einscheren",
    "einschöret": "einscheren",
    "einschösse": "einschießen",
    "einschössen": "einschießen",
    "einschössest": "einschießen",
    "einschösset": "einschießen",
    "einschütte": "einschütten",
    "einschüttend": "einschütten",
    "einschüttende": "einschüttend",
    "einschüttendem": "einschüttend",
    "einschüttenden": "einschüttend",
    "einschüttender": "einschüttend",
    "einschüttendes": "einschüttend",
    "einschüttest": "einschütten",
    "einschüttet": "einschütten",
    "einschüttete": "einschütten",
    "einschütteten": "einschütten",
    "einschüttetest": "einschütten",
    "einschüttetet": "einschütten",
    "einsegne": "einsegnen",
    "einsegnend": "einsegnen",
    "einsegnende": "einsegnend",
    "einsegnendem": "einsegnend",
    "einsegnenden": "einsegnend",
    "einsegnender": "einsegnend",
    "einsegnendes": "einsegnend",
    "einsegnest": "einsegnen",
    "einsegnet": "einsegnen",
    "einsegnete": "einsegnen",
    "einsegneten": "einsegnen",
    "einsegnetest": "einsegnen",
    "einsegnetet": "einsegnen",
    "einsehe": "einsehen",
    "einsehend": "einsehen",
    "einsehende": "einsehend",
    "einsehendem": "einsehend",
    "einsehenden": "einsehend",
    "einsehender": "einsehend",
    "einsehendes": "einsehend",
    "einsehest": "einsehen",
    "einsehet": "einsehen",
    "einseht": "einsehen",
    "einseife": "einseifen",
    "einseifend": "einseifen",
    "einseifende": "einseifend",
    "einseifendem": "einseifend",
    "einseifenden": "einseifend",
    "einseifender": "einseifend",
    "einseifendere": "einseifend",
    "einseifenderem": "einseifend",
    "einseifenderen": "einseifend",
    "einseifenderer": "einseifend",
    "einseifenderes": "einseifend",
    "einseifendes": "einseifend",
    "einseifendste": "einseifend",
    "einseifendstem": "einseifend",
    "einseifendsten": "einseifend",
    "einseifendster": "einseifend",
    "einseifendstes": "einseifend",
    "einseifest": "einseifen",
    "einseifet": "einseifen",
    "einseifst": "einseifen",
    "einseift": "einseifen",
    "einseifte": "einseifen",
    "einseiften": "einseifen",
    "einseiftest": "einseifen",
    "einseiftet": "einseifen",
    "einseitige": "einseitig",
    "einseitigem": "einseitig",
    "einseitigen": "einseitig",
    "einseitiger": "einseitig",
    "einseitigere": "einseitig",
    "einseitigerem": "einseitig",
    "einseitigeren": "einseitig",
    "einseitigerer": "einseitig",
    "einseitigeres": "einseitig",
    "einseitiges": "einseitig",
    "einseitigste": "einseitig",
    "einseitigstem": "einseitig",
    "einseitigsten": "einseitig",
    "einseitigster": "einseitig",
    "einseitigstes": "einseitig",
    "einsende": "einsenden",
    "einsendend": "einsenden",
    "einsendende": "einsendend",
    "einsendendem": "einsendend",
    "einsendenden": "einsendend",
    "einsendender": "einsendend",
    "einsendendes": "einsendend",
    "einsendest": "einsenden",
    "einsendet": "einsenden",
    "einsendete": "einsenden",
    "einsendeten": "einsenden",
    "einsendetest": "einsenden",
    "einsendetet": "einsenden",
    "einsenge": "einsengen",
    "einsengend": "einsengen",
    "einsengende": "einsengend",
    "einsengendem": "einsengend",
    "einsengenden": "einsengend",
    "einsengender": "einsengend",
    "einsengendere": "einsengend",
    "einsengenderem": "einsengend",
    "einsengenderen": "einsengend",
    "einsengenderer": "einsengend",
    "einsengenderes": "einsengend",
    "einsengendes": "einsengend",
    "einsengendste": "einsengend",
    "einsengendstem": "einsengend",
    "einsengendsten": "einsengend",
    "einsengendster": "einsengend",
    "einsengendstes": "einsengend",
    "einsengest": "einsengen",
    "einsenget": "einsengen",
    "einsengst": "einsengen",
    "einsengt": "einsengen",
    "einsengte": "einsengen",
    "einsengten": "einsengen",
    "einsengtest": "einsengen",
    "einsengtet": "einsengen",
    "einsetze": "einsetzen",
    "einsetzend": "einsetzen",
    "einsetzende": "einsetzend",
    "einsetzendem": "einsetzend",
    "einsetzenden": "einsetzend",
    "einsetzender": "einsetzend",
    "einsetzendes": "einsetzend",
    "einsetzest": "einsetzen",
    "einsetzet": "einsetzen",
    "einsetzt": "einsetzen",
    "einsetzte": "einsetzen",
    "einsetzten": "einsetzen",
    "einsetztest": "einsetzen",
    "einsetztet": "einsetzen",
    "einsichtigem": "einsichtig",
    "einsichtigen": "einsichtig",
    "einsichtiger": "einsichtig",
    "einsichtigere": "einsichtig",
    "einsichtigerem": "einsichtig",
    "einsichtigeren": "einsichtig",
    "einsichtigerer": "einsichtig",
    "einsichtigeres": "einsichtig",
    "einsichtiges": "einsichtig",
    "einsichtigste": "einsichtig",
    "einsichtigstem": "einsichtig",
    "einsichtigsten": "einsichtig",
    "einsichtigster": "einsichtig",
    "einsichtigstes": "einsichtig",
    "einsiehst": "einsehen",
    "einsieht": "einsehen",
    "einsilbigem": "einsilbig",
    "einsilbigen": "einsilbig",
    "einsilbiger": "einsilbig",
    "einsilbigere": "einsilbig",
    "einsilbigerem": "einsilbig",
    "einsilbigeren": "einsilbig",
    "einsilbigerer": "einsilbig",
    "einsilbigeres": "einsilbig",
    "einsilbiges": "einsilbig",
    "einsilbigste": "einsilbig",
    "einsilbigstem": "einsilbig",
    "einsilbigsten": "einsilbig",
    "einsilbigster": "einsilbig",
    "einsilbigstes": "einsilbig",
    "einsinge": "einsingen",
    "einsingend": "einsingen",
    "einsingende": "einsingend",
    "einsingendem": "einsingend",
    "einsingenden": "einsingend",
    "einsingender": "einsingend",
    "einsingendes": "einsingend",
    "einsingest": "einsingen",
    "einsinget": "einsingen",
    "einsingst": "einsingen",
    "einsingt": "einsingen",
    "einsinke": "einsinken",
    "einsinkend": "einsinken",
    "einsinkende": "einsinkend",
    "einsinkendem": "einsinkend",
    "einsinkenden": "einsinkend",
    "einsinkender": "einsinkend",
    "einsinkendes": "einsinkend",
    "einsinkest": "einsinken",
    "einsinket": "einsinken",
    "einsinkst": "einsinken",
    "einsinkt": "einsinken",
    "einsitze": "einsitzen",
    "einsitzend": "einsitzen",
    "einsitzende": "einsitzend",
    "einsitzendem": "einsitzend",
    "einsitzenden": "einsitzend",
    "einsitzender": "einsitzend",
    "einsitzendere": "einsitzend",
    "einsitzenderem": "einsitzend",
    "einsitzenderen": "einsitzend",
    "einsitzenderer": "einsitzend",
    "einsitzenderes": "einsitzend",
    "einsitzendes": "einsitzend",
    "einsitzendste": "einsitzend",
    "einsitzendstem": "einsitzend",
    "einsitzendsten": "einsitzend",
    "einsitzendster": "einsitzend",
    "einsitzendstes": "einsitzend",
    "einsitzest": "einsitzen",
    "einsitzet": "einsitzen",
    "einsitzt": "einsitzen",
    "einsog": "einsaugen",
    "einsogen": "einsaugen",
    "einsogst": "einsaugen",
    "einsogt": "einsaugen",
    "einsortiere": "einsortieren",
    "einsortierend": "einsortieren",
    "einsortierende": "einsortierend",
    "einsortierendem": "einsortierend",
    "einsortierenden": "einsortierend",
    "einsortierender": "einsortierend",
    "einsortierendere": "einsortierend",
    "einsortierenderem": "einsortierend",
    "einsortierenderen": "einsortierend",
    "einsortierenderer": "einsortierend",
    "einsortierenderes": "einsortierend",
    "einsortierendes": "einsortierend",
    "einsortierendste": "einsortierend",
    "einsortierendstem": "einsortierend",
    "einsortierendsten": "einsortierend",
    "einsortierendster": "einsortierend",
    "einsortierendstes": "einsortierend",
    "einsortierest": "einsortieren",
    "einsortieret": "einsortieren",
    "einsortierst": "einsortieren",
    "einsortiert": "einsortieren",
    "einsortierte": "einsortieren",
    "einsortiertem": "einsortiert",
    "einsortierten": "einsortieren",
    "einsortierter": "einsortiert",
    "einsortiertere": "einsortiert",
    "einsortierterem": "einsortiert",
    "einsortierteren": "einsortiert",
    "einsortierterer": "einsortiert",
    "einsortierteres": "einsortiert",
    "einsortiertes": "einsortiert",
    "einsortiertest": "einsortieren",
    "einsortierteste": "einsortiert",
    "einsortiertestem": "einsortiert",
    "einsortiertesten": "einsortiert",
    "einsortiertester": "einsortiert",
    "einsortiertestes": "einsortiert",
    "einsortiertet": "einsortieren",
    "einspanne": "einspannen",
    "einspannend": "einspannen",
    "einspannende": "einspannend",
    "einspannendem": "einspannend",
    "einspannenden": "einspannend",
    "einspannender": "einspannend",
    "einspannendes": "einspannend",
    "einspannest": "einspannen",
    "einspannet": "einspannen",
    "einspannst": "einspannen",
    "einspannt": "einspannen",
    "einspannte": "einspannen",
    "einspannten": "einspannen",
    "einspanntest": "einspannen",
    "einspanntet": "einspannen",
    "einspare": "einsparen",
    "einsparend": "einsparen",
    "einsparende": "einsparend",
    "einsparendem": "einsparend",
    "einsparenden": "einsparend",
    "einsparender": "einsparend",
    "einsparendere": "einsparend",
    "einsparenderem": "einsparend",
    "einsparenderen": "einsparend",
    "einsparenderer": "einsparend",
    "einsparenderes": "einsparend",
    "einsparendes": "einsparend",
    "einsparendste": "einsparend",
    "einsparendstem": "einsparend",
    "einsparendsten": "einsparend",
    "einsparendster": "einsparend",
    "einsparendstes": "einsparend",
    "einsparest": "einsparen",
    "einsparet": "einsparen",
    "einsparst": "einsparen",
    "einspart": "einsparen",
    "einsparte": "einsparen",
    "einsparten": "einsparen",
    "einspartest": "einsparen",
    "einspartet": "einsparen",
    "einspeichere": "einspeichern",
    "einspeichernd": "einspeichern",
    "einspeichernde": "einspeichernd",
    "einspeicherndem": "einspeichernd",
    "einspeichernden": "einspeichernd",
    "einspeichernder": "einspeichernd",
    "einspeicherndes": "einspeichernd",
    "einspeicherst": "einspeichern",
    "einspeichert": "einspeichern",
    "einspeicherte": "einspeichern",
    "einspeicherten": "einspeichern",
    "einspeichertest": "einspeichern",
    "einspeichertet": "einspeichern",
    "einsperre": "einsperren",
    "einsperrend": "einsperren",
    "einsperrende": "einsperrend",
    "einsperrendem": "einsperrend",
    "einsperrenden": "einsperrend",
    "einsperrender": "einsperrend",
    "einsperrendes": "einsperrend",
    "einsperrest": "einsperren",
    "einsperret": "einsperren",
    "einsperrst": "einsperren",
    "einsperrt": "einsperren",
    "einsperrte": "einsperren",
    "einsperrten": "einsperren",
    "einsperrtest": "einsperren",
    "einsperrtet": "einsperren",
    "einspiele": "einspielen",
    "einspielend": "einspielen",
    "einspielende": "einspielend",
    "einspielendem": "einspielend",
    "einspielenden": "einspielend",
    "einspielender": "einspielend",
    "einspielendere": "einspielend",
    "einspielenderem": "einspielend",
    "einspielenderen": "einspielend",
    "einspielenderer": "einspielend",
    "einspielenderes": "einspielend",
    "einspielendes": "einspielend",
    "einspielendste": "einspielend",
    "einspielendstem": "einspielend",
    "einspielendsten": "einspielend",
    "einspielendster": "einspielend",
    "einspielendstes": "einspielend",
    "einspielest": "einspielen",
    "einspielet": "einspielen",
    "einspielst": "einspielen",
    "einspielt": "einspielen",
    "einspielte": "einspielen",
    "einspielten": "einspielen",
    "einspieltest": "einspielen",
    "einspieltet": "einspielen",
    "einsprach": "einsprechen",
    "einsprachen": "einsprechen",
    "einsprachige": "einsprachig",
    "einsprachigem": "einsprachig",
    "einsprachigen": "einsprachig",
    "einsprachiger": "einsprachig",
    "einsprachiges": "einsprachig",
    "einsprachst": "einsprechen",
    "einspracht": "einsprechen",
    "einsprang": "einspringen",
    "einsprangen": "einspringen",
    "einsprangst": "einspringen",
    "einsprangt": "einspringen",
    "einspreche": "einsprechen",
    "einsprechend": "einsprechen",
    "einsprechende": "einsprechend",
    "einsprechendem": "einsprechend",
    "einsprechenden": "einsprechend",
    "einsprechender": "einsprechend",
    "einsprechendes": "einsprechend",
    "einsprechest": "einsprechen",
    "einsprechet": "einsprechen",
    "einsprecht": "einsprechen",
    "einsprenge": "einsprengen",
    "einsprengend": "einsprengen",
    "einsprengende": "einsprengend",
    "einsprengendem": "einsprengend",
    "einsprengenden": "einsprengend",
    "einsprengender": "einsprengend",
    "einsprengendes": "einsprengend",
    "einsprengest": "einsprengen",
    "einsprenget": "einsprengen",
    "einsprengst": "einsprengen",
    "einsprengt": "einsprengen",
    "einsprengte": "einsprengen",
    "einsprengten": "einsprengen",
    "einsprengtest": "einsprengen",
    "einsprengtet": "einsprengen",
    "einsprichst": "einsprechen",
    "einspricht": "einsprechen",
    "einspringe": "einspringen",
    "einspringend": "einspringen",
    "einspringende": "einspringend",
    "einspringendem": "einspringend",
    "einspringenden": "einspringend",
    "einspringender": "einspringend",
    "einspringendes": "einspringend",
    "einspringest": "einspringen",
    "einspringet": "einspringen",
    "einspringst": "einspringen",
    "einspringt": "einspringen",
    "einspritze": "einspritzen",
    "einspritzend": "einspritzen",
    "einspritzende": "einspritzend",
    "einspritzendem": "einspritzend",
    "einspritzenden": "einspritzend",
    "einspritzender": "einspritzend",
    "einspritzendes": "einspritzend",
    "einspritzest": "einspritzen",
    "einspritzet": "einspritzen",
    "einspritzt": "einspritzen",
    "einspritzte": "einspritzen",
    "einspritzten": "einspritzen",
    "einspritztest": "einspritzen",
    "einspritztet": "einspritzen",
    "einspräche": "einsprechen",
    "einsprächen": "einsprechen",
    "einsprächest": "einsprechen",
    "einsprächet": "einsprechen",
    "einspränge": "einspringen",
    "einsprängen": "einspringen",
    "einsprängest": "einspringen",
    "einspränget": "einspringen",
    "einsprühe": "einsprühen",
    "einsprühend": "einsprühen",
    "einsprühende": "einsprühend",
    "einsprühendem": "einsprühend",
    "einsprühenden": "einsprühend",
    "einsprühender": "einsprühend",
    "einsprühendes": "einsprühend",
    "einsprühest": "einsprühen",
    "einsprühet": "einsprühen",
    "einsprühst": "einsprühen",
    "einsprüht": "einsprühen",
    "einsprühte": "einsprühen",
    "einsprühten": "einsprühen",
    "einsprühtest": "einsprühen",
    "einsprühtet": "einsprühen",
    "einspurige": "einspurig",
    "einspurigem": "einspurig",
    "einspurigen": "einspurig",
    "einspuriger": "einspurig",
    "einspuriges": "einspurig",
    "einst": "einen",
    "einstach": "einstechen",
    "einstachen": "einstechen",
    "einstachst": "einstechen",
    "einstacht": "einstechen",
    "einstampfe": "einstampfen",
    "einstampfend": "einstampfen",
    "einstampfende": "einstampfend",
    "einstampfendem": "einstampfend",
    "einstampfenden": "einstampfend",
    "einstampfender": "einstampfend",
    "einstampfendes": "einstampfend",
    "einstampfest": "einstampfen",
    "einstampfet": "einstampfen",
    "einstampfst": "einstampfen",
    "einstampft": "einstampfen",
    "einstampfte": "einstampfen",
    "einstampften": "einstampfen",
    "einstampftest": "einstampfen",
    "einstampftet": "einstampfen",
    "einstand": "einstehen",
    "einstanden": "einstehen",
    "einstandest": "einstehen",
    "einstandet": "einstehen",
    "einstaube": "einstauben",
    "einstaubend": "einstauben",
    "einstaubende": "einstaubend",
    "einstaubendem": "einstaubend",
    "einstaubenden": "einstaubend",
    "einstaubender": "einstaubend",
    "einstaubendere": "einstaubend",
    "einstaubenderem": "einstaubend",
    "einstaubenderen": "einstaubend",
    "einstaubenderer": "einstaubend",
    "einstaubenderes": "einstaubend",
    "einstaubendes": "einstaubend",
    "einstaubendste": "einstaubend",
    "einstaubendstem": "einstaubend",
    "einstaubendsten": "einstaubend",
    "einstaubendster": "einstaubend",
    "einstaubendstes": "einstaubend",
    "einstaubest": "einstauben",
    "einstaubet": "einstauben",
    "einstaubst": "einstauben",
    "einstaubt": "einstauben",
    "einstaubte": "einstauben",
    "einstaubten": "einstauben",
    "einstaubtest": "einstauben",
    "einstaubtet": "einstauben",
    "einsteche": "einstechen",
    "einstechend": "einstechen",
    "einstechende": "einstechend",
    "einstechendem": "einstechend",
    "einstechenden": "einstechend",
    "einstechender": "einstechend",
    "einstechendes": "einstechend",
    "einstechest": "einstechen",
    "einstechet": "einstechen",
    "einstecht": "einstechen",
    "einstecke": "einstecken",
    "einsteckend": "einstecken",
    "einsteckende": "einsteckend",
    "einsteckendem": "einsteckend",
    "einsteckenden": "einsteckend",
    "einsteckender": "einsteckend",
    "einsteckendes": "einsteckend",
    "einsteckest": "einstecken",
    "einstecket": "einstecken",
    "einsteckst": "einstecken",
    "einsteckt": "einstecken",
    "einsteckte": "einstecken",
    "einsteckten": "einstecken",
    "einstecktest": "einstecken",
    "einstecktet": "einstecken",
    "einstehe": "einstehen",
    "einstehend": "einstehen",
    "einstehende": "einstehend",
    "einstehendem": "einstehend",
    "einstehenden": "einstehend",
    "einstehender": "einstehend",
    "einstehendes": "einstehend",
    "einstehest": "einstehen",
    "einstehet": "einstehen",
    "einstehst": "einstehen",
    "einsteht": "einstehen",
    "einsteige": "einsteigen",
    "einsteigend": "einsteigen",
    "einsteigende": "einsteigend",
    "einsteigendem": "einsteigend",
    "einsteigenden": "einsteigend",
    "einsteigender": "einsteigend",
    "einsteigendes": "einsteigend",
    "einsteigest": "einsteigen",
    "einsteiget": "einsteigen",
    "einsteigst": "einsteigen",
    "einsteigt": "einsteigen",
    "einstellbare": "einstellbar",
    "einstellbarem": "einstellbar",
    "einstellbaren": "einstellbar",
    "einstellbarer": "einstellbar",
    "einstellbares": "einstellbar",
    "einstelle": "einstellen",
    "einstellend": "einstellen",
    "einstellende": "einstellend",
    "einstellendem": "einstellend",
    "einstellenden": "einstellend",
    "einstellender": "einstellend",
    "einstellendes": "einstellend",
    "einstellest": "einstellen",
    "einstellet": "einstellen",
    "einstellige": "einstellig",
    "einstelligem": "einstellig",
    "einstelligen": "einstellig",
    "einstelliger": "einstellig",
    "einstelliges": "einstellig",
    "einstellst": "einstellen",
    "einstellt": "einstellen",
    "einstellte": "einstellen",
    "einstellten": "einstellen",
    "einstelltest": "einstellen",
    "einstelltet": "einstellen",
    "einstichst": "einstechen",
    "einsticht": "einstechen",
    "einstieg": "einsteigen",
    "einstiegest": "einsteigen",
    "einstieget": "einsteigen",
    "einstiegst": "einsteigen",
    "einstiegt": "einsteigen",
    "einstige": "einstig",
    "einstigem": "einstig",
    "einstigen": "einstig",
    "einstiger": "einstig",
    "einstiges": "einstig",
    "einstimme": "einstimmen",
    "einstimmend": "einstimmen",
    "einstimmende": "einstimmend",
    "einstimmendem": "einstimmend",
    "einstimmenden": "einstimmend",
    "einstimmender": "einstimmend",
    "einstimmendes": "einstimmend",
    "einstimmest": "einstimmen",
    "einstimmet": "einstimmen",
    "einstimmige": "einstimmig",
    "einstimmigem": "einstimmig",
    "einstimmigen": "einstimmig",
    "einstimmiger": "einstimmig",
    "einstimmiges": "einstimmig",
    "einstimmst": "einstimmen",
    "einstimmt": "einstimmen",
    "einstimmte": "einstimmen",
    "einstimmten": "einstimmen",
    "einstimmtest": "einstimmen",
    "einstimmtet": "einstimmen",
    "einstippe": "einstippen",
    "einstippend": "einstippen",
    "einstippende": "einstippend",
    "einstippendem": "einstippend",
    "einstippenden": "einstippend",
    "einstippender": "einstippend",
    "einstippendes": "einstippend",
    "einstippest": "einstippen",
    "einstippet": "einstippen",
    "einstippst": "einstippen",
    "einstippt": "einstippen",
    "einstippte": "einstippen",
    "einstippten": "einstippen",
    "einstipptest": "einstippen",
    "einstipptet": "einstippen",
    "einstrahle": "einstrahlen",
    "einstrahlend": "einstrahlen",
    "einstrahlende": "einstrahlend",
    "einstrahlendem": "einstrahlend",
    "einstrahlenden": "einstrahlend",
    "einstrahlender": "einstrahlend",
    "einstrahlendes": "einstrahlend",
    "einstrahlest": "einstrahlen",
    "einstrahlet": "einstrahlen",
    "einstrahlst": "einstrahlen",
    "einstrahlt": "einstrahlen",
    "einstrahlte": "einstrahlen",
    "einstrahlten": "einstrahlen",
    "einstrahltest": "einstrahlen",
    "einstrahltet": "einstrahlen",
    "einstreiche": "einstreichen",
    "einstreichend": "einstreichen",
    "einstreichende": "einstreichend",
    "einstreichendem": "einstreichend",
    "einstreichenden": "einstreichend",
    "einstreichender": "einstreichend",
    "einstreichendes": "einstreichend",
    "einstreichest": "einstreichen",
    "einstreichet": "einstreichen",
    "einstreichst": "einstreichen",
    "einstreicht": "einstreichen",
    "einstreue": "einstreuen",
    "einstreuend": "einstreuen",
    "einstreuende": "einstreuend",
    "einstreuendem": "einstreuend",
    "einstreuenden": "einstreuend",
    "einstreuender": "einstreuend",
    "einstreuendes": "einstreuend",
    "einstreuest": "einstreuen",
    "einstreuet": "einstreuen",
    "einstreust": "einstreuen",
    "einstreut": "einstreuen",
    "einstreute": "einstreuen",
    "einstreuten": "einstreuen",
    "einstreutest": "einstreuen",
    "einstreutet": "einstreuen",
    "einstrich": "einstreichen",
    "einstriche": "einstreichen",
    "einstrichen": "einstreichen",
    "einstrichest": "einstreichen",
    "einstrichet": "einstreichen",
    "einstrichst": "einstreichen",
    "einstricht": "einstreichen",
    "einströme": "einströmen",
    "einströmend": "einströmen",
    "einströmende": "einströmend",
    "einströmendem": "einströmend",
    "einströmenden": "einströmend",
    "einströmender": "einströmend",
    "einströmendes": "einströmend",
    "einströmest": "einströmen",
    "einströmet": "einströmen",
    "einströmst": "einströmen",
    "einströmt": "einströmen",
    "einströmte": "einströmen",
    "einströmten": "einströmen",
    "einströmtest": "einströmen",
    "einströmtet": "einströmen",
    "einstudiere": "einstudieren",
    "einstudierend": "einstudieren",
    "einstudierende": "einstudierend",
    "einstudierendem": "einstudierend",
    "einstudierenden": "einstudierend",
    "einstudierender": "einstudierend",
    "einstudierendes": "einstudierend",
    "einstudierest": "einstudieren",
    "einstudieret": "einstudieren",
    "einstudierst": "einstudieren",
    "einstudiert": "einstudieren",
    "einstudierte": "einstudieren",
    "einstudiertem": "einstudiert",
    "einstudierten": "einstudieren",
    "einstudierter": "einstudiert",
    "einstudiertes": "einstudiert",
    "einstudiertest": "einstudieren",
    "einstudiertet": "einstudieren",
    "einstufe": "einstufen",
    "einstufend": "einstufen",
    "einstufende": "einstufend",
    "einstufendem": "einstufend",
    "einstufenden": "einstufend",
    "einstufender": "einstufend",
    "einstufendes": "einstufend",
    "einstufest": "einstufen",
    "einstufet": "einstufen",
    "einstufst": "einstufen",
    "einstuft": "einstufen",
    "einstufte": "einstufen",
    "einstuften": "einstufen",
    "einstuftest": "einstufen",
    "einstuftet": "einstufen",
    "einstweilige": "einstweilig",
    "einstweiligem": "einstweilig",
    "einstweiligen": "einstweilig",
    "einstweiliger": "einstweilig",
    "einstweiliges": "einstweilig",
    "einstäche": "einstechen",
    "einstächen": "einstechen",
    "einstächest": "einstechen",
    "einstächet": "einstechen",
    "einstülpe": "einstülpen",
    "einstülpend": "einstülpen",
    "einstülpende": "einstülpend",
    "einstülpendem": "einstülpend",
    "einstülpenden": "einstülpend",
    "einstülpender": "einstülpend",
    "einstülpendes": "einstülpend",
    "einstülpest": "einstülpen",
    "einstülpet": "einstülpen",
    "einstülpst": "einstülpen",
    "einstülpt": "einstülpen",
    "einstülpte": "einstülpen",
    "einstülpten": "einstülpen",
    "einstülptest": "einstülpen",
    "einstülptet": "einstülpen",
    "einstünde": "einstehen",
    "einstünden": "einstehen",
    "einstündest": "einstehen",
    "einstündet": "einstehen",
    "einstürme": "einstürmen",
    "einstürmend": "einstürmen",
    "einstürmende": "einstürmend",
    "einstürmendem": "einstürmend",
    "einstürmenden": "einstürmend",
    "einstürmender": "einstürmend",
    "einstürmendes": "einstürmend",
    "einstürmest": "einstürmen",
    "einstürmet": "einstürmen",
    "einstürmst": "einstürmen",
    "einstürmt": "einstürmen",
    "einstürmte": "einstürmen",
    "einstürmten": "einstürmen",
    "einstürmtest": "einstürmen",
    "einstürmtet": "einstürmen",
    "einstürze": "einstürzen",
    "einstürzend": "einstürzen",
    "einstürzende": "einstürzend",
    "einstürzendem": "einstürzend",
    "einstürzenden": "einstürzend",
    "einstürzender": "einstürzend",
    "einstürzendere": "einstürzend",
    "einstürzenderem": "einstürzend",
    "einstürzenderen": "einstürzend",
    "einstürzenderer": "einstürzend",
    "einstürzenderes": "einstürzend",
    "einstürzendes": "einstürzend",
    "einstürzendste": "einstürzend",
    "einstürzendstem": "einstürzend",
    "einstürzendsten": "einstürzend",
    "einstürzendster": "einstürzend",
    "einstürzendstes": "einstürzend",
    "einstürzest": "einstürzen",
    "einstürzet": "einstürzen",
    "einstürzt": "einstürzen",
    "einstürzte": "einstürzen",
    "einstürzten": "einstürzen",
    "einstürztest": "einstürzen",
    "einstürztet": "einstürzen",
    "einsäge": "einsägen",
    "einsägend": "einsägen",
    "einsägendem": "einsägend",
    "einsägender": "einsägend",
    "einsägendes": "einsägend",
    "einsägest": "einsägen",
    "einsäget": "einsägen",
    "einsägst": "einsägen",
    "einsägt": "einsägen",
    "einsägte": "einsägen",
    "einsägten": "einsägen",
    "einsägtest": "einsägen",
    "einsägtet": "einsägen",
    "einsähe": "einsehen",
    "einsähen": "einsehen",
    "einsähest": "einsehen",
    "einsähet": "einsehen",
    "einsänge": "einsingen",
    "einsängen": "einsingen",
    "einsängest": "einsingen",
    "einsänget": "einsingen",
    "einsänke": "einsinken",
    "einsänken": "einsinken",
    "einsänkest": "einsinken",
    "einsänket": "einsinken",
    "einsäuere": "einsäuern",
    "einsäuernd": "einsäuern",
    "einsäuernde": "einsäuernd",
    "einsäuerndem": "einsäuernd",
    "einsäuernden": "einsäuernd",
    "einsäuernder": "einsäuernd",
    "einsäuerndere": "einsäuernd",
    "einsäuernderem": "einsäuernd",
    "einsäuernderen": "einsäuernd",
    "einsäuernderer": "einsäuernd",
    "einsäuernderes": "einsäuernd",
    "einsäuerndes": "einsäuernd",
    "einsäuerndste": "einsäuernd",
    "einsäuerndstem": "einsäuernd",
    "einsäuerndsten": "einsäuernd",
    "einsäuerndster": "einsäuernd",
    "einsäuerndstes": "einsäuernd",
    "einsäuerst": "einsäuern",
    "einsäuert": "einsäuern",
    "einsäuerte": "einsäuern",
    "einsäuerten": "einsäuern",
    "einsäuertest": "einsäuern",
    "einsäuertet": "einsäuern",
    "einsäume": "einsäumen",
    "einsäumend": "einsäumen",
    "einsäumende": "einsäumend",
    "einsäumendem": "einsäumend",
    "einsäumenden": "einsäumend",
    "einsäumender": "einsäumend",
    "einsäumendes": "einsäumend",
    "einsäumest": "einsäumen",
    "einsäumet": "einsäumen",
    "einsäumst": "einsäumen",
    "einsäumt": "einsäumen",
    "einsäumte": "einsäumen",
    "einsäumten": "einsäumen",
    "einsäumtest": "einsäumen",
    "einsäumtet": "einsäumen",
    "einsäße": "einsitzen",
    "einsäßen": "einsitzen",
    "einsäßest": "einsitzen",
    "einsäßet": "einsitzen",
    "einsöge": "einsaugen",
    "einsögen": "einsaugen",
    "einsögest": "einsaugen",
    "einsöget": "einsaugen",
    "eint": "einen",
    "eintanze": "eintanzen",
    "eintanzend": "eintanzen",
    "eintanzende": "eintanzend",
    "eintanzendem": "eintanzend",
    "eintanzenden": "eintanzend",
    "eintanzender": "eintanzend",
    "eintanzendes": "eintanzend",
    "eintanzest": "eintanzen",
    "eintanzet": "eintanzen",
    "eintanzt": "eintanzen",
    "eintanzte": "eintanzen",
    "eintanzten": "eintanzen",
    "eintanztest": "eintanzen",
    "eintanztet": "eintanzen",
    "eintauche": "eintauchen",
    "eintauchend": "eintauchen",
    "eintauchende": "eintauchend",
    "eintauchendem": "eintauchend",
    "eintauchenden": "eintauchend",
    "eintauchender": "eintauchend",
    "eintauchendes": "eintauchend",
    "eintauchest": "eintauchen",
    "eintauchet": "eintauchen",
    "eintauchst": "eintauchen",
    "eintaucht": "eintauchen",
    "eintauchte": "eintauchen",
    "eintauchten": "eintauchen",
    "eintauchtest": "eintauchen",
    "eintauchtet": "eintauchen",
    "eintausche": "eintauschen",
    "eintauschend": "eintauschen",
    "eintauschende": "eintauschend",
    "eintauschendem": "eintauschend",
    "eintauschenden": "eintauschend",
    "eintauschender": "eintauschend",
    "eintauschendes": "eintauschend",
    "eintauschest": "eintauschen",
    "eintauschet": "eintauschen",
    "eintauschst": "eintauschen",
    "eintauscht": "eintauschen",
    "eintauschte": "eintauschen",
    "eintauschten": "eintauschen",
    "eintauschtest": "eintauschen",
    "eintauschtet": "eintauschen",
    "einte": "einen",
    "einteile": "einteilen",
    "einteilend": "einteilen",
    "einteilende": "einteilend",
    "einteilendem": "einteilend",
    "einteilenden": "einteilend",
    "einteilender": "einteilend",
    "einteilendes": "einteilend",
    "einteilest": "einteilen",
    "einteilet": "einteilen",
    "einteilige": "einteilig",
    "einteiligem": "einteilig",
    "einteiligen": "einteilig",
    "einteiliger": "einteilig",
    "einteiliges": "einteilig",
    "einteilst": "einteilen",
    "einteilt": "einteilen",
    "einteilte": "einteilen",
    "einteilten": "einteilen",
    "einteiltest": "einteilen",
    "einteiltet": "einteilen",
    "einten": "einen",
    "eintest": "einen",
    "eintet": "einen",
    "eintopfend": "eintopfen",
    "eintopfende": "eintopfend",
    "eintopfendem": "eintopfend",
    "eintopfenden": "eintopfend",
    "eintopfender": "eintopfend",
    "eintopfendes": "eintopfend",
    "eintopfest": "eintopfen",
    "eintopfet": "eintopfen",
    "eintopfst": "eintopfen",
    "eintopft": "eintopfen",
    "eintopfte": "eintopfen",
    "eintopften": "eintopfen",
    "eintopftest": "eintopfen",
    "eintopftet": "eintopfen",
    "eintraf": "eintreffen",
    "eintrafen": "eintreffen",
    "eintrafst": "eintreffen",
    "eintraft": "eintreffen",
    "eintragend": "eintragen",
    "eintragende": "eintragend",
    "eintragendem": "eintragend",
    "eintragenden": "eintragend",
    "eintragender": "eintragend",
    "eintragendes": "eintragend",
    "eintragest": "eintragen",
    "eintraget": "eintragen",
    "eintragt": "eintragen",
    "eintrat": "eintreten",
    "eintraten": "eintreten",
    "eintratest": "eintreten",
    "eintratet": "eintreten",
    "eintreffe": "eintreffen",
    "eintreffend": "eintreffen",
    "eintreffende": "eintreffend",
    "eintreffendem": "eintreffend",
    "eintreffenden": "eintreffend",
    "eintreffender": "eintreffend",
    "eintreffendes": "eintreffend",
    "eintreffest": "eintreffen",
    "eintreffet": "eintreffen",
    "eintrefft": "eintreffen",
    "eintreibbare": "eintreibbar",
    "eintreibbarem": "eintreibbar",
    "eintreibbaren": "eintreibbar",
    "eintreibbarer": "eintreibbar",
    "eintreibbares": "eintreibbar",
    "eintreibe": "eintreiben",
    "eintreibend": "eintreiben",
    "eintreibende": "eintreibend",
    "eintreibendem": "eintreibend",
    "eintreibenden": "eintreibend",
    "eintreibender": "eintreibend",
    "eintreibendes": "eintreibend",
    "eintreibest": "eintreiben",
    "eintreibet": "eintreiben",
    "eintreibst": "eintreiben",
    "eintreibt": "eintreiben",
    "eintrete": "eintreten",
    "eintretend": "eintreten",
    "eintretende": "eintretend",
    "eintretendem": "eintretend",
    "eintretenden": "eintretend",
    "eintretender": "eintretend",
    "eintretendes": "eintretend",
    "eintretest": "eintreten",
    "eintretet": "eintreten",
    "eintrichtere": "eintrichtern",
    "eintrichternd": "eintrichtern",
    "eintrichternde": "eintrichternd",
    "eintrichterndem": "eintrichternd",
    "eintrichternden": "eintrichternd",
    "eintrichternder": "eintrichternd",
    "eintrichterndes": "eintrichternd",
    "eintrichterst": "eintrichtern",
    "eintrichtert": "eintrichtern",
    "eintrichterte": "eintrichtern",
    "eintrichterten": "eintrichtern",
    "eintrichtertest": "eintrichtern",
    "eintrichtertet": "eintrichtern",
    "eintrieb": "eintreiben",
    "eintriebe": "eintreiben",
    "eintrieben": "eintreiben",
    "eintriebest": "eintreiben",
    "eintriebet": "eintreiben",
    "eintriebst": "eintreiben",
    "eintriebt": "eintreiben",
    "eintriffst": "eintreffen",
    "eintrifft": "eintreffen",
    "eintritt": "eintreten",
    "eintrittst": "eintreten",
    "eintrockne": "eintrocknen",
    "eintrocknend": "eintrocknen",
    "eintrocknende": "eintrocknend",
    "eintrocknendem": "eintrocknend",
    "eintrocknenden": "eintrocknend",
    "eintrocknender": "eintrocknend",
    "eintrocknendere": "eintrocknend",
    "eintrocknenderem": "eintrocknend",
    "eintrocknenderen": "eintrocknend",
    "eintrocknenderer": "eintrocknend",
    "eintrocknenderes": "eintrocknend",
    "eintrocknendes": "eintrocknend",
    "eintrocknendste": "eintrocknend",
    "eintrocknendstem": "eintrocknend",
    "eintrocknendsten": "eintrocknend",
    "eintrocknendster": "eintrocknend",
    "eintrocknendstes": "eintrocknend",
    "eintrocknest": "eintrocknen",
    "eintrocknet": "eintrocknen",
    "eintrocknete": "eintrocknen",
    "eintrockneten": "eintrocknen",
    "eintrocknetest": "eintrocknen",
    "eintrocknetet": "eintrocknen",
    "eintrudele": "eintrudeln",
    "eintrudelnd": "eintrudeln",
    "eintrudelnde": "eintrudelnd",
    "eintrudelndem": "eintrudelnd",
    "eintrudelnden": "eintrudelnd",
    "eintrudelnder": "eintrudelnd",
    "eintrudelndes": "eintrudelnd",
    "eintrudelst": "eintrudeln",
    "eintrudelt": "eintrudeln",
    "eintrudelte": "eintrudeln",
    "eintrudelten": "eintrudeln",
    "eintrudeltest": "eintrudeln",
    "eintrudeltet": "eintrudeln",
    "eintrudle": "eintrudeln",
    "eintrug": "eintragen",
    "eintrugen": "eintragen",
    "eintrugst": "eintragen",
    "eintrugt": "eintragen",
    "einträchtige": "einträchtig",
    "einträchtigem": "einträchtig",
    "einträchtigen": "einträchtig",
    "einträchtiger": "einträchtig",
    "einträchtigere": "einträchtig",
    "einträchtigerem": "einträchtig",
    "einträchtigeren": "einträchtig",
    "einträchtigerer": "einträchtig",
    "einträchtigeres": "einträchtig",
    "einträchtiges": "einträchtig",
    "einträchtigste": "einträchtig",
    "einträchtigstem": "einträchtig",
    "einträchtigsten": "einträchtig",
    "einträchtigster": "einträchtig",
    "einträchtigstes": "einträchtig",
    "einträfe": "eintreffen",
    "einträfen": "eintreffen",
    "einträfest": "eintreffen",
    "einträfet": "eintreffen",
    "einträgliche": "einträglich",
    "einträglichem": "einträglich",
    "einträglichen": "einträglich",
    "einträglicher": "einträglich",
    "einträgliches": "einträglich",
    "einträgst": "eintragen",
    "einträgt": "eintragen",
    "einträte": "eintreten",
    "einträten": "eintreten",
    "einträtest": "eintreten",
    "einträtet": "eintreten",
    "einträufele": "einträufeln",
    "einträufelnd": "einträufeln",
    "einträufelnde": "einträufelnd",
    "einträufelndem": "einträufelnd",
    "einträufelnden": "einträufelnd",
    "einträufelnder": "einträufelnd",
    "einträufelndes": "einträufelnd",
    "einträufelst": "einträufeln",
    "einträufelt": "einträufeln",
    "einträufelte": "einträufeln",
    "einträufelten": "einträufeln",
    "einträufeltest": "einträufeln",
    "einträufeltet": "einträufeln",
    "einträufle": "einträufeln",
    "eintrübe": "eintrüben",
    "eintrübend": "eintrüben",
    "eintrübende": "eintrübend",
    "eintrübendem": "eintrübend",
    "eintrübenden": "eintrübend",
    "eintrübender": "eintrübend",
    "eintrübendes": "eintrübend",
    "eintrübest": "eintrüben",
    "eintrübet": "eintrüben",
    "eintrübst": "eintrüben",
    "eintrübt": "eintrüben",
    "eintrübte": "eintrüben",
    "eintrübten": "eintrüben",
    "eintrübtest": "eintrüben",
    "eintrübtet": "eintrüben",
    "eintrüge": "eintragen",
    "eintrügen": "eintragen",
    "eintrügest": "eintragen",
    "eintrüget": "eintragen",
    "eintunke": "eintunken",
    "eintunkend": "eintunken",
    "eintunkende": "eintunkend",
    "eintunkendem": "eintunkend",
    "eintunkenden": "eintunkend",
    "eintunkender": "eintunkend",
    "eintunkendes": "eintunkend",
    "eintunkest": "eintunken",
    "eintunket": "eintunken",
    "eintunkst": "eintunken",
    "eintunkt": "eintunken",
    "eintunkte": "eintunken",
    "eintunkten": "eintunken",
    "eintunktest": "eintunken",
    "eintunktet": "eintunken",
    "eintägige": "eintägig",
    "eintägigem": "eintägig",
    "eintägigen": "eintägig",
    "eintägiger": "eintägig",
    "eintägiges": "eintägig",
    "eintönige": "eintönig",
    "eintönigem": "eintönig",
    "eintönigen": "eintönig",
    "eintöniger": "eintönig",
    "eintönigere": "eintönig",
    "eintönigerem": "eintönig",
    "eintönigeren": "eintönig",
    "eintönigerer": "eintönig",
    "eintönigeres": "eintönig",
    "eintöniges": "eintönig",
    "eintönigste": "eintönig",
    "eintönigstem": "eintönig",
    "eintönigsten": "eintönig",
    "eintönigster": "eintönig",
    "eintönigstes": "eintönig",
    "eintüte": "eintüten",
    "eintütend": "eintüten",
    "eintütende": "eintütend",
    "eintütendem": "eintütend",
    "eintütenden": "eintütend",
    "eintütender": "eintütend",
    "eintütendes": "eintütend",
    "eintütest": "eintüten",
    "eintütet": "eintüten",
    "eintütete": "eintüten",
    "eintüteten": "eintüten",
    "eintütetest": "eintüten",
    "eintütetet": "eintüten",
    "einverleibe": "einverleiben",
    "einverleibend": "einverleiben",
    "einverleibende": "einverleibend",
    "einverleibendem": "einverleibend",
    "einverleibenden": "einverleibend",
    "einverleibender": "einverleibend",
    "einverleibendes": "einverleibend",
    "einverleibest": "einverleiben",
    "einverleibet": "einverleiben",
    "einverleibst": "einverleiben",
    "einverleibt": "einverleiben",
    "einverleibte": "einverleiben",
    "einverleibtem": "einverleibt",
    "einverleibten": "einverleiben",
    "einverleibter": "einverleibt",
    "einverleibtes": "einverleibt",
    "einverleibtest": "einverleiben",
    "einverleibtet": "einverleiben",
    "einvernehmlichem": "einvernehmlich",
    "einvernehmlichen": "einvernehmlich",
    "einvernehmlicher": "einvernehmlich",
    "einvernehmliches": "einvernehmlich",
    "einverstandene": "einverstanden",
    "einverstandenem": "einverstanden",
    "einverstandenen": "einverstanden",
    "einverstandener": "einverstanden",
    "einverstandenes": "einverstanden",
    "einwachse": "einwachsen",
    "einwachsend": "einwachsen",
    "einwachsende": "einwachsend",
    "einwachsendem": "einwachsend",
    "einwachsenden": "einwachsend",
    "einwachsender": "einwachsend",
    "einwachsendes": "einwachsend",
    "einwachsest": "einwachsen",
    "einwachset": "einwachsen",
    "einwachst": "einwachsen",
    "einwachste": "einwachsen",
    "einwachsten": "einwachsen",
    "einwachstest": "einwachsen",
    "einwachstet": "einwachsen",
    "einwandere": "einwandern",
    "einwandernd": "einwandern",
    "einwandernde": "einwandernd",
    "einwanderndem": "einwandernd",
    "einwandernden": "einwandernd",
    "einwandernder": "einwandernd",
    "einwanderndes": "einwandernd",
    "einwanderst": "einwandern",
    "einwandert": "einwandern",
    "einwanderte": "einwandern",
    "einwanderten": "einwandern",
    "einwandertest": "einwandern",
    "einwandertet": "einwandern",
    "einwandfreiem": "einwandfrei",
    "einwandfreien": "einwandfrei",
    "einwandfreier": "einwandfrei",
    "einwandfreies": "einwandfrei",
    "einwandte": "einwenden",
    "einwandten": "einwenden",
    "einwandtest": "einwenden",
    "einwandtet": "einwenden",
    "einwarf": "einwerfen",
    "einwarfen": "einwerfen",
    "einwarfst": "einwerfen",
    "einwarft": "einwerfen",
    "einwebe": "einweben",
    "einwebend": "einweben",
    "einwebende": "einwebend",
    "einwebendem": "einwebend",
    "einwebenden": "einwebend",
    "einwebender": "einwebend",
    "einwebendes": "einwebend",
    "einwebest": "einweben",
    "einwebet": "einweben",
    "einwebst": "einweben",
    "einwebt": "einweben",
    "einwebte": "einweben",
    "einwebten": "einweben",
    "einwebtest": "einweben",
    "einwebtet": "einweben",
    "einwechsele": "einwechseln",
    "einwechselnd": "einwechseln",
    "einwechselnde": "einwechselnd",
    "einwechselndem": "einwechselnd",
    "einwechselnden": "einwechselnd",
    "einwechselnder": "einwechselnd",
    "einwechselndes": "einwechselnd",
    "einwechselst": "einwechseln",
    "einwechselt": "einwechseln",
    "einwechselte": "einwechseln",
    "einwechselten": "einwechseln",
    "einwechseltest": "einwechseln",
    "einwechseltet": "einwechseln",
    "einwechsle": "einwechseln",
    "einweiche": "einweichen",
    "einweichend": "einweichen",
    "einweichende": "einweichend",
    "einweichendem": "einweichend",
    "einweichenden": "einweichend",
    "einweichender": "einweichend",
    "einweichendes": "einweichend",
    "einweichest": "einweichen",
    "einweichet": "einweichen",
    "einweichst": "einweichen",
    "einweicht": "einweichen",
    "einweichte": "einweichen",
    "einweichten": "einweichen",
    "einweichtest": "einweichen",
    "einweichtet": "einweichen",
    "einweihe": "einweihen",
    "einweihend": "einweihen",
    "einweihende": "einweihend",
    "einweihendem": "einweihend",
    "einweihenden": "einweihend",
    "einweihender": "einweihend",
    "einweihendes": "einweihend",
    "einweihest": "einweihen",
    "einweihet": "einweihen",
    "einweihst": "einweihen",
    "einweiht": "einweihen",
    "einweihte": "einweihen",
    "einweihten": "einweihen",
    "einweihtest": "einweihen",
    "einweihtet": "einweihen",
    "einweise": "einweisen",
    "einweisend": "einweisen",
    "einweisende": "einweisend",
    "einweisendem": "einweisend",
    "einweisenden": "einweisend",
    "einweisender": "einweisend",
    "einweisendes": "einweisend",
    "einweisest": "einweisen",
    "einweiset": "einweisen",
    "einweist": "einweisen",
    "einwende": "einwenden",
    "einwendend": "einwenden",
    "einwendende": "einwendend",
    "einwendendem": "einwendend",
    "einwendenden": "einwendend",
    "einwendender": "einwendend",
    "einwendendes": "einwendend",
    "einwendest": "einwenden",
    "einwendet": "einwenden",
    "einwendete": "einwenden",
    "einwendeten": "einwenden",
    "einwendetest": "einwenden",
    "einwendetet": "einwenden",
    "einwerfe": "einwerfen",
    "einwerfend": "einwerfen",
    "einwerfende": "einwerfend",
    "einwerfendem": "einwerfend",
    "einwerfenden": "einwerfend",
    "einwerfender": "einwerfend",
    "einwerfendes": "einwerfend",
    "einwerfest": "einwerfen",
    "einwerfet": "einwerfen",
    "einwerft": "einwerfen",
    "einwickele": "einwickeln",
    "einwickelnd": "einwickeln",
    "einwickelnde": "einwickelnd",
    "einwickelndem": "einwickelnd",
    "einwickelnden": "einwickelnd",
    "einwickelnder": "einwickelnd",
    "einwickelndere": "einwickelnd",
    "einwickelnderem": "einwickelnd",
    "einwickelnderen": "einwickelnd",
    "einwickelnderer": "einwickelnd",
    "einwickelnderes": "einwickelnd",
    "einwickelndes": "einwickelnd",
    "einwickelndste": "einwickelnd",
    "einwickelndstem": "einwickelnd",
    "einwickelndsten": "einwickelnd",
    "einwickelndster": "einwickelnd",
    "einwickelndstes": "einwickelnd",
    "einwickelst": "einwickeln",
    "einwickelt": "einwickeln",
    "einwickelte": "einwickeln",
    "einwickelten": "einwickeln",
    "einwickeltest": "einwickeln",
    "einwickeltet": "einwickeln",
    "einwickle": "einwickeln",
    "einwiege": "einwiegen",
    "einwiegend": "einwiegen",
    "einwiegende": "einwiegend",
    "einwiegendem": "einwiegend",
    "einwiegenden": "einwiegend",
    "einwiegender": "einwiegend",
    "einwiegendes": "einwiegend",
    "einwiegest": "einwiegen",
    "einwieget": "einwiegen",
    "einwiegst": "einwiegen",
    "einwiegt": "einwiegen",
    "einwies": "einweisen",
    "einwiese": "einweisen",
    "einwiesen": "einweisen",
    "einwiesest": "einweisen",
    "einwieset": "einweisen",
    "einwiest": "einweisen",
    "einwillige": "einwilligen",
    "einwilligend": "einwilligen",
    "einwilligende": "einwilligend",
    "einwilligendem": "einwilligend",
    "einwilligenden": "einwilligend",
    "einwilligender": "einwilligend",
    "einwilligendes": "einwilligend",
    "einwilligest": "einwilligen",
    "einwilliget": "einwilligen",
    "einwilligst": "einwilligen",
    "einwilligt": "einwilligen",
    "einwilligte": "einwilligen",
    "einwilligten": "einwilligen",
    "einwilligtest": "einwilligen",
    "einwilligtet": "einwilligen",
    "einwinke": "einwinken",
    "einwinkend": "einwinken",
    "einwinkende": "einwinkend",
    "einwinkendem": "einwinkend",
    "einwinkenden": "einwinkend",
    "einwinkender": "einwinkend",
    "einwinkendes": "einwinkend",
    "einwinkest": "einwinken",
    "einwinket": "einwinken",
    "einwinkst": "einwinken",
    "einwinkt": "einwinken",
    "einwinkte": "einwinken",
    "einwinkten": "einwinken",
    "einwinktest": "einwinken",
    "einwinktet": "einwinken",
    "einwirfst": "einwerfen",
    "einwirft": "einwerfen",
    "einwirke": "einwirken",
    "einwirkend": "einwirken",
    "einwirkende": "einwirkend",
    "einwirkendem": "einwirkend",
    "einwirkenden": "einwirkend",
    "einwirkender": "einwirkend",
    "einwirkendes": "einwirkend",
    "einwirkest": "einwirken",
    "einwirket": "einwirken",
    "einwirkst": "einwirken",
    "einwirkt": "einwirken",
    "einwirkte": "einwirken",
    "einwirkten": "einwirken",
    "einwirktest": "einwirken",
    "einwirktet": "einwirken",
    "einwob": "einweben",
    "einwoben": "einweben",
    "einwobst": "einweben",
    "einwobt": "einweben",
    "einwog": "einwiegen",
    "einwogen": "einwiegen",
    "einwogst": "einwiegen",
    "einwogt": "einwiegen",
    "einwohne": "einwohnen",
    "einwohnend": "einwohnen",
    "einwohnende": "einwohnend",
    "einwohnendem": "einwohnend",
    "einwohnenden": "einwohnend",
    "einwohnender": "einwohnend",
    "einwohnendes": "einwohnend",
    "einwohnest": "einwohnen",
    "einwohnet": "einwohnen",
    "einwohnst": "einwohnen",
    "einwohnt": "einwohnen",
    "einwohnte": "einwohnen",
    "einwohnten": "einwohnen",
    "einwohntest": "einwohnen",
    "einwohntet": "einwohnen",
    "einwuchs": "einwachsen",
    "einwuchsen": "einwachsen",
    "einwuchst": "einwachsen",
    "einwurzele": "einwurzeln",
    "einwurzelnd": "einwurzeln",
    "einwurzelnde": "einwurzelnd",
    "einwurzelndem": "einwurzelnd",
    "einwurzelnden": "einwurzelnd",
    "einwurzelnder": "einwurzelnd",
    "einwurzelndes": "einwurzelnd",
    "einwurzelst": "einwurzeln",
    "einwurzelt": "einwurzeln",
    "einwurzelte": "einwurzeln",
    "einwurzelten": "einwurzeln",
    "einwurzeltest": "einwurzeln",
    "einwurzeltet": "einwurzeln",
    "einwurzle": "einwurzeln",
    "einwächst": "einwachsen",
    "einwärfe": "einwerfen",
    "einwärfen": "einwerfen",
    "einwärfest": "einwerfen",
    "einwärfet": "einwerfen",
    "einwöbe": "einweben",
    "einwöben": "einweben",
    "einwöbest": "einweben",
    "einwöbet": "einweben",
    "einwöge": "einwiegen",
    "einwögen": "einwiegen",
    "einwögest": "einwiegen",
    "einwöget": "einwiegen",
    "einwüchse": "einwachsen",
    "einwüchsen": "einwachsen",
    "einwüchsest": "einwachsen",
    "einwüchset": "einwachsen",
    "einzahle": "einzahlen",
    "einzahlend": "einzahlen",
    "einzahlende": "einzahlend",
    "einzahlendem": "einzahlend",
    "einzahlenden": "einzahlend",
    "einzahlender": "einzahlend",
    "einzahlendes": "einzahlend",
    "einzahlest": "einzahlen",
    "einzahlet": "einzahlen",
    "einzahlst": "einzahlen",
    "einzahlt": "einzahlen",
    "einzahlte": "einzahlen",
    "einzahlten": "einzahlen",
    "einzahltest": "einzahlen",
    "einzahltet": "einzahlen",
    "einzeichne": "einzeichnen",
    "einzeichnend": "einzeichnen",
    "einzeichnende": "einzeichnend",
    "einzeichnendem": "einzeichnend",
    "einzeichnenden": "einzeichnend",
    "einzeichnender": "einzeichnend",
    "einzeichnendes": "einzeichnend",
    "einzeichnest": "einzeichnen",
    "einzeichnet": "einzeichnen",
    "einzeichnete": "einzeichnen",
    "einzeichneten": "einzeichnen",
    "einzeichnetest": "einzeichnen",
    "einzeichnetet": "einzeichnen",
    "einzeilige": "einzeilig",
    "einzeiligem": "einzeilig",
    "einzeiligen": "einzeilig",
    "einzeiliger": "einzeilig",
    "einzeiliges": "einzeilig",
    "einzelligem": "einzellig",
    "einzelligen": "einzellig",
    "einzelliger": "einzellig",
    "einzelliges": "einzellig",
    "einzelnem": "einzeln",
    "einzelnen": "einzeln",
    "einzelner": "einzeln",
    "einzelnes": "einzeln",
    "einziehe": "einziehen",
    "einziehend": "einziehen",
    "einziehende": "einziehend",
    "einziehendem": "einziehend",
    "einziehenden": "einziehend",
    "einziehender": "einziehend",
    "einziehendes": "einziehend",
    "einziehest": "einziehen",
    "einziehet": "einziehen",
    "einziehst": "einziehen",
    "einzieht": "einziehen",
    "einzigartige": "einzigartig",
    "einzigartigem": "einzigartig",
    "einzigartigen": "einzigartig",
    "einzigartiger": "einzigartig",
    "einzigartigere": "einzigartig",
    "einzigartigerem": "einzigartig",
    "einzigartigeren": "einzigartig",
    "einzigartigerer": "einzigartig",
    "einzigartigeres": "einzigartig",
    "einzigartiges": "einzigartig",
    "einzigartigste": "einzigartig",
    "einzigartigstem": "einzigartig",
    "einzigartigsten": "einzigartig",
    "einzigartigster": "einzigartig",
    "einzigartigstes": "einzigartig",
    "einzige": "einzig",
    "einzigem": "einzig",
    "einzigen": "einzig",
    "einziger": "einzig",
    "einziges": "einzig",
    "einzog": "einziehen",
    "einzogen": "einziehen",
    "einzogst": "einziehen",
    "einzogt": "einziehen",
    "einzuarbeiten": "einarbeiten",
    "einzuatmen": "einatmen",
    "einzubalsamieren": "einbalsamieren",
    "einzubauen": "einbauen",
    "einzubehalten": "einbehalten",
    "einzubekennen": "einbekennen",
    "einzuberufen": "einberufen",
    "einzubestellen": "einbestellen",
    "einzubetonieren": "einbetonieren",
    "einzubetten": "einbetten",
    "einzubeziehen": "einbeziehen",
    "einzubiegen": "einbiegen",
    "einzubilden": "einbilden",
    "einzubinden": "einbinden",
    "einzublasen": "einblasen",
    "einzublenden": "einblenden",
    "einzubleuen": "einbleuen",
    "einzubläuen": "einbläuen",
    "einzubooten": "einbooten",
    "einzubrechen": "einbrechen",
    "einzubrennen": "einbrennen",
    "einzubringen": "einbringen",
    "einzubuchten": "einbuchten",
    "einzubuddeln": "einbuddeln",
    "einzubunkern": "einbunkern",
    "einzubürgern": "einbürgern",
    "einzubüßen": "einbüßen",
    "einzuchecken": "einchecken",
    "einzucremen": "eincremen",
    "einzudampfen": "eindampfen",
    "einzudeichen": "eindeichen",
    "einzudellen": "eindellen",
    "einzudeutschen": "eindeutschen",
    "einzudosen": "eindosen",
    "einzudrehen": "eindrehen",
    "einzudrillen": "eindrillen",
    "einzudringen": "eindringen",
    "einzudrücken": "eindrücken",
    "einzudämmen": "eindämmen",
    "einzuebnen": "einebnen",
    "einzuengen": "einengen",
    "einzuernten": "einernten",
    "einzufahren": "einfahren",
    "einzufallen": "einfallen",
    "einzufangen": "einfangen",
    "einzufassen": "einfassen",
    "einzufetten": "einfetten",
    "einzufeuern": "einfeuern",
    "einzufinden": "einfinden",
    "einzuflechten": "einflechten",
    "einzufliegen": "einfliegen",
    "einzufließen": "einfließen",
    "einzuflippen": "einflippen",
    "einzuflößen": "einflößen",
    "einzuflüstern": "einflüstern",
    "einzufordern": "einfordern",
    "einzufressen": "einfressen",
    "einzufrieren": "einfrieren",
    "einzufädeln": "einfädeln",
    "einzufärben": "einfärben",
    "einzufügen": "einfügen",
    "einzufühlen": "einfühlen",
    "einzuführen": "einführen",
    "einzufüllen": "einfüllen",
    "einzugeben": "eingeben",
    "einzugehen": "eingehen",
    "einzugemeinden": "eingemeinden",
    "einzugestehen": "eingestehen",
    "einzugewöhnen": "eingewöhnen",
    "einzugießen": "eingießen",
    "einzugipsen": "eingipsen",
    "einzugittern": "eingittern",
    "einzuglasen": "einglasen",
    "einzugleisen": "eingleisen",
    "einzugliedern": "eingliedern",
    "einzugraben": "eingraben",
    "einzugreifen": "eingreifen",
    "einzugrenzen": "eingrenzen",
    "einzugruppieren": "eingruppieren",
    "einzuhaken": "einhaken",
    "einzuhalten": "einhalten",
    "einzuhandeln": "einhandeln",
    "einzuhauen": "einhauen",
    "einzuheben": "einheben",
    "einzuheften": "einheften",
    "einzuheilen": "einheilen",
    "einzuheimsen": "einheimsen",
    "einzuheiraten": "einheiraten",
    "einzuheizen": "einheizen",
    "einzuhelfen": "einhelfen",
    "einzuhieven": "einhieven",
    "einzuholen": "einholen",
    "einzuhändigen": "einhändigen",
    "einzuhängen": "einhängen",
    "einzuhüllen": "einhüllen",
    "einzuhüten": "einhüten",
    "einzuigeln": "einigeln",
    "einzuimpfen": "einimpfen",
    "einzujagen": "einjagen",
    "einzukacheln": "einkacheln",
    "einzukalkulieren": "einkalkulieren",
    "einzukapseln": "einkapseln",
    "einzukassieren": "einkassieren",
    "einzukaufen": "einkaufen",
    "einzukehren": "einkehren",
    "einzukeilen": "einkeilen",
    "einzukellern": "einkellern",
    "einzukerben": "einkerben",
    "einzukerkern": "einkerkern",
    "einzukesseln": "einkesseln",
    "einzukitten": "einkitten",
    "einzuklagen": "einklagen",
    "einzuklammern": "einklammern",
    "einzukleben": "einkleben",
    "einzukleiden": "einkleiden",
    "einzuklemmen": "einklemmen",
    "einzuklinken": "einklinken",
    "einzuklopfen": "einklopfen",
    "einzukneifen": "einkneifen",
    "einzuknicken": "einknicken",
    "einzuknoten": "einknoten",
    "einzuknöpfen": "einknöpfen",
    "einzuknüpfen": "einknüpfen",
    "einzukochen": "einkochen",
    "einzukratzen": "einkratzen",
    "einzukreisen": "einkreisen",
    "einzukreuzen": "einkreuzen",
    "einzukriegen": "einkriegen",
    "einzuladen": "einladen",
    "einzulagern": "einlagern",
    "einzulangen": "einlangen",
    "einzulassen": "einlassen",
    "einzulaufen": "einlaufen",
    "einzuleben": "einleben",
    "einzulegen": "einlegen",
    "einzuleiten": "einleiten",
    "einzulenken": "einlenken",
    "einzulernen": "einlernen",
    "einzulesen": "einlesen",
    "einzuleuchten": "einleuchten",
    "einzuliefern": "einliefern",
    "einzuliegen": "einliegen",
    "einzulochen": "einlochen",
    "einzulullen": "einlullen",
    "einzuläuten": "einläuten",
    "einzulösen": "einlösen",
    "einzulöten": "einlöten",
    "einzumachen": "einmachen",
    "einzumahnen": "einmahnen",
    "einzumarschieren": "einmarschieren",
    "einzumauern": "einmauern",
    "einzumeißeln": "einmeißeln",
    "einzumengen": "einmengen",
    "einzumieten": "einmieten",
    "einzumischen": "einmischen",
    "einzumotten": "einmotten",
    "einzumümmeln": "einmümmeln",
    "einzumünden": "einmünden",
    "einzunebeln": "einnebeln",
    "einzunehmen": "einnehmen",
    "einzunisten": "einnisten",
    "einzunähen": "einnähen",
    "einzunässen": "einnässen",
    "einzuoperieren": "einoperieren",
    "einzuordnen": "einordnen",
    "einzupacken": "einpacken",
    "einzuparken": "einparken",
    "einzupassen": "einpassen",
    "einzupauken": "einpauken",
    "einzupendeln": "einpendeln",
    "einzupferchen": "einpferchen",
    "einzupflanzen": "einpflanzen",
    "einzupfropfen": "einpfropfen",
    "einzupinseln": "einpinseln",
    "einzuplanen": "einplanen",
    "einzupressen": "einpressen",
    "einzuprogrammieren": "einprogrammieren",
    "einzuprägen": "einprägen",
    "einzupudern": "einpudern",
    "einzupumpen": "einpumpen",
    "einzupökeln": "einpökeln",
    "einzuquartieren": "einquartieren",
    "einzurahmen": "einrahmen",
    "einzurammen": "einrammen",
    "einzurasten": "einrasten",
    "einzurechnen": "einrechnen",
    "einzureden": "einreden",
    "einzuregnen": "einregnen",
    "einzureiben": "einreiben",
    "einzureichen": "einreichen",
    "einzureihen": "einreihen",
    "einzureisen": "einreisen",
    "einzureiten": "einreiten",
    "einzureißen": "einreißen",
    "einzurenken": "einrenken",
    "einzurennen": "einrennen",
    "einzurichten": "einrichten",
    "einzuriegeln": "einriegeln",
    "einzuritzen": "einritzen",
    "einzurollen": "einrollen",
    "einzurosten": "einrosten",
    "einzuräuchern": "einräuchern",
    "einzuräumen": "einräumen",
    "einzurücken": "einrücken",
    "einzurühren": "einrühren",
    "einzurüsten": "einrüsten",
    "einzusagen": "einsagen",
    "einzusalben": "einsalben",
    "einzusalzen": "einsalzen",
    "einzusammeln": "einsammeln",
    "einzusargen": "einsargen",
    "einzusauen": "einsauen",
    "einzusaugen": "einsaugen",
    "einzuschachteln": "einschachteln",
    "einzuschalten": "einschalten",
    "einzuscharren": "einscharren",
    "einzuschenken": "einschenken",
    "einzuscheren": "einscheren",
    "einzuschieben": "einschieben",
    "einzuschießen": "einschießen",
    "einzuschiffen": "einschiffen",
    "einzuschlafen": "einschlafen",
    "einzuschlagen": "einschlagen",
    "einzuschleichen": "einschleichen",
    "einzuschleifen": "einschleifen",
    "einzuschleimen": "einschleimen",
    "einzuschleppen": "einschleppen",
    "einzuschleusen": "einschleusen",
    "einzuschließen": "einschließen",
    "einzuschlummern": "einschlummern",
    "einzuschläfern": "einschläfern",
    "einzuschmeicheln": "einschmeicheln",
    "einzuschmeißen": "einschmeißen",
    "einzuschmelzen": "einschmelzen",
    "einzuschmieren": "einschmieren",
    "einzuschmuggeln": "einschmuggeln",
    "einzuschnappen": "einschnappen",
    "einzuschneiden": "einschneiden",
    "einzuschneien": "einschneien",
    "einzuschnitzen": "einschnitzen",
    "einzuschnüren": "einschnüren",
    "einzuschrauben": "einschrauben",
    "einzuschreiben": "einschreiben",
    "einzuschrumpfen": "einschrumpfen",
    "einzuschränken": "einschränken",
    "einzuschulen": "einschulen",
    "einzuschweben": "einschweben",
    "einzuschwefeln": "einschwefeln",
    "einzuschwenken": "einschwenken",
    "einzuschwimmen": "einschwimmen",
    "einzuschwingen": "einschwingen",
    "einzuschwärzen": "einschwärzen",
    "einzuschwören": "einschwören",
    "einzuschärfen": "einschärfen",
    "einzuschätzen": "einschätzen",
    "einzuschütten": "einschütten",
    "einzusegnen": "einsegnen",
    "einzusehen": "einsehen",
    "einzuseifen": "einseifen",
    "einzusenden": "einsenden",
    "einzusengen": "einsengen",
    "einzusetzen": "einsetzen",
    "einzusingen": "einsingen",
    "einzusinken": "einsinken",
    "einzusitzen": "einsitzen",
    "einzusortieren": "einsortieren",
    "einzuspannen": "einspannen",
    "einzusparen": "einsparen",
    "einzuspeichern": "einspeichern",
    "einzusperren": "einsperren",
    "einzuspielen": "einspielen",
    "einzusprechen": "einsprechen",
    "einzusprengen": "einsprengen",
    "einzuspringen": "einspringen",
    "einzuspritzen": "einspritzen",
    "einzusprühen": "einsprühen",
    "einzustampfen": "einstampfen",
    "einzustauben": "einstauben",
    "einzustechen": "einstechen",
    "einzustecken": "einstecken",
    "einzustehen": "einstehen",
    "einzusteigen": "einsteigen",
    "einzustellen": "einstellen",
    "einzustimmen": "einstimmen",
    "einzustippen": "einstippen",
    "einzustrahlen": "einstrahlen",
    "einzustreichen": "einstreichen",
    "einzustreuen": "einstreuen",
    "einzuströmen": "einströmen",
    "einzustudieren": "einstudieren",
    "einzustufen": "einstufen",
    "einzustülpen": "einstülpen",
    "einzustürmen": "einstürmen",
    "einzustürzen": "einstürzen",
    "einzusägen": "einsägen",
    "einzusäuern": "einsäuern",
    "einzusäumen": "einsäumen",
    "einzutanzen": "eintanzen",
    "einzutauchen": "eintauchen",
    "einzutauschen": "eintauschen",
    "einzuteilen": "einteilen",
    "einzutopfen": "eintopfen",
    "einzutragen": "eintragen",
    "einzutreffen": "eintreffen",
    "einzutreiben": "eintreiben",
    "einzutreten": "eintreten",
    "einzutrichtern": "eintrichtern",
    "einzutrocknen": "eintrocknen",
    "einzutrudeln": "eintrudeln",
    "einzuträufeln": "einträufeln",
    "einzutrüben": "eintrüben",
    "einzutunken": "eintunken",
    "einzutüten": "eintüten",
    "einzuverleiben": "einverleiben",
    "einzuwachsen": "einwachsen",
    "einzuwandern": "einwandern",
    "einzuweben": "einweben",
    "einzuwechseln": "einwechseln",
    "einzuweichen": "einweichen",
    "einzuweihen": "einweihen",
    "einzuweisen": "einweisen",
    "einzuwenden": "einwenden",
    "einzuwerfen": "einwerfen",
    "einzuwickeln": "einwickeln",
    "einzuwiegen": "einwiegen",
    "einzuwilligen": "einwilligen",
    "einzuwinken": "einwinken",
    "einzuwirken": "einwirken",
    "einzuwohnen": "einwohnen",
    "einzuwurzeln": "einwurzeln",
    "einzuzahlen": "einzahlen",
    "einzuzeichnen": "einzeichnen",
    "einzuziehen": "einziehen",
    "einzuzwängen": "einzwängen",
    "einzuzäunen": "einzäunen",
    "einzuäschern": "einäschern",
    "einzuölen": "einölen",
    "einzuüben": "einüben",
    "einzwänge": "einzwängen",
    "einzwängend": "einzwängen",
    "einzwängende": "einzwängend",
    "einzwängendem": "einzwängend",
    "einzwängenden": "einzwängend",
    "einzwängender": "einzwängend",
    "einzwängendes": "einzwängend",
    "einzwängest": "einzwängen",
    "einzwänget": "einzwängen",
    "einzwängst": "einzwängen",
    "einzwängt": "einzwängen",
    "einzwängte": "einzwängen",
    "einzwängten": "einzwängen",
    "einzwängtest": "einzwängen",
    "einzwängtet": "einzwängen",
    "einzäune": "einzäunen",
    "einzäunend": "einzäunen",
    "einzäunende": "einzäunend",
    "einzäunendem": "einzäunend",
    "einzäunenden": "einzäunend",
    "einzäunender": "einzäunend",
    "einzäunendes": "einzäunend",
    "einzäunest": "einzäunen",
    "einzäunet": "einzäunen",
    "einzäunst": "einzäunen",
    "einzäunt": "einzäunen",
    "einzäunte": "einzäunen",
    "einzäunten": "einzäunen",
    "einzäuntest": "einzäunen",
    "einzäuntet": "einzäunen",
    "einzöge": "einziehen",
    "einzögen": "einziehen",
    "einzögest": "einziehen",
    "einzöget": "einziehen",
    "einäschere": "einäschern",
    "einäschernd": "einäschern",
    "einäschernde": "einäschernd",
    "einäscherndem": "einäschernd",
    "einäschernden": "einäschernd",
    "einäschernder": "einäschernd",
    "einäscherndes": "einäschernd",
    "einäscherst": "einäschern",
    "einäschert": "einäschern",
    "einäscherte": "einäschern",
    "einäscherten": "einäschern",
    "einäschertest": "einäschern",
    "einäschertet": "einäschern",
    "einöle": "einölen",
    "einölend": "einölen",
    "einölende": "einölend",
    "einölendem": "einölend",
    "einölenden": "einölend",
    "einölender": "einölend",
    "einölendere": "einölend",
    "einölenderem": "einölend",
    "einölenderen": "einölend",
    "einölenderer": "einölend",
    "einölenderes": "einölend",
    "einölendes": "einölend",
    "einölendste": "einölend",
    "einölendstem": "einölend",
    "einölendsten": "einölend",
    "einölendster": "einölend",
    "einölendstes": "einölend",
    "einölest": "einölen",
    "einölet": "einölen",
    "einölst": "einölen",
    "einölt": "einölen",
    "einölte": "einölen",
    "einölten": "einölen",
    "einöltest": "einölen",
    "einöltet": "einölen",
    "einübe": "einüben",
    "einübend": "einüben",
    "einübende": "einübend",
    "einübendem": "einübend",
    "einübenden": "einübend",
    "einübender": "einübend",
    "einübendere": "einübend",
    "einübenderem": "einübend",
    "einübenderen": "einübend",
    "einübenderer": "einübend",
    "einübenderes": "einübend",
    "einübendes": "einübend",
    "einübendste": "einübend",
    "einübendstem": "einübend",
    "einübendsten": "einübend",
    "einübendster": "einübend",
    "einübendstes": "einübend",
    "einübest": "einüben",
    "einübet": "einüben",
    "einübst": "einüben",
    "einübt": "einüben",
    "einübte": "einüben",
    "einübten": "einüben",
    "einübtest": "einüben",
    "einübtet": "einüben",
    "eise": "eisen",
    "eisend": "eisen",
    "eisende": "eisend",
    "eisendem": "eisend",
    "eisenden": "eisend",
    "eisender": "eisend",
    "eisendes": "eisend",
    "eisenharte": "eisenhart",
    "eisenhartem": "eisenhart",
    "eisenharten": "eisenhart",
    "eisenharter": "eisenhart",
    "eisenhartes": "eisenhart",
    "eisenhärter": "eisenhart",
    "eisenhärtere": "eisenhart",
    "eisenhärterem": "eisenhart",
    "eisenhärteren": "eisenhart",
    "eisenhärterer": "eisenhart",
    "eisenhärteres": "eisenhart",
    "eisenhärteste": "eisenhart",
    "eisenhärtestem": "eisenhart",
    "eisenhärtesten": "eisenhart",
    "eisenhärtester": "eisenhart",
    "eisenhärtestes": "eisenhart",
    "eisernem": "eisern",
    "eisernen": "eisern",
    "eiserner": "eisern",
    "eisernere": "eisern",
    "eisernerem": "eisern",
    "eiserneren": "eisern",
    "eisernerer": "eisern",
    "eiserneres": "eisern",
    "eisernes": "eisern",
    "eisernste": "eisern",
    "eisernstem": "eisern",
    "eisernsten": "eisern",
    "eisernster": "eisern",
    "eisernstes": "eisern",
    "eisest": "eisen",
    "eiset": "eisen",
    "eisfreie": "eisfrei",
    "eisfreiem": "eisfrei",
    "eisfreien": "eisfrei",
    "eisfreier": "eisfrei",
    "eisfreies": "eisfrei",
    "eisgekühlte": "eisgekühlt",
    "eisgekühltem": "eisgekühlt",
    "eisgekühlten": "eisgekühlt",
    "eisgekühlter": "eisgekühlt",
    "eisgekühltere": "eisgekühlt",
    "eisgekühlterem": "eisgekühlt",
    "eisgekühlteren": "eisgekühlt",
    "eisgekühlterer": "eisgekühlt",
    "eisgekühlteres": "eisgekühlt",
    "eisgekühltes": "eisgekühlt",
    "eisgekühlteste": "eisgekühlt",
    "eisgekühltestem": "eisgekühlt",
    "eisgekühltesten": "eisgekühlt",
    "eisgekühltester": "eisgekühlt",
    "eisgekühltestes": "eisgekühlt",
    "eisige": "eisig",
    "eisigem": "eisig",
    "eisigen": "eisig",
    "eisiger": "eisig",
    "eisigere": "eisig",
    "eisigerem": "eisig",
    "eisigeren": "eisig",
    "eisigerer": "eisig",
    "eisigeres": "eisig",
    "eisiges": "eisig",
    "eisigste": "eisig",
    "eisigstem": "eisig",
    "eisigsten": "eisig",
    "eisigster": "eisig",
    "eisigstes": "eisig",
    "eiskalte": "eiskalt",
    "eiskaltem": "eiskalt",
    "eiskalten": "eiskalt",
    "eiskalter": "eiskalt",
    "eiskaltes": "eiskalt",
    "eist": "eisen",
    "eiste": "eisen",
    "eisten": "eisen",
    "eistest": "eisen",
    "eistet": "eisen",
    "eitelstem": "eitel",
    "eitelsten": "eitel",
    "eitelster": "eitel",
    "eitelstes": "eitel",
    "eitere": "eitern",
    "eiterige": "eiterig",
    "eiterigem": "eiterig",
    "eiterigen": "eiterig",
    "eiteriger": "eiterig",
    "eiterigere": "eiterig",
    "eiterigerem": "eiterig",
    "eiterigeren": "eiterig",
    "eiterigerer": "eiterig",
    "eiterigeres": "eiterig",
    "eiteriges": "eiterig",
    "eiterigste": "eiterig",
    "eiterigstem": "eiterig",
    "eiterigsten": "eiterig",
    "eiterigster": "eiterig",
    "eiterigstes": "eiterig",
    "eiternd": "eitern",
    "eiternde": "eiternd",
    "eiterndem": "eiternd",
    "eiternden": "eiternd",
    "eiternder": "eiternd",
    "eiterndere": "eiternd",
    "eiternderem": "eiternd",
    "eiternderen": "eiternd",
    "eiternderer": "eiternd",
    "eiternderes": "eiternd",
    "eiterndes": "eiternd",
    "eiterndste": "eiternd",
    "eiterndstem": "eiternd",
    "eiterndsten": "eiternd",
    "eiterndster": "eiternd",
    "eiterndstes": "eiternd",
    "eiterst": "eitern",
    "eitert": "eitern",
    "eiterte": "eitern",
    "eiterten": "eitern",
    "eitertest": "eitern",
    "eitertet": "eitern",
    "eitle": "eitel",
    "eitlem": "eitel",
    "eitlen": "eitel",
    "eitler": "eitel",
    "eitlere": "eitel",
    "eitlerem": "eitel",
    "eitleren": "eitel",
    "eitlerer": "eitel",
    "eitleres": "eitel",
    "eitles": "eitel",
    "eitrige": "eitrig",
    "eitrigem": "eitrig",
    "eitrigen": "eitrig",
    "eitriger": "eitrig",
    "eitrigere": "eitrig",
    "eitrigerem": "eitrig",
    "eitrigeren": "eitrig",
    "eitrigerer": "eitrig",
    "eitrigeres": "eitrig",
    "eitriges": "eitrig",
    "eitrigste": "eitrig",
    "eitrigstem": "eitrig",
    "eitrigsten": "eitrig",
    "eitrigster": "eitrig",
    "eitrigstes": "eitrig",
    "ejakuliere": "ejakulieren",
    "ejakulierend": "ejakulieren",
    "ejakulierende": "ejakulierend",
    "ejakulierendem": "ejakulierend",
    "ejakulierenden": "ejakulierend",
    "ejakulierender": "ejakulierend",
    "ejakulierendes": "ejakulierend",
    "ejakulierest": "ejakulieren",
    "ejakulieret": "ejakulieren",
    "ejakulierst": "ejakulieren",
    "ejakuliert": "ejakulieren",
    "ejakulierte": "ejakulieren",
    "ejakuliertem": "ejakuliert",
    "ejakulierten": "ejakulieren",
    "ejakulierter": "ejakuliert",
    "ejakuliertes": "ejakuliert",
    "ejakuliertest": "ejakulieren",
    "ejakuliertet": "ejakulieren",
    "ekele": "ekeln",
    "ekelhafte": "ekelhaft",
    "ekelhaftem": "ekelhaft",
    "ekelhaften": "ekelhaft",
    "ekelhafter": "ekelhaft",
    "ekelhaftere": "ekelhaft",
    "ekelhafterem": "ekelhaft",
    "ekelhafteren": "ekelhaft",
    "ekelhafterer": "ekelhaft",
    "ekelhafteres": "ekelhaft",
    "ekelhaftes": "ekelhaft",
    "ekelhafteste": "ekelhaft",
    "ekelhaftestem": "ekelhaft",
    "ekelhaftesten": "ekelhaft",
    "ekelhaftester": "ekelhaft",
    "ekelhaftestes": "ekelhaft",
    "ekelige": "ekelig",
    "ekeligem": "ekelig",
    "ekeligen": "ekelig",
    "ekeliger": "ekelig",
    "ekeligere": "ekelig",
    "ekeligerem": "ekelig",
    "ekeligeren": "ekelig",
    "ekeligerer": "ekelig",
    "ekeligeres": "ekelig",
    "ekeliges": "ekelig",
    "ekeligste": "ekelig",
    "ekeligstem": "ekelig",
    "ekeligsten": "ekelig",
    "ekeligster": "ekelig",
    "ekeligstes": "ekelig",
    "ekelnd": "ekeln",
    "ekelnde": "ekelnd",
    "ekelndem": "ekelnd",
    "ekelnden": "ekelnd",
    "ekelnder": "ekelnd",
    "ekelndere": "ekelnd",
    "ekelnderem": "ekelnd",
    "ekelnderen": "ekelnd",
    "ekelnderer": "ekelnd",
    "ekelnderes": "ekelnd",
    "ekelndes": "ekelnd",
    "ekelndste": "ekelnd",
    "ekelndstem": "ekelnd",
    "ekelndsten": "ekelnd",
    "ekelndster": "ekelnd",
    "ekelndstes": "ekelnd",
    "ekelst": "ekeln",
    "ekelt": "ekeln",
    "ekelte": "ekeln",
    "ekelten": "ekeln",
    "ekeltest": "ekeln",
    "ekeltet": "ekeln",
    "ekle": "ekeln",
    "eklige": "eklig",
    "ekligem": "eklig",
    "ekligen": "eklig",
    "ekliger": "eklig",
    "ekligere": "eklig",
    "ekligerem": "eklig",
    "ekligeren": "eklig",
    "ekligerer": "eklig",
    "ekligeres": "eklig",
    "ekliges": "eklig",
    "ekligste": "eklig",
    "ekligstem": "eklig",
    "ekligsten": "eklig",
    "ekligster": "eklig",
    "ekligstes": "eklig",
    "elaboriere": "elaborieren",
    "elaborierend": "elaborieren",
    "elaborierende": "elaborierend",
    "elaborierendem": "elaborierend",
    "elaborierenden": "elaborierend",
    "elaborierender": "elaborierend",
    "elaborierendes": "elaborierend",
    "elaborierest": "elaborieren",
    "elaborieret": "elaborieren",
    "elaborierst": "elaborieren",
    "elaboriert": "elaborieren",
    "elaborierte": "elaborieren",
    "elaboriertem": "elaboriert",
    "elaborierten": "elaborieren",
    "elaborierter": "elaboriert",
    "elaboriertes": "elaboriert",
    "elaboriertest": "elaborieren",
    "elaboriertet": "elaborieren",
    "elastischem": "elastisch",
    "elastischen": "elastisch",
    "elastischer": "elastisch",
    "elastischere": "elastisch",
    "elastischerem": "elastisch",
    "elastischeren": "elastisch",
    "elastischerer": "elastisch",
    "elastischeres": "elastisch",
    "elastisches": "elastisch",
    "elastischste": "elastisch",
    "elastischstem": "elastisch",
    "elastischsten": "elastisch",
    "elastischster": "elastisch",
    "elastischstes": "elastisch",
    "elegantem": "elegant",
    "eleganten": "elegant",
    "eleganter": "elegant",
    "elegantere": "elegant",
    "eleganterem": "elegant",
    "eleganteren": "elegant",
    "eleganterer": "elegant",
    "eleganteres": "elegant",
    "elegantes": "elegant",
    "eleganteste": "elegant",
    "elegantestem": "elegant",
    "elegantesten": "elegant",
    "elegantester": "elegant",
    "elegantestes": "elegant",
    "elektrifiziere": "elektrifizieren",
    "elektrifizierend": "elektrifizieren",
    "elektrifizierende": "elektrifizierend",
    "elektrifizierendem": "elektrifizierend",
    "elektrifizierenden": "elektrifizierend",
    "elektrifizierender": "elektrifizierend",
    "elektrifizierendere": "elektrifizierend",
    "elektrifizierenderem": "elektrifizierend",
    "elektrifizierenderen": "elektrifizierend",
    "elektrifizierenderer": "elektrifizierend",
    "elektrifizierenderes": "elektrifizierend",
    "elektrifizierendes": "elektrifizierend",
    "elektrifizierendste": "elektrifizierend",
    "elektrifizierendstem": "elektrifizierend",
    "elektrifizierendsten": "elektrifizierend",
    "elektrifizierendster": "elektrifizierend",
    "elektrifizierendstes": "elektrifizierend",
    "elektrifizierest": "elektrifizieren",
    "elektrifizieret": "elektrifizieren",
    "elektrifizierst": "elektrifizieren",
    "elektrifiziert": "elektrifizieren",
    "elektrifizierte": "elektrifizieren",
    "elektrifiziertem": "elektrifiziert",
    "elektrifizierten": "elektrifizieren",
    "elektrifizierter": "elektrifiziert",
    "elektrifiziertere": "elektrifiziert",
    "elektrifizierterem": "elektrifiziert",
    "elektrifizierteren": "elektrifiziert",
    "elektrifizierterer": "elektrifiziert",
    "elektrifizierteres": "elektrifiziert",
    "elektrifiziertes": "elektrifiziert",
    "elektrifiziertest": "elektrifizieren",
    "elektrifizierteste": "elektrifiziert",
    "elektrifiziertestem": "elektrifiziert",
    "elektrifiziertesten": "elektrifiziert",
    "elektrifiziertester": "elektrifiziert",
    "elektrifiziertestes": "elektrifiziert",
    "elektrifiziertet": "elektrifizieren",
    "elektrischem": "elektrisch",
    "elektrischen": "elektrisch",
    "elektrischer": "elektrisch",
    "elektrisches": "elektrisch",
    "elektrisiere": "elektrisieren",
    "elektrisierend": "elektrisieren",
    "elektrisierende": "elektrisierend",
    "elektrisierendem": "elektrisierend",
    "elektrisierenden": "elektrisierend",
    "elektrisierender": "elektrisierend",
    "elektrisierendere": "elektrisierend",
    "elektrisierenderem": "elektrisierend",
    "elektrisierenderen": "elektrisierend",
    "elektrisierenderer": "elektrisierend",
    "elektrisierenderes": "elektrisierend",
    "elektrisierendes": "elektrisierend",
    "elektrisierendste": "elektrisierend",
    "elektrisierendstem": "elektrisierend",
    "elektrisierendsten": "elektrisierend",
    "elektrisierendster": "elektrisierend",
    "elektrisierendstes": "elektrisierend",
    "elektrisierest": "elektrisieren",
    "elektrisieret": "elektrisieren",
    "elektrisierst": "elektrisieren",
    "elektrisiert": "elektrisieren",
    "elektrisierte": "elektrisieren",
    "elektrisiertem": "elektrisiert",
    "elektrisierten": "elektrisieren",
    "elektrisierter": "elektrisiert",
    "elektrisiertere": "elektrisiert",
    "elektrisierterem": "elektrisiert",
    "elektrisierteren": "elektrisiert",
    "elektrisierterer": "elektrisiert",
    "elektrisierteres": "elektrisiert",
    "elektrisiertes": "elektrisiert",
    "elektrisiertest": "elektrisieren",
    "elektrisierteste": "elektrisiert",
    "elektrisiertestem": "elektrisiert",
    "elektrisiertesten": "elektrisiert",
    "elektrisiertester": "elektrisiert",
    "elektrisiertestes": "elektrisiert",
    "elektrisiertet": "elektrisieren",
    "elektrodynamischem": "elektrodynamisch",
    "elektrodynamischen": "elektrodynamisch",
    "elektrodynamischer": "elektrodynamisch",
    "elektrodynamisches": "elektrodynamisch",
    "elektrolytischem": "elektrolytisch",
    "elektrolytischen": "elektrolytisch",
    "elektrolytischer": "elektrolytisch",
    "elektrolytisches": "elektrolytisch",
    "elektromechanische": "elektromechanisch",
    "elektromechanischem": "elektromechanisch",
    "elektromechanischen": "elektromechanisch",
    "elektromechanischer": "elektromechanisch",
    "elektromechanisches": "elektromechanisch",
    "elektronischem": "elektronisch",
    "elektronischen": "elektronisch",
    "elektronischer": "elektronisch",
    "elektronisches": "elektronisch",
    "elektrostatischem": "elektrostatisch",
    "elektrostatischen": "elektrostatisch",
    "elektrostatischer": "elektrostatisch",
    "elektrostatisches": "elektrostatisch",
    "elektrotechnischem": "elektrotechnisch",
    "elektrotechnischen": "elektrotechnisch",
    "elektrotechnischer": "elektrotechnisch",
    "elektrotechnisches": "elektrotechnisch",
    "elementarem": "elementar",
    "elementaren": "elementar",
    "elementarer": "elementar",
    "elementarere": "elementar",
    "elementarerem": "elementar",
    "elementareren": "elementar",
    "elementarerer": "elementar",
    "elementareres": "elementar",
    "elementares": "elementar",
    "elementarstem": "elementar",
    "elementarsten": "elementar",
    "elementarster": "elementar",
    "elementarstes": "elementar",
    "elendem": "elend",
    "elenden": "elend",
    "elender": "elend",
    "elendere": "elend",
    "elenderem": "elend",
    "elenderen": "elend",
    "elenderer": "elend",
    "elenderes": "elend",
    "elendes": "elend",
    "elendeste": "elend",
    "elendestem": "elend",
    "elendesten": "elend",
    "elendester": "elend",
    "elendestes": "elend",
    "elendige": "elendig",
    "elendigem": "elendig",
    "elendigen": "elendig",
    "elendiger": "elendig",
    "elendigere": "elendig",
    "elendigerem": "elendig",
    "elendigeren": "elendig",
    "elendigerer": "elendig",
    "elendigeres": "elendig",
    "elendiges": "elendig",
    "elendigste": "elendig",
    "elendigstem": "elendig",
    "elendigsten": "elendig",
    "elendigster": "elendig",
    "elendigstes": "elendig",
    "eliminiere": "eliminieren",
    "eliminierend": "eliminieren",
    "eliminierende": "eliminierend",
    "eliminierendem": "eliminierend",
    "eliminierenden": "eliminierend",
    "eliminierender": "eliminierend",
    "eliminierendes": "eliminierend",
    "eliminierest": "eliminieren",
    "eliminieret": "eliminieren",
    "eliminierst": "eliminieren",
    "eliminiert": "eliminieren",
    "eliminierte": "eliminieren",
    "eliminiertem": "eliminiert",
    "eliminierten": "eliminieren",
    "eliminierter": "eliminiert",
    "eliminiertes": "eliminiert",
    "eliminiertest": "eliminieren",
    "eliminiertet": "eliminieren",
    "elitärem": "elitär",
    "elitären": "elitär",
    "elitärer": "elitär",
    "elitärere": "elitär",
    "elitärerem": "elitär",
    "elitäreren": "elitär",
    "elitärerer": "elitär",
    "elitäreres": "elitär",
    "elitäres": "elitär",
    "elitärste": "elitär",
    "elitärstem": "elitär",
    "elitärsten": "elitär",
    "elitärster": "elitär",
    "elitärstes": "elitär",
    "ellenlangem": "ellenlang",
    "ellenlangen": "ellenlang",
    "ellenlanger": "ellenlang",
    "ellenlanges": "ellenlang",
    "elliptischem": "elliptisch",
    "elliptischen": "elliptisch",
    "elliptischer": "elliptisch",
    "elliptisches": "elliptisch",
    "eloquentem": "eloquent",
    "eloquenten": "eloquent",
    "eloquenter": "eloquent",
    "eloquentes": "eloquent",
    "elsässischem": "elsässisch",
    "elsässischen": "elsässisch",
    "elsässischer": "elsässisch",
    "elsässisches": "elsässisch",
    "elterlichem": "elterlich",
    "elterlichen": "elterlich",
    "elterlicher": "elterlich",
    "elterliches": "elterlich",
    "elternlose": "elternlos",
    "elternlosem": "elternlos",
    "elternlosen": "elternlos",
    "elternloser": "elternlos",
    "elternloses": "elternlos",
    "emanzipiere": "emanzipieren",
    "emanzipierend": "emanzipieren",
    "emanzipierende": "emanzipierend",
    "emanzipierendem": "emanzipierend",
    "emanzipierenden": "emanzipierend",
    "emanzipierender": "emanzipierend",
    "emanzipierendere": "emanzipierend",
    "emanzipierenderem": "emanzipierend",
    "emanzipierenderen": "emanzipierend",
    "emanzipierenderer": "emanzipierend",
    "emanzipierenderes": "emanzipierend",
    "emanzipierendes": "emanzipierend",
    "emanzipierendste": "emanzipierend",
    "emanzipierendstem": "emanzipierend",
    "emanzipierendsten": "emanzipierend",
    "emanzipierendster": "emanzipierend",
    "emanzipierendstes": "emanzipierend",
    "emanzipierest": "emanzipieren",
    "emanzipieret": "emanzipieren",
    "emanzipierst": "emanzipieren",
    "emanzipiert": "emanzipieren",
    "emanzipierte": "emanzipieren",
    "emanzipiertem": "emanzipiert",
    "emanzipierten": "emanzipieren",
    "emanzipierter": "emanzipiert",
    "emanzipiertere": "emanzipiert",
    "emanzipierterem": "emanzipiert",
    "emanzipierteren": "emanzipiert",
    "emanzipierterer": "emanzipiert",
    "emanzipierteres": "emanzipiert",
    "emanzipiertes": "emanzipiert",
    "emanzipiertest": "emanzipieren",
    "emanzipierteste": "emanzipiert",
    "emanzipiertestem": "emanzipiert",
    "emanzipiertesten": "emanzipiert",
    "emanzipiertester": "emanzipiert",
    "emanzipiertestes": "emanzipiert",
    "emanzipiertet": "emanzipieren",
    "embryonalem": "embryonal",
    "embryonalen": "embryonal",
    "embryonaler": "embryonal",
    "embryonales": "embryonal",
    "emeritiere": "emeritieren",
    "emeritierend": "emeritieren",
    "emeritierende": "emeritierend",
    "emeritierendem": "emeritierend",
    "emeritierenden": "emeritierend",
    "emeritierender": "emeritierend",
    "emeritierendes": "emeritierend",
    "emeritierest": "emeritieren",
    "emeritieret": "emeritieren",
    "emeritierst": "emeritieren",
    "emeritiert": "emeritieren",
    "emeritierte": "emeritieren",
    "emeritiertem": "emeritiert",
    "emeritierten": "emeritieren",
    "emeritierter": "emeritiert",
    "emeritiertes": "emeritiert",
    "emeritiertest": "emeritieren",
    "emeritiertet": "emeritieren",
    "eminentem": "eminent",
    "eminenten": "eminent",
    "eminenter": "eminent",
    "eminentes": "eminent",
    "emotionalem": "emotional",
    "emotionalen": "emotional",
    "emotionaler": "emotional",
    "emotionalere": "emotional",
    "emotionalerem": "emotional",
    "emotionaleren": "emotional",
    "emotionalerer": "emotional",
    "emotionaleres": "emotional",
    "emotionales": "emotional",
    "emotionalisiere": "emotionalisieren",
    "emotionalisierend": "emotionalisieren",
    "emotionalisierende": "emotionalisierend",
    "emotionalisierendem": "emotionalisierend",
    "emotionalisierenden": "emotionalisierend",
    "emotionalisierender": "emotionalisierend",
    "emotionalisierendere": "emotionalisierend",
    "emotionalisierenderem": "emotionalisierend",
    "emotionalisierenderen": "emotionalisierend",
    "emotionalisierenderer": "emotionalisierend",
    "emotionalisierenderes": "emotionalisierend",
    "emotionalisierendes": "emotionalisierend",
    "emotionalisierendste": "emotionalisierend",
    "emotionalisierendstem": "emotionalisierend",
    "emotionalisierendsten": "emotionalisierend",
    "emotionalisierendster": "emotionalisierend",
    "emotionalisierendstes": "emotionalisierend",
    "emotionalisierest": "emotionalisieren",
    "emotionalisieret": "emotionalisieren",
    "emotionalisierst": "emotionalisieren",
    "emotionalisiert": "emotionalisieren",
    "emotionalisierte": "emotionalisieren",
    "emotionalisiertem": "emotionalisiert",
    "emotionalisierten": "emotionalisieren",
    "emotionalisierter": "emotionalisiert",
    "emotionalisiertere": "emotionalisiert",
    "emotionalisierterem": "emotionalisiert",
    "emotionalisierteren": "emotionalisiert",
    "emotionalisierterer": "emotionalisiert",
    "emotionalisierteres": "emotionalisiert",
    "emotionalisiertes": "emotionalisiert",
    "emotionalisiertest": "emotionalisieren",
    "emotionalisierteste": "emotionalisiert",
    "emotionalisiertestem": "emotionalisiert",
    "emotionalisiertesten": "emotionalisiert",
    "emotionalisiertester": "emotionalisiert",
    "emotionalisiertestes": "emotionalisiert",
    "emotionalisiertet": "emotionalisieren",
    "emotionalste": "emotional",
    "emotionalstem": "emotional",
    "emotionalsten": "emotional",
    "emotionalster": "emotional",
    "emotionalstes": "emotional",
    "emotionelle": "emotionell",
    "emotionellem": "emotionell",
    "emotionellen": "emotionell",
    "emotioneller": "emotionell",
    "emotionellere": "emotionell",
    "emotionellerem": "emotionell",
    "emotionelleren": "emotionell",
    "emotionellerer": "emotionell",
    "emotionelleres": "emotionell",
    "emotionelles": "emotionell",
    "emotionellste": "emotionell",
    "emotionellstem": "emotionell",
    "emotionellsten": "emotionell",
    "emotionellster": "emotionell",
    "emotionellstes": "emotionell",
    "emotionsfreiem": "emotionsfrei",
    "emotionsfreien": "emotionsfrei",
    "emotionsfreier": "emotionsfrei",
    "emotionsfreiere": "emotionsfrei",
    "emotionsfreierem": "emotionsfrei",
    "emotionsfreieren": "emotionsfrei",
    "emotionsfreierer": "emotionsfrei",
    "emotionsfreieres": "emotionsfrei",
    "emotionsfreies": "emotionsfrei",
    "emotionsfreiste": "emotionsfrei",
    "emotionsfreistem": "emotionsfrei",
    "emotionsfreisten": "emotionsfrei",
    "emotionsfreister": "emotionsfrei",
    "emotionsfreistes": "emotionsfrei",
    "emotionsgeladene": "emotionsgeladen",
    "emotionsgeladenem": "emotionsgeladen",
    "emotionsgeladenen": "emotionsgeladen",
    "emotionsgeladener": "emotionsgeladen",
    "emotionsgeladenere": "emotionsgeladen",
    "emotionsgeladenerem": "emotionsgeladen",
    "emotionsgeladeneren": "emotionsgeladen",
    "emotionsgeladenerer": "emotionsgeladen",
    "emotionsgeladeneres": "emotionsgeladen",
    "emotionsgeladenes": "emotionsgeladen",
    "emotionsgeladenste": "emotionsgeladen",
    "emotionsgeladenstem": "emotionsgeladen",
    "emotionsgeladensten": "emotionsgeladen",
    "emotionsgeladenster": "emotionsgeladen",
    "emotionsgeladenstes": "emotionsgeladen",
    "empfahl": "empfehlen",
    "empfahlen": "empfehlen",
    "empfahlst": "empfehlen",
    "empfahlt": "empfehlen",
    "empfand": "empfinden",
    "empfanden": "empfinden",
    "empfandest": "empfinden",
    "empfandet": "empfinden",
    "empfangend": "empfangen",
    "empfangende": "empfangend",
    "empfangendem": "empfangend",
    "empfangenden": "empfangend",
    "empfangender": "empfangend",
    "empfangendes": "empfangend",
    "empfangene": "empfangen",
    "empfangenem": "empfangen",
    "empfangenen": "empfangen",
    "empfangener": "empfangen",
    "empfangenes": "empfangen",
    "empfangest": "empfangen",
    "empfanget": "empfangen",
    "empfangsberechtigtem": "empfangsberechtigt",
    "empfangsberechtigten": "empfangsberechtigt",
    "empfangsberechtigter": "empfangsberechtigt",
    "empfangsberechtigtes": "empfangsberechtigt",
    "empfangt": "empfangen",
    "empfehle": "empfehlen",
    "empfehlend": "empfehlen",
    "empfehlende": "empfehlend",
    "empfehlendem": "empfehlend",
    "empfehlenden": "empfehlend",
    "empfehlender": "empfehlend",
    "empfehlendes": "empfehlend",
    "empfehlenswertem": "empfehlenswert",
    "empfehlenswerten": "empfehlenswert",
    "empfehlenswerter": "empfehlenswert",
    "empfehlenswertere": "empfehlenswert",
    "empfehlenswerterem": "empfehlenswert",
    "empfehlenswerteren": "empfehlenswert",
    "empfehlenswerterer": "empfehlenswert",
    "empfehlenswerteres": "empfehlenswert",
    "empfehlenswertes": "empfehlenswert",
    "empfehlenswerteste": "empfehlenswert",
    "empfehlenswertestem": "empfehlenswert",
    "empfehlenswertesten": "empfehlenswert",
    "empfehlenswertester": "empfehlenswert",
    "empfehlenswertestes": "empfehlenswert",
    "empfehlest": "empfehlen",
    "empfehlet": "empfehlen",
    "empfehlt": "empfehlen",
    "empfiehl": "empfehlen",
    "empfiehlst": "empfehlen",
    "empfiehlt": "empfehlen",
    "empfinde": "empfinden",
    "empfindend": "empfinden",
    "empfindende": "empfindend",
    "empfindendem": "empfindend",
    "empfindenden": "empfindend",
    "empfindender": "empfindend",
    "empfindendere": "empfindend",
    "empfindenderem": "empfindend",
    "empfindenderen": "empfindend",
    "empfindenderer": "empfindend",
    "empfindenderes": "empfindend",
    "empfindendes": "empfindend",
    "empfindendste": "empfindend",
    "empfindendstem": "empfindend",
    "empfindendsten": "empfindend",
    "empfindendster": "empfindend",
    "empfindendstes": "empfindend",
    "empfindest": "empfinden",
    "empfindet": "empfinden",
    "empfindliche": "empfindlich",
    "empfindlichem": "empfindlich",
    "empfindlichen": "empfindlich",
    "empfindlicher": "empfindlich",
    "empfindlichere": "empfindlich",
    "empfindlicherem": "empfindlich",
    "empfindlicheren": "empfindlich",
    "empfindlicherer": "empfindlich",
    "empfindlicheres": "empfindlich",
    "empfindliches": "empfindlich",
    "empfindlichstem": "empfindlich",
    "empfindlichsten": "empfindlich",
    "empfindlichster": "empfindlich",
    "empfindlichstes": "empfindlich",
    "empfindsame": "empfindsam",
    "empfindsamem": "empfindsam",
    "empfindsamen": "empfindsam",
    "empfindsamer": "empfindsam",
    "empfindsamere": "empfindsam",
    "empfindsamerem": "empfindsam",
    "empfindsameren": "empfindsam",
    "empfindsamerer": "empfindsam",
    "empfindsameres": "empfindsam",
    "empfindsames": "empfindsam",
    "empfindsamstem": "empfindsam",
    "empfindsamsten": "empfindsam",
    "empfindsamster": "empfindsam",
    "empfindsamstes": "empfindsam",
    "empfindungsfähigem": "empfindungsfähig",
    "empfindungsfähigen": "empfindungsfähig",
    "empfindungsfähiger": "empfindungsfähig",
    "empfindungsfähigere": "empfindungsfähig",
    "empfindungsfähigerem": "empfindungsfähig",
    "empfindungsfähigeren": "empfindungsfähig",
    "empfindungsfähigerer": "empfindungsfähig",
    "empfindungsfähigeres": "empfindungsfähig",
    "empfindungsfähiges": "empfindungsfähig",
    "empfindungsfähigste": "empfindungsfähig",
    "empfindungsfähigstem": "empfindungsfähig",
    "empfindungsfähigsten": "empfindungsfähig",
    "empfindungsfähigster": "empfindungsfähig",
    "empfindungsfähigstes": "empfindungsfähig",
    "empfindungslose": "empfindungslos",
    "empfindungslosem": "empfindungslos",
    "empfindungslosen": "empfindungslos",
    "empfindungsloser": "empfindungslos",
    "empfindungslosere": "empfindungslos",
    "empfindungsloserem": "empfindungslos",
    "empfindungsloseren": "empfindungslos",
    "empfindungsloserer": "empfindungslos",
    "empfindungsloseres": "empfindungslos",
    "empfindungsloses": "empfindungslos",
    "empfindungsloseste": "empfindungslos",
    "empfindungslosestem": "empfindungslos",
    "empfindungslosesten": "empfindungslos",
    "empfindungslosester": "empfindungslos",
    "empfindungslosestes": "empfindungslos",
    "empfing": "empfangen",
    "empfinge": "empfangen",
    "empfingen": "empfangen",
    "empfingest": "empfangen",
    "empfinget": "empfangen",
    "empfingst": "empfangen",
    "empfingt": "empfangen",
    "empfohlen": "empfehlen",
    "empfohlene": "empfohlen",
    "empfohlenem": "empfohlen",
    "empfohlenen": "empfohlen",
    "empfohlener": "empfohlen",
    "empfohlenes": "empfohlen",
    "empfunden": "empfinden",
    "empfundene": "empfunden",
    "empfundenem": "empfunden",
    "empfundenen": "empfunden",
    "empfundener": "empfunden",
    "empfundenes": "empfunden",
    "empfähle": "empfehlen",
    "empfählen": "empfehlen",
    "empfählest": "empfehlen",
    "empfählet": "empfehlen",
    "empfände": "empfinden",
    "empfänden": "empfinden",
    "empfändest": "empfinden",
    "empfändet": "empfinden",
    "empfängnisverhütendem": "empfängnisverhütend",
    "empfängnisverhütenden": "empfängnisverhütend",
    "empfängnisverhütender": "empfängnisverhütend",
    "empfängnisverhütendes": "empfängnisverhütend",
    "empfängst": "empfangen",
    "empfängt": "empfangen",
    "empirischem": "empirisch",
    "empirischen": "empirisch",
    "empirischer": "empirisch",
    "empirischere": "empirisch",
    "empirischerem": "empirisch",
    "empirischeren": "empirisch",
    "empirischerer": "empirisch",
    "empirischeres": "empirisch",
    "empirisches": "empirisch",
    "empirischste": "empirisch",
    "empirischstem": "empirisch",
    "empirischsten": "empirisch",
    "empirischster": "empirisch",
    "empirischstes": "empirisch",
    "emporarbeite": "emporarbeiten",
    "emporarbeitend": "emporarbeiten",
    "emporarbeitende": "emporarbeitend",
    "emporarbeitendem": "emporarbeitend",
    "emporarbeitenden": "emporarbeitend",
    "emporarbeitender": "emporarbeitend",
    "emporarbeitendere": "emporarbeitend",
    "emporarbeitenderem": "emporarbeitend",
    "emporarbeitenderen": "emporarbeitend",
    "emporarbeitenderer": "emporarbeitend",
    "emporarbeitenderes": "emporarbeitend",
    "emporarbeitendes": "emporarbeitend",
    "emporarbeitendste": "emporarbeitend",
    "emporarbeitendstem": "emporarbeitend",
    "emporarbeitendsten": "emporarbeitend",
    "emporarbeitendster": "emporarbeitend",
    "emporarbeitendstes": "emporarbeitend",
    "emporarbeitest": "emporarbeiten",
    "emporarbeitet": "emporarbeiten",
    "emporarbeitete": "emporarbeiten",
    "emporarbeiteten": "emporarbeiten",
    "emporarbeitetest": "emporarbeiten",
    "emporarbeitetet": "emporarbeiten",
    "empordrang": "empordringen",
    "empordrangen": "empordringen",
    "empordrangst": "empordringen",
    "empordrangt": "empordringen",
    "empordringe": "empordringen",
    "empordringend": "empordringen",
    "empordringende": "empordringend",
    "empordringendem": "empordringend",
    "empordringenden": "empordringend",
    "empordringender": "empordringend",
    "empordringendes": "empordringend",
    "empordringest": "empordringen",
    "empordringet": "empordringen",
    "empordringst": "empordringen",
    "empordringt": "empordringen",
    "empordränge": "empordringen",
    "empordrängen": "empordringen",
    "empordrängest": "empordringen",
    "empordränget": "empordringen",
    "emporfliege": "emporfliegen",
    "emporfliegend": "emporfliegen",
    "emporfliegende": "emporfliegend",
    "emporfliegendem": "emporfliegend",
    "emporfliegenden": "emporfliegend",
    "emporfliegender": "emporfliegend",
    "emporfliegendes": "emporfliegend",
    "emporfliegest": "emporfliegen",
    "emporflieget": "emporfliegen",
    "emporfliegst": "emporfliegen",
    "emporfliegt": "emporfliegen",
    "emporflog": "emporfliegen",
    "emporflogen": "emporfliegen",
    "emporflogst": "emporfliegen",
    "emporflogt": "emporfliegen",
    "emporflöge": "emporfliegen",
    "emporflögen": "emporfliegen",
    "emporflögest": "emporfliegen",
    "emporflöget": "emporfliegen",
    "emporgearbeitet": "emporarbeiten",
    "emporgearbeitete": "emporgearbeitet",
    "emporgearbeitetem": "emporgearbeitet",
    "emporgearbeiteten": "emporgearbeitet",
    "emporgearbeiteter": "emporgearbeitet",
    "emporgearbeitetere": "emporgearbeitet",
    "emporgearbeiteterem": "emporgearbeitet",
    "emporgearbeiteteren": "emporgearbeitet",
    "emporgearbeiteterer": "emporgearbeitet",
    "emporgearbeiteteres": "emporgearbeitet",
    "emporgearbeitetes": "emporgearbeitet",
    "emporgearbeiteteste": "emporgearbeitet",
    "emporgearbeitetestem": "emporgearbeitet",
    "emporgearbeitetesten": "emporgearbeitet",
    "emporgearbeitetester": "emporgearbeitet",
    "emporgearbeitetestes": "emporgearbeitet",
    "emporgedrungen": "empordringen",
    "emporgedrungene": "emporgedrungen",
    "emporgedrungenem": "emporgedrungen",
    "emporgedrungenen": "emporgedrungen",
    "emporgedrungener": "emporgedrungen",
    "emporgedrungenes": "emporgedrungen",
    "emporgeflogen": "emporfliegen",
    "emporgeflogene": "emporgeflogen",
    "emporgeflogenem": "emporgeflogen",
    "emporgeflogenen": "emporgeflogen",
    "emporgeflogener": "emporgeflogen",
    "emporgeflogenes": "emporgeflogen",
    "emporgehoben": "emporheben",
    "emporgehobene": "emporgehoben",
    "emporgehobenem": "emporgehoben",
    "emporgehobenen": "emporgehoben",
    "emporgehobener": "emporgehoben",
    "emporgehobenere": "emporgehoben",
    "emporgehobenerem": "emporgehoben",
    "emporgehobeneren": "emporgehoben",
    "emporgehobenerer": "emporgehoben",
    "emporgehobeneres": "emporgehoben",
    "emporgehobenes": "emporgehoben",
    "emporgehobenste": "emporgehoben",
    "emporgehobenstem": "emporgehoben",
    "emporgehobensten": "emporgehoben",
    "emporgehobenster": "emporgehoben",
    "emporgehobenstes": "emporgehoben",
    "emporgeholfen": "emporhelfen",
    "emporgeholfene": "emporgeholfen",
    "emporgeholfenem": "emporgeholfen",
    "emporgeholfenen": "emporgeholfen",
    "emporgeholfener": "emporgeholfen",
    "emporgeholfenes": "emporgeholfen",
    "emporgeragt": "emporragen",
    "emporgeragte": "emporgeragt",
    "emporgeragtem": "emporgeragt",
    "emporgeragten": "emporgeragt",
    "emporgeragter": "emporgeragt",
    "emporgeragtes": "emporgeragt",
    "emporgerichtet": "emporrichten",
    "emporgerichtete": "emporgerichtet",
    "emporgerichtetem": "emporgerichtet",
    "emporgerichteten": "emporgerichtet",
    "emporgerichteter": "emporgerichtet",
    "emporgerichtetes": "emporgerichtet",
    "emporgeschaut": "emporschauen",
    "emporgeschaute": "emporgeschaut",
    "emporgeschautem": "emporgeschaut",
    "emporgeschauten": "emporgeschaut",
    "emporgeschauter": "emporgeschaut",
    "emporgeschautes": "emporgeschaut",
    "emporgeschnellt": "emporschnellen",
    "emporgeschnellte": "emporgeschnellt",
    "emporgeschnelltem": "emporgeschnellt",
    "emporgeschnellten": "emporgeschnellt",
    "emporgeschnellter": "emporgeschnellt",
    "emporgeschnelltes": "emporgeschnellt",
    "emporgeschwebt": "emporschweben",
    "emporgeschwebte": "emporgeschwebt",
    "emporgeschwebtem": "emporgeschwebt",
    "emporgeschwebten": "emporgeschwebt",
    "emporgeschwebter": "emporgeschwebt",
    "emporgeschwebtes": "emporgeschwebt",
    "emporgeschwungen": "emporschwingen",
    "emporgeschwungene": "emporgeschwungen",
    "emporgeschwungenem": "emporgeschwungen",
    "emporgeschwungenen": "emporgeschwungen",
    "emporgeschwungener": "emporgeschwungen",
    "emporgeschwungenes": "emporgeschwungen",
    "emporgesprungen": "emporspringen",
    "emporgesprungene": "emporgesprungen",
    "emporgesprungenem": "emporgesprungen",
    "emporgesprungenen": "emporgesprungen",
    "emporgesprungener": "emporgesprungen",
    "emporgesprungenes": "emporgesprungen",
    "emporgestiegen": "emporsteigen",
    "emporgestiegene": "emporgestiegen",
    "emporgestiegenem": "emporgestiegen",
    "emporgestiegenen": "emporgestiegen",
    "emporgestiegener": "emporgestiegen",
    "emporgestiegenere": "emporgestiegen",
    "emporgestiegenerem": "emporgestiegen",
    "emporgestiegeneren": "emporgestiegen",
    "emporgestiegenerer": "emporgestiegen",
    "emporgestiegeneres": "emporgestiegen",
    "emporgestiegenes": "emporgestiegen",
    "emporgestiegenste": "emporgestiegen",
    "emporgestiegenstem": "emporgestiegen",
    "emporgestiegensten": "emporgestiegen",
    "emporgestiegenster": "emporgestiegen",
    "emporgestiegenstes": "emporgestiegen",
    "emporgestrebt": "emporstreben",
    "emporgestrebte": "emporgestrebt",
    "emporgestrebtem": "emporgestrebt",
    "emporgestrebten": "emporgestrebt",
    "emporgestrebter": "emporgestrebt",
    "emporgestrebtere": "emporgestrebt",
    "emporgestrebterem": "emporgestrebt",
    "emporgestrebteren": "emporgestrebt",
    "emporgestrebterer": "emporgestrebt",
    "emporgestrebteres": "emporgestrebt",
    "emporgestrebtes": "emporgestrebt",
    "emporgestrebteste": "emporgestrebt",
    "emporgestrebtestem": "emporgestrebt",
    "emporgestrebtesten": "emporgestrebt",
    "emporgestrebtester": "emporgestrebt",
    "emporgestrebtestes": "emporgestrebt",
    "emporgewunden": "emporwinden",
    "emporgewundene": "emporgewunden",
    "emporgewundenem": "emporgewunden",
    "emporgewundenen": "emporgewunden",
    "emporgewundener": "emporgewunden",
    "emporgewundenes": "emporgewunden",
    "emporhalf": "emporhelfen",
    "emporhalfen": "emporhelfen",
    "emporhalfst": "emporhelfen",
    "emporhalft": "emporhelfen",
    "emporhebe": "emporheben",
    "emporhebend": "emporheben",
    "emporhebende": "emporhebend",
    "emporhebendem": "emporhebend",
    "emporhebenden": "emporhebend",
    "emporhebender": "emporhebend",
    "emporhebendere": "emporhebend",
    "emporhebenderem": "emporhebend",
    "emporhebenderen": "emporhebend",
    "emporhebenderer": "emporhebend",
    "emporhebenderes": "emporhebend",
    "emporhebendes": "emporhebend",
    "emporhebendste": "emporhebend",
    "emporhebendstem": "emporhebend",
    "emporhebendsten": "emporhebend",
    "emporhebendster": "emporhebend",
    "emporhebendstes": "emporhebend",
    "emporhebest": "emporheben",
    "emporhebet": "emporheben",
    "emporhebst": "emporheben",
    "emporhebt": "emporheben",
    "emporhelfe": "emporhelfen",
    "emporhelfend": "emporhelfen",
    "emporhelfende": "emporhelfend",
    "emporhelfendem": "emporhelfend",
    "emporhelfenden": "emporhelfend",
    "emporhelfender": "emporhelfend",
    "emporhelfendes": "emporhelfend",
    "emporhelfest": "emporhelfen",
    "emporhelfet": "emporhelfen",
    "emporhelft": "emporhelfen",
    "emporhilfst": "emporhelfen",
    "emporhilft": "emporhelfen",
    "emporhob": "emporheben",
    "emporhoben": "emporheben",
    "emporhobst": "emporheben",
    "emporhobt": "emporheben",
    "emporhälfe": "emporhelfen",
    "emporhälfen": "emporhelfen",
    "emporhälfest": "emporhelfen",
    "emporhälfet": "emporhelfen",
    "emporhöbe": "emporheben",
    "emporhöben": "emporheben",
    "emporhöbest": "emporheben",
    "emporhöbet": "emporheben",
    "emporrage": "emporragen",
    "emporragend": "emporragen",
    "emporragende": "emporragend",
    "emporragendem": "emporragend",
    "emporragenden": "emporragend",
    "emporragender": "emporragend",
    "emporragendes": "emporragend",
    "emporragest": "emporragen",
    "emporraget": "emporragen",
    "emporragst": "emporragen",
    "emporragt": "emporragen",
    "emporragte": "emporragen",
    "emporragten": "emporragen",
    "emporragtest": "emporragen",
    "emporragtet": "emporragen",
    "emporrichte": "emporrichten",
    "emporrichtend": "emporrichten",
    "emporrichtende": "emporrichtend",
    "emporrichtendem": "emporrichtend",
    "emporrichtenden": "emporrichtend",
    "emporrichtender": "emporrichtend",
    "emporrichtendes": "emporrichtend",
    "emporrichtest": "emporrichten",
    "emporrichtet": "emporrichten",
    "emporrichtete": "emporrichten",
    "emporrichteten": "emporrichten",
    "emporrichtetest": "emporrichten",
    "emporrichtetet": "emporrichten",
    "emporschaue": "emporschauen",
    "emporschauend": "emporschauen",
    "emporschauende": "emporschauend",
    "emporschauendem": "emporschauend",
    "emporschauenden": "emporschauend",
    "emporschauender": "emporschauend",
    "emporschauendes": "emporschauend",
    "emporschauest": "emporschauen",
    "emporschauet": "emporschauen",
    "emporschaust": "emporschauen",
    "emporschaut": "emporschauen",
    "emporschaute": "emporschauen",
    "emporschauten": "emporschauen",
    "emporschautest": "emporschauen",
    "emporschautet": "emporschauen",
    "emporschnelle": "emporschnellen",
    "emporschnellend": "emporschnellen",
    "emporschnellende": "emporschnellend",
    "emporschnellendem": "emporschnellend",
    "emporschnellenden": "emporschnellend",
    "emporschnellender": "emporschnellend",
    "emporschnellendes": "emporschnellend",
    "emporschnellest": "emporschnellen",
    "emporschnellet": "emporschnellen",
    "emporschnellst": "emporschnellen",
    "emporschnellt": "emporschnellen",
    "emporschnellte": "emporschnellen",
    "emporschnellten": "emporschnellen",
    "emporschnelltest": "emporschnellen",
    "emporschnelltet": "emporschnellen",
    "emporschwang": "emporschwingen",
    "emporschwangen": "emporschwingen",
    "emporschwangst": "emporschwingen",
    "emporschwangt": "emporschwingen",
    "emporschwebe": "emporschweben",
    "emporschwebend": "emporschweben",
    "emporschwebende": "emporschwebend",
    "emporschwebendem": "emporschwebend",
    "emporschwebenden": "emporschwebend",
    "emporschwebender": "emporschwebend",
    "emporschwebendes": "emporschwebend",
    "emporschwebest": "emporschweben",
    "emporschwebet": "emporschweben",
    "emporschwebst": "emporschweben",
    "emporschwebt": "emporschweben",
    "emporschwebte": "emporschweben",
    "emporschwebten": "emporschweben",
    "emporschwebtest": "emporschweben",
    "emporschwebtet": "emporschweben",
    "emporschwinge": "emporschwingen",
    "emporschwingend": "emporschwingen",
    "emporschwingende": "emporschwingend",
    "emporschwingendem": "emporschwingend",
    "emporschwingenden": "emporschwingend",
    "emporschwingender": "emporschwingend",
    "emporschwingendes": "emporschwingend",
    "emporschwingest": "emporschwingen",
    "emporschwinget": "emporschwingen",
    "emporschwingst": "emporschwingen",
    "emporschwingt": "emporschwingen",
    "emporschwänge": "emporschwingen",
    "emporschwängen": "emporschwingen",
    "emporschwängest": "emporschwingen",
    "emporschwänget": "emporschwingen",
    "emporsprang": "emporspringen",
    "emporsprangen": "emporspringen",
    "emporsprangst": "emporspringen",
    "emporsprangt": "emporspringen",
    "emporspringe": "emporspringen",
    "emporspringend": "emporspringen",
    "emporspringende": "emporspringend",
    "emporspringendem": "emporspringend",
    "emporspringenden": "emporspringend",
    "emporspringender": "emporspringend",
    "emporspringendes": "emporspringend",
    "emporspringest": "emporspringen",
    "emporspringet": "emporspringen",
    "emporspringst": "emporspringen",
    "emporspringt": "emporspringen",
    "emporspränge": "emporspringen",
    "emporsprängen": "emporspringen",
    "emporsprängest": "emporspringen",
    "emporspränget": "emporspringen",
    "emporsteige": "emporsteigen",
    "emporsteigend": "emporsteigen",
    "emporsteigende": "emporsteigend",
    "emporsteigendem": "emporsteigend",
    "emporsteigenden": "emporsteigend",
    "emporsteigender": "emporsteigend",
    "emporsteigendere": "emporsteigend",
    "emporsteigenderem": "emporsteigend",
    "emporsteigenderen": "emporsteigend",
    "emporsteigenderer": "emporsteigend",
    "emporsteigenderes": "emporsteigend",
    "emporsteigendes": "emporsteigend",
    "emporsteigendste": "emporsteigend",
    "emporsteigendstem": "emporsteigend",
    "emporsteigendsten": "emporsteigend",
    "emporsteigendster": "emporsteigend",
    "emporsteigendstes": "emporsteigend",
    "emporsteigest": "emporsteigen",
    "emporsteiget": "emporsteigen",
    "emporsteigst": "emporsteigen",
    "emporsteigt": "emporsteigen",
    "emporstieg": "emporsteigen",
    "emporstiege": "emporsteigen",
    "emporstiegen": "emporsteigen",
    "emporstiegest": "emporsteigen",
    "emporstieget": "emporsteigen",
    "emporstiegst": "emporsteigen",
    "emporstiegt": "emporsteigen",
    "emporstrebe": "emporstreben",
    "emporstrebend": "emporstreben",
    "emporstrebende": "emporstrebend",
    "emporstrebendem": "emporstrebend",
    "emporstrebenden": "emporstrebend",
    "emporstrebender": "emporstrebend",
    "emporstrebendere": "emporstrebend",
    "emporstrebenderem": "emporstrebend",
    "emporstrebenderen": "emporstrebend",
    "emporstrebenderer": "emporstrebend",
    "emporstrebenderes": "emporstrebend",
    "emporstrebendes": "emporstrebend",
    "emporstrebendste": "emporstrebend",
    "emporstrebendstem": "emporstrebend",
    "emporstrebendsten": "emporstrebend",
    "emporstrebendster": "emporstrebend",
    "emporstrebendstes": "emporstrebend",
    "emporstrebest": "emporstreben",
    "emporstrebet": "emporstreben",
    "emporstrebst": "emporstreben",
    "emporstrebt": "emporstreben",
    "emporstrebte": "emporstreben",
    "emporstrebten": "emporstreben",
    "emporstrebtest": "emporstreben",
    "emporstrebtet": "emporstreben",
    "emporwand": "emporwinden",
    "emporwanden": "emporwinden",
    "emporwandest": "emporwinden",
    "emporwandet": "emporwinden",
    "emporwinde": "emporwinden",
    "emporwindend": "emporwinden",
    "emporwindende": "emporwindend",
    "emporwindendem": "emporwindend",
    "emporwindenden": "emporwindend",
    "emporwindender": "emporwindend",
    "emporwindendes": "emporwindend",
    "emporwindest": "emporwinden",
    "emporwindet": "emporwinden",
    "emporwände": "emporwinden",
    "emporwänden": "emporwinden",
    "emporwändest": "emporwinden",
    "emporwändet": "emporwinden",
    "emporzuarbeiten": "emporarbeiten",
    "emporzudringen": "empordringen",
    "emporzufliegen": "emporfliegen",
    "emporzuheben": "emporheben",
    "emporzuhelfen": "emporhelfen",
    "emporzuragen": "emporragen",
    "emporzurichten": "emporrichten",
    "emporzuschauen": "emporschauen",
    "emporzuschnellen": "emporschnellen",
    "emporzuschweben": "emporschweben",
    "emporzuschwingen": "emporschwingen",
    "emporzuspringen": "emporspringen",
    "emporzusteigen": "emporsteigen",
    "emporzustreben": "emporstreben",
    "emporzuwinden": "emporwinden",
    "empöre": "empören",
    "empörend": "empören",
    "empörende": "empörend",
    "empörendem": "empörend",
    "empörenden": "empörend",
    "empörender": "empörend",
    "empörendere": "empörend",
    "empörenderem": "empörend",
    "empörenderen": "empörend",
    "empörenderer": "empörend",
    "empörenderes": "empörend",
    "empörendes": "empörend",
    "empörendste": "empörend",
    "empörendstem": "empörend",
    "empörendsten": "empörend",
    "empörendster": "empörend",
    "empörendstes": "empörend",
    "empörest": "empören",
    "empöret": "empören",
    "empörst": "empören",
    "empört": "empören",
    "empörte": "empören",
    "empörtem": "empört",
    "empörten": "empören",
    "empörter": "empört",
    "empörtere": "empört",
    "empörterem": "empört",
    "empörteren": "empört",
    "empörterer": "empört",
    "empörteres": "empört",
    "empörtes": "empört",
    "empörtest": "empören",
    "empörteste": "empört",
    "empörtestem": "empört",
    "empörtesten": "empört",
    "empörtester": "empört",
    "empörtestes": "empört",
    "empörtet": "empören",
    "emsige": "emsig",
    "emsigem": "emsig",
    "emsigen": "emsig",
    "emsiger": "emsig",
    "emsigere": "emsig",
    "emsigerem": "emsig",
    "emsigeren": "emsig",
    "emsigerer": "emsig",
    "emsigeres": "emsig",
    "emsiges": "emsig",
    "emsigste": "emsig",
    "emsigstem": "emsig",
    "emsigsten": "emsig",
    "emsigster": "emsig",
    "emsigstes": "emsig",
    "emulgiere": "emulgieren",
    "emulgierend": "emulgieren",
    "emulgierende": "emulgierend",
    "emulgierendem": "emulgierend",
    "emulgierenden": "emulgierend",
    "emulgierender": "emulgierend",
    "emulgierendes": "emulgierend",
    "emulgierest": "emulgieren",
    "emulgieret": "emulgieren",
    "emulgierst": "emulgieren",
    "emulgiert": "emulgieren",
    "emulgierte": "emulgieren",
    "emulgiertem": "emulgiert",
    "emulgierten": "emulgieren",
    "emulgierter": "emulgiert",
    "emulgiertes": "emulgiert",
    "emulgiertest": "emulgieren",
    "emulgiertet": "emulgieren",
    "endend": "enden",
    "endende": "endend",
    "endendem": "endend",
    "endenden": "endend",
    "endender": "endend",
    "endendes": "endend",
    "endest": "enden",
    "endet": "enden",
    "endete": "enden",
    "endeten": "enden",
    "endetest": "enden",
    "endetet": "enden",
    "endgültige": "endgültig",
    "endgültigem": "endgültig",
    "endgültigen": "endgültig",
    "endgültiger": "endgültig",
    "endgültiges": "endgültig",
    "endlichem": "endlich",
    "endlichen": "endlich",
    "endlicher": "endlich",
    "endliches": "endlich",
    "endlose": "endlos",
    "endlosem": "endlos",
    "endlosen": "endlos",
    "endloser": "endlos",
    "endlosere": "endlos",
    "endloserem": "endlos",
    "endloseren": "endlos",
    "endloserer": "endlos",
    "endloseres": "endlos",
    "endloses": "endlos",
    "endloseste": "endlos",
    "endlosestem": "endlos",
    "endlosesten": "endlos",
    "endlosester": "endlos",
    "endlosestes": "endlos",
    "energiereichem": "energiereich",
    "energiereichen": "energiereich",
    "energiereicher": "energiereich",
    "energiereichere": "energiereich",
    "energiereicherem": "energiereich",
    "energiereicheren": "energiereich",
    "energiereicherer": "energiereich",
    "energiereicheres": "energiereich",
    "energiereiches": "energiereich",
    "energiereichste": "energiereich",
    "energiereichstem": "energiereich",
    "energiereichsten": "energiereich",
    "energiereichster": "energiereich",
    "energiereichstes": "energiereich",
    "energische": "energisch",
    "energischem": "energisch",
    "energischen": "energisch",
    "energischer": "energisch",
    "energischere": "energisch",
    "energischerem": "energisch",
    "energischeren": "energisch",
    "energischerer": "energisch",
    "energischeres": "energisch",
    "energisches": "energisch",
    "energischste": "energisch",
    "energischstem": "energisch",
    "energischsten": "energisch",
    "energischster": "energisch",
    "energischstes": "energisch",
    "eng": "engen",
    "engagiere": "engagieren",
    "engagierend": "engagieren",
    "engagierende": "engagierend",
    "engagierendem": "engagierend",
    "engagierenden": "engagierend",
    "engagierender": "engagierend",
    "engagierendes": "engagierend",
    "engagierest": "engagieren",
    "engagieret": "engagieren",
    "engagierst": "engagieren",
    "engagiert": "engagieren",
    "engagierte": "engagieren",
    "engagiertem": "engagiert",
    "engagierten": "engagieren",
    "engagierter": "engagiert",
    "engagiertere": "engagiert",
    "engagierterem": "engagiert",
    "engagierteren": "engagiert",
    "engagierterer": "engagiert",
    "engagierteres": "engagiert",
    "engagiertes": "engagiert",
    "engagiertest": "engagieren",
    "engagierteste": "engagiert",
    "engagiertestem": "engagiert",
    "engagiertesten": "engagiert",
    "engagiertester": "engagiert",
    "engagiertestes": "engagiert",
    "engagiertet": "engagieren",
    "engbrüstige": "engbrüstig",
    "engbrüstigem": "engbrüstig",
    "engbrüstigen": "engbrüstig",
    "engbrüstiger": "engbrüstig",
    "engbrüstigere": "engbrüstig",
    "engbrüstigerem": "engbrüstig",
    "engbrüstigeren": "engbrüstig",
    "engbrüstigerer": "engbrüstig",
    "engbrüstigeres": "engbrüstig",
    "engbrüstiges": "engbrüstig",
    "engbrüstigste": "engbrüstig",
    "engbrüstigstem": "engbrüstig",
    "engbrüstigsten": "engbrüstig",
    "engbrüstigster": "engbrüstig",
    "engbrüstigstes": "engbrüstig",
    "enge": "eng",
    "engem": "eng",
    "engen": "eng",
    "engend": "engen",
    "engende": "engend",
    "engendem": "engend",
    "engenden": "engend",
    "engender": "engend",
    "engendere": "engend",
    "engenderem": "engend",
    "engenderen": "engend",
    "engenderer": "engend",
    "engenderes": "engend",
    "engendes": "engend",
    "engendste": "engend",
    "engendstem": "engend",
    "engendsten": "engend",
    "engendster": "engend",
    "engendstes": "engend",
    "enger": "eng",
    "engere": "eng",
    "engerem": "eng",
    "engeren": "eng",
    "engerer": "eng",
    "engeres": "eng",
    "enges": "eng",
    "engest": "engen",
    "enget": "engen",
    "enggesetzt": "engsetzen",
    "enggesetzte": "enggesetzt",
    "enggesetztem": "enggesetzt",
    "enggesetzten": "enggesetzt",
    "enggesetzter": "enggesetzt",
    "enggesetztere": "enggesetzt",
    "enggesetzterem": "enggesetzt",
    "enggesetzteren": "enggesetzt",
    "enggesetzterer": "enggesetzt",
    "enggesetzteres": "enggesetzt",
    "enggesetztes": "enggesetzt",
    "enggesetzteste": "enggesetzt",
    "enggesetztestem": "enggesetzt",
    "enggesetztesten": "enggesetzt",
    "enggesetztester": "enggesetzt",
    "enggesetztestes": "enggesetzt",
    "engherzige": "engherzig",
    "engherzigem": "engherzig",
    "engherzigen": "engherzig",
    "engherziger": "engherzig",
    "engherzigere": "engherzig",
    "engherzigerem": "engherzig",
    "engherzigeren": "engherzig",
    "engherzigerer": "engherzig",
    "engherzigeres": "engherzig",
    "engherziges": "engherzig",
    "engherzigste": "engherzig",
    "engherzigstem": "engherzig",
    "engherzigsten": "engherzig",
    "engherzigster": "engherzig",
    "engherzigstes": "engherzig",
    "englischem": "englisch",
    "englischen": "englisch",
    "englischer": "englisch",
    "englischere": "englisch",
    "englischerem": "englisch",
    "englischeren": "englisch",
    "englischerer": "englisch",
    "englischeres": "englisch",
    "englisches": "englisch",
    "englischsprachigem": "englischsprachig",
    "englischsprachigen": "englischsprachig",
    "englischsprachiger": "englischsprachig",
    "englischsprachiges": "englischsprachig",
    "englischste": "englisch",
    "englischstem": "englisch",
    "englischsten": "englisch",
    "englischster": "englisch",
    "englischstes": "englisch",
    "engmaschige": "engmaschig",
    "engmaschigem": "engmaschig",
    "engmaschigen": "engmaschig",
    "engmaschiger": "engmaschig",
    "engmaschigere": "engmaschig",
    "engmaschigerem": "engmaschig",
    "engmaschigeren": "engmaschig",
    "engmaschigerer": "engmaschig",
    "engmaschigeres": "engmaschig",
    "engmaschiges": "engmaschig",
    "engmaschigste": "engmaschig",
    "engmaschigstem": "engmaschig",
    "engmaschigsten": "engmaschig",
    "engmaschigster": "engmaschig",
    "engmaschigstes": "engmaschig",
    "engsetze": "engsetzen",
    "engsetzend": "engsetzen",
    "engsetzende": "engsetzend",
    "engsetzendem": "engsetzend",
    "engsetzenden": "engsetzend",
    "engsetzender": "engsetzend",
    "engsetzendes": "engsetzend",
    "engsetzest": "engsetzen",
    "engsetzet": "engsetzen",
    "engsetzt": "engsetzen",
    "engsetzte": "engsetzen",
    "engsetzten": "engsetzen",
    "engsetztest": "engsetzen",
    "engsetztet": "engsetzen",
    "engst": "engen",
    "engste": "eng",
    "engstem": "eng",
    "engsten": "eng",
    "engster": "eng",
    "engstes": "eng",
    "engstirnige": "engstirnig",
    "engstirnigem": "engstirnig",
    "engstirnigen": "engstirnig",
    "engstirniger": "engstirnig",
    "engstirnigere": "engstirnig",
    "engstirnigerem": "engstirnig",
    "engstirnigeren": "engstirnig",
    "engstirnigerer": "engstirnig",
    "engstirnigeres": "engstirnig",
    "engstirniges": "engstirnig",
    "engstirnigste": "engstirnig",
    "engstirnigstem": "engstirnig",
    "engstirnigsten": "engstirnig",
    "engstirnigster": "engstirnig",
    "engstirnigstes": "engstirnig",
    "engt": "engen",
    "engte": "engen",
    "engten": "engen",
    "engtest": "engen",
    "engtet": "engen",
    "engzeilige": "engzeilig",
    "engzeiligem": "engzeilig",
    "engzeiligen": "engzeilig",
    "engzeiliger": "engzeilig",
    "engzeiligere": "engzeilig",
    "engzeiligerem": "engzeilig",
    "engzeiligeren": "engzeilig",
    "engzeiligerer": "engzeilig",
    "engzeiligeres": "engzeilig",
    "engzeiliges": "engzeilig",
    "engzeiligste": "engzeilig",
    "engzeiligstem": "engzeilig",
    "engzeiligsten": "engzeilig",
    "engzeiligster": "engzeilig",
    "engzeiligstes": "engzeilig",
    "engzusetzen": "engsetzen",
    "enormem": "enorm",
    "enormen": "enorm",
    "enormer": "enorm",
    "enormere": "enorm",
    "enormerem": "enorm",
    "enormeren": "enorm",
    "enormerer": "enorm",
    "enormeres": "enorm",
    "enormes": "enorm",
    "enormste": "enorm",
    "enormstem": "enorm",
    "enormsten": "enorm",
    "enormster": "enorm",
    "enormstes": "enorm",
    "entalkoholisiere": "entalkoholisieren",
    "entalkoholisierend": "entalkoholisieren",
    "entalkoholisierende": "entalkoholisierend",
    "entalkoholisierendem": "entalkoholisierend",
    "entalkoholisierenden": "entalkoholisierend",
    "entalkoholisierender": "entalkoholisierend",
    "entalkoholisierendes": "entalkoholisierend",
    "entalkoholisierest": "entalkoholisieren",
    "entalkoholisieret": "entalkoholisieren",
    "entalkoholisierst": "entalkoholisieren",
    "entalkoholisiert": "entalkoholisieren",
    "entalkoholisierte": "entalkoholisieren",
    "entalkoholisiertem": "entalkoholisiert",
    "entalkoholisierten": "entalkoholisieren",
    "entalkoholisierter": "entalkoholisiert",
    "entalkoholisiertes": "entalkoholisiert",
    "entalkoholisiertest": "entalkoholisieren",
    "entalkoholisiertet": "entalkoholisieren",
    "entarte": "entarten",
    "entartend": "entarten",
    "entartende": "entartend",
    "entartendem": "entartend",
    "entartenden": "entartend",
    "entartender": "entartend",
    "entartendere": "entartend",
    "entartenderem": "entartend",
    "entartenderen": "entartend",
    "entartenderer": "entartend",
    "entartenderes": "entartend",
    "entartendes": "entartend",
    "entartendste": "entartend",
    "entartendstem": "entartend",
    "entartendsten": "entartend",
    "entartendster": "entartend",
    "entartendstes": "entartend",
    "entartest": "entarten",
    "entartet": "entarten",
    "entartete": "entarten",
    "entartetem": "entartet",
    "entarteten": "entarten",
    "entarteter": "entartet",
    "entartetere": "entartet",
    "entarteterem": "entartet",
    "entarteteren": "entartet",
    "entarteterer": "entartet",
    "entarteteres": "entartet",
    "entartetes": "entartet",
    "entartetest": "entarten",
    "entarteteste": "entartet",
    "entartetestem": "entartet",
    "entartetesten": "entartet",
    "entartetester": "entartet",
    "entartetestes": "entartet",
    "entartetet": "entarten",
    "entautomatisiere": "entautomatisieren",
    "entautomatisierend": "entautomatisieren",
    "entautomatisierende": "entautomatisierend",
    "entautomatisierendem": "entautomatisierend",
    "entautomatisierenden": "entautomatisierend",
    "entautomatisierender": "entautomatisierend",
    "entautomatisierendes": "entautomatisierend",
    "entautomatisierest": "entautomatisieren",
    "entautomatisieret": "entautomatisieren",
    "entautomatisierst": "entautomatisieren",
    "entautomatisiert": "entautomatisieren",
    "entautomatisierte": "entautomatisieren",
    "entautomatisiertem": "entautomatisiert",
    "entautomatisierten": "entautomatisieren",
    "entautomatisierter": "entautomatisiert",
    "entautomatisiertes": "entautomatisiert",
    "entautomatisiertest": "entautomatisieren",
    "entautomatisiertet": "entautomatisieren",
    "entbalkanisiere": "entbalkanisieren",
    "entbalkanisierend": "entbalkanisieren",
    "entbalkanisierende": "entbalkanisierend",
    "entbalkanisierendem": "entbalkanisierend",
    "entbalkanisierenden": "entbalkanisierend",
    "entbalkanisierender": "entbalkanisierend",
    "entbalkanisierendes": "entbalkanisierend",
    "entbalkanisierest": "entbalkanisieren",
    "entbalkanisieret": "entbalkanisieren",
    "entbalkanisierst": "entbalkanisieren",
    "entbalkanisiert": "entbalkanisieren",
    "entbalkanisierte": "entbalkanisieren",
    "entbalkanisiertem": "entbalkanisiert",
    "entbalkanisierten": "entbalkanisieren",
    "entbalkanisierter": "entbalkanisiert",
    "entbalkanisiertes": "entbalkanisiert",
    "entbalkanisiertest": "entbalkanisieren",
    "entbalkanisiertet": "entbalkanisieren",
    "entband": "entbinden",
    "entbanden": "entbinden",
    "entbandest": "entbinden",
    "entbandet": "entbinden",
    "entbehre": "entbehren",
    "entbehrend": "entbehren",
    "entbehrende": "entbehrend",
    "entbehrendem": "entbehrend",
    "entbehrenden": "entbehrend",
    "entbehrender": "entbehrend",
    "entbehrendes": "entbehrend",
    "entbehrest": "entbehren",
    "entbehret": "entbehren",
    "entbehrliche": "entbehrlich",
    "entbehrlichem": "entbehrlich",
    "entbehrlichen": "entbehrlich",
    "entbehrlicher": "entbehrlich",
    "entbehrlichere": "entbehrlich",
    "entbehrlicherem": "entbehrlich",
    "entbehrlicheren": "entbehrlich",
    "entbehrlicherer": "entbehrlich",
    "entbehrlicheres": "entbehrlich",
    "entbehrliches": "entbehrlich",
    "entbehrlichste": "entbehrlich",
    "entbehrlichstem": "entbehrlich",
    "entbehrlichsten": "entbehrlich",
    "entbehrlichster": "entbehrlich",
    "entbehrlichstes": "entbehrlich",
    "entbehrst": "entbehren",
    "entbehrt": "entbehren",
    "entbehrte": "entbehren",
    "entbehrtem": "entbehrt",
    "entbehrten": "entbehren",
    "entbehrter": "entbehrt",
    "entbehrtes": "entbehrt",
    "entbehrtest": "entbehren",
    "entbehrtet": "entbehren",
    "entbinde": "entbinden",
    "entbindend": "entbinden",
    "entbindende": "entbindend",
    "entbindendem": "entbindend",
    "entbindenden": "entbindend",
    "entbindender": "entbindend",
    "entbindendes": "entbindend",
    "entbindest": "entbinden",
    "entbindet": "entbinden",
    "entblättere": "entblättern",
    "entblätternd": "entblättern",
    "entblätternde": "entblätternd",
    "entblätterndem": "entblätternd",
    "entblätternden": "entblätternd",
    "entblätternder": "entblätternd",
    "entblätterndes": "entblätternd",
    "entblätterst": "entblättern",
    "entblättert": "entblättern",
    "entblätterte": "entblättern",
    "entblättertem": "entblättert",
    "entblätterten": "entblättern",
    "entblätterter": "entblättert",
    "entblättertes": "entblättert",
    "entblättertest": "entblättern",
    "entblättertet": "entblättern",
    "entblöße": "entblößen",
    "entblößend": "entblößen",
    "entblößende": "entblößend",
    "entblößendem": "entblößend",
    "entblößenden": "entblößend",
    "entblößender": "entblößend",
    "entblößendere": "entblößend",
    "entblößenderem": "entblößend",
    "entblößenderen": "entblößend",
    "entblößenderer": "entblößend",
    "entblößenderes": "entblößend",
    "entblößendes": "entblößend",
    "entblößendste": "entblößend",
    "entblößendstem": "entblößend",
    "entblößendsten": "entblößend",
    "entblößendster": "entblößend",
    "entblößendstes": "entblößend",
    "entblößest": "entblößen",
    "entblößet": "entblößen",
    "entblößt": "entblößen",
    "entblößte": "entblößen",
    "entblößtem": "entblößt",
    "entblößten": "entblößen",
    "entblößter": "entblößt",
    "entblößtere": "entblößt",
    "entblößterem": "entblößt",
    "entblößteren": "entblößt",
    "entblößterer": "entblößt",
    "entblößteres": "entblößt",
    "entblößtes": "entblößt",
    "entblößtest": "entblößen",
    "entblößteste": "entblößt",
    "entblößtestem": "entblößt",
    "entblößtesten": "entblößt",
    "entblößtester": "entblößt",
    "entblößtestes": "entblößt",
    "entblößtet": "entblößen",
    "entbrannt": "entbrennen",
    "entbrannte": "entbrannt",
    "entbranntem": "entbrannt",
    "entbrannten": "entbrannt",
    "entbrannter": "entbrannt",
    "entbranntes": "entbrannt",
    "entbranntest": "entbrennen",
    "entbranntet": "entbrennen",
    "entbrenne": "entbrennen",
    "entbrennend": "entbrennen",
    "entbrennende": "entbrennend",
    "entbrennendem": "entbrennend",
    "entbrennenden": "entbrennend",
    "entbrennender": "entbrennend",
    "entbrennendes": "entbrennend",
    "entbrennest": "entbrennen",
    "entbrennet": "entbrennen",
    "entbrennst": "entbrennen",
    "entbrennt": "entbrennen",
    "entbunden": "entbinden",
    "entbundene": "entbunden",
    "entbundenem": "entbunden",
    "entbundenen": "entbunden",
    "entbundener": "entbunden",
    "entbundenes": "entbunden",
    "entbände": "entbinden",
    "entbänden": "entbinden",
    "entbändest": "entbinden",
    "entbändet": "entbinden",
    "entbürokratisieren": "entbürokratisiere",
    "entbürokratisierend": "entbürokratisiere",
    "entbürokratisierende": "entbürokratisierend",
    "entbürokratisierendem": "entbürokratisierend",
    "entbürokratisierenden": "entbürokratisierend",
    "entbürokratisierender": "entbürokratisierend",
    "entbürokratisierendere": "entbürokratisierend",
    "entbürokratisierenderem": "entbürokratisierend",
    "entbürokratisierenderen": "entbürokratisierend",
    "entbürokratisierenderer": "entbürokratisierend",
    "entbürokratisierenderes": "entbürokratisierend",
    "entbürokratisierendes": "entbürokratisierend",
    "entbürokratisierendste": "entbürokratisierend",
    "entbürokratisierendstem": "entbürokratisierend",
    "entbürokratisierendsten": "entbürokratisierend",
    "entbürokratisierendster": "entbürokratisierend",
    "entbürokratisierendstes": "entbürokratisierend",
    "entbürokratisierest": "entbürokratisiere",
    "entbürokratisieret": "entbürokratisiere",
    "entbürokratisierst": "entbürokratisiere",
    "entbürokratisiert": "entbürokratisiere",
    "entbürokratisierte": "entbürokratisiere",
    "entbürokratisiertem": "entbürokratisiert",
    "entbürokratisierten": "entbürokratisiere",
    "entbürokratisierter": "entbürokratisiert",
    "entbürokratisiertere": "entbürokratisiert",
    "entbürokratisierterem": "entbürokratisiert",
    "entbürokratisierteren": "entbürokratisiert",
    "entbürokratisierterer": "entbürokratisiert",
    "entbürokratisierteres": "entbürokratisiert",
    "entbürokratisiertes": "entbürokratisiert",
    "entbürokratisiertest": "entbürokratisiere",
    "entbürokratisierteste": "entbürokratisiert",
    "entbürokratisiertestem": "entbürokratisiert",
    "entbürokratisiertesten": "entbürokratisiert",
    "entbürokratisiertester": "entbürokratisiert",
    "entbürokratisiertestes": "entbürokratisiert",
    "entbürokratisiertet": "entbürokratisiere",
    "entcarbonisiere": "entcarbonisieren",
    "entcarbonisierend": "entcarbonisieren",
    "entcarbonisierende": "entcarbonisierend",
    "entcarbonisierendem": "entcarbonisierend",
    "entcarbonisierenden": "entcarbonisierend",
    "entcarbonisierender": "entcarbonisierend",
    "entcarbonisierendere": "entcarbonisierend",
    "entcarbonisierenderem": "entcarbonisierend",
    "entcarbonisierenderen": "entcarbonisierend",
    "entcarbonisierenderer": "entcarbonisierend",
    "entcarbonisierenderes": "entcarbonisierend",
    "entcarbonisierendes": "entcarbonisierend",
    "entcarbonisierendste": "entcarbonisierend",
    "entcarbonisierendstem": "entcarbonisierend",
    "entcarbonisierendsten": "entcarbonisierend",
    "entcarbonisierendster": "entcarbonisierend",
    "entcarbonisierendstes": "entcarbonisierend",
    "entcarbonisierest": "entcarbonisieren",
    "entcarbonisieret": "entcarbonisieren",
    "entcarbonisierst": "entcarbonisieren",
    "entcarbonisiert": "entcarbonisieren",
    "entcarbonisierte": "entcarbonisieren",
    "entcarbonisiertem": "entcarbonisiert",
    "entcarbonisierten": "entcarbonisieren",
    "entcarbonisierter": "entcarbonisiert",
    "entcarbonisiertere": "entcarbonisiert",
    "entcarbonisierterem": "entcarbonisiert",
    "entcarbonisierteren": "entcarbonisiert",
    "entcarbonisierterer": "entcarbonisiert",
    "entcarbonisierteres": "entcarbonisiert",
    "entcarbonisiertes": "entcarbonisiert",
    "entcarbonisiertest": "entcarbonisieren",
    "entcarbonisierteste": "entcarbonisiert",
    "entcarbonisiertestem": "entcarbonisiert",
    "entcarbonisiertesten": "entcarbonisiert",
    "entcarbonisiertester": "entcarbonisiert",
    "entcarbonisiertestes": "entcarbonisiert",
    "entcarbonisiertet": "entcarbonisieren",
    "entdecke": "entdecken",
    "entdeckend": "entdecken",
    "entdeckende": "entdeckend",
    "entdeckendem": "entdeckend",
    "entdeckenden": "entdeckend",
    "entdeckender": "entdeckend",
    "entdeckendes": "entdeckend",
    "entdeckest": "entdecken",
    "entdecket": "entdecken",
    "entdeckst": "entdecken",
    "entdeckt": "entdecken",
    "entdeckte": "entdecken",
    "entdecktem": "entdeckt",
    "entdeckten": "entdecken",
    "entdeckter": "entdeckt",
    "entdecktes": "entdeckt",
    "entdecktest": "entdecken",
    "entdecktet": "entdecken",
    "entehre": "entehren",
    "entehrend": "entehren",
    "entehrende": "entehrend",
    "entehrendem": "entehrend",
    "entehrenden": "entehrend",
    "entehrender": "entehrend",
    "entehrendes": "entehrend",
    "entehrest": "entehren",
    "entehret": "entehren",
    "entehrst": "entehren",
    "entehrt": "entehren",
    "entehrte": "entehren",
    "entehrtem": "entehrt",
    "entehrten": "entehren",
    "entehrter": "entehrt",
    "entehrtere": "entehrt",
    "entehrterem": "entehrt",
    "entehrteren": "entehrt",
    "entehrterer": "entehrt",
    "entehrteres": "entehrt",
    "entehrtes": "entehrt",
    "entehrtest": "entehren",
    "entehrteste": "entehrt",
    "entehrtestem": "entehrt",
    "entehrtesten": "entehrt",
    "entehrtester": "entehrt",
    "entehrtestes": "entehrt",
    "entehrtet": "entehren",
    "enteigne": "enteignen",
    "enteignend": "enteignen",
    "enteignende": "enteignend",
    "enteignendem": "enteignend",
    "enteignenden": "enteignend",
    "enteignender": "enteignend",
    "enteignendes": "enteignend",
    "enteignest": "enteignen",
    "enteignet": "enteignen",
    "enteignete": "enteignen",
    "enteignetem": "enteignet",
    "enteigneten": "enteignen",
    "enteigneter": "enteignet",
    "enteignetes": "enteignet",
    "enteignetest": "enteignen",
    "enteignetet": "enteignen",
    "enteile": "enteilen",
    "enteilend": "enteilen",
    "enteilende": "enteilend",
    "enteilendem": "enteilend",
    "enteilenden": "enteilend",
    "enteilender": "enteilend",
    "enteilendes": "enteilend",
    "enteilest": "enteilen",
    "enteilet": "enteilen",
    "enteilst": "enteilen",
    "enteilt": "enteilen",
    "enteilte": "enteilen",
    "enteiltem": "enteilt",
    "enteilten": "enteilen",
    "enteilter": "enteilt",
    "enteiltes": "enteilt",
    "enteiltest": "enteilen",
    "enteiltet": "enteilen",
    "enteise": "enteisen",
    "enteisend": "enteisen",
    "enteisende": "enteisend",
    "enteisendem": "enteisend",
    "enteisenden": "enteisend",
    "enteisender": "enteisend",
    "enteisendes": "enteisend",
    "enteisentem": "enteisent",
    "enteisenten": "enteisent",
    "enteisenter": "enteisent",
    "enteisentes": "enteisent",
    "enteisest": "enteisen",
    "enteiset": "enteisen",
    "enteist": "enteisen",
    "enteiste": "enteisen",
    "enteistem": "enteist",
    "enteisten": "enteisen",
    "enteister": "enteist",
    "enteistes": "enteist",
    "enteistest": "enteisen",
    "enteistet": "enteisen",
    "enterbe": "enterben",
    "enterbend": "enterben",
    "enterbende": "enterbend",
    "enterbendem": "enterbend",
    "enterbenden": "enterbend",
    "enterbender": "enterbend",
    "enterbendes": "enterbend",
    "enterbest": "enterben",
    "enterbet": "enterben",
    "enterbst": "enterben",
    "enterbt": "enterben",
    "enterbte": "enterben",
    "enterbtem": "enterbt",
    "enterbten": "enterben",
    "enterbter": "enterbt",
    "enterbtes": "enterbt",
    "enterbtest": "enterben",
    "enterbtet": "enterben",
    "entfache": "entfachen",
    "entfachend": "entfachen",
    "entfachende": "entfachend",
    "entfachendem": "entfachend",
    "entfachenden": "entfachend",
    "entfachender": "entfachend",
    "entfachendes": "entfachend",
    "entfachest": "entfachen",
    "entfachet": "entfachen",
    "entfachst": "entfachen",
    "entfacht": "entfachen",
    "entfachte": "entfachen",
    "entfachtem": "entfacht",
    "entfachten": "entfachen",
    "entfachter": "entfacht",
    "entfachtes": "entfacht",
    "entfachtest": "entfachen",
    "entfachtet": "entfachen",
    "entfalle": "entfallen",
    "entfallend": "entfallen",
    "entfallende": "entfallend",
    "entfallendem": "entfallend",
    "entfallenden": "entfallend",
    "entfallender": "entfallend",
    "entfallendes": "entfallend",
    "entfallene": "entfallen",
    "entfallenem": "entfallen",
    "entfallenen": "entfallen",
    "entfallener": "entfallen",
    "entfallenere": "entfallen",
    "entfallenerem": "entfallen",
    "entfalleneren": "entfallen",
    "entfallenerer": "entfallen",
    "entfalleneres": "entfallen",
    "entfallenes": "entfallen",
    "entfallenstem": "entfallen",
    "entfallensten": "entfallen",
    "entfallenster": "entfallen",
    "entfallenstes": "entfallen",
    "entfallest": "entfallen",
    "entfallet": "entfallen",
    "entfallt": "entfallen",
    "entfalte": "entfalten",
    "entfaltend": "entfalten",
    "entfaltende": "entfaltend",
    "entfaltendem": "entfaltend",
    "entfaltenden": "entfaltend",
    "entfaltender": "entfaltend",
    "entfaltendes": "entfaltend",
    "entfaltest": "entfalten",
    "entfaltet": "entfalten",
    "entfaltete": "entfalten",
    "entfaltetem": "entfaltet",
    "entfalteten": "entfalten",
    "entfalteter": "entfaltet",
    "entfaltetes": "entfaltet",
    "entfaltetest": "entfalten",
    "entfaltetet": "entfalten",
    "entferne": "entfernen",
    "entfernend": "entfernen",
    "entfernende": "entfernend",
    "entfernendem": "entfernend",
    "entfernenden": "entfernend",
    "entfernender": "entfernend",
    "entfernendes": "entfernend",
    "entfernest": "entfernen",
    "entfernet": "entfernen",
    "entfernst": "entfernen",
    "entfernt": "entfernen",
    "entfernte": "entfernen",
    "entferntem": "entfernt",
    "entfernten": "entfernen",
    "entfernter": "entfernt",
    "entferntere": "entfernt",
    "entfernterem": "entfernt",
    "entfernteren": "entfernt",
    "entfernterer": "entfernt",
    "entfernteres": "entfernt",
    "entferntes": "entfernt",
    "entferntest": "entfernen",
    "entfernteste": "entfernt",
    "entferntestem": "entfernt",
    "entferntesten": "entfernt",
    "entferntester": "entfernt",
    "entferntestes": "entfernt",
    "entferntet": "entfernen",
    "entfessele": "entfesseln",
    "entfesselnd": "entfesseln",
    "entfesselnde": "entfesselnd",
    "entfesselndem": "entfesselnd",
    "entfesselnden": "entfesselnd",
    "entfesselnder": "entfesselnd",
    "entfesselndere": "entfesselnd",
    "entfesselnderem": "entfesselnd",
    "entfesselnderen": "entfesselnd",
    "entfesselnderer": "entfesselnd",
    "entfesselnderes": "entfesselnd",
    "entfesselndes": "entfesselnd",
    "entfesselndste": "entfesselnd",
    "entfesselndstem": "entfesselnd",
    "entfesselndsten": "entfesselnd",
    "entfesselndster": "entfesselnd",
    "entfesselndstes": "entfesselnd",
    "entfesselst": "entfesseln",
    "entfesselt": "entfesseln",
    "entfesselte": "entfesseln",
    "entfesseltem": "entfesselt",
    "entfesselten": "entfesseln",
    "entfesselter": "entfesselt",
    "entfesseltere": "entfesselt",
    "entfesselterem": "entfesselt",
    "entfesselteren": "entfesselt",
    "entfesselterer": "entfesselt",
    "entfesselteres": "entfesselt",
    "entfesseltes": "entfesselt",
    "entfesseltest": "entfesseln",
    "entfesselteste": "entfesselt",
    "entfesseltestem": "entfesselt",
    "entfesseltesten": "entfesselt",
    "entfesseltester": "entfesselt",
    "entfesseltestes": "entfesselt",
    "entfesseltet": "entfesseln",
    "entfessle": "entfesseln",
    "entfette": "entfetten",
    "entfettend": "entfetten",
    "entfettende": "entfettend",
    "entfettendem": "entfettend",
    "entfettenden": "entfettend",
    "entfettender": "entfettend",
    "entfettendere": "entfettend",
    "entfettenderem": "entfettend",
    "entfettenderen": "entfettend",
    "entfettenderer": "entfettend",
    "entfettenderes": "entfettend",
    "entfettendes": "entfettend",
    "entfettendste": "entfettend",
    "entfettendstem": "entfettend",
    "entfettendsten": "entfettend",
    "entfettendster": "entfettend",
    "entfettendstes": "entfettend",
    "entfettest": "entfetten",
    "entfettet": "entfetten",
    "entfettete": "entfetten",
    "entfettetem": "entfettet",
    "entfetteten": "entfetten",
    "entfetteter": "entfettet",
    "entfettetere": "entfettet",
    "entfetteterem": "entfettet",
    "entfetteteren": "entfettet",
    "entfetteterer": "entfettet",
    "entfetteteres": "entfettet",
    "entfettetes": "entfettet",
    "entfettetest": "entfetten",
    "entfetteteste": "entfettet",
    "entfettetestem": "entfettet",
    "entfettetesten": "entfettet",
    "entfettetester": "entfettet",
    "entfettetestes": "entfettet",
    "entfettetet": "entfetten",
    "entfiel": "entfallen",
    "entfiele": "entfallen",
    "entfielen": "entfallen",
    "entfielest": "entfallen",
    "entfielet": "entfallen",
    "entfielst": "entfallen",
    "entfielt": "entfallen",
    "entfilze": "entfilzen",
    "entfilzend": "entfilzen",
    "entfilzende": "entfilzend",
    "entfilzendem": "entfilzend",
    "entfilzenden": "entfilzend",
    "entfilzender": "entfilzend",
    "entfilzendere": "entfilzend",
    "entfilzenderem": "entfilzend",
    "entfilzenderen": "entfilzend",
    "entfilzenderer": "entfilzend",
    "entfilzenderes": "entfilzend",
    "entfilzendes": "entfilzend",
    "entfilzendste": "entfilzend",
    "entfilzendstem": "entfilzend",
    "entfilzendsten": "entfilzend",
    "entfilzendster": "entfilzend",
    "entfilzendstes": "entfilzend",
    "entfilzest": "entfilzen",
    "entfilzet": "entfilzen",
    "entfilzt": "entfilzen",
    "entfilzte": "entfilzen",
    "entfilztem": "entfilzt",
    "entfilzten": "entfilzen",
    "entfilzter": "entfilzt",
    "entfilztere": "entfilzt",
    "entfilzterem": "entfilzt",
    "entfilzteren": "entfilzt",
    "entfilzterer": "entfilzt",
    "entfilzteres": "entfilzt",
    "entfilztes": "entfilzt",
    "entfilztest": "entfilzen",
    "entfilzteste": "entfilzt",
    "entfilztestem": "entfilzt",
    "entfilztesten": "entfilzt",
    "entfilztester": "entfilzt",
    "entfilztestes": "entfilzt",
    "entfilztet": "entfilzen",
    "entflagge": "entflaggen",
    "entflaggend": "entflaggen",
    "entflaggende": "entflaggend",
    "entflaggendem": "entflaggend",
    "entflaggenden": "entflaggend",
    "entflaggender": "entflaggend",
    "entflaggendere": "entflaggend",
    "entflaggenderem": "entflaggend",
    "entflaggenderen": "entflaggend",
    "entflaggenderer": "entflaggend",
    "entflaggenderes": "entflaggend",
    "entflaggendes": "entflaggend",
    "entflaggendste": "entflaggend",
    "entflaggendstem": "entflaggend",
    "entflaggendsten": "entflaggend",
    "entflaggendster": "entflaggend",
    "entflaggendstes": "entflaggend",
    "entflaggest": "entflaggen",
    "entflagget": "entflaggen",
    "entflaggst": "entflaggen",
    "entflaggt": "entflaggen",
    "entflaggte": "entflaggen",
    "entflaggtem": "entflaggt",
    "entflaggten": "entflaggen",
    "entflaggter": "entflaggt",
    "entflaggtere": "entflaggt",
    "entflaggterem": "entflaggt",
    "entflaggteren": "entflaggt",
    "entflaggterer": "entflaggt",
    "entflaggteres": "entflaggt",
    "entflaggtes": "entflaggt",
    "entflaggtest": "entflaggen",
    "entflaggteste": "entflaggt",
    "entflaggtestem": "entflaggt",
    "entflaggtesten": "entflaggt",
    "entflaggtester": "entflaggt",
    "entflaggtestes": "entflaggt",
    "entflaggtet": "entflaggen",
    "entflamme": "entflammen",
    "entflammend": "entflammen",
    "entflammende": "entflammend",
    "entflammendem": "entflammend",
    "entflammenden": "entflammend",
    "entflammender": "entflammend",
    "entflammendere": "entflammend",
    "entflammenderem": "entflammend",
    "entflammenderen": "entflammend",
    "entflammenderer": "entflammend",
    "entflammenderes": "entflammend",
    "entflammendes": "entflammend",
    "entflammendste": "entflammend",
    "entflammendstem": "entflammend",
    "entflammendsten": "entflammend",
    "entflammendster": "entflammend",
    "entflammendstes": "entflammend",
    "entflammest": "entflammen",
    "entflammet": "entflammen",
    "entflammst": "entflammen",
    "entflammt": "entflammen",
    "entflammte": "entflammen",
    "entflammtem": "entflammt",
    "entflammten": "entflammen",
    "entflammter": "entflammt",
    "entflammtere": "entflammt",
    "entflammterem": "entflammt",
    "entflammteren": "entflammt",
    "entflammterer": "entflammt",
    "entflammteres": "entflammt",
    "entflammtes": "entflammt",
    "entflammtest": "entflammen",
    "entflammteste": "entflammt",
    "entflammtestem": "entflammt",
    "entflammtesten": "entflammt",
    "entflammtester": "entflammt",
    "entflammtestes": "entflammt",
    "entflammtet": "entflammen",
    "entflattere": "entflattern",
    "entflatternd": "entflattern",
    "entflatternde": "entflatternd",
    "entflatterndem": "entflatternd",
    "entflatternden": "entflatternd",
    "entflatternder": "entflatternd",
    "entflatterndes": "entflatternd",
    "entflatterst": "entflattern",
    "entflattert": "entflattern",
    "entflatterte": "entflattern",
    "entflattertem": "entflattert",
    "entflatterten": "entflattern",
    "entflatterter": "entflattert",
    "entflattertes": "entflattert",
    "entflattertest": "entflattern",
    "entflattertet": "entflattern",
    "entfliege": "entfliegen",
    "entfliegend": "entfliegen",
    "entfliegende": "entfliegend",
    "entfliegendem": "entfliegend",
    "entfliegenden": "entfliegend",
    "entfliegender": "entfliegend",
    "entfliegendes": "entfliegend",
    "entfliegest": "entfliegen",
    "entflieget": "entfliegen",
    "entfliegst": "entfliegen",
    "entfliegt": "entfliegen",
    "entfliehe": "entfliehen",
    "entfliehend": "entfliehen",
    "entfliehende": "entfliehend",
    "entfliehendem": "entfliehend",
    "entfliehenden": "entfliehend",
    "entfliehender": "entfliehend",
    "entfliehendes": "entfliehend",
    "entfliehest": "entfliehen",
    "entfliehet": "entfliehen",
    "entfliehst": "entfliehen",
    "entflieht": "entfliehen",
    "entflog": "entfliegen",
    "entflogen": "entfliegen",
    "entflogene": "entflogen",
    "entflogenem": "entflogen",
    "entflogenen": "entflogen",
    "entflogener": "entflogen",
    "entflogenere": "entflogen",
    "entflogenerem": "entflogen",
    "entflogeneren": "entflogen",
    "entflogenerer": "entflogen",
    "entflogeneres": "entflogen",
    "entflogenes": "entflogen",
    "entflogenste": "entflogen",
    "entflogenstem": "entflogen",
    "entflogensten": "entflogen",
    "entflogenster": "entflogen",
    "entflogenstes": "entflogen",
    "entflogst": "entfliegen",
    "entflogt": "entfliegen",
    "entfloh": "entfliehen",
    "entflohen": "entfliehen",
    "entflohene": "entflohen",
    "entflohenem": "entflohen",
    "entflohenen": "entflohen",
    "entflohener": "entflohen",
    "entflohenes": "entflohen",
    "entflohst": "entfliehen",
    "entfloht": "entfliehen",
    "entflutsche": "entflutschen",
    "entflutschend": "entflutschen",
    "entflutschende": "entflutschend",
    "entflutschendem": "entflutschend",
    "entflutschenden": "entflutschend",
    "entflutschender": "entflutschend",
    "entflutschendere": "entflutschend",
    "entflutschenderem": "entflutschend",
    "entflutschenderen": "entflutschend",
    "entflutschenderer": "entflutschend",
    "entflutschenderes": "entflutschend",
    "entflutschendes": "entflutschend",
    "entflutschendste": "entflutschend",
    "entflutschendstem": "entflutschend",
    "entflutschendsten": "entflutschend",
    "entflutschendster": "entflutschend",
    "entflutschendstes": "entflutschend",
    "entflutschest": "entflutschen",
    "entflutschet": "entflutschen",
    "entflutschst": "entflutschen",
    "entflutscht": "entflutschen",
    "entflutschte": "entflutschen",
    "entflutschtem": "entflutscht",
    "entflutschten": "entflutschen",
    "entflutschter": "entflutscht",
    "entflutschtere": "entflutscht",
    "entflutschterem": "entflutscht",
    "entflutschteren": "entflutscht",
    "entflutschterer": "entflutscht",
    "entflutschteres": "entflutscht",
    "entflutschtes": "entflutscht",
    "entflutschtest": "entflutschen",
    "entflutschteste": "entflutscht",
    "entflutschtestem": "entflutscht",
    "entflutschtesten": "entflutscht",
    "entflutschtester": "entflutscht",
    "entflutschtestes": "entflutscht",
    "entflutschtet": "entflutschen",
    "entflöge": "entfliegen",
    "entflögen": "entfliegen",
    "entflögest": "entfliegen",
    "entflöget": "entfliegen",
    "entflöhe": "entfliehen",
    "entflöhen": "entfliehen",
    "entflöhest": "entfliehen",
    "entflöhet": "entfliehen",
    "entformalisiere": "entformalisieren",
    "entformalisierend": "entformalisieren",
    "entformalisierende": "entformalisierend",
    "entformalisierendem": "entformalisierend",
    "entformalisierenden": "entformalisierend",
    "entformalisierender": "entformalisierend",
    "entformalisierendere": "entformalisierend",
    "entformalisierenderem": "entformalisierend",
    "entformalisierenderen": "entformalisierend",
    "entformalisierenderer": "entformalisierend",
    "entformalisierenderes": "entformalisierend",
    "entformalisierendes": "entformalisierend",
    "entformalisierendste": "entformalisierend",
    "entformalisierendstem": "entformalisierend",
    "entformalisierendsten": "entformalisierend",
    "entformalisierendster": "entformalisierend",
    "entformalisierendstes": "entformalisierend",
    "entformalisierest": "entformalisieren",
    "entformalisieret": "entformalisieren",
    "entformalisierst": "entformalisieren",
    "entformalisiert": "entformalisieren",
    "entformalisierte": "entformalisieren",
    "entformalisiertem": "entformalisiert",
    "entformalisierten": "entformalisieren",
    "entformalisierter": "entformalisiert",
    "entformalisiertere": "entformalisiert",
    "entformalisierterem": "entformalisiert",
    "entformalisierteren": "entformalisiert",
    "entformalisierterer": "entformalisiert",
    "entformalisierteres": "entformalisiert",
    "entformalisiertes": "entformalisiert",
    "entformalisiertest": "entformalisieren",
    "entformalisierteste": "entformalisiert",
    "entformalisiertestem": "entformalisiert",
    "entformalisiertesten": "entformalisiert",
    "entformalisiertester": "entformalisiert",
    "entformalisiertestes": "entformalisiert",
    "entformalisiertet": "entformalisieren",
    "entfrachte": "entfrachten",
    "entfrachtend": "entfrachten",
    "entfrachtende": "entfrachtend",
    "entfrachtendem": "entfrachtend",
    "entfrachtenden": "entfrachtend",
    "entfrachtender": "entfrachtend",
    "entfrachtendere": "entfrachtend",
    "entfrachtenderem": "entfrachtend",
    "entfrachtenderen": "entfrachtend",
    "entfrachtenderer": "entfrachtend",
    "entfrachtenderes": "entfrachtend",
    "entfrachtendes": "entfrachtend",
    "entfrachtendste": "entfrachtend",
    "entfrachtendstem": "entfrachtend",
    "entfrachtendsten": "entfrachtend",
    "entfrachtendster": "entfrachtend",
    "entfrachtendstes": "entfrachtend",
    "entfrachtest": "entfrachten",
    "entfrachtet": "entfrachten",
    "entfrachtete": "entfrachten",
    "entfrachtetem": "entfrachtet",
    "entfrachteten": "entfrachten",
    "entfrachteter": "entfrachtet",
    "entfrachtetere": "entfrachtet",
    "entfrachteterem": "entfrachtet",
    "entfrachteteren": "entfrachtet",
    "entfrachteterer": "entfrachtet",
    "entfrachteteres": "entfrachtet",
    "entfrachtetes": "entfrachtet",
    "entfrachtetest": "entfrachten",
    "entfrachteteste": "entfrachtet",
    "entfrachtetestem": "entfrachtet",
    "entfrachtetesten": "entfrachtet",
    "entfrachtetester": "entfrachtet",
    "entfrachtetestes": "entfrachtet",
    "entfrachtetet": "entfrachten",
    "entfremde": "entfremden",
    "entfremdend": "entfremden",
    "entfremdende": "entfremdend",
    "entfremdendem": "entfremdend",
    "entfremdenden": "entfremdend",
    "entfremdender": "entfremdend",
    "entfremdendere": "entfremdend",
    "entfremdenderem": "entfremdend",
    "entfremdenderen": "entfremdend",
    "entfremdenderer": "entfremdend",
    "entfremdenderes": "entfremdend",
    "entfremdendes": "entfremdend",
    "entfremdendste": "entfremdend",
    "entfremdendstem": "entfremdend",
    "entfremdendsten": "entfremdend",
    "entfremdendster": "entfremdend",
    "entfremdendstes": "entfremdend",
    "entfremdest": "entfremden",
    "entfremdet": "entfremden",
    "entfremdete": "entfremden",
    "entfremdetem": "entfremdet",
    "entfremdeten": "entfremden",
    "entfremdeter": "entfremdet",
    "entfremdetes": "entfremdet",
    "entfremdetest": "entfremden",
    "entfremdetet": "entfremden",
    "entfroste": "entfrosten",
    "entfrostend": "entfrosten",
    "entfrostende": "entfrostend",
    "entfrostendem": "entfrostend",
    "entfrostenden": "entfrostend",
    "entfrostender": "entfrostend",
    "entfrostendes": "entfrostend",
    "entfrostest": "entfrosten",
    "entfrostet": "entfrosten",
    "entfrostete": "entfrosten",
    "entfrostetem": "entfrostet",
    "entfrosteten": "entfrosten",
    "entfrosteter": "entfrostet",
    "entfrostetes": "entfrostet",
    "entfrostetest": "entfrosten",
    "entfrostetet": "entfrosten",
    "entfuge": "entfugen",
    "entfugend": "entfugen",
    "entfugende": "entfugend",
    "entfugendem": "entfugend",
    "entfugenden": "entfugend",
    "entfugender": "entfugend",
    "entfugendere": "entfugend",
    "entfugenderem": "entfugend",
    "entfugenderen": "entfugend",
    "entfugenderer": "entfugend",
    "entfugenderes": "entfugend",
    "entfugendes": "entfugend",
    "entfugendste": "entfugend",
    "entfugendstem": "entfugend",
    "entfugendsten": "entfugend",
    "entfugendster": "entfugend",
    "entfugendstes": "entfugend",
    "entfugest": "entfugen",
    "entfuget": "entfugen",
    "entfugst": "entfugen",
    "entfugt": "entfugen",
    "entfugte": "entfugen",
    "entfugtem": "entfugt",
    "entfugten": "entfugen",
    "entfugter": "entfugt",
    "entfugtere": "entfugt",
    "entfugterem": "entfugt",
    "entfugteren": "entfugt",
    "entfugterer": "entfugt",
    "entfugteres": "entfugt",
    "entfugtes": "entfugt",
    "entfugtest": "entfugen",
    "entfugteste": "entfugt",
    "entfugtestem": "entfugt",
    "entfugtesten": "entfugt",
    "entfugtester": "entfugt",
    "entfugtestes": "entfugt",
    "entfugtet": "entfugen",
    "entfällst": "entfallen",
    "entfällt": "entfallen",
    "entfärbe": "entfärben",
    "entfärbend": "entfärben",
    "entfärbende": "entfärbend",
    "entfärbendem": "entfärbend",
    "entfärbenden": "entfärbend",
    "entfärbender": "entfärbend",
    "entfärbendere": "entfärbend",
    "entfärbenderem": "entfärbend",
    "entfärbenderen": "entfärbend",
    "entfärbenderer": "entfärbend",
    "entfärbenderes": "entfärbend",
    "entfärbendes": "entfärbend",
    "entfärbendste": "entfärbend",
    "entfärbendstem": "entfärbend",
    "entfärbendsten": "entfärbend",
    "entfärbendster": "entfärbend",
    "entfärbendstes": "entfärbend",
    "entfärbest": "entfärben",
    "entfärbet": "entfärben",
    "entfärbst": "entfärben",
    "entfärbt": "entfärben",
    "entfärbte": "entfärben",
    "entfärbtem": "entfärbt",
    "entfärbten": "entfärben",
    "entfärbter": "entfärbt",
    "entfärbtere": "entfärbt",
    "entfärbterem": "entfärbt",
    "entfärbteren": "entfärbt",
    "entfärbterer": "entfärbt",
    "entfärbteres": "entfärbt",
    "entfärbtes": "entfärbt",
    "entfärbtest": "entfärben",
    "entfärbteste": "entfärbt",
    "entfärbtestem": "entfärbt",
    "entfärbtesten": "entfärbt",
    "entfärbtester": "entfärbt",
    "entfärbtestes": "entfärbt",
    "entfärbtet": "entfärben",
    "entführe": "entführen",
    "entführend": "entführen",
    "entführende": "entführend",
    "entführendem": "entführend",
    "entführenden": "entführend",
    "entführender": "entführend",
    "entführendes": "entführend",
    "entführest": "entführen",
    "entführet": "entführen",
    "entführst": "entführen",
    "entführt": "entführen",
    "entführte": "entführen",
    "entführtem": "entführt",
    "entführten": "entführen",
    "entführter": "entführt",
    "entführtes": "entführt",
    "entführtest": "entführen",
    "entführtet": "entführen",
    "entgangen": "entgehen",
    "entgangene": "entgangen",
    "entgangenem": "entgangen",
    "entgangenen": "entgangen",
    "entgangener": "entgangen",
    "entgangenes": "entgangen",
    "entgefallen": "entfallen",
    "entgegenarbeite": "entgegenarbeiten",
    "entgegenarbeitend": "entgegenarbeiten",
    "entgegenarbeitende": "entgegenarbeitend",
    "entgegenarbeitendem": "entgegenarbeitend",
    "entgegenarbeitenden": "entgegenarbeitend",
    "entgegenarbeitender": "entgegenarbeitend",
    "entgegenarbeitendes": "entgegenarbeitend",
    "entgegenarbeitest": "entgegenarbeiten",
    "entgegenarbeitet": "entgegenarbeiten",
    "entgegenarbeitete": "entgegenarbeiten",
    "entgegenarbeiteten": "entgegenarbeiten",
    "entgegenarbeitetest": "entgegenarbeiten",
    "entgegenarbeitetet": "entgegenarbeiten",
    "entgegenbrachte": "entgegenbringen",
    "entgegenbrachten": "entgegenbringen",
    "entgegenbrachtest": "entgegenbringen",
    "entgegenbrachtet": "entgegenbringen",
    "entgegenbringe": "entgegenbringen",
    "entgegenbringend": "entgegenbringen",
    "entgegenbringende": "entgegenbringend",
    "entgegenbringendem": "entgegenbringend",
    "entgegenbringenden": "entgegenbringend",
    "entgegenbringender": "entgegenbringend",
    "entgegenbringendes": "entgegenbringend",
    "entgegenbringest": "entgegenbringen",
    "entgegenbringet": "entgegenbringen",
    "entgegenbringst": "entgegenbringen",
    "entgegenbringt": "entgegenbringen",
    "entgegenbrächte": "entgegenbringen",
    "entgegenbrächten": "entgegenbringen",
    "entgegenbrächtest": "entgegenbringen",
    "entgegenbrächtet": "entgegenbringen",
    "entgegeneile": "entgegeneilen",
    "entgegeneilend": "entgegeneilen",
    "entgegeneilende": "entgegeneilend",
    "entgegeneilendem": "entgegeneilend",
    "entgegeneilenden": "entgegeneilend",
    "entgegeneilender": "entgegeneilend",
    "entgegeneilendes": "entgegeneilend",
    "entgegeneilest": "entgegeneilen",
    "entgegeneilet": "entgegeneilen",
    "entgegeneilst": "entgegeneilen",
    "entgegeneilt": "entgegeneilen",
    "entgegeneilte": "entgegeneilen",
    "entgegeneilten": "entgegeneilen",
    "entgegeneiltest": "entgegeneilen",
    "entgegeneiltet": "entgegeneilen",
    "entgegenfahre": "entgegenfahren",
    "entgegenfahrend": "entgegenfahren",
    "entgegenfahrende": "entgegenfahrend",
    "entgegenfahrendem": "entgegenfahrend",
    "entgegenfahrenden": "entgegenfahrend",
    "entgegenfahrender": "entgegenfahrend",
    "entgegenfahrendes": "entgegenfahrend",
    "entgegenfahrest": "entgegenfahren",
    "entgegenfahret": "entgegenfahren",
    "entgegenfahrt": "entgegenfahren",
    "entgegenfiebere": "entgegenfiebern",
    "entgegenfiebernd": "entgegenfiebern",
    "entgegenfiebernde": "entgegenfiebernd",
    "entgegenfieberndem": "entgegenfiebernd",
    "entgegenfiebernden": "entgegenfiebernd",
    "entgegenfiebernder": "entgegenfiebernd",
    "entgegenfieberndes": "entgegenfiebernd",
    "entgegenfieberst": "entgegenfiebern",
    "entgegenfiebert": "entgegenfiebern",
    "entgegenfieberte": "entgegenfiebern",
    "entgegenfieberten": "entgegenfiebern",
    "entgegenfiebertest": "entgegenfiebern",
    "entgegenfiebertet": "entgegenfiebern",
    "entgegenfuhr": "entgegenfahren",
    "entgegenfuhren": "entgegenfahren",
    "entgegenfuhrst": "entgegenfahren",
    "entgegenfuhrt": "entgegenfahren",
    "entgegenfährst": "entgegenfahren",
    "entgegenfährt": "entgegenfahren",
    "entgegenführe": "entgegenführen",
    "entgegenführen": "entgegenfahren",
    "entgegenführend": "entgegenführen",
    "entgegenführende": "entgegenführend",
    "entgegenführendem": "entgegenführend",
    "entgegenführenden": "entgegenführend",
    "entgegenführender": "entgegenführend",
    "entgegenführendes": "entgegenführend",
    "entgegenführest": "entgegenführen",
    "entgegenführet": "entgegenführen",
    "entgegenführst": "entgegenführen",
    "entgegenführt": "entgegenführen",
    "entgegenführte": "entgegenführen",
    "entgegenführten": "entgegenführen",
    "entgegenführtest": "entgegenführen",
    "entgegenführtet": "entgegenführen",
    "entgegengearbeitet": "entgegenarbeiten",
    "entgegengearbeitete": "entgegengearbeitet",
    "entgegengearbeitetem": "entgegengearbeitet",
    "entgegengearbeiteten": "entgegengearbeitet",
    "entgegengearbeiteter": "entgegengearbeitet",
    "entgegengearbeitetes": "entgegengearbeitet",
    "entgegengebracht": "entgegenbringen",
    "entgegengebrachte": "entgegengebracht",
    "entgegengebrachtem": "entgegengebracht",
    "entgegengebrachten": "entgegengebracht",
    "entgegengebrachter": "entgegengebracht",
    "entgegengebrachtes": "entgegengebracht",
    "entgegengeeilt": "entgegeneilen",
    "entgegengeeilte": "entgegengeeilt",
    "entgegengeeiltem": "entgegengeeilt",
    "entgegengeeilten": "entgegengeeilt",
    "entgegengeeilter": "entgegengeeilt",
    "entgegengeeiltes": "entgegengeeilt",
    "entgegengefahren": "entgegenfahren",
    "entgegengefahrene": "entgegengefahren",
    "entgegengefahrenem": "entgegengefahren",
    "entgegengefahrenen": "entgegengefahren",
    "entgegengefahrener": "entgegengefahren",
    "entgegengefahrenes": "entgegengefahren",
    "entgegengefiebert": "entgegenfiebern",
    "entgegengefieberte": "entgegengefiebert",
    "entgegengefiebertem": "entgegengefiebert",
    "entgegengefieberten": "entgegengefiebert",
    "entgegengefieberter": "entgegengefiebert",
    "entgegengefiebertes": "entgegengefiebert",
    "entgegengeführt": "entgegenführen",
    "entgegengeführte": "entgegengeführt",
    "entgegengeführtem": "entgegengeführt",
    "entgegengeführten": "entgegengeführt",
    "entgegengeführter": "entgegengeführt",
    "entgegengeführtes": "entgegengeführt",
    "entgegengehalten": "entgegenhalten",
    "entgegengehaltene": "entgegengehalten",
    "entgegengehaltenem": "entgegengehalten",
    "entgegengehaltenen": "entgegengehalten",
    "entgegengehaltener": "entgegengehalten",
    "entgegengehaltenes": "entgegengehalten",
    "entgegengehandelt": "entgegenhandeln",
    "entgegengehandelte": "entgegengehandelt",
    "entgegengehandeltem": "entgegengehandelt",
    "entgegengehandelten": "entgegengehandelt",
    "entgegengehandelter": "entgegengehandelt",
    "entgegengehandeltes": "entgegengehandelt",
    "entgegengekommen": "entgegenkommen",
    "entgegengekommene": "entgegengekommen",
    "entgegengekommenem": "entgegengekommen",
    "entgegengekommenen": "entgegengekommen",
    "entgegengekommener": "entgegengekommen",
    "entgegengekommenes": "entgegengekommen",
    "entgegengelaufen": "entgegenlaufen",
    "entgegengelaufene": "entgegengelaufen",
    "entgegengelaufenem": "entgegengelaufen",
    "entgegengelaufenen": "entgegengelaufen",
    "entgegengelaufener": "entgegengelaufen",
    "entgegengelaufenes": "entgegengelaufen",
    "entgegengenommen": "entgegennehmen",
    "entgegengenommene": "entgegengenommen",
    "entgegengenommenem": "entgegengenommen",
    "entgegengenommenen": "entgegengenommen",
    "entgegengenommener": "entgegengenommen",
    "entgegengenommenes": "entgegengenommen",
    "entgegengeschallt": "entgegenschallen",
    "entgegengeschallte": "entgegengeschallt",
    "entgegengeschalltem": "entgegengeschallt",
    "entgegengeschallten": "entgegengeschallt",
    "entgegengeschallter": "entgegengeschallt",
    "entgegengeschalltes": "entgegengeschallt",
    "entgegengesehen": "entgegensehen",
    "entgegengesehene": "entgegengesehen",
    "entgegengesehenem": "entgegengesehen",
    "entgegengesehenen": "entgegengesehen",
    "entgegengesehener": "entgegengesehen",
    "entgegengesehenes": "entgegengesehen",
    "entgegengesetzt": "entgegensetzen",
    "entgegengesetzte": "entgegengesetzt",
    "entgegengesetztem": "entgegengesetzt",
    "entgegengesetzten": "entgegengesetzt",
    "entgegengesetzter": "entgegengesetzt",
    "entgegengesetztes": "entgegengesetzt",
    "entgegengestanden": "entgegenstehen",
    "entgegengestandene": "entgegengestanden",
    "entgegengestandenem": "entgegengestanden",
    "entgegengestandenen": "entgegengestanden",
    "entgegengestandener": "entgegengestanden",
    "entgegengestandenes": "entgegengestanden",
    "entgegengestellt": "entgegenstellen",
    "entgegengestellte": "entgegengestellt",
    "entgegengestelltem": "entgegengestellt",
    "entgegengestellten": "entgegengestellt",
    "entgegengestellter": "entgegengestellt",
    "entgegengestelltes": "entgegengestellt",
    "entgegengestürzt": "entgegenstürzen",
    "entgegengestürzte": "entgegengestürzt",
    "entgegengestürztem": "entgegengestürzt",
    "entgegengestürzten": "entgegengestürzt",
    "entgegengestürzter": "entgegengestürzt",
    "entgegengestürztes": "entgegengestürzt",
    "entgegengetragen": "entgegentragen",
    "entgegengetragene": "entgegengetragen",
    "entgegengetragenem": "entgegengetragen",
    "entgegengetragenen": "entgegengetragen",
    "entgegengetragener": "entgegengetragen",
    "entgegengetragenes": "entgegengetragen",
    "entgegengetreten": "entgegentreten",
    "entgegengetretene": "entgegengetreten",
    "entgegengetretenem": "entgegengetreten",
    "entgegengetretenen": "entgegengetreten",
    "entgegengetretener": "entgegengetreten",
    "entgegengetretenes": "entgegengetreten",
    "entgegengetrieben": "entgegentreiben",
    "entgegengetriebene": "entgegengetrieben",
    "entgegengetriebenem": "entgegengetrieben",
    "entgegengetriebenen": "entgegengetrieben",
    "entgegengetriebener": "entgegengetrieben",
    "entgegengetriebenes": "entgegengetrieben",
    "entgegengewirkt": "entgegenwirken",
    "entgegengewirkte": "entgegengewirkt",
    "entgegengewirktem": "entgegengewirkt",
    "entgegengewirkten": "entgegengewirkt",
    "entgegengewirkter": "entgegengewirkt",
    "entgegengewirktes": "entgegengewirkt",
    "entgegenhalte": "entgegenhalten",
    "entgegenhaltend": "entgegenhalten",
    "entgegenhaltende": "entgegenhaltend",
    "entgegenhaltendem": "entgegenhaltend",
    "entgegenhaltenden": "entgegenhaltend",
    "entgegenhaltender": "entgegenhaltend",
    "entgegenhaltendes": "entgegenhaltend",
    "entgegenhaltest": "entgegenhalten",
    "entgegenhaltet": "entgegenhalten",
    "entgegenhandele": "entgegenhandeln",
    "entgegenhandelnd": "entgegenhandeln",
    "entgegenhandelnde": "entgegenhandelnd",
    "entgegenhandelndem": "entgegenhandelnd",
    "entgegenhandelnden": "entgegenhandelnd",
    "entgegenhandelnder": "entgegenhandelnd",
    "entgegenhandelndes": "entgegenhandelnd",
    "entgegenhandelst": "entgegenhandeln",
    "entgegenhandelt": "entgegenhandeln",
    "entgegenhandelte": "entgegenhandeln",
    "entgegenhandelten": "entgegenhandeln",
    "entgegenhandeltest": "entgegenhandeln",
    "entgegenhandeltet": "entgegenhandeln",
    "entgegenhandle": "entgegenhandeln",
    "entgegenhielt": "entgegenhalten",
    "entgegenhielte": "entgegenhalten",
    "entgegenhielten": "entgegenhalten",
    "entgegenhieltest": "entgegenhalten",
    "entgegenhieltet": "entgegenhalten",
    "entgegenhält": "entgegenhalten",
    "entgegenhältst": "entgegenhalten",
    "entgegenkam": "entgegenkommen",
    "entgegenkamen": "entgegenkommen",
    "entgegenkamst": "entgegenkommen",
    "entgegenkamt": "entgegenkommen",
    "entgegenkomme": "entgegenkommen",
    "entgegenkommend": "entgegenkommen",
    "entgegenkommende": "entgegenkommend",
    "entgegenkommendem": "entgegenkommend",
    "entgegenkommenden": "entgegenkommend",
    "entgegenkommender": "entgegenkommend",
    "entgegenkommendes": "entgegenkommend",
    "entgegenkommest": "entgegenkommen",
    "entgegenkommet": "entgegenkommen",
    "entgegenkommst": "entgegenkommen",
    "entgegenkommt": "entgegenkommen",
    "entgegenkäme": "entgegenkommen",
    "entgegenkämen": "entgegenkommen",
    "entgegenkämest": "entgegenkommen",
    "entgegenkämet": "entgegenkommen",
    "entgegenlaufe": "entgegenlaufen",
    "entgegenlaufend": "entgegenlaufen",
    "entgegenlaufende": "entgegenlaufend",
    "entgegenlaufendem": "entgegenlaufend",
    "entgegenlaufenden": "entgegenlaufend",
    "entgegenlaufender": "entgegenlaufend",
    "entgegenlaufendes": "entgegenlaufend",
    "entgegenlaufest": "entgegenlaufen",
    "entgegenlaufet": "entgegenlaufen",
    "entgegenlauft": "entgegenlaufen",
    "entgegenlief": "entgegenlaufen",
    "entgegenliefe": "entgegenlaufen",
    "entgegenliefen": "entgegenlaufen",
    "entgegenliefest": "entgegenlaufen",
    "entgegenliefet": "entgegenlaufen",
    "entgegenliefst": "entgegenlaufen",
    "entgegenlieft": "entgegenlaufen",
    "entgegenläufst": "entgegenlaufen",
    "entgegenläuft": "entgegenlaufen",
    "entgegennahm": "entgegennehmen",
    "entgegennahmst": "entgegennehmen",
    "entgegennahmt": "entgegennehmen",
    "entgegennehme": "entgegennehmen",
    "entgegennehmend": "entgegennehmen",
    "entgegennehmende": "entgegennehmend",
    "entgegennehmendem": "entgegennehmend",
    "entgegennehmenden": "entgegennehmend",
    "entgegennehmender": "entgegennehmend",
    "entgegennehmendes": "entgegennehmend",
    "entgegennehmest": "entgegennehmen",
    "entgegennehmet": "entgegennehmen",
    "entgegennehmt": "entgegennehmen",
    "entgegennimmst": "entgegennehmen",
    "entgegennimmt": "entgegennehmen",
    "entgegennähme": "entgegennehmen",
    "entgegennähmen": "entgegennehmen",
    "entgegennähmest": "entgegennehmen",
    "entgegennähmet": "entgegennehmen",
    "entgegensah": "entgegensehen",
    "entgegensahen": "entgegensehen",
    "entgegensahst": "entgegensehen",
    "entgegensaht": "entgegensehen",
    "entgegenschalle": "entgegenschallen",
    "entgegenschallend": "entgegenschallen",
    "entgegenschallende": "entgegenschallend",
    "entgegenschallendem": "entgegenschallend",
    "entgegenschallenden": "entgegenschallend",
    "entgegenschallender": "entgegenschallend",
    "entgegenschallendes": "entgegenschallend",
    "entgegenschallest": "entgegenschallen",
    "entgegenschallet": "entgegenschallen",
    "entgegenschallst": "entgegenschallen",
    "entgegenschallt": "entgegenschallen",
    "entgegenschallte": "entgegenschallen",
    "entgegenschallten": "entgegenschallen",
    "entgegenschalltest": "entgegenschallen",
    "entgegenschalltet": "entgegenschallen",
    "entgegensehe": "entgegensehen",
    "entgegensehend": "entgegensehen",
    "entgegensehende": "entgegensehend",
    "entgegensehendem": "entgegensehend",
    "entgegensehenden": "entgegensehend",
    "entgegensehender": "entgegensehend",
    "entgegensehendes": "entgegensehend",
    "entgegensehest": "entgegensehen",
    "entgegensehet": "entgegensehen",
    "entgegenseht": "entgegensehen",
    "entgegensetze": "entgegensetzen",
    "entgegensetzend": "entgegensetzen",
    "entgegensetzende": "entgegensetzend",
    "entgegensetzendem": "entgegensetzend",
    "entgegensetzenden": "entgegensetzend",
    "entgegensetzender": "entgegensetzend",
    "entgegensetzendes": "entgegensetzend",
    "entgegensetzest": "entgegensetzen",
    "entgegensetzet": "entgegensetzen",
    "entgegensetzt": "entgegensetzen",
    "entgegensetzte": "entgegensetzen",
    "entgegensetzten": "entgegensetzen",
    "entgegensetztest": "entgegensetzen",
    "entgegensetztet": "entgegensetzen",
    "entgegensiehst": "entgegensehen",
    "entgegensieht": "entgegensehen",
    "entgegenstand": "entgegenstehen",
    "entgegenstanden": "entgegenstehen",
    "entgegenstandest": "entgegenstehen",
    "entgegenstandet": "entgegenstehen",
    "entgegenstehe": "entgegenstehen",
    "entgegenstehend": "entgegenstehen",
    "entgegenstehende": "entgegenstehend",
    "entgegenstehendem": "entgegenstehend",
    "entgegenstehenden": "entgegenstehend",
    "entgegenstehender": "entgegenstehend",
    "entgegenstehendes": "entgegenstehend",
    "entgegenstehest": "entgegenstehen",
    "entgegenstehet": "entgegenstehen",
    "entgegenstehst": "entgegenstehen",
    "entgegensteht": "entgegenstehen",
    "entgegenstelle": "entgegenstellen",
    "entgegenstellend": "entgegenstellen",
    "entgegenstellende": "entgegenstellend",
    "entgegenstellendem": "entgegenstellend",
    "entgegenstellenden": "entgegenstellend",
    "entgegenstellender": "entgegenstellend",
    "entgegenstellendes": "entgegenstellend",
    "entgegenstellest": "entgegenstellen",
    "entgegenstellet": "entgegenstellen",
    "entgegenstellst": "entgegenstellen",
    "entgegenstellt": "entgegenstellen",
    "entgegenstellte": "entgegenstellen",
    "entgegenstellten": "entgegenstellen",
    "entgegenstelltest": "entgegenstellen",
    "entgegenstelltet": "entgegenstellen",
    "entgegenstünde": "entgegenstehen",
    "entgegenstünden": "entgegenstehen",
    "entgegenstündest": "entgegenstehen",
    "entgegenstündet": "entgegenstehen",
    "entgegenstürze": "entgegenstürzen",
    "entgegenstürzend": "entgegenstürzen",
    "entgegenstürzende": "entgegenstürzend",
    "entgegenstürzendem": "entgegenstürzend",
    "entgegenstürzenden": "entgegenstürzend",
    "entgegenstürzender": "entgegenstürzend",
    "entgegenstürzendes": "entgegenstürzend",
    "entgegenstürzest": "entgegenstürzen",
    "entgegenstürzet": "entgegenstürzen",
    "entgegenstürzt": "entgegenstürzen",
    "entgegenstürzte": "entgegenstürzen",
    "entgegenstürzten": "entgegenstürzen",
    "entgegenstürztest": "entgegenstürzen",
    "entgegenstürztet": "entgegenstürzen",
    "entgegensähe": "entgegensehen",
    "entgegensähen": "entgegensehen",
    "entgegensähest": "entgegensehen",
    "entgegensähet": "entgegensehen",
    "entgegentrage": "entgegentragen",
    "entgegentragend": "entgegentragen",
    "entgegentragende": "entgegentragend",
    "entgegentragendem": "entgegentragend",
    "entgegentragenden": "entgegentragend",
    "entgegentragender": "entgegentragend",
    "entgegentragendes": "entgegentragend",
    "entgegentragest": "entgegentragen",
    "entgegentraget": "entgegentragen",
    "entgegentragt": "entgegentragen",
    "entgegentrat": "entgegentreten",
    "entgegentraten": "entgegentreten",
    "entgegentratest": "entgegentreten",
    "entgegentratet": "entgegentreten",
    "entgegentreibe": "entgegentreiben",
    "entgegentreibend": "entgegentreiben",
    "entgegentreibende": "entgegentreibend",
    "entgegentreibendem": "entgegentreibend",
    "entgegentreibenden": "entgegentreibend",
    "entgegentreibender": "entgegentreibend",
    "entgegentreibendes": "entgegentreibend",
    "entgegentreibest": "entgegentreiben",
    "entgegentreibet": "entgegentreiben",
    "entgegentreibst": "entgegentreiben",
    "entgegentreibt": "entgegentreiben",
    "entgegentrete": "entgegentreten",
    "entgegentretend": "entgegentreten",
    "entgegentretende": "entgegentretend",
    "entgegentretendem": "entgegentretend",
    "entgegentretenden": "entgegentretend",
    "entgegentretender": "entgegentretend",
    "entgegentretendes": "entgegentretend",
    "entgegentretest": "entgegentreten",
    "entgegentretet": "entgegentreten",
    "entgegentrieb": "entgegentreiben",
    "entgegentriebe": "entgegentreiben",
    "entgegentrieben": "entgegentreiben",
    "entgegentriebest": "entgegentreiben",
    "entgegentriebet": "entgegentreiben",
    "entgegentriebst": "entgegentreiben",
    "entgegentriebt": "entgegentreiben",
    "entgegentritt": "entgegentreten",
    "entgegentrittst": "entgegentreten",
    "entgegentrug": "entgegentragen",
    "entgegentrugen": "entgegentragen",
    "entgegentrugst": "entgegentragen",
    "entgegentrugt": "entgegentragen",
    "entgegenträgst": "entgegentragen",
    "entgegenträgt": "entgegentragen",
    "entgegenträte": "entgegentreten",
    "entgegenträten": "entgegentreten",
    "entgegenträtest": "entgegentreten",
    "entgegenträtet": "entgegentreten",
    "entgegentrüge": "entgegentragen",
    "entgegentrügen": "entgegentragen",
    "entgegentrügest": "entgegentragen",
    "entgegentrüget": "entgegentragen",
    "entgegenwirke": "entgegenwirken",
    "entgegenwirkend": "entgegenwirken",
    "entgegenwirkende": "entgegenwirkend",
    "entgegenwirkendem": "entgegenwirkend",
    "entgegenwirkenden": "entgegenwirkend",
    "entgegenwirkender": "entgegenwirkend",
    "entgegenwirkendes": "entgegenwirkend",
    "entgegenwirkest": "entgegenwirken",
    "entgegenwirket": "entgegenwirken",
    "entgegenwirkst": "entgegenwirken",
    "entgegenwirkt": "entgegenwirken",
    "entgegenwirkte": "entgegenwirken",
    "entgegenwirkten": "entgegenwirken",
    "entgegenwirktest": "entgegenwirken",
    "entgegenwirktet": "entgegenwirken",
    "entgegenzuarbeiten": "entgegenarbeiten",
    "entgegenzubringen": "entgegenbringen",
    "entgegenzueilen": "entgegeneilen",
    "entgegenzufahren": "entgegenfahren",
    "entgegenzufiebern": "entgegenfiebern",
    "entgegenzuführen": "entgegenführen",
    "entgegenzuhalten": "entgegenhalten",
    "entgegenzuhandeln": "entgegenhandeln",
    "entgegenzukommen": "entgegenkommen",
    "entgegenzulaufen": "entgegenlaufen",
    "entgegenzunehmen": "entgegennehmen",
    "entgegenzuschallen": "entgegenschallen",
    "entgegenzusehen": "entgegensehen",
    "entgegenzusetzen": "entgegensetzen",
    "entgegenzustehen": "entgegenstehen",
    "entgegenzustellen": "entgegenstellen",
    "entgegenzustürzen": "entgegenstürzen",
    "entgegenzutragen": "entgegentragen",
    "entgegenzutreiben": "entgegentreiben",
    "entgegenzutreten": "entgegentreten",
    "entgegenzuwirken": "entgegenwirken",
    "entgegne": "entgegnen",
    "entgegnend": "entgegnen",
    "entgegnende": "entgegnend",
    "entgegnendem": "entgegnend",
    "entgegnenden": "entgegnend",
    "entgegnender": "entgegnend",
    "entgegnendes": "entgegnend",
    "entgegnest": "entgegnen",
    "entgegnet": "entgegnen",
    "entgegnete": "entgegnen",
    "entgegnetem": "entgegnet",
    "entgegneten": "entgegnen",
    "entgegneter": "entgegnet",
    "entgegnetes": "entgegnet",
    "entgegnetest": "entgegnen",
    "entgegnetet": "entgegnen",
    "entgehe": "entgehen",
    "entgehend": "entgehen",
    "entgehende": "entgehend",
    "entgehendem": "entgehend",
    "entgehenden": "entgehend",
    "entgehender": "entgehend",
    "entgehendes": "entgehend",
    "entgehest": "entgehen",
    "entgehet": "entgehen",
    "entgehst": "entgehen",
    "entgeht": "entgehen",
    "entgeisterte": "entgeistert",
    "entgeistertem": "entgeistert",
    "entgeisterten": "entgeistert",
    "entgeisterter": "entgeistert",
    "entgeistertere": "entgeistert",
    "entgeisterterem": "entgeistert",
    "entgeisterteren": "entgeistert",
    "entgeisterterer": "entgeistert",
    "entgeisterteres": "entgeistert",
    "entgeistertes": "entgeistert",
    "entgeisterteste": "entgeistert",
    "entgeistertestem": "entgeistert",
    "entgeistertesten": "entgeistert",
    "entgeistertester": "entgeistert",
    "entgeistertestes": "entgeistert",
    "entgeltlichem": "entgeltlich",
    "entgeltlichen": "entgeltlich",
    "entgeltlicher": "entgeltlich",
    "entgeltliches": "entgeltlich",
    "entgifte": "entgiften",
    "entgiftend": "entgiften",
    "entgiftende": "entgiftend",
    "entgiftendem": "entgiftend",
    "entgiftenden": "entgiftend",
    "entgiftender": "entgiftend",
    "entgiftendes": "entgiftend",
    "entgiftest": "entgiften",
    "entgiftet": "entgiften",
    "entgiftete": "entgiften",
    "entgiftetem": "entgiftet",
    "entgifteten": "entgiften",
    "entgifteter": "entgiftet",
    "entgiftetes": "entgiftet",
    "entgiftetest": "entgiften",
    "entgiftetet": "entgiften",
    "entging": "entgehen",
    "entginge": "entgehen",
    "entgingen": "entgehen",
    "entgingest": "entgehen",
    "entginget": "entgehen",
    "entgingst": "entgehen",
    "entgingt": "entgehen",
    "entgleise": "entgleisen",
    "entgleisend": "entgleisen",
    "entgleisende": "entgleisend",
    "entgleisendem": "entgleisend",
    "entgleisenden": "entgleisend",
    "entgleisender": "entgleisend",
    "entgleisendes": "entgleisend",
    "entgleisest": "entgleisen",
    "entgleiset": "entgleisen",
    "entgleist": "entgleisen",
    "entgleiste": "entgleisen",
    "entgleistem": "entgleist",
    "entgleisten": "entgleisen",
    "entgleister": "entgleist",
    "entgleistes": "entgleist",
    "entgleistest": "entgleisen",
    "entgleistet": "entgleisen",
    "entgleite": "entgleiten",
    "entgleitend": "entgleiten",
    "entgleitende": "entgleitend",
    "entgleitendem": "entgleitend",
    "entgleitenden": "entgleitend",
    "entgleitender": "entgleitend",
    "entgleitendes": "entgleitend",
    "entgleitest": "entgleiten",
    "entgleitet": "entgleiten",
    "entglitt": "entgleiten",
    "entglitte": "entgleiten",
    "entglitten": "entgleiten",
    "entglittene": "entglitten",
    "entglittenem": "entglitten",
    "entglittenen": "entglitten",
    "entglittener": "entglitten",
    "entglittenere": "entglitten",
    "entglittenerem": "entglitten",
    "entglitteneren": "entglitten",
    "entglittenerer": "entglitten",
    "entglitteneres": "entglitten",
    "entglittenes": "entglitten",
    "entglittenste": "entglitten",
    "entglittenstem": "entglitten",
    "entglittensten": "entglitten",
    "entglittenster": "entglitten",
    "entglittenstes": "entglitten",
    "entglittest": "entgleiten",
    "entglittet": "entgleiten",
    "entgräte": "entgräten",
    "entgrätend": "entgräten",
    "entgrätende": "entgrätend",
    "entgrätendem": "entgrätend",
    "entgrätenden": "entgrätend",
    "entgrätender": "entgrätend",
    "entgrätendere": "entgrätend",
    "entgrätenderem": "entgrätend",
    "entgrätenderen": "entgrätend",
    "entgrätenderer": "entgrätend",
    "entgrätenderes": "entgrätend",
    "entgrätendes": "entgrätend",
    "entgrätendste": "entgrätend",
    "entgrätendstem": "entgrätend",
    "entgrätendsten": "entgrätend",
    "entgrätendster": "entgrätend",
    "entgrätendstes": "entgrätend",
    "entgrätest": "entgräten",
    "entgrätet": "entgräten",
    "entgrätete": "entgräten",
    "entgrätetem": "entgrätet",
    "entgräteten": "entgräten",
    "entgräteter": "entgrätet",
    "entgrätetere": "entgrätet",
    "entgräteterem": "entgrätet",
    "entgräteteren": "entgrätet",
    "entgräteterer": "entgrätet",
    "entgräteteres": "entgrätet",
    "entgrätetes": "entgrätet",
    "entgrätetest": "entgräten",
    "entgräteteste": "entgrätet",
    "entgrätetestem": "entgrätet",
    "entgrätetesten": "entgrätet",
    "entgrätetester": "entgrätet",
    "entgrätetestes": "entgrätet",
    "entgrätetet": "entgräten",
    "enthaare": "enthaaren",
    "enthaarend": "enthaaren",
    "enthaarende": "enthaarend",
    "enthaarendem": "enthaarend",
    "enthaarenden": "enthaarend",
    "enthaarender": "enthaarend",
    "enthaarendere": "enthaarend",
    "enthaarenderem": "enthaarend",
    "enthaarenderen": "enthaarend",
    "enthaarenderer": "enthaarend",
    "enthaarenderes": "enthaarend",
    "enthaarendes": "enthaarend",
    "enthaarendste": "enthaarend",
    "enthaarendstem": "enthaarend",
    "enthaarendsten": "enthaarend",
    "enthaarendster": "enthaarend",
    "enthaarendstes": "enthaarend",
    "enthaarest": "enthaaren",
    "enthaaret": "enthaaren",
    "enthaarst": "enthaaren",
    "enthaart": "enthaaren",
    "enthaarte": "enthaaren",
    "enthaartem": "enthaart",
    "enthaarten": "enthaaren",
    "enthaarter": "enthaart",
    "enthaartere": "enthaart",
    "enthaarterem": "enthaart",
    "enthaarteren": "enthaart",
    "enthaarterer": "enthaart",
    "enthaarteres": "enthaart",
    "enthaartes": "enthaart",
    "enthaartest": "enthaaren",
    "enthaarteste": "enthaart",
    "enthaartestem": "enthaart",
    "enthaartesten": "enthaart",
    "enthaartester": "enthaart",
    "enthaartestes": "enthaart",
    "enthaartet": "enthaaren",
    "enthalte": "enthalten",
    "enthaltend": "enthalten",
    "enthaltende": "enthaltend",
    "enthaltendem": "enthaltend",
    "enthaltenden": "enthaltend",
    "enthaltender": "enthaltend",
    "enthaltendes": "enthaltend",
    "enthaltene": "enthalten",
    "enthaltenem": "enthalten",
    "enthaltenen": "enthalten",
    "enthaltener": "enthalten",
    "enthaltenes": "enthalten",
    "enthaltest": "enthalten",
    "enthaltet": "enthalten",
    "enthaltsame": "enthaltsam",
    "enthaltsamem": "enthaltsam",
    "enthaltsamen": "enthaltsam",
    "enthaltsamer": "enthaltsam",
    "enthaltsamere": "enthaltsam",
    "enthaltsamerem": "enthaltsam",
    "enthaltsameren": "enthaltsam",
    "enthaltsamerer": "enthaltsam",
    "enthaltsameres": "enthaltsam",
    "enthaltsames": "enthaltsam",
    "enthaltsamste": "enthaltsam",
    "enthaltsamstem": "enthaltsam",
    "enthaltsamsten": "enthaltsam",
    "enthaltsamster": "enthaltsam",
    "enthaltsamstes": "enthaltsam",
    "enthaupte": "enthaupten",
    "enthauptend": "enthaupten",
    "enthauptende": "enthauptend",
    "enthauptendem": "enthauptend",
    "enthauptenden": "enthauptend",
    "enthauptender": "enthauptend",
    "enthauptendes": "enthauptend",
    "enthauptest": "enthaupten",
    "enthauptet": "enthaupten",
    "enthauptete": "enthaupten",
    "enthauptetem": "enthauptet",
    "enthaupteten": "enthaupten",
    "enthaupteter": "enthauptet",
    "enthauptetes": "enthauptet",
    "enthauptetest": "enthaupten",
    "enthauptetet": "enthaupten",
    "enthebe": "entheben",
    "enthebend": "entheben",
    "enthebende": "enthebend",
    "enthebendem": "enthebend",
    "enthebenden": "enthebend",
    "enthebender": "enthebend",
    "enthebendes": "enthebend",
    "enthebest": "entheben",
    "enthebet": "entheben",
    "enthebst": "entheben",
    "enthebt": "entheben",
    "enthemme": "enthemmen",
    "enthemmend": "enthemmen",
    "enthemmende": "enthemmend",
    "enthemmendem": "enthemmend",
    "enthemmenden": "enthemmend",
    "enthemmender": "enthemmend",
    "enthemmendes": "enthemmend",
    "enthemmest": "enthemmen",
    "enthemmet": "enthemmen",
    "enthemmst": "enthemmen",
    "enthemmt": "enthemmen",
    "enthemmte": "enthemmen",
    "enthemmtem": "enthemmt",
    "enthemmten": "enthemmen",
    "enthemmter": "enthemmt",
    "enthemmtere": "enthemmt",
    "enthemmterem": "enthemmt",
    "enthemmteren": "enthemmt",
    "enthemmterer": "enthemmt",
    "enthemmteres": "enthemmt",
    "enthemmtes": "enthemmt",
    "enthemmtest": "enthemmen",
    "enthemmteste": "enthemmt",
    "enthemmtestem": "enthemmt",
    "enthemmtesten": "enthemmt",
    "enthemmtester": "enthemmt",
    "enthemmtestes": "enthemmt",
    "enthemmtet": "enthemmen",
    "enthielt": "enthalten",
    "enthielte": "enthalten",
    "enthielten": "enthalten",
    "enthieltest": "enthalten",
    "enthieltet": "enthalten",
    "enthob": "entheben",
    "enthoben": "entheben",
    "enthobene": "enthoben",
    "enthobenem": "enthoben",
    "enthobenen": "enthoben",
    "enthobener": "enthoben",
    "enthobenes": "enthoben",
    "enthobst": "entheben",
    "enthobt": "entheben",
    "entholze": "entholzen",
    "entholzend": "entholzen",
    "entholzende": "entholzend",
    "entholzendem": "entholzend",
    "entholzenden": "entholzend",
    "entholzender": "entholzend",
    "entholzendes": "entholzend",
    "entholzest": "entholzen",
    "entholzet": "entholzen",
    "entholzt": "entholzen",
    "entholzte": "entholzen",
    "entholztem": "entholzt",
    "entholzten": "entholzen",
    "entholzter": "entholzt",
    "entholztes": "entholzt",
    "entholztest": "entholzen",
    "entholztet": "entholzen",
    "enthält": "enthalten",
    "enthältst": "enthalten",
    "enthärte": "enthärten",
    "enthärtend": "enthärten",
    "enthärtende": "enthärtend",
    "enthärtendem": "enthärtend",
    "enthärtenden": "enthärtend",
    "enthärtender": "enthärtend",
    "enthärtendere": "enthärtend",
    "enthärtenderem": "enthärtend",
    "enthärtenderen": "enthärtend",
    "enthärtenderer": "enthärtend",
    "enthärtenderes": "enthärtend",
    "enthärtendes": "enthärtend",
    "enthärtendste": "enthärtend",
    "enthärtendstem": "enthärtend",
    "enthärtendsten": "enthärtend",
    "enthärtendster": "enthärtend",
    "enthärtendstes": "enthärtend",
    "enthärtest": "enthärten",
    "enthärtet": "enthärten",
    "enthärtete": "enthärten",
    "enthärtetem": "enthärtet",
    "enthärteten": "enthärten",
    "enthärteter": "enthärtet",
    "enthärtetere": "enthärtet",
    "enthärteterem": "enthärtet",
    "enthärteteren": "enthärtet",
    "enthärteterer": "enthärtet",
    "enthärteteres": "enthärtet",
    "enthärtetes": "enthärtet",
    "enthärtetest": "enthärten",
    "enthärteteste": "enthärtet",
    "enthärtetestem": "enthärtet",
    "enthärtetesten": "enthärtet",
    "enthärtetester": "enthärtet",
    "enthärtetestes": "enthärtet",
    "enthärtetet": "enthärten",
    "enthäute": "enthäuten",
    "enthäutend": "enthäuten",
    "enthäutende": "enthäutend",
    "enthäutendem": "enthäutend",
    "enthäutenden": "enthäutend",
    "enthäutender": "enthäutend",
    "enthäutendes": "enthäutend",
    "enthäutest": "enthäuten",
    "enthäutet": "enthäuten",
    "enthäutete": "enthäuten",
    "enthäutetem": "enthäutet",
    "enthäuteten": "enthäuten",
    "enthäuteter": "enthäutet",
    "enthäutetes": "enthäutet",
    "enthäutetest": "enthäuten",
    "enthäutetet": "enthäuten",
    "enthöbe": "entheben",
    "enthöben": "entheben",
    "enthöbest": "entheben",
    "enthöbet": "entheben",
    "enthülle": "enthüllen",
    "enthüllend": "enthüllen",
    "enthüllende": "enthüllend",
    "enthüllendem": "enthüllend",
    "enthüllenden": "enthüllend",
    "enthüllender": "enthüllend",
    "enthüllendes": "enthüllend",
    "enthüllest": "enthüllen",
    "enthüllet": "enthüllen",
    "enthüllst": "enthüllen",
    "enthüllt": "enthüllen",
    "enthüllte": "enthüllen",
    "enthülltem": "enthüllt",
    "enthüllten": "enthüllen",
    "enthüllter": "enthüllt",
    "enthülltere": "enthüllt",
    "enthüllterem": "enthüllt",
    "enthüllteren": "enthüllt",
    "enthüllterer": "enthüllt",
    "enthüllteres": "enthüllt",
    "enthülltes": "enthüllt",
    "enthülltest": "enthüllen",
    "enthüllteste": "enthüllt",
    "enthülltestem": "enthüllt",
    "enthülltesten": "enthüllt",
    "enthülltester": "enthüllt",
    "enthülltestes": "enthüllt",
    "enthülltet": "enthüllen",
    "entjungfere": "entjungfern",
    "entjungfernd": "entjungfern",
    "entjungfernde": "entjungfernd",
    "entjungferndem": "entjungfernd",
    "entjungfernden": "entjungfernd",
    "entjungfernder": "entjungfernd",
    "entjungferndes": "entjungfernd",
    "entjungferst": "entjungfern",
    "entjungfert": "entjungfern",
    "entjungferte": "entjungfern",
    "entjungfertem": "entjungfert",
    "entjungferten": "entjungfern",
    "entjungferter": "entjungfert",
    "entjungfertes": "entjungfert",
    "entjungfertest": "entjungfern",
    "entjungfertet": "entjungfern",
    "entkalke": "entkalken",
    "entkalkend": "entkalken",
    "entkalkende": "entkalkend",
    "entkalkendem": "entkalkend",
    "entkalkenden": "entkalkend",
    "entkalkender": "entkalkend",
    "entkalkendere": "entkalkend",
    "entkalkenderem": "entkalkend",
    "entkalkenderen": "entkalkend",
    "entkalkenderer": "entkalkend",
    "entkalkenderes": "entkalkend",
    "entkalkendes": "entkalkend",
    "entkalkendste": "entkalkend",
    "entkalkendstem": "entkalkend",
    "entkalkendsten": "entkalkend",
    "entkalkendster": "entkalkend",
    "entkalkendstes": "entkalkend",
    "entkalkest": "entkalken",
    "entkalket": "entkalken",
    "entkalkst": "entkalken",
    "entkalkt": "entkalken",
    "entkalkte": "entkalken",
    "entkalktem": "entkalkt",
    "entkalkten": "entkalken",
    "entkalkter": "entkalkt",
    "entkalktere": "entkalkt",
    "entkalkterem": "entkalkt",
    "entkalkteren": "entkalkt",
    "entkalkterer": "entkalkt",
    "entkalkteres": "entkalkt",
    "entkalktes": "entkalkt",
    "entkalktest": "entkalken",
    "entkalkteste": "entkalkt",
    "entkalktestem": "entkalkt",
    "entkalktesten": "entkalkt",
    "entkalktester": "entkalkt",
    "entkalktestes": "entkalkt",
    "entkalktet": "entkalken",
    "entkam": "entkommen",
    "entkamen": "entkommen",
    "entkamst": "entkommen",
    "entkamt": "entkommen",
    "entkerne": "entkernen",
    "entkernend": "entkernen",
    "entkernende": "entkernend",
    "entkernendem": "entkernend",
    "entkernenden": "entkernend",
    "entkernender": "entkernend",
    "entkernendes": "entkernend",
    "entkernest": "entkernen",
    "entkernet": "entkernen",
    "entkernst": "entkernen",
    "entkernt": "entkernen",
    "entkernte": "entkernen",
    "entkerntem": "entkernt",
    "entkernten": "entkernen",
    "entkernter": "entkernt",
    "entkerntere": "entkernt",
    "entkernterem": "entkernt",
    "entkernteren": "entkernt",
    "entkernterer": "entkernt",
    "entkernteres": "entkernt",
    "entkerntes": "entkernt",
    "entkerntest": "entkernen",
    "entkernteste": "entkernt",
    "entkerntestem": "entkernt",
    "entkerntesten": "entkernt",
    "entkerntester": "entkernt",
    "entkerntestes": "entkernt",
    "entkerntet": "entkernen",
    "entklammere": "entklammern",
    "entklammernd": "entklammern",
    "entklammernde": "entklammernd",
    "entklammerndem": "entklammernd",
    "entklammernden": "entklammernd",
    "entklammernder": "entklammernd",
    "entklammerndere": "entklammernd",
    "entklammernderem": "entklammernd",
    "entklammernderen": "entklammernd",
    "entklammernderer": "entklammernd",
    "entklammernderes": "entklammernd",
    "entklammerndes": "entklammernd",
    "entklammerndste": "entklammernd",
    "entklammerndstem": "entklammernd",
    "entklammerndsten": "entklammernd",
    "entklammerndster": "entklammernd",
    "entklammerndstes": "entklammernd",
    "entklammerst": "entklammern",
    "entklammert": "entklammern",
    "entklammerte": "entklammern",
    "entklammertem": "entklammert",
    "entklammerten": "entklammern",
    "entklammerter": "entklammert",
    "entklammertere": "entklammert",
    "entklammerterem": "entklammert",
    "entklammerteren": "entklammert",
    "entklammerterer": "entklammert",
    "entklammerteres": "entklammert",
    "entklammertes": "entklammert",
    "entklammertest": "entklammern",
    "entklammerteste": "entklammert",
    "entklammertestem": "entklammert",
    "entklammertesten": "entklammert",
    "entklammertester": "entklammert",
    "entklammertestes": "entklammert",
    "entklammertet": "entklammern",
    "entkleide": "entkleiden",
    "entkleidend": "entkleiden",
    "entkleidende": "entkleidend",
    "entkleidendem": "entkleidend",
    "entkleidenden": "entkleidend",
    "entkleidender": "entkleidend",
    "entkleidendere": "entkleidend",
    "entkleidenderem": "entkleidend",
    "entkleidenderen": "entkleidend",
    "entkleidenderer": "entkleidend",
    "entkleidenderes": "entkleidend",
    "entkleidendes": "entkleidend",
    "entkleidendste": "entkleidend",
    "entkleidendstem": "entkleidend",
    "entkleidendsten": "entkleidend",
    "entkleidendster": "entkleidend",
    "entkleidendstes": "entkleidend",
    "entkleidest": "entkleiden",
    "entkleidet": "entkleiden",
    "entkleidete": "entkleiden",
    "entkleidetem": "entkleidet",
    "entkleideten": "entkleiden",
    "entkleideter": "entkleidet",
    "entkleidetere": "entkleidet",
    "entkleideterem": "entkleidet",
    "entkleideteren": "entkleidet",
    "entkleideterer": "entkleidet",
    "entkleideteres": "entkleidet",
    "entkleidetes": "entkleidet",
    "entkleidetest": "entkleiden",
    "entkleideteste": "entkleidet",
    "entkleidetestem": "entkleidet",
    "entkleidetesten": "entkleidet",
    "entkleidetester": "entkleidet",
    "entkleidetestes": "entkleidet",
    "entkleidetet": "entkleiden",
    "entklumpe": "entklumpen",
    "entklumpend": "entklumpen",
    "entklumpende": "entklumpend",
    "entklumpendem": "entklumpend",
    "entklumpenden": "entklumpend",
    "entklumpender": "entklumpend",
    "entklumpendere": "entklumpend",
    "entklumpenderem": "entklumpend",
    "entklumpenderen": "entklumpend",
    "entklumpenderer": "entklumpend",
    "entklumpenderes": "entklumpend",
    "entklumpendes": "entklumpend",
    "entklumpendste": "entklumpend",
    "entklumpendstem": "entklumpend",
    "entklumpendsten": "entklumpend",
    "entklumpendster": "entklumpend",
    "entklumpendstes": "entklumpend",
    "entklumpest": "entklumpen",
    "entklumpet": "entklumpen",
    "entklumpst": "entklumpen",
    "entklumpt": "entklumpen",
    "entklumpte": "entklumpen",
    "entklumptem": "entklumpt",
    "entklumpten": "entklumpen",
    "entklumpter": "entklumpt",
    "entklumptere": "entklumpt",
    "entklumpterem": "entklumpt",
    "entklumpteren": "entklumpt",
    "entklumpterer": "entklumpt",
    "entklumpteres": "entklumpt",
    "entklumptes": "entklumpt",
    "entklumptest": "entklumpen",
    "entklumpteste": "entklumpt",
    "entklumptestem": "entklumpt",
    "entklumptesten": "entklumpt",
    "entklumptester": "entklumpt",
    "entklumptestes": "entklumpt",
    "entklumptet": "entklumpen",
    "entkolonialisieren": "entkolonialisiere",
    "entkolonialisierend": "entkolonialisiere",
    "entkolonialisierende": "entkolonialisierend",
    "entkolonialisierendem": "entkolonialisierend",
    "entkolonialisierenden": "entkolonialisierend",
    "entkolonialisierender": "entkolonialisierend",
    "entkolonialisierendes": "entkolonialisierend",
    "entkolonialisierest": "entkolonialisiere",
    "entkolonialisieret": "entkolonialisiere",
    "entkolonialisierst": "entkolonialisiere",
    "entkolonialisiert": "entkolonialisiere",
    "entkolonialisierte": "entkolonialisiere",
    "entkolonialisiertem": "entkolonialisiert",
    "entkolonialisierten": "entkolonialisiere",
    "entkolonialisierter": "entkolonialisiert",
    "entkolonialisiertes": "entkolonialisiert",
    "entkolonialisiertest": "entkolonialisiere",
    "entkolonialisiertet": "entkolonialisiere",
    "entkomme": "entkommen",
    "entkommend": "entkommen",
    "entkommende": "entkommend",
    "entkommendem": "entkommend",
    "entkommenden": "entkommend",
    "entkommender": "entkommend",
    "entkommendes": "entkommend",
    "entkommene": "entkommen",
    "entkommenem": "entkommen",
    "entkommenen": "entkommen",
    "entkommener": "entkommen",
    "entkommenes": "entkommen",
    "entkommerzialisiere": "entkommerzialisie",
    "entkommerzialisieren": "entkommerzialisie",
    "entkommerzialisierest": "entkommerzialisie",
    "entkommerzialisieret": "entkommerzialisie",
    "entkommerzialisierst": "entkommerzialisie",
    "entkommerzialisiert": "entkommerzialisie",
    "entkommerzialisierte": "entkommerzialisie",
    "entkommerzialisiertem": "entkommerzialisiert",
    "entkommerzialisierten": "entkommerzialisie",
    "entkommerzialisierter": "entkommerzialisiert",
    "entkommerzialisiertere": "entkommerzialisiert",
    "entkommerzialisierterem": "entkommerzialisiert",
    "entkommerzialisierteren": "entkommerzialisiert",
    "entkommerzialisierterer": "entkommerzialisiert",
    "entkommerzialisierteres": "entkommerzialisiert",
    "entkommerzialisiertes": "entkommerzialisiert",
    "entkommerzialisiertest": "entkommerzialisie",
    "entkommerzialisierteste": "entkommerzialisiert",
    "entkommerzialisiertestem": "entkommerzialisiert",
    "entkommerzialisiertesten": "entkommerzialisiert",
    "entkommerzialisiertester": "entkommerzialisiert",
    "entkommerzialisiertestes": "entkommerzialisiert",
    "entkommerzialisiertet": "entkommerzialisie",
    "entkommest": "entkommen",
    "entkommet": "entkommen",
    "entkommst": "entkommen",
    "entkommt": "entkommen",
    "entkommunalisieren": "entkommunalisiere",
    "entkommunalisierend": "entkommunalisiere",
    "entkommunalisierende": "entkommunalisierend",
    "entkommunalisierendem": "entkommunalisierend",
    "entkommunalisierenden": "entkommunalisierend",
    "entkommunalisierender": "entkommunalisierend",
    "entkommunalisierendere": "entkommunalisierend",
    "entkommunalisierenderem": "entkommunalisierend",
    "entkommunalisierenderen": "entkommunalisierend",
    "entkommunalisierenderer": "entkommunalisierend",
    "entkommunalisierenderes": "entkommunalisierend",
    "entkommunalisierendes": "entkommunalisierend",
    "entkommunalisierendste": "entkommunalisierend",
    "entkommunalisierendstem": "entkommunalisierend",
    "entkommunalisierendsten": "entkommunalisierend",
    "entkommunalisierendster": "entkommunalisierend",
    "entkommunalisierendstes": "entkommunalisierend",
    "entkommunalisierest": "entkommunalisiere",
    "entkommunalisieret": "entkommunalisiere",
    "entkommunalisierst": "entkommunalisiere",
    "entkommunalisiert": "entkommunalisiere",
    "entkommunalisierte": "entkommunalisiere",
    "entkommunalisiertem": "entkommunalisiert",
    "entkommunalisierten": "entkommunalisiere",
    "entkommunalisierter": "entkommunalisiert",
    "entkommunalisiertere": "entkommunalisiert",
    "entkommunalisierterem": "entkommunalisiert",
    "entkommunalisierteren": "entkommunalisiert",
    "entkommunalisierterer": "entkommunalisiert",
    "entkommunalisierteres": "entkommunalisiert",
    "entkommunalisiertes": "entkommunalisiert",
    "entkommunalisiertest": "entkommunalisiere",
    "entkommunalisierteste": "entkommunalisiert",
    "entkommunalisiertestem": "entkommunalisiert",
    "entkommunalisiertesten": "entkommunalisiert",
    "entkommunalisiertester": "entkommunalisiert",
    "entkommunalisiertestes": "entkommunalisiert",
    "entkommunalisiertet": "entkommunalisiere",
    "entkompliziere": "entkomplizieren",
    "entkomplizierend": "entkomplizieren",
    "entkomplizierende": "entkomplizierend",
    "entkomplizierendem": "entkomplizierend",
    "entkomplizierenden": "entkomplizierend",
    "entkomplizierender": "entkomplizierend",
    "entkomplizierendere": "entkomplizierend",
    "entkomplizierenderem": "entkomplizierend",
    "entkomplizierenderen": "entkomplizierend",
    "entkomplizierenderer": "entkomplizierend",
    "entkomplizierenderes": "entkomplizierend",
    "entkomplizierendes": "entkomplizierend",
    "entkomplizierendste": "entkomplizierend",
    "entkomplizierendstem": "entkomplizierend",
    "entkomplizierendsten": "entkomplizierend",
    "entkomplizierendster": "entkomplizierend",
    "entkomplizierendstes": "entkomplizierend",
    "entkomplizierest": "entkomplizieren",
    "entkomplizieret": "entkomplizieren",
    "entkomplizierst": "entkomplizieren",
    "entkompliziert": "entkomplizieren",
    "entkomplizierte": "entkomplizieren",
    "entkompliziertem": "entkompliziert",
    "entkomplizierten": "entkomplizieren",
    "entkomplizierter": "entkompliziert",
    "entkompliziertere": "entkompliziert",
    "entkomplizierterem": "entkompliziert",
    "entkomplizierteren": "entkompliziert",
    "entkomplizierterer": "entkompliziert",
    "entkomplizierteres": "entkompliziert",
    "entkompliziertes": "entkompliziert",
    "entkompliziertest": "entkomplizieren",
    "entkomplizierteste": "entkompliziert",
    "entkompliziertestem": "entkompliziert",
    "entkompliziertesten": "entkompliziert",
    "entkompliziertester": "entkompliziert",
    "entkompliziertestes": "entkompliziert",
    "entkompliziertet": "entkomplizieren",
    "entkomprimiere": "entkomprimieren",
    "entkomprimierend": "entkomprimieren",
    "entkomprimierende": "entkomprimierend",
    "entkomprimierendem": "entkomprimierend",
    "entkomprimierenden": "entkomprimierend",
    "entkomprimierender": "entkomprimierend",
    "entkomprimierendere": "entkomprimierend",
    "entkomprimierenderem": "entkomprimierend",
    "entkomprimierenderen": "entkomprimierend",
    "entkomprimierenderer": "entkomprimierend",
    "entkomprimierenderes": "entkomprimierend",
    "entkomprimierendes": "entkomprimierend",
    "entkomprimierendste": "entkomprimierend",
    "entkomprimierendstem": "entkomprimierend",
    "entkomprimierendsten": "entkomprimierend",
    "entkomprimierendster": "entkomprimierend",
    "entkomprimierendstes": "entkomprimierend",
    "entkomprimierest": "entkomprimieren",
    "entkomprimieret": "entkomprimieren",
    "entkomprimierst": "entkomprimieren",
    "entkomprimiert": "entkomprimieren",
    "entkomprimierte": "entkomprimieren",
    "entkomprimiertem": "entkomprimiert",
    "entkomprimierten": "entkomprimieren",
    "entkomprimierter": "entkomprimiert",
    "entkomprimiertere": "entkomprimiert",
    "entkomprimierterem": "entkomprimiert",
    "entkomprimierteren": "entkomprimiert",
    "entkomprimierterer": "entkomprimiert",
    "entkomprimierteres": "entkomprimiert",
    "entkomprimiertes": "entkomprimiert",
    "entkomprimiertest": "entkomprimieren",
    "entkomprimierteste": "entkomprimiert",
    "entkomprimiertestem": "entkomprimiert",
    "entkomprimiertesten": "entkomprimiert",
    "entkomprimiertester": "entkomprimiert",
    "entkomprimiertestes": "entkomprimiert",
    "entkomprimiertet": "entkomprimieren",
    "entkoppele": "entkoppeln",
    "entkoppelnd": "entkoppeln",
    "entkoppelnde": "entkoppelnd",
    "entkoppelndem": "entkoppelnd",
    "entkoppelnden": "entkoppelnd",
    "entkoppelnder": "entkoppelnd",
    "entkoppelndes": "entkoppelnd",
    "entkoppelst": "entkoppeln",
    "entkoppelt": "entkoppeln",
    "entkoppelte": "entkoppeln",
    "entkoppeltem": "entkoppelt",
    "entkoppelten": "entkoppeln",
    "entkoppelter": "entkoppelt",
    "entkoppeltes": "entkoppelt",
    "entkoppeltest": "entkoppeln",
    "entkoppeltet": "entkoppeln",
    "entkopple": "entkoppeln",
    "entkorke": "entkorken",
    "entkorkend": "entkorken",
    "entkorkende": "entkorkend",
    "entkorkendem": "entkorkend",
    "entkorkenden": "entkorkend",
    "entkorkender": "entkorkend",
    "entkorkendes": "entkorkend",
    "entkorkest": "entkorken",
    "entkorket": "entkorken",
    "entkorkst": "entkorken",
    "entkorkt": "entkorken",
    "entkorkte": "entkorken",
    "entkorktem": "entkorkt",
    "entkorkten": "entkorken",
    "entkorkter": "entkorkt",
    "entkorktes": "entkorkt",
    "entkorktest": "entkorken",
    "entkorktet": "entkorken",
    "entkrampfe": "entkrampfen",
    "entkrampfend": "entkrampfen",
    "entkrampfende": "entkrampfend",
    "entkrampfendem": "entkrampfend",
    "entkrampfenden": "entkrampfend",
    "entkrampfender": "entkrampfend",
    "entkrampfendes": "entkrampfend",
    "entkrampfest": "entkrampfen",
    "entkrampfet": "entkrampfen",
    "entkrampfst": "entkrampfen",
    "entkrampft": "entkrampfen",
    "entkrampfte": "entkrampfen",
    "entkrampftem": "entkrampft",
    "entkrampften": "entkrampfen",
    "entkrampfter": "entkrampft",
    "entkrampftes": "entkrampft",
    "entkrampftest": "entkrampfen",
    "entkrampftet": "entkrampfen",
    "entkriminalisieren": "entkriminalisiere",
    "entkriminalisierend": "entkriminalisiere",
    "entkriminalisierende": "entkriminalisierend",
    "entkriminalisierendem": "entkriminalisierend",
    "entkriminalisierenden": "entkriminalisierend",
    "entkriminalisierender": "entkriminalisierend",
    "entkriminalisierendere": "entkriminalisierend",
    "entkriminalisierenderem": "entkriminalisierend",
    "entkriminalisierenderen": "entkriminalisierend",
    "entkriminalisierenderer": "entkriminalisierend",
    "entkriminalisierenderes": "entkriminalisierend",
    "entkriminalisierendes": "entkriminalisierend",
    "entkriminalisierendste": "entkriminalisierend",
    "entkriminalisierendstem": "entkriminalisierend",
    "entkriminalisierendsten": "entkriminalisierend",
    "entkriminalisierendster": "entkriminalisierend",
    "entkriminalisierendstes": "entkriminalisierend",
    "entkriminalisierest": "entkriminalisiere",
    "entkriminalisieret": "entkriminalisiere",
    "entkriminalisierst": "entkriminalisiere",
    "entkriminalisiert": "entkriminalisiere",
    "entkriminalisierte": "entkriminalisiere",
    "entkriminalisiertem": "entkriminalisiert",
    "entkriminalisierten": "entkriminalisiere",
    "entkriminalisierter": "entkriminalisiert",
    "entkriminalisiertere": "entkriminalisiert",
    "entkriminalisierterem": "entkriminalisiert",
    "entkriminalisierteren": "entkriminalisiert",
    "entkriminalisierterer": "entkriminalisiert",
    "entkriminalisierteres": "entkriminalisiert",
    "entkriminalisiertes": "entkriminalisiert",
    "entkriminalisiertest": "entkriminalisiere",
    "entkriminalisierteste": "entkriminalisiert",
    "entkriminalisiertestem": "entkriminalisiert",
    "entkriminalisiertesten": "entkriminalisiert",
    "entkriminalisiertester": "entkriminalisiert",
    "entkriminalisiertestes": "entkriminalisiert",
    "entkriminalisiertet": "entkriminalisiere",
    "entkräfte": "entkräften",
    "entkräftend": "entkräften",
    "entkräftende": "entkräftend",
    "entkräftendem": "entkräftend",
    "entkräftenden": "entkräftend",
    "entkräftender": "entkräftend",
    "entkräftendes": "entkräftend",
    "entkräftest": "entkräften",
    "entkräftet": "entkräften",
    "entkräftete": "entkräften",
    "entkräftetem": "entkräftet",
    "entkräfteten": "entkräften",
    "entkräfteter": "entkräftet",
    "entkräftetes": "entkräftet",
    "entkräftetest": "entkräften",
    "entkräftetet": "entkräften",
    "entkrümele": "entkrümeln",
    "entkrümelnd": "entkrümeln",
    "entkrümelnde": "entkrümelnd",
    "entkrümelndem": "entkrümelnd",
    "entkrümelnden": "entkrümelnd",
    "entkrümelnder": "entkrümelnd",
    "entkrümelndere": "entkrümelnd",
    "entkrümelnderem": "entkrümelnd",
    "entkrümelnderen": "entkrümelnd",
    "entkrümelnderer": "entkrümelnd",
    "entkrümelnderes": "entkrümelnd",
    "entkrümelndes": "entkrümelnd",
    "entkrümelndste": "entkrümelnd",
    "entkrümelndstem": "entkrümelnd",
    "entkrümelndsten": "entkrümelnd",
    "entkrümelndster": "entkrümelnd",
    "entkrümelndstes": "entkrümelnd",
    "entkrümelst": "entkrümeln",
    "entkrümelt": "entkrümeln",
    "entkrümelte": "entkrümeln",
    "entkrümeltem": "entkrümelt",
    "entkrümelten": "entkrümeln",
    "entkrümelter": "entkrümelt",
    "entkrümeltere": "entkrümelt",
    "entkrümelterem": "entkrümelt",
    "entkrümelteren": "entkrümelt",
    "entkrümelterer": "entkrümelt",
    "entkrümelteres": "entkrümelt",
    "entkrümeltes": "entkrümelt",
    "entkrümeltest": "entkrümeln",
    "entkrümelteste": "entkrümelt",
    "entkrümeltestem": "entkrümelt",
    "entkrümeltesten": "entkrümelt",
    "entkrümeltester": "entkrümelt",
    "entkrümeltestes": "entkrümelt",
    "entkrümeltet": "entkrümeln",
    "entkrümle": "entkrümeln",
    "entkuppele": "entkuppeln",
    "entkuppelnd": "entkuppeln",
    "entkuppelnde": "entkuppelnd",
    "entkuppelndem": "entkuppelnd",
    "entkuppelnden": "entkuppelnd",
    "entkuppelnder": "entkuppelnd",
    "entkuppelndes": "entkuppelnd",
    "entkuppelst": "entkuppeln",
    "entkuppelt": "entkuppeln",
    "entkuppelte": "entkuppeln",
    "entkuppeltem": "entkuppelt",
    "entkuppelten": "entkuppeln",
    "entkuppelter": "entkuppelt",
    "entkuppeltes": "entkuppelt",
    "entkuppeltest": "entkuppeln",
    "entkuppeltet": "entkuppeln",
    "entkupple": "entkuppeln",
    "entkäme": "entkommen",
    "entkämen": "entkommen",
    "entkämest": "entkommen",
    "entkämet": "entkommen",
    "entlade": "entladen",
    "entladend": "entladen",
    "entladende": "entladend",
    "entladendem": "entladend",
    "entladenden": "entladend",
    "entladender": "entladend",
    "entladendes": "entladend",
    "entladene": "entladen",
    "entladenem": "entladen",
    "entladenen": "entladen",
    "entladener": "entladen",
    "entladenes": "entladen",
    "entladest": "entladen",
    "entladet": "entladen",
    "entlangfahre": "entlangfahren",
    "entlangfahrend": "entlangfahren",
    "entlangfahrende": "entlangfahrend",
    "entlangfahrendem": "entlangfahrend",
    "entlangfahrenden": "entlangfahrend",
    "entlangfahrender": "entlangfahrend",
    "entlangfahrendes": "entlangfahrend",
    "entlangfahrest": "entlangfahren",
    "entlangfahret": "entlangfahren",
    "entlangfahrt": "entlangfahren",
    "entlangfuhr": "entlangfahren",
    "entlangfuhren": "entlangfahren",
    "entlangfuhrst": "entlangfahren",
    "entlangfuhrt": "entlangfahren",
    "entlangfährst": "entlangfahren",
    "entlangfährt": "entlangfahren",
    "entlangführe": "entlangfahren",
    "entlangführen": "entlangfahren",
    "entlangführest": "entlangfahren",
    "entlangführet": "entlangfahren",
    "entlanggefahren": "entlangfahren",
    "entlanggefahrene": "entlanggefahren",
    "entlanggefahrenem": "entlanggefahren",
    "entlanggefahrenen": "entlanggefahren",
    "entlanggefahrener": "entlanggefahren",
    "entlanggefahrenes": "entlanggefahren",
    "entlanggegangen": "entlanggehen",
    "entlanggegangene": "entlanggegangen",
    "entlanggegangenem": "entlanggegangen",
    "entlanggegangenen": "entlanggegangen",
    "entlanggegangener": "entlanggegangen",
    "entlanggegangenes": "entlanggegangen",
    "entlanggehe": "entlanggehen",
    "entlanggehend": "entlanggehen",
    "entlanggehende": "entlanggehend",
    "entlanggehendem": "entlanggehend",
    "entlanggehenden": "entlanggehend",
    "entlanggehender": "entlanggehend",
    "entlanggehendes": "entlanggehend",
    "entlanggehest": "entlanggehen",
    "entlanggehet": "entlanggehen",
    "entlanggehst": "entlanggehen",
    "entlanggeht": "entlanggehen",
    "entlanggelaufen": "entlanglaufen",
    "entlanggelaufene": "entlanggelaufen",
    "entlanggelaufenem": "entlanggelaufen",
    "entlanggelaufenen": "entlanggelaufen",
    "entlanggelaufener": "entlanggelaufen",
    "entlanggelaufenes": "entlanggelaufen",
    "entlangging": "entlanggehen",
    "entlangginge": "entlanggehen",
    "entlanggingen": "entlanggehen",
    "entlanggingest": "entlanggehen",
    "entlangginget": "entlanggehen",
    "entlanggingst": "entlanggehen",
    "entlanggingt": "entlanggehen",
    "entlanglaufe": "entlanglaufen",
    "entlanglaufend": "entlanglaufen",
    "entlanglaufende": "entlanglaufend",
    "entlanglaufendem": "entlanglaufend",
    "entlanglaufenden": "entlanglaufend",
    "entlanglaufender": "entlanglaufend",
    "entlanglaufendes": "entlanglaufend",
    "entlanglaufest": "entlanglaufen",
    "entlanglaufet": "entlanglaufen",
    "entlanglauft": "entlanglaufen",
    "entlanglief": "entlanglaufen",
    "entlangliefe": "entlanglaufen",
    "entlangliefen": "entlanglaufen",
    "entlangliefest": "entlanglaufen",
    "entlangliefet": "entlanglaufen",
    "entlangliefst": "entlanglaufen",
    "entlanglieft": "entlanglaufen",
    "entlangläufst": "entlanglaufen",
    "entlangläuft": "entlanglaufen",
    "entlangzufahren": "entlangfahren",
    "entlangzugehen": "entlanggehen",
    "entlangzulaufen": "entlanglaufen",
    "entlarve": "entlarven",
    "entlarvend": "entlarven",
    "entlarvende": "entlarvend",
    "entlarvendem": "entlarvend",
    "entlarvenden": "entlarvend",
    "entlarvender": "entlarvend",
    "entlarvendes": "entlarvend",
    "entlarvest": "entlarven",
    "entlarvet": "entlarven",
    "entlarvst": "entlarven",
    "entlarvt": "entlarven",
    "entlarvte": "entlarven",
    "entlarvtem": "entlarvt",
    "entlarvten": "entlarven",
    "entlarvter": "entlarvt",
    "entlarvtes": "entlarvt",
    "entlarvtest": "entlarven",
    "entlarvtet": "entlarven",
    "entlasse": "entlassen",
    "entlassend": "entlassen",
    "entlassende": "entlassend",
    "entlassendem": "entlassend",
    "entlassenden": "entlassend",
    "entlassender": "entlassend",
    "entlassendes": "entlassend",
    "entlassene": "entlassen",
    "entlassenem": "entlassen",
    "entlassenen": "entlassen",
    "entlassener": "entlassen",
    "entlassenes": "entlassen",
    "entlassest": "entlassen",
    "entlasset": "entlassen",
    "entlaste": "entlasten",
    "entlastend": "entlasten",
    "entlastende": "entlastend",
    "entlastendem": "entlastend",
    "entlastenden": "entlastend",
    "entlastender": "entlastend",
    "entlastendes": "entlastend",
    "entlastest": "entlasten",
    "entlastet": "entlasten",
    "entlastete": "entlasten",
    "entlastetem": "entlastet",
    "entlasteten": "entlasten",
    "entlasteter": "entlastet",
    "entlastetes": "entlastet",
    "entlastetest": "entlasten",
    "entlastetet": "entlasten",
    "entlaufe": "entlaufen",
    "entlaufend": "entlaufen",
    "entlaufende": "entlaufend",
    "entlaufendem": "entlaufend",
    "entlaufenden": "entlaufend",
    "entlaufender": "entlaufend",
    "entlaufendes": "entlaufend",
    "entlaufene": "entlaufen",
    "entlaufenem": "entlaufen",
    "entlaufenen": "entlaufen",
    "entlaufener": "entlaufen",
    "entlaufenes": "entlaufen",
    "entlaufest": "entlaufen",
    "entlaufet": "entlaufen",
    "entlauft": "entlaufen",
    "entlause": "entlausen",
    "entlausend": "entlausen",
    "entlausende": "entlausend",
    "entlausendem": "entlausend",
    "entlausenden": "entlausend",
    "entlausender": "entlausend",
    "entlausendere": "entlausend",
    "entlausenderem": "entlausend",
    "entlausenderen": "entlausend",
    "entlausenderer": "entlausend",
    "entlausenderes": "entlausend",
    "entlausendes": "entlausend",
    "entlausendste": "entlausend",
    "entlausendstem": "entlausend",
    "entlausendsten": "entlausend",
    "entlausendster": "entlausend",
    "entlausendstes": "entlausend",
    "entlausest": "entlausen",
    "entlauset": "entlausen",
    "entlaust": "entlausen",
    "entlauste": "entlausen",
    "entlaustem": "entlaust",
    "entlausten": "entlausen",
    "entlauster": "entlaust",
    "entlaustere": "entlaust",
    "entlausterem": "entlaust",
    "entlausteren": "entlaust",
    "entlausterer": "entlaust",
    "entlausteres": "entlaust",
    "entlaustes": "entlaust",
    "entlaustest": "entlausen",
    "entlausteste": "entlaust",
    "entlaustestem": "entlaust",
    "entlaustesten": "entlaust",
    "entlaustester": "entlaust",
    "entlaustestes": "entlaust",
    "entlaustet": "entlausen",
    "entlaß": "entlassen",
    "entlaßt": "entlassen",
    "entledige": "entledigen",
    "entledigend": "entledigen",
    "entledigende": "entledigend",
    "entledigendem": "entledigend",
    "entledigenden": "entledigend",
    "entledigender": "entledigend",
    "entledigendes": "entledigend",
    "entledigest": "entledigen",
    "entlediget": "entledigen",
    "entledigst": "entledigen",
    "entledigt": "entledigen",
    "entledigte": "entledigen",
    "entledigtem": "entledigt",
    "entledigten": "entledigen",
    "entledigter": "entledigt",
    "entledigtes": "entledigt",
    "entledigtest": "entledigen",
    "entledigtet": "entledigen",
    "entleere": "entleeren",
    "entleerend": "entleeren",
    "entleerende": "entleerend",
    "entleerendem": "entleerend",
    "entleerenden": "entleerend",
    "entleerender": "entleerend",
    "entleerendes": "entleerend",
    "entleerest": "entleeren",
    "entleeret": "entleeren",
    "entleerst": "entleeren",
    "entleert": "entleeren",
    "entleerte": "entleeren",
    "entleertem": "entleert",
    "entleerten": "entleeren",
    "entleerter": "entleert",
    "entleertere": "entleert",
    "entleerterem": "entleert",
    "entleerteren": "entleert",
    "entleerterer": "entleert",
    "entleerteres": "entleert",
    "entleertes": "entleert",
    "entleertest": "entleeren",
    "entleerteste": "entleert",
    "entleertestem": "entleert",
    "entleertesten": "entleert",
    "entleertester": "entleert",
    "entleertestes": "entleert",
    "entleertet": "entleeren",
    "entlegene": "entlegen",
    "entlegenem": "entlegen",
    "entlegenen": "entlegen",
    "entlegener": "entlegen",
    "entlegenere": "entlegen",
    "entlegenerem": "entlegen",
    "entlegeneren": "entlegen",
    "entlegenerer": "entlegen",
    "entlegeneres": "entlegen",
    "entlegenes": "entlegen",
    "entlegenste": "entlegen",
    "entlegenstem": "entlegen",
    "entlegensten": "entlegen",
    "entlegenster": "entlegen",
    "entlegenstes": "entlegen",
    "entleihe": "entleihen",
    "entleihend": "entleihen",
    "entleihende": "entleihend",
    "entleihendem": "entleihend",
    "entleihenden": "entleihend",
    "entleihender": "entleihend",
    "entleihendes": "entleihend",
    "entleihest": "entleihen",
    "entleihet": "entleihen",
    "entleihst": "entleihen",
    "entleiht": "entleihen",
    "entliberalisiere": "entliberalisieren",
    "entliberalisierend": "entliberalisieren",
    "entliberalisierende": "entliberalisierend",
    "entliberalisierendem": "entliberalisierend",
    "entliberalisierenden": "entliberalisierend",
    "entliberalisierender": "entliberalisierend",
    "entliberalisierendere": "entliberalisierend",
    "entliberalisierenderem": "entliberalisierend",
    "entliberalisierenderen": "entliberalisierend",
    "entliberalisierenderer": "entliberalisierend",
    "entliberalisierenderes": "entliberalisierend",
    "entliberalisierendes": "entliberalisierend",
    "entliberalisierendste": "entliberalisierend",
    "entliberalisierendstem": "entliberalisierend",
    "entliberalisierendsten": "entliberalisierend",
    "entliberalisierendster": "entliberalisierend",
    "entliberalisierendstes": "entliberalisierend",
    "entliberalisierest": "entliberalisieren",
    "entliberalisieret": "entliberalisieren",
    "entliberalisierst": "entliberalisieren",
    "entliberalisiert": "entliberalisieren",
    "entliberalisierte": "entliberalisieren",
    "entliberalisiertem": "entliberalisiert",
    "entliberalisierten": "entliberalisieren",
    "entliberalisierter": "entliberalisiert",
    "entliberalisiertere": "entliberalisiert",
    "entliberalisierterem": "entliberalisiert",
    "entliberalisierteren": "entliberalisiert",
    "entliberalisierterer": "entliberalisiert",
    "entliberalisierteres": "entliberalisiert",
    "entliberalisiertes": "entliberalisiert",
    "entliberalisiertest": "entliberalisieren",
    "entliberalisierteste": "entliberalisiert",
    "entliberalisiertestem": "entliberalisiert",
    "entliberalisiertesten": "entliberalisiert",
    "entliberalisiertester": "entliberalisiert",
    "entliberalisiertestes": "entliberalisiert",
    "entliberalisiertet": "entliberalisieren",
    "entlief": "entlaufen",
    "entliefe": "entlaufen",
    "entliefen": "entlaufen",
    "entliefest": "entlaufen",
    "entliefet": "entlaufen",
    "entliefst": "entlaufen",
    "entlieft": "entlaufen",
    "entlieh": "entleihen",
    "entliehe": "entleihen",
    "entliehen": "entleihen",
    "entliehene": "entliehen",
    "entliehenem": "entliehen",
    "entliehenen": "entliehen",
    "entliehener": "entliehen",
    "entliehenes": "entliehen",
    "entliehest": "entleihen",
    "entliehet": "entleihen",
    "entliehst": "entleihen",
    "entlieht": "entleihen",
    "entließ": "entlassen",
    "entließe": "entlassen",
    "entließen": "entlassen",
    "entließest": "entlassen",
    "entließet": "entlassen",
    "entließt": "entlassen",
    "entlobe": "entloben",
    "entlobend": "entloben",
    "entlobende": "entlobend",
    "entlobendem": "entlobend",
    "entlobenden": "entlobend",
    "entlobender": "entlobend",
    "entlobendes": "entlobend",
    "entlobest": "entloben",
    "entlobet": "entloben",
    "entlobst": "entloben",
    "entlobt": "entloben",
    "entlobte": "entloben",
    "entlobtem": "entlobt",
    "entlobten": "entloben",
    "entlobter": "entlobt",
    "entlobtes": "entlobt",
    "entlobtest": "entloben",
    "entlobtet": "entloben",
    "entlohne": "entlohnen",
    "entlohnend": "entlohnen",
    "entlohnende": "entlohnend",
    "entlohnendem": "entlohnend",
    "entlohnenden": "entlohnend",
    "entlohnender": "entlohnend",
    "entlohnendes": "entlohnend",
    "entlohnest": "entlohnen",
    "entlohnet": "entlohnen",
    "entlohnst": "entlohnen",
    "entlohnt": "entlohnen",
    "entlohnte": "entlohnen",
    "entlohntem": "entlohnt",
    "entlohnten": "entlohnen",
    "entlohnter": "entlohnt",
    "entlohntes": "entlohnt",
    "entlohntest": "entlohnen",
    "entlohntet": "entlohnen",
    "entlud": "entladen",
    "entluden": "entladen",
    "entludest": "entladen",
    "entludet": "entladen",
    "entlädst": "entladen",
    "entlädt": "entladen",
    "entläufst": "entlaufen",
    "entläuft": "entlaufen",
    "entläßt": "entlassen",
    "entlüde": "entladen",
    "entlüden": "entladen",
    "entlüdest": "entladen",
    "entlüdet": "entladen",
    "entlüfte": "entlüften",
    "entlüftend": "entlüften",
    "entlüftende": "entlüftend",
    "entlüftendem": "entlüftend",
    "entlüftenden": "entlüftend",
    "entlüftender": "entlüftend",
    "entlüftendere": "entlüftend",
    "entlüftenderem": "entlüftend",
    "entlüftenderen": "entlüftend",
    "entlüftenderer": "entlüftend",
    "entlüftenderes": "entlüftend",
    "entlüftendes": "entlüftend",
    "entlüftendste": "entlüftend",
    "entlüftendstem": "entlüftend",
    "entlüftendsten": "entlüftend",
    "entlüftendster": "entlüftend",
    "entlüftendstes": "entlüftend",
    "entlüftest": "entlüften",
    "entlüftet": "entlüften",
    "entlüftete": "entlüften",
    "entlüftetem": "entlüftet",
    "entlüfteten": "entlüften",
    "entlüfteter": "entlüftet",
    "entlüftetere": "entlüftet",
    "entlüfteterem": "entlüftet",
    "entlüfteteren": "entlüftet",
    "entlüfteterer": "entlüftet",
    "entlüfteteres": "entlüftet",
    "entlüftetes": "entlüftet",
    "entlüftetest": "entlüften",
    "entlüfteteste": "entlüftet",
    "entlüftetestem": "entlüftet",
    "entlüftetesten": "entlüftet",
    "entlüftetester": "entlüftet",
    "entlüftetestes": "entlüftet",
    "entlüftetet": "entlüften",
    "entmachte": "entmachten",
    "entmachtend": "entmachten",
    "entmachtende": "entmachtend",
    "entmachtendem": "entmachtend",
    "entmachtenden": "entmachtend",
    "entmachtender": "entmachtend",
    "entmachtendes": "entmachtend",
    "entmachtest": "entmachten",
    "entmachtet": "entmachten",
    "entmachtete": "entmachten",
    "entmachtetem": "entmachtet",
    "entmachteten": "entmachten",
    "entmachteter": "entmachtet",
    "entmachtetes": "entmachtet",
    "entmachtetest": "entmachten",
    "entmachtetet": "entmachten",
    "entmetallisiere": "entmetallisieren",
    "entmetallisierend": "entmetallisieren",
    "entmetallisierende": "entmetallisierend",
    "entmetallisierendem": "entmetallisierend",
    "entmetallisierenden": "entmetallisierend",
    "entmetallisierender": "entmetallisierend",
    "entmetallisierendere": "entmetallisierend",
    "entmetallisierenderem": "entmetallisierend",
    "entmetallisierenderen": "entmetallisierend",
    "entmetallisierenderer": "entmetallisierend",
    "entmetallisierenderes": "entmetallisierend",
    "entmetallisierendes": "entmetallisierend",
    "entmetallisierendste": "entmetallisierend",
    "entmetallisierendstem": "entmetallisierend",
    "entmetallisierendsten": "entmetallisierend",
    "entmetallisierendster": "entmetallisierend",
    "entmetallisierendstes": "entmetallisierend",
    "entmetallisierest": "entmetallisieren",
    "entmetallisieret": "entmetallisieren",
    "entmetallisierst": "entmetallisieren",
    "entmetallisiert": "entmetallisieren",
    "entmetallisierte": "entmetallisieren",
    "entmetallisiertem": "entmetallisiert",
    "entmetallisierten": "entmetallisieren",
    "entmetallisierter": "entmetallisiert",
    "entmetallisiertere": "entmetallisiert",
    "entmetallisierterem": "entmetallisiert",
    "entmetallisierteren": "entmetallisiert",
    "entmetallisierterer": "entmetallisiert",
    "entmetallisierteres": "entmetallisiert",
    "entmetallisiertes": "entmetallisiert",
    "entmetallisiertest": "entmetallisieren",
    "entmetallisierteste": "entmetallisiert",
    "entmetallisiertestem": "entmetallisiert",
    "entmetallisiertesten": "entmetallisiert",
    "entmetallisiertester": "entmetallisiert",
    "entmetallisiertestes": "entmetallisiert",
    "entmetallisiertet": "entmetallisieren",
    "entmiefe": "entmiefen",
    "entmiefend": "entmiefen",
    "entmiefende": "entmiefend",
    "entmiefendem": "entmiefend",
    "entmiefenden": "entmiefend",
    "entmiefender": "entmiefend",
    "entmiefendere": "entmiefend",
    "entmiefenderem": "entmiefend",
    "entmiefenderen": "entmiefend",
    "entmiefenderer": "entmiefend",
    "entmiefenderes": "entmiefend",
    "entmiefendes": "entmiefend",
    "entmiefendste": "entmiefend",
    "entmiefendstem": "entmiefend",
    "entmiefendsten": "entmiefend",
    "entmiefendster": "entmiefend",
    "entmiefendstes": "entmiefend",
    "entmiefest": "entmiefen",
    "entmiefet": "entmiefen",
    "entmiefst": "entmiefen",
    "entmieft": "entmiefen",
    "entmiefte": "entmiefen",
    "entmieftem": "entmieft",
    "entmieften": "entmiefen",
    "entmiefter": "entmieft",
    "entmieftere": "entmieft",
    "entmiefterem": "entmieft",
    "entmiefteren": "entmieft",
    "entmiefterer": "entmieft",
    "entmiefteres": "entmieft",
    "entmieftes": "entmieft",
    "entmieftest": "entmiefen",
    "entmiefteste": "entmieft",
    "entmieftestem": "entmieft",
    "entmieftesten": "entmieft",
    "entmieftester": "entmieft",
    "entmieftestes": "entmieft",
    "entmieftet": "entmiefen",
    "entmilitarisiere": "entmilitarisieren",
    "entmilitarisierend": "entmilitarisieren",
    "entmilitarisierende": "entmilitarisierend",
    "entmilitarisierendem": "entmilitarisierend",
    "entmilitarisierenden": "entmilitarisierend",
    "entmilitarisierender": "entmilitarisierend",
    "entmilitarisierendes": "entmilitarisierend",
    "entmilitarisierest": "entmilitarisieren",
    "entmilitarisieret": "entmilitarisieren",
    "entmilitarisierst": "entmilitarisieren",
    "entmilitarisiert": "entmilitarisieren",
    "entmilitarisierte": "entmilitarisieren",
    "entmilitarisiertem": "entmilitarisiert",
    "entmilitarisierten": "entmilitarisieren",
    "entmilitarisierter": "entmilitarisiert",
    "entmilitarisiertes": "entmilitarisiert",
    "entmilitarisiertest": "entmilitarisieren",
    "entmilitarisiertet": "entmilitarisieren",
    "entmiste": "entmisten",
    "entmistend": "entmisten",
    "entmistende": "entmistend",
    "entmistendem": "entmistend",
    "entmistenden": "entmistend",
    "entmistender": "entmistend",
    "entmistendere": "entmistend",
    "entmistenderem": "entmistend",
    "entmistenderen": "entmistend",
    "entmistenderer": "entmistend",
    "entmistenderes": "entmistend",
    "entmistendes": "entmistend",
    "entmistendste": "entmistend",
    "entmistendstem": "entmistend",
    "entmistendsten": "entmistend",
    "entmistendster": "entmistend",
    "entmistendstes": "entmistend",
    "entmistest": "entmisten",
    "entmistet": "entmisten",
    "entmistete": "entmisten",
    "entmistetem": "entmistet",
    "entmisteten": "entmisten",
    "entmisteter": "entmistet",
    "entmistetere": "entmistet",
    "entmisteterem": "entmistet",
    "entmisteteren": "entmistet",
    "entmisteterer": "entmistet",
    "entmisteteres": "entmistet",
    "entmistetes": "entmistet",
    "entmistetest": "entmisten",
    "entmisteteste": "entmistet",
    "entmistetestem": "entmistet",
    "entmistetesten": "entmistet",
    "entmistetester": "entmistet",
    "entmistetestes": "entmistet",
    "entmistetet": "entmisten",
    "entmonopolisiere": "entmonopolisieren",
    "entmonopolisierend": "entmonopolisieren",
    "entmonopolisierende": "entmonopolisierend",
    "entmonopolisierendem": "entmonopolisierend",
    "entmonopolisierenden": "entmonopolisierend",
    "entmonopolisierender": "entmonopolisierend",
    "entmonopolisierendere": "entmonopolisierend",
    "entmonopolisierenderem": "entmonopolisierend",
    "entmonopolisierenderen": "entmonopolisierend",
    "entmonopolisierenderer": "entmonopolisierend",
    "entmonopolisierenderes": "entmonopolisierend",
    "entmonopolisierendes": "entmonopolisierend",
    "entmonopolisierendste": "entmonopolisierend",
    "entmonopolisierendstem": "entmonopolisierend",
    "entmonopolisierendsten": "entmonopolisierend",
    "entmonopolisierendster": "entmonopolisierend",
    "entmonopolisierendstes": "entmonopolisierend",
    "entmonopolisierest": "entmonopolisieren",
    "entmonopolisieret": "entmonopolisieren",
    "entmonopolisierst": "entmonopolisieren",
    "entmonopolisiert": "entmonopolisieren",
    "entmonopolisierte": "entmonopolisieren",
    "entmonopolisiertem": "entmonopolisiert",
    "entmonopolisierten": "entmonopolisieren",
    "entmonopolisierter": "entmonopolisiert",
    "entmonopolisiertere": "entmonopolisiert",
    "entmonopolisierterem": "entmonopolisiert",
    "entmonopolisierteren": "entmonopolisiert",
    "entmonopolisierterer": "entmonopolisiert",
    "entmonopolisierteres": "entmonopolisiert",
    "entmonopolisiertes": "entmonopolisiert",
    "entmonopolisiertest": "entmonopolisieren",
    "entmonopolisierteste": "entmonopolisiert",
    "entmonopolisiertestem": "entmonopolisiert",
    "entmonopolisiertesten": "entmonopolisiert",
    "entmonopolisiertester": "entmonopolisiert",
    "entmonopolisiertestes": "entmonopolisiert",
    "entmonopolisiertet": "entmonopolisieren",
    "entmutige": "entmutigen",
    "entmutigend": "entmutigen",
    "entmutigende": "entmutigend",
    "entmutigendem": "entmutigend",
    "entmutigenden": "entmutigend",
    "entmutigender": "entmutigend",
    "entmutigendere": "entmutigend",
    "entmutigenderem": "entmutigend",
    "entmutigenderen": "entmutigend",
    "entmutigenderer": "entmutigend",
    "entmutigenderes": "entmutigend",
    "entmutigendes": "entmutigend",
    "entmutigendste": "entmutigend",
    "entmutigendstem": "entmutigend",
    "entmutigendsten": "entmutigend",
    "entmutigendster": "entmutigend",
    "entmutigendstes": "entmutigend",
    "entmutigest": "entmutigen",
    "entmutiget": "entmutigen",
    "entmutigst": "entmutigen",
    "entmutigt": "entmutigen",
    "entmutigte": "entmutigen",
    "entmutigtem": "entmutigt",
    "entmutigten": "entmutigen",
    "entmutigter": "entmutigt",
    "entmutigtere": "entmutigt",
    "entmutigterem": "entmutigt",
    "entmutigteren": "entmutigt",
    "entmutigterer": "entmutigt",
    "entmutigteres": "entmutigt",
    "entmutigtes": "entmutigt",
    "entmutigtest": "entmutigen",
    "entmutigteste": "entmutigt",
    "entmutigtestem": "entmutigt",
    "entmutigtesten": "entmutigt",
    "entmutigtester": "entmutigt",
    "entmutigtestes": "entmutigt",
    "entmutigtet": "entmutigen",
    "entmystifiziere": "entmystifizieren",
    "entmystifizierend": "entmystifizieren",
    "entmystifizierende": "entmystifizierend",
    "entmystifizierendem": "entmystifizierend",
    "entmystifizierenden": "entmystifizierend",
    "entmystifizierender": "entmystifizierend",
    "entmystifizierendere": "entmystifizierend",
    "entmystifizierenderem": "entmystifizierend",
    "entmystifizierenderen": "entmystifizierend",
    "entmystifizierenderer": "entmystifizierend",
    "entmystifizierenderes": "entmystifizierend",
    "entmystifizierendes": "entmystifizierend",
    "entmystifizierendste": "entmystifizierend",
    "entmystifizierendstem": "entmystifizierend",
    "entmystifizierendsten": "entmystifizierend",
    "entmystifizierendster": "entmystifizierend",
    "entmystifizierendstes": "entmystifizierend",
    "entmystifizierest": "entmystifizieren",
    "entmystifizieret": "entmystifizieren",
    "entmystifizierst": "entmystifizieren",
    "entmystifiziert": "entmystifizieren",
    "entmystifizierte": "entmystifizieren",
    "entmystifiziertem": "entmystifiziert",
    "entmystifizierten": "entmystifizieren",
    "entmystifizierter": "entmystifiziert",
    "entmystifiziertere": "entmystifiziert",
    "entmystifizierterem": "entmystifiziert",
    "entmystifizierteren": "entmystifiziert",
    "entmystifizierterer": "entmystifiziert",
    "entmystifizierteres": "entmystifiziert",
    "entmystifiziertes": "entmystifiziert",
    "entmystifiziertest": "entmystifizieren",
    "entmystifizierteste": "entmystifiziert",
    "entmystifiziertestem": "entmystifiziert",
    "entmystifiziertesten": "entmystifiziert",
    "entmystifiziertester": "entmystifiziert",
    "entmystifiziertestes": "entmystifiziert",
    "entmystifiziertet": "entmystifizieren",
    "entmündige": "entmündigen",
    "entmündigend": "entmündigen",
    "entmündigende": "entmündigend",
    "entmündigendem": "entmündigend",
    "entmündigenden": "entmündigend",
    "entmündigender": "entmündigend",
    "entmündigendere": "entmündigend",
    "entmündigenderem": "entmündigend",
    "entmündigenderen": "entmündigend",
    "entmündigenderer": "entmündigend",
    "entmündigenderes": "entmündigend",
    "entmündigendes": "entmündigend",
    "entmündigendste": "entmündigend",
    "entmündigendstem": "entmündigend",
    "entmündigendsten": "entmündigend",
    "entmündigendster": "entmündigend",
    "entmündigendstes": "entmündigend",
    "entmündigest": "entmündigen",
    "entmündiget": "entmündigen",
    "entmündigst": "entmündigen",
    "entmündigt": "entmündigen",
    "entmündigte": "entmündigen",
    "entmündigtem": "entmündigt",
    "entmündigten": "entmündigen",
    "entmündigter": "entmündigt",
    "entmündigtere": "entmündigt",
    "entmündigterem": "entmündigt",
    "entmündigteren": "entmündigt",
    "entmündigterer": "entmündigt",
    "entmündigteres": "entmündigt",
    "entmündigtes": "entmündigt",
    "entmündigtest": "entmündigen",
    "entmündigteste": "entmündigt",
    "entmündigtestem": "entmündigt",
    "entmündigtesten": "entmündigt",
    "entmündigtester": "entmündigt",
    "entmündigtestes": "entmündigt",
    "entmündigtet": "entmündigen",
    "entnahm": "entnehmen",
    "entnahmst": "entnehmen",
    "entnahmt": "entnehmen",
    "entnaturalisiere": "entnaturalisieren",
    "entnaturalisierend": "entnaturalisieren",
    "entnaturalisierende": "entnaturalisierend",
    "entnaturalisierendem": "entnaturalisierend",
    "entnaturalisierenden": "entnaturalisierend",
    "entnaturalisierender": "entnaturalisierend",
    "entnaturalisierendes": "entnaturalisierend",
    "entnaturalisierest": "entnaturalisieren",
    "entnaturalisieret": "entnaturalisieren",
    "entnaturalisierst": "entnaturalisieren",
    "entnaturalisiert": "entnaturalisieren",
    "entnaturalisierte": "entnaturalisieren",
    "entnaturalisiertem": "entnaturalisiert",
    "entnaturalisierten": "entnaturalisieren",
    "entnaturalisierter": "entnaturalisiert",
    "entnaturalisiertes": "entnaturalisiert",
    "entnaturalisiertest": "entnaturalisieren",
    "entnaturalisiertet": "entnaturalisieren",
    "entnazifiziere": "entnazifizieren",
    "entnazifizierend": "entnazifizieren",
    "entnazifizierende": "entnazifizierend",
    "entnazifizierendem": "entnazifizierend",
    "entnazifizierenden": "entnazifizierend",
    "entnazifizierender": "entnazifizierend",
    "entnazifizierendes": "entnazifizierend",
    "entnazifizierest": "entnazifizieren",
    "entnazifizieret": "entnazifizieren",
    "entnazifizierst": "entnazifizieren",
    "entnazifiziert": "entnazifizieren",
    "entnazifizierte": "entnazifizieren",
    "entnazifiziertem": "entnazifiziert",
    "entnazifizierten": "entnazifizieren",
    "entnazifizierter": "entnazifiziert",
    "entnazifiziertere": "entnazifiziert",
    "entnazifizierterem": "entnazifiziert",
    "entnazifizierteren": "entnazifiziert",
    "entnazifizierterer": "entnazifiziert",
    "entnazifizierteres": "entnazifiziert",
    "entnazifiziertes": "entnazifiziert",
    "entnazifiziertest": "entnazifizieren",
    "entnazifizierteste": "entnazifiziert",
    "entnazifiziertestem": "entnazifiziert",
    "entnazifiziertesten": "entnazifiziert",
    "entnazifiziertester": "entnazifiziert",
    "entnazifiziertestes": "entnazifiziert",
    "entnazifiziertet": "entnazifizieren",
    "entnehme": "entnehmen",
    "entnehmend": "entnehmen",
    "entnehmende": "entnehmend",
    "entnehmendem": "entnehmend",
    "entnehmenden": "entnehmend",
    "entnehmender": "entnehmend",
    "entnehmendes": "entnehmend",
    "entnehmest": "entnehmen",
    "entnehmet": "entnehmen",
    "entnehmt": "entnehmen",
    "entnerve": "entnerven",
    "entnervend": "entnerven",
    "entnervende": "entnervend",
    "entnervendem": "entnervend",
    "entnervenden": "entnervend",
    "entnervender": "entnervend",
    "entnervendere": "entnervend",
    "entnervenderem": "entnervend",
    "entnervenderen": "entnervend",
    "entnervenderer": "entnervend",
    "entnervenderes": "entnervend",
    "entnervendes": "entnervend",
    "entnervendste": "entnervend",
    "entnervendstem": "entnervend",
    "entnervendsten": "entnervend",
    "entnervendster": "entnervend",
    "entnervendstes": "entnervend",
    "entnervest": "entnerven",
    "entnervet": "entnerven",
    "entnervst": "entnerven",
    "entnervt": "entnerven",
    "entnervte": "entnerven",
    "entnervtem": "entnervt",
    "entnervten": "entnerven",
    "entnervter": "entnervt",
    "entnervtere": "entnervt",
    "entnervterem": "entnervt",
    "entnervteren": "entnervt",
    "entnervterer": "entnervt",
    "entnervteres": "entnervt",
    "entnervtes": "entnervt",
    "entnervtest": "entnerven",
    "entnervteste": "entnervt",
    "entnervtestem": "entnervt",
    "entnervtesten": "entnervt",
    "entnervtester": "entnervt",
    "entnervtestes": "entnervt",
    "entnervtet": "entnerven",
    "entnimm": "entnehmen",
    "entnimmst": "entnehmen",
    "entnimmt": "entnehmen",
    "entnommen": "entnehmen",
    "entnommene": "entnommen",
    "entnommenem": "entnommen",
    "entnommenen": "entnommen",
    "entnommener": "entnommen",
    "entnommenes": "entnommen",
    "entnähme": "entnehmen",
    "entnähmen": "entnehmen",
    "entnähmest": "entnehmen",
    "entnähmet": "entnehmen",
    "entnässe": "entnässen",
    "entnässend": "entnässen",
    "entnässende": "entnässend",
    "entnässendem": "entnässend",
    "entnässenden": "entnässend",
    "entnässender": "entnässend",
    "entnässendes": "entnässend",
    "entnässest": "entnässen",
    "entnässet": "entnässen",
    "entnäßt": "entnässen",
    "entnäßte": "entnässen",
    "entnäßtem": "entnäßt",
    "entnäßten": "entnässen",
    "entnäßter": "entnäßt",
    "entnäßtes": "entnäßt",
    "entnäßtest": "entnässen",
    "entnäßtet": "entnässen",
    "entomologischem": "entomologisch",
    "entomologischen": "entomologisch",
    "entomologischer": "entomologisch",
    "entomologisches": "entomologisch",
    "entpacke": "entpacken",
    "entpackend": "entpacken",
    "entpackende": "entpackend",
    "entpackendem": "entpackend",
    "entpackenden": "entpackend",
    "entpackender": "entpackend",
    "entpackendes": "entpackend",
    "entpackest": "entpacken",
    "entpacket": "entpacken",
    "entpackst": "entpacken",
    "entpackt": "entpacken",
    "entpackte": "entpacken",
    "entpacktem": "entpackt",
    "entpackten": "entpacken",
    "entpackter": "entpackt",
    "entpacktes": "entpackt",
    "entpacktest": "entpacken",
    "entpacktet": "entpacken",
    "entpelle": "entpellen",
    "entpellend": "entpellen",
    "entpellende": "entpellend",
    "entpellendem": "entpellend",
    "entpellenden": "entpellend",
    "entpellender": "entpellend",
    "entpellendere": "entpellend",
    "entpellenderem": "entpellend",
    "entpellenderen": "entpellend",
    "entpellenderer": "entpellend",
    "entpellenderes": "entpellend",
    "entpellendes": "entpellend",
    "entpellendste": "entpellend",
    "entpellendstem": "entpellend",
    "entpellendsten": "entpellend",
    "entpellendster": "entpellend",
    "entpellendstes": "entpellend",
    "entpellest": "entpellen",
    "entpellet": "entpellen",
    "entpellst": "entpellen",
    "entpellt": "entpellen",
    "entpellte": "entpellen",
    "entpelltem": "entpellt",
    "entpellten": "entpellen",
    "entpellter": "entpellt",
    "entpelltere": "entpellt",
    "entpellterem": "entpellt",
    "entpellteren": "entpellt",
    "entpellterer": "entpellt",
    "entpellteres": "entpellt",
    "entpelltes": "entpellt",
    "entpelltest": "entpellen",
    "entpellteste": "entpellt",
    "entpelltestem": "entpellt",
    "entpelltesten": "entpellt",
    "entpelltester": "entpellt",
    "entpelltestes": "entpellt",
    "entpelltet": "entpellen",
    "entpolitisiere": "entpolitisieren",
    "entpolitisierend": "entpolitisieren",
    "entpolitisierende": "entpolitisierend",
    "entpolitisierendem": "entpolitisierend",
    "entpolitisierenden": "entpolitisierend",
    "entpolitisierender": "entpolitisierend",
    "entpolitisierendere": "entpolitisierend",
    "entpolitisierenderem": "entpolitisierend",
    "entpolitisierenderen": "entpolitisierend",
    "entpolitisierenderer": "entpolitisierend",
    "entpolitisierenderes": "entpolitisierend",
    "entpolitisierendes": "entpolitisierend",
    "entpolitisierendste": "entpolitisierend",
    "entpolitisierendstem": "entpolitisierend",
    "entpolitisierendsten": "entpolitisierend",
    "entpolitisierendster": "entpolitisierend",
    "entpolitisierendstes": "entpolitisierend",
    "entpolitisierest": "entpolitisieren",
    "entpolitisieret": "entpolitisieren",
    "entpolitisierst": "entpolitisieren",
    "entpolitisiert": "entpolitisieren",
    "entpolitisierte": "entpolitisieren",
    "entpolitisiertem": "entpolitisiert",
    "entpolitisierten": "entpolitisieren",
    "entpolitisierter": "entpolitisiert",
    "entpolitisiertere": "entpolitisiert",
    "entpolitisierterem": "entpolitisiert",
    "entpolitisierteren": "entpolitisiert",
    "entpolitisierterer": "entpolitisiert",
    "entpolitisierteres": "entpolitisiert",
    "entpolitisiertes": "entpolitisiert",
    "entpolitisiertest": "entpolitisieren",
    "entpolitisierteste": "entpolitisiert",
    "entpolitisiertestem": "entpolitisiert",
    "entpolitisiertesten": "entpolitisiert",
    "entpolitisiertester": "entpolitisiert",
    "entpolitisiertestes": "entpolitisiert",
    "entpolitisiertet": "entpolitisieren",
    "entpudere": "entpudern",
    "entpudernd": "entpudern",
    "entpudernde": "entpudernd",
    "entpuderndem": "entpudernd",
    "entpudernden": "entpudernd",
    "entpudernder": "entpudernd",
    "entpuderndere": "entpudernd",
    "entpudernderem": "entpudernd",
    "entpudernderen": "entpudernd",
    "entpudernderer": "entpudernd",
    "entpudernderes": "entpudernd",
    "entpuderndes": "entpudernd",
    "entpuderndste": "entpudernd",
    "entpuderndstem": "entpudernd",
    "entpuderndsten": "entpudernd",
    "entpuderndster": "entpudernd",
    "entpuderndstes": "entpudernd",
    "entpuderst": "entpudern",
    "entpudert": "entpudern",
    "entpuderte": "entpudern",
    "entpudertem": "entpudert",
    "entpuderten": "entpudern",
    "entpuderter": "entpudert",
    "entpudertere": "entpudert",
    "entpuderterem": "entpudert",
    "entpuderteren": "entpudert",
    "entpuderterer": "entpudert",
    "entpuderteres": "entpudert",
    "entpudertes": "entpudert",
    "entpudertest": "entpudern",
    "entpuderteste": "entpudert",
    "entpudertestem": "entpudert",
    "entpudertesten": "entpudert",
    "entpudertester": "entpudert",
    "entpudertestes": "entpudert",
    "entpudertet": "entpudern",
    "entpuppe": "entpuppen",
    "entpuppend": "entpuppen",
    "entpuppende": "entpuppend",
    "entpuppendem": "entpuppend",
    "entpuppenden": "entpuppend",
    "entpuppender": "entpuppend",
    "entpuppendes": "entpuppend",
    "entpuppest": "entpuppen",
    "entpuppet": "entpuppen",
    "entpuppst": "entpuppen",
    "entpuppt": "entpuppen",
    "entpuppte": "entpuppen",
    "entpupptem": "entpuppt",
    "entpuppten": "entpuppen",
    "entpuppter": "entpuppt",
    "entpupptes": "entpuppt",
    "entpupptest": "entpuppen",
    "entpupptet": "entpuppen",
    "entrann": "entrinnen",
    "entrannen": "entrinnen",
    "entrannst": "entrinnen",
    "entrannt": "entrinnen",
    "entrausche": "entrauschen",
    "entrauschend": "entrauschen",
    "entrauschende": "entrauschend",
    "entrauschendem": "entrauschend",
    "entrauschenden": "entrauschend",
    "entrauschender": "entrauschend",
    "entrauschendes": "entrauschend",
    "entrauschest": "entrauschen",
    "entrauschet": "entrauschen",
    "entrauschst": "entrauschen",
    "entrauscht": "entrauschen",
    "entrauschte": "entrauschen",
    "entrauschtem": "entrauscht",
    "entrauschten": "entrauschen",
    "entrauschter": "entrauscht",
    "entrauschtes": "entrauscht",
    "entrauschtest": "entrauschen",
    "entrauschtet": "entrauschen",
    "entreiße": "entreißen",
    "entreißend": "entreißen",
    "entreißende": "entreißend",
    "entreißendem": "entreißend",
    "entreißenden": "entreißend",
    "entreißender": "entreißend",
    "entreißendes": "entreißend",
    "entreißest": "entreißen",
    "entreißet": "entreißen",
    "entreißt": "entreißen",
    "entrichte": "entrichten",
    "entrichtend": "entrichten",
    "entrichtende": "entrichtend",
    "entrichtendem": "entrichtend",
    "entrichtenden": "entrichtend",
    "entrichtender": "entrichtend",
    "entrichtendes": "entrichtend",
    "entrichtest": "entrichten",
    "entrichtet": "entrichten",
    "entrichtete": "entrichten",
    "entrichtetem": "entrichtet",
    "entrichteten": "entrichten",
    "entrichteter": "entrichtet",
    "entrichtetes": "entrichtet",
    "entrichtetest": "entrichten",
    "entrichtetet": "entrichten",
    "entriegele": "entriegeln",
    "entriegelnd": "entriegeln",
    "entriegelnde": "entriegelnd",
    "entriegelndem": "entriegelnd",
    "entriegelnden": "entriegelnd",
    "entriegelnder": "entriegelnd",
    "entriegelndere": "entriegelnd",
    "entriegelnderem": "entriegelnd",
    "entriegelnderen": "entriegelnd",
    "entriegelnderer": "entriegelnd",
    "entriegelnderes": "entriegelnd",
    "entriegelndes": "entriegelnd",
    "entriegelndste": "entriegelnd",
    "entriegelndstem": "entriegelnd",
    "entriegelndsten": "entriegelnd",
    "entriegelndster": "entriegelnd",
    "entriegelndstes": "entriegelnd",
    "entriegelst": "entriegeln",
    "entriegelt": "entriegeln",
    "entriegelte": "entriegeln",
    "entriegeltem": "entriegelt",
    "entriegelten": "entriegeln",
    "entriegelter": "entriegelt",
    "entriegeltere": "entriegelt",
    "entriegelterem": "entriegelt",
    "entriegelteren": "entriegelt",
    "entriegelterer": "entriegelt",
    "entriegelteres": "entriegelt",
    "entriegeltes": "entriegelt",
    "entriegeltest": "entriegeln",
    "entriegelteste": "entriegelt",
    "entriegeltestem": "entriegelt",
    "entriegeltesten": "entriegelt",
    "entriegeltester": "entriegelt",
    "entriegeltestes": "entriegelt",
    "entriegeltet": "entriegeln",
    "entriegle": "entriegeln",
    "entrinne": "entrinnen",
    "entrinnend": "entrinnen",
    "entrinnende": "entrinnend",
    "entrinnendem": "entrinnend",
    "entrinnenden": "entrinnend",
    "entrinnender": "entrinnend",
    "entrinnendes": "entrinnend",
    "entrinnest": "entrinnen",
    "entrinnet": "entrinnen",
    "entrinnst": "entrinnen",
    "entrinnt": "entrinnen",
    "entrisse": "entreißen",
    "entrissen": "entreißen",
    "entrissene": "entrissen",
    "entrissenem": "entrissen",
    "entrissenen": "entrissen",
    "entrissener": "entrissen",
    "entrissenes": "entrissen",
    "entrissest": "entreißen",
    "entrisset": "entreißen",
    "entriß": "entreißen",
    "entrißt": "entreißen",
    "entronnen": "entrinnen",
    "entronnene": "entronnen",
    "entronnenem": "entronnen",
    "entronnenen": "entronnen",
    "entronnener": "entronnen",
    "entronnenere": "entronnen",
    "entronnenerem": "entronnen",
    "entronneneren": "entronnen",
    "entronnenerer": "entronnen",
    "entronneneres": "entronnen",
    "entronnenes": "entronnen",
    "entronnenste": "entronnen",
    "entronnenstem": "entronnen",
    "entronnensten": "entronnen",
    "entronnenster": "entronnen",
    "entronnenstes": "entronnen",
    "entroste": "entrosten",
    "entrostend": "entrosten",
    "entrostende": "entrostend",
    "entrostendem": "entrostend",
    "entrostenden": "entrostend",
    "entrostender": "entrostend",
    "entrostendere": "entrostend",
    "entrostenderem": "entrostend",
    "entrostenderen": "entrostend",
    "entrostenderer": "entrostend",
    "entrostenderes": "entrostend",
    "entrostendes": "entrostend",
    "entrostendste": "entrostend",
    "entrostendstem": "entrostend",
    "entrostendsten": "entrostend",
    "entrostendster": "entrostend",
    "entrostendstes": "entrostend",
    "entrostest": "entrosten",
    "entrostet": "entrosten",
    "entrostete": "entrosten",
    "entrostetem": "entrostet",
    "entrosteten": "entrosten",
    "entrosteter": "entrostet",
    "entrostetere": "entrostet",
    "entrosteterem": "entrostet",
    "entrosteteren": "entrostet",
    "entrosteterer": "entrostet",
    "entrosteteres": "entrostet",
    "entrostetes": "entrostet",
    "entrostetest": "entrosten",
    "entrosteteste": "entrostet",
    "entrostetestem": "entrostet",
    "entrostetesten": "entrostet",
    "entrostetester": "entrostet",
    "entrostetestes": "entrostet",
    "entrostetet": "entrosten",
    "entränne": "entrinnen",
    "entrännen": "entrinnen",
    "entrännest": "entrinnen",
    "entrännet": "entrinnen",
    "enträtsele": "enträtseln",
    "enträtselnd": "enträtseln",
    "enträtselnde": "enträtselnd",
    "enträtselndem": "enträtselnd",
    "enträtselnden": "enträtselnd",
    "enträtselnder": "enträtselnd",
    "enträtselndes": "enträtselnd",
    "enträtselst": "enträtseln",
    "enträtselt": "enträtseln",
    "enträtselte": "enträtseln",
    "enträtseltem": "enträtselt",
    "enträtselten": "enträtseln",
    "enträtselter": "enträtselt",
    "enträtseltes": "enträtselt",
    "enträtseltest": "enträtseln",
    "enträtseltet": "enträtseln",
    "enträtsle": "enträtseln",
    "entrücke": "entrücken",
    "entrückend": "entrücken",
    "entrückende": "entrückend",
    "entrückendem": "entrückend",
    "entrückenden": "entrückend",
    "entrückender": "entrückend",
    "entrückendes": "entrückend",
    "entrückest": "entrücken",
    "entrücket": "entrücken",
    "entrückst": "entrücken",
    "entrückt": "entrücken",
    "entrückte": "entrücken",
    "entrücktem": "entrückt",
    "entrückten": "entrücken",
    "entrückter": "entrückt",
    "entrücktes": "entrückt",
    "entrücktest": "entrücken",
    "entrücktet": "entrücken",
    "entrümpele": "entrümpeln",
    "entrümpelnd": "entrümpeln",
    "entrümpelnde": "entrümpelnd",
    "entrümpelndem": "entrümpelnd",
    "entrümpelnden": "entrümpelnd",
    "entrümpelnder": "entrümpelnd",
    "entrümpelndere": "entrümpelnd",
    "entrümpelnderem": "entrümpelnd",
    "entrümpelnderen": "entrümpelnd",
    "entrümpelnderer": "entrümpelnd",
    "entrümpelnderes": "entrümpelnd",
    "entrümpelndes": "entrümpelnd",
    "entrümpelndste": "entrümpelnd",
    "entrümpelndstem": "entrümpelnd",
    "entrümpelndsten": "entrümpelnd",
    "entrümpelndster": "entrümpelnd",
    "entrümpelndstes": "entrümpelnd",
    "entrümpelst": "entrümpeln",
    "entrümpelt": "entrümpeln",
    "entrümpelte": "entrümpeln",
    "entrümpeltem": "entrümpelt",
    "entrümpelten": "entrümpeln",
    "entrümpelter": "entrümpelt",
    "entrümpeltere": "entrümpelt",
    "entrümpelterem": "entrümpelt",
    "entrümpelteren": "entrümpelt",
    "entrümpelterer": "entrümpelt",
    "entrümpelteres": "entrümpelt",
    "entrümpeltes": "entrümpelt",
    "entrümpeltest": "entrümpeln",
    "entrümpelteste": "entrümpelt",
    "entrümpeltestem": "entrümpelt",
    "entrümpeltesten": "entrümpelt",
    "entrümpeltester": "entrümpelt",
    "entrümpeltestes": "entrümpelt",
    "entrümpeltet": "entrümpeln",
    "entrümple": "entrümpeln",
    "entrüste": "entrüsten",
    "entrüstend": "entrüsten",
    "entrüstende": "entrüstend",
    "entrüstendem": "entrüstend",
    "entrüstenden": "entrüstend",
    "entrüstender": "entrüstend",
    "entrüstendes": "entrüstend",
    "entrüstest": "entrüsten",
    "entrüstet": "entrüsten",
    "entrüstete": "entrüsten",
    "entrüstetem": "entrüstet",
    "entrüsteten": "entrüsten",
    "entrüsteter": "entrüstet",
    "entrüstetere": "entrüstet",
    "entrüsteterem": "entrüstet",
    "entrüsteteren": "entrüstet",
    "entrüsteterer": "entrüstet",
    "entrüsteteres": "entrüstet",
    "entrüstetes": "entrüstet",
    "entrüstetest": "entrüsten",
    "entrüsteteste": "entrüstet",
    "entrüstetestem": "entrüstet",
    "entrüstetesten": "entrüstet",
    "entrüstetester": "entrüstet",
    "entrüstetestes": "entrüstet",
    "entrüstetet": "entrüsten",
    "entsafte": "entsaften",
    "entsaftend": "entsaften",
    "entsaftende": "entsaftend",
    "entsaftendem": "entsaftend",
    "entsaftenden": "entsaftend",
    "entsaftender": "entsaftend",
    "entsaftendes": "entsaftend",
    "entsaftest": "entsaften",
    "entsaftet": "entsaften",
    "entsaftete": "entsaften",
    "entsaftetem": "entsaftet",
    "entsafteten": "entsaften",
    "entsafteter": "entsaftet",
    "entsaftetes": "entsaftet",
    "entsaftetest": "entsaften",
    "entsaftetet": "entsaften",
    "entsage": "entsagen",
    "entsagend": "entsagen",
    "entsagende": "entsagend",
    "entsagendem": "entsagend",
    "entsagenden": "entsagend",
    "entsagender": "entsagend",
    "entsagendes": "entsagend",
    "entsagest": "entsagen",
    "entsaget": "entsagen",
    "entsagst": "entsagen",
    "entsagt": "entsagen",
    "entsagte": "entsagen",
    "entsagtem": "entsagt",
    "entsagten": "entsagen",
    "entsagter": "entsagt",
    "entsagtes": "entsagt",
    "entsagtest": "entsagen",
    "entsagtet": "entsagen",
    "entsagungsvolle": "entsagungsvoll",
    "entsagungsvollem": "entsagungsvoll",
    "entsagungsvollen": "entsagungsvoll",
    "entsagungsvoller": "entsagungsvoll",
    "entsagungsvollere": "entsagungsvoll",
    "entsagungsvollerem": "entsagungsvoll",
    "entsagungsvolleren": "entsagungsvoll",
    "entsagungsvollerer": "entsagungsvoll",
    "entsagungsvolleres": "entsagungsvoll",
    "entsagungsvolles": "entsagungsvoll",
    "entsagungsvollste": "entsagungsvoll",
    "entsagungsvollstem": "entsagungsvoll",
    "entsagungsvollsten": "entsagungsvoll",
    "entsagungsvollster": "entsagungsvoll",
    "entsagungsvollstes": "entsagungsvoll",
    "entsandt": "entsenden",
    "entsandte": "entsandt",
    "entsandtem": "entsandt",
    "entsandten": "entsandt",
    "entsandter": "entsandt",
    "entsandtes": "entsandt",
    "entsandtest": "entsenden",
    "entsandtet": "entsenden",
    "entsank": "entsinken",
    "entsanken": "entsinken",
    "entsankst": "entsinken",
    "entsankt": "entsinken",
    "entsann": "entsinnen",
    "entsannen": "entsinnen",
    "entsannst": "entsinnen",
    "entsannt": "entsinnen",
    "entscheidend": "entscheiden",
    "entscheidende": "entscheidend",
    "entscheidendem": "entscheidend",
    "entscheidenden": "entscheidend",
    "entscheidender": "entscheidend",
    "entscheidendere": "entscheidend",
    "entscheidenderem": "entscheidend",
    "entscheidenderen": "entscheidend",
    "entscheidenderer": "entscheidend",
    "entscheidenderes": "entscheidend",
    "entscheidendes": "entscheidend",
    "entscheidendste": "entscheidend",
    "entscheidendstem": "entscheidend",
    "entscheidendsten": "entscheidend",
    "entscheidendster": "entscheidend",
    "entscheidendstes": "entscheidend",
    "entscheidest": "entscheiden",
    "entscheidet": "entscheiden",
    "entschied": "entscheiden",
    "entschiede": "entscheiden",
    "entschieden": "entscheiden",
    "entschiedene": "entschieden",
    "entschiedenem": "entschieden",
    "entschiedenen": "entschieden",
    "entschiedener": "entschieden",
    "entschiedenere": "entschieden",
    "entschiedenerem": "entschieden",
    "entschiedeneren": "entschieden",
    "entschiedenerer": "entschieden",
    "entschiedeneres": "entschieden",
    "entschiedenes": "entschieden",
    "entschiedenste": "entschieden",
    "entschiedenstem": "entschieden",
    "entschiedensten": "entschieden",
    "entschiedenster": "entschieden",
    "entschiedenstes": "entschieden",
    "entschiedest": "entscheiden",
    "entschiedet": "entscheiden",
    "entschlafe": "entschlafen",
    "entschlafend": "entschlafen",
    "entschlafende": "entschlafend",
    "entschlafendem": "entschlafend",
    "entschlafenden": "entschlafend",
    "entschlafender": "entschlafend",
    "entschlafendes": "entschlafend",
    "entschlafene": "entschlafen",
    "entschlafenem": "entschlafen",
    "entschlafenen": "entschlafen",
    "entschlafener": "entschlafen",
    "entschlafenes": "entschlafen",
    "entschlafest": "entschlafen",
    "entschlafet": "entschlafen",
    "entschlaft": "entschlafen",
    "entschleiche": "entschleichen",
    "entschleichend": "entschleichen",
    "entschleichende": "entschleichend",
    "entschleichendem": "entschleichend",
    "entschleichenden": "entschleichend",
    "entschleichender": "entschleichend",
    "entschleichendes": "entschleichend",
    "entschleichest": "entschleichen",
    "entschleichet": "entschleichen",
    "entschleichst": "entschleichen",
    "entschleicht": "entschleichen",
    "entschleime": "entschleimen",
    "entschleimend": "entschleimen",
    "entschleimende": "entschleimend",
    "entschleimendem": "entschleimend",
    "entschleimenden": "entschleimend",
    "entschleimender": "entschleimend",
    "entschleimendere": "entschleimend",
    "entschleimenderem": "entschleimend",
    "entschleimenderen": "entschleimend",
    "entschleimenderer": "entschleimend",
    "entschleimenderes": "entschleimend",
    "entschleimendes": "entschleimend",
    "entschleimendste": "entschleimend",
    "entschleimendstem": "entschleimend",
    "entschleimendsten": "entschleimend",
    "entschleimendster": "entschleimend",
    "entschleimendstes": "entschleimend",
    "entschleimest": "entschleimen",
    "entschleimet": "entschleimen",
    "entschleimst": "entschleimen",
    "entschleimt": "entschleimen",
    "entschleimte": "entschleimen",
    "entschleimtem": "entschleimt",
    "entschleimten": "entschleimen",
    "entschleimter": "entschleimt",
    "entschleimtere": "entschleimt",
    "entschleimterem": "entschleimt",
    "entschleimteren": "entschleimt",
    "entschleimterer": "entschleimt",
    "entschleimteres": "entschleimt",
    "entschleimtes": "entschleimt",
    "entschleimtest": "entschleimen",
    "entschleimteste": "entschleimt",
    "entschleimtestem": "entschleimt",
    "entschleimtesten": "entschleimt",
    "entschleimtester": "entschleimt",
    "entschleimtestes": "entschleimt",
    "entschleimtet": "entschleimen",
    "entschlich": "entschleichen",
    "entschliche": "entschleichen",
    "entschlichen": "entschleichen",
    "entschlichene": "entschlichen",
    "entschlichenem": "entschlichen",
    "entschlichenen": "entschlichen",
    "entschlichener": "entschlichen",
    "entschlichenes": "entschlichen",
    "entschlichest": "entschleichen",
    "entschlichet": "entschleichen",
    "entschlichst": "entschleichen",
    "entschlicht": "entschleichen",
    "entschlief": "entschlafen",
    "entschliefe": "entschlafen",
    "entschliefen": "entschlafen",
    "entschliefest": "entschlafen",
    "entschliefet": "entschlafen",
    "entschliefst": "entschlafen",
    "entschlieft": "entschlafen",
    "entschließe": "entschließen",
    "entschließend": "entschließen",
    "entschließende": "entschließend",
    "entschließendem": "entschließend",
    "entschließenden": "entschließend",
    "entschließender": "entschließend",
    "entschließendes": "entschließend",
    "entschließest": "entschließen",
    "entschließet": "entschließen",
    "entschließt": "entschließen",
    "entschlossen": "entschließen",
    "entschlossene": "entschlossen",
    "entschlossenem": "entschlossen",
    "entschlossenen": "entschlossen",
    "entschlossener": "entschlossen",
    "entschlossenere": "entschlossen",
    "entschlossenerem": "entschlossen",
    "entschlosseneren": "entschlossen",
    "entschlossenerer": "entschlossen",
    "entschlosseneres": "entschlossen",
    "entschlossenes": "entschlossen",
    "entschlossenste": "entschlossen",
    "entschlossenstem": "entschlossen",
    "entschlossensten": "entschlossen",
    "entschlossenster": "entschlossen",
    "entschlossenstes": "entschlossen",
    "entschloß": "entschließen",
    "entschloßt": "entschließen",
    "entschlummere": "entschlummern",
    "entschlummernd": "entschlummern",
    "entschlummernde": "entschlummernd",
    "entschlummerndem": "entschlummernd",
    "entschlummernden": "entschlummernd",
    "entschlummernder": "entschlummernd",
    "entschlummerndes": "entschlummernd",
    "entschlummerst": "entschlummern",
    "entschlummert": "entschlummern",
    "entschlummerte": "entschlummern",
    "entschlummertem": "entschlummert",
    "entschlummerten": "entschlummern",
    "entschlummerter": "entschlummert",
    "entschlummertes": "entschlummert",
    "entschlummertest": "entschlummern",
    "entschlummertet": "entschlummern",
    "entschläfst": "entschlafen",
    "entschläft": "entschlafen",
    "entschlösse": "entschließen",
    "entschlössen": "entschließen",
    "entschlössest": "entschließen",
    "entschlösset": "entschließen",
    "entschlüpfe": "entschlüpfen",
    "entschlüpfend": "entschlüpfen",
    "entschlüpfende": "entschlüpfend",
    "entschlüpfendem": "entschlüpfend",
    "entschlüpfenden": "entschlüpfend",
    "entschlüpfender": "entschlüpfend",
    "entschlüpfendes": "entschlüpfend",
    "entschlüpfest": "entschlüpfen",
    "entschlüpfet": "entschlüpfen",
    "entschlüpfst": "entschlüpfen",
    "entschlüpft": "entschlüpfen",
    "entschlüpfte": "entschlüpfen",
    "entschlüpftem": "entschlüpft",
    "entschlüpften": "entschlüpfen",
    "entschlüpfter": "entschlüpft",
    "entschlüpftes": "entschlüpft",
    "entschlüpftest": "entschlüpfen",
    "entschlüpftet": "entschlüpfen",
    "entschlüssele": "entschlüsseln",
    "entschlüsselnd": "entschlüsseln",
    "entschlüsselnde": "entschlüsselnd",
    "entschlüsselndem": "entschlüsselnd",
    "entschlüsselnden": "entschlüsselnd",
    "entschlüsselnder": "entschlüsselnd",
    "entschlüsselndes": "entschlüsselnd",
    "entschlüsselst": "entschlüsseln",
    "entschlüsselt": "entschlüsseln",
    "entschlüsselte": "entschlüsseln",
    "entschlüsseltem": "entschlüsselt",
    "entschlüsselten": "entschlüsseln",
    "entschlüsselter": "entschlüsselt",
    "entschlüsseltes": "entschlüsselt",
    "entschlüsseltest": "entschlüsseln",
    "entschlüsseltet": "entschlüsseln",
    "entschlüssle": "entschlüsseln",
    "entschuldbare": "entschuldbar",
    "entschuldbarem": "entschuldbar",
    "entschuldbaren": "entschuldbar",
    "entschuldbarer": "entschuldbar",
    "entschuldbares": "entschuldbar",
    "entschulde": "entschulden",
    "entschuldend": "entschulden",
    "entschuldende": "entschuldend",
    "entschuldendem": "entschuldend",
    "entschuldenden": "entschuldend",
    "entschuldender": "entschuldend",
    "entschuldendere": "entschuldend",
    "entschuldenderem": "entschuldend",
    "entschuldenderen": "entschuldend",
    "entschuldenderer": "entschuldend",
    "entschuldenderes": "entschuldend",
    "entschuldendes": "entschuldend",
    "entschuldendste": "entschuldend",
    "entschuldendstem": "entschuldend",
    "entschuldendsten": "entschuldend",
    "entschuldendster": "entschuldend",
    "entschuldendstes": "entschuldend",
    "entschuldest": "entschulden",
    "entschuldet": "entschulden",
    "entschuldete": "entschulden",
    "entschuldetem": "entschuldet",
    "entschuldeten": "entschulden",
    "entschuldeter": "entschuldet",
    "entschuldetere": "entschuldet",
    "entschuldeterem": "entschuldet",
    "entschuldeteren": "entschuldet",
    "entschuldeterer": "entschuldet",
    "entschuldeteres": "entschuldet",
    "entschuldetes": "entschuldet",
    "entschuldetest": "entschulden",
    "entschuldeteste": "entschuldet",
    "entschuldetestem": "entschuldet",
    "entschuldetesten": "entschuldet",
    "entschuldetester": "entschuldet",
    "entschuldetestes": "entschuldet",
    "entschuldetet": "entschulden",
    "entschuldige": "entschuldigen",
    "entschuldigend": "entschuldigen",
    "entschuldigende": "entschuldigend",
    "entschuldigendem": "entschuldigend",
    "entschuldigenden": "entschuldigend",
    "entschuldigender": "entschuldigend",
    "entschuldigendes": "entschuldigend",
    "entschuldigest": "entschuldigen",
    "entschuldiget": "entschuldigen",
    "entschuldigst": "entschuldigen",
    "entschuldigt": "entschuldigen",
    "entschuldigte": "entschuldigen",
    "entschuldigtem": "entschuldigt",
    "entschuldigten": "entschuldigen",
    "entschuldigter": "entschuldigt",
    "entschuldigtes": "entschuldigt",
    "entschuldigtest": "entschuldigen",
    "entschuldigtet": "entschuldigen",
    "entschwand": "entschwinden",
    "entschwanden": "entschwinden",
    "entschwandest": "entschwinden",
    "entschwandet": "entschwinden",
    "entschwinde": "entschwinden",
    "entschwindend": "entschwinden",
    "entschwindende": "entschwindend",
    "entschwindendem": "entschwindend",
    "entschwindenden": "entschwindend",
    "entschwindender": "entschwindend",
    "entschwindendes": "entschwindend",
    "entschwindest": "entschwinden",
    "entschwindet": "entschwinden",
    "entschwirre": "entschwirren",
    "entschwirrend": "entschwirren",
    "entschwirrende": "entschwirrend",
    "entschwirrendem": "entschwirrend",
    "entschwirrenden": "entschwirrend",
    "entschwirrender": "entschwirrend",
    "entschwirrendes": "entschwirrend",
    "entschwirrest": "entschwirren",
    "entschwirret": "entschwirren",
    "entschwirrst": "entschwirren",
    "entschwirrt": "entschwirren",
    "entschwirrte": "entschwirren",
    "entschwirrtem": "entschwirrt",
    "entschwirrten": "entschwirren",
    "entschwirrter": "entschwirrt",
    "entschwirrtes": "entschwirrt",
    "entschwirrtest": "entschwirren",
    "entschwirrtet": "entschwirren",
    "entschwunden": "entschwinden",
    "entschwundene": "entschwunden",
    "entschwundenem": "entschwunden",
    "entschwundenen": "entschwunden",
    "entschwundener": "entschwunden",
    "entschwundenes": "entschwunden",
    "entschwände": "entschwinden",
    "entschwänden": "entschwinden",
    "entschwändest": "entschwinden",
    "entschwändet": "entschwinden",
    "entschädige": "entschädigen",
    "entschädigend": "entschädigen",
    "entschädigende": "entschädigend",
    "entschädigendem": "entschädigend",
    "entschädigenden": "entschädigend",
    "entschädigender": "entschädigend",
    "entschädigendes": "entschädigend",
    "entschädigest": "entschädigen",
    "entschädiget": "entschädigen",
    "entschädigst": "entschädigen",
    "entschädigt": "entschädigen",
    "entschädigte": "entschädigen",
    "entschädigtem": "entschädigt",
    "entschädigten": "entschädigen",
    "entschädigter": "entschädigt",
    "entschädigtere": "entschädigt",
    "entschädigterem": "entschädigt",
    "entschädigteren": "entschädigt",
    "entschädigterer": "entschädigt",
    "entschädigteres": "entschädigt",
    "entschädigtes": "entschädigt",
    "entschädigtest": "entschädigen",
    "entschädigteste": "entschädigt",
    "entschädigtestem": "entschädigt",
    "entschädigtesten": "entschädigt",
    "entschädigtester": "entschädigt",
    "entschädigtestes": "entschädigt",
    "entschädigtet": "entschädigen",
    "entschärfe": "entschärfen",
    "entschärfend": "entschärfen",
    "entschärfende": "entschärfend",
    "entschärfendem": "entschärfend",
    "entschärfenden": "entschärfend",
    "entschärfender": "entschärfend",
    "entschärfendes": "entschärfend",
    "entschärfest": "entschärfen",
    "entschärfet": "entschärfen",
    "entschärfst": "entschärfen",
    "entschärft": "entschärfen",
    "entschärfte": "entschärfen",
    "entschärftem": "entschärft",
    "entschärften": "entschärfen",
    "entschärfter": "entschärft",
    "entschärftes": "entschärft",
    "entschärftest": "entschärfen",
    "entschärftet": "entschärfen",
    "entsende": "entsenden",
    "entsendend": "entsenden",
    "entsendende": "entsendend",
    "entsendendem": "entsendend",
    "entsendenden": "entsendend",
    "entsendender": "entsendend",
    "entsendendes": "entsendend",
    "entsendest": "entsenden",
    "entsendet": "entsenden",
    "entsendete": "entsenden",
    "entsendetem": "entsendet",
    "entsendeten": "entsenden",
    "entsendeter": "entsendet",
    "entsendetes": "entsendet",
    "entsendetest": "entsenden",
    "entsendetet": "entsenden",
    "entsetzlichem": "entsetzlich",
    "entsetzlichen": "entsetzlich",
    "entsetzlicher": "entsetzlich",
    "entsetzlichere": "entsetzlich",
    "entsetzlicherem": "entsetzlich",
    "entsetzlicheren": "entsetzlich",
    "entsetzlicherer": "entsetzlich",
    "entsetzlicheres": "entsetzlich",
    "entsetzliches": "entsetzlich",
    "entsetzlichste": "entsetzlich",
    "entsetzlichstem": "entsetzlich",
    "entsetzlichsten": "entsetzlich",
    "entsetzlichster": "entsetzlich",
    "entsetzlichstes": "entsetzlich",
    "entsetzte": "entsetzt",
    "entsetztem": "entsetzt",
    "entsetzten": "entsetzt",
    "entsetzter": "entsetzt",
    "entsetztes": "entsetzt",
    "entseuche": "entseuchen",
    "entseuchend": "entseuchen",
    "entseuchende": "entseuchend",
    "entseuchendem": "entseuchend",
    "entseuchenden": "entseuchend",
    "entseuchender": "entseuchend",
    "entseuchendere": "entseuchend",
    "entseuchenderem": "entseuchend",
    "entseuchenderen": "entseuchend",
    "entseuchenderer": "entseuchend",
    "entseuchenderes": "entseuchend",
    "entseuchendes": "entseuchend",
    "entseuchendste": "entseuchend",
    "entseuchendstem": "entseuchend",
    "entseuchendsten": "entseuchend",
    "entseuchendster": "entseuchend",
    "entseuchendstes": "entseuchend",
    "entseuchest": "entseuchen",
    "entseuchet": "entseuchen",
    "entseuchst": "entseuchen",
    "entseucht": "entseuchen",
    "entseuchte": "entseuchen",
    "entseuchtem": "entseucht",
    "entseuchten": "entseuchen",
    "entseuchter": "entseucht",
    "entseuchtere": "entseucht",
    "entseuchterem": "entseucht",
    "entseuchteren": "entseucht",
    "entseuchterer": "entseucht",
    "entseuchteres": "entseucht",
    "entseuchtes": "entseucht",
    "entseuchtest": "entseuchen",
    "entseuchteste": "entseucht",
    "entseuchtestem": "entseucht",
    "entseuchtesten": "entseucht",
    "entseuchtester": "entseucht",
    "entseuchtestes": "entseucht",
    "entseuchtet": "entseuchen",
    "entsichere": "entsichern",
    "entsichernd": "entsichern",
    "entsichernde": "entsichernd",
    "entsicherndem": "entsichernd",
    "entsichernden": "entsichernd",
    "entsichernder": "entsichernd",
    "entsicherndes": "entsichernd",
    "entsicherst": "entsichern",
    "entsichert": "entsichern",
    "entsicherte": "entsichern",
    "entsichertem": "entsichert",
    "entsicherten": "entsichern",
    "entsicherter": "entsichert",
    "entsichertes": "entsichert",
    "entsichertest": "entsichern",
    "entsichertet": "entsichern",
    "entsinke": "entsinken",
    "entsinkend": "entsinken",
    "entsinkende": "entsinkend",
    "entsinkendem": "entsinkend",
    "entsinkenden": "entsinkend",
    "entsinkender": "entsinkend",
    "entsinkendere": "entsinkend",
    "entsinkenderem": "entsinkend",
    "entsinkenderen": "entsinkend",
    "entsinkenderer": "entsinkend",
    "entsinkenderes": "entsinkend",
    "entsinkendes": "entsinkend",
    "entsinkendste": "entsinkend",
    "entsinkendstem": "entsinkend",
    "entsinkendsten": "entsinkend",
    "entsinkendster": "entsinkend",
    "entsinkendstes": "entsinkend",
    "entsinkest": "entsinken",
    "entsinket": "entsinken",
    "entsinkst": "entsinken",
    "entsinkt": "entsinken",
    "entsinne": "entsinnen",
    "entsinnend": "entsinnen",
    "entsinnende": "entsinnend",
    "entsinnendem": "entsinnend",
    "entsinnenden": "entsinnend",
    "entsinnender": "entsinnend",
    "entsinnendes": "entsinnend",
    "entsinnest": "entsinnen",
    "entsinnet": "entsinnen",
    "entsinnst": "entsinnen",
    "entsinnt": "entsinnen",
    "entsonnen": "entsinnen",
    "entsonnene": "entsonnen",
    "entsonnenem": "entsonnen",
    "entsonnenen": "entsonnen",
    "entsonnener": "entsonnen",
    "entsonnenes": "entsonnen",
    "entsorge": "entsorgen",
    "entsorgend": "entsorgen",
    "entsorgende": "entsorgend",
    "entsorgendem": "entsorgend",
    "entsorgenden": "entsorgend",
    "entsorgender": "entsorgend",
    "entsorgendes": "entsorgend",
    "entsorgest": "entsorgen",
    "entsorget": "entsorgen",
    "entsorgst": "entsorgen",
    "entsorgt": "entsorgen",
    "entsorgte": "entsorgen",
    "entsorgtem": "entsorgt",
    "entsorgten": "entsorgen",
    "entsorgter": "entsorgt",
    "entsorgtes": "entsorgt",
    "entsorgtest": "entsorgen",
    "entsorgtet": "entsorgen",
    "entspanne": "entspannen",
    "entspannend": "entspannen",
    "entspannende": "entspannend",
    "entspannendem": "entspannend",
    "entspannenden": "entspannend",
    "entspannender": "entspannend",
    "entspannendere": "entspannend",
    "entspannenderem": "entspannend",
    "entspannenderen": "entspannend",
    "entspannenderer": "entspannend",
    "entspannenderes": "entspannend",
    "entspannendes": "entspannend",
    "entspannendste": "entspannend",
    "entspannendstem": "entspannend",
    "entspannendsten": "entspannend",
    "entspannendster": "entspannend",
    "entspannendstes": "entspannend",
    "entspannest": "entspannen",
    "entspannet": "entspannen",
    "entspannst": "entspannen",
    "entspannt": "entspannen",
    "entspannte": "entspannen",
    "entspanntem": "entspannt",
    "entspannten": "entspannen",
    "entspannter": "entspannt",
    "entspanntere": "entspannt",
    "entspannterem": "entspannt",
    "entspannteren": "entspannt",
    "entspannterer": "entspannt",
    "entspannteres": "entspannt",
    "entspanntes": "entspannt",
    "entspanntest": "entspannen",
    "entspannteste": "entspannt",
    "entspanntestem": "entspannt",
    "entspanntesten": "entspannt",
    "entspanntester": "entspannt",
    "entspanntestes": "entspannt",
    "entspanntet": "entspannen",
    "entspiegele": "entspiegeln",
    "entspiegelnd": "entspiegeln",
    "entspiegelnde": "entspiegelnd",
    "entspiegelndem": "entspiegelnd",
    "entspiegelnden": "entspiegelnd",
    "entspiegelnder": "entspiegelnd",
    "entspiegelndere": "entspiegelnd",
    "entspiegelnderem": "entspiegelnd",
    "entspiegelnderen": "entspiegelnd",
    "entspiegelnderer": "entspiegelnd",
    "entspiegelnderes": "entspiegelnd",
    "entspiegelndes": "entspiegelnd",
    "entspiegelndste": "entspiegelnd",
    "entspiegelndstem": "entspiegelnd",
    "entspiegelndsten": "entspiegelnd",
    "entspiegelndster": "entspiegelnd",
    "entspiegelndstes": "entspiegelnd",
    "entspiegelst": "entspiegeln",
    "entspiegelt": "entspiegeln",
    "entspiegelte": "entspiegeln",
    "entspiegeltem": "entspiegelt",
    "entspiegelten": "entspiegeln",
    "entspiegelter": "entspiegelt",
    "entspiegeltere": "entspiegelt",
    "entspiegelterem": "entspiegelt",
    "entspiegelteren": "entspiegelt",
    "entspiegelterer": "entspiegelt",
    "entspiegelteres": "entspiegelt",
    "entspiegeltes": "entspiegelt",
    "entspiegeltest": "entspiegeln",
    "entspiegelteste": "entspiegelt",
    "entspiegeltestem": "entspiegelt",
    "entspiegeltesten": "entspiegelt",
    "entspiegeltester": "entspiegelt",
    "entspiegeltestes": "entspiegelt",
    "entspiegeltet": "entspiegeln",
    "entspiegle": "entspiegeln",
    "entsprach": "entsprechen",
    "entsprachen": "entsprechen",
    "entsprachst": "entsprechen",
    "entspracht": "entsprechen",
    "entsprang": "entspringen",
    "entsprangen": "entspringen",
    "entsprangst": "entspringen",
    "entsprangt": "entspringen",
    "entspreche": "entsprechen",
    "entsprechend": "entsprechen",
    "entsprechende": "entsprechend",
    "entsprechendem": "entsprechend",
    "entsprechenden": "entsprechend",
    "entsprechender": "entsprechend",
    "entsprechendere": "entsprechend",
    "entsprechenderem": "entsprechend",
    "entsprechenderen": "entsprechend",
    "entsprechenderer": "entsprechend",
    "entsprechenderes": "entsprechend",
    "entsprechendes": "entsprechend",
    "entsprechendste": "entsprechend",
    "entsprechendstem": "entsprechend",
    "entsprechendsten": "entsprechend",
    "entsprechendster": "entsprechend",
    "entsprechendstes": "entsprechend",
    "entsprechest": "entsprechen",
    "entsprechet": "entsprechen",
    "entsprecht": "entsprechen",
    "entsprich": "entsprechen",
    "entsprichst": "entsprechen",
    "entspricht": "entsprechen",
    "entspringe": "entspringen",
    "entspringend": "entspringen",
    "entspringende": "entspringend",
    "entspringendem": "entspringend",
    "entspringenden": "entspringend",
    "entspringender": "entspringend",
    "entspringendes": "entspringend",
    "entspringest": "entspringen",
    "entspringet": "entspringen",
    "entspringst": "entspringen",
    "entspringt": "entspringen",
    "entsprochen": "entsprechen",
    "entsprochene": "entsprochen",
    "entsprochenem": "entsprochen",
    "entsprochenen": "entsprochen",
    "entsprochener": "entsprochen",
    "entsprochenere": "entsprochen",
    "entsprochenerem": "entsprochen",
    "entsprocheneren": "entsprochen",
    "entsprochenerer": "entsprochen",
    "entsprocheneres": "entsprochen",
    "entsprochenes": "entsprochen",
    "entsprochenste": "entsprochen",
    "entsprochenstem": "entsprochen",
    "entsprochensten": "entsprochen",
    "entsprochenster": "entsprochen",
    "entsprochenstes": "entsprochen",
    "entsprungen": "entspringen",
    "entsprungene": "entsprungen",
    "entsprungenem": "entsprungen",
    "entsprungenen": "entsprungen",
    "entsprungener": "entsprungen",
    "entsprungenes": "entsprungen",
    "entspräche": "entsprechen",
    "entsprächen": "entsprechen",
    "entsprächest": "entsprechen",
    "entsprächet": "entsprechen",
    "entspränge": "entspringen",
    "entsprängen": "entspringen",
    "entsprängest": "entspringen",
    "entspränget": "entspringen",
    "entstachele": "entstacheln",
    "entstachelnd": "entstacheln",
    "entstachelnde": "entstachelnd",
    "entstachelndem": "entstachelnd",
    "entstachelnden": "entstachelnd",
    "entstachelnder": "entstachelnd",
    "entstachelndes": "entstachelnd",
    "entstachelst": "entstacheln",
    "entstachelt": "entstacheln",
    "entstachelte": "entstacheln",
    "entstacheltem": "entstachelt",
    "entstachelten": "entstacheln",
    "entstachelter": "entstachelt",
    "entstacheltes": "entstachelt",
    "entstacheltest": "entstacheln",
    "entstacheltet": "entstacheln",
    "entstachle": "entstacheln",
    "entstamme": "entstammen",
    "entstammend": "entstammen",
    "entstammende": "entstammend",
    "entstammendem": "entstammend",
    "entstammenden": "entstammend",
    "entstammender": "entstammend",
    "entstammendes": "entstammend",
    "entstammest": "entstammen",
    "entstammet": "entstammen",
    "entstammst": "entstammen",
    "entstammt": "entstammen",
    "entstammte": "entstammen",
    "entstammtem": "entstammt",
    "entstammten": "entstammen",
    "entstammter": "entstammt",
    "entstammtes": "entstammt",
    "entstammtest": "entstammen",
    "entstammtet": "entstammen",
    "entstand": "entstehen",
    "entstanden": "entstehen",
    "entstandene": "entstanden",
    "entstandenem": "entstanden",
    "entstandenen": "entstanden",
    "entstandener": "entstanden",
    "entstandenes": "entstanden",
    "entstandest": "entstehen",
    "entstandet": "entstehen",
    "entstaube": "entstauben",
    "entstaubend": "entstauben",
    "entstaubende": "entstaubend",
    "entstaubendem": "entstaubend",
    "entstaubenden": "entstaubend",
    "entstaubender": "entstaubend",
    "entstaubendere": "entstaubend",
    "entstaubenderem": "entstaubend",
    "entstaubenderen": "entstaubend",
    "entstaubenderer": "entstaubend",
    "entstaubenderes": "entstaubend",
    "entstaubendes": "entstaubend",
    "entstaubendste": "entstaubend",
    "entstaubendstem": "entstaubend",
    "entstaubendsten": "entstaubend",
    "entstaubendster": "entstaubend",
    "entstaubendstes": "entstaubend",
    "entstaubest": "entstauben",
    "entstaubet": "entstauben",
    "entstaubst": "entstauben",
    "entstaubt": "entstauben",
    "entstaubte": "entstauben",
    "entstaubtem": "entstaubt",
    "entstaubten": "entstauben",
    "entstaubter": "entstaubt",
    "entstaubtere": "entstaubt",
    "entstaubterem": "entstaubt",
    "entstaubteren": "entstaubt",
    "entstaubterer": "entstaubt",
    "entstaubteres": "entstaubt",
    "entstaubtes": "entstaubt",
    "entstaubtest": "entstauben",
    "entstaubteste": "entstaubt",
    "entstaubtestem": "entstaubt",
    "entstaubtesten": "entstaubt",
    "entstaubtester": "entstaubt",
    "entstaubtestes": "entstaubt",
    "entstaubtet": "entstauben",
    "entstehe": "entstehen",
    "entstehend": "entstehen",
    "entstehende": "entstehend",
    "entstehendem": "entstehend",
    "entstehenden": "entstehend",
    "entstehender": "entstehend",
    "entstehendes": "entstehend",
    "entstehest": "entstehen",
    "entstehet": "entstehen",
    "entstehst": "entstehen",
    "entsteht": "entstehen",
    "entsteige": "entsteigen",
    "entsteigend": "entsteigen",
    "entsteigende": "entsteigend",
    "entsteigendem": "entsteigend",
    "entsteigenden": "entsteigend",
    "entsteigender": "entsteigend",
    "entsteigendes": "entsteigend",
    "entsteigest": "entsteigen",
    "entsteiget": "entsteigen",
    "entsteigst": "entsteigen",
    "entsteigt": "entsteigen",
    "entsteine": "entsteinen",
    "entsteinend": "entsteinen",
    "entsteinende": "entsteinend",
    "entsteinendem": "entsteinend",
    "entsteinenden": "entsteinend",
    "entsteinender": "entsteinend",
    "entsteinendes": "entsteinend",
    "entsteinest": "entsteinen",
    "entsteinet": "entsteinen",
    "entsteinst": "entsteinen",
    "entsteint": "entsteinen",
    "entsteinte": "entsteinen",
    "entsteintem": "entsteint",
    "entsteinten": "entsteinen",
    "entsteinter": "entsteint",
    "entsteintes": "entsteint",
    "entsteintest": "entsteinen",
    "entsteintet": "entsteinen",
    "entstelle": "entstellen",
    "entstellend": "entstellen",
    "entstellende": "entstellend",
    "entstellendem": "entstellend",
    "entstellenden": "entstellend",
    "entstellender": "entstellend",
    "entstellendes": "entstellend",
    "entstellest": "entstellen",
    "entstellet": "entstellen",
    "entstellst": "entstellen",
    "entstellt": "entstellen",
    "entstellte": "entstellen",
    "entstelltem": "entstellt",
    "entstellten": "entstellen",
    "entstellter": "entstellt",
    "entstelltere": "entstellt",
    "entstellterem": "entstellt",
    "entstellteren": "entstellt",
    "entstellterer": "entstellt",
    "entstellteres": "entstellt",
    "entstelltes": "entstellt",
    "entstelltest": "entstellen",
    "entstellteste": "entstellt",
    "entstelltestem": "entstellt",
    "entstelltesten": "entstellt",
    "entstelltester": "entstellt",
    "entstelltestes": "entstellt",
    "entstelltet": "entstellen",
    "entstieg": "entsteigen",
    "entstiege": "entsteigen",
    "entstiegen": "entsteigen",
    "entstiegene": "entstiegen",
    "entstiegenem": "entstiegen",
    "entstiegenen": "entstiegen",
    "entstiegener": "entstiegen",
    "entstiegenes": "entstiegen",
    "entstiegest": "entsteigen",
    "entstieget": "entsteigen",
    "entstiegst": "entsteigen",
    "entstiegt": "entsteigen",
    "entströme": "entströmen",
    "entströmend": "entströmen",
    "entströmende": "entströmend",
    "entströmendem": "entströmend",
    "entströmenden": "entströmend",
    "entströmender": "entströmend",
    "entströmendes": "entströmend",
    "entströmest": "entströmen",
    "entströmet": "entströmen",
    "entströmst": "entströmen",
    "entströmt": "entströmen",
    "entströmte": "entströmen",
    "entströmtem": "entströmt",
    "entströmten": "entströmen",
    "entströmter": "entströmt",
    "entströmtes": "entströmt",
    "entströmtest": "entströmen",
    "entströmtet": "entströmen",
    "entstöre": "entstören",
    "entstörend": "entstören",
    "entstörende": "entstörend",
    "entstörendem": "entstörend",
    "entstörenden": "entstörend",
    "entstörender": "entstörend",
    "entstörendes": "entstörend",
    "entstörest": "entstören",
    "entstöret": "entstören",
    "entstörst": "entstören",
    "entstört": "entstören",
    "entstörte": "entstören",
    "entstörtem": "entstört",
    "entstörten": "entstören",
    "entstörter": "entstört",
    "entstörtere": "entstört",
    "entstörterem": "entstört",
    "entstörteren": "entstört",
    "entstörterer": "entstört",
    "entstörteres": "entstört",
    "entstörtes": "entstört",
    "entstörtest": "entstören",
    "entstörteste": "entstört",
    "entstörtestem": "entstört",
    "entstörtesten": "entstört",
    "entstörtester": "entstört",
    "entstörtestes": "entstört",
    "entstörtet": "entstören",
    "entstünde": "entstehen",
    "entstünden": "entstehen",
    "entstündest": "entstehen",
    "entstündet": "entstehen",
    "entsunken": "entsinken",
    "entsunkene": "entsunken",
    "entsunkenem": "entsunken",
    "entsunkenen": "entsunken",
    "entsunkener": "entsunken",
    "entsunkenere": "entsunken",
    "entsunkenerem": "entsunken",
    "entsunkeneren": "entsunken",
    "entsunkenerer": "entsunken",
    "entsunkeneres": "entsunken",
    "entsunkenes": "entsunken",
    "entsunkenste": "entsunken",
    "entsunkenstem": "entsunken",
    "entsunkensten": "entsunken",
    "entsunkenster": "entsunken",
    "entsunkenstes": "entsunken",
    "entsänke": "entsinken",
    "entsänken": "entsinken",
    "entsänkest": "entsinken",
    "entsänket": "entsinken",
    "entsänne": "entsinnen",
    "entsännen": "entsinnen",
    "entsännest": "entsinnen",
    "entsännet": "entsinnen",
    "enttabuiere": "enttabuieren",
    "enttabuierend": "enttabuieren",
    "enttabuierende": "enttabuierend",
    "enttabuierendem": "enttabuierend",
    "enttabuierenden": "enttabuierend",
    "enttabuierender": "enttabuierend",
    "enttabuierendere": "enttabuierend",
    "enttabuierenderem": "enttabuierend",
    "enttabuierenderen": "enttabuierend",
    "enttabuierenderer": "enttabuierend",
    "enttabuierenderes": "enttabuierend",
    "enttabuierendes": "enttabuierend",
    "enttabuierendste": "enttabuierend",
    "enttabuierendstem": "enttabuierend",
    "enttabuierendsten": "enttabuierend",
    "enttabuierendster": "enttabuierend",
    "enttabuierendstes": "enttabuierend",
    "enttabuierest": "enttabuieren",
    "enttabuieret": "enttabuieren",
    "enttabuierst": "enttabuieren",
    "enttabuiert": "enttabuieren",
    "enttabuierte": "enttabuieren",
    "enttabuiertem": "enttabuiert",
    "enttabuierten": "enttabuieren",
    "enttabuierter": "enttabuiert",
    "enttabuiertere": "enttabuiert",
    "enttabuierterem": "enttabuiert",
    "enttabuierteren": "enttabuiert",
    "enttabuierterer": "enttabuiert",
    "enttabuierteres": "enttabuiert",
    "enttabuiertes": "enttabuiert",
    "enttabuiertest": "enttabuieren",
    "enttabuierteste": "enttabuiert",
    "enttabuiertestem": "enttabuiert",
    "enttabuiertesten": "enttabuiert",
    "enttabuiertester": "enttabuiert",
    "enttabuiertestes": "enttabuiert",
    "enttabuiertet": "enttabuieren",
    "enttarne": "enttarnen",
    "enttarnend": "enttarnen",
    "enttarnende": "enttarnend",
    "enttarnendem": "enttarnend",
    "enttarnenden": "enttarnend",
    "enttarnender": "enttarnend",
    "enttarnendere": "enttarnend",
    "enttarnenderem": "enttarnend",
    "enttarnenderen": "enttarnend",
    "enttarnenderer": "enttarnend",
    "enttarnenderes": "enttarnend",
    "enttarnendes": "enttarnend",
    "enttarnendste": "enttarnend",
    "enttarnendstem": "enttarnend",
    "enttarnendsten": "enttarnend",
    "enttarnendster": "enttarnend",
    "enttarnendstes": "enttarnend",
    "enttarnest": "enttarnen",
    "enttarnet": "enttarnen",
    "enttarnst": "enttarnen",
    "enttarnt": "enttarnen",
    "enttarnte": "enttarnen",
    "enttarntem": "enttarnt",
    "enttarnten": "enttarnen",
    "enttarnter": "enttarnt",
    "enttarntere": "enttarnt",
    "enttarnterem": "enttarnt",
    "enttarnteren": "enttarnt",
    "enttarnterer": "enttarnt",
    "enttarnteres": "enttarnt",
    "enttarntes": "enttarnt",
    "enttarntest": "enttarnen",
    "enttarnteste": "enttarnt",
    "enttarntestem": "enttarnt",
    "enttarntesten": "enttarnt",
    "enttarntester": "enttarnt",
    "enttarntestes": "enttarnt",
    "enttarntet": "enttarnen",
    "enttechnisiere": "enttechnisieren",
    "enttechnisierend": "enttechnisieren",
    "enttechnisierende": "enttechnisierend",
    "enttechnisierendem": "enttechnisierend",
    "enttechnisierenden": "enttechnisierend",
    "enttechnisierender": "enttechnisierend",
    "enttechnisierendere": "enttechnisierend",
    "enttechnisierenderem": "enttechnisierend",
    "enttechnisierenderen": "enttechnisierend",
    "enttechnisierenderer": "enttechnisierend",
    "enttechnisierenderes": "enttechnisierend",
    "enttechnisierendes": "enttechnisierend",
    "enttechnisierendste": "enttechnisierend",
    "enttechnisierendstem": "enttechnisierend",
    "enttechnisierendsten": "enttechnisierend",
    "enttechnisierendster": "enttechnisierend",
    "enttechnisierendstes": "enttechnisierend",
    "enttechnisierest": "enttechnisieren",
    "enttechnisieret": "enttechnisieren",
    "enttechnisierst": "enttechnisieren",
    "enttechnisiert": "enttechnisieren",
    "enttechnisierte": "enttechnisieren",
    "enttechnisiertem": "enttechnisiert",
    "enttechnisierten": "enttechnisieren",
    "enttechnisierter": "enttechnisiert",
    "enttechnisiertere": "enttechnisiert",
    "enttechnisierterem": "enttechnisiert",
    "enttechnisierteren": "enttechnisiert",
    "enttechnisierterer": "enttechnisiert",
    "enttechnisierteres": "enttechnisiert",
    "enttechnisiertes": "enttechnisiert",
    "enttechnisiertest": "enttechnisieren",
    "enttechnisierteste": "enttechnisiert",
    "enttechnisiertestem": "enttechnisiert",
    "enttechnisiertesten": "enttechnisiert",
    "enttechnisiertester": "enttechnisiert",
    "enttechnisiertestes": "enttechnisiert",
    "enttechnisiertet": "enttechnisieren",
    "entthrone": "entthronen",
    "entthronend": "entthronen",
    "entthronende": "entthronend",
    "entthronendem": "entthronend",
    "entthronenden": "entthronend",
    "entthronender": "entthronend",
    "entthronendes": "entthronend",
    "entthronest": "entthronen",
    "entthronet": "entthronen",
    "entthronst": "entthronen",
    "entthront": "entthronen",
    "entthronte": "entthronen",
    "entthrontem": "entthront",
    "entthronten": "entthronen",
    "entthronter": "entthront",
    "entthrontes": "entthront",
    "entthrontest": "entthronen",
    "entthrontet": "entthronen",
    "enttäusche": "enttäuschen",
    "enttäuschend": "enttäuschen",
    "enttäuschende": "enttäuschend",
    "enttäuschendem": "enttäuschend",
    "enttäuschenden": "enttäuschend",
    "enttäuschender": "enttäuschend",
    "enttäuschendere": "enttäuschend",
    "enttäuschenderem": "enttäuschend",
    "enttäuschenderen": "enttäuschend",
    "enttäuschenderer": "enttäuschend",
    "enttäuschenderes": "enttäuschend",
    "enttäuschendes": "enttäuschend",
    "enttäuschendste": "enttäuschend",
    "enttäuschendstem": "enttäuschend",
    "enttäuschendsten": "enttäuschend",
    "enttäuschendster": "enttäuschend",
    "enttäuschendstes": "enttäuschend",
    "enttäuschest": "enttäuschen",
    "enttäuschet": "enttäuschen",
    "enttäuschst": "enttäuschen",
    "enttäuscht": "enttäuschen",
    "enttäuschte": "enttäuschen",
    "enttäuschtem": "enttäuscht",
    "enttäuschten": "enttäuschen",
    "enttäuschter": "enttäuscht",
    "enttäuschtere": "enttäuscht",
    "enttäuschterem": "enttäuscht",
    "enttäuschteren": "enttäuscht",
    "enttäuschterer": "enttäuscht",
    "enttäuschteres": "enttäuscht",
    "enttäuschtes": "enttäuscht",
    "enttäuschtest": "enttäuschen",
    "enttäuschteste": "enttäuscht",
    "enttäuschtestem": "enttäuscht",
    "enttäuschtesten": "enttäuscht",
    "enttäuschtester": "enttäuscht",
    "enttäuschtestes": "enttäuscht",
    "enttäuschtet": "enttäuschen",
    "entwaffne": "entwaffnen",
    "entwaffnend": "entwaffnen",
    "entwaffnende": "entwaffnend",
    "entwaffnendem": "entwaffnend",
    "entwaffnenden": "entwaffnend",
    "entwaffnender": "entwaffnend",
    "entwaffnendes": "entwaffnend",
    "entwaffnest": "entwaffnen",
    "entwaffnet": "entwaffnen",
    "entwaffnete": "entwaffnen",
    "entwaffnetem": "entwaffnet",
    "entwaffneten": "entwaffnen",
    "entwaffneter": "entwaffnet",
    "entwaffnetes": "entwaffnet",
    "entwaffnetest": "entwaffnen",
    "entwaffnetet": "entwaffnen",
    "entwandt": "entwenden",
    "entwandte": "entwandt",
    "entwandtem": "entwandt",
    "entwandten": "entwandt",
    "entwandter": "entwandt",
    "entwandtes": "entwandt",
    "entwandtest": "entwenden",
    "entwandtet": "entwenden",
    "entwarf": "entwerfen",
    "entwarfen": "entwerfen",
    "entwarfst": "entwerfen",
    "entwarft": "entwerfen",
    "entwarne": "entwarnen",
    "entwarnend": "entwarnen",
    "entwarnende": "entwarnend",
    "entwarnendem": "entwarnend",
    "entwarnenden": "entwarnend",
    "entwarnender": "entwarnend",
    "entwarnendes": "entwarnend",
    "entwarnest": "entwarnen",
    "entwarnet": "entwarnen",
    "entwarnst": "entwarnen",
    "entwarnt": "entwarnen",
    "entwarnte": "entwarnen",
    "entwarntem": "entwarnt",
    "entwarnten": "entwarnen",
    "entwarnter": "entwarnt",
    "entwarntes": "entwarnt",
    "entwarntest": "entwarnen",
    "entwarntet": "entwarnen",
    "entweiche": "entweichen",
    "entweichend": "entweichen",
    "entweichende": "entweichend",
    "entweichendem": "entweichend",
    "entweichenden": "entweichend",
    "entweichender": "entweichend",
    "entweichendes": "entweichend",
    "entweichest": "entweichen",
    "entweichet": "entweichen",
    "entweichst": "entweichen",
    "entweicht": "entweichen",
    "entwende": "entwenden",
    "entwendend": "entwenden",
    "entwendende": "entwendend",
    "entwendendem": "entwendend",
    "entwendenden": "entwendend",
    "entwendender": "entwendend",
    "entwendendes": "entwendend",
    "entwendest": "entwenden",
    "entwendet": "entwenden",
    "entwendete": "entwenden",
    "entwendetem": "entwendet",
    "entwendeten": "entwenden",
    "entwendeter": "entwendet",
    "entwendetes": "entwendet",
    "entwendetest": "entwenden",
    "entwendetet": "entwenden",
    "entwerfe": "entwerfen",
    "entwerfend": "entwerfen",
    "entwerfende": "entwerfend",
    "entwerfendem": "entwerfend",
    "entwerfenden": "entwerfend",
    "entwerfender": "entwerfend",
    "entwerfendes": "entwerfend",
    "entwerfest": "entwerfen",
    "entwerfet": "entwerfen",
    "entwerft": "entwerfen",
    "entwerte": "entwerten",
    "entwertend": "entwerten",
    "entwertende": "entwertend",
    "entwertendem": "entwertend",
    "entwertenden": "entwertend",
    "entwertender": "entwertend",
    "entwertendes": "entwertend",
    "entwertest": "entwerten",
    "entwertet": "entwerten",
    "entwertete": "entwerten",
    "entwertetem": "entwertet",
    "entwerteten": "entwerten",
    "entwerteter": "entwertet",
    "entwertetes": "entwertet",
    "entwertetest": "entwerten",
    "entwertetet": "entwerten",
    "entwich": "entweichen",
    "entwiche": "entweichen",
    "entwichen": "entweichen",
    "entwichene": "entwichen",
    "entwichenem": "entwichen",
    "entwichenen": "entwichen",
    "entwichener": "entwichen",
    "entwichenes": "entwichen",
    "entwichest": "entweichen",
    "entwichet": "entweichen",
    "entwichst": "entweichen",
    "entwicht": "entweichen",
    "entwickele": "entwickeln",
    "entwickelnd": "entwickeln",
    "entwickelnde": "entwickelnd",
    "entwickelndem": "entwickelnd",
    "entwickelnden": "entwickelnd",
    "entwickelnder": "entwickelnd",
    "entwickelndes": "entwickelnd",
    "entwickelst": "entwickeln",
    "entwickelt": "entwickeln",
    "entwickelte": "entwickeln",
    "entwickeltem": "entwickelt",
    "entwickelten": "entwickeln",
    "entwickelter": "entwickelt",
    "entwickeltere": "entwickelt",
    "entwickelterem": "entwickelt",
    "entwickelteren": "entwickelt",
    "entwickelterer": "entwickelt",
    "entwickelteres": "entwickelt",
    "entwickeltes": "entwickelt",
    "entwickeltest": "entwickeln",
    "entwickelteste": "entwickelt",
    "entwickeltestem": "entwickelt",
    "entwickeltesten": "entwickelt",
    "entwickeltester": "entwickelt",
    "entwickeltestes": "entwickelt",
    "entwickeltet": "entwickeln",
    "entwickle": "entwickeln",
    "entwicklungsfähigem": "entwicklungsfähig",
    "entwicklungsfähigen": "entwicklungsfähig",
    "entwicklungsfähiger": "entwicklungsfähig",
    "entwicklungsfähigere": "entwicklungsfähig",
    "entwicklungsfähigerem": "entwicklungsfähig",
    "entwicklungsfähigeren": "entwicklungsfähig",
    "entwicklungsfähigerer": "entwicklungsfähig",
    "entwicklungsfähigeres": "entwicklungsfähig",
    "entwicklungsfähiges": "entwicklungsfähig",
    "entwicklungsfähigste": "entwicklungsfähig",
    "entwicklungsfähigstem": "entwicklungsfähig",
    "entwicklungsfähigsten": "entwicklungsfähig",
    "entwicklungsfähigster": "entwicklungsfähig",
    "entwicklungsfähigstes": "entwicklungsfähig",
    "entwirf": "entwerfen",
    "entwirfst": "entwerfen",
    "entwirft": "entwerfen",
    "entwirre": "entwirren",
    "entwirrend": "entwirren",
    "entwirrende": "entwirrend",
    "entwirrendem": "entwirrend",
    "entwirrenden": "entwirrend",
    "entwirrender": "entwirrend",
    "entwirrendere": "entwirrend",
    "entwirrenderem": "entwirrend",
    "entwirrenderen": "entwirrend",
    "entwirrenderer": "entwirrend",
    "entwirrenderes": "entwirrend",
    "entwirrendes": "entwirrend",
    "entwirrendste": "entwirrend",
    "entwirrendstem": "entwirrend",
    "entwirrendsten": "entwirrend",
    "entwirrendster": "entwirrend",
    "entwirrendstes": "entwirrend",
    "entwirrest": "entwirren",
    "entwirret": "entwirren",
    "entwirrst": "entwirren",
    "entwirrt": "entwirren",
    "entwirrte": "entwirren",
    "entwirrtem": "entwirrt",
    "entwirrten": "entwirren",
    "entwirrter": "entwirrt",
    "entwirrtere": "entwirrt",
    "entwirrterem": "entwirrt",
    "entwirrteren": "entwirrt",
    "entwirrterer": "entwirrt",
    "entwirrteres": "entwirrt",
    "entwirrtes": "entwirrt",
    "entwirrtest": "entwirren",
    "entwirrteste": "entwirrt",
    "entwirrtestem": "entwirrt",
    "entwirrtesten": "entwirrt",
    "entwirrtester": "entwirrt",
    "entwirrtestes": "entwirrt",
    "entwirrtet": "entwirren",
    "entwische": "entwischen",
    "entwischend": "entwischen",
    "entwischende": "entwischend",
    "entwischendem": "entwischend",
    "entwischenden": "entwischend",
    "entwischender": "entwischend",
    "entwischendes": "entwischend",
    "entwischest": "entwischen",
    "entwischet": "entwischen",
    "entwischst": "entwischen",
    "entwischt": "entwischen",
    "entwischte": "entwischen",
    "entwischtem": "entwischt",
    "entwischten": "entwischen",
    "entwischter": "entwischt",
    "entwischtes": "entwischt",
    "entwischtest": "entwischen",
    "entwischtet": "entwischen",
    "entworfen": "entwerfen",
    "entworfene": "entworfen",
    "entworfenem": "entworfen",
    "entworfenen": "entworfen",
    "entworfener": "entworfen",
    "entworfenes": "entworfen",
    "entwurzele": "entwurzeln",
    "entwurzelnd": "entwurzeln",
    "entwurzelnde": "entwurzelnd",
    "entwurzelndem": "entwurzelnd",
    "entwurzelnden": "entwurzelnd",
    "entwurzelnder": "entwurzelnd",
    "entwurzelndes": "entwurzelnd",
    "entwurzelst": "entwurzeln",
    "entwurzelt": "entwurzeln",
    "entwurzelte": "entwurzeln",
    "entwurzeltem": "entwurzelt",
    "entwurzelten": "entwurzeln",
    "entwurzelter": "entwurzelt",
    "entwurzeltes": "entwurzelt",
    "entwurzeltest": "entwurzeln",
    "entwurzeltet": "entwurzeln",
    "entwurzle": "entwurzeln",
    "entwärfe": "entwerfen",
    "entwärfen": "entwerfen",
    "entwärfest": "entwerfen",
    "entwärfet": "entwerfen",
    "entwöhne": "entwöhnen",
    "entwöhnend": "entwöhnen",
    "entwöhnende": "entwöhnend",
    "entwöhnendem": "entwöhnend",
    "entwöhnenden": "entwöhnend",
    "entwöhnender": "entwöhnend",
    "entwöhnendere": "entwöhnend",
    "entwöhnenderem": "entwöhnend",
    "entwöhnenderen": "entwöhnend",
    "entwöhnenderer": "entwöhnend",
    "entwöhnenderes": "entwöhnend",
    "entwöhnendes": "entwöhnend",
    "entwöhnendste": "entwöhnend",
    "entwöhnendstem": "entwöhnend",
    "entwöhnendsten": "entwöhnend",
    "entwöhnendster": "entwöhnend",
    "entwöhnendstes": "entwöhnend",
    "entwöhnest": "entwöhnen",
    "entwöhnet": "entwöhnen",
    "entwöhnst": "entwöhnen",
    "entwöhnt": "entwöhnen",
    "entwöhnte": "entwöhnen",
    "entwöhntem": "entwöhnt",
    "entwöhnten": "entwöhnen",
    "entwöhnter": "entwöhnt",
    "entwöhntere": "entwöhnt",
    "entwöhnterem": "entwöhnt",
    "entwöhnteren": "entwöhnt",
    "entwöhnterer": "entwöhnt",
    "entwöhnteres": "entwöhnt",
    "entwöhntes": "entwöhnt",
    "entwöhntest": "entwöhnen",
    "entwöhnteste": "entwöhnt",
    "entwöhntestem": "entwöhnt",
    "entwöhntesten": "entwöhnt",
    "entwöhntester": "entwöhnt",
    "entwöhntestes": "entwöhnt",
    "entwöhntet": "entwöhnen",
    "entwürdigende": "entwürdigend",
    "entwürdigendem": "entwürdigend",
    "entwürdigenden": "entwürdigend",
    "entwürdigender": "entwürdigend",
    "entwürdigendere": "entwürdigend",
    "entwürdigenderem": "entwürdigend",
    "entwürdigenderen": "entwürdigend",
    "entwürdigenderer": "entwürdigend",
    "entwürdigenderes": "entwürdigend",
    "entwürdigendes": "entwürdigend",
    "entwürdigendste": "entwürdigend",
    "entwürdigendstem": "entwürdigend",
    "entwürdigendsten": "entwürdigend",
    "entwürdigendster": "entwürdigend",
    "entwürdigendstes": "entwürdigend",
    "entzaubere": "entzaubern",
    "entzaubernd": "entzaubern",
    "entzaubernde": "entzaubernd",
    "entzauberndem": "entzaubernd",
    "entzaubernden": "entzaubernd",
    "entzaubernder": "entzaubernd",
    "entzauberndere": "entzaubernd",
    "entzaubernderem": "entzaubernd",
    "entzaubernderen": "entzaubernd",
    "entzaubernderer": "entzaubernd",
    "entzaubernderes": "entzaubernd",
    "entzauberndes": "entzaubernd",
    "entzauberndste": "entzaubernd",
    "entzauberndstem": "entzaubernd",
    "entzauberndsten": "entzaubernd",
    "entzauberndster": "entzaubernd",
    "entzauberndstes": "entzaubernd",
    "entzauberst": "entzaubern",
    "entzaubert": "entzaubern",
    "entzauberte": "entzaubern",
    "entzaubertem": "entzaubert",
    "entzauberten": "entzaubern",
    "entzauberter": "entzaubert",
    "entzaubertere": "entzaubert",
    "entzauberterem": "entzaubert",
    "entzauberteren": "entzaubert",
    "entzauberterer": "entzaubert",
    "entzauberteres": "entzaubert",
    "entzaubertes": "entzaubert",
    "entzaubertest": "entzaubern",
    "entzauberteste": "entzaubert",
    "entzaubertestem": "entzaubert",
    "entzaubertesten": "entzaubert",
    "entzaubertester": "entzaubert",
    "entzaubertestes": "entzaubert",
    "entzaubertet": "entzaubern",
    "entzerre": "entzerren",
    "entzerrend": "entzerren",
    "entzerrende": "entzerrend",
    "entzerrendem": "entzerrend",
    "entzerrenden": "entzerrend",
    "entzerrender": "entzerrend",
    "entzerrendere": "entzerrend",
    "entzerrenderem": "entzerrend",
    "entzerrenderen": "entzerrend",
    "entzerrenderer": "entzerrend",
    "entzerrenderes": "entzerrend",
    "entzerrendes": "entzerrend",
    "entzerrendste": "entzerrend",
    "entzerrendstem": "entzerrend",
    "entzerrendsten": "entzerrend",
    "entzerrendster": "entzerrend",
    "entzerrendstes": "entzerrend",
    "entzerrest": "entzerren",
    "entzerret": "entzerren",
    "entzerrst": "entzerren",
    "entzerrt": "entzerren",
    "entzerrte": "entzerren",
    "entzerrtem": "entzerrt",
    "entzerrten": "entzerren",
    "entzerrter": "entzerrt",
    "entzerrtere": "entzerrt",
    "entzerrterem": "entzerrt",
    "entzerrteren": "entzerrt",
    "entzerrterer": "entzerrt",
    "entzerrteres": "entzerrt",
    "entzerrtes": "entzerrt",
    "entzerrtest": "entzerren",
    "entzerrteste": "entzerrt",
    "entzerrtestem": "entzerrt",
    "entzerrtesten": "entzerrt",
    "entzerrtester": "entzerrt",
    "entzerrtestes": "entzerrt",
    "entzerrtet": "entzerren",
    "entziehe": "entziehen",
    "entziehend": "entziehen",
    "entziehende": "entziehend",
    "entziehendem": "entziehend",
    "entziehenden": "entziehend",
    "entziehender": "entziehend",
    "entziehendes": "entziehend",
    "entziehest": "entziehen",
    "entziehet": "entziehen",
    "entziehst": "entziehen",
    "entzieht": "entziehen",
    "entzifferbare": "entzifferbar",
    "entzifferbarem": "entzifferbar",
    "entzifferbaren": "entzifferbar",
    "entzifferbarer": "entzifferbar",
    "entzifferbarere": "entzifferbar",
    "entzifferbarerem": "entzifferbar",
    "entzifferbareren": "entzifferbar",
    "entzifferbarerer": "entzifferbar",
    "entzifferbareres": "entzifferbar",
    "entzifferbares": "entzifferbar",
    "entzifferbarste": "entzifferbar",
    "entzifferbarstem": "entzifferbar",
    "entzifferbarsten": "entzifferbar",
    "entzifferbarster": "entzifferbar",
    "entzifferbarstes": "entzifferbar",
    "entziffere": "entziffern",
    "entziffernd": "entziffern",
    "entziffernde": "entziffernd",
    "entzifferndem": "entziffernd",
    "entziffernden": "entziffernd",
    "entziffernder": "entziffernd",
    "entzifferndes": "entziffernd",
    "entzifferst": "entziffern",
    "entziffert": "entziffern",
    "entzifferte": "entziffern",
    "entziffertem": "entziffert",
    "entzifferten": "entziffern",
    "entzifferter": "entziffert",
    "entziffertes": "entziffert",
    "entziffertest": "entziffern",
    "entziffertet": "entziffern",
    "entzog": "entziehen",
    "entzogen": "entziehen",
    "entzogene": "entzogen",
    "entzogenem": "entzogen",
    "entzogenen": "entzogen",
    "entzogener": "entzogen",
    "entzogenes": "entzogen",
    "entzogst": "entziehen",
    "entzogt": "entziehen",
    "entzweibeiße": "entzweibeißen",
    "entzweibeißend": "entzweibeißen",
    "entzweibeißende": "entzweibeißend",
    "entzweibeißendem": "entzweibeißend",
    "entzweibeißenden": "entzweibeißend",
    "entzweibeißender": "entzweibeißend",
    "entzweibeißendes": "entzweibeißend",
    "entzweibeißest": "entzweibeißen",
    "entzweibeißet": "entzweibeißen",
    "entzweibeißt": "entzweibeißen",
    "entzweibisse": "entzweibeißen",
    "entzweibissen": "entzweibeißen",
    "entzweibissest": "entzweibeißen",
    "entzweibisset": "entzweibeißen",
    "entzweibiß": "entzweibeißen",
    "entzweibißt": "entzweibeißen",
    "entzweibrach": "entzweibrechen",
    "entzweibrachen": "entzweibrechen",
    "entzweibrachst": "entzweibrechen",
    "entzweibracht": "entzweibrechen",
    "entzweibreche": "entzweibrechen",
    "entzweibrechend": "entzweibrechen",
    "entzweibrechende": "entzweibrechend",
    "entzweibrechendem": "entzweibrechend",
    "entzweibrechenden": "entzweibrechend",
    "entzweibrechender": "entzweibrechend",
    "entzweibrechendes": "entzweibrechend",
    "entzweibrechest": "entzweibrechen",
    "entzweibrechet": "entzweibrechen",
    "entzweibrecht": "entzweibrechen",
    "entzweibrichst": "entzweibrechen",
    "entzweibricht": "entzweibrechen",
    "entzweibräche": "entzweibrechen",
    "entzweibrächen": "entzweibrechen",
    "entzweibrächest": "entzweibrechen",
    "entzweibrächet": "entzweibrechen",
    "entzweigebissen": "entzweibeißen",
    "entzweigebissene": "entzweigebissen",
    "entzweigebissenem": "entzweigebissen",
    "entzweigebissenen": "entzweigebissen",
    "entzweigebissener": "entzweigebissen",
    "entzweigebissenes": "entzweigebissen",
    "entzweigebrochen": "entzweibrechen",
    "entzweigebrochene": "entzweigebrochen",
    "entzweigebrochenem": "entzweigebrochen",
    "entzweigebrochenen": "entzweigebrochen",
    "entzweigebrochener": "entzweigebrochen",
    "entzweigebrochenes": "entzweigebrochen",
    "entzweigehaucht": "entzweihauchen",
    "entzweigehauchte": "entzweigehaucht",
    "entzweigehauchtem": "entzweigehaucht",
    "entzweigehauchten": "entzweigehaucht",
    "entzweigehauchter": "entzweigehaucht",
    "entzweigehauchtes": "entzweigehaucht",
    "entzweigehauen": "entzweihauen",
    "entzweigehauene": "entzweigehauen",
    "entzweigehauenem": "entzweigehauen",
    "entzweigehauenen": "entzweigehauen",
    "entzweigehauener": "entzweigehauen",
    "entzweigehauenes": "entzweigehauen",
    "entzweigemacht": "entzweimachen",
    "entzweigemachte": "entzweigemacht",
    "entzweigemachtem": "entzweigemacht",
    "entzweigemachten": "entzweigemacht",
    "entzweigemachter": "entzweigemacht",
    "entzweigemachtes": "entzweigemacht",
    "entzweigerissen": "entzweireißen",
    "entzweigerissene": "entzweigerissen",
    "entzweigerissenem": "entzweigerissen",
    "entzweigerissenen": "entzweigerissen",
    "entzweigerissener": "entzweigerissen",
    "entzweigerissenere": "entzweigerissen",
    "entzweigerissenerem": "entzweigerissen",
    "entzweigerisseneren": "entzweigerissen",
    "entzweigerissenerer": "entzweigerissen",
    "entzweigerisseneres": "entzweigerissen",
    "entzweigerissenes": "entzweigerissen",
    "entzweigerissenste": "entzweigerissen",
    "entzweigerissenstem": "entzweigerissen",
    "entzweigerissensten": "entzweigerissen",
    "entzweigerissenster": "entzweigerissen",
    "entzweigerissenstes": "entzweigerissen",
    "entzweigeschlagen": "entzweischlagen",
    "entzweigeschlagene": "entzweigeschlagen",
    "entzweigeschlagenem": "entzweigeschlagen",
    "entzweigeschlagenen": "entzweigeschlagen",
    "entzweigeschlagener": "entzweigeschlagen",
    "entzweigeschlagenere": "entzweigeschlagen",
    "entzweigeschlagenerem": "entzweigeschlagen",
    "entzweigeschlageneren": "entzweigeschlagen",
    "entzweigeschlagenerer": "entzweigeschlagen",
    "entzweigeschlageneres": "entzweigeschlagen",
    "entzweigeschlagenes": "entzweigeschlagen",
    "entzweigeschlagenste": "entzweigeschlagen",
    "entzweigeschlagenstem": "entzweigeschlagen",
    "entzweigeschlagensten": "entzweigeschlagen",
    "entzweigeschlagenster": "entzweigeschlagen",
    "entzweigeschlagenstes": "entzweigeschlagen",
    "entzweigeschnitten": "entzweischneiden",
    "entzweigeschnittene": "entzweigeschnitten",
    "entzweigeschnittenem": "entzweigeschnitten",
    "entzweigeschnittenen": "entzweigeschnitten",
    "entzweigeschnittener": "entzweigeschnitten",
    "entzweigeschnittenes": "entzweigeschnitten",
    "entzweihauche": "entzweihauchen",
    "entzweihauchend": "entzweihauchen",
    "entzweihauchende": "entzweihauchend",
    "entzweihauchendem": "entzweihauchend",
    "entzweihauchenden": "entzweihauchend",
    "entzweihauchender": "entzweihauchend",
    "entzweihauchendes": "entzweihauchend",
    "entzweihauchest": "entzweihauchen",
    "entzweihauchet": "entzweihauchen",
    "entzweihauchst": "entzweihauchen",
    "entzweihaucht": "entzweihauchen",
    "entzweihauchte": "entzweihauchen",
    "entzweihauchten": "entzweihauchen",
    "entzweihauchtest": "entzweihauchen",
    "entzweihauchtet": "entzweihauchen",
    "entzweihaue": "entzweihauen",
    "entzweihauend": "entzweihauen",
    "entzweihauende": "entzweihauend",
    "entzweihauendem": "entzweihauend",
    "entzweihauenden": "entzweihauend",
    "entzweihauender": "entzweihauend",
    "entzweihauendes": "entzweihauend",
    "entzweihauest": "entzweihauen",
    "entzweihauet": "entzweihauen",
    "entzweihaust": "entzweihauen",
    "entzweihaut": "entzweihauen",
    "entzweihaute": "entzweihauen",
    "entzweihauten": "entzweihauen",
    "entzweihautest": "entzweihauen",
    "entzweihautet": "entzweihauen",
    "entzweimache": "entzweimachen",
    "entzweimachend": "entzweimachen",
    "entzweimachende": "entzweimachend",
    "entzweimachendem": "entzweimachend",
    "entzweimachenden": "entzweimachend",
    "entzweimachender": "entzweimachend",
    "entzweimachendes": "entzweimachend",
    "entzweimachest": "entzweimachen",
    "entzweimachet": "entzweimachen",
    "entzweimachst": "entzweimachen",
    "entzweimacht": "entzweimachen",
    "entzweimachte": "entzweimachen",
    "entzweimachten": "entzweimachen",
    "entzweimachtest": "entzweimachen",
    "entzweimachtet": "entzweimachen",
    "entzweireiße": "entzweireißen",
    "entzweireißend": "entzweireißen",
    "entzweireißende": "entzweireißend",
    "entzweireißendem": "entzweireißend",
    "entzweireißenden": "entzweireißend",
    "entzweireißender": "entzweireißend",
    "entzweireißendere": "entzweireißend",
    "entzweireißenderem": "entzweireißend",
    "entzweireißenderen": "entzweireißend",
    "entzweireißenderer": "entzweireißend",
    "entzweireißenderes": "entzweireißend",
    "entzweireißendes": "entzweireißend",
    "entzweireißendste": "entzweireißend",
    "entzweireißendstem": "entzweireißend",
    "entzweireißendsten": "entzweireißend",
    "entzweireißendster": "entzweireißend",
    "entzweireißendstes": "entzweireißend",
    "entzweireißest": "entzweireißen",
    "entzweireißet": "entzweireißen",
    "entzweireißt": "entzweireißen",
    "entzweirisse": "entzweireißen",
    "entzweirissen": "entzweireißen",
    "entzweirissest": "entzweireißen",
    "entzweirisset": "entzweireißen",
    "entzweiriß": "entzweireißen",
    "entzweirißt": "entzweireißen",
    "entzweischlage": "entzweischlagen",
    "entzweischlagend": "entzweischlagen",
    "entzweischlagende": "entzweischlagend",
    "entzweischlagendem": "entzweischlagend",
    "entzweischlagenden": "entzweischlagend",
    "entzweischlagender": "entzweischlagend",
    "entzweischlagendere": "entzweischlagend",
    "entzweischlagenderem": "entzweischlagend",
    "entzweischlagenderen": "entzweischlagend",
    "entzweischlagenderer": "entzweischlagend",
    "entzweischlagenderes": "entzweischlagend",
    "entzweischlagendes": "entzweischlagend",
    "entzweischlagendste": "entzweischlagend",
    "entzweischlagendstem": "entzweischlagend",
    "entzweischlagendsten": "entzweischlagend",
    "entzweischlagendster": "entzweischlagend",
    "entzweischlagendstes": "entzweischlagend",
    "entzweischlagest": "entzweischlagen",
    "entzweischlaget": "entzweischlagen",
    "entzweischlagt": "entzweischlagen",
    "entzweischlug": "entzweischlagen",
    "entzweischlugen": "entzweischlagen",
    "entzweischlugst": "entzweischlagen",
    "entzweischlugt": "entzweischlagen",
    "entzweischlägst": "entzweischlagen",
    "entzweischlägt": "entzweischlagen",
    "entzweischlüge": "entzweischlagen",
    "entzweischlügen": "entzweischlagen",
    "entzweischlügest": "entzweischlagen",
    "entzweischlüget": "entzweischlagen",
    "entzweischneide": "entzweischneiden",
    "entzweischneidend": "entzweischneiden",
    "entzweischneidende": "entzweischneidend",
    "entzweischneidendem": "entzweischneidend",
    "entzweischneidenden": "entzweischneidend",
    "entzweischneidender": "entzweischneidend",
    "entzweischneidendes": "entzweischneidend",
    "entzweischneidest": "entzweischneiden",
    "entzweischneidet": "entzweischneiden",
    "entzweischnitt": "entzweischneiden",
    "entzweischnitte": "entzweischneiden",
    "entzweischnitten": "entzweischneiden",
    "entzweischnittest": "entzweischneiden",
    "entzweischnittet": "entzweischneiden",
    "entzweizubeißen": "entzweibeißen",
    "entzweizubrechen": "entzweibrechen",
    "entzweizuhauchen": "entzweihauchen",
    "entzweizuhauen": "entzweihauen",
    "entzweizumachen": "entzweimachen",
    "entzweizureißen": "entzweireißen",
    "entzweizuschlagen": "entzweischlagen",
    "entzweizuschneiden": "entzweischneiden",
    "entzöge": "entziehen",
    "entzögen": "entziehen",
    "entzögest": "entziehen",
    "entzöget": "entziehen",
    "entzückende": "entzückend",
    "entzückendem": "entzückend",
    "entzückenden": "entzückend",
    "entzückender": "entzückend",
    "entzückendere": "entzückend",
    "entzückenderem": "entzückend",
    "entzückenderen": "entzückend",
    "entzückenderer": "entzückend",
    "entzückenderes": "entzückend",
    "entzückendes": "entzückend",
    "entzückendste": "entzückend",
    "entzückendstem": "entzückend",
    "entzückendsten": "entzückend",
    "entzückendster": "entzückend",
    "entzückendstes": "entzückend",
    "entzündbarem": "entzündbar",
    "entzündbaren": "entzündbar",
    "entzündbarer": "entzündbar",
    "entzündbarere": "entzündbar",
    "entzündbarerem": "entzündbar",
    "entzündbareren": "entzündbar",
    "entzündbarerer": "entzündbar",
    "entzündbareres": "entzündbar",
    "entzündbares": "entzündbar",
    "entzündbarste": "entzündbar",
    "entzündbarstem": "entzündbar",
    "entzündbarsten": "entzündbar",
    "entzündbarster": "entzündbar",
    "entzündbarstes": "entzündbar",
    "entzünde": "entzünden",
    "entzündend": "entzünden",
    "entzündende": "entzündend",
    "entzündendem": "entzündend",
    "entzündenden": "entzündend",
    "entzündender": "entzündend",
    "entzündendes": "entzündend",
    "entzündest": "entzünden",
    "entzündet": "entzünden",
    "entzündete": "entzünden",
    "entzündetem": "entzündet",
    "entzündeten": "entzünden",
    "entzündeter": "entzündet",
    "entzündetes": "entzündet",
    "entzündetest": "entzünden",
    "entzündetet": "entzünden",
    "entzündliche": "entzündlich",
    "entzündlichem": "entzündlich",
    "entzündlichen": "entzündlich",
    "entzündlicher": "entzündlich",
    "entzündlichere": "entzündlich",
    "entzündlicherem": "entzündlich",
    "entzündlicheren": "entzündlich",
    "entzündlicherer": "entzündlich",
    "entzündlicheres": "entzündlich",
    "entzündliches": "entzündlich",
    "entzündlichste": "entzündlich",
    "entzündlichstem": "entzündlich",
    "entzündlichsten": "entzündlich",
    "entzündlichster": "entzündlich",
    "entzündlichstes": "entzündlich",
    "epidemiologischem": "epidemiologisch",
    "epidemiologischen": "epidemiologisch",
    "epidemiologischer": "epidemiologisch",
    "epidemiologisches": "epidemiologisch",
    "epileptischem": "epileptisch",
    "epileptischen": "epileptisch",
    "epileptischer": "epileptisch",
    "epileptisches": "epileptisch",
    "er": "ich",
    "erachte": "erachten",
    "erachtend": "erachten",
    "erachtende": "erachtend",
    "erachtendem": "erachtend",
    "erachtenden": "erachtend",
    "erachtender": "erachtend",
    "erachtendes": "erachtend",
    "erachtest": "erachten",
    "erachtet": "erachten",
    "erachtete": "erachten",
    "erachtetem": "erachtet",
    "erachteten": "erachten",
    "erachteter": "erachtet",
    "erachtetes": "erachtet",
    "erachtetest": "erachten",
    "erachtetet": "erachten",
    "erahne": "erahnen",
    "erahnend": "erahnen",
    "erahnende": "erahnend",
    "erahnendem": "erahnend",
    "erahnenden": "erahnend",
    "erahnender": "erahnend",
    "erahnendes": "erahnend",
    "erahnest": "erahnen",
    "erahnet": "erahnen",
    "erahnst": "erahnen",
    "erahnt": "erahnen",
    "erahnte": "erahnen",
    "erahntem": "erahnt",
    "erahnten": "erahnen",
    "erahnter": "erahnt",
    "erahntes": "erahnt",
    "erahntest": "erahnen",
    "erahntet": "erahnen",
    "erarbeite": "erarbeiten",
    "erarbeitend": "erarbeiten",
    "erarbeitende": "erarbeitend",
    "erarbeitendem": "erarbeitend",
    "erarbeitenden": "erarbeitend",
    "erarbeitender": "erarbeitend",
    "erarbeitendes": "erarbeitend",
    "erarbeitest": "erarbeiten",
    "erarbeitet": "erarbeiten",
    "erarbeitete": "erarbeiten",
    "erarbeitetem": "erarbeitet",
    "erarbeiteten": "erarbeiten",
    "erarbeiteter": "erarbeitet",
    "erarbeitetes": "erarbeitet",
    "erarbeitetest": "erarbeiten",
    "erarbeitetet": "erarbeiten",
    "erbarme": "erbarmen",
    "erbarmend": "erbarmen",
    "erbarmende": "erbarmend",
    "erbarmendem": "erbarmend",
    "erbarmenden": "erbarmend",
    "erbarmender": "erbarmend",
    "erbarmendes": "erbarmend",
    "erbarmenswertem": "erbarmenswert",
    "erbarmenswerten": "erbarmenswert",
    "erbarmenswerter": "erbarmenswert",
    "erbarmenswertere": "erbarmenswert",
    "erbarmenswerterem": "erbarmenswert",
    "erbarmenswerteren": "erbarmenswert",
    "erbarmenswerterer": "erbarmenswert",
    "erbarmenswerteres": "erbarmenswert",
    "erbarmenswertes": "erbarmenswert",
    "erbarmenswerteste": "erbarmenswert",
    "erbarmenswertestem": "erbarmenswert",
    "erbarmenswertesten": "erbarmenswert",
    "erbarmenswertester": "erbarmenswert",
    "erbarmenswertestes": "erbarmenswert",
    "erbarmest": "erbarmen",
    "erbarmet": "erbarmen",
    "erbarmst": "erbarmen",
    "erbarmt": "erbarmen",
    "erbarmte": "erbarmen",
    "erbarmtem": "erbarmt",
    "erbarmten": "erbarmen",
    "erbarmter": "erbarmt",
    "erbarmtes": "erbarmt",
    "erbarmtest": "erbarmen",
    "erbarmtet": "erbarmen",
    "erbarmungslose": "erbarmungslos",
    "erbarmungslosem": "erbarmungslos",
    "erbarmungslosen": "erbarmungslos",
    "erbarmungsloser": "erbarmungslos",
    "erbarmungslosere": "erbarmungslos",
    "erbarmungsloserem": "erbarmungslos",
    "erbarmungsloseren": "erbarmungslos",
    "erbarmungsloserer": "erbarmungslos",
    "erbarmungsloseres": "erbarmungslos",
    "erbarmungsloses": "erbarmungslos",
    "erbarmungsloseste": "erbarmungslos",
    "erbarmungslosestem": "erbarmungslos",
    "erbarmungslosesten": "erbarmungslos",
    "erbarmungslosester": "erbarmungslos",
    "erbarmungslosestes": "erbarmungslos",
    "erbarmungsvolle": "erbarmungsvoll",
    "erbarmungsvollem": "erbarmungsvoll",
    "erbarmungsvollen": "erbarmungsvoll",
    "erbarmungsvoller": "erbarmungsvoll",
    "erbarmungsvollere": "erbarmungsvoll",
    "erbarmungsvollerem": "erbarmungsvoll",
    "erbarmungsvolleren": "erbarmungsvoll",
    "erbarmungsvollerer": "erbarmungsvoll",
    "erbarmungsvolleres": "erbarmungsvoll",
    "erbarmungsvolles": "erbarmungsvoll",
    "erbarmungsvollste": "erbarmungsvoll",
    "erbarmungsvollstem": "erbarmungsvoll",
    "erbarmungsvollsten": "erbarmungsvoll",
    "erbarmungsvollster": "erbarmungsvoll",
    "erbarmungsvollstes": "erbarmungsvoll",
    "erbat": "erbitten",
    "erbaten": "erbitten",
    "erbatest": "erbitten",
    "erbatet": "erbitten",
    "erbaue": "erbauen",
    "erbauend": "erbauen",
    "erbauende": "erbauend",
    "erbauendem": "erbauend",
    "erbauenden": "erbauend",
    "erbauender": "erbauend",
    "erbauendes": "erbauend",
    "erbauest": "erbauen",
    "erbauet": "erbauen",
    "erbauliche": "erbaulich",
    "erbaulichem": "erbaulich",
    "erbaulichen": "erbaulich",
    "erbaulicher": "erbaulich",
    "erbaulichere": "erbaulich",
    "erbaulicherem": "erbaulich",
    "erbaulicheren": "erbaulich",
    "erbaulicherer": "erbaulich",
    "erbaulicheres": "erbaulich",
    "erbauliches": "erbaulich",
    "erbaulichste": "erbaulich",
    "erbaulichstem": "erbaulich",
    "erbaulichsten": "erbaulich",
    "erbaulichster": "erbaulich",
    "erbaulichstes": "erbaulich",
    "erbaust": "erbauen",
    "erbaut": "erbauen",
    "erbaute": "erbauen",
    "erbautem": "erbaut",
    "erbauten": "erbauen",
    "erbauter": "erbaut",
    "erbautes": "erbaut",
    "erbautest": "erbauen",
    "erbautet": "erbauen",
    "erbberechtigte": "erbberechtigt",
    "erbberechtigtem": "erbberechtigt",
    "erbberechtigten": "erbberechtigt",
    "erbberechtigter": "erbberechtigt",
    "erbberechtigtes": "erbberechtigt",
    "erbe": "erben",
    "erbebe": "erbeben",
    "erbebend": "erbeben",
    "erbebende": "erbebend",
    "erbebendem": "erbebend",
    "erbebenden": "erbebend",
    "erbebender": "erbebend",
    "erbebendere": "erbebend",
    "erbebenderem": "erbebend",
    "erbebenderen": "erbebend",
    "erbebenderer": "erbebend",
    "erbebenderes": "erbebend",
    "erbebendes": "erbebend",
    "erbebendste": "erbebend",
    "erbebendstem": "erbebend",
    "erbebendsten": "erbebend",
    "erbebendster": "erbebend",
    "erbebendstes": "erbebend",
    "erbebest": "erbeben",
    "erbebet": "erbeben",
    "erbebst": "erbeben",
    "erbebt": "erbeben",
    "erbebte": "erbeben",
    "erbebtem": "erbebt",
    "erbebten": "erbeben",
    "erbebter": "erbebt",
    "erbebtes": "erbebt",
    "erbebtest": "erbeben",
    "erbebtet": "erbeben",
    "erbend": "erben",
    "erbende": "erbend",
    "erbendem": "erbend",
    "erbenden": "erbend",
    "erbender": "erbend",
    "erbendes": "erbend",
    "erbest": "erben",
    "erbet": "erben",
    "erbete": "erbeten",
    "erbeten": "erbitten",
    "erbetend": "erbeten",
    "erbetende": "erbetend",
    "erbetendem": "erbetend",
    "erbetenden": "erbetend",
    "erbetender": "erbetend",
    "erbetendes": "erbetend",
    "erbetene": "erbeten",
    "erbetenem": "erbeten",
    "erbetenen": "erbeten",
    "erbetener": "erbeten",
    "erbetenes": "erbeten",
    "erbetest": "erbeten",
    "erbetet": "erbeten",
    "erbetete": "erbeten",
    "erbetetem": "erbetet",
    "erbeteten": "erbeten",
    "erbeteter": "erbetet",
    "erbetetes": "erbetet",
    "erbetetest": "erbeten",
    "erbetetet": "erbeten",
    "erbettele": "erbetteln",
    "erbettelnd": "erbetteln",
    "erbettelnde": "erbettelnd",
    "erbettelndem": "erbettelnd",
    "erbettelnden": "erbettelnd",
    "erbettelnder": "erbettelnd",
    "erbettelndes": "erbettelnd",
    "erbettelst": "erbetteln",
    "erbettelt": "erbetteln",
    "erbettelte": "erbetteln",
    "erbetteltem": "erbettelt",
    "erbettelten": "erbetteln",
    "erbettelter": "erbettelt",
    "erbetteltes": "erbettelt",
    "erbetteltest": "erbetteln",
    "erbetteltet": "erbetteln",
    "erbettle": "erbetteln",
    "erbeute": "erbeuten",
    "erbeutend": "erbeuten",
    "erbeutende": "erbeutend",
    "erbeutendem": "erbeutend",
    "erbeutenden": "erbeutend",
    "erbeutender": "erbeutend",
    "erbeutendes": "erbeutend",
    "erbeutest": "erbeuten",
    "erbeutet": "erbeuten",
    "erbeutete": "erbeuten",
    "erbeutetem": "erbeutet",
    "erbeuteten": "erbeuten",
    "erbeuteter": "erbeutet",
    "erbeutetes": "erbeutet",
    "erbeutetest": "erbeuten",
    "erbeutetet": "erbeuten",
    "erbitte": "erbitten",
    "erbittend": "erbitten",
    "erbittende": "erbittend",
    "erbittendem": "erbittend",
    "erbittenden": "erbittend",
    "erbittender": "erbittend",
    "erbittendes": "erbittend",
    "erbittest": "erbitten",
    "erbittet": "erbitten",
    "erblasse": "erblassen",
    "erblassend": "erblassen",
    "erblassende": "erblassend",
    "erblassendem": "erblassend",
    "erblassenden": "erblassend",
    "erblassender": "erblassend",
    "erblassendere": "erblassend",
    "erblassenderem": "erblassend",
    "erblassenderen": "erblassend",
    "erblassenderer": "erblassend",
    "erblassenderes": "erblassend",
    "erblassendes": "erblassend",
    "erblassendste": "erblassend",
    "erblassendstem": "erblassend",
    "erblassendsten": "erblassend",
    "erblassendster": "erblassend",
    "erblassendstes": "erblassend",
    "erblassest": "erblassen",
    "erblasset": "erblassen",
    "erblaßt": "erblassen",
    "erblaßte": "erblassen",
    "erblaßtem": "erblaßt",
    "erblaßten": "erblassen",
    "erblaßter": "erblaßt",
    "erblaßtere": "erblaßt",
    "erblaßterem": "erblaßt",
    "erblaßteren": "erblaßt",
    "erblaßterer": "erblaßt",
    "erblaßteres": "erblaßt",
    "erblaßtes": "erblaßt",
    "erblaßtest": "erblassen",
    "erblaßteste": "erblaßt",
    "erblaßtestem": "erblaßt",
    "erblaßtesten": "erblaßt",
    "erblaßtester": "erblaßt",
    "erblaßtestes": "erblaßt",
    "erblaßtet": "erblassen",
    "erbleiche": "erbleichen",
    "erbleichend": "erbleichen",
    "erbleichende": "erbleichend",
    "erbleichendem": "erbleichend",
    "erbleichenden": "erbleichend",
    "erbleichender": "erbleichend",
    "erbleichendere": "erbleichend",
    "erbleichenderem": "erbleichend",
    "erbleichenderen": "erbleichend",
    "erbleichenderer": "erbleichend",
    "erbleichenderes": "erbleichend",
    "erbleichendes": "erbleichend",
    "erbleichendste": "erbleichend",
    "erbleichendstem": "erbleichend",
    "erbleichendsten": "erbleichend",
    "erbleichendster": "erbleichend",
    "erbleichendstes": "erbleichend",
    "erbleichest": "erbleichen",
    "erbleichet": "erbleichen",
    "erbleichst": "erbleichen",
    "erbleicht": "erbleichen",
    "erblich": "erbleichen",
    "erbliche": "erbleichen",
    "erblichen": "erbleichen",
    "erblichene": "erblichen",
    "erblichenem": "erblichen",
    "erblichenen": "erblichen",
    "erblichener": "erblichen",
    "erblichenere": "erblichen",
    "erblichenerem": "erblichen",
    "erblicheneren": "erblichen",
    "erblichenerer": "erblichen",
    "erblicheneres": "erblichen",
    "erblichenes": "erblichen",
    "erblichenste": "erblichen",
    "erblichenstem": "erblichen",
    "erblichensten": "erblichen",
    "erblichenster": "erblichen",
    "erblichenstes": "erblichen",
    "erblichest": "erbleichen",
    "erblichet": "erbleichen",
    "erblichst": "erbleichen",
    "erblicht": "erbleichen",
    "erblicke": "erblicken",
    "erblickend": "erblicken",
    "erblickende": "erblickend",
    "erblickendem": "erblickend",
    "erblickenden": "erblickend",
    "erblickender": "erblickend",
    "erblickendes": "erblickend",
    "erblickest": "erblicken",
    "erblicket": "erblicken",
    "erblickst": "erblicken",
    "erblickt": "erblicken",
    "erblickte": "erblicken",
    "erblicktem": "erblickt",
    "erblickten": "erblicken",
    "erblickter": "erblickt",
    "erblicktes": "erblickt",
    "erblicktest": "erblicken",
    "erblicktet": "erblicken",
    "erblinde": "erblinden",
    "erblindend": "erblinden",
    "erblindende": "erblindend",
    "erblindendem": "erblindend",
    "erblindenden": "erblindend",
    "erblindender": "erblindend",
    "erblindendes": "erblindend",
    "erblindest": "erblinden",
    "erblindet": "erblinden",
    "erblindete": "erblinden",
    "erblindetem": "erblindet",
    "erblindeten": "erblinden",
    "erblindeter": "erblindet",
    "erblindetes": "erblindet",
    "erblindetest": "erblinden",
    "erblindetet": "erblinden",
    "erblühe": "erblühen",
    "erblühend": "erblühen",
    "erblühende": "erblühend",
    "erblühendem": "erblühend",
    "erblühenden": "erblühend",
    "erblühender": "erblühend",
    "erblühendere": "erblühend",
    "erblühenderem": "erblühend",
    "erblühenderen": "erblühend",
    "erblühenderer": "erblühend",
    "erblühenderes": "erblühend",
    "erblühendes": "erblühend",
    "erblühendste": "erblühend",
    "erblühendstem": "erblühend",
    "erblühendsten": "erblühend",
    "erblühendster": "erblühend",
    "erblühendstes": "erblühend",
    "erblühest": "erblühen",
    "erblühet": "erblühen",
    "erblühst": "erblühen",
    "erblüht": "erblühen",
    "erblühte": "erblühen",
    "erblühtem": "erblüht",
    "erblühten": "erblühen",
    "erblühter": "erblüht",
    "erblühtes": "erblüht",
    "erblühtest": "erblühen",
    "erblühtet": "erblühen",
    "erbrach": "erbrechen",
    "erbrachen": "erbrechen",
    "erbrachst": "erbrechen",
    "erbracht": "erbringen",
    "erbrachte": "erbracht",
    "erbrachtem": "erbracht",
    "erbrachten": "erbracht",
    "erbrachter": "erbracht",
    "erbrachtes": "erbracht",
    "erbrachtest": "erbringen",
    "erbrachtet": "erbringen",
    "erbreche": "erbrechen",
    "erbrechend": "erbrechen",
    "erbrechende": "erbrechend",
    "erbrechendem": "erbrechend",
    "erbrechenden": "erbrechend",
    "erbrechender": "erbrechend",
    "erbrechendes": "erbrechend",
    "erbrechest": "erbrechen",
    "erbrechet": "erbrechen",
    "erbrecht": "erbrechen",
    "erbrich": "erbrechen",
    "erbrichst": "erbrechen",
    "erbricht": "erbrechen",
    "erbringe": "erbringen",
    "erbringend": "erbringen",
    "erbringende": "erbringend",
    "erbringendem": "erbringend",
    "erbringenden": "erbringend",
    "erbringender": "erbringend",
    "erbringendes": "erbringend",
    "erbringest": "erbringen",
    "erbringet": "erbringen",
    "erbringst": "erbringen",
    "erbringt": "erbringen",
    "erbrochen": "erbrechen",
    "erbrochene": "erbrochen",
    "erbrochenem": "erbrochen",
    "erbrochenen": "erbrochen",
    "erbrochener": "erbrochen",
    "erbrochenes": "erbrochen",
    "erbräche": "erbrechen",
    "erbrächen": "erbrechen",
    "erbrächest": "erbrechen",
    "erbrächet": "erbrechen",
    "erbrächte": "erbringen",
    "erbrächten": "erbringen",
    "erbrächtest": "erbringen",
    "erbrächtet": "erbringen",
    "erbst": "erben",
    "erbt": "erben",
    "erbte": "erben",
    "erbten": "erben",
    "erbtest": "erben",
    "erbtet": "erben",
    "erbärmliche": "erbärmlich",
    "erbärmlichem": "erbärmlich",
    "erbärmlichen": "erbärmlich",
    "erbärmlicher": "erbärmlich",
    "erbärmlichere": "erbärmlich",
    "erbärmlicherem": "erbärmlich",
    "erbärmlicheren": "erbärmlich",
    "erbärmlicherer": "erbärmlich",
    "erbärmlicheres": "erbärmlich",
    "erbärmliches": "erbärmlich",
    "erbärmlichste": "erbärmlich",
    "erbärmlichstem": "erbärmlich",
    "erbärmlichsten": "erbärmlich",
    "erbärmlichster": "erbärmlich",
    "erbärmlichstes": "erbärmlich",
    "erbäte": "erbitten",
    "erbäten": "erbitten",
    "erbätest": "erbitten",
    "erbätet": "erbitten",
    "erdacht": "erdenken",
    "erdachte": "erdacht",
    "erdachtem": "erdacht",
    "erdachten": "erdacht",
    "erdachter": "erdacht",
    "erdachtes": "erdacht",
    "erdachtest": "erdenken",
    "erdachtet": "erdenken",
    "erdend": "erden",
    "erdende": "erdend",
    "erdendem": "erdend",
    "erdenden": "erdend",
    "erdender": "erdend",
    "erdendes": "erdend",
    "erdenke": "erdenken",
    "erdenkend": "erdenken",
    "erdenkende": "erdenkend",
    "erdenkendem": "erdenkend",
    "erdenkenden": "erdenkend",
    "erdenkender": "erdenkend",
    "erdenkendes": "erdenkend",
    "erdenkest": "erdenken",
    "erdenket": "erdenken",
    "erdenkliche": "erdenklich",
    "erdenklichem": "erdenklich",
    "erdenklichen": "erdenklich",
    "erdenklicher": "erdenklich",
    "erdenkliches": "erdenklich",
    "erdenkst": "erdenken",
    "erdenkt": "erdenken",
    "erdest": "erden",
    "erdet": "erden",
    "erdete": "erden",
    "erdeten": "erden",
    "erdetest": "erden",
    "erdetet": "erden",
    "erdfarbene": "erdfarben",
    "erdfarbenem": "erdfarben",
    "erdfarbenen": "erdfarben",
    "erdfarbener": "erdfarben",
    "erdfarbenes": "erdfarben",
    "erdigem": "erdig",
    "erdigen": "erdig",
    "erdiger": "erdig",
    "erdiges": "erdig",
    "erdolche": "erdolchen",
    "erdolchend": "erdolchen",
    "erdolchende": "erdolchend",
    "erdolchendem": "erdolchend",
    "erdolchenden": "erdolchend",
    "erdolchender": "erdolchend",
    "erdolchendes": "erdolchend",
    "erdolchest": "erdolchen",
    "erdolchet": "erdolchen",
    "erdolchst": "erdolchen",
    "erdolcht": "erdolchen",
    "erdolchte": "erdolchen",
    "erdolchtem": "erdolcht",
    "erdolchten": "erdolchen",
    "erdolchter": "erdolcht",
    "erdolchtes": "erdolcht",
    "erdolchtest": "erdolchen",
    "erdolchtet": "erdolchen",
    "erdreiste": "erdreisten",
    "erdreistend": "erdreisten",
    "erdreistende": "erdreistend",
    "erdreistendem": "erdreistend",
    "erdreistenden": "erdreistend",
    "erdreistender": "erdreistend",
    "erdreistendes": "erdreistend",
    "erdreistest": "erdreisten",
    "erdreistet": "erdreisten",
    "erdreistete": "erdreisten",
    "erdreistetem": "erdreistet",
    "erdreisteten": "erdreisten",
    "erdreisteter": "erdreistet",
    "erdreistetere": "erdreistet",
    "erdreisteterem": "erdreistet",
    "erdreisteteren": "erdreistet",
    "erdreisteterer": "erdreistet",
    "erdreisteteres": "erdreistet",
    "erdreistetes": "erdreistet",
    "erdreistetest": "erdreisten",
    "erdreisteteste": "erdreistet",
    "erdreistetestem": "erdreistet",
    "erdreistetesten": "erdreistet",
    "erdreistetester": "erdreistet",
    "erdreistetestes": "erdreistet",
    "erdreistetet": "erdreisten",
    "erdrossele": "erdrosseln",
    "erdrosselnd": "erdrosseln",
    "erdrosselnde": "erdrosselnd",
    "erdrosselndem": "erdrosselnd",
    "erdrosselnden": "erdrosselnd",
    "erdrosselnder": "erdrosselnd",
    "erdrosselndes": "erdrosselnd",
    "erdrosselst": "erdrosseln",
    "erdrosselt": "erdrosseln",
    "erdrosselte": "erdrosseln",
    "erdrosseltem": "erdrosselt",
    "erdrosselten": "erdrosseln",
    "erdrosselter": "erdrosselt",
    "erdrosseltes": "erdrosselt",
    "erdrosseltest": "erdrosseln",
    "erdrosseltet": "erdrosseln",
    "erdrossle": "erdrosseln",
    "erdrutschartige": "erdrutschartig",
    "erdrutschartigem": "erdrutschartig",
    "erdrutschartigen": "erdrutschartig",
    "erdrutschartiger": "erdrutschartig",
    "erdrutschartiges": "erdrutschartig",
    "erdulde": "erdulden",
    "erduldend": "erdulden",
    "erduldende": "erduldend",
    "erduldendem": "erduldend",
    "erduldenden": "erduldend",
    "erduldender": "erduldend",
    "erduldendere": "erduldend",
    "erduldenderem": "erduldend",
    "erduldenderen": "erduldend",
    "erduldenderer": "erduldend",
    "erduldenderes": "erduldend",
    "erduldendes": "erduldend",
    "erduldendste": "erduldend",
    "erduldendstem": "erduldend",
    "erduldendsten": "erduldend",
    "erduldendster": "erduldend",
    "erduldendstes": "erduldend",
    "erduldest": "erdulden",
    "erduldet": "erdulden",
    "erduldete": "erdulden",
    "erduldetem": "erduldet",
    "erduldeten": "erdulden",
    "erduldeter": "erduldet",
    "erduldetere": "erduldet",
    "erduldeterem": "erduldet",
    "erduldeteren": "erduldet",
    "erduldeterer": "erduldet",
    "erduldeteres": "erduldet",
    "erduldetes": "erduldet",
    "erduldetest": "erdulden",
    "erduldeteste": "erduldet",
    "erduldetestem": "erduldet",
    "erduldetesten": "erduldet",
    "erduldetester": "erduldet",
    "erduldetestes": "erduldet",
    "erduldetet": "erdulden",
    "erdumspannendem": "erdumspannend",
    "erdumspannenden": "erdumspannend",
    "erdumspannender": "erdumspannend",
    "erdumspannendes": "erdumspannend",
    "erdverbundenem": "erdverbunden",
    "erdverbundenen": "erdverbunden",
    "erdverbundener": "erdverbunden",
    "erdverbundenere": "erdverbunden",
    "erdverbundenerem": "erdverbunden",
    "erdverbundeneren": "erdverbunden",
    "erdverbundenerer": "erdverbunden",
    "erdverbundeneres": "erdverbunden",
    "erdverbundenes": "erdverbunden",
    "erdverbundenste": "erdverbunden",
    "erdverbundenstem": "erdverbunden",
    "erdverbundensten": "erdverbunden",
    "erdverbundenster": "erdverbunden",
    "erdverbundenstes": "erdverbunden",
    "erdächte": "erdenken",
    "erdächten": "erdenken",
    "erdächtest": "erdenken",
    "erdächtet": "erdenken",
    "ereifere": "ereifern",
    "ereifernd": "ereifern",
    "ereifernde": "ereifernd",
    "ereiferndem": "ereifernd",
    "ereifernden": "ereifernd",
    "ereifernder": "ereifernd",
    "ereiferndere": "ereifernd",
    "ereifernderem": "ereifernd",
    "ereifernderen": "ereifernd",
    "ereifernderer": "ereifernd",
    "ereifernderes": "ereifernd",
    "ereiferndes": "ereifernd",
    "ereiferndste": "ereifernd",
    "ereiferndstem": "ereifernd",
    "ereiferndsten": "ereifernd",
    "ereiferndster": "ereifernd",
    "ereiferndstes": "ereifernd",
    "ereiferst": "ereifern",
    "ereifert": "ereifern",
    "ereiferte": "ereifern",
    "ereifertem": "ereifert",
    "ereiferten": "ereifern",
    "ereiferter": "ereifert",
    "ereifertere": "ereifert",
    "ereiferterem": "ereifert",
    "ereiferteren": "ereifert",
    "ereiferterer": "ereifert",
    "ereiferteres": "ereifert",
    "ereifertes": "ereifert",
    "ereifertest": "ereifern",
    "ereiferteste": "ereifert",
    "ereifertestem": "ereifert",
    "ereifertesten": "ereifert",
    "ereifertester": "ereifert",
    "ereifertestes": "ereifert",
    "ereifertet": "ereifern",
    "ereigne": "ereignen",
    "ereignend": "ereignen",
    "ereignende": "ereignend",
    "ereignendem": "ereignend",
    "ereignenden": "ereignend",
    "ereignender": "ereignend",
    "ereignendes": "ereignend",
    "ereignest": "ereignen",
    "ereignet": "ereignen",
    "ereignete": "ereignen",
    "ereignetem": "ereignet",
    "ereigneten": "ereignen",
    "ereigneter": "ereignet",
    "ereignetes": "ereignet",
    "ereignetest": "ereignen",
    "ereignetet": "ereignen",
    "ereignislose": "ereignislos",
    "ereignislosem": "ereignislos",
    "ereignislosen": "ereignislos",
    "ereignisloser": "ereignislos",
    "ereignislosere": "ereignislos",
    "ereignisloserem": "ereignislos",
    "ereignisloseren": "ereignislos",
    "ereignisloserer": "ereignislos",
    "ereignisloseres": "ereignislos",
    "ereignisloses": "ereignislos",
    "ereignisloseste": "ereignislos",
    "ereignislosestem": "ereignislos",
    "ereignislosesten": "ereignislos",
    "ereignislosester": "ereignislos",
    "ereignislosestes": "ereignislos",
    "ereignisreiche": "ereignisreich",
    "ereignisreichem": "ereignisreich",
    "ereignisreichen": "ereignisreich",
    "ereignisreicher": "ereignisreich",
    "ereignisreichere": "ereignisreich",
    "ereignisreicherem": "ereignisreich",
    "ereignisreicheren": "ereignisreich",
    "ereignisreicherer": "ereignisreich",
    "ereignisreicheres": "ereignisreich",
    "ereignisreiches": "ereignisreich",
    "ereignisreichste": "ereignisreich",
    "ereignisreichstem": "ereignisreich",
    "ereignisreichsten": "ereignisreich",
    "ereignisreichster": "ereignisreich",
    "ereignisreichstes": "ereignisreich",
    "ereile": "ereilen",
    "ereilend": "ereilen",
    "ereilende": "ereilend",
    "ereilendem": "ereilend",
    "ereilenden": "ereilend",
    "ereilender": "ereilend",
    "ereilendes": "ereilend",
    "ereilest": "ereilen",
    "ereilet": "ereilen",
    "ereilst": "ereilen",
    "ereilt": "ereilen",
    "ereilte": "ereilen",
    "ereiltem": "ereilt",
    "ereilten": "ereilen",
    "ereilter": "ereilt",
    "ereiltes": "ereilt",
    "ereiltest": "ereilen",
    "ereiltet": "ereilen",
    "erfahre": "erfahren",
    "erfahrend": "erfahren",
    "erfahrende": "erfahrend",
    "erfahrendem": "erfahrend",
    "erfahrenden": "erfahrend",
    "erfahrender": "erfahrend",
    "erfahrendes": "erfahrend",
    "erfahrene": "erfahren",
    "erfahrenem": "erfahren",
    "erfahrenen": "erfahren",
    "erfahrener": "erfahren",
    "erfahrenere": "erfahren",
    "erfahrenerem": "erfahren",
    "erfahreneren": "erfahren",
    "erfahrenerer": "erfahren",
    "erfahreneres": "erfahren",
    "erfahrenes": "erfahren",
    "erfahrenstem": "erfahren",
    "erfahrensten": "erfahren",
    "erfahrenster": "erfahren",
    "erfahrenstes": "erfahren",
    "erfahrest": "erfahren",
    "erfahret": "erfahren",
    "erfahrt": "erfahren",
    "erfahrungsgemäßem": "erfahrungsgemäß",
    "erfahrungsgemäßen": "erfahrungsgemäß",
    "erfahrungsgemäßer": "erfahrungsgemäß",
    "erfahrungsgemäßes": "erfahrungsgemäß",
    "erfand": "erfinden",
    "erfanden": "erfinden",
    "erfandest": "erfinden",
    "erfandet": "erfinden",
    "erfasse": "erfassen",
    "erfassend": "erfassen",
    "erfassende": "erfassend",
    "erfassendem": "erfassend",
    "erfassenden": "erfassend",
    "erfassender": "erfassend",
    "erfassendes": "erfassend",
    "erfassest": "erfassen",
    "erfasset": "erfassen",
    "erfaßt": "erfassen",
    "erfaßte": "erfassen",
    "erfaßtem": "erfaßt",
    "erfaßten": "erfassen",
    "erfaßter": "erfaßt",
    "erfaßtes": "erfaßt",
    "erfaßtest": "erfassen",
    "erfaßtet": "erfassen",
    "erfinde": "erfinden",
    "erfindend": "erfinden",
    "erfindende": "erfindend",
    "erfindendem": "erfindend",
    "erfindenden": "erfindend",
    "erfindender": "erfindend",
    "erfindendere": "erfindend",
    "erfindenderem": "erfindend",
    "erfindenderen": "erfindend",
    "erfindenderer": "erfindend",
    "erfindenderes": "erfindend",
    "erfindendes": "erfindend",
    "erfindendste": "erfindend",
    "erfindendstem": "erfindend",
    "erfindendsten": "erfindend",
    "erfindendster": "erfindend",
    "erfindendstes": "erfindend",
    "erfinderischem": "erfinderisch",
    "erfinderischen": "erfinderisch",
    "erfinderischer": "erfinderisch",
    "erfinderischere": "erfinderisch",
    "erfinderischerem": "erfinderisch",
    "erfinderischeren": "erfinderisch",
    "erfinderischerer": "erfinderisch",
    "erfinderischeres": "erfinderisch",
    "erfinderisches": "erfinderisch",
    "erfinderischste": "erfinderisch",
    "erfinderischstem": "erfinderisch",
    "erfinderischsten": "erfinderisch",
    "erfinderischster": "erfinderisch",
    "erfinderischstes": "erfinderisch",
    "erfindest": "erfinden",
    "erfindet": "erfinden",
    "erfindungsreichem": "erfindungsreich",
    "erfindungsreichen": "erfindungsreich",
    "erfindungsreicher": "erfindungsreich",
    "erfindungsreichere": "erfindungsreich",
    "erfindungsreicherem": "erfindungsreich",
    "erfindungsreicheren": "erfindungsreich",
    "erfindungsreicherer": "erfindungsreich",
    "erfindungsreicheres": "erfindungsreich",
    "erfindungsreiches": "erfindungsreich",
    "erfindungsreichste": "erfindungsreich",
    "erfindungsreichstem": "erfindungsreich",
    "erfindungsreichsten": "erfindungsreich",
    "erfindungsreichster": "erfindungsreich",
    "erfindungsreichstes": "erfindungsreich",
    "erfolgend": "erfolgen",
    "erfolgende": "erfolgend",
    "erfolgendem": "erfolgend",
    "erfolgenden": "erfolgend",
    "erfolgender": "erfolgend",
    "erfolgendes": "erfolgend",
    "erfolgest": "erfolgen",
    "erfolget": "erfolgen",
    "erfolglose": "erfolglos",
    "erfolglosem": "erfolglos",
    "erfolglosen": "erfolglos",
    "erfolgloser": "erfolglos",
    "erfolglosere": "erfolglos",
    "erfolgloserem": "erfolglos",
    "erfolgloseren": "erfolglos",
    "erfolgloserer": "erfolglos",
    "erfolgloseres": "erfolglos",
    "erfolgloses": "erfolglos",
    "erfolgloseste": "erfolglos",
    "erfolglosestem": "erfolglos",
    "erfolglosesten": "erfolglos",
    "erfolglosester": "erfolglos",
    "erfolglosestes": "erfolglos",
    "erfolgreiche": "erfolgreich",
    "erfolgreichem": "erfolgreich",
    "erfolgreichen": "erfolgreich",
    "erfolgreicher": "erfolgreich",
    "erfolgreichere": "erfolgreich",
    "erfolgreicherem": "erfolgreich",
    "erfolgreicheren": "erfolgreich",
    "erfolgreicherer": "erfolgreich",
    "erfolgreicheres": "erfolgreich",
    "erfolgreiches": "erfolgreich",
    "erfolgreichste": "erfolgreich",
    "erfolgreichstem": "erfolgreich",
    "erfolgreichsten": "erfolgreich",
    "erfolgreichster": "erfolgreich",
    "erfolgreichstes": "erfolgreich",
    "erfolgssicherem": "erfolgssicher",
    "erfolgssicheren": "erfolgssicher",
    "erfolgssicherer": "erfolgssicher",
    "erfolgssicheres": "erfolgssicher",
    "erfolgst": "erfolgen",
    "erfolgsverwöhnte": "erfolgsverwöhnt",
    "erfolgsverwöhntem": "erfolgsverwöhnt",
    "erfolgsverwöhnten": "erfolgsverwöhnt",
    "erfolgsverwöhnter": "erfolgsverwöhnt",
    "erfolgsverwöhntere": "erfolgsverwöhnt",
    "erfolgsverwöhnterem": "erfolgsverwöhnt",
    "erfolgsverwöhnteren": "erfolgsverwöhnt",
    "erfolgsverwöhnterer": "erfolgsverwöhnt",
    "erfolgsverwöhnteres": "erfolgsverwöhnt",
    "erfolgsverwöhntes": "erfolgsverwöhnt",
    "erfolgsverwöhnteste": "erfolgsverwöhnt",
    "erfolgsverwöhntestem": "erfolgsverwöhnt",
    "erfolgsverwöhntesten": "erfolgsverwöhnt",
    "erfolgsverwöhntester": "erfolgsverwöhnt",
    "erfolgsverwöhntestes": "erfolgsverwöhnt",
    "erfolgt": "erfolgen",
    "erfolgte": "erfolgen",
    "erfolgtem": "erfolgt",
    "erfolgten": "erfolgen",
    "erfolgter": "erfolgt",
    "erfolgtes": "erfolgt",
    "erfolgtest": "erfolgen",
    "erfolgtet": "erfolgen",
    "erfolgversprechende": "erfolgversprechend",
    "erfolgversprechendem": "erfolgversprechend",
    "erfolgversprechenden": "erfolgversprechend",
    "erfolgversprechender": "erfolgversprechend",
    "erfolgversprechendere": "erfolgversprechend",
    "erfolgversprechenderem": "erfolgversprechend",
    "erfolgversprechenderen": "erfolgversprechend",
    "erfolgversprechenderer": "erfolgversprechend",
    "erfolgversprechenderes": "erfolgversprechend",
    "erfolgversprechendes": "erfolgversprechend",
    "erfolgversprechendste": "erfolgversprechend",
    "erfolgversprechendstem": "erfolgversprechend",
    "erfolgversprechendsten": "erfolgversprechend",
    "erfolgversprechendster": "erfolgversprechend",
    "erfolgversprechendstes": "erfolgversprechend",
    "erfordere": "erfordern",
    "erforderliche": "erforderlich",
    "erforderlichem": "erforderlich",
    "erforderlichen": "erforderlich",
    "erforderlicher": "erforderlich",
    "erforderliches": "erforderlich",
    "erfordernd": "erfordern",
    "erfordernde": "erfordernd",
    "erforderndem": "erfordernd",
    "erfordernden": "erfordernd",
    "erfordernder": "erfordernd",
    "erforderndes": "erfordernd",
    "erforderst": "erfordern",
    "erfordert": "erfordern",
    "erforderte": "erfordern",
    "erfordertem": "erfordert",
    "erforderten": "erfordern",
    "erforderter": "erfordert",
    "erfordertes": "erfordert",
    "erfordertest": "erfordern",
    "erfordertet": "erfordern",
    "erforsche": "erforschen",
    "erforschend": "erforschen",
    "erforschende": "erforschend",
    "erforschendem": "erforschend",
    "erforschenden": "erforschend",
    "erforschender": "erforschend",
    "erforschendere": "erforschend",
    "erforschenderem": "erforschend",
    "erforschenderen": "erforschend",
    "erforschenderer": "erforschend",
    "erforschenderes": "erforschend",
    "erforschendes": "erforschend",
    "erforschendste": "erforschend",
    "erforschendstem": "erforschend",
    "erforschendsten": "erforschend",
    "erforschendster": "erforschend",
    "erforschendstes": "erforschend",
    "erforschest": "erforschen",
    "erforschet": "erforschen",
    "erforschst": "erforschen",
    "erforscht": "erforschen",
    "erforschte": "erforschen",
    "erforschtem": "erforscht",
    "erforschten": "erforschen",
    "erforschter": "erforscht",
    "erforschtere": "erforscht",
    "erforschterem": "erforscht",
    "erforschteren": "erforscht",
    "erforschterer": "erforscht",
    "erforschteres": "erforscht",
    "erforschtes": "erforscht",
    "erforschtest": "erforschen",
    "erforschteste": "erforscht",
    "erforschtestem": "erforscht",
    "erforschtesten": "erforscht",
    "erforschtester": "erforscht",
    "erforschtestes": "erforscht",
    "erforschtet": "erforschen",
    "erfrage": "erfragen",
    "erfragend": "erfragen",
    "erfragende": "erfragend",
    "erfragendem": "erfragend",
    "erfragenden": "erfragend",
    "erfragender": "erfragend",
    "erfragendes": "erfragend",
    "erfragest": "erfragen",
    "erfraget": "erfragen",
    "erfragst": "erfragen",
    "erfragt": "erfragen",
    "erfragte": "erfragen",
    "erfragtem": "erfragt",
    "erfragten": "erfragen",
    "erfragter": "erfragt",
    "erfragtes": "erfragt",
    "erfragtest": "erfragen",
    "erfragtet": "erfragen",
    "erfreue": "erfreuen",
    "erfreuend": "erfreuen",
    "erfreuende": "erfreuend",
    "erfreuendem": "erfreuend",
    "erfreuenden": "erfreuend",
    "erfreuender": "erfreuend",
    "erfreuendere": "erfreuend",
    "erfreuenderem": "erfreuend",
    "erfreuenderen": "erfreuend",
    "erfreuenderer": "erfreuend",
    "erfreuenderes": "erfreuend",
    "erfreuendes": "erfreuend",
    "erfreuendste": "erfreuend",
    "erfreuendstem": "erfreuend",
    "erfreuendsten": "erfreuend",
    "erfreuendster": "erfreuend",
    "erfreuendstes": "erfreuend",
    "erfreuest": "erfreuen",
    "erfreuet": "erfreuen",
    "erfreuliche": "erfreulich",
    "erfreulichem": "erfreulich",
    "erfreulichen": "erfreulich",
    "erfreulicher": "erfreulich",
    "erfreulichere": "erfreulich",
    "erfreulicherem": "erfreulich",
    "erfreulicheren": "erfreulich",
    "erfreulicherer": "erfreulich",
    "erfreulicheres": "erfreulich",
    "erfreuliches": "erfreulich",
    "erfreulichste": "erfreulich",
    "erfreulichstem": "erfreulich",
    "erfreulichsten": "erfreulich",
    "erfreulichster": "erfreulich",
    "erfreulichstes": "erfreulich",
    "erfreust": "erfreuen",
    "erfreut": "erfreuen",
    "erfreute": "erfreuen",
    "erfreutem": "erfreut",
    "erfreuten": "erfreuen",
    "erfreuter": "erfreut",
    "erfreutere": "erfreut",
    "erfreuterem": "erfreut",
    "erfreuteren": "erfreut",
    "erfreuterer": "erfreut",
    "erfreuteres": "erfreut",
    "erfreutes": "erfreut",
    "erfreutest": "erfreuen",
    "erfreuteste": "erfreut",
    "erfreutestem": "erfreut",
    "erfreutesten": "erfreut",
    "erfreutester": "erfreut",
    "erfreutestes": "erfreut",
    "erfreutet": "erfreuen",
    "erfrische": "erfrischen",
    "erfrischend": "erfrischen",
    "erfrischende": "erfrischend",
    "erfrischendem": "erfrischend",
    "erfrischenden": "erfrischend",
    "erfrischender": "erfrischend",
    "erfrischendere": "erfrischend",
    "erfrischenderem": "erfrischend",
    "erfrischenderen": "erfrischend",
    "erfrischenderer": "erfrischend",
    "erfrischenderes": "erfrischend",
    "erfrischendes": "erfrischend",
    "erfrischendste": "erfrischend",
    "erfrischendstem": "erfrischend",
    "erfrischendsten": "erfrischend",
    "erfrischendster": "erfrischend",
    "erfrischendstes": "erfrischend",
    "erfrischest": "erfrischen",
    "erfrischet": "erfrischen",
    "erfrischst": "erfrischen",
    "erfrischt": "erfrischen",
    "erfrischte": "erfrischen",
    "erfrischtem": "erfrischt",
    "erfrischten": "erfrischen",
    "erfrischter": "erfrischt",
    "erfrischtere": "erfrischt",
    "erfrischterem": "erfrischt",
    "erfrischteren": "erfrischt",
    "erfrischterer": "erfrischt",
    "erfrischteres": "erfrischt",
    "erfrischtes": "erfrischt",
    "erfrischtest": "erfrischen",
    "erfrischteste": "erfrischt",
    "erfrischtestem": "erfrischt",
    "erfrischtesten": "erfrischt",
    "erfrischtester": "erfrischt",
    "erfrischtestes": "erfrischt",
    "erfrischtet": "erfrischen",
    "erfuhr": "erfahren",
    "erfuhren": "erfahren",
    "erfuhrst": "erfahren",
    "erfuhrt": "erfahren",
    "erfunden": "erfinden",
    "erfundene": "erfunden",
    "erfundenem": "erfunden",
    "erfundenen": "erfunden",
    "erfundener": "erfunden",
    "erfundenes": "erfunden",
    "erfährst": "erfahren",
    "erfährt": "erfahren",
    "erfände": "erfinden",
    "erfänden": "erfinden",
    "erfändest": "erfinden",
    "erfändet": "erfinden",
    "erführe": "erfahren",
    "erführen": "erfahren",
    "erführest": "erfahren",
    "erführet": "erfahren",
    "erfülle": "erfüllen",
    "erfüllend": "erfüllen",
    "erfüllende": "erfüllend",
    "erfüllendem": "erfüllend",
    "erfüllenden": "erfüllend",
    "erfüllender": "erfüllend",
    "erfüllendes": "erfüllend",
    "erfüllest": "erfüllen",
    "erfüllet": "erfüllen",
    "erfüllst": "erfüllen",
    "erfüllt": "erfüllen",
    "erfüllte": "erfüllen",
    "erfülltem": "erfüllt",
    "erfüllten": "erfüllen",
    "erfüllter": "erfüllt",
    "erfülltere": "erfüllt",
    "erfüllterem": "erfüllt",
    "erfüllteren": "erfüllt",
    "erfüllterer": "erfüllt",
    "erfüllteres": "erfüllt",
    "erfülltes": "erfüllt",
    "erfülltest": "erfüllen",
    "erfüllteste": "erfüllt",
    "erfülltestem": "erfüllt",
    "erfülltesten": "erfüllt",
    "erfülltester": "erfüllt",
    "erfülltestes": "erfüllt",
    "erfülltet": "erfüllen",
    "ergab": "ergeben",
    "ergaben": "ergeben",
    "ergabst": "ergeben",
    "ergabt": "ergeben",
    "ergaunere": "ergaunern",
    "ergaunernd": "ergaunern",
    "ergaunernde": "ergaunernd",
    "ergaunerndem": "ergaunernd",
    "ergaunernden": "ergaunernd",
    "ergaunernder": "ergaunernd",
    "ergaunerndes": "ergaunernd",
    "ergaunerst": "ergaunern",
    "ergaunert": "ergaunern",
    "ergaunerte": "ergaunern",
    "ergaunertem": "ergaunert",
    "ergaunerten": "ergaunern",
    "ergaunerter": "ergaunert",
    "ergaunertes": "ergaunert",
    "ergaunertest": "ergaunern",
    "ergaunertet": "ergaunern",
    "ergebe": "ergeben",
    "ergebend": "ergeben",
    "ergebende": "ergebend",
    "ergebendem": "ergebend",
    "ergebenden": "ergebend",
    "ergebender": "ergebend",
    "ergebendere": "ergebend",
    "ergebenderem": "ergebend",
    "ergebenderen": "ergebend",
    "ergebenderer": "ergebend",
    "ergebenderes": "ergebend",
    "ergebendes": "ergebend",
    "ergebendste": "ergebend",
    "ergebendstem": "ergebend",
    "ergebendsten": "ergebend",
    "ergebendster": "ergebend",
    "ergebendstes": "ergebend",
    "ergebene": "ergeben",
    "ergebenem": "ergeben",
    "ergebenen": "ergeben",
    "ergebener": "ergeben",
    "ergebenere": "ergeben",
    "ergebenerem": "ergeben",
    "ergebeneren": "ergeben",
    "ergebenerer": "ergeben",
    "ergebeneres": "ergeben",
    "ergebenes": "ergeben",
    "ergebenstem": "ergeben",
    "ergebensten": "ergeben",
    "ergebenster": "ergeben",
    "ergebenstes": "ergeben",
    "ergebest": "ergeben",
    "ergebet": "ergeben",
    "ergebnislose": "ergebnislos",
    "ergebnislosem": "ergebnislos",
    "ergebnislosen": "ergebnislos",
    "ergebnisloser": "ergebnislos",
    "ergebnislosere": "ergebnislos",
    "ergebnisloserem": "ergebnislos",
    "ergebnisloseren": "ergebnislos",
    "ergebnisloserer": "ergebnislos",
    "ergebnisloseres": "ergebnislos",
    "ergebnisloses": "ergebnislos",
    "ergebnisloseste": "ergebnislos",
    "ergebnislosestem": "ergebnislos",
    "ergebnislosesten": "ergebnislos",
    "ergebnislosester": "ergebnislos",
    "ergebnislosestes": "ergebnislos",
    "ergebt": "ergeben",
    "ergib": "ergeben",
    "ergibst": "ergeben",
    "ergibt": "ergeben",
    "ergiebige": "ergiebig",
    "ergiebigem": "ergiebig",
    "ergiebigen": "ergiebig",
    "ergiebiger": "ergiebig",
    "ergiebigere": "ergiebig",
    "ergiebigerem": "ergiebig",
    "ergiebigeren": "ergiebig",
    "ergiebigerer": "ergiebig",
    "ergiebigeres": "ergiebig",
    "ergiebiges": "ergiebig",
    "ergiebigste": "ergiebig",
    "ergiebigstem": "ergiebig",
    "ergiebigsten": "ergiebig",
    "ergiebigster": "ergiebig",
    "ergiebigstes": "ergiebig",
    "ergieße": "ergießen",
    "ergießend": "ergießen",
    "ergießende": "ergießend",
    "ergießendem": "ergießend",
    "ergießenden": "ergießend",
    "ergießender": "ergießend",
    "ergießendes": "ergießend",
    "ergießest": "ergießen",
    "ergießet": "ergießen",
    "ergießt": "ergießen",
    "ergonomische": "ergonomisch",
    "ergonomischem": "ergonomisch",
    "ergonomischen": "ergonomisch",
    "ergonomischer": "ergonomisch",
    "ergonomischere": "ergonomisch",
    "ergonomischerem": "ergonomisch",
    "ergonomischeren": "ergonomisch",
    "ergonomischerer": "ergonomisch",
    "ergonomischeres": "ergonomisch",
    "ergonomisches": "ergonomisch",
    "ergonomischste": "ergonomisch",
    "ergonomischstem": "ergonomisch",
    "ergonomischsten": "ergonomisch",
    "ergonomischster": "ergonomisch",
    "ergonomischstes": "ergonomisch",
    "ergossen": "ergießen",
    "ergossene": "ergossen",
    "ergossenem": "ergossen",
    "ergossenen": "ergossen",
    "ergossener": "ergossen",
    "ergossenes": "ergossen",
    "ergoß": "ergießen",
    "ergoßt": "ergießen",
    "ergreife": "ergreifen",
    "ergreifend": "ergreifen",
    "ergreifende": "ergreifend",
    "ergreifendem": "ergreifend",
    "ergreifenden": "ergreifend",
    "ergreifender": "ergreifend",
    "ergreifendes": "ergreifend",
    "ergreifest": "ergreifen",
    "ergreifet": "ergreifen",
    "ergreifst": "ergreifen",
    "ergreift": "ergreifen",
    "ergriff": "ergreifen",
    "ergriffe": "ergreifen",
    "ergriffen": "ergreifen",
    "ergriffene": "ergriffen",
    "ergriffenem": "ergriffen",
    "ergriffenen": "ergriffen",
    "ergriffener": "ergriffen",
    "ergriffenere": "ergriffen",
    "ergriffenerem": "ergriffen",
    "ergriffeneren": "ergriffen",
    "ergriffenerer": "ergriffen",
    "ergriffeneres": "ergriffen",
    "ergriffenes": "ergriffen",
    "ergriffenste": "ergriffen",
    "ergriffenstem": "ergriffen",
    "ergriffensten": "ergriffen",
    "ergriffenster": "ergriffen",
    "ergriffenstes": "ergriffen",
    "ergriffest": "ergreifen",
    "ergriffet": "ergreifen",
    "ergriffst": "ergreifen",
    "ergrifft": "ergreifen",
    "ergründe": "ergründen",
    "ergründend": "ergründen",
    "ergründende": "ergründend",
    "ergründendem": "ergründend",
    "ergründenden": "ergründend",
    "ergründender": "ergründend",
    "ergründendes": "ergründend",
    "ergründest": "ergründen",
    "ergründet": "ergründen",
    "ergründete": "ergründen",
    "ergründetem": "ergründet",
    "ergründeten": "ergründen",
    "ergründeter": "ergründet",
    "ergründetes": "ergründet",
    "ergründetest": "ergründen",
    "ergründetet": "ergründen",
    "ergäbe": "ergeben",
    "ergäben": "ergeben",
    "ergäbest": "ergeben",
    "ergäbet": "ergeben",
    "ergänze": "ergänzen",
    "ergänzend": "ergänzen",
    "ergänzende": "ergänzend",
    "ergänzendem": "ergänzend",
    "ergänzenden": "ergänzend",
    "ergänzender": "ergänzend",
    "ergänzendes": "ergänzend",
    "ergänzest": "ergänzen",
    "ergänzet": "ergänzen",
    "ergänzt": "ergänzen",
    "ergänzte": "ergänzen",
    "ergänztem": "ergänzt",
    "ergänzten": "ergänzen",
    "ergänzter": "ergänzt",
    "ergänztes": "ergänzt",
    "ergänztest": "ergänzen",
    "ergänztet": "ergänzen",
    "ergösse": "ergießen",
    "ergössen": "ergießen",
    "ergössest": "ergießen",
    "ergösset": "ergießen",
    "erhalle": "erhallen",
    "erhallend": "erhallen",
    "erhallende": "erhallend",
    "erhallendem": "erhallend",
    "erhallenden": "erhallend",
    "erhallender": "erhallend",
    "erhallendere": "erhallend",
    "erhallenderem": "erhallend",
    "erhallenderen": "erhallend",
    "erhallenderer": "erhallend",
    "erhallenderes": "erhallend",
    "erhallendes": "erhallend",
    "erhallendste": "erhallend",
    "erhallendstem": "erhallend",
    "erhallendsten": "erhallend",
    "erhallendster": "erhallend",
    "erhallendstes": "erhallend",
    "erhallest": "erhallen",
    "erhallet": "erhallen",
    "erhallst": "erhallen",
    "erhallt": "erhallen",
    "erhallte": "erhallen",
    "erhalltem": "erhallt",
    "erhallten": "erhallen",
    "erhallter": "erhallt",
    "erhalltere": "erhallt",
    "erhallterem": "erhallt",
    "erhallteren": "erhallt",
    "erhallterer": "erhallt",
    "erhallteres": "erhallt",
    "erhalltes": "erhallt",
    "erhalltest": "erhallen",
    "erhallteste": "erhallt",
    "erhalltestem": "erhallt",
    "erhalltesten": "erhallt",
    "erhalltester": "erhallt",
    "erhalltestes": "erhallt",
    "erhalltet": "erhallen",
    "erhalte": "erhalten",
    "erhaltend": "erhalten",
    "erhaltende": "erhaltend",
    "erhaltendem": "erhaltend",
    "erhaltenden": "erhaltend",
    "erhaltender": "erhaltend",
    "erhaltendes": "erhaltend",
    "erhaltene": "erhalten",
    "erhaltenem": "erhalten",
    "erhaltenen": "erhalten",
    "erhaltener": "erhalten",
    "erhaltenere": "erhalten",
    "erhaltenerem": "erhalten",
    "erhalteneren": "erhalten",
    "erhaltenerer": "erhalten",
    "erhalteneres": "erhalten",
    "erhaltenes": "erhalten",
    "erhaltenstem": "erhalten",
    "erhaltensten": "erhalten",
    "erhaltenster": "erhalten",
    "erhaltenstes": "erhalten",
    "erhaltest": "erhalten",
    "erhaltet": "erhalten",
    "erhasche": "erhaschen",
    "erhaschend": "erhaschen",
    "erhaschende": "erhaschend",
    "erhaschendem": "erhaschend",
    "erhaschenden": "erhaschend",
    "erhaschender": "erhaschend",
    "erhaschendes": "erhaschend",
    "erhaschest": "erhaschen",
    "erhaschet": "erhaschen",
    "erhaschst": "erhaschen",
    "erhascht": "erhaschen",
    "erhaschte": "erhaschen",
    "erhaschtem": "erhascht",
    "erhaschten": "erhaschen",
    "erhaschter": "erhascht",
    "erhaschtes": "erhascht",
    "erhaschtest": "erhaschen",
    "erhaschtet": "erhaschen",
    "erhebe": "erheben",
    "erhebend": "erheben",
    "erhebende": "erhebend",
    "erhebendem": "erhebend",
    "erhebenden": "erhebend",
    "erhebender": "erhebend",
    "erhebendes": "erhebend",
    "erhebest": "erheben",
    "erhebet": "erheben",
    "erhebliche": "erheblich",
    "erheblichem": "erheblich",
    "erheblichen": "erheblich",
    "erheblicher": "erheblich",
    "erheblichere": "erheblich",
    "erheblicherem": "erheblich",
    "erheblicheren": "erheblich",
    "erheblicherer": "erheblich",
    "erheblicheres": "erheblich",
    "erhebliches": "erheblich",
    "erheblichste": "erheblich",
    "erheblichstem": "erheblich",
    "erheblichsten": "erheblich",
    "erheblichster": "erheblich",
    "erheblichstes": "erheblich",
    "erhebst": "erheben",
    "erhebt": "erheben",
    "erheitere": "erheitern",
    "erheiternd": "erheitern",
    "erheiternde": "erheiternd",
    "erheiterndem": "erheiternd",
    "erheiternden": "erheiternd",
    "erheiternder": "erheiternd",
    "erheiterndere": "erheiternd",
    "erheiternderem": "erheiternd",
    "erheiternderen": "erheiternd",
    "erheiternderer": "erheiternd",
    "erheiternderes": "erheiternd",
    "erheiterndes": "erheiternd",
    "erheiterndste": "erheiternd",
    "erheiterndstem": "erheiternd",
    "erheiterndsten": "erheiternd",
    "erheiterndster": "erheiternd",
    "erheiterndstes": "erheiternd",
    "erheiterst": "erheitern",
    "erheitert": "erheitern",
    "erheiterte": "erheitern",
    "erheitertem": "erheitert",
    "erheiterten": "erheitern",
    "erheiterter": "erheitert",
    "erheitertere": "erheitert",
    "erheiterterem": "erheitert",
    "erheiterteren": "erheitert",
    "erheiterterer": "erheitert",
    "erheiterteres": "erheitert",
    "erheitertes": "erheitert",
    "erheitertest": "erheitern",
    "erheiterteste": "erheitert",
    "erheitertestem": "erheitert",
    "erheitertesten": "erheitert",
    "erheitertester": "erheitert",
    "erheitertestes": "erheitert",
    "erheitertet": "erheitern",
    "erhelle": "erhellen",
    "erhellend": "erhellen",
    "erhellende": "erhellend",
    "erhellendem": "erhellend",
    "erhellenden": "erhellend",
    "erhellender": "erhellend",
    "erhellendere": "erhellend",
    "erhellenderem": "erhellend",
    "erhellenderen": "erhellend",
    "erhellenderer": "erhellend",
    "erhellenderes": "erhellend",
    "erhellendes": "erhellend",
    "erhellendste": "erhellend",
    "erhellendstem": "erhellend",
    "erhellendsten": "erhellend",
    "erhellendster": "erhellend",
    "erhellendstes": "erhellend",
    "erhellest": "erhellen",
    "erhellet": "erhellen",
    "erhellst": "erhellen",
    "erhellt": "erhellen",
    "erhellte": "erhellen",
    "erhelltem": "erhellt",
    "erhellten": "erhellen",
    "erhellter": "erhellt",
    "erhelltere": "erhellt",
    "erhellterem": "erhellt",
    "erhellteren": "erhellt",
    "erhellterer": "erhellt",
    "erhellteres": "erhellt",
    "erhelltes": "erhellt",
    "erhelltest": "erhellen",
    "erhellteste": "erhellt",
    "erhelltestem": "erhellt",
    "erhelltesten": "erhellt",
    "erhelltester": "erhellt",
    "erhelltestes": "erhellt",
    "erhelltet": "erhellen",
    "erhielt": "erhalten",
    "erhielte": "erhalten",
    "erhielten": "erhalten",
    "erhieltest": "erhalten",
    "erhieltet": "erhalten",
    "erhitze": "erhitzen",
    "erhitzend": "erhitzen",
    "erhitzende": "erhitzend",
    "erhitzendem": "erhitzend",
    "erhitzenden": "erhitzend",
    "erhitzender": "erhitzend",
    "erhitzendere": "erhitzend",
    "erhitzenderem": "erhitzend",
    "erhitzenderen": "erhitzend",
    "erhitzenderer": "erhitzend",
    "erhitzenderes": "erhitzend",
    "erhitzendes": "erhitzend",
    "erhitzendste": "erhitzend",
    "erhitzendstem": "erhitzend",
    "erhitzendsten": "erhitzend",
    "erhitzendster": "erhitzend",
    "erhitzendstes": "erhitzend",
    "erhitzest": "erhitzen",
    "erhitzet": "erhitzen",
    "erhitzt": "erhitzen",
    "erhitzte": "erhitzen",
    "erhitztem": "erhitzt",
    "erhitzten": "erhitzen",
    "erhitzter": "erhitzt",
    "erhitztere": "erhitzt",
    "erhitzterem": "erhitzt",
    "erhitzteren": "erhitzt",
    "erhitzterer": "erhitzt",
    "erhitzteres": "erhitzt",
    "erhitztes": "erhitzt",
    "erhitztest": "erhitzen",
    "erhitzteste": "erhitzt",
    "erhitztestem": "erhitzt",
    "erhitztesten": "erhitzt",
    "erhitztester": "erhitzt",
    "erhitztestes": "erhitzt",
    "erhitztet": "erhitzen",
    "erhob": "erheben",
    "erhoben": "erheben",
    "erhobene": "erhoben",
    "erhobenem": "erhoben",
    "erhobenen": "erhoben",
    "erhobener": "erhoben",
    "erhobenere": "erhoben",
    "erhobenerem": "erhoben",
    "erhobeneren": "erhoben",
    "erhobenerer": "erhoben",
    "erhobeneres": "erhoben",
    "erhobenes": "erhoben",
    "erhobenste": "erhoben",
    "erhobenstem": "erhoben",
    "erhobensten": "erhoben",
    "erhobenster": "erhoben",
    "erhobenstes": "erhoben",
    "erhobst": "erheben",
    "erhobt": "erheben",
    "erhoffe": "erhoffen",
    "erhoffend": "erhoffen",
    "erhoffende": "erhoffend",
    "erhoffendem": "erhoffend",
    "erhoffenden": "erhoffend",
    "erhoffender": "erhoffend",
    "erhoffendes": "erhoffend",
    "erhoffest": "erhoffen",
    "erhoffet": "erhoffen",
    "erhoffst": "erhoffen",
    "erhofft": "erhoffen",
    "erhoffte": "erhoffen",
    "erhofftem": "erhofft",
    "erhofften": "erhoffen",
    "erhoffter": "erhofft",
    "erhofftes": "erhofft",
    "erhofftest": "erhoffen",
    "erhofftet": "erhoffen",
    "erhole": "erholen",
    "erholend": "erholen",
    "erholende": "erholend",
    "erholendem": "erholend",
    "erholenden": "erholend",
    "erholender": "erholend",
    "erholendes": "erholend",
    "erholest": "erholen",
    "erholet": "erholen",
    "erholsame": "erholsam",
    "erholsamem": "erholsam",
    "erholsamen": "erholsam",
    "erholsamer": "erholsam",
    "erholsamere": "erholsam",
    "erholsamerem": "erholsam",
    "erholsameren": "erholsam",
    "erholsamerer": "erholsam",
    "erholsameres": "erholsam",
    "erholsames": "erholsam",
    "erholsamste": "erholsam",
    "erholsamstem": "erholsam",
    "erholsamsten": "erholsam",
    "erholsamster": "erholsam",
    "erholsamstes": "erholsam",
    "erholst": "erholen",
    "erholt": "erholen",
    "erholte": "erholen",
    "erholtem": "erholt",
    "erholten": "erholen",
    "erholter": "erholt",
    "erholtere": "erholt",
    "erholterem": "erholt",
    "erholteren": "erholt",
    "erholterer": "erholt",
    "erholteres": "erholt",
    "erholtes": "erholt",
    "erholtest": "erholen",
    "erholteste": "erholt",
    "erholtestem": "erholt",
    "erholtesten": "erholt",
    "erholtester": "erholt",
    "erholtestes": "erholt",
    "erholtet": "erholen",
    "erholungsbedürftige": "erholungsbedürftig",
    "erholungsbedürftigem": "erholungsbedürftig",
    "erholungsbedürftigen": "erholungsbedürftig",
    "erholungsbedürftiger": "erholungsbedürftig",
    "erholungsbedürftigere": "erholungsbedürftig",
    "erholungsbedürftigerem": "erholungsbedürftig",
    "erholungsbedürftigeren": "erholungsbedürftig",
    "erholungsbedürftigerer": "erholungsbedürftig",
    "erholungsbedürftigeres": "erholungsbedürftig",
    "erholungsbedürftiges": "erholungsbedürftig",
    "erholungsbedürftigste": "erholungsbedürftig",
    "erholungsbedürftigstem": "erholungsbedürftig",
    "erholungsbedürftigsten": "erholungsbedürftig",
    "erholungsbedürftigster": "erholungsbedürftig",
    "erholungsbedürftigstes": "erholungsbedürftig",
    "erhält": "erhalten",
    "erhältliche": "erhältlich",
    "erhältlichem": "erhältlich",
    "erhältlichen": "erhältlich",
    "erhältlicher": "erhältlich",
    "erhältliches": "erhältlich",
    "erhältst": "erhalten",
    "erhänge": "erhängen",
    "erhängend": "erhängen",
    "erhängende": "erhängend",
    "erhängendem": "erhängend",
    "erhängenden": "erhängend",
    "erhängender": "erhängend",
    "erhängendes": "erhängend",
    "erhängest": "erhängen",
    "erhänget": "erhängen",
    "erhängst": "erhängen",
    "erhängt": "erhängen",
    "erhängte": "erhängen",
    "erhängtem": "erhängt",
    "erhängten": "erhängen",
    "erhängter": "erhängt",
    "erhängtes": "erhängt",
    "erhängtest": "erhängen",
    "erhängtet": "erhängen",
    "erhärte": "erhärten",
    "erhärtend": "erhärten",
    "erhärtende": "erhärtend",
    "erhärtendem": "erhärtend",
    "erhärtenden": "erhärtend",
    "erhärtender": "erhärtend",
    "erhärtendere": "erhärtend",
    "erhärtenderem": "erhärtend",
    "erhärtenderen": "erhärtend",
    "erhärtenderer": "erhärtend",
    "erhärtenderes": "erhärtend",
    "erhärtendes": "erhärtend",
    "erhärtendste": "erhärtend",
    "erhärtendstem": "erhärtend",
    "erhärtendsten": "erhärtend",
    "erhärtendster": "erhärtend",
    "erhärtendstes": "erhärtend",
    "erhärtest": "erhärten",
    "erhärtet": "erhärten",
    "erhärtete": "erhärten",
    "erhärtetem": "erhärtet",
    "erhärteten": "erhärten",
    "erhärteter": "erhärtet",
    "erhärtetere": "erhärtet",
    "erhärteterem": "erhärtet",
    "erhärteteren": "erhärtet",
    "erhärteterer": "erhärtet",
    "erhärteteres": "erhärtet",
    "erhärtetes": "erhärtet",
    "erhärtetest": "erhärten",
    "erhärteteste": "erhärtet",
    "erhärtetestem": "erhärtet",
    "erhärtetesten": "erhärtet",
    "erhärtetester": "erhärtet",
    "erhärtetestes": "erhärtet",
    "erhärtetet": "erhärten",
    "erhöbe": "erheben",
    "erhöben": "erheben",
    "erhöbest": "erheben",
    "erhöbet": "erheben",
    "erhöhe": "erhöhen",
    "erhöhend": "erhöhen",
    "erhöhende": "erhöhend",
    "erhöhendem": "erhöhend",
    "erhöhenden": "erhöhend",
    "erhöhender": "erhöhend",
    "erhöhendes": "erhöhend",
    "erhöhest": "erhöhen",
    "erhöhet": "erhöhen",
    "erhöhst": "erhöhen",
    "erhöht": "erhöhen",
    "erhöhte": "erhöhen",
    "erhöhtem": "erhöht",
    "erhöhten": "erhöhen",
    "erhöhter": "erhöht",
    "erhöhtes": "erhöht",
    "erhöhtest": "erhöhen",
    "erhöhtet": "erhöhen",
    "erhöre": "erhören",
    "erhörend": "erhören",
    "erhörende": "erhörend",
    "erhörendem": "erhörend",
    "erhörenden": "erhörend",
    "erhörender": "erhörend",
    "erhörendes": "erhörend",
    "erhörest": "erhören",
    "erhöret": "erhören",
    "erhörst": "erhören",
    "erhört": "erhören",
    "erhörte": "erhören",
    "erhörtem": "erhört",
    "erhörten": "erhören",
    "erhörter": "erhört",
    "erhörtes": "erhört",
    "erhörtest": "erhören",
    "erhörtet": "erhören",
    "erinnere": "erinnern",
    "erinnernd": "erinnern",
    "erinnernde": "erinnernd",
    "erinnerndem": "erinnernd",
    "erinnernden": "erinnernd",
    "erinnernder": "erinnernd",
    "erinnerndes": "erinnernd",
    "erinnerst": "erinnern",
    "erinnert": "erinnern",
    "erinnerte": "erinnern",
    "erinnertem": "erinnert",
    "erinnerten": "erinnern",
    "erinnerter": "erinnert",
    "erinnertes": "erinnert",
    "erinnertest": "erinnern",
    "erinnertet": "erinnern",
    "erkalte": "erkalten",
    "erkaltend": "erkalten",
    "erkaltende": "erkaltend",
    "erkaltendem": "erkaltend",
    "erkaltenden": "erkaltend",
    "erkaltender": "erkaltend",
    "erkaltendere": "erkaltend",
    "erkaltenderem": "erkaltend",
    "erkaltenderen": "erkaltend",
    "erkaltenderer": "erkaltend",
    "erkaltenderes": "erkaltend",
    "erkaltendes": "erkaltend",
    "erkaltendste": "erkaltend",
    "erkaltendstem": "erkaltend",
    "erkaltendsten": "erkaltend",
    "erkaltendster": "erkaltend",
    "erkaltendstes": "erkaltend",
    "erkaltest": "erkalten",
    "erkaltet": "erkalten",
    "erkaltete": "erkalten",
    "erkaltetem": "erkaltet",
    "erkalteten": "erkalten",
    "erkalteter": "erkaltet",
    "erkaltetere": "erkaltet",
    "erkalteterem": "erkaltet",
    "erkalteteren": "erkaltet",
    "erkalteterer": "erkaltet",
    "erkalteteres": "erkaltet",
    "erkaltetes": "erkaltet",
    "erkaltetest": "erkalten",
    "erkalteteste": "erkaltet",
    "erkaltetestem": "erkaltet",
    "erkaltetesten": "erkaltet",
    "erkaltetester": "erkaltet",
    "erkaltetestes": "erkaltet",
    "erkaltetet": "erkalten",
    "erkannt": "erkennen",
    "erkannte": "erkannt",
    "erkanntem": "erkannt",
    "erkannten": "erkannt",
    "erkannter": "erkannt",
    "erkanntes": "erkannt",
    "erkanntest": "erkennen",
    "erkanntet": "erkennen",
    "erkaufe": "erkaufen",
    "erkaufend": "erkaufen",
    "erkaufest": "erkaufen",
    "erkaufet": "erkaufen",
    "erkaufst": "erkaufen",
    "erkauft": "erkaufen",
    "erkaufte": "erkaufen",
    "erkauften": "erkaufen",
    "erkauftest": "erkaufen",
    "erkauftet": "erkaufen",
    "erkennbare": "erkennbar",
    "erkennbarem": "erkennbar",
    "erkennbaren": "erkennbar",
    "erkennbarer": "erkennbar",
    "erkennbarere": "erkennbar",
    "erkennbarerem": "erkennbar",
    "erkennbareren": "erkennbar",
    "erkennbarerer": "erkennbar",
    "erkennbareres": "erkennbar",
    "erkennbares": "erkennbar",
    "erkennbarste": "erkennbar",
    "erkennbarstem": "erkennbar",
    "erkennbarsten": "erkennbar",
    "erkennbarster": "erkennbar",
    "erkennbarstes": "erkennbar",
    "erkenne": "erkennen",
    "erkennend": "erkennen",
    "erkennende": "erkennend",
    "erkennendem": "erkennend",
    "erkennenden": "erkennend",
    "erkennender": "erkennend",
    "erkennendes": "erkennend",
    "erkennest": "erkennen",
    "erkennet": "erkennen",
    "erkennst": "erkennen",
    "erkennt": "erkennen",
    "erkiese": "erkiesen",
    "erkiesend": "erkiesen",
    "erkiesende": "erkiesend",
    "erkiesendem": "erkiesend",
    "erkiesenden": "erkiesend",
    "erkiesender": "erkiesend",
    "erkiesendes": "erkiesend",
    "erkiesest": "erkiesen",
    "erkieset": "erkiesen",
    "erkiest": "erkiesen",
    "erklang": "erklingen",
    "erklangen": "erklingen",
    "erklangst": "erklingen",
    "erklangt": "erklingen",
    "erklimme": "erklimmen",
    "erklimmend": "erklimmen",
    "erklimmende": "erklimmend",
    "erklimmendem": "erklimmend",
    "erklimmenden": "erklimmend",
    "erklimmender": "erklimmend",
    "erklimmendere": "erklimmend",
    "erklimmenderem": "erklimmend",
    "erklimmenderen": "erklimmend",
    "erklimmenderer": "erklimmend",
    "erklimmenderes": "erklimmend",
    "erklimmendes": "erklimmend",
    "erklimmendste": "erklimmend",
    "erklimmendstem": "erklimmend",
    "erklimmendsten": "erklimmend",
    "erklimmendster": "erklimmend",
    "erklimmendstes": "erklimmend",
    "erklimmest": "erklimmen",
    "erklimmet": "erklimmen",
    "erklimmst": "erklimmen",
    "erklimmt": "erklimmen",
    "erklinge": "erklingen",
    "erklingend": "erklingen",
    "erklingende": "erklingend",
    "erklingendem": "erklingend",
    "erklingenden": "erklingend",
    "erklingender": "erklingend",
    "erklingendes": "erklingend",
    "erklingest": "erklingen",
    "erklinget": "erklingen",
    "erklingst": "erklingen",
    "erklingt": "erklingen",
    "erklomm": "erklimmen",
    "erklommen": "erklimmen",
    "erklommene": "erklommen",
    "erklommenem": "erklommen",
    "erklommenen": "erklommen",
    "erklommener": "erklommen",
    "erklommenere": "erklommen",
    "erklommenerem": "erklommen",
    "erklommeneren": "erklommen",
    "erklommenerer": "erklommen",
    "erklommeneres": "erklommen",
    "erklommenes": "erklommen",
    "erklommenste": "erklommen",
    "erklommenstem": "erklommen",
    "erklommensten": "erklommen",
    "erklommenster": "erklommen",
    "erklommenstes": "erklommen",
    "erklommst": "erklimmen",
    "erklommt": "erklimmen",
    "erklungen": "erklingen",
    "erklungene": "erklungen",
    "erklungenem": "erklungen",
    "erklungenen": "erklungen",
    "erklungener": "erklungen",
    "erklungenes": "erklungen",
    "erklänge": "erklingen",
    "erklängen": "erklingen",
    "erklängest": "erklingen",
    "erklänget": "erklingen",
    "erklärbare": "erklärbar",
    "erklärbarem": "erklärbar",
    "erklärbaren": "erklärbar",
    "erklärbarer": "erklärbar",
    "erklärbares": "erklärbar",
    "erkläre": "erklären",
    "erklärend": "erklären",
    "erklärende": "erklärend",
    "erklärendem": "erklärend",
    "erklärenden": "erklärend",
    "erklärender": "erklärend",
    "erklärendes": "erklärend",
    "erklärest": "erklären",
    "erkläret": "erklären",
    "erklärliche": "erklärlich",
    "erklärlichem": "erklärlich",
    "erklärlichen": "erklärlich",
    "erklärlicher": "erklärlich",
    "erklärliches": "erklärlich",
    "erklärst": "erklären",
    "erklärt": "erklären",
    "erklärte": "erklären",
    "erklärtem": "erklärt",
    "erklärten": "erklären",
    "erklärter": "erklärt",
    "erklärtes": "erklärt",
    "erklärtest": "erklären",
    "erklärtet": "erklären",
    "erklömme": "erklimmen",
    "erklömmen": "erklimmen",
    "erklömmest": "erklimmen",
    "erklömmet": "erklimmen",
    "erkor": "erkiesen",
    "erkoren": "erkiesen",
    "erkorene": "erkoren",
    "erkorenem": "erkoren",
    "erkorenen": "erkoren",
    "erkorener": "erkoren",
    "erkorenere": "erkoren",
    "erkorenerem": "erkoren",
    "erkoreneren": "erkoren",
    "erkorenerer": "erkoren",
    "erkoreneres": "erkoren",
    "erkorenes": "erkoren",
    "erkorenste": "erkoren",
    "erkorenstem": "erkoren",
    "erkorensten": "erkoren",
    "erkorenster": "erkoren",
    "erkorenstes": "erkoren",
    "erkorst": "erkiesen",
    "erkort": "erkiesen",
    "erkranke": "erkranken",
    "erkrankend": "erkranken",
    "erkrankende": "erkrankend",
    "erkrankendem": "erkrankend",
    "erkrankenden": "erkrankend",
    "erkrankender": "erkrankend",
    "erkrankendere": "erkrankend",
    "erkrankenderem": "erkrankend",
    "erkrankenderen": "erkrankend",
    "erkrankenderer": "erkrankend",
    "erkrankenderes": "erkrankend",
    "erkrankendes": "erkrankend",
    "erkrankendste": "erkrankend",
    "erkrankendstem": "erkrankend",
    "erkrankendsten": "erkrankend",
    "erkrankendster": "erkrankend",
    "erkrankendstes": "erkrankend",
    "erkrankest": "erkranken",
    "erkranket": "erkranken",
    "erkrankst": "erkranken",
    "erkrankt": "erkranken",
    "erkrankte": "erkranken",
    "erkranktem": "erkrankt",
    "erkrankten": "erkranken",
    "erkrankter": "erkrankt",
    "erkranktere": "erkrankt",
    "erkrankterem": "erkrankt",
    "erkrankteren": "erkrankt",
    "erkrankterer": "erkrankt",
    "erkrankteres": "erkrankt",
    "erkranktes": "erkrankt",
    "erkranktest": "erkranken",
    "erkrankteste": "erkrankt",
    "erkranktestem": "erkrankt",
    "erkranktesten": "erkrankt",
    "erkranktester": "erkrankt",
    "erkranktestes": "erkrankt",
    "erkranktet": "erkranken",
    "erkunde": "erkunden",
    "erkundend": "erkunden",
    "erkundende": "erkundend",
    "erkundendem": "erkundend",
    "erkundenden": "erkundend",
    "erkundender": "erkundend",
    "erkundendes": "erkundend",
    "erkundest": "erkunden",
    "erkundet": "erkunden",
    "erkundete": "erkunden",
    "erkundetem": "erkundet",
    "erkundeten": "erkunden",
    "erkundeter": "erkundet",
    "erkundetere": "erkundet",
    "erkundeterem": "erkundet",
    "erkundeteren": "erkundet",
    "erkundeterer": "erkundet",
    "erkundeteres": "erkundet",
    "erkundetes": "erkundet",
    "erkundetest": "erkunden",
    "erkundeteste": "erkundet",
    "erkundetestem": "erkundet",
    "erkundetesten": "erkundet",
    "erkundetester": "erkundet",
    "erkundetestes": "erkundet",
    "erkundetet": "erkunden",
    "erkundige": "erkundigen",
    "erkundigend": "erkundigen",
    "erkundigende": "erkundigend",
    "erkundigendem": "erkundigend",
    "erkundigenden": "erkundigend",
    "erkundigender": "erkundigend",
    "erkundigendes": "erkundigend",
    "erkundigest": "erkundigen",
    "erkundiget": "erkundigen",
    "erkundigst": "erkundigen",
    "erkundigt": "erkundigen",
    "erkundigte": "erkundigen",
    "erkundigtem": "erkundigt",
    "erkundigten": "erkundigen",
    "erkundigter": "erkundigt",
    "erkundigtes": "erkundigt",
    "erkundigtest": "erkundigen",
    "erkundigtet": "erkundigen",
    "erkälte": "erkälten",
    "erkältend": "erkälten",
    "erkältendem": "erkältend",
    "erkältender": "erkältend",
    "erkältendes": "erkältend",
    "erkältest": "erkälten",
    "erkältet": "erkälten",
    "erkältete": "erkälten",
    "erkältetem": "erkältet",
    "erkälteten": "erkältet",
    "erkälteter": "erkältet",
    "erkältetes": "erkältet",
    "erkältetest": "erkälten",
    "erkältetet": "erkälten",
    "erkämpfe": "erkämpfen",
    "erkämpfend": "erkämpfen",
    "erkämpfende": "erkämpfend",
    "erkämpfendem": "erkämpfend",
    "erkämpfenden": "erkämpfend",
    "erkämpfender": "erkämpfend",
    "erkämpfendes": "erkämpfend",
    "erkämpfest": "erkämpfen",
    "erkämpfet": "erkämpfen",
    "erkämpfst": "erkämpfen",
    "erkämpft": "erkämpfen",
    "erkämpfte": "erkämpfen",
    "erkämpftem": "erkämpft",
    "erkämpften": "erkämpfen",
    "erkämpfter": "erkämpft",
    "erkämpftes": "erkämpft",
    "erkämpftest": "erkämpfen",
    "erkämpftet": "erkämpfen",
    "erköre": "erkiesen",
    "erkören": "erkiesen",
    "erkörest": "erkiesen",
    "erköret": "erkiesen",
    "erlag": "erliegen",
    "erlagen": "erliegen",
    "erlagst": "erliegen",
    "erlagt": "erliegen",
    "erlahme": "erlahmen",
    "erlahmend": "erlahmen",
    "erlahmende": "erlahmend",
    "erlahmendem": "erlahmend",
    "erlahmenden": "erlahmend",
    "erlahmender": "erlahmend",
    "erlahmendere": "erlahmend",
    "erlahmenderem": "erlahmend",
    "erlahmenderen": "erlahmend",
    "erlahmenderer": "erlahmend",
    "erlahmenderes": "erlahmend",
    "erlahmendes": "erlahmend",
    "erlahmendste": "erlahmend",
    "erlahmendstem": "erlahmend",
    "erlahmendsten": "erlahmend",
    "erlahmendster": "erlahmend",
    "erlahmendstes": "erlahmend",
    "erlahmest": "erlahmen",
    "erlahmet": "erlahmen",
    "erlahmst": "erlahmen",
    "erlahmt": "erlahmen",
    "erlahmte": "erlahmen",
    "erlahmtem": "erlahmt",
    "erlahmten": "erlahmen",
    "erlahmter": "erlahmt",
    "erlahmtes": "erlahmt",
    "erlahmtest": "erlahmen",
    "erlahmtet": "erlahmen",
    "erlange": "erlangen",
    "erlangend": "erlangen",
    "erlangende": "erlangend",
    "erlangendem": "erlangend",
    "erlangenden": "erlangend",
    "erlangender": "erlangend",
    "erlangendes": "erlangend",
    "erlangest": "erlangen",
    "erlanget": "erlangen",
    "erlangst": "erlangen",
    "erlangt": "erlangen",
    "erlangte": "erlangen",
    "erlangtem": "erlangt",
    "erlangten": "erlangen",
    "erlangter": "erlangt",
    "erlangtes": "erlangt",
    "erlangtest": "erlangen",
    "erlangtet": "erlangen",
    "erlasse": "erlassen",
    "erlassend": "erlassen",
    "erlassende": "erlassend",
    "erlassendem": "erlassend",
    "erlassenden": "erlassend",
    "erlassender": "erlassend",
    "erlassendes": "erlassend",
    "erlassene": "erlassen",
    "erlassenem": "erlassen",
    "erlassenen": "erlassen",
    "erlassener": "erlassen",
    "erlassenes": "erlassen",
    "erlassest": "erlassen",
    "erlasset": "erlassen",
    "erlaube": "erlauben",
    "erlaubend": "erlauben",
    "erlaubende": "erlaubend",
    "erlaubendem": "erlaubend",
    "erlaubenden": "erlaubend",
    "erlaubender": "erlaubend",
    "erlaubendes": "erlaubend",
    "erlaubest": "erlauben",
    "erlaubet": "erlauben",
    "erlaubst": "erlauben",
    "erlaubt": "erlauben",
    "erlaubte": "erlauben",
    "erlaubtem": "erlaubt",
    "erlaubten": "erlauben",
    "erlaubter": "erlaubt",
    "erlaubtes": "erlaubt",
    "erlaubtest": "erlauben",
    "erlaubtet": "erlauben",
    "erlauchte": "erlaucht",
    "erlauchtem": "erlaucht",
    "erlauchten": "erlaucht",
    "erlauchter": "erlaucht",
    "erlauchtes": "erlaucht",
    "erlaufe": "erlaufen",
    "erlaufend": "erlaufen",
    "erlaufende": "erlaufend",
    "erlaufendem": "erlaufend",
    "erlaufenden": "erlaufend",
    "erlaufender": "erlaufend",
    "erlaufendes": "erlaufend",
    "erlaufene": "erlaufen",
    "erlaufenem": "erlaufen",
    "erlaufenen": "erlaufen",
    "erlaufener": "erlaufen",
    "erlaufenes": "erlaufen",
    "erlaufest": "erlaufen",
    "erlaufet": "erlaufen",
    "erlauft": "erlaufen",
    "erlaß": "erlassen",
    "erlaßt": "erlassen",
    "erlebe": "erleben",
    "erlebend": "erleben",
    "erlebende": "erlebend",
    "erlebendem": "erlebend",
    "erlebenden": "erlebend",
    "erlebender": "erlebend",
    "erlebendes": "erlebend",
    "erlebest": "erleben",
    "erlebet": "erleben",
    "erlebst": "erleben",
    "erlebt": "erleben",
    "erlebte": "erleben",
    "erlebtem": "erlebt",
    "erlebten": "erleben",
    "erlebter": "erlebt",
    "erlebtes": "erlebt",
    "erlebtest": "erleben",
    "erlebtet": "erleben",
    "erledige": "erledigen",
    "erledigend": "erledigen",
    "erledigende": "erledigend",
    "erledigendem": "erledigend",
    "erledigenden": "erledigend",
    "erledigender": "erledigend",
    "erledigendes": "erledigend",
    "erledigest": "erledigen",
    "erlediget": "erledigen",
    "erledigst": "erledigen",
    "erledigt": "erledigen",
    "erledigte": "erledigen",
    "erledigtem": "erledigt",
    "erledigten": "erledigen",
    "erledigter": "erledigt",
    "erledigtes": "erledigt",
    "erledigtest": "erledigen",
    "erledigtet": "erledigen",
    "erlege": "erlegen",
    "erlegen": "erliegen",
    "erlegend": "erlegen",
    "erlegende": "erlegend",
    "erlegendem": "erlegend",
    "erlegenden": "erlegend",
    "erlegender": "erlegend",
    "erlegendes": "erlegend",
    "erlegene": "erlegen",
    "erlegenem": "erlegen",
    "erlegenen": "erlegen",
    "erlegener": "erlegen",
    "erlegenes": "erlegen",
    "erlegest": "erlegen",
    "erleget": "erlegen",
    "erlegst": "erlegen",
    "erlegt": "erlegen",
    "erlegte": "erlegen",
    "erlegtem": "erlegt",
    "erlegten": "erlegen",
    "erlegter": "erlegt",
    "erlegtes": "erlegt",
    "erlegtest": "erlegen",
    "erlegtet": "erlegen",
    "erleichtere": "erleichtern",
    "erleichternd": "erleichtern",
    "erleichternde": "erleichternd",
    "erleichterndem": "erleichternd",
    "erleichternden": "erleichternd",
    "erleichternder": "erleichternd",
    "erleichterndere": "erleichternd",
    "erleichternderem": "erleichternd",
    "erleichternderen": "erleichternd",
    "erleichternderer": "erleichternd",
    "erleichternderes": "erleichternd",
    "erleichterndes": "erleichternd",
    "erleichterndste": "erleichternd",
    "erleichterndstem": "erleichternd",
    "erleichterndsten": "erleichternd",
    "erleichterndster": "erleichternd",
    "erleichterndstes": "erleichternd",
    "erleichterst": "erleichtern",
    "erleichtert": "erleichtern",
    "erleichterte": "erleichtern",
    "erleichtertem": "erleichtert",
    "erleichterten": "erleichtern",
    "erleichterter": "erleichtert",
    "erleichtertere": "erleichtert",
    "erleichterterem": "erleichtert",
    "erleichterteren": "erleichtert",
    "erleichterterer": "erleichtert",
    "erleichterteres": "erleichtert",
    "erleichtertes": "erleichtert",
    "erleichtertest": "erleichtern",
    "erleichterteste": "erleichtert",
    "erleichtertestem": "erleichtert",
    "erleichtertesten": "erleichtert",
    "erleichtertester": "erleichtert",
    "erleichtertestes": "erleichtert",
    "erleichtertet": "erleichtern",
    "erleide": "erleiden",
    "erleidend": "erleiden",
    "erleidende": "erleidend",
    "erleidendem": "erleidend",
    "erleidenden": "erleidend",
    "erleidender": "erleidend",
    "erleidendes": "erleidend",
    "erleidest": "erleiden",
    "erleidet": "erleiden",
    "erlernbarem": "erlernbar",
    "erlernbaren": "erlernbar",
    "erlernbarer": "erlernbar",
    "erlernbares": "erlernbar",
    "erlerne": "erlernen",
    "erlernend": "erlernen",
    "erlernende": "erlernend",
    "erlernendem": "erlernend",
    "erlernenden": "erlernend",
    "erlernender": "erlernend",
    "erlernendes": "erlernend",
    "erlernest": "erlernen",
    "erlernet": "erlernen",
    "erlernst": "erlernen",
    "erlernt": "erlernen",
    "erlernte": "erlernen",
    "erlerntem": "erlernt",
    "erlernten": "erlernen",
    "erlernter": "erlernt",
    "erlerntes": "erlernt",
    "erlerntest": "erlernen",
    "erlerntet": "erlernen",
    "erlesene": "erlesen",
    "erlesenem": "erlesen",
    "erlesenen": "erlesen",
    "erlesener": "erlesen",
    "erlesenere": "erlesen",
    "erlesenerem": "erlesen",
    "erleseneren": "erlesen",
    "erlesenerer": "erlesen",
    "erleseneres": "erlesen",
    "erlesenes": "erlesen",
    "erlesenste": "erlesen",
    "erlesenstem": "erlesen",
    "erlesensten": "erlesen",
    "erlesenster": "erlesen",
    "erlesenstes": "erlesen",
    "erlief": "erlaufen",
    "erliefe": "erlaufen",
    "erliefen": "erlaufen",
    "erliefest": "erlaufen",
    "erliefet": "erlaufen",
    "erliefst": "erlaufen",
    "erlieft": "erlaufen",
    "erliege": "erliegen",
    "erliegend": "erliegen",
    "erliegende": "erliegend",
    "erliegendem": "erliegend",
    "erliegenden": "erliegend",
    "erliegender": "erliegend",
    "erliegendes": "erliegend",
    "erliegest": "erliegen",
    "erlieget": "erliegen",
    "erliegst": "erliegen",
    "erliegt": "erliegen",
    "erließ": "erlassen",
    "erließe": "erlassen",
    "erließen": "erlassen",
    "erließest": "erlassen",
    "erließet": "erlassen",
    "erließt": "erlassen",
    "erlisch": "erlöschen",
    "erlischst": "erlöschen",
    "erlischt": "erlöschen",
    "erlitt": "erleiden",
    "erlitte": "erleiden",
    "erlitten": "erleiden",
    "erlittene": "erlitten",
    "erlittenem": "erlitten",
    "erlittenen": "erlitten",
    "erlittener": "erlitten",
    "erlittenes": "erlitten",
    "erlittest": "erleiden",
    "erlittet": "erleiden",
    "erlosch": "erlöschen",
    "erloschen": "erlöschen",
    "erloschene": "erloschen",
    "erloschenem": "erloschen",
    "erloschenen": "erloschen",
    "erloschener": "erloschen",
    "erloschenere": "erloschen",
    "erloschenerem": "erloschen",
    "erloscheneren": "erloschen",
    "erloschenerer": "erloschen",
    "erloscheneres": "erloschen",
    "erloschenes": "erloschen",
    "erloschenstem": "erloschen",
    "erloschensten": "erloschen",
    "erloschenster": "erloschen",
    "erloschenstes": "erloschen",
    "erloschst": "erlöschen",
    "erloscht": "erlöschen",
    "erläge": "erliegen",
    "erlägen": "erliegen",
    "erlägest": "erliegen",
    "erläget": "erliegen",
    "erläufst": "erlaufen",
    "erläuft": "erlaufen",
    "erläutere": "erläutern",
    "erläuternd": "erläutern",
    "erläuternde": "erläuternd",
    "erläuterndem": "erläuternd",
    "erläuternden": "erläuternd",
    "erläuternder": "erläuternd",
    "erläuterndes": "erläuternd",
    "erläuterst": "erläutern",
    "erläutert": "erläutern",
    "erläuterte": "erläutern",
    "erläutertem": "erläutert",
    "erläuterten": "erläutern",
    "erläuterter": "erläutert",
    "erläutertere": "erläutert",
    "erläuterterem": "erläutert",
    "erläuterteren": "erläutert",
    "erläuterterer": "erläutert",
    "erläuterteres": "erläutert",
    "erläutertes": "erläutert",
    "erläutertest": "erläutern",
    "erläuterteste": "erläutert",
    "erläutertestem": "erläutert",
    "erläutertesten": "erläutert",
    "erläutertester": "erläutert",
    "erläutertestes": "erläutert",
    "erläutertet": "erläutern",
    "erläßt": "erlassen",
    "erlösche": "erlöschen",
    "erlöschend": "erlöschen",
    "erlöschende": "erlöschend",
    "erlöschendem": "erlöschend",
    "erlöschenden": "erlöschend",
    "erlöschender": "erlöschend",
    "erlöschendes": "erlöschend",
    "erlöschest": "erlöschen",
    "erlöschet": "erlöschen",
    "erlöscht": "erlöschen",
    "erlösend": "erlösen",
    "erlösende": "erlösend",
    "erlösendem": "erlösend",
    "erlösenden": "erlösend",
    "erlösender": "erlösend",
    "erlösendere": "erlösend",
    "erlösenderem": "erlösend",
    "erlösenderen": "erlösend",
    "erlösenderer": "erlösend",
    "erlösenderes": "erlösend",
    "erlösendes": "erlösend",
    "erlösendste": "erlösend",
    "erlösendstem": "erlösend",
    "erlösendsten": "erlösend",
    "erlösendster": "erlösend",
    "erlösendstes": "erlösend",
    "erlösest": "erlösen",
    "erlöset": "erlösen",
    "erlöst": "erlösen",
    "erlöste": "erlösen",
    "erlöstem": "erlöst",
    "erlösten": "erlösen",
    "erlöster": "erlöst",
    "erlöstes": "erlöst",
    "erlöstest": "erlösen",
    "erlöstet": "erlösen",
    "ermahne": "ermahnen",
    "ermahnend": "ermahnen",
    "ermahnende": "ermahnend",
    "ermahnendem": "ermahnend",
    "ermahnenden": "ermahnend",
    "ermahnender": "ermahnend",
    "ermahnendere": "ermahnend",
    "ermahnenderem": "ermahnend",
    "ermahnenderen": "ermahnend",
    "ermahnenderer": "ermahnend",
    "ermahnenderes": "ermahnend",
    "ermahnendes": "ermahnend",
    "ermahnendste": "ermahnend",
    "ermahnendstem": "ermahnend",
    "ermahnendsten": "ermahnend",
    "ermahnendster": "ermahnend",
    "ermahnendstes": "ermahnend",
    "ermahnest": "ermahnen",
    "ermahnet": "ermahnen",
    "ermahnst": "ermahnen",
    "ermahnt": "ermahnen",
    "ermahnte": "ermahnen",
    "ermahntem": "ermahnt",
    "ermahnten": "ermahnen",
    "ermahnter": "ermahnt",
    "ermahntes": "ermahnt",
    "ermahntest": "ermahnen",
    "ermahntet": "ermahnen",
    "ermatte": "ermatten",
    "ermattend": "ermatten",
    "ermattende": "ermattend",
    "ermattendem": "ermattend",
    "ermattenden": "ermattend",
    "ermattender": "ermattend",
    "ermattendere": "ermattend",
    "ermattenderem": "ermattend",
    "ermattenderen": "ermattend",
    "ermattenderer": "ermattend",
    "ermattenderes": "ermattend",
    "ermattendes": "ermattend",
    "ermattendste": "ermattend",
    "ermattendstem": "ermattend",
    "ermattendsten": "ermattend",
    "ermattendster": "ermattend",
    "ermattendstes": "ermattend",
    "ermattest": "ermatten",
    "ermattet": "ermatten",
    "ermattete": "ermatten",
    "ermattetem": "ermattet",
    "ermatteten": "ermatten",
    "ermatteter": "ermattet",
    "ermattetere": "ermattet",
    "ermatteterem": "ermattet",
    "ermatteteren": "ermattet",
    "ermatteterer": "ermattet",
    "ermatteteres": "ermattet",
    "ermattetes": "ermattet",
    "ermattetest": "ermatten",
    "ermatteteste": "ermattet",
    "ermattetestem": "ermattet",
    "ermattetesten": "ermattet",
    "ermattetester": "ermattet",
    "ermattetestes": "ermattet",
    "ermattetet": "ermatten",
    "ermittele": "ermitteln",
    "ermittelnd": "ermitteln",
    "ermittelnde": "ermittelnd",
    "ermittelndem": "ermittelnd",
    "ermittelnden": "ermittelnd",
    "ermittelnder": "ermittelnd",
    "ermittelndes": "ermittelnd",
    "ermittelst": "ermitteln",
    "ermittelt": "ermitteln",
    "ermittelte": "ermitteln",
    "ermitteltem": "ermittelt",
    "ermittelten": "ermitteln",
    "ermittelter": "ermittelt",
    "ermitteltes": "ermittelt",
    "ermitteltest": "ermitteln",
    "ermitteltet": "ermitteln",
    "ermittle": "ermitteln",
    "ermorde": "ermorden",
    "ermordend": "ermorden",
    "ermordende": "ermordend",
    "ermordendem": "ermordend",
    "ermordenden": "ermordend",
    "ermordender": "ermordend",
    "ermordendes": "ermordend",
    "ermordest": "ermorden",
    "ermordet": "ermorden",
    "ermordete": "ermorden",
    "ermordetem": "ermordet",
    "ermordeten": "ermorden",
    "ermordeter": "ermordet",
    "ermordetes": "ermordet",
    "ermordetest": "ermorden",
    "ermordetet": "ermorden",
    "ermutige": "ermutigen",
    "ermutigend": "ermutigen",
    "ermutigende": "ermutigend",
    "ermutigendem": "ermutigend",
    "ermutigenden": "ermutigend",
    "ermutigender": "ermutigend",
    "ermutigendere": "ermutigend",
    "ermutigenderem": "ermutigend",
    "ermutigenderen": "ermutigend",
    "ermutigenderer": "ermutigend",
    "ermutigenderes": "ermutigend",
    "ermutigendes": "ermutigend",
    "ermutigendste": "ermutigend",
    "ermutigendstem": "ermutigend",
    "ermutigendsten": "ermutigend",
    "ermutigendster": "ermutigend",
    "ermutigendstes": "ermutigend",
    "ermutigest": "ermutigen",
    "ermutiget": "ermutigen",
    "ermutigst": "ermutigen",
    "ermutigt": "ermutigen",
    "ermutigte": "ermutigen",
    "ermutigtem": "ermutigt",
    "ermutigten": "ermutigen",
    "ermutigter": "ermutigt",
    "ermutigtere": "ermutigt",
    "ermutigterem": "ermutigt",
    "ermutigteren": "ermutigt",
    "ermutigterer": "ermutigt",
    "ermutigteres": "ermutigt",
    "ermutigtes": "ermutigt",
    "ermutigtest": "ermutigen",
    "ermutigteste": "ermutigt",
    "ermutigtestem": "ermutigt",
    "ermutigtesten": "ermutigt",
    "ermutigtester": "ermutigt",
    "ermutigtestes": "ermutigt",
    "ermutigtet": "ermutigen",
    "ermächtige": "ermächtigen",
    "ermächtigend": "ermächtigen",
    "ermächtigende": "ermächtigend",
    "ermächtigendem": "ermächtigend",
    "ermächtigenden": "ermächtigend",
    "ermächtigender": "ermächtigend",
    "ermächtigendes": "ermächtigend",
    "ermächtigest": "ermächtigen",
    "ermächtiget": "ermächtigen",
    "ermächtigst": "ermächtigen",
    "ermächtigt": "ermächtigen",
    "ermächtigte": "ermächtigen",
    "ermächtigtem": "ermächtigt",
    "ermächtigten": "ermächtigen",
    "ermächtigter": "ermächtigt",
    "ermächtigtes": "ermächtigt",
    "ermächtigtest": "ermächtigen",
    "ermächtigtet": "ermächtigen",
    "ermögliche": "ermöglichen",
    "ermöglichend": "ermöglichen",
    "ermöglichende": "ermöglichend",
    "ermöglichendem": "ermöglichend",
    "ermöglichenden": "ermöglichend",
    "ermöglichender": "ermöglichend",
    "ermöglichendes": "ermöglichend",
    "ermöglichest": "ermöglichen",
    "ermöglichet": "ermöglichen",
    "ermöglichst": "ermöglichen",
    "ermöglicht": "ermöglichen",
    "ermöglichte": "ermöglichen",
    "ermöglichtem": "ermöglicht",
    "ermöglichten": "ermöglichen",
    "ermöglichter": "ermöglicht",
    "ermöglichtes": "ermöglicht",
    "ermöglichtest": "ermöglichen",
    "ermöglichtet": "ermöglichen",
    "ermüde": "ermüden",
    "ermüdend": "ermüden",
    "ermüdende": "ermüdend",
    "ermüdendem": "ermüdend",
    "ermüdenden": "ermüdend",
    "ermüdender": "ermüdend",
    "ermüdendere": "ermüdend",
    "ermüdenderem": "ermüdend",
    "ermüdenderen": "ermüdend",
    "ermüdenderer": "ermüdend",
    "ermüdenderes": "ermüdend",
    "ermüdendes": "ermüdend",
    "ermüdendste": "ermüdend",
    "ermüdendstem": "ermüdend",
    "ermüdendsten": "ermüdend",
    "ermüdendster": "ermüdend",
    "ermüdendstes": "ermüdend",
    "ermüdest": "ermüden",
    "ermüdet": "ermüden",
    "ermüdete": "ermüden",
    "ermüdetem": "ermüdet",
    "ermüdeten": "ermüden",
    "ermüdeter": "ermüdet",
    "ermüdetes": "ermüdet",
    "ermüdetest": "ermüden",
    "ermüdetet": "ermüden",
    "ernannt": "ernennen",
    "ernannte": "ernannt",
    "ernanntem": "ernannt",
    "ernannten": "ernannt",
    "ernannter": "ernannt",
    "ernanntes": "ernannt",
    "ernanntest": "ernennen",
    "ernanntet": "ernennen",
    "ernenne": "ernennen",
    "ernennend": "ernennen",
    "ernennende": "ernennend",
    "ernennendem": "ernennend",
    "ernennenden": "ernennend",
    "ernennender": "ernennend",
    "ernennendes": "ernennend",
    "ernennest": "ernennen",
    "ernennet": "ernennen",
    "ernennst": "ernennen",
    "ernennt": "ernennen",
    "erneuere": "erneuern",
    "erneuernd": "erneuern",
    "erneuernde": "erneuernd",
    "erneuerndem": "erneuernd",
    "erneuernden": "erneuernd",
    "erneuernder": "erneuernd",
    "erneuerndes": "erneuernd",
    "erneuerst": "erneuern",
    "erneuert": "erneuern",
    "erneuerte": "erneuern",
    "erneuertem": "erneuert",
    "erneuerten": "erneuern",
    "erneuerter": "erneuert",
    "erneuertere": "erneuert",
    "erneuerterem": "erneuert",
    "erneuerteren": "erneuert",
    "erneuerterer": "erneuert",
    "erneuerteres": "erneuert",
    "erneuertes": "erneuert",
    "erneuertest": "erneuern",
    "erneuerteste": "erneuert",
    "erneuertestem": "erneuert",
    "erneuertesten": "erneuert",
    "erneuertester": "erneuert",
    "erneuertestes": "erneuert",
    "erneuertet": "erneuern",
    "erneutem": "erneut",
    "erneuten": "erneut",
    "erneuter": "erneut",
    "erneutes": "erneut",
    "erniedrige": "erniedrigen",
    "erniedrigend": "erniedrigen",
    "erniedrigende": "erniedrigend",
    "erniedrigendem": "erniedrigend",
    "erniedrigenden": "erniedrigend",
    "erniedrigender": "erniedrigend",
    "erniedrigendere": "erniedrigend",
    "erniedrigenderem": "erniedrigend",
    "erniedrigenderen": "erniedrigend",
    "erniedrigenderer": "erniedrigend",
    "erniedrigenderes": "erniedrigend",
    "erniedrigendes": "erniedrigend",
    "erniedrigendste": "erniedrigend",
    "erniedrigendstem": "erniedrigend",
    "erniedrigendsten": "erniedrigend",
    "erniedrigendster": "erniedrigend",
    "erniedrigendstes": "erniedrigend",
    "erniedrigest": "erniedrigen",
    "erniedriget": "erniedrigen",
    "erniedrigst": "erniedrigen",
    "erniedrigt": "erniedrigen",
    "erniedrigte": "erniedrigen",
    "erniedrigtem": "erniedrigt",
    "erniedrigten": "erniedrigen",
    "erniedrigter": "erniedrigt",
    "erniedrigtere": "erniedrigt",
    "erniedrigterem": "erniedrigt",
    "erniedrigteren": "erniedrigt",
    "erniedrigterer": "erniedrigt",
    "erniedrigteres": "erniedrigt",
    "erniedrigtes": "erniedrigt",
    "erniedrigtest": "erniedrigen",
    "erniedrigteste": "erniedrigt",
    "erniedrigtestem": "erniedrigt",
    "erniedrigtesten": "erniedrigt",
    "erniedrigtester": "erniedrigt",
    "erniedrigtestes": "erniedrigt",
    "erniedrigtet": "erniedrigen",
    "ernste": "ernst",
    "ernstem": "ernst",
    "ernsten": "ernst",
    "ernster": "ernst",
    "ernstere": "ernst",
    "ernsterem": "ernst",
    "ernsteren": "ernst",
    "ernsterer": "ernst",
    "ernsteres": "ernst",
    "ernstes": "ernst",
    "ernstestem": "ernst",
    "ernstesten": "ernst",
    "ernstester": "ernst",
    "ernstestes": "ernst",
    "ernstgemeinte": "ernstgemeint",
    "ernstgemeintem": "ernstgemeint",
    "ernstgemeinten": "ernstgemeint",
    "ernstgemeinter": "ernstgemeint",
    "ernstgemeintes": "ernstgemeint",
    "ernsthafte": "ernsthaft",
    "ernsthaftem": "ernsthaft",
    "ernsthaften": "ernsthaft",
    "ernsthafter": "ernsthaft",
    "ernsthaftere": "ernsthaft",
    "ernsthafterem": "ernsthaft",
    "ernsthafteren": "ernsthaft",
    "ernsthafterer": "ernsthaft",
    "ernsthafteres": "ernsthaft",
    "ernsthaftes": "ernsthaft",
    "ernsthafteste": "ernsthaft",
    "ernsthaftestem": "ernsthaft",
    "ernsthaftesten": "ernsthaft",
    "ernsthaftester": "ernsthaft",
    "ernsthaftestes": "ernsthaft",
    "ernstliche": "ernstlich",
    "ernstlichem": "ernstlich",
    "ernstlichen": "ernstlich",
    "ernstlicher": "ernstlich",
    "ernstlichere": "ernstlich",
    "ernstlicherem": "ernstlich",
    "ernstlicheren": "ernstlich",
    "ernstlicherer": "ernstlich",
    "ernstlicheres": "ernstlich",
    "ernstliches": "ernstlich",
    "ernstlichste": "ernstlich",
    "ernstlichstem": "ernstlich",
    "ernstlichsten": "ernstlich",
    "ernstlichster": "ernstlich",
    "ernstlichstes": "ernstlich",
    "erntend": "ernten",
    "erntende": "erntend",
    "erntendem": "erntend",
    "erntenden": "erntend",
    "erntender": "erntend",
    "erntendes": "erntend",
    "erntest": "ernten",
    "erntet": "ernten",
    "erntete": "ernten",
    "ernteten": "ernten",
    "erntetest": "ernten",
    "erntetet": "ernten",
    "ernähre": "ernähren",
    "ernährend": "ernähren",
    "ernährende": "ernährend",
    "ernährendem": "ernährend",
    "ernährenden": "ernährend",
    "ernährender": "ernährend",
    "ernährendes": "ernährend",
    "ernährest": "ernähren",
    "ernähret": "ernähren",
    "ernährst": "ernähren",
    "ernährt": "ernähren",
    "ernährte": "ernähren",
    "ernährtem": "ernährt",
    "ernährten": "ernähren",
    "ernährter": "ernährt",
    "ernährtes": "ernährt",
    "ernährtest": "ernähren",
    "ernährtet": "ernähren",
    "erobere": "erobern",
    "erobernd": "erobern",
    "erobernde": "erobernd",
    "eroberndem": "erobernd",
    "erobernden": "erobernd",
    "erobernder": "erobernd",
    "eroberndes": "erobernd",
    "eroberst": "erobern",
    "erobert": "erobern",
    "eroberte": "erobern",
    "erobertem": "erobert",
    "eroberten": "erobern",
    "eroberter": "erobert",
    "erobertes": "erobert",
    "erobertest": "erobern",
    "erobertet": "erobern",
    "erogenem": "erogen",
    "erogenen": "erogen",
    "erogener": "erogen",
    "erogenes": "erogen",
    "erotischem": "erotisch",
    "erotischen": "erotisch",
    "erotischer": "erotisch",
    "erotischere": "erotisch",
    "erotischerem": "erotisch",
    "erotischeren": "erotisch",
    "erotischerer": "erotisch",
    "erotischeres": "erotisch",
    "erotisches": "erotisch",
    "erotischste": "erotisch",
    "erotischstem": "erotisch",
    "erotischsten": "erotisch",
    "erotischster": "erotisch",
    "erotischstes": "erotisch",
    "erotisiere": "erotisieren",
    "erotisierend": "erotisieren",
    "erotisierende": "erotisierend",
    "erotisierendem": "erotisierend",
    "erotisierenden": "erotisierend",
    "erotisierender": "erotisierend",
    "erotisierendere": "erotisierend",
    "erotisierenderem": "erotisierend",
    "erotisierenderen": "erotisierend",
    "erotisierenderer": "erotisierend",
    "erotisierenderes": "erotisierend",
    "erotisierendes": "erotisierend",
    "erotisierendste": "erotisierend",
    "erotisierendstem": "erotisierend",
    "erotisierendsten": "erotisierend",
    "erotisierendster": "erotisierend",
    "erotisierendstes": "erotisierend",
    "erotisierest": "erotisieren",
    "erotisieret": "erotisieren",
    "erotisierst": "erotisieren",
    "erotisiert": "erotisieren",
    "erotisierte": "erotisieren",
    "erotisiertem": "erotisiert",
    "erotisierten": "erotisieren",
    "erotisierter": "erotisiert",
    "erotisiertere": "erotisiert",
    "erotisierterem": "erotisiert",
    "erotisierteren": "erotisiert",
    "erotisierterer": "erotisiert",
    "erotisierteres": "erotisiert",
    "erotisiertes": "erotisiert",
    "erotisiertest": "erotisieren",
    "erotisierteste": "erotisiert",
    "erotisiertestem": "erotisiert",
    "erotisiertesten": "erotisiert",
    "erotisiertester": "erotisiert",
    "erotisiertestes": "erotisiert",
    "erotisiertet": "erotisieren",
    "erpiche": "erpichen",
    "erpichend": "erpichen",
    "erpichende": "erpichend",
    "erpichendem": "erpichend",
    "erpichenden": "erpichend",
    "erpichender": "erpichend",
    "erpichendere": "erpichend",
    "erpichenderem": "erpichend",
    "erpichenderen": "erpichend",
    "erpichenderer": "erpichend",
    "erpichenderes": "erpichend",
    "erpichendes": "erpichend",
    "erpichendste": "erpichend",
    "erpichendstem": "erpichend",
    "erpichendsten": "erpichend",
    "erpichendster": "erpichend",
    "erpichendstes": "erpichend",
    "erpichest": "erpichen",
    "erpichet": "erpichen",
    "erpichst": "erpichen",
    "erpicht": "erpichen",
    "erpichte": "erpichen",
    "erpichtem": "erpicht",
    "erpichten": "erpichen",
    "erpichter": "erpicht",
    "erpichtere": "erpicht",
    "erpichterem": "erpicht",
    "erpichteren": "erpicht",
    "erpichterer": "erpicht",
    "erpichteres": "erpicht",
    "erpichtes": "erpicht",
    "erpichtest": "erpichen",
    "erpichteste": "erpicht",
    "erpichtestem": "erpicht",
    "erpichtesten": "erpicht",
    "erpichtester": "erpicht",
    "erpichtestes": "erpicht",
    "erpichtet": "erpichen",
    "erpresse": "erpressen",
    "erpressend": "erpressen",
    "erpressende": "erpressend",
    "erpressendem": "erpressend",
    "erpressenden": "erpressend",
    "erpressender": "erpressend",
    "erpressendes": "erpressend",
    "erpresserischem": "erpresserisch",
    "erpresserischen": "erpresserisch",
    "erpresserischer": "erpresserisch",
    "erpresserisches": "erpresserisch",
    "erpressest": "erpressen",
    "erpresset": "erpressen",
    "erpreßt": "erpressen",
    "erpreßte": "erpressen",
    "erpreßtem": "erpreßt",
    "erpreßten": "erpressen",
    "erpreßter": "erpreßt",
    "erpreßtes": "erpreßt",
    "erpreßtest": "erpressen",
    "erpreßtet": "erpressen",
    "erprobe": "erproben",
    "erprobend": "erproben",
    "erprobende": "erprobend",
    "erprobendem": "erprobend",
    "erprobenden": "erprobend",
    "erprobender": "erprobend",
    "erprobendes": "erprobend",
    "erprobest": "erproben",
    "erprobet": "erproben",
    "erprobst": "erproben",
    "erprobt": "erproben",
    "erprobte": "erproben",
    "erprobtem": "erprobt",
    "erprobten": "erproben",
    "erprobter": "erprobt",
    "erprobtere": "erprobt",
    "erprobterem": "erprobt",
    "erprobteren": "erprobt",
    "erprobterer": "erprobt",
    "erprobteres": "erprobt",
    "erprobtes": "erprobt",
    "erprobtest": "erproben",
    "erprobteste": "erprobt",
    "erprobtestem": "erprobt",
    "erprobtesten": "erprobt",
    "erprobtester": "erprobt",
    "erprobtestes": "erprobt",
    "erprobtet": "erproben",
    "erquicklichem": "erquicklich",
    "erquicklichen": "erquicklich",
    "erquicklicher": "erquicklich",
    "erquicklichere": "erquicklich",
    "erquicklicherem": "erquicklich",
    "erquicklicheren": "erquicklich",
    "erquicklicherer": "erquicklich",
    "erquicklicheres": "erquicklich",
    "erquickliches": "erquicklich",
    "erquicklichste": "erquicklich",
    "erquicklichstem": "erquicklich",
    "erquicklichsten": "erquicklich",
    "erquicklichster": "erquicklich",
    "erquicklichstes": "erquicklich",
    "errang": "erringen",
    "errangen": "erringen",
    "errangst": "erringen",
    "errangt": "erringen",
    "errate": "erraten",
    "erratend": "erraten",
    "erratende": "erratend",
    "erratendem": "erratend",
    "erratenden": "erratend",
    "erratender": "erratend",
    "erratendes": "erratend",
    "erratene": "erraten",
    "erratenem": "erraten",
    "erratenen": "erraten",
    "erratener": "erraten",
    "erratenes": "erraten",
    "erratest": "erraten",
    "erratet": "erraten",
    "errechne": "errechnen",
    "errechnend": "errechnen",
    "errechnende": "errechnend",
    "errechnendem": "errechnend",
    "errechnenden": "errechnend",
    "errechnender": "errechnend",
    "errechnendes": "errechnend",
    "errechnest": "errechnen",
    "errechnet": "errechnen",
    "errechnete": "errechnen",
    "errechnetem": "errechnet",
    "errechneten": "errechnen",
    "errechneter": "errechnet",
    "errechnetes": "errechnet",
    "errechnetest": "errechnen",
    "errechnetet": "errechnen",
    "erregbare": "erregbar",
    "erregbarem": "erregbar",
    "erregbaren": "erregbar",
    "erregbarer": "erregbar",
    "erregbarere": "erregbar",
    "erregbarerem": "erregbar",
    "erregbareren": "erregbar",
    "erregbarerer": "erregbar",
    "erregbareres": "erregbar",
    "erregbares": "erregbar",
    "erregbarste": "erregbar",
    "erregbarstem": "erregbar",
    "erregbarsten": "erregbar",
    "erregbarster": "erregbar",
    "erregbarstes": "erregbar",
    "errege": "erregen",
    "erregend": "erregen",
    "erregende": "erregend",
    "erregendem": "erregend",
    "erregenden": "erregend",
    "erregender": "erregend",
    "erregendere": "erregend",
    "erregenderem": "erregend",
    "erregenderen": "erregend",
    "erregenderer": "erregend",
    "erregenderes": "erregend",
    "erregendes": "erregend",
    "erregendste": "erregend",
    "erregendstem": "erregend",
    "erregendsten": "erregend",
    "erregendster": "erregend",
    "erregendstes": "erregend",
    "erregest": "erregen",
    "erreget": "erregen",
    "erregst": "erregen",
    "erregt": "erregen",
    "erregte": "erregen",
    "erregtem": "erregt",
    "erregten": "erregen",
    "erregter": "erregt",
    "erregtere": "erregt",
    "erregterem": "erregt",
    "erregteren": "erregt",
    "erregterer": "erregt",
    "erregteres": "erregt",
    "erregtes": "erregt",
    "erregtest": "erregen",
    "erregteste": "erregt",
    "erregtestem": "erregt",
    "erregtesten": "erregt",
    "erregtester": "erregt",
    "erregtestes": "erregt",
    "erregtet": "erregen",
    "erreichbarem": "erreichbar",
    "erreichbaren": "erreichbar",
    "erreichbarer": "erreichbar",
    "erreichbarere": "erreichbar",
    "erreichbarerem": "erreichbar",
    "erreichbareren": "erreichbar",
    "erreichbarerer": "erreichbar",
    "erreichbareres": "erreichbar",
    "erreichbares": "erreichbar",
    "erreichbarste": "erreichbar",
    "erreichbarstem": "erreichbar",
    "erreichbarsten": "erreichbar",
    "erreichbarster": "erreichbar",
    "erreichbarstes": "erreichbar",
    "erreiche": "erreichen",
    "erreichend": "erreichen",
    "erreichende": "erreichend",
    "erreichendem": "erreichend",
    "erreichenden": "erreichend",
    "erreichender": "erreichend",
    "erreichendes": "erreichend",
    "erreichest": "erreichen",
    "erreichet": "erreichen",
    "erreichst": "erreichen",
    "erreicht": "erreichen",
    "erreichte": "erreichen",
    "erreichtem": "erreicht",
    "erreichten": "erreichen",
    "erreichter": "erreicht",
    "erreichtes": "erreicht",
    "erreichtest": "erreichen",
    "erreichtet": "erreichen",
    "errichte": "errichten",
    "errichtend": "errichten",
    "errichtende": "errichtend",
    "errichtendem": "errichtend",
    "errichtenden": "errichtend",
    "errichtender": "errichtend",
    "errichtendes": "errichtend",
    "errichtest": "errichten",
    "errichtet": "errichten",
    "errichtete": "errichten",
    "errichtetem": "errichtet",
    "errichteten": "errichten",
    "errichteter": "errichtet",
    "errichtetes": "errichtet",
    "errichtetest": "errichten",
    "errichtetet": "errichten",
    "erriet": "erraten",
    "erriete": "erraten",
    "errieten": "erraten",
    "errietest": "erraten",
    "errietet": "erraten",
    "erringe": "erringen",
    "erringend": "erringen",
    "erringende": "erringend",
    "erringendem": "erringend",
    "erringenden": "erringend",
    "erringender": "erringend",
    "erringendes": "erringend",
    "erringest": "erringen",
    "erringet": "erringen",
    "erringst": "erringen",
    "erringt": "erringen",
    "errungen": "erringen",
    "errungene": "errungen",
    "errungenem": "errungen",
    "errungenen": "errungen",
    "errungener": "errungen",
    "errungenes": "errungen",
    "erränge": "erringen",
    "errängen": "erringen",
    "errängest": "erringen",
    "erränget": "erringen",
    "errät": "erraten",
    "errätst": "erraten",
    "erröte": "erröten",
    "errötend": "erröten",
    "errötende": "errötend",
    "errötendem": "errötend",
    "errötenden": "errötend",
    "errötender": "errötend",
    "errötendere": "errötend",
    "errötenderem": "errötend",
    "errötenderen": "errötend",
    "errötenderer": "errötend",
    "errötenderes": "errötend",
    "errötendes": "errötend",
    "errötendste": "errötend",
    "errötendstem": "errötend",
    "errötendsten": "errötend",
    "errötendster": "errötend",
    "errötendstes": "errötend",
    "errötest": "erröten",
    "errötet": "erröten",
    "errötete": "erröten",
    "errötetem": "errötet",
    "erröteten": "erröten",
    "erröteter": "errötet",
    "errötetere": "errötet",
    "erröteterem": "errötet",
    "erröteteren": "errötet",
    "erröteterer": "errötet",
    "erröteteres": "errötet",
    "errötetes": "errötet",
    "errötetest": "erröten",
    "erröteteste": "errötet",
    "errötetestem": "errötet",
    "errötetesten": "errötet",
    "errötetester": "errötet",
    "errötetestes": "errötet",
    "errötetet": "erröten",
    "ersah": "ersehen",
    "ersahen": "ersehen",
    "ersahst": "ersehen",
    "ersaht": "ersehen",
    "ersann": "ersinnen",
    "ersannen": "ersinnen",
    "ersannst": "ersinnen",
    "ersannt": "ersinnen",
    "ersatzlosem": "ersatzlos",
    "ersatzlosen": "ersatzlos",
    "ersatzloser": "ersatzlos",
    "ersatzloses": "ersatzlos",
    "ersatzpflichtigem": "ersatzpflichtig",
    "ersatzpflichtigen": "ersatzpflichtig",
    "ersatzpflichtiger": "ersatzpflichtig",
    "ersatzpflichtiges": "ersatzpflichtig",
    "ersatzweisem": "ersatzweise",
    "ersatzweisen": "ersatzweise",
    "ersatzweiser": "ersatzweise",
    "ersatzweises": "ersatzweise",
    "ersaufe": "ersaufen",
    "ersaufend": "ersaufen",
    "ersaufende": "ersaufend",
    "ersaufendem": "ersaufend",
    "ersaufenden": "ersaufend",
    "ersaufender": "ersaufend",
    "ersaufendes": "ersaufend",
    "ersaufest": "ersaufen",
    "ersaufet": "ersaufen",
    "ersauft": "ersaufen",
    "erschaffe": "erschaffen",
    "erschaffend": "erschaffen",
    "erschaffende": "erschaffend",
    "erschaffendem": "erschaffend",
    "erschaffenden": "erschaffend",
    "erschaffender": "erschaffend",
    "erschaffendes": "erschaffend",
    "erschaffene": "erschaffen",
    "erschaffenem": "erschaffen",
    "erschaffenen": "erschaffen",
    "erschaffener": "erschaffen",
    "erschaffenes": "erschaffen",
    "erschaffest": "erschaffen",
    "erschaffet": "erschaffen",
    "erschaffst": "erschaffen",
    "erschafft": "erschaffen",
    "erschaffte": "erschafft",
    "erschafftem": "erschafft",
    "erschafften": "erschafft",
    "erschaffter": "erschafft",
    "erschafftes": "erschafft",
    "erschalle": "erschallen",
    "erschallend": "erschallen",
    "erschallende": "erschallend",
    "erschallendem": "erschallend",
    "erschallenden": "erschallend",
    "erschallender": "erschallend",
    "erschallendes": "erschallend",
    "erschallest": "erschallen",
    "erschallet": "erschallen",
    "erschallst": "erschallen",
    "erschallt": "erschallen",
    "erschallte": "erschallen",
    "erschalltem": "erschallt",
    "erschallten": "erschallen",
    "erschallter": "erschallt",
    "erschalltes": "erschallt",
    "erschalltest": "erschallen",
    "erschalltet": "erschallen",
    "erscheine": "erscheinen",
    "erscheinend": "erscheinen",
    "erscheinende": "erscheinend",
    "erscheinendem": "erscheinend",
    "erscheinenden": "erscheinend",
    "erscheinender": "erscheinend",
    "erscheinendes": "erscheinend",
    "erscheinest": "erscheinen",
    "erscheinet": "erscheinen",
    "erscheinst": "erscheinen",
    "erscheint": "erscheinen",
    "erschien": "erscheinen",
    "erschiene": "erscheinen",
    "erschienen": "erscheinen",
    "erschienene": "erschienen",
    "erschienenem": "erschienen",
    "erschienenen": "erschienen",
    "erschienener": "erschienen",
    "erschienenes": "erschienen",
    "erschienest": "erscheinen",
    "erschienet": "erscheinen",
    "erschienst": "erscheinen",
    "erschient": "erscheinen",
    "erschieße": "erschießen",
    "erschießend": "erschießen",
    "erschießende": "erschießend",
    "erschießendem": "erschießend",
    "erschießenden": "erschießend",
    "erschießender": "erschießend",
    "erschießendes": "erschießend",
    "erschießest": "erschießen",
    "erschießet": "erschießen",
    "erschießt": "erschießen",
    "erschlaffe": "erschlaffen",
    "erschlaffend": "erschlaffen",
    "erschlaffende": "erschlaffend",
    "erschlaffendem": "erschlaffend",
    "erschlaffenden": "erschlaffend",
    "erschlaffender": "erschlaffend",
    "erschlaffendere": "erschlaffend",
    "erschlaffenderem": "erschlaffend",
    "erschlaffenderen": "erschlaffend",
    "erschlaffenderer": "erschlaffend",
    "erschlaffenderes": "erschlaffend",
    "erschlaffendes": "erschlaffend",
    "erschlaffendste": "erschlaffend",
    "erschlaffendstem": "erschlaffend",
    "erschlaffendsten": "erschlaffend",
    "erschlaffendster": "erschlaffend",
    "erschlaffendstes": "erschlaffend",
    "erschlaffest": "erschlaffen",
    "erschlaffet": "erschlaffen",
    "erschlaffst": "erschlaffen",
    "erschlafft": "erschlaffen",
    "erschlaffte": "erschlaffen",
    "erschlafftem": "erschlafft",
    "erschlafften": "erschlaffen",
    "erschlaffter": "erschlafft",
    "erschlafftere": "erschlafft",
    "erschlaffterem": "erschlafft",
    "erschlaffteren": "erschlafft",
    "erschlaffterer": "erschlafft",
    "erschlaffteres": "erschlafft",
    "erschlafftes": "erschlafft",
    "erschlafftest": "erschlaffen",
    "erschlaffteste": "erschlafft",
    "erschlafftestem": "erschlafft",
    "erschlafftesten": "erschlafft",
    "erschlafftester": "erschlafft",
    "erschlafftestes": "erschlafft",
    "erschlafftet": "erschlaffen",
    "erschlage": "erschlagen",
    "erschlagend": "erschlagen",
    "erschlagende": "erschlagend",
    "erschlagendem": "erschlagend",
    "erschlagenden": "erschlagend",
    "erschlagender": "erschlagend",
    "erschlagendes": "erschlagend",
    "erschlagene": "erschlagen",
    "erschlagenem": "erschlagen",
    "erschlagenen": "erschlagen",
    "erschlagener": "erschlagen",
    "erschlagenere": "erschlagen",
    "erschlagenerem": "erschlagen",
    "erschlageneren": "erschlagen",
    "erschlagenerer": "erschlagen",
    "erschlageneres": "erschlagen",
    "erschlagenes": "erschlagen",
    "erschlagenstem": "erschlagen",
    "erschlagensten": "erschlagen",
    "erschlagenster": "erschlagen",
    "erschlagenstes": "erschlagen",
    "erschlagest": "erschlagen",
    "erschlaget": "erschlagen",
    "erschlagt": "erschlagen",
    "erschleiche": "erschleichen",
    "erschleichend": "erschleichen",
    "erschleichende": "erschleichend",
    "erschleichendem": "erschleichend",
    "erschleichenden": "erschleichend",
    "erschleichender": "erschleichend",
    "erschleichendes": "erschleichend",
    "erschleichest": "erschleichen",
    "erschleichet": "erschleichen",
    "erschleichst": "erschleichen",
    "erschleicht": "erschleichen",
    "erschlich": "erschleichen",
    "erschliche": "erschleichen",
    "erschlichen": "erschleichen",
    "erschlichene": "erschlichen",
    "erschlichenem": "erschlichen",
    "erschlichenen": "erschlichen",
    "erschlichener": "erschlichen",
    "erschlichenes": "erschlichen",
    "erschlichest": "erschleichen",
    "erschlichet": "erschleichen",
    "erschlichst": "erschleichen",
    "erschlicht": "erschleichen",
    "erschließe": "erschließen",
    "erschließend": "erschließen",
    "erschließende": "erschließend",
    "erschließendem": "erschließend",
    "erschließenden": "erschließend",
    "erschließender": "erschließend",
    "erschließendes": "erschließend",
    "erschließest": "erschließen",
    "erschließet": "erschließen",
    "erschließt": "erschließen",
    "erschlossen": "erschließen",
    "erschlossene": "erschlossen",
    "erschlossenem": "erschlossen",
    "erschlossenen": "erschlossen",
    "erschlossener": "erschlossen",
    "erschlossenere": "erschlossen",
    "erschlossenerem": "erschlossen",
    "erschlosseneren": "erschlossen",
    "erschlossenerer": "erschlossen",
    "erschlosseneres": "erschlossen",
    "erschlossenes": "erschlossen",
    "erschlossenste": "erschlossen",
    "erschlossenstem": "erschlossen",
    "erschlossensten": "erschlossen",
    "erschlossenster": "erschlossen",
    "erschlossenstes": "erschlossen",
    "erschloß": "erschließen",
    "erschloßt": "erschließen",
    "erschlug": "erschlagen",
    "erschlugen": "erschlagen",
    "erschlugst": "erschlagen",
    "erschlugt": "erschlagen",
    "erschlägst": "erschlagen",
    "erschlägt": "erschlagen",
    "erschlösse": "erschließen",
    "erschlössen": "erschließen",
    "erschlössest": "erschließen",
    "erschlösset": "erschließen",
    "erschlüge": "erschlagen",
    "erschlügen": "erschlagen",
    "erschlügest": "erschlagen",
    "erschlüget": "erschlagen",
    "erschossen": "erschießen",
    "erschossene": "erschossen",
    "erschossenem": "erschossen",
    "erschossenen": "erschossen",
    "erschossener": "erschossen",
    "erschossenes": "erschossen",
    "erschoß": "erschießen",
    "erschoßt": "erschießen",
    "erschrak": "erschrecken",
    "erschraken": "erschrecken",
    "erschrakst": "erschrecken",
    "erschrakt": "erschrecken",
    "erschrecke": "erschrecken",
    "erschreckend": "erschrecken",
    "erschreckende": "erschreckend",
    "erschreckendem": "erschreckend",
    "erschreckenden": "erschreckend",
    "erschreckender": "erschreckend",
    "erschreckendere": "erschreckend",
    "erschreckenderem": "erschreckend",
    "erschreckenderen": "erschreckend",
    "erschreckenderer": "erschreckend",
    "erschreckenderes": "erschreckend",
    "erschreckendes": "erschreckend",
    "erschreckendste": "erschreckend",
    "erschreckendstem": "erschreckend",
    "erschreckendsten": "erschreckend",
    "erschreckendster": "erschreckend",
    "erschreckendstes": "erschreckend",
    "erschreckest": "erschrecken",
    "erschrecket": "erschrecken",
    "erschreckst": "erschrecken",
    "erschreckt": "erschrecken",
    "erschreckte": "erschrecken",
    "erschrecktem": "erschreckt",
    "erschreckten": "erschrecken",
    "erschreckter": "erschreckt",
    "erschrecktere": "erschreckt",
    "erschreckterem": "erschreckt",
    "erschreckteren": "erschreckt",
    "erschreckterer": "erschreckt",
    "erschreckteres": "erschreckt",
    "erschrecktes": "erschreckt",
    "erschrecktest": "erschrecken",
    "erschreckteste": "erschreckt",
    "erschrecktestem": "erschreckt",
    "erschrecktesten": "erschreckt",
    "erschrecktester": "erschreckt",
    "erschrecktestes": "erschreckt",
    "erschrecktet": "erschrecken",
    "erschrick": "erschrecken",
    "erschrickst": "erschrecken",
    "erschrickt": "erschrecken",
    "erschrocken": "erschrecken",
    "erschrockene": "erschrocken",
    "erschrockenem": "erschrocken",
    "erschrockenen": "erschrocken",
    "erschrockener": "erschrocken",
    "erschrockenere": "erschrocken",
    "erschrockenerem": "erschrocken",
    "erschrockeneren": "erschrocken",
    "erschrockenerer": "erschrocken",
    "erschrockeneres": "erschrocken",
    "erschrockenes": "erschrocken",
    "erschrockenste": "erschrocken",
    "erschrockenstem": "erschrocken",
    "erschrockensten": "erschrocken",
    "erschrockenster": "erschrocken",
    "erschrockenstes": "erschrocken",
    "erschräke": "erschrecken",
    "erschräken": "erschrecken",
    "erschräkest": "erschrecken",
    "erschräket": "erschrecken",
    "erschuf": "erschaffen",
    "erschufen": "erschaffen",
    "erschufst": "erschaffen",
    "erschuft": "erschaffen",
    "erschwere": "erschweren",
    "erschwerend": "erschweren",
    "erschwerende": "erschwerend",
    "erschwerendem": "erschwerend",
    "erschwerenden": "erschwerend",
    "erschwerender": "erschwerend",
    "erschwerendere": "erschwerend",
    "erschwerenderem": "erschwerend",
    "erschwerenderen": "erschwerend",
    "erschwerenderer": "erschwerend",
    "erschwerenderes": "erschwerend",
    "erschwerendes": "erschwerend",
    "erschwerendste": "erschwerend",
    "erschwerendstem": "erschwerend",
    "erschwerendsten": "erschwerend",
    "erschwerendster": "erschwerend",
    "erschwerendstes": "erschwerend",
    "erschwerest": "erschweren",
    "erschweret": "erschweren",
    "erschwerst": "erschweren",
    "erschwert": "erschweren",
    "erschwerte": "erschweren",
    "erschwertem": "erschwert",
    "erschwerten": "erschweren",
    "erschwerter": "erschwert",
    "erschwertes": "erschwert",
    "erschwertest": "erschweren",
    "erschwertet": "erschweren",
    "erschwindele": "erschwindeln",
    "erschwindelnd": "erschwindeln",
    "erschwindelnde": "erschwindelnd",
    "erschwindelndem": "erschwindelnd",
    "erschwindelnden": "erschwindelnd",
    "erschwindelnder": "erschwindelnd",
    "erschwindelndes": "erschwindelnd",
    "erschwindelst": "erschwindeln",
    "erschwindelt": "erschwindeln",
    "erschwindelte": "erschwindeln",
    "erschwindeltem": "erschwindelt",
    "erschwindelten": "erschwindeln",
    "erschwindelter": "erschwindelt",
    "erschwindeltes": "erschwindelt",
    "erschwindeltest": "erschwindeln",
    "erschwindeltet": "erschwindeln",
    "erschwindle": "erschwindeln",
    "erschwingliche": "erschwinglich",
    "erschwinglichem": "erschwinglich",
    "erschwinglichen": "erschwinglich",
    "erschwinglicher": "erschwinglich",
    "erschwinglichere": "erschwinglich",
    "erschwinglicherem": "erschwinglich",
    "erschwinglicheren": "erschwinglich",
    "erschwinglicherer": "erschwinglich",
    "erschwinglicheres": "erschwinglich",
    "erschwingliches": "erschwinglich",
    "erschwinglichste": "erschwinglich",
    "erschwinglichstem": "erschwinglich",
    "erschwinglichsten": "erschwinglich",
    "erschwinglichster": "erschwinglich",
    "erschwinglichstes": "erschwinglich",
    "erschöpfe": "erschöpfen",
    "erschöpfend": "erschöpfen",
    "erschöpfende": "erschöpfend",
    "erschöpfendem": "erschöpfend",
    "erschöpfenden": "erschöpfend",
    "erschöpfender": "erschöpfend",
    "erschöpfendere": "erschöpfend",
    "erschöpfenderem": "erschöpfend",
    "erschöpfenderen": "erschöpfend",
    "erschöpfenderer": "erschöpfend",
    "erschöpfenderes": "erschöpfend",
    "erschöpfendes": "erschöpfend",
    "erschöpfendste": "erschöpfend",
    "erschöpfendstem": "erschöpfend",
    "erschöpfendsten": "erschöpfend",
    "erschöpfendster": "erschöpfend",
    "erschöpfendstes": "erschöpfend",
    "erschöpfest": "erschöpfen",
    "erschöpfet": "erschöpfen",
    "erschöpfst": "erschöpfen",
    "erschöpft": "erschöpfen",
    "erschöpfte": "erschöpfen",
    "erschöpftem": "erschöpft",
    "erschöpften": "erschöpfen",
    "erschöpfter": "erschöpft",
    "erschöpftere": "erschöpft",
    "erschöpfterem": "erschöpft",
    "erschöpfteren": "erschöpft",
    "erschöpfterer": "erschöpft",
    "erschöpfteres": "erschöpft",
    "erschöpftes": "erschöpft",
    "erschöpftest": "erschöpfen",
    "erschöpfteste": "erschöpft",
    "erschöpftestem": "erschöpft",
    "erschöpftesten": "erschöpft",
    "erschöpftester": "erschöpft",
    "erschöpftestes": "erschöpft",
    "erschöpftet": "erschöpfen",
    "erschösse": "erschießen",
    "erschössen": "erschießen",
    "erschössest": "erschießen",
    "erschösset": "erschießen",
    "erschüfe": "erschaffen",
    "erschüfen": "erschaffen",
    "erschüfest": "erschaffen",
    "erschüfet": "erschaffen",
    "erschüttere": "erschüttern",
    "erschütternd": "erschüttern",
    "erschütternde": "erschütternd",
    "erschütterndem": "erschütternd",
    "erschütternden": "erschütternd",
    "erschütternder": "erschütternd",
    "erschütterndere": "erschütternd",
    "erschütternderem": "erschütternd",
    "erschütternderen": "erschütternd",
    "erschütternderer": "erschütternd",
    "erschütternderes": "erschütternd",
    "erschütterndes": "erschütternd",
    "erschütterndste": "erschütternd",
    "erschütterndstem": "erschütternd",
    "erschütterndsten": "erschütternd",
    "erschütterndster": "erschütternd",
    "erschütterndstes": "erschütternd",
    "erschütterst": "erschüttern",
    "erschüttert": "erschüttern",
    "erschütterte": "erschüttern",
    "erschüttertem": "erschüttert",
    "erschütterten": "erschüttern",
    "erschütterter": "erschüttert",
    "erschüttertere": "erschüttert",
    "erschütterterem": "erschüttert",
    "erschütterteren": "erschüttert",
    "erschütterterer": "erschüttert",
    "erschütterteres": "erschüttert",
    "erschüttertes": "erschüttert",
    "erschüttertest": "erschüttern",
    "erschütterteste": "erschüttert",
    "erschüttertestem": "erschüttert",
    "erschüttertesten": "erschüttert",
    "erschüttertester": "erschüttert",
    "erschüttertestes": "erschüttert",
    "erschüttertet": "erschüttern",
    "ersehe": "ersehen",
    "ersehend": "ersehen",
    "ersehende": "ersehend",
    "ersehendem": "ersehend",
    "ersehenden": "ersehend",
    "ersehender": "ersehend",
    "ersehendes": "ersehend",
    "ersehene": "ersehen",
    "ersehenem": "ersehen",
    "ersehenen": "ersehen",
    "ersehener": "ersehen",
    "ersehenes": "ersehen",
    "ersehest": "ersehen",
    "ersehet": "ersehen",
    "ersehne": "ersehnen",
    "ersehnend": "ersehnen",
    "ersehnende": "ersehnend",
    "ersehnendem": "ersehnend",
    "ersehnenden": "ersehnend",
    "ersehnender": "ersehnend",
    "ersehnendere": "ersehnend",
    "ersehnenderem": "ersehnend",
    "ersehnenderen": "ersehnend",
    "ersehnenderer": "ersehnend",
    "ersehnenderes": "ersehnend",
    "ersehnendes": "ersehnend",
    "ersehnendste": "ersehnend",
    "ersehnendstem": "ersehnend",
    "ersehnendsten": "ersehnend",
    "ersehnendster": "ersehnend",
    "ersehnendstes": "ersehnend",
    "ersehnest": "ersehnen",
    "ersehnet": "ersehnen",
    "ersehnst": "ersehnen",
    "ersehnt": "ersehnen",
    "ersehnte": "ersehnen",
    "ersehntem": "ersehnt",
    "ersehnten": "ersehnen",
    "ersehnter": "ersehnt",
    "ersehntere": "ersehnt",
    "ersehnterem": "ersehnt",
    "ersehnteren": "ersehnt",
    "ersehnterer": "ersehnt",
    "ersehnteres": "ersehnt",
    "ersehntes": "ersehnt",
    "ersehntest": "ersehnen",
    "ersehnteste": "ersehnt",
    "ersehntestem": "ersehnt",
    "ersehntesten": "ersehnt",
    "ersehntester": "ersehnt",
    "ersehntestes": "ersehnt",
    "ersehntet": "ersehnen",
    "erseht": "ersehen",
    "ersetzbare": "ersetzbar",
    "ersetzbarem": "ersetzbar",
    "ersetzbaren": "ersetzbar",
    "ersetzbarer": "ersetzbar",
    "ersetzbares": "ersetzbar",
    "ersetze": "ersetzen",
    "ersetzend": "ersetzen",
    "ersetzende": "ersetzend",
    "ersetzendem": "ersetzend",
    "ersetzenden": "ersetzend",
    "ersetzender": "ersetzend",
    "ersetzendes": "ersetzend",
    "ersetzest": "ersetzen",
    "ersetzet": "ersetzen",
    "ersetzt": "ersetzen",
    "ersetzte": "ersetzen",
    "ersetztem": "ersetzt",
    "ersetzten": "ersetzen",
    "ersetzter": "ersetzt",
    "ersetztes": "ersetzt",
    "ersetztest": "ersetzen",
    "ersetztet": "ersetzen",
    "ersichtlichem": "ersichtlich",
    "ersichtlichen": "ersichtlich",
    "ersichtlicher": "ersichtlich",
    "ersichtliches": "ersichtlich",
    "ersieh": "ersehen",
    "ersiehst": "ersehen",
    "ersieht": "ersehen",
    "ersinne": "ersinnen",
    "ersinnend": "ersinnen",
    "ersinnende": "ersinnend",
    "ersinnendem": "ersinnend",
    "ersinnenden": "ersinnend",
    "ersinnender": "ersinnend",
    "ersinnendere": "ersinnend",
    "ersinnenderem": "ersinnend",
    "ersinnenderen": "ersinnend",
    "ersinnenderer": "ersinnend",
    "ersinnenderes": "ersinnend",
    "ersinnendes": "ersinnend",
    "ersinnendste": "ersinnend",
    "ersinnendstem": "ersinnend",
    "ersinnendsten": "ersinnend",
    "ersinnendster": "ersinnend",
    "ersinnendstes": "ersinnend",
    "ersinnest": "ersinnen",
    "ersinnet": "ersinnen",
    "ersinnst": "ersinnen",
    "ersinnt": "ersinnen",
    "ersoff": "ersaufen",
    "ersoffen": "ersaufen",
    "ersoffene": "ersoffen",
    "ersoffenem": "ersoffen",
    "ersoffenen": "ersoffen",
    "ersoffener": "ersoffen",
    "ersoffenes": "ersoffen",
    "ersoffst": "ersaufen",
    "ersofft": "ersaufen",
    "ersonnen": "ersinnen",
    "ersonnene": "ersonnen",
    "ersonnenem": "ersonnen",
    "ersonnenen": "ersonnen",
    "ersonnener": "ersonnen",
    "ersonnenere": "ersonnen",
    "ersonnenerem": "ersonnen",
    "ersonneneren": "ersonnen",
    "ersonnenerer": "ersonnen",
    "ersonneneres": "ersonnen",
    "ersonnenes": "ersonnen",
    "ersonnenste": "ersonnen",
    "ersonnenstem": "ersonnen",
    "ersonnensten": "ersonnen",
    "ersonnenster": "ersonnen",
    "ersonnenstes": "ersonnen",
    "erspare": "ersparen",
    "ersparend": "ersparen",
    "ersparende": "ersparend",
    "ersparendem": "ersparend",
    "ersparenden": "ersparend",
    "ersparender": "ersparend",
    "ersparendes": "ersparend",
    "ersparest": "ersparen",
    "ersparet": "ersparen",
    "ersparst": "ersparen",
    "erspart": "ersparen",
    "ersparte": "ersparen",
    "erspartem": "erspart",
    "ersparten": "ersparen",
    "ersparter": "erspart",
    "erspartes": "erspart",
    "erspartest": "ersparen",
    "erspartet": "ersparen",
    "erspiele": "erspielen",
    "erspielend": "erspielen",
    "erspielende": "erspielend",
    "erspielendem": "erspielend",
    "erspielenden": "erspielend",
    "erspielender": "erspielend",
    "erspielendes": "erspielend",
    "erspielest": "erspielen",
    "erspielet": "erspielen",
    "erspielst": "erspielen",
    "erspielt": "erspielen",
    "erspielte": "erspielen",
    "erspieltem": "erspielt",
    "erspielten": "erspielen",
    "erspielter": "erspielt",
    "erspieltes": "erspielt",
    "erspieltest": "erspielen",
    "erspieltet": "erspielen",
    "erspähe": "erspähen",
    "erspähend": "erspähen",
    "erspähende": "erspähend",
    "erspähendem": "erspähend",
    "erspähenden": "erspähend",
    "erspähender": "erspähend",
    "erspähendes": "erspähend",
    "erspähest": "erspähen",
    "erspähet": "erspähen",
    "erspähst": "erspähen",
    "erspäht": "erspähen",
    "erspähte": "erspähen",
    "erspähtem": "erspäht",
    "erspähten": "erspähen",
    "erspähter": "erspäht",
    "erspähtes": "erspäht",
    "erspähtest": "erspähen",
    "erspähtet": "erspähen",
    "erstand": "erstehen",
    "erstanden": "erstehen",
    "erstandene": "erstanden",
    "erstandenem": "erstanden",
    "erstandenen": "erstanden",
    "erstandener": "erstanden",
    "erstandenes": "erstanden",
    "erstandest": "erstehen",
    "erstandet": "erstehen",
    "erstank": "erstinken",
    "erstanken": "erstinken",
    "erstankst": "erstinken",
    "erstankt": "erstinken",
    "erstarke": "erstarken",
    "erstarkend": "erstarken",
    "erstarkende": "erstarkend",
    "erstarkendem": "erstarkend",
    "erstarkenden": "erstarkend",
    "erstarkender": "erstarkend",
    "erstarkendere": "erstarkend",
    "erstarkenderem": "erstarkend",
    "erstarkenderen": "erstarkend",
    "erstarkenderer": "erstarkend",
    "erstarkenderes": "erstarkend",
    "erstarkendes": "erstarkend",
    "erstarkendste": "erstarkend",
    "erstarkendstem": "erstarkend",
    "erstarkendsten": "erstarkend",
    "erstarkendster": "erstarkend",
    "erstarkendstes": "erstarkend",
    "erstarkest": "erstarken",
    "erstarket": "erstarken",
    "erstarkst": "erstarken",
    "erstarkt": "erstarken",
    "erstarkte": "erstarken",
    "erstarktem": "erstarkt",
    "erstarkten": "erstarken",
    "erstarkter": "erstarkt",
    "erstarktere": "erstarkt",
    "erstarkterem": "erstarkt",
    "erstarkteren": "erstarkt",
    "erstarkterer": "erstarkt",
    "erstarkteres": "erstarkt",
    "erstarktes": "erstarkt",
    "erstarktest": "erstarken",
    "erstarkteste": "erstarkt",
    "erstarktestem": "erstarkt",
    "erstarktesten": "erstarkt",
    "erstarktester": "erstarkt",
    "erstarktestes": "erstarkt",
    "erstarktet": "erstarken",
    "erstarre": "erstarren",
    "erstarrend": "erstarren",
    "erstarrende": "erstarrend",
    "erstarrendem": "erstarrend",
    "erstarrenden": "erstarrend",
    "erstarrender": "erstarrend",
    "erstarrendere": "erstarrend",
    "erstarrenderem": "erstarrend",
    "erstarrenderen": "erstarrend",
    "erstarrenderer": "erstarrend",
    "erstarrenderes": "erstarrend",
    "erstarrendes": "erstarrend",
    "erstarrendste": "erstarrend",
    "erstarrendstem": "erstarrend",
    "erstarrendsten": "erstarrend",
    "erstarrendster": "erstarrend",
    "erstarrendstes": "erstarrend",
    "erstarrest": "erstarren",
    "erstarret": "erstarren",
    "erstarrst": "erstarren",
    "erstarrt": "erstarren",
    "erstarrte": "erstarren",
    "erstarrtem": "erstarrt",
    "erstarrten": "erstarren",
    "erstarrter": "erstarrt",
    "erstarrtere": "erstarrt",
    "erstarrterem": "erstarrt",
    "erstarrteren": "erstarrt",
    "erstarrterer": "erstarrt",
    "erstarrteres": "erstarrt",
    "erstarrtes": "erstarrt",
    "erstarrtest": "erstarren",
    "erstarrteste": "erstarrt",
    "erstarrtestem": "erstarrt",
    "erstarrtesten": "erstarrt",
    "erstarrtester": "erstarrt",
    "erstarrtestes": "erstarrt",
    "erstarrtet": "erstarren",
    "erstatte": "erstatten",
    "erstattend": "erstatten",
    "erstattende": "erstattend",
    "erstattendem": "erstattend",
    "erstattenden": "erstattend",
    "erstattender": "erstattend",
    "erstattendes": "erstattend",
    "erstattest": "erstatten",
    "erstattet": "erstatten",
    "erstattete": "erstatten",
    "erstattetem": "erstattet",
    "erstatteten": "erstatten",
    "erstatteter": "erstattet",
    "erstattetes": "erstattet",
    "erstattetest": "erstatten",
    "erstattetet": "erstatten",
    "erstaune": "erstaunen",
    "erstaunend": "erstaunen",
    "erstaunende": "erstaunend",
    "erstaunendem": "erstaunend",
    "erstaunenden": "erstaunend",
    "erstaunender": "erstaunend",
    "erstaunendes": "erstaunend",
    "erstaunest": "erstaunen",
    "erstaunet": "erstaunen",
    "erstaunliche": "erstaunlich",
    "erstaunlichem": "erstaunlich",
    "erstaunlichen": "erstaunlich",
    "erstaunlicher": "erstaunlich",
    "erstaunlichere": "erstaunlich",
    "erstaunlicherem": "erstaunlich",
    "erstaunlicheren": "erstaunlich",
    "erstaunlicherer": "erstaunlich",
    "erstaunlicheres": "erstaunlich",
    "erstaunliches": "erstaunlich",
    "erstaunlichste": "erstaunlich",
    "erstaunlichstem": "erstaunlich",
    "erstaunlichsten": "erstaunlich",
    "erstaunlichster": "erstaunlich",
    "erstaunlichstes": "erstaunlich",
    "erstaunst": "erstaunen",
    "erstaunt": "erstaunen",
    "erstaunte": "erstaunen",
    "erstauntem": "erstaunt",
    "erstaunten": "erstaunen",
    "erstaunter": "erstaunt",
    "erstauntes": "erstaunt",
    "erstauntest": "erstaunen",
    "erstauntet": "erstaunen",
    "erstehe": "erstehen",
    "erstehend": "erstehen",
    "erstehende": "erstehend",
    "erstehendem": "erstehend",
    "erstehenden": "erstehend",
    "erstehender": "erstehend",
    "erstehendes": "erstehend",
    "erstehest": "erstehen",
    "erstehet": "erstehen",
    "erstehst": "erstehen",
    "ersteht": "erstehen",
    "ersteigere": "ersteigern",
    "ersteigernd": "ersteigern",
    "ersteigernde": "ersteigernd",
    "ersteigerndem": "ersteigernd",
    "ersteigernden": "ersteigernd",
    "ersteigernder": "ersteigernd",
    "ersteigerndes": "ersteigernd",
    "ersteigerst": "ersteigern",
    "ersteigert": "ersteigern",
    "ersteigerte": "ersteigern",
    "ersteigertem": "ersteigert",
    "ersteigerten": "ersteigern",
    "ersteigerter": "ersteigert",
    "ersteigertes": "ersteigert",
    "ersteigertest": "ersteigern",
    "ersteigertet": "ersteigern",
    "erstelle": "erstellen",
    "erstellend": "erstellen",
    "erstellende": "erstellend",
    "erstellendem": "erstellend",
    "erstellenden": "erstellend",
    "erstellender": "erstellend",
    "erstellendes": "erstellend",
    "erstellest": "erstellen",
    "erstellet": "erstellen",
    "erstellst": "erstellen",
    "erstellt": "erstellen",
    "erstellte": "erstellen",
    "erstelltem": "erstellt",
    "erstellten": "erstellen",
    "erstellter": "erstellt",
    "erstelltes": "erstellt",
    "erstelltest": "erstellen",
    "erstelltet": "erstellen",
    "erstem": "erst",
    "ersten": "erst",
    "erster": "erst",
    "erstes": "erst",
    "erstgeborenem": "erstgeboren",
    "erstgeborenen": "erstgeboren",
    "erstgeborener": "erstgeboren",
    "erstgeborenes": "erstgeboren",
    "erstgenannte": "erstgenannt",
    "erstgenanntem": "erstgenannt",
    "erstgenannten": "erstgenannt",
    "erstgenannter": "erstgenannt",
    "erstgenanntes": "erstgenannt",
    "erstinke": "erstinken",
    "erstinkend": "erstinken",
    "erstinkende": "erstinkend",
    "erstinkendem": "erstinkend",
    "erstinkenden": "erstinkend",
    "erstinkender": "erstinkend",
    "erstinkendes": "erstinkend",
    "erstinkest": "erstinken",
    "erstinket": "erstinken",
    "erstinkst": "erstinken",
    "erstinkt": "erstinken",
    "erstklassige": "erstklassig",
    "erstklassigem": "erstklassig",
    "erstklassigen": "erstklassig",
    "erstklassiger": "erstklassig",
    "erstklassigere": "erstklassig",
    "erstklassigerem": "erstklassig",
    "erstklassigeren": "erstklassig",
    "erstklassigerer": "erstklassig",
    "erstklassigeres": "erstklassig",
    "erstklassiges": "erstklassig",
    "erstklassigste": "erstklassig",
    "erstklassigstem": "erstklassig",
    "erstklassigsten": "erstklassig",
    "erstklassigster": "erstklassig",
    "erstklassigstes": "erstklassig",
    "erstmaligem": "erstmalig",
    "erstmaligen": "erstmalig",
    "erstmaliger": "erstmalig",
    "erstmaliges": "erstmalig",
    "erstrebe": "erstreben",
    "erstrebend": "erstreben",
    "erstrebende": "erstrebend",
    "erstrebendem": "erstrebend",
    "erstrebenden": "erstrebend",
    "erstrebender": "erstrebend",
    "erstrebendes": "erstrebend",
    "erstrebenswertem": "erstrebenswert",
    "erstrebenswerten": "erstrebenswert",
    "erstrebenswerter": "erstrebenswert",
    "erstrebenswertere": "erstrebenswert",
    "erstrebenswerterem": "erstrebenswert",
    "erstrebenswerteren": "erstrebenswert",
    "erstrebenswerterer": "erstrebenswert",
    "erstrebenswerteres": "erstrebenswert",
    "erstrebenswertes": "erstrebenswert",
    "erstrebenswerteste": "erstrebenswert",
    "erstrebenswertestem": "erstrebenswert",
    "erstrebenswertesten": "erstrebenswert",
    "erstrebenswertester": "erstrebenswert",
    "erstrebenswertestes": "erstrebenswert",
    "erstrebest": "erstreben",
    "erstrebet": "erstreben",
    "erstrebst": "erstreben",
    "erstrebt": "erstreben",
    "erstrebte": "erstreben",
    "erstrebtem": "erstrebt",
    "erstrebten": "erstreben",
    "erstrebter": "erstrebt",
    "erstrebtes": "erstrebt",
    "erstrebtest": "erstreben",
    "erstrebtet": "erstreben",
    "erstrecke": "erstrecken",
    "erstreckend": "erstrecken",
    "erstreckende": "erstreckend",
    "erstreckendem": "erstreckend",
    "erstreckenden": "erstreckend",
    "erstreckender": "erstreckend",
    "erstreckendes": "erstreckend",
    "erstreckest": "erstrecken",
    "erstrecket": "erstrecken",
    "erstreckst": "erstrecken",
    "erstreckt": "erstrecken",
    "erstreckte": "erstrecken",
    "erstrecktem": "erstreckt",
    "erstreckten": "erstrecken",
    "erstreckter": "erstreckt",
    "erstrecktes": "erstreckt",
    "erstrecktest": "erstrecken",
    "erstrecktet": "erstrecken",
    "erstreike": "erstreiken",
    "erstreikend": "erstreiken",
    "erstreikende": "erstreikend",
    "erstreikendem": "erstreikend",
    "erstreikenden": "erstreikend",
    "erstreikender": "erstreikend",
    "erstreikendes": "erstreikend",
    "erstreikest": "erstreiken",
    "erstreiket": "erstreiken",
    "erstreikst": "erstreiken",
    "erstreikt": "erstreiken",
    "erstreikte": "erstreiken",
    "erstreiktem": "erstreikt",
    "erstreikten": "erstreiken",
    "erstreikter": "erstreikt",
    "erstreiktes": "erstreikt",
    "erstreiktest": "erstreiken",
    "erstreiktet": "erstreiken",
    "erstunken": "erstinken",
    "erstunkene": "erstunken",
    "erstunkenem": "erstunken",
    "erstunkenen": "erstunken",
    "erstunkener": "erstunken",
    "erstunkenere": "erstunken",
    "erstunkenerem": "erstunken",
    "erstunkeneren": "erstunken",
    "erstunkenerer": "erstunken",
    "erstunkeneres": "erstunken",
    "erstunkenes": "erstunken",
    "erstunkenste": "erstunken",
    "erstunkenstem": "erstunken",
    "erstunkensten": "erstunken",
    "erstunkenster": "erstunken",
    "erstunkenstes": "erstunken",
    "erstänke": "erstinken",
    "erstänken": "erstinken",
    "erstänkest": "erstinken",
    "erstänket": "erstinken",
    "erstünde": "erstehen",
    "erstünden": "erstehen",
    "erstündest": "erstehen",
    "erstündet": "erstehen",
    "ersuche": "ersuchen",
    "ersuchend": "ersuchen",
    "ersuchende": "ersuchend",
    "ersuchendem": "ersuchend",
    "ersuchenden": "ersuchend",
    "ersuchender": "ersuchend",
    "ersuchendes": "ersuchend",
    "ersuchest": "ersuchen",
    "ersuchet": "ersuchen",
    "ersuchst": "ersuchen",
    "ersucht": "ersuchen",
    "ersuchte": "ersuchen",
    "ersuchtem": "ersucht",
    "ersuchten": "ersuchen",
    "ersuchter": "ersucht",
    "ersuchtes": "ersucht",
    "ersuchtest": "ersuchen",
    "ersuchtet": "ersuchen",
    "ersähe": "ersehen",
    "ersähen": "ersehen",
    "ersähest": "ersehen",
    "ersähet": "ersehen",
    "ersänne": "ersinnen",
    "ersännen": "ersinnen",
    "ersännest": "ersinnen",
    "ersännet": "ersinnen",
    "ersäufst": "ersaufen",
    "ersäuft": "ersaufen",
    "ersöffe": "ersaufen",
    "ersöffen": "ersaufen",
    "ersöffest": "ersaufen",
    "ersöffet": "ersaufen",
    "ertappe": "ertappen",
    "ertappend": "ertappen",
    "ertappende": "ertappend",
    "ertappendem": "ertappend",
    "ertappenden": "ertappend",
    "ertappender": "ertappend",
    "ertappendes": "ertappend",
    "ertappest": "ertappen",
    "ertappet": "ertappen",
    "ertappst": "ertappen",
    "ertappt": "ertappen",
    "ertappte": "ertappen",
    "ertapptem": "ertappt",
    "ertappten": "ertappen",
    "ertappter": "ertappt",
    "ertapptes": "ertappt",
    "ertapptest": "ertappen",
    "ertapptet": "ertappen",
    "ertaste": "ertasten",
    "ertastend": "ertasten",
    "ertastende": "ertastend",
    "ertastendem": "ertastend",
    "ertastenden": "ertastend",
    "ertastender": "ertastend",
    "ertastendes": "ertastend",
    "ertastest": "ertasten",
    "ertastet": "ertasten",
    "ertastete": "ertasten",
    "ertastetem": "ertastet",
    "ertasteten": "ertasten",
    "ertasteter": "ertastet",
    "ertastetes": "ertastet",
    "ertastetest": "ertasten",
    "ertastetet": "ertasten",
    "erteile": "erteilen",
    "erteilend": "erteilen",
    "erteilende": "erteilend",
    "erteilendem": "erteilend",
    "erteilenden": "erteilend",
    "erteilender": "erteilend",
    "erteilendes": "erteilend",
    "erteilest": "erteilen",
    "erteilet": "erteilen",
    "erteilst": "erteilen",
    "erteilt": "erteilen",
    "erteilte": "erteilen",
    "erteiltem": "erteilt",
    "erteilten": "erteilen",
    "erteilter": "erteilt",
    "erteiltes": "erteilt",
    "erteiltest": "erteilen",
    "erteiltet": "erteilen",
    "ertragbarem": "ertragbar",
    "ertragbaren": "ertragbar",
    "ertragbarer": "ertragbar",
    "ertragbarere": "ertragbar",
    "ertragbarerem": "ertragbar",
    "ertragbareren": "ertragbar",
    "ertragbarerer": "ertragbar",
    "ertragbareres": "ertragbar",
    "ertragbares": "ertragbar",
    "ertragbarste": "ertragbar",
    "ertragbarstem": "ertragbar",
    "ertragbarsten": "ertragbar",
    "ertragbarster": "ertragbar",
    "ertragbarstes": "ertragbar",
    "ertragend": "ertragen",
    "ertragende": "ertragend",
    "ertragendem": "ertragend",
    "ertragenden": "ertragend",
    "ertragender": "ertragend",
    "ertragendere": "ertragend",
    "ertragenderem": "ertragend",
    "ertragenderen": "ertragend",
    "ertragenderer": "ertragend",
    "ertragenderes": "ertragend",
    "ertragendes": "ertragend",
    "ertragendste": "ertragend",
    "ertragendstem": "ertragend",
    "ertragendsten": "ertragend",
    "ertragendster": "ertragend",
    "ertragendstes": "ertragend",
    "ertragene": "ertragen",
    "ertragenem": "ertragen",
    "ertragenen": "ertragen",
    "ertragener": "ertragen",
    "ertragenes": "ertragen",
    "ertragest": "ertragen",
    "ertraget": "ertragen",
    "ertragfähige": "ertragfähig",
    "ertragfähigem": "ertragfähig",
    "ertragfähigen": "ertragfähig",
    "ertragfähiger": "ertragfähig",
    "ertragfähigere": "ertragfähig",
    "ertragfähigerem": "ertragfähig",
    "ertragfähigeren": "ertragfähig",
    "ertragfähigerer": "ertragfähig",
    "ertragfähigeres": "ertragfähig",
    "ertragfähiges": "ertragfähig",
    "ertragfähigste": "ertragfähig",
    "ertragfähigstem": "ertragfähig",
    "ertragfähigsten": "ertragfähig",
    "ertragfähigster": "ertragfähig",
    "ertragfähigstes": "ertragfähig",
    "ertraglose": "ertraglos",
    "ertraglosem": "ertraglos",
    "ertraglosen": "ertraglos",
    "ertragloser": "ertraglos",
    "ertraglosere": "ertraglos",
    "ertragloserem": "ertraglos",
    "ertragloseren": "ertraglos",
    "ertragloserer": "ertraglos",
    "ertragloseres": "ertraglos",
    "ertragloses": "ertraglos",
    "ertragloseste": "ertraglos",
    "ertraglosestem": "ertraglos",
    "ertraglosesten": "ertraglos",
    "ertraglosester": "ertraglos",
    "ertraglosestes": "ertraglos",
    "ertragreiche": "ertragreich",
    "ertragreichem": "ertragreich",
    "ertragreichen": "ertragreich",
    "ertragreicher": "ertragreich",
    "ertragreichere": "ertragreich",
    "ertragreicherem": "ertragreich",
    "ertragreicheren": "ertragreich",
    "ertragreicherer": "ertragreich",
    "ertragreicheres": "ertragreich",
    "ertragreiches": "ertragreich",
    "ertragreichste": "ertragreich",
    "ertragreichstem": "ertragreich",
    "ertragreichsten": "ertragreich",
    "ertragreichster": "ertragreich",
    "ertragreichstes": "ertragreich",
    "ertragt": "ertragen",
    "ertrank": "ertrinken",
    "ertranken": "ertrinken",
    "ertrankst": "ertrinken",
    "ertrankt": "ertrinken",
    "ertrinke": "ertrinken",
    "ertrinkend": "ertrinken",
    "ertrinkende": "ertrinkend",
    "ertrinkendem": "ertrinkend",
    "ertrinkenden": "ertrinkend",
    "ertrinkender": "ertrinkend",
    "ertrinkendes": "ertrinkend",
    "ertrinkest": "ertrinken",
    "ertrinket": "ertrinken",
    "ertrinkst": "ertrinken",
    "ertrinkt": "ertrinken",
    "ertrug": "ertragen",
    "ertrugen": "ertragen",
    "ertrugst": "ertragen",
    "ertrugt": "ertragen",
    "ertrunken": "ertrinken",
    "ertrunkene": "ertrunken",
    "ertrunkenem": "ertrunken",
    "ertrunkenen": "ertrunken",
    "ertrunkener": "ertrunken",
    "ertrunkenes": "ertrunken",
    "erträgliche": "erträglich",
    "erträglichem": "erträglich",
    "erträglichen": "erträglich",
    "erträglicher": "erträglich",
    "erträglichere": "erträglich",
    "erträglicherem": "erträglich",
    "erträglicheren": "erträglich",
    "erträglicherer": "erträglich",
    "erträglicheres": "erträglich",
    "erträgliches": "erträglich",
    "erträglichste": "erträglich",
    "erträglichstem": "erträglich",
    "erträglichsten": "erträglich",
    "erträglichster": "erträglich",
    "erträglichstes": "erträglich",
    "erträgst": "ertragen",
    "erträgt": "ertragen",
    "ertränke": "ertrinken",
    "ertränken": "ertrinken",
    "ertränkest": "ertrinken",
    "ertränket": "ertrinken",
    "erträumbare": "erträumbar",
    "erträumbarem": "erträumbar",
    "erträumbaren": "erträumbar",
    "erträumbarer": "erträumbar",
    "erträumbares": "erträumbar",
    "erträume": "erträumen",
    "erträumend": "erträumen",
    "erträumende": "erträumend",
    "erträumendem": "erträumend",
    "erträumenden": "erträumend",
    "erträumender": "erträumend",
    "erträumendes": "erträumend",
    "erträumest": "erträumen",
    "erträumet": "erträumen",
    "erträumst": "erträumen",
    "erträumt": "erträumen",
    "erträumte": "erträumen",
    "erträumtem": "erträumt",
    "erträumten": "erträumen",
    "erträumter": "erträumt",
    "erträumtes": "erträumt",
    "erträumtest": "erträumen",
    "erträumtet": "erträumen",
    "ertrüge": "ertragen",
    "ertrügen": "ertragen",
    "ertrügest": "ertragen",
    "ertrüget": "ertragen",
    "eruiere": "eruieren",
    "eruierend": "eruieren",
    "eruierende": "eruierend",
    "eruierendem": "eruierend",
    "eruierenden": "eruierend",
    "eruierender": "eruierend",
    "eruierendes": "eruierend",
    "eruierest": "eruieren",
    "eruieret": "eruieren",
    "eruierst": "eruieren",
    "eruiert": "eruieren",
    "eruierte": "eruieren",
    "eruiertem": "eruiert",
    "eruierten": "eruieren",
    "eruierter": "eruiert",
    "eruiertes": "eruiert",
    "eruiertest": "eruieren",
    "eruiertet": "eruieren",
    "erwache": "erwachen",
    "erwachend": "erwachen",
    "erwachende": "erwachend",
    "erwachendem": "erwachend",
    "erwachenden": "erwachend",
    "erwachender": "erwachend",
    "erwachendes": "erwachend",
    "erwachest": "erwachen",
    "erwachet": "erwachen",
    "erwachse": "erwachsen",
    "erwachsend": "erwachsen",
    "erwachsende": "erwachsend",
    "erwachsendem": "erwachsend",
    "erwachsenden": "erwachsend",
    "erwachsender": "erwachsend",
    "erwachsendes": "erwachsend",
    "erwachsene": "erwachsen",
    "erwachsenem": "erwachsen",
    "erwachsenen": "erwachsen",
    "erwachsener": "erwachsen",
    "erwachsenere": "erwachsen",
    "erwachsenerem": "erwachsen",
    "erwachseneren": "erwachsen",
    "erwachsenerer": "erwachsen",
    "erwachseneres": "erwachsen",
    "erwachsenes": "erwachsen",
    "erwachsenste": "erwachsen",
    "erwachsenstem": "erwachsen",
    "erwachsensten": "erwachsen",
    "erwachsenster": "erwachsen",
    "erwachsenstes": "erwachsen",
    "erwachsest": "erwachsen",
    "erwachset": "erwachsen",
    "erwachst": "erwachsen",
    "erwacht": "erwachen",
    "erwachte": "erwachen",
    "erwachtem": "erwacht",
    "erwachten": "erwachen",
    "erwachter": "erwacht",
    "erwachtes": "erwacht",
    "erwachtest": "erwachen",
    "erwachtet": "erwachen",
    "erwarb": "erwerben",
    "erwarben": "erwerben",
    "erwarbst": "erwerben",
    "erwarbt": "erwerben",
    "erwarte": "erwarten",
    "erwartend": "erwarten",
    "erwartende": "erwartend",
    "erwartendem": "erwartend",
    "erwartenden": "erwartend",
    "erwartender": "erwartend",
    "erwartendes": "erwartend",
    "erwartest": "erwarten",
    "erwartet": "erwarten",
    "erwartete": "erwarten",
    "erwartetem": "erwartet",
    "erwarteten": "erwarten",
    "erwarteter": "erwartet",
    "erwartetes": "erwartet",
    "erwartetest": "erwarten",
    "erwartetet": "erwarten",
    "erwartungsgemäßem": "erwartungsgemäß",
    "erwartungsgemäßen": "erwartungsgemäß",
    "erwartungsgemäßer": "erwartungsgemäß",
    "erwartungsgemäßes": "erwartungsgemäß",
    "erwartungsvolle": "erwartungsvoll",
    "erwartungsvollem": "erwartungsvoll",
    "erwartungsvollen": "erwartungsvoll",
    "erwartungsvoller": "erwartungsvoll",
    "erwartungsvollere": "erwartungsvoll",
    "erwartungsvollerem": "erwartungsvoll",
    "erwartungsvolleren": "erwartungsvoll",
    "erwartungsvollerer": "erwartungsvoll",
    "erwartungsvolleres": "erwartungsvoll",
    "erwartungsvolles": "erwartungsvoll",
    "erwartungsvollste": "erwartungsvoll",
    "erwartungsvollstem": "erwartungsvoll",
    "erwartungsvollsten": "erwartungsvoll",
    "erwartungsvollster": "erwartungsvoll",
    "erwartungsvollstes": "erwartungsvoll",
    "erwecke": "erwecken",
    "erweckend": "erwecken",
    "erweckende": "erweckend",
    "erweckendem": "erweckend",
    "erweckenden": "erweckend",
    "erweckender": "erweckend",
    "erweckendes": "erweckend",
    "erweckest": "erwecken",
    "erwecket": "erwecken",
    "erweckst": "erwecken",
    "erweckt": "erwecken",
    "erweckte": "erwecken",
    "erwecktem": "erweckt",
    "erweckten": "erwecken",
    "erweckter": "erweckt",
    "erwecktes": "erweckt",
    "erwecktest": "erwecken",
    "erwecktet": "erwecken",
    "erweise": "erweisen",
    "erweisend": "erweisen",
    "erweisende": "erweisend",
    "erweisendem": "erweisend",
    "erweisenden": "erweisend",
    "erweisender": "erweisend",
    "erweisendes": "erweisend",
    "erweisest": "erweisen",
    "erweiset": "erweisen",
    "erweist": "erweisen",
    "erweitere": "erweitern",
    "erweiternd": "erweitern",
    "erweiternde": "erweiternd",
    "erweiterndem": "erweiternd",
    "erweiternden": "erweiternd",
    "erweiternder": "erweiternd",
    "erweiterndes": "erweiternd",
    "erweiterst": "erweitern",
    "erweitert": "erweitern",
    "erweiterte": "erweitern",
    "erweitertem": "erweitert",
    "erweiterten": "erweitern",
    "erweiterter": "erweitert",
    "erweitertere": "erweitert",
    "erweiterterem": "erweitert",
    "erweiterteren": "erweitert",
    "erweiterterer": "erweitert",
    "erweiterteres": "erweitert",
    "erweitertes": "erweitert",
    "erweitertest": "erweitern",
    "erweiterteste": "erweitert",
    "erweitertestem": "erweitert",
    "erweitertesten": "erweitert",
    "erweitertester": "erweitert",
    "erweitertestes": "erweitert",
    "erweitertet": "erweitern",
    "erwerbend": "erwerben",
    "erwerbende": "erwerbend",
    "erwerbendem": "erwerbend",
    "erwerbenden": "erwerbend",
    "erwerbender": "erwerbend",
    "erwerbendes": "erwerbend",
    "erwerbest": "erwerben",
    "erwerbet": "erwerben",
    "erwerbsfähigem": "erwerbsfähig",
    "erwerbsfähigen": "erwerbsfähig",
    "erwerbsfähiger": "erwerbsfähig",
    "erwerbsfähigere": "erwerbsfähig",
    "erwerbsfähigerem": "erwerbsfähig",
    "erwerbsfähigeren": "erwerbsfähig",
    "erwerbsfähigerer": "erwerbsfähig",
    "erwerbsfähigeres": "erwerbsfähig",
    "erwerbsfähiges": "erwerbsfähig",
    "erwerbsfähigste": "erwerbsfähig",
    "erwerbsfähigstem": "erwerbsfähig",
    "erwerbsfähigsten": "erwerbsfähig",
    "erwerbsfähigster": "erwerbsfähig",
    "erwerbsfähigstes": "erwerbsfähig",
    "erwerbslose": "erwerbslos",
    "erwerbslosem": "erwerbslos",
    "erwerbslosen": "erwerbslos",
    "erwerbsloser": "erwerbslos",
    "erwerbslosere": "erwerbslos",
    "erwerbsloserem": "erwerbslos",
    "erwerbsloseren": "erwerbslos",
    "erwerbsloserer": "erwerbslos",
    "erwerbsloseres": "erwerbslos",
    "erwerbsloses": "erwerbslos",
    "erwerbsloseste": "erwerbslos",
    "erwerbslosestem": "erwerbslos",
    "erwerbslosesten": "erwerbslos",
    "erwerbslosester": "erwerbslos",
    "erwerbslosestes": "erwerbslos",
    "erwerbstätigem": "erwerbstätig",
    "erwerbstätigen": "erwerbstätig",
    "erwerbstätiger": "erwerbstätig",
    "erwerbstätiges": "erwerbstätig",
    "erwerbsunfähige": "erwerbsunfähig",
    "erwerbsunfähigem": "erwerbsunfähig",
    "erwerbsunfähigen": "erwerbsunfähig",
    "erwerbsunfähiger": "erwerbsunfähig",
    "erwerbsunfähigere": "erwerbsunfähig",
    "erwerbsunfähigerem": "erwerbsunfähig",
    "erwerbsunfähigeren": "erwerbsunfähig",
    "erwerbsunfähigerer": "erwerbsunfähig",
    "erwerbsunfähigeres": "erwerbsunfähig",
    "erwerbsunfähiges": "erwerbsunfähig",
    "erwerbsunfähigste": "erwerbsunfähig",
    "erwerbsunfähigstem": "erwerbsunfähig",
    "erwerbsunfähigsten": "erwerbsunfähig",
    "erwerbsunfähigster": "erwerbsunfähig",
    "erwerbsunfähigstes": "erwerbsunfähig",
    "erwerbt": "erwerben",
    "erwidere": "erwidern",
    "erwidernd": "erwidern",
    "erwidernde": "erwidernd",
    "erwiderndem": "erwidernd",
    "erwidernden": "erwidernd",
    "erwidernder": "erwidernd",
    "erwiderndes": "erwidernd",
    "erwiderst": "erwidern",
    "erwidert": "erwidern",
    "erwiderte": "erwidern",
    "erwidertem": "erwidert",
    "erwiderten": "erwidern",
    "erwiderter": "erwidert",
    "erwidertes": "erwidert",
    "erwidertest": "erwidern",
    "erwidertet": "erwidern",
    "erwies": "erweisen",
    "erwiese": "erweisen",
    "erwiesen": "erweisen",
    "erwiesene": "erwiesen",
    "erwiesenem": "erwiesen",
    "erwiesenen": "erwiesen",
    "erwiesener": "erwiesen",
    "erwiesenere": "erwiesen",
    "erwiesenerem": "erwiesen",
    "erwieseneren": "erwiesen",
    "erwiesenerer": "erwiesen",
    "erwieseneres": "erwiesen",
    "erwiesenes": "erwiesen",
    "erwiesenste": "erwiesen",
    "erwiesenstem": "erwiesen",
    "erwiesensten": "erwiesen",
    "erwiesenster": "erwiesen",
    "erwiesenstes": "erwiesen",
    "erwiesest": "erweisen",
    "erwieset": "erweisen",
    "erwiest": "erweisen",
    "erwirb": "erwerben",
    "erwirbst": "erwerben",
    "erwirbt": "erwerben",
    "erwirke": "erwirken",
    "erwirkend": "erwirken",
    "erwirkende": "erwirkend",
    "erwirkendem": "erwirkend",
    "erwirkenden": "erwirkend",
    "erwirkender": "erwirkend",
    "erwirkendes": "erwirkend",
    "erwirkest": "erwirken",
    "erwirket": "erwirken",
    "erwirkst": "erwirken",
    "erwirkt": "erwirken",
    "erwirkte": "erwirken",
    "erwirktem": "erwirkt",
    "erwirkten": "erwirken",
    "erwirkter": "erwirkt",
    "erwirktes": "erwirkt",
    "erwirktest": "erwirken",
    "erwirktet": "erwirken",
    "erwirtschafte": "erwirtschaften",
    "erwirtschaftend": "erwirtschaften",
    "erwirtschaftende": "erwirtschaftend",
    "erwirtschaftendem": "erwirtschaftend",
    "erwirtschaftenden": "erwirtschaftend",
    "erwirtschaftender": "erwirtschaftend",
    "erwirtschaftendes": "erwirtschaftend",
    "erwirtschaftest": "erwirtschaften",
    "erwirtschaftet": "erwirtschaften",
    "erwirtschaftete": "erwirtschaften",
    "erwirtschaftetem": "erwirtschaftet",
    "erwirtschafteten": "erwirtschaften",
    "erwirtschafteter": "erwirtschaftet",
    "erwirtschaftetes": "erwirtschaftet",
    "erwirtschaftetest": "erwirtschaften",
    "erwirtschaftetet": "erwirtschaften",
    "erwische": "erwischen",
    "erwischend": "erwischen",
    "erwischende": "erwischend",
    "erwischendem": "erwischend",
    "erwischenden": "erwischend",
    "erwischender": "erwischend",
    "erwischendes": "erwischend",
    "erwischest": "erwischen",
    "erwischet": "erwischen",
    "erwischst": "erwischen",
    "erwischt": "erwischen",
    "erwischte": "erwischen",
    "erwischtem": "erwischt",
    "erwischten": "erwischen",
    "erwischter": "erwischt",
    "erwischtes": "erwischt",
    "erwischtest": "erwischen",
    "erwischtet": "erwischen",
    "erwog": "erwägen",
    "erwogen": "erwägen",
    "erwogene": "erwogen",
    "erwogenem": "erwogen",
    "erwogenen": "erwogen",
    "erwogener": "erwogen",
    "erwogenere": "erwogen",
    "erwogenerem": "erwogen",
    "erwogeneren": "erwogen",
    "erwogenerer": "erwogen",
    "erwogeneres": "erwogen",
    "erwogenes": "erwogen",
    "erwogenste": "erwogen",
    "erwogenstem": "erwogen",
    "erwogensten": "erwogen",
    "erwogenster": "erwogen",
    "erwogenstes": "erwogen",
    "erwogst": "erwägen",
    "erwogt": "erwägen",
    "erworben": "erwerben",
    "erworbene": "erworben",
    "erworbenem": "erworben",
    "erworbenen": "erworben",
    "erworbener": "erworben",
    "erworbenes": "erworben",
    "erwuchs": "erwachsen",
    "erwuchsen": "erwachsen",
    "erwuchst": "erwachsen",
    "erwächst": "erwachsen",
    "erwäge": "erwägen",
    "erwägend": "erwägen",
    "erwägende": "erwägend",
    "erwägendem": "erwägend",
    "erwägenden": "erwägend",
    "erwägender": "erwägend",
    "erwägendes": "erwägend",
    "erwägenswertem": "erwägenswert",
    "erwägenswerten": "erwägenswert",
    "erwägenswerter": "erwägenswert",
    "erwägenswertes": "erwägenswert",
    "erwägest": "erwägen",
    "erwäget": "erwägen",
    "erwägst": "erwägen",
    "erwägt": "erwägen",
    "erwähle": "erwählen",
    "erwählend": "erwählen",
    "erwählende": "erwählend",
    "erwählendem": "erwählend",
    "erwählenden": "erwählend",
    "erwählender": "erwählend",
    "erwählendes": "erwählend",
    "erwählest": "erwählen",
    "erwählet": "erwählen",
    "erwählst": "erwählen",
    "erwählt": "erwählen",
    "erwählte": "erwählen",
    "erwähltem": "erwählt",
    "erwählten": "erwählen",
    "erwählter": "erwählt",
    "erwähltes": "erwählt",
    "erwähltest": "erwählen",
    "erwähltet": "erwählen",
    "erwähne": "erwähnen",
    "erwähnend": "erwähnen",
    "erwähnende": "erwähnend",
    "erwähnendem": "erwähnend",
    "erwähnenden": "erwähnend",
    "erwähnender": "erwähnend",
    "erwähnendes": "erwähnend",
    "erwähnenswertem": "erwähnenswert",
    "erwähnenswerten": "erwähnenswert",
    "erwähnenswerter": "erwähnenswert",
    "erwähnenswertes": "erwähnenswert",
    "erwähnest": "erwähnen",
    "erwähnet": "erwähnen",
    "erwähnst": "erwähnen",
    "erwähnt": "erwähnen",
    "erwähnte": "erwähnen",
    "erwähntem": "erwähnt",
    "erwähnten": "erwähnen",
    "erwähnter": "erwähnt",
    "erwähntes": "erwähnt",
    "erwähntest": "erwähnen",
    "erwähntet": "erwähnen",
    "erwärbe": "erwerben",
    "erwärben": "erwerben",
    "erwärbest": "erwerben",
    "erwärbet": "erwerben",
    "erwärme": "erwärmen",
    "erwärmend": "erwärmen",
    "erwärmende": "erwärmend",
    "erwärmendem": "erwärmend",
    "erwärmenden": "erwärmend",
    "erwärmender": "erwärmend",
    "erwärmendes": "erwärmend",
    "erwärmest": "erwärmen",
    "erwärmet": "erwärmen",
    "erwärmst": "erwärmen",
    "erwärmt": "erwärmen",
    "erwärmte": "erwärmen",
    "erwärmtem": "erwärmt",
    "erwärmten": "erwärmen",
    "erwärmter": "erwärmt",
    "erwärmtere": "erwärmt",
    "erwärmterem": "erwärmt",
    "erwärmteren": "erwärmt",
    "erwärmterer": "erwärmt",
    "erwärmteres": "erwärmt",
    "erwärmtes": "erwärmt",
    "erwärmtest": "erwärmen",
    "erwärmteste": "erwärmt",
    "erwärmtestem": "erwärmt",
    "erwärmtesten": "erwärmt",
    "erwärmtester": "erwärmt",
    "erwärmtestes": "erwärmt",
    "erwärmtet": "erwärmen",
    "erwöge": "erwägen",
    "erwögen": "erwägen",
    "erwögest": "erwägen",
    "erwöget": "erwägen",
    "erwüchse": "erwachsen",
    "erwüchsen": "erwachsen",
    "erwüchsest": "erwachsen",
    "erwüchset": "erwachsen",
    "erwünschte": "erwünscht",
    "erwünschtem": "erwünscht",
    "erwünschten": "erwünscht",
    "erwünschter": "erwünscht",
    "erwünschtere": "erwünscht",
    "erwünschterem": "erwünscht",
    "erwünschteren": "erwünscht",
    "erwünschterer": "erwünscht",
    "erwünschteres": "erwünscht",
    "erwünschtes": "erwünscht",
    "erwünschteste": "erwünscht",
    "erwünschtestem": "erwünscht",
    "erwünschtesten": "erwünscht",
    "erwünschtester": "erwünscht",
    "erwünschtestes": "erwünscht",
    "erwürge": "erwürgen",
    "erwürgend": "erwürgen",
    "erwürgende": "erwürgend",
    "erwürgendem": "erwürgend",
    "erwürgenden": "erwürgend",
    "erwürgender": "erwürgend",
    "erwürgendere": "erwürgend",
    "erwürgenderem": "erwürgend",
    "erwürgenderen": "erwürgend",
    "erwürgenderer": "erwürgend",
    "erwürgenderes": "erwürgend",
    "erwürgendes": "erwürgend",
    "erwürgendste": "erwürgend",
    "erwürgendstem": "erwürgend",
    "erwürgendsten": "erwürgend",
    "erwürgendster": "erwürgend",
    "erwürgendstes": "erwürgend",
    "erwürgest": "erwürgen",
    "erwürget": "erwürgen",
    "erwürgst": "erwürgen",
    "erwürgt": "erwürgen",
    "erwürgte": "erwürgen",
    "erwürgtem": "erwürgt",
    "erwürgten": "erwürgen",
    "erwürgter": "erwürgt",
    "erwürgtere": "erwürgt",
    "erwürgterem": "erwürgt",
    "erwürgteren": "erwürgt",
    "erwürgterer": "erwürgt",
    "erwürgteres": "erwürgt",
    "erwürgtes": "erwürgt",
    "erwürgtest": "erwürgen",
    "erwürgteste": "erwürgt",
    "erwürgtestem": "erwürgt",
    "erwürgtesten": "erwürgt",
    "erwürgtester": "erwürgt",
    "erwürgtestes": "erwürgt",
    "erwürgtet": "erwürgen",
    "erzbischöflichem": "erzbischöflich",
    "erzbischöflichen": "erzbischöflich",
    "erzbischöflicher": "erzbischöflich",
    "erzbischöfliches": "erzbischöflich",
    "erzeuge": "erzeugen",
    "erzeugend": "erzeugen",
    "erzeugende": "erzeugend",
    "erzeugendem": "erzeugend",
    "erzeugenden": "erzeugend",
    "erzeugender": "erzeugend",
    "erzeugendes": "erzeugend",
    "erzeugest": "erzeugen",
    "erzeuget": "erzeugen",
    "erzeugst": "erzeugen",
    "erzeugt": "erzeugen",
    "erzeugte": "erzeugen",
    "erzeugtem": "erzeugt",
    "erzeugten": "erzeugen",
    "erzeugter": "erzeugt",
    "erzeugtes": "erzeugt",
    "erzeugtest": "erzeugen",
    "erzeugtet": "erzeugen",
    "erziehe": "erziehen",
    "erziehend": "erziehen",
    "erziehende": "erziehend",
    "erziehendem": "erziehend",
    "erziehenden": "erziehend",
    "erziehender": "erziehend",
    "erziehendes": "erziehend",
    "erzieherischem": "erzieherisch",
    "erzieherischen": "erzieherisch",
    "erzieherischer": "erzieherisch",
    "erzieherisches": "erzieherisch",
    "erziehest": "erziehen",
    "erziehet": "erziehen",
    "erziehst": "erziehen",
    "erzieht": "erziehen",
    "erziele": "erzielen",
    "erzielend": "erzielen",
    "erzielende": "erzielend",
    "erzielendem": "erzielend",
    "erzielenden": "erzielend",
    "erzielender": "erzielend",
    "erzielendes": "erzielend",
    "erzielest": "erzielen",
    "erzielet": "erzielen",
    "erzielst": "erzielen",
    "erzielt": "erzielen",
    "erzielte": "erzielen",
    "erzieltem": "erzielt",
    "erzielten": "erzielen",
    "erzielter": "erzielt",
    "erzieltes": "erzielt",
    "erzieltest": "erzielen",
    "erzieltet": "erzielen",
    "erzog": "erziehen",
    "erzogen": "erziehen",
    "erzogene": "erzogen",
    "erzogenem": "erzogen",
    "erzogenen": "erzogen",
    "erzogener": "erzogen",
    "erzogenes": "erzogen",
    "erzogst": "erziehen",
    "erzogt": "erziehen",
    "erzwang": "erzwingen",
    "erzwangen": "erzwingen",
    "erzwangst": "erzwingen",
    "erzwangt": "erzwingen",
    "erzwinge": "erzwingen",
    "erzwingend": "erzwingen",
    "erzwingende": "erzwingend",
    "erzwingendem": "erzwingend",
    "erzwingenden": "erzwingend",
    "erzwingender": "erzwingend",
    "erzwingendes": "erzwingend",
    "erzwingest": "erzwingen",
    "erzwinget": "erzwingen",
    "erzwingst": "erzwingen",
    "erzwingt": "erzwingen",
    "erzwungen": "erzwingen",
    "erzwungene": "erzwungen",
    "erzwungenem": "erzwungen",
    "erzwungenen": "erzwungen",
    "erzwungener": "erzwungen",
    "erzwungenere": "erzwungen",
    "erzwungenerem": "erzwungen",
    "erzwungeneren": "erzwungen",
    "erzwungenerer": "erzwungen",
    "erzwungeneres": "erzwungen",
    "erzwungenes": "erzwungen",
    "erzwungenste": "erzwungen",
    "erzwungenstem": "erzwungen",
    "erzwungensten": "erzwungen",
    "erzwungenster": "erzwungen",
    "erzwungenstes": "erzwungen",
    "erzwänge": "erzwingen",
    "erzwängen": "erzwingen",
    "erzwängest": "erzwingen",
    "erzwänget": "erzwingen",
    "erzähle": "erzählen",
    "erzählend": "erzählen",
    "erzählende": "erzählend",
    "erzählendem": "erzählend",
    "erzählenden": "erzählend",
    "erzählender": "erzählend",
    "erzählendere": "erzählend",
    "erzählenderem": "erzählend",
    "erzählenderen": "erzählend",
    "erzählenderer": "erzählend",
    "erzählenderes": "erzählend",
    "erzählendes": "erzählend",
    "erzählendste": "erzählend",
    "erzählendstem": "erzählend",
    "erzählendsten": "erzählend",
    "erzählendster": "erzählend",
    "erzählendstes": "erzählend",
    "erzählenswertem": "erzählenswert",
    "erzählenswerten": "erzählenswert",
    "erzählenswerter": "erzählenswert",
    "erzählenswertere": "erzählenswert",
    "erzählenswerterem": "erzählenswert",
    "erzählenswerteren": "erzählenswert",
    "erzählenswerterer": "erzählenswert",
    "erzählenswerteres": "erzählenswert",
    "erzählenswertes": "erzählenswert",
    "erzählenswerteste": "erzählenswert",
    "erzählenswertestem": "erzählenswert",
    "erzählenswertesten": "erzählenswert",
    "erzählenswertester": "erzählenswert",
    "erzählenswertestes": "erzählenswert",
    "erzählerische": "erzählerisch",
    "erzählerischem": "erzählerisch",
    "erzählerischen": "erzählerisch",
    "erzählerischer": "erzählerisch",
    "erzählerisches": "erzählerisch",
    "erzählest": "erzählen",
    "erzählet": "erzählen",
    "erzählst": "erzählen",
    "erzählt": "erzählen",
    "erzählte": "erzählen",
    "erzähltechnische": "erzähltechnisch",
    "erzähltechnischem": "erzähltechnisch",
    "erzähltechnischen": "erzähltechnisch",
    "erzähltechnischer": "erzähltechnisch",
    "erzähltechnisches": "erzähltechnisch",
    "erzähltem": "erzählt",
    "erzählten": "erzählen",
    "erzählter": "erzählt",
    "erzähltes": "erzählt",
    "erzähltest": "erzählen",
    "erzähltet": "erzählen",
    "erzöge": "erziehen",
    "erzögen": "erziehen",
    "erzögest": "erziehen",
    "erzöget": "erziehen",
    "erzürne": "erzürnen",
    "erzürnend": "erzürnen",
    "erzürnende": "erzürnend",
    "erzürnendem": "erzürnend",
    "erzürnenden": "erzürnend",
    "erzürnender": "erzürnend",
    "erzürnendere": "erzürnend",
    "erzürnenderem": "erzürnend",
    "erzürnenderen": "erzürnend",
    "erzürnenderer": "erzürnend",
    "erzürnenderes": "erzürnend",
    "erzürnendes": "erzürnend",
    "erzürnendste": "erzürnend",
    "erzürnendstem": "erzürnend",
    "erzürnendsten": "erzürnend",
    "erzürnendster": "erzürnend",
    "erzürnendstes": "erzürnend",
    "erzürnest": "erzürnen",
    "erzürnet": "erzürnen",
    "erzürnst": "erzürnen",
    "erzürnt": "erzürnen",
    "erzürnte": "erzürnen",
    "erzürntem": "erzürnt",
    "erzürnten": "erzürnen",
    "erzürnter": "erzürnt",
    "erzürntere": "erzürnt",
    "erzürnterem": "erzürnt",
    "erzürnteren": "erzürnt",
    "erzürnterer": "erzürnt",
    "erzürnteres": "erzürnt",
    "erzürntes": "erzürnt",
    "erzürntest": "erzürnen",
    "erzürnteste": "erzürnt",
    "erzürntestem": "erzürnt",
    "erzürntesten": "erzürnt",
    "erzürntester": "erzürnt",
    "erzürntestes": "erzürnt",
    "erzürntet": "erzürnen",
    "eröffne": "eröffnen",
    "eröffnend": "eröffnen",
    "eröffnende": "eröffnend",
    "eröffnendem": "eröffnend",
    "eröffnenden": "eröffnend",
    "eröffnender": "eröffnend",
    "eröffnendes": "eröffnend",
    "eröffnest": "eröffnen",
    "eröffnet": "eröffnen",
    "eröffnete": "eröffnen",
    "eröffnetem": "eröffnet",
    "eröffneten": "eröffnen",
    "eröffneter": "eröffnet",
    "eröffnetes": "eröffnet",
    "eröffnetest": "eröffnen",
    "eröffnetet": "eröffnen",
    "erörtere": "erörtern",
    "erörternd": "erörtern",
    "erörternde": "erörternd",
    "erörterndem": "erörternd",
    "erörternden": "erörternd",
    "erörternder": "erörternd",
    "erörterndes": "erörternd",
    "erörternswertem": "erörternswert",
    "erörternswerten": "erörternswert",
    "erörternswerter": "erörternswert",
    "erörternswertere": "erörternswert",
    "erörternswerterem": "erörternswert",
    "erörternswerteren": "erörternswert",
    "erörternswerterer": "erörternswert",
    "erörternswerteres": "erörternswert",
    "erörternswertes": "erörternswert",
    "erörternswerteste": "erörternswert",
    "erörternswertestem": "erörternswert",
    "erörternswertesten": "erörternswert",
    "erörternswertester": "erörternswert",
    "erörternswertestes": "erörternswert",
    "erörterst": "erörtern",
    "erörtert": "erörtern",
    "erörterte": "erörtern",
    "erörtertem": "erörtert",
    "erörterten": "erörtern",
    "erörterter": "erörtert",
    "erörtertes": "erörtert",
    "erörtertest": "erörtern",
    "erörtertet": "erörtern",
    "erübrige": "erübrigen",
    "erübrigend": "erübrigen",
    "erübrigende": "erübrigend",
    "erübrigendem": "erübrigend",
    "erübrigenden": "erübrigend",
    "erübrigender": "erübrigend",
    "erübrigendes": "erübrigend",
    "erübrigest": "erübrigen",
    "erübriget": "erübrigen",
    "erübrigst": "erübrigen",
    "erübrigt": "erübrigen",
    "erübrigte": "erübrigen",
    "erübrigtem": "erübrigt",
    "erübrigten": "erübrigen",
    "erübrigter": "erübrigt",
    "erübrigtes": "erübrigt",
    "erübrigtest": "erübrigen",
    "erübrigtet": "erübrigen",
    "es": "ich",
    "eskaliere": "eskalieren",
    "eskalierend": "eskalieren",
    "eskalierende": "eskalierend",
    "eskalierendem": "eskalierend",
    "eskalierenden": "eskalierend",
    "eskalierender": "eskalierend",
    "eskalierendere": "eskalierend",
    "eskalierenderem": "eskalierend",
    "eskalierenderen": "eskalierend",
    "eskalierenderer": "eskalierend",
    "eskalierenderes": "eskalierend",
    "eskalierendes": "eskalierend",
    "eskalierendste": "eskalierend",
    "eskalierendstem": "eskalierend",
    "eskalierendsten": "eskalierend",
    "eskalierendster": "eskalierend",
    "eskalierendstes": "eskalierend",
    "eskalierest": "eskalieren",
    "eskalieret": "eskalieren",
    "eskalierst": "eskalieren",
    "eskaliert": "eskalieren",
    "eskalierte": "eskalieren",
    "eskaliertem": "eskaliert",
    "eskalierten": "eskalieren",
    "eskalierter": "eskaliert",
    "eskaliertere": "eskaliert",
    "eskalierterem": "eskaliert",
    "eskalierteren": "eskaliert",
    "eskalierterer": "eskaliert",
    "eskalierteres": "eskaliert",
    "eskaliertes": "eskaliert",
    "eskaliertest": "eskalieren",
    "eskalierteste": "eskaliert",
    "eskaliertestem": "eskaliert",
    "eskaliertesten": "eskaliert",
    "eskaliertester": "eskaliert",
    "eskaliertestes": "eskaliert",
    "eskaliertet": "eskalieren",
    "eskortiere": "eskortieren",
    "eskortierend": "eskortieren",
    "eskortierende": "eskortierend",
    "eskortierendem": "eskortierend",
    "eskortierenden": "eskortierend",
    "eskortierender": "eskortierend",
    "eskortierendes": "eskortierend",
    "eskortierest": "eskortieren",
    "eskortieret": "eskortieren",
    "eskortierst": "eskortieren",
    "eskortiert": "eskortieren",
    "eskortierte": "eskortieren",
    "eskortiertem": "eskortiert",
    "eskortierten": "eskortieren",
    "eskortierter": "eskortiert",
    "eskortiertes": "eskortiert",
    "eskortiertest": "eskortieren",
    "eskortiertet": "eskortieren",
    "esoterische": "esoterisch",
    "esoterischem": "esoterisch",
    "esoterischen": "esoterisch",
    "esoterischer": "esoterisch",
    "esoterisches": "esoterisch",
    "esse": "essen",
    "essend": "essen",
    "essende": "essend",
    "essendem": "essend",
    "essenden": "essend",
    "essender": "essend",
    "essendes": "essend",
    "essenziellem": "essenziell",
    "essenziellen": "essenziell",
    "essenzieller": "essenziell",
    "essenzielles": "essenziell",
    "essest": "essen",
    "esset": "essen",
    "etabliere": "etablieren",
    "etablierend": "etablieren",
    "etablierende": "etablierend",
    "etablierendem": "etablierend",
    "etablierenden": "etablierend",
    "etablierender": "etablierend",
    "etablierendes": "etablierend",
    "etablierest": "etablieren",
    "etablieret": "etablieren",
    "etablierst": "etablieren",
    "etabliert": "etablieren",
    "etablierte": "etablieren",
    "etabliertem": "etabliert",
    "etablierten": "etablieren",
    "etablierter": "etabliert",
    "etabliertere": "etabliert",
    "etablierterem": "etabliert",
    "etablierteren": "etabliert",
    "etablierterer": "etabliert",
    "etablierteres": "etabliert",
    "etabliertes": "etabliert",
    "etabliertest": "etablieren",
    "etablierteste": "etabliert",
    "etabliertestem": "etabliert",
    "etabliertesten": "etabliert",
    "etabliertester": "etabliert",
    "etabliertestes": "etabliert",
    "etabliertet": "etablieren",
    "ethischem": "ethisch",
    "ethischen": "ethisch",
    "ethischer": "ethisch",
    "ethischere": "ethisch",
    "ethischerem": "ethisch",
    "ethischeren": "ethisch",
    "ethischerer": "ethisch",
    "ethischeres": "ethisch",
    "ethisches": "ethisch",
    "ethischste": "ethisch",
    "ethischstem": "ethisch",
    "ethischsten": "ethisch",
    "ethischster": "ethisch",
    "ethischstes": "ethisch",
    "ethnische": "ethnisch",
    "ethnischem": "ethnisch",
    "ethnischen": "ethnisch",
    "ethnischer": "ethnisch",
    "ethnisches": "ethnisch",
    "ethnographischem": "ethnographisch",
    "ethnographischen": "ethnographisch",
    "ethnographischer": "ethnographisch",
    "ethnographisches": "ethnographisch",
    "ethnologischem": "ethnologisch",
    "ethnologischen": "ethnologisch",
    "ethnologischer": "ethnologisch",
    "ethnologisches": "ethnologisch",
    "etikettiere": "etikettieren",
    "etikettierend": "etikettieren",
    "etikettierende": "etikettierend",
    "etikettierendem": "etikettierend",
    "etikettierenden": "etikettierend",
    "etikettierender": "etikettierend",
    "etikettierendes": "etikettierend",
    "etikettierest": "etikettieren",
    "etikettieret": "etikettieren",
    "etikettierst": "etikettieren",
    "etikettiert": "etikettieren",
    "etikettierte": "etikettieren",
    "etikettiertem": "etikettiert",
    "etikettierten": "etikettieren",
    "etikettierter": "etikettiert",
    "etikettiertes": "etikettiert",
    "etikettiertest": "etikettieren",
    "etikettiertet": "etikettieren",
    "etliche": "etlich",
    "etlichen": "etlich",
    "etlicher": "etlich",
    "etwaigem": "etwaig",
    "etwaigen": "etwaig",
    "etwaiger": "etwaig",
    "etwaiges": "etwaig",
    "euch": "sich",
    "euer": "sich",
    "euphemistischem": "euphemistisch",
    "euphemistischen": "euphemistisch",
    "euphemistischer": "euphemistisch",
    "euphemistisches": "euphemistisch",
    "euphorische": "euphorisch",
    "euphorischem": "euphorisch",
    "euphorischen": "euphorisch",
    "euphorischer": "euphorisch",
    "euphorischere": "euphorisch",
    "euphorischerem": "euphorisch",
    "euphorischeren": "euphorisch",
    "euphorischerer": "euphorisch",
    "euphorischeres": "euphorisch",
    "euphorisches": "euphorisch",
    "euphorischste": "euphorisch",
    "euphorischstem": "euphorisch",
    "euphorischsten": "euphorisch",
    "euphorischster": "euphorisch",
    "euphorischstes": "euphorisch",
    "eurasische": "eurasisch",
    "eurasischem": "eurasisch",
    "eurasischen": "eurasisch",
    "eurasischer": "eurasisch",
    "eurasisches": "eurasisch",
    "eure": "mein",
    "eurem": "mein",
    "euren": "mein",
    "eures": "mein",
    "euresgleichen": "meinesgleichen",
    "europäischem": "europäisch",
    "europäischen": "europäisch",
    "europäischer": "europäisch",
    "europäischere": "europäisch",
    "europäischerem": "europäisch",
    "europäischeren": "europäisch",
    "europäischerer": "europäisch",
    "europäischeres": "europäisch",
    "europäisches": "europäisch",
    "europäischste": "europäisch",
    "europäischstem": "europäisch",
    "europäischsten": "europäisch",
    "europäischster": "europäisch",
    "europäischstes": "europäisch",
    "europäisiere": "europäisieren",
    "europäisierend": "europäisieren",
    "europäisierende": "europäisierend",
    "europäisierendem": "europäisierend",
    "europäisierenden": "europäisierend",
    "europäisierender": "europäisierend",
    "europäisierendere": "europäisierend",
    "europäisierenderem": "europäisierend",
    "europäisierenderen": "europäisierend",
    "europäisierenderer": "europäisierend",
    "europäisierenderes": "europäisierend",
    "europäisierendes": "europäisierend",
    "europäisierendste": "europäisierend",
    "europäisierendstem": "europäisierend",
    "europäisierendsten": "europäisierend",
    "europäisierendster": "europäisierend",
    "europäisierendstes": "europäisierend",
    "europäisierest": "europäisieren",
    "europäisieret": "europäisieren",
    "europäisierst": "europäisieren",
    "europäisiert": "europäisieren",
    "europäisierte": "europäisieren",
    "europäisiertem": "europäisiert",
    "europäisierten": "europäisieren",
    "europäisierter": "europäisiert",
    "europäisiertere": "europäisiert",
    "europäisierterem": "europäisiert",
    "europäisierteren": "europäisiert",
    "europäisierterer": "europäisiert",
    "europäisierteres": "europäisiert",
    "europäisiertes": "europäisiert",
    "europäisiertest": "europäisieren",
    "europäisierteste": "europäisiert",
    "europäisiertestem": "europäisiert",
    "europäisiertesten": "europäisiert",
    "europäisiertester": "europäisiert",
    "europäisiertestes": "europäisiert",
    "europäisiertet": "europäisieren",
    "evakuiere": "evakuieren",
    "evakuierend": "evakuieren",
    "evakuierende": "evakuierend",
    "evakuierendem": "evakuierend",
    "evakuierenden": "evakuierend",
    "evakuierender": "evakuierend",
    "evakuierendes": "evakuierend",
    "evakuierest": "evakuieren",
    "evakuieret": "evakuieren",
    "evakuierst": "evakuieren",
    "evakuiert": "evakuieren",
    "evakuierte": "evakuieren",
    "evakuiertem": "evakuiert",
    "evakuierten": "evakuieren",
    "evakuierter": "evakuiert",
    "evakuiertes": "evakuiert",
    "evakuiertest": "evakuieren",
    "evakuiertet": "evakuieren",
    "evangelischem": "evangelisch",
    "evangelischen": "evangelisch",
    "evangelischer": "evangelisch",
    "evangelischere": "evangelisch",
    "evangelischerem": "evangelisch",
    "evangelischeren": "evangelisch",
    "evangelischerer": "evangelisch",
    "evangelischeres": "evangelisch",
    "evangelisches": "evangelisch",
    "evangelischste": "evangelisch",
    "evangelischstem": "evangelisch",
    "evangelischsten": "evangelisch",
    "evangelischster": "evangelisch",
    "evangelischstes": "evangelisch",
    "evangelistische": "evangelistisch",
    "evangelistischem": "evangelistisch",
    "evangelistischen": "evangelistisch",
    "evangelistischer": "evangelistisch",
    "evangelistisches": "evangelistisch",
    "eventuellem": "eventuell",
    "eventuellen": "eventuell",
    "eventueller": "eventuell",
    "eventuelles": "eventuell",
    "ewigem": "ewig",
    "ewigen": "ewig",
    "ewiger": "ewig",
    "ewiges": "ewig",
    "ewiglichem": "ewiglich",
    "ewiglichen": "ewiglich",
    "ewiglicher": "ewiglich",
    "ewigliches": "ewiglich",
    "exakte": "exakt",
    "exaktem": "exakt",
    "exakten": "exakt",
    "exakter": "exakt",
    "exaktere": "exakt",
    "exakterem": "exakt",
    "exakteren": "exakt",
    "exakterer": "exakt",
    "exakteres": "exakt",
    "exaktes": "exakt",
    "exakteste": "exakt",
    "exaktestem": "exakt",
    "exaktesten": "exakt",
    "exaktester": "exakt",
    "exaktestes": "exakt",
    "exekutiere": "exekutieren",
    "exekutierend": "exekutieren",
    "exekutierende": "exekutierend",
    "exekutierendem": "exekutierend",
    "exekutierenden": "exekutierend",
    "exekutierender": "exekutierend",
    "exekutierendes": "exekutierend",
    "exekutierest": "exekutieren",
    "exekutieret": "exekutieren",
    "exekutierst": "exekutieren",
    "exekutiert": "exekutieren",
    "exekutierte": "exekutieren",
    "exekutiertem": "exekutiert",
    "exekutierten": "exekutieren",
    "exekutierter": "exekutiert",
    "exekutiertes": "exekutiert",
    "exekutiertest": "exekutieren",
    "exekutiertet": "exekutieren",
    "exekutivem": "exekutiv",
    "exekutiven": "exekutiv",
    "exekutiver": "exekutiv",
    "exekutives": "exekutiv",
    "exemplarischem": "exemplarisch",
    "exemplarischen": "exemplarisch",
    "exemplarischer": "exemplarisch",
    "exemplarisches": "exemplarisch",
    "exerziere": "exerzieren",
    "exerzierend": "exerzieren",
    "exerzierende": "exerzierend",
    "exerzierendem": "exerzierend",
    "exerzierenden": "exerzierend",
    "exerzierender": "exerzierend",
    "exerzierendes": "exerzierend",
    "exerzierest": "exerzieren",
    "exerzieret": "exerzieren",
    "exerzierst": "exerzieren",
    "exerziert": "exerzieren",
    "exerzierte": "exerzieren",
    "exerziertem": "exerziert",
    "exerzierten": "exerzieren",
    "exerzierter": "exerziert",
    "exerziertes": "exerziert",
    "exerziertest": "exerzieren",
    "exerziertet": "exerzieren",
    "exhibiere": "exhibieren",
    "exhibierend": "exhibieren",
    "exhibierende": "exhibierend",
    "exhibierendem": "exhibierend",
    "exhibierenden": "exhibierend",
    "exhibierender": "exhibierend",
    "exhibierendes": "exhibierend",
    "exhibierest": "exhibieren",
    "exhibieret": "exhibieren",
    "exhibierst": "exhibieren",
    "exhibiert": "exhibieren",
    "exhibierte": "exhibieren",
    "exhibiertem": "exhibiert",
    "exhibierten": "exhibieren",
    "exhibierter": "exhibiert",
    "exhibiertes": "exhibiert",
    "exhibiertest": "exhibieren",
    "exhibiertet": "exhibieren",
    "exhumiere": "exhumieren",
    "exhumierend": "exhumieren",
    "exhumierende": "exhumierend",
    "exhumierendem": "exhumierend",
    "exhumierenden": "exhumierend",
    "exhumierender": "exhumierend",
    "exhumierendes": "exhumierend",
    "exhumierest": "exhumieren",
    "exhumieret": "exhumieren",
    "exhumierst": "exhumieren",
    "exhumiert": "exhumieren",
    "exhumierte": "exhumieren",
    "exhumiertem": "exhumiert",
    "exhumierten": "exhumieren",
    "exhumierter": "exhumiert",
    "exhumiertes": "exhumiert",
    "exhumiertest": "exhumieren",
    "exhumiertet": "exhumieren",
    "existentiellem": "existentiell",
    "existentiellen": "existentiell",
    "existentieller": "existentiell",
    "existentiellere": "existentiell",
    "existentiellerem": "existentiell",
    "existentielleren": "existentiell",
    "existentiellerer": "existentiell",
    "existentielleres": "existentiell",
    "existentielles": "existentiell",
    "existentiellste": "existentiell",
    "existentiellstem": "existentiell",
    "existentiellsten": "existentiell",
    "existentiellster": "existentiell",
    "existentiellstes": "existentiell",
    "existenzbedrohende": "existenzbedrohend",
    "existenzbedrohendem": "existenzbedrohend",
    "existenzbedrohenden": "existenzbedrohend",
    "existenzbedrohender": "existenzbedrohend",
    "existenzbedrohendere": "existenzbedrohend",
    "existenzbedrohenderem": "existenzbedrohend",
    "existenzbedrohenderen": "existenzbedrohend",
    "existenzbedrohenderer": "existenzbedrohend",
    "existenzbedrohenderes": "existenzbedrohend",
    "existenzbedrohendes": "existenzbedrohend",
    "existenzbedrohendste": "existenzbedrohend",
    "existenzbedrohendstem": "existenzbedrohend",
    "existenzbedrohendsten": "existenzbedrohend",
    "existenzbedrohendster": "existenzbedrohend",
    "existenzbedrohendstes": "existenzbedrohend",
    "existenzfähigem": "existenzfähig",
    "existenzfähigen": "existenzfähig",
    "existenzfähiger": "existenzfähig",
    "existenzfähigere": "existenzfähig",
    "existenzfähigerem": "existenzfähig",
    "existenzfähigeren": "existenzfähig",
    "existenzfähigerer": "existenzfähig",
    "existenzfähigeres": "existenzfähig",
    "existenzfähiges": "existenzfähig",
    "existenzfähigste": "existenzfähig",
    "existenzfähigstem": "existenzfähig",
    "existenzfähigsten": "existenzfähig",
    "existenzfähigster": "existenzfähig",
    "existenzfähigstes": "existenzfähig",
    "existenzielle": "existenziell",
    "existenziellem": "existenziell",
    "existenziellen": "existenziell",
    "existenzieller": "existenziell",
    "existenzielles": "existenziell",
    "existiere": "existieren",
    "existierend": "existieren",
    "existierende": "existierend",
    "existierendem": "existierend",
    "existierenden": "existierend",
    "existierender": "existierend",
    "existierendes": "existierend",
    "existierest": "existieren",
    "existieret": "existieren",
    "existierst": "existieren",
    "existiert": "existieren",
    "existierte": "existieren",
    "existiertem": "existiert",
    "existierten": "existieren",
    "existierter": "existiert",
    "existiertes": "existiert",
    "existiertest": "existieren",
    "existiertet": "existieren",
    "exklusivem": "exklusiv",
    "exklusiven": "exklusiv",
    "exklusiver": "exklusiv",
    "exklusivere": "exklusiv",
    "exklusiverem": "exklusiv",
    "exklusiveren": "exklusiv",
    "exklusiverer": "exklusiv",
    "exklusiveres": "exklusiv",
    "exklusives": "exklusiv",
    "exklusivste": "exklusiv",
    "exklusivstem": "exklusiv",
    "exklusivsten": "exklusiv",
    "exklusivster": "exklusiv",
    "exklusivstes": "exklusiv",
    "exorbitantem": "exorbitant",
    "exorbitanten": "exorbitant",
    "exorbitanter": "exorbitant",
    "exorbitantes": "exorbitant",
    "exotischem": "exotisch",
    "exotischen": "exotisch",
    "exotischer": "exotisch",
    "exotischere": "exotisch",
    "exotischerem": "exotisch",
    "exotischeren": "exotisch",
    "exotischerer": "exotisch",
    "exotischeres": "exotisch",
    "exotisches": "exotisch",
    "exotischste": "exotisch",
    "exotischstem": "exotisch",
    "exotischsten": "exotisch",
    "exotischster": "exotisch",
    "exotischstes": "exotisch",
    "expandiere": "expandieren",
    "expandierend": "expandieren",
    "expandierende": "expandierend",
    "expandierendem": "expandierend",
    "expandierenden": "expandierend",
    "expandierender": "expandierend",
    "expandierendere": "expandierend",
    "expandierenderem": "expandierend",
    "expandierenderen": "expandierend",
    "expandierenderer": "expandierend",
    "expandierenderes": "expandierend",
    "expandierendes": "expandierend",
    "expandierendste": "expandierend",
    "expandierendstem": "expandierend",
    "expandierendsten": "expandierend",
    "expandierendster": "expandierend",
    "expandierendstes": "expandierend",
    "expandierest": "expandieren",
    "expandieret": "expandieren",
    "expandierst": "expandieren",
    "expandiert": "expandieren",
    "expandierte": "expandieren",
    "expandiertem": "expandiert",
    "expandierten": "expandieren",
    "expandierter": "expandiert",
    "expandiertere": "expandiert",
    "expandierterem": "expandiert",
    "expandierteren": "expandiert",
    "expandierterer": "expandiert",
    "expandierteres": "expandiert",
    "expandiertes": "expandiert",
    "expandiertest": "expandieren",
    "expandierteste": "expandiert",
    "expandiertestem": "expandiert",
    "expandiertesten": "expandiert",
    "expandiertester": "expandiert",
    "expandiertestes": "expandiert",
    "expandiertet": "expandieren",
    "expansivem": "expansiv",
    "expansiven": "expansiv",
    "expansiver": "expansiv",
    "expansives": "expansiv",
    "expensivem": "expensiv",
    "expensiven": "expensiv",
    "expensiver": "expensiv",
    "expensivere": "expensiv",
    "expensiverem": "expensiv",
    "expensiveren": "expensiv",
    "expensiverer": "expensiv",
    "expensiveres": "expensiv",
    "expensives": "expensiv",
    "expensivste": "expensiv",
    "expensivstem": "expensiv",
    "expensivsten": "expensiv",
    "expensivster": "expensiv",
    "expensivstes": "expensiv",
    "experimentellem": "experimentell",
    "experimentellen": "experimentell",
    "experimenteller": "experimentell",
    "experimentelles": "experimentell",
    "experimentiere": "experimentieren",
    "experimentierend": "experimentieren",
    "experimentierende": "experimentierend",
    "experimentierendem": "experimentierend",
    "experimentierenden": "experimentierend",
    "experimentierender": "experimentierend",
    "experimentierendes": "experimentierend",
    "experimentierest": "experimentieren",
    "experimentieret": "experimentieren",
    "experimentierst": "experimentieren",
    "experimentiert": "experimentieren",
    "experimentierte": "experimentieren",
    "experimentiertem": "experimentiert",
    "experimentierten": "experimentieren",
    "experimentierter": "experimentiert",
    "experimentiertes": "experimentiert",
    "experimentiertest": "experimentieren",
    "experimentiertet": "experimentieren",
    "explaniere": "explanieren",
    "explanierend": "explanieren",
    "explanierende": "explanierend",
    "explanierendem": "explanierend",
    "explanierenden": "explanierend",
    "explanierender": "explanierend",
    "explanierendere": "explanierend",
    "explanierenderem": "explanierend",
    "explanierenderen": "explanierend",
    "explanierenderer": "explanierend",
    "explanierenderes": "explanierend",
    "explanierendes": "explanierend",
    "explanierendste": "explanierend",
    "explanierendstem": "explanierend",
    "explanierendsten": "explanierend",
    "explanierendster": "explanierend",
    "explanierendstes": "explanierend",
    "explanierest": "explanieren",
    "explanieret": "explanieren",
    "explanierst": "explanieren",
    "explaniert": "explanieren",
    "explanierte": "explanieren",
    "explaniertem": "explaniert",
    "explanierten": "explanieren",
    "explanierter": "explaniert",
    "explaniertere": "explaniert",
    "explanierterem": "explaniert",
    "explanierteren": "explaniert",
    "explanierterer": "explaniert",
    "explanierteres": "explaniert",
    "explaniertes": "explaniert",
    "explaniertest": "explanieren",
    "explanierteste": "explaniert",
    "explaniertestem": "explaniert",
    "explaniertesten": "explaniert",
    "explaniertester": "explaniert",
    "explaniertestes": "explaniert",
    "explaniertet": "explanieren",
    "expliziere": "explizieren",
    "explizierend": "explizieren",
    "explizierende": "explizierend",
    "explizierendem": "explizierend",
    "explizierenden": "explizierend",
    "explizierender": "explizierend",
    "explizierendes": "explizierend",
    "explizierest": "explizieren",
    "explizieret": "explizieren",
    "explizierst": "explizieren",
    "expliziert": "explizieren",
    "explizierte": "explizieren",
    "expliziertem": "expliziert",
    "explizierten": "explizieren",
    "explizierter": "expliziert",
    "expliziertes": "expliziert",
    "expliziertest": "explizieren",
    "expliziertet": "explizieren",
    "explizite": "explizit",
    "explizitem": "explizit",
    "expliziten": "explizit",
    "expliziter": "explizit",
    "explizites": "explizit",
    "explodiere": "explodieren",
    "explodierend": "explodieren",
    "explodierende": "explodierend",
    "explodierendem": "explodierend",
    "explodierenden": "explodierend",
    "explodierender": "explodierend",
    "explodierendere": "explodierend",
    "explodierenderem": "explodierend",
    "explodierenderen": "explodierend",
    "explodierenderer": "explodierend",
    "explodierenderes": "explodierend",
    "explodierendes": "explodierend",
    "explodierendste": "explodierend",
    "explodierendstem": "explodierend",
    "explodierendsten": "explodierend",
    "explodierendster": "explodierend",
    "explodierendstes": "explodierend",
    "explodierest": "explodieren",
    "explodieret": "explodieren",
    "explodierst": "explodieren",
    "explodiert": "explodieren",
    "explodierte": "explodieren",
    "explodiertem": "explodiert",
    "explodierten": "explodieren",
    "explodierter": "explodiert",
    "explodiertere": "explodiert",
    "explodierterem": "explodiert",
    "explodierteren": "explodiert",
    "explodierterer": "explodiert",
    "explodierteres": "explodiert",
    "explodiertes": "explodiert",
    "explodiertest": "explodieren",
    "explodierteste": "explodiert",
    "explodiertestem": "explodiert",
    "explodiertesten": "explodiert",
    "explodiertester": "explodiert",
    "explodiertestes": "explodiert",
    "explodiertet": "explodieren",
    "exploriere": "explorieren",
    "explorierend": "explorieren",
    "explorierende": "explorierend",
    "explorierendem": "explorierend",
    "explorierenden": "explorierend",
    "explorierender": "explorierend",
    "explorierendere": "explorierend",
    "explorierenderem": "explorierend",
    "explorierenderen": "explorierend",
    "explorierenderer": "explorierend",
    "explorierenderes": "explorierend",
    "explorierendes": "explorierend",
    "explorierendste": "explorierend",
    "explorierendstem": "explorierend",
    "explorierendsten": "explorierend",
    "explorierendster": "explorierend",
    "explorierendstes": "explorierend",
    "explorierest": "explorieren",
    "explorieret": "explorieren",
    "explorierst": "explorieren",
    "exploriert": "explorieren",
    "explorierte": "explorieren",
    "exploriertem": "exploriert",
    "explorierten": "explorieren",
    "explorierter": "exploriert",
    "exploriertere": "exploriert",
    "explorierterem": "exploriert",
    "explorierteren": "exploriert",
    "explorierterer": "exploriert",
    "explorierteres": "exploriert",
    "exploriertes": "exploriert",
    "exploriertest": "explorieren",
    "explorierteste": "exploriert",
    "exploriertestem": "exploriert",
    "exploriertesten": "exploriert",
    "exploriertester": "exploriert",
    "exploriertestes": "exploriert",
    "exploriertet": "explorieren",
    "explosivem": "explosiv",
    "explosiven": "explosiv",
    "explosiver": "explosiv",
    "explosivere": "explosiv",
    "explosiverem": "explosiv",
    "explosiveren": "explosiv",
    "explosiverer": "explosiv",
    "explosiveres": "explosiv",
    "explosives": "explosiv",
    "explosivste": "explosiv",
    "explosivstem": "explosiv",
    "explosivsten": "explosiv",
    "explosivster": "explosiv",
    "explosivstes": "explosiv",
    "exponentiellem": "exponentiell",
    "exponentiellen": "exponentiell",
    "exponentieller": "exponentiell",
    "exponentielles": "exponentiell",
    "exponiere": "exponieren",
    "exponierend": "exponieren",
    "exponierende": "exponierend",
    "exponierendem": "exponierend",
    "exponierenden": "exponierend",
    "exponierender": "exponierend",
    "exponierendes": "exponierend",
    "exponierest": "exponieren",
    "exponieret": "exponieren",
    "exponierst": "exponieren",
    "exponiert": "exponieren",
    "exponierte": "exponieren",
    "exponiertem": "exponiert",
    "exponierten": "exponieren",
    "exponierter": "exponiert",
    "exponiertes": "exponiert",
    "exponiertest": "exponieren",
    "exponiertet": "exponieren",
    "exportiere": "exportieren",
    "exportierend": "exportieren",
    "exportierende": "exportierend",
    "exportierendem": "exportierend",
    "exportierenden": "exportierend",
    "exportierender": "exportierend",
    "exportierendere": "exportierend",
    "exportierenderem": "exportierend",
    "exportierenderen": "exportierend",
    "exportierenderer": "exportierend",
    "exportierenderes": "exportierend",
    "exportierendes": "exportierend",
    "exportierendste": "exportierend",
    "exportierendstem": "exportierend",
    "exportierendsten": "exportierend",
    "exportierendster": "exportierend",
    "exportierendstes": "exportierend",
    "exportierest": "exportieren",
    "exportieret": "exportieren",
    "exportierst": "exportieren",
    "exportiert": "exportieren",
    "exportierte": "exportieren",
    "exportiertem": "exportiert",
    "exportierten": "exportieren",
    "exportierter": "exportiert",
    "exportiertere": "exportiert",
    "exportierterem": "exportiert",
    "exportierteren": "exportiert",
    "exportierterer": "exportiert",
    "exportierteres": "exportiert",
    "exportiertes": "exportiert",
    "exportiertest": "exportieren",
    "exportierteste": "exportiert",
    "exportiertestem": "exportiert",
    "exportiertesten": "exportiert",
    "exportiertester": "exportiert",
    "exportiertestes": "exportiert",
    "exportiertet": "exportieren",
    "expressionistischem": "expressionistisch",
    "expressionistischen": "expressionistisch",
    "expressionistischer": "expressionistisch",
    "expressionistisches": "expressionistisch",
    "expressive": "expressiv",
    "expressivem": "expressiv",
    "expressiven": "expressiv",
    "expressiver": "expressiv",
    "expressivere": "expressiv",
    "expressiverem": "expressiv",
    "expressiveren": "expressiv",
    "expressiverer": "expressiv",
    "expressiveres": "expressiv",
    "expressives": "expressiv",
    "expressivste": "expressiv",
    "expressivstem": "expressiv",
    "expressivsten": "expressiv",
    "expressivster": "expressiv",
    "expressivstes": "expressiv",
    "exquisite": "exquisit",
    "exquisitem": "exquisit",
    "exquisiten": "exquisit",
    "exquisiter": "exquisit",
    "exquisitere": "exquisit",
    "exquisiterem": "exquisit",
    "exquisiteren": "exquisit",
    "exquisiterer": "exquisit",
    "exquisiteres": "exquisit",
    "exquisites": "exquisit",
    "exquisiteste": "exquisit",
    "exquisitestem": "exquisit",
    "exquisitesten": "exquisit",
    "exquisitester": "exquisit",
    "exquisitestes": "exquisit",
    "extensivem": "extensiv",
    "extensiven": "extensiv",
    "extensiver": "extensiv",
    "extensivere": "extensiv",
    "extensiverem": "extensiv",
    "extensiveren": "extensiv",
    "extensiverer": "extensiv",
    "extensiveres": "extensiv",
    "extensives": "extensiv",
    "extensivste": "extensiv",
    "extensivstem": "extensiv",
    "extensivsten": "extensiv",
    "extensivster": "extensiv",
    "extensivstes": "extensiv",
    "externem": "extern",
    "externen": "extern",
    "externer": "extern",
    "externes": "extern",
    "exterritorialem": "exterritorial",
    "exterritorialen": "exterritorial",
    "exterritorialer": "exterritorial",
    "exterritoriales": "exterritorial",
    "extrafeinem": "extrafein",
    "extrafeinen": "extrafein",
    "extrafeiner": "extrafein",
    "extrafeines": "extrafein",
    "extragalaktische": "extragalaktisch",
    "extragalaktischem": "extragalaktisch",
    "extragalaktischen": "extragalaktisch",
    "extragalaktischer": "extragalaktisch",
    "extragalaktisches": "extragalaktisch",
    "extrahiere": "extrahieren",
    "extrahierend": "extrahieren",
    "extrahierende": "extrahierend",
    "extrahierendem": "extrahierend",
    "extrahierenden": "extrahierend",
    "extrahierender": "extrahierend",
    "extrahierendes": "extrahierend",
    "extrahierest": "extrahieren",
    "extrahieret": "extrahieren",
    "extrahierst": "extrahieren",
    "extrahiert": "extrahieren",
    "extrahierte": "extrahieren",
    "extrahiertem": "extrahiert",
    "extrahierten": "extrahieren",
    "extrahierter": "extrahiert",
    "extrahiertes": "extrahiert",
    "extrahiertest": "extrahieren",
    "extrahiertet": "extrahieren",
    "extrapolierend": "extrapolieren",
    "extrapolierende": "extrapolierend",
    "extrapolierendem": "extrapolierend",
    "extrapolierenden": "extrapolierend",
    "extrapolierender": "extrapolierend",
    "extrapolierendere": "extrapolierend",
    "extrapolierenderem": "extrapolierend",
    "extrapolierenderen": "extrapolierend",
    "extrapolierenderer": "extrapolierend",
    "extrapolierenderes": "extrapolierend",
    "extrapolierendes": "extrapolierend",
    "extrapolierendste": "extrapolierend",
    "extrapolierendstem": "extrapolierend",
    "extrapolierendsten": "extrapolierend",
    "extrapolierendster": "extrapolierend",
    "extrapolierendstes": "extrapolierend",
    "extrapolierest": "extrapolieren",
    "extrapolieret": "extrapolieren",
    "extrapolierst": "extrapolieren",
    "extrapoliert": "extrapolieren",
    "extrapolierte": "extrapolieren",
    "extrapoliertem": "extrapoliert",
    "extrapolierten": "extrapolieren",
    "extrapolierter": "extrapoliert",
    "extrapoliertere": "extrapoliert",
    "extrapolierterem": "extrapoliert",
    "extrapolierteren": "extrapoliert",
    "extrapolierterer": "extrapoliert",
    "extrapolierteres": "extrapoliert",
    "extrapoliertes": "extrapoliert",
    "extrapoliertest": "extrapolieren",
    "extrapolierteste": "extrapoliert",
    "extrapoliertestem": "extrapoliert",
    "extrapoliertesten": "extrapoliert",
    "extrapoliertester": "extrapoliert",
    "extrapoliertestes": "extrapoliert",
    "extrapoliertet": "extrapolieren",
    "extremem": "extrem",
    "extremen": "extrem",
    "extremer": "extrem",
    "extremere": "extrem",
    "extremerem": "extrem",
    "extremeren": "extrem",
    "extremerer": "extrem",
    "extremeres": "extrem",
    "extremes": "extrem",
    "extremistischem": "extremistisch",
    "extremistischen": "extremistisch",
    "extremistischer": "extremistisch",
    "extremistischere": "extremistisch",
    "extremistischerem": "extremistisch",
    "extremistischeren": "extremistisch",
    "extremistischerer": "extremistisch",
    "extremistischeres": "extremistisch",
    "extremistisches": "extremistisch",
    "extremistischste": "extremistisch",
    "extremistischstem": "extremistisch",
    "extremistischsten": "extremistisch",
    "extremistischster": "extremistisch",
    "extremistischstes": "extremistisch",
    "extremstem": "extrem",
    "extremsten": "extrem",
    "extremster": "extrem",
    "extremstes": "extrem",
    "extrinsischem": "extrinsisch",
    "extrinsischen": "extrinsisch",
    "extrinsischer": "extrinsisch",
    "extrinsisches": "extrinsisch",
    "exzellente": "exzellent",
    "exzellentem": "exzellent",
    "exzellenten": "exzellent",
    "exzellenter": "exzellent",
    "exzellentere": "exzellent",
    "exzellenterem": "exzellent",
    "exzellenteren": "exzellent",
    "exzellenterer": "exzellent",
    "exzellenteres": "exzellent",
    "exzellentes": "exzellent",
    "exzellenteste": "exzellent",
    "exzellentestem": "exzellent",
    "exzellentesten": "exzellent",
    "exzellentester": "exzellent",
    "exzellentestes": "exzellent",
    "exzessivem": "exzessiv",
    "exzessiven": "exzessiv",
    "exzessiver": "exzessiv",
    "exzessivere": "exzessiv",
    "exzessiverem": "exzessiv",
    "exzessiveren": "exzessiv",
    "exzessiverer": "exzessiv",
    "exzessiveres": "exzessiv",
    "exzessives": "exzessiv",
    "exzessivste": "exzessiv",
    "exzessivstem": "exzessiv",
    "exzessivsten": "exzessiv",
    "exzessivster": "exzessiv",
    "exzessivstes": "exzessiv",
    "eßbarem": "eßbar",
    "eßbaren": "eßbar",
    "eßbarer": "eßbar",
    "eßbarere": "eßbar",
    "eßbarerem": "eßbar",
    "eßbareren": "eßbar",
    "eßbarerer": "eßbar",
    "eßbareres": "eßbar",
    "eßbares": "eßbar",
    "eßbarste": "eßbar",
    "eßbarstem": "eßbar",
    "eßbarsten": "eßbar",
    "eßbarster": "eßbar",
    "eßbarstes": "eßbar",
    "eßgestörtem": "eßgestört",
    "eßgestörten": "eßgestört",
    "eßgestörter": "eßgestört",
    "eßgestörtere": "eßgestört",
    "eßgestörterem": "eßgestört",
    "eßgestörteren": "eßgestört",
    "eßgestörterer": "eßgestört",
    "eßgestörteres": "eßgestört",
    "eßgestörtes": "eßgestört",
    "eßgestörteste": "eßgestört",
    "eßgestörtestem": "eßgestört",
    "eßgestörtesten": "eßgestört",
    "eßgestörtester": "eßgestört",
    "eßgestörtestes": "eßgestört",
    "eßsüchtigem": "eßsüchtig",
    "eßsüchtigen": "eßsüchtig",
    "eßsüchtiger": "eßsüchtig",
    "eßsüchtigere": "eßsüchtig",
    "eßsüchtigerem": "eßsüchtig",
    "eßsüchtigeren": "eßsüchtig",
    "eßsüchtigerer": "eßsüchtig",
    "eßsüchtigeres": "eßsüchtig",
    "eßsüchtiges": "eßsüchtig",
    "eßsüchtigste": "eßsüchtig",
    "eßsüchtigstem": "eßsüchtig",
    "eßsüchtigsten": "eßsüchtig",
    "eßsüchtigster": "eßsüchtig",
    "eßsüchtigstes": "eßsüchtig",
    "eßt": "essen",
    "fabelhaftem": "fabelhaft",
    "fabelhaften": "fabelhaft",
    "fabelhafter": "fabelhaft",
    "fabelhaftere": "fabelhaft",
    "fabelhafterem": "fabelhaft",
    "fabelhafteren": "fabelhaft",
    "fabelhafterer": "fabelhaft",
    "fabelhafteres": "fabelhaft",
    "fabelhaftes": "fabelhaft",
    "fabelhafteste": "fabelhaft",
    "fabelhaftestem": "fabelhaft",
    "fabelhaftesten": "fabelhaft",
    "fabelhaftester": "fabelhaft",
    "fabelhaftestes": "fabelhaft",
    "fabulösem": "fabulös",
    "fabulösen": "fabulös",
    "fabulöser": "fabulös",
    "fabulöses": "fabulös",
    "fachend": "fachen",
    "fachende": "fachend",
    "fachendem": "fachend",
    "fachenden": "fachend",
    "fachender": "fachend",
    "fachendere": "fachend",
    "fachenderem": "fachend",
    "fachenderen": "fachend",
    "fachenderer": "fachend",
    "fachenderes": "fachend",
    "fachendes": "fachend",
    "fachendste": "fachend",
    "fachendstem": "fachend",
    "fachendsten": "fachend",
    "fachendster": "fachend",
    "fachendstes": "fachend",
    "fachest": "fachen",
    "fachet": "fachen",
    "fachfremde": "fachfremd",
    "fachfremdem": "fachfremd",
    "fachfremden": "fachfremd",
    "fachfremder": "fachfremd",
    "fachfremdes": "fachfremd",
    "fachgemäße": "fachgemäß",
    "fachgemäßem": "fachgemäß",
    "fachgemäßen": "fachgemäß",
    "fachgemäßer": "fachgemäß",
    "fachgemäßes": "fachgemäß",
    "fachgerechtem": "fachgerecht",
    "fachgerechten": "fachgerecht",
    "fachgerechter": "fachgerecht",
    "fachgerechtere": "fachgerecht",
    "fachgerechterem": "fachgerecht",
    "fachgerechteren": "fachgerecht",
    "fachgerechterer": "fachgerecht",
    "fachgerechteres": "fachgerecht",
    "fachgerechtes": "fachgerecht",
    "fachgerechteste": "fachgerecht",
    "fachgerechtestem": "fachgerecht",
    "fachgerechtesten": "fachgerecht",
    "fachgerechtester": "fachgerecht",
    "fachgerechtestes": "fachgerecht",
    "fachkundige": "fachkundig",
    "fachkundigem": "fachkundig",
    "fachkundigen": "fachkundig",
    "fachkundiger": "fachkundig",
    "fachkundigere": "fachkundig",
    "fachkundigerem": "fachkundig",
    "fachkundigeren": "fachkundig",
    "fachkundigerer": "fachkundig",
    "fachkundigeres": "fachkundig",
    "fachkundiges": "fachkundig",
    "fachkundigste": "fachkundig",
    "fachkundigstem": "fachkundig",
    "fachkundigsten": "fachkundig",
    "fachkundigster": "fachkundig",
    "fachkundigstes": "fachkundig",
    "fachlichem": "fachlich",
    "fachlichen": "fachlich",
    "fachlicher": "fachlich",
    "fachliches": "fachlich",
    "fachmännische": "fachmännisch",
    "fachmännischem": "fachmännisch",
    "fachmännischen": "fachmännisch",
    "fachmännischer": "fachmännisch",
    "fachmännischere": "fachmännisch",
    "fachmännischerem": "fachmännisch",
    "fachmännischeren": "fachmännisch",
    "fachmännischerer": "fachmännisch",
    "fachmännischeres": "fachmännisch",
    "fachmännisches": "fachmännisch",
    "fachmännischste": "fachmännisch",
    "fachmännischstem": "fachmännisch",
    "fachmännischsten": "fachmännisch",
    "fachmännischster": "fachmännisch",
    "fachmännischstes": "fachmännisch",
    "fachst": "fachen",
    "facht": "fachen",
    "fachte": "fachen",
    "fachten": "fachen",
    "fachtest": "fachen",
    "fachtet": "fachen",
    "fachärztlichem": "fachärztlich",
    "fachärztlichen": "fachärztlich",
    "fachärztlicher": "fachärztlich",
    "fachärztliches": "fachärztlich",
    "fadem": "fad",
    "faden": "fad",
    "fadenscheinigem": "fadenscheinig",
    "fadenscheinigen": "fadenscheinig",
    "fadenscheiniger": "fadenscheinig",
    "fadenscheinigere": "fadenscheinig",
    "fadenscheinigerem": "fadenscheinig",
    "fadenscheinigeren": "fadenscheinig",
    "fadenscheinigerer": "fadenscheinig",
    "fadenscheinigeres": "fadenscheinig",
    "fadenscheiniges": "fadenscheinig",
    "fadenscheinigste": "fadenscheinig",
    "fadenscheinigstem": "fadenscheinig",
    "fadenscheinigsten": "fadenscheinig",
    "fadenscheinigster": "fadenscheinig",
    "fadenscheinigstes": "fadenscheinig",
    "fader": "fad",
    "fadere": "fad",
    "faderem": "fad",
    "faderen": "fad",
    "faderer": "fad",
    "faderes": "fad",
    "fades": "fad",
    "fadeste": "fad",
    "fadestem": "fad",
    "fadesten": "fad",
    "fadester": "fad",
    "fadestes": "fad",
    "fahle": "fahl",
    "fahlem": "fahl",
    "fahlen": "fahl",
    "fahler": "fahl",
    "fahlere": "fahl",
    "fahlerem": "fahl",
    "fahleren": "fahl",
    "fahlerer": "fahl",
    "fahleres": "fahl",
    "fahles": "fahl",
    "fahlste": "fahl",
    "fahlstem": "fahl",
    "fahlsten": "fahl",
    "fahlster": "fahl",
    "fahlstes": "fahl",
    "fahnde": "fahnden",
    "fahndend": "fahnden",
    "fahndende": "fahndend",
    "fahndendem": "fahndend",
    "fahndenden": "fahndend",
    "fahndender": "fahndend",
    "fahndendes": "fahndend",
    "fahndest": "fahnden",
    "fahndet": "fahnden",
    "fahndete": "fahnden",
    "fahndeten": "fahnden",
    "fahndetest": "fahnden",
    "fahndetet": "fahnden",
    "fahnenflüchtigem": "fahnenflüchtig",
    "fahnenflüchtigen": "fahnenflüchtig",
    "fahnenflüchtiger": "fahnenflüchtig",
    "fahnenflüchtiges": "fahnenflüchtig",
    "fahrbarem": "fahrbar",
    "fahrbaren": "fahrbar",
    "fahrbarer": "fahrbar",
    "fahrbarere": "fahrbar",
    "fahrbarerem": "fahrbar",
    "fahrbareren": "fahrbar",
    "fahrbarerer": "fahrbar",
    "fahrbareres": "fahrbar",
    "fahrbares": "fahrbar",
    "fahrbarste": "fahrbar",
    "fahrbarstem": "fahrbar",
    "fahrbarsten": "fahrbar",
    "fahrbarster": "fahrbar",
    "fahrbarstes": "fahrbar",
    "fahrbereite": "fahrbereit",
    "fahrbereitem": "fahrbereit",
    "fahrbereiten": "fahrbereit",
    "fahrbereiter": "fahrbereit",
    "fahrbereites": "fahrbereit",
    "fahre": "fahren",
    "fahrend": "fahren",
    "fahrende": "fahrend",
    "fahrendem": "fahrend",
    "fahrenden": "fahrend",
    "fahrender": "fahrend",
    "fahrendes": "fahrend",
    "fahrest": "fahren",
    "fahret": "fahren",
    "fahrlässigem": "fahrlässig",
    "fahrlässigen": "fahrlässig",
    "fahrlässiger": "fahrlässig",
    "fahrlässigere": "fahrlässig",
    "fahrlässigerem": "fahrlässig",
    "fahrlässigeren": "fahrlässig",
    "fahrlässigerer": "fahrlässig",
    "fahrlässigeres": "fahrlässig",
    "fahrlässiges": "fahrlässig",
    "fahrlässigste": "fahrlässig",
    "fahrlässigstem": "fahrlässig",
    "fahrlässigsten": "fahrlässig",
    "fahrlässigster": "fahrlässig",
    "fahrlässigstes": "fahrlässig",
    "fahrplanmäßigem": "fahrplanmäßig",
    "fahrplanmäßigen": "fahrplanmäßig",
    "fahrplanmäßiger": "fahrplanmäßig",
    "fahrplanmäßiges": "fahrplanmäßig",
    "fahrtüchtigem": "fahrtüchtig",
    "fahrtüchtigen": "fahrtüchtig",
    "fahrtüchtiger": "fahrtüchtig",
    "fahrtüchtigere": "fahrtüchtig",
    "fahrtüchtigerem": "fahrtüchtig",
    "fahrtüchtigeren": "fahrtüchtig",
    "fahrtüchtigerer": "fahrtüchtig",
    "fahrtüchtigeres": "fahrtüchtig",
    "fahrtüchtiges": "fahrtüchtig",
    "fahrtüchtigste": "fahrtüchtig",
    "fahrtüchtigstem": "fahrtüchtig",
    "fahrtüchtigsten": "fahrtüchtig",
    "fahrtüchtigster": "fahrtüchtig",
    "fahrtüchtigstes": "fahrtüchtig",
    "fahruntüchtige": "fahruntüchtig",
    "fahruntüchtigem": "fahruntüchtig",
    "fahruntüchtigen": "fahruntüchtig",
    "fahruntüchtiger": "fahruntüchtig",
    "fahruntüchtigere": "fahruntüchtig",
    "fahruntüchtigerem": "fahruntüchtig",
    "fahruntüchtigeren": "fahruntüchtig",
    "fahruntüchtigerer": "fahruntüchtig",
    "fahruntüchtigeres": "fahruntüchtig",
    "fahruntüchtiges": "fahruntüchtig",
    "fahruntüchtigste": "fahruntüchtig",
    "fahruntüchtigstem": "fahruntüchtig",
    "fahruntüchtigsten": "fahruntüchtig",
    "fahruntüchtigster": "fahruntüchtig",
    "fahruntüchtigstes": "fahruntüchtig",
    "fairem": "fair",
    "fairen": "fair",
    "fairer": "fair",
    "fairere": "fair",
    "fairerem": "fair",
    "faireren": "fair",
    "fairerer": "fair",
    "faireres": "fair",
    "faires": "fair",
    "fairste": "fair",
    "fairstem": "fair",
    "fairsten": "fair",
    "fairster": "fair",
    "fairstes": "fair",
    "faktischem": "faktisch",
    "faktischen": "faktisch",
    "faktischer": "faktisch",
    "faktisches": "faktisch",
    "fakturiere": "fakturieren",
    "fakturierend": "fakturieren",
    "fakturierende": "fakturierend",
    "fakturierendem": "fakturierend",
    "fakturierenden": "fakturierend",
    "fakturierender": "fakturierend",
    "fakturierendes": "fakturierend",
    "fakturierest": "fakturieren",
    "fakturieret": "fakturieren",
    "fakturierst": "fakturieren",
    "fakturiert": "fakturieren",
    "fakturierte": "fakturieren",
    "fakturiertem": "fakturiert",
    "fakturierten": "fakturieren",
    "fakturierter": "fakturiert",
    "fakturiertes": "fakturiert",
    "fakturiertest": "fakturieren",
    "fakturiertet": "fakturieren",
    "fakultativem": "fakultativ",
    "fakultativen": "fakultativ",
    "fakultativer": "fakultativ",
    "fakultatives": "fakultativ",
    "fallend": "fallen",
    "fallende": "fallend",
    "fallendem": "fallend",
    "fallenden": "fallend",
    "fallender": "fallend",
    "fallendes": "fallend",
    "fallest": "fallen",
    "fallet": "fallen",
    "fallt": "fallen",
    "falsche": "falsch",
    "falschem": "falsch",
    "falschen": "falsch",
    "falscher": "falsch",
    "falschere": "falsch",
    "falscherem": "falsch",
    "falscheren": "falsch",
    "falscherer": "falsch",
    "falscheres": "falsch",
    "falsches": "falsch",
    "falscheste": "falsch",
    "falschestem": "falsch",
    "falschesten": "falsch",
    "falschester": "falsch",
    "falschestes": "falsch",
    "falschgläubigem": "falschgläubig",
    "falschgläubigen": "falschgläubig",
    "falschgläubiger": "falschgläubig",
    "falschgläubiges": "falschgläubig",
    "falsifiziere": "falsifizieren",
    "falsifizierend": "falsifizieren",
    "falsifizierende": "falsifizierend",
    "falsifizierendem": "falsifizierend",
    "falsifizierenden": "falsifizierend",
    "falsifizierender": "falsifizierend",
    "falsifizierendes": "falsifizierend",
    "falsifizierest": "falsifizieren",
    "falsifizieret": "falsifizieren",
    "falsifizierst": "falsifizieren",
    "falsifiziert": "falsifizieren",
    "falsifizierte": "falsifizieren",
    "falsifiziertem": "falsifiziert",
    "falsifizierten": "falsifizieren",
    "falsifizierter": "falsifiziert",
    "falsifiziertes": "falsifiziert",
    "falsifiziertest": "falsifizieren",
    "falsifiziertet": "falsifizieren",
    "faltend": "falten",
    "faltende": "faltend",
    "faltendem": "faltend",
    "faltenden": "faltend",
    "faltender": "faltend",
    "faltendes": "faltend",
    "faltenlose": "faltenlos",
    "faltenlosem": "faltenlos",
    "faltenlosen": "faltenlos",
    "faltenloser": "faltenlos",
    "faltenlosere": "faltenlos",
    "faltenloserem": "faltenlos",
    "faltenloseren": "faltenlos",
    "faltenloserer": "faltenlos",
    "faltenloseres": "faltenlos",
    "faltenloses": "faltenlos",
    "faltenloseste": "faltenlos",
    "faltenlosestem": "faltenlos",
    "faltenlosesten": "faltenlos",
    "faltenlosester": "faltenlos",
    "faltenlosestes": "faltenlos",
    "faltenreiche": "faltenreich",
    "faltenreichem": "faltenreich",
    "faltenreichen": "faltenreich",
    "faltenreicher": "faltenreich",
    "faltenreichere": "faltenreich",
    "faltenreicherem": "faltenreich",
    "faltenreicheren": "faltenreich",
    "faltenreicherer": "faltenreich",
    "faltenreicheres": "faltenreich",
    "faltenreiches": "faltenreich",
    "faltenreichste": "faltenreich",
    "faltenreichstem": "faltenreich",
    "faltenreichsten": "faltenreich",
    "faltenreichster": "faltenreich",
    "faltenreichstes": "faltenreich",
    "faltest": "falten",
    "faltet": "falten",
    "faltete": "falten",
    "falteten": "falten",
    "faltetest": "falten",
    "faltetet": "falten",
    "faltige": "faltig",
    "faltigem": "faltig",
    "faltigen": "faltig",
    "faltiger": "faltig",
    "faltigere": "faltig",
    "faltigerem": "faltig",
    "faltigeren": "faltig",
    "faltigerer": "faltig",
    "faltigeres": "faltig",
    "faltiges": "faltig",
    "faltigste": "faltig",
    "faltigstem": "faltig",
    "faltigsten": "faltig",
    "faltigster": "faltig",
    "faltigstes": "faltig",
    "falze": "falzen",
    "falzend": "falzen",
    "falzende": "falzend",
    "falzendem": "falzend",
    "falzenden": "falzend",
    "falzender": "falzend",
    "falzendes": "falzend",
    "falzest": "falzen",
    "falzet": "falzen",
    "falzige": "falzig",
    "falzigem": "falzig",
    "falzigen": "falzig",
    "falziger": "falzig",
    "falzigere": "falzig",
    "falzigerem": "falzig",
    "falzigeren": "falzig",
    "falzigerer": "falzig",
    "falzigeres": "falzig",
    "falziges": "falzig",
    "falzigste": "falzig",
    "falzigstem": "falzig",
    "falzigsten": "falzig",
    "falzigster": "falzig",
    "falzigstes": "falzig",
    "falzt": "falzen",
    "falzte": "falzen",
    "falzten": "falzen",
    "falztest": "falzen",
    "falztet": "falzen",
    "familiengerechtem": "familiengerecht",
    "familiengerechten": "familiengerecht",
    "familiengerechter": "familiengerecht",
    "familiengerechtere": "familiengerecht",
    "familiengerechterem": "familiengerecht",
    "familiengerechteren": "familiengerecht",
    "familiengerechterer": "familiengerecht",
    "familiengerechteres": "familiengerecht",
    "familiengerechtes": "familiengerecht",
    "familiengerechteste": "familiengerecht",
    "familiengerechtestem": "familiengerecht",
    "familiengerechtesten": "familiengerecht",
    "familiengerechtester": "familiengerecht",
    "familiengerechtestes": "familiengerecht",
    "familiäre": "familiär",
    "familiärem": "familiär",
    "familiären": "familiär",
    "familiärer": "familiär",
    "familiärere": "familiär",
    "familiärerem": "familiär",
    "familiäreren": "familiär",
    "familiärerer": "familiär",
    "familiäreres": "familiär",
    "familiäres": "familiär",
    "familiärste": "familiär",
    "familiärstem": "familiär",
    "familiärsten": "familiär",
    "familiärster": "familiär",
    "familiärstes": "familiär",
    "famose": "famos",
    "famosem": "famos",
    "famosen": "famos",
    "famoser": "famos",
    "famosere": "famos",
    "famoserem": "famos",
    "famoseren": "famos",
    "famoserer": "famos",
    "famoseres": "famos",
    "famoses": "famos",
    "famoseste": "famos",
    "famosestem": "famos",
    "famosesten": "famos",
    "famosester": "famos",
    "famosestes": "famos",
    "fanatischem": "fanatisch",
    "fanatischen": "fanatisch",
    "fanatischer": "fanatisch",
    "fanatischere": "fanatisch",
    "fanatischerem": "fanatisch",
    "fanatischeren": "fanatisch",
    "fanatischerer": "fanatisch",
    "fanatischeres": "fanatisch",
    "fanatisches": "fanatisch",
    "fanatischste": "fanatisch",
    "fanatischstem": "fanatisch",
    "fanatischsten": "fanatisch",
    "fanatischster": "fanatisch",
    "fanatischstes": "fanatisch",
    "fand": "finden",
    "fanden": "finden",
    "fandest": "finden",
    "fandet": "finden",
    "fangend": "fangen",
    "fangende": "fangend",
    "fangendem": "fangend",
    "fangenden": "fangend",
    "fangender": "fangend",
    "fangendes": "fangend",
    "fangest": "fangen",
    "fanget": "fangen",
    "fangt": "fangen",
    "fantastischem": "fantastisch",
    "fantastischen": "fantastisch",
    "fantastischer": "fantastisch",
    "fantastischere": "fantastisch",
    "fantastischerem": "fantastisch",
    "fantastischeren": "fantastisch",
    "fantastischerer": "fantastisch",
    "fantastischeres": "fantastisch",
    "fantastisches": "fantastisch",
    "fantastischste": "fantastisch",
    "fantastischstem": "fantastisch",
    "fantastischsten": "fantastisch",
    "fantastischster": "fantastisch",
    "fantastischstes": "fantastisch",
    "farbechte": "farbecht",
    "farbechtem": "farbecht",
    "farbechten": "farbecht",
    "farbechter": "farbecht",
    "farbechtere": "farbecht",
    "farbechterem": "farbecht",
    "farbechteren": "farbecht",
    "farbechterer": "farbecht",
    "farbechteres": "farbecht",
    "farbechtes": "farbecht",
    "farbechteste": "farbecht",
    "farbechtestem": "farbecht",
    "farbechtesten": "farbecht",
    "farbechtester": "farbecht",
    "farbechtestes": "farbecht",
    "farbempfindliche": "farbempfindlich",
    "farbempfindlichem": "farbempfindlich",
    "farbempfindlichen": "farbempfindlich",
    "farbempfindlicher": "farbempfindlich",
    "farbempfindlichere": "farbempfindlich",
    "farbempfindlicherem": "farbempfindlich",
    "farbempfindlicheren": "farbempfindlich",
    "farbempfindlicherer": "farbempfindlich",
    "farbempfindlicheres": "farbempfindlich",
    "farbempfindliches": "farbempfindlich",
    "farbempfindlichste": "farbempfindlich",
    "farbempfindlichstem": "farbempfindlich",
    "farbempfindlichsten": "farbempfindlich",
    "farbempfindlichster": "farbempfindlich",
    "farbempfindlichstes": "farbempfindlich",
    "farbenblindem": "farbenblind",
    "farbenblinden": "farbenblind",
    "farbenblinder": "farbenblind",
    "farbenblindes": "farbenblind",
    "farbenfreudige": "farbenfreudig",
    "farbenfreudigem": "farbenfreudig",
    "farbenfreudigen": "farbenfreudig",
    "farbenfreudiger": "farbenfreudig",
    "farbenfreudigere": "farbenfreudig",
    "farbenfreudigerem": "farbenfreudig",
    "farbenfreudigeren": "farbenfreudig",
    "farbenfreudigerer": "farbenfreudig",
    "farbenfreudigeres": "farbenfreudig",
    "farbenfreudiges": "farbenfreudig",
    "farbenfreudigste": "farbenfreudig",
    "farbenfreudigstem": "farbenfreudig",
    "farbenfreudigsten": "farbenfreudig",
    "farbenfreudigster": "farbenfreudig",
    "farbenfreudigstes": "farbenfreudig",
    "farbenfrohe": "farbenfroh",
    "farbenfrohem": "farbenfroh",
    "farbenfrohen": "farbenfroh",
    "farbenfroher": "farbenfroh",
    "farbenfrohere": "farbenfroh",
    "farbenfroherem": "farbenfroh",
    "farbenfroheren": "farbenfroh",
    "farbenfroherer": "farbenfroh",
    "farbenfroheres": "farbenfroh",
    "farbenfrohes": "farbenfroh",
    "farbenfrohste": "farbenfroh",
    "farbenfrohstem": "farbenfroh",
    "farbenfrohsten": "farbenfroh",
    "farbenfrohster": "farbenfroh",
    "farbenfrohstes": "farbenfroh",
    "farbenprächtige": "farbenprächtig",
    "farbenprächtigem": "farbenprächtig",
    "farbenprächtigen": "farbenprächtig",
    "farbenprächtiger": "farbenprächtig",
    "farbenprächtigere": "farbenprächtig",
    "farbenprächtigerem": "farbenprächtig",
    "farbenprächtigeren": "farbenprächtig",
    "farbenprächtigerer": "farbenprächtig",
    "farbenprächtigeres": "farbenprächtig",
    "farbenprächtiges": "farbenprächtig",
    "farbenprächtigste": "farbenprächtig",
    "farbenprächtigstem": "farbenprächtig",
    "farbenprächtigsten": "farbenprächtig",
    "farbenprächtigster": "farbenprächtig",
    "farbenprächtigstes": "farbenprächtig",
    "farbenreiche": "farbenreich",
    "farbenreichem": "farbenreich",
    "farbenreichen": "farbenreich",
    "farbenreicher": "farbenreich",
    "farbenreichere": "farbenreich",
    "farbenreicherem": "farbenreich",
    "farbenreicheren": "farbenreich",
    "farbenreicherer": "farbenreich",
    "farbenreicheres": "farbenreich",
    "farbenreiches": "farbenreich",
    "farbenreichste": "farbenreich",
    "farbenreichstem": "farbenreich",
    "farbenreichsten": "farbenreich",
    "farbenreichster": "farbenreich",
    "farbenreichstes": "farbenreich",
    "farbigem": "farbig",
    "farbigen": "farbig",
    "farbiger": "farbig",
    "farbigere": "farbig",
    "farbigerem": "farbig",
    "farbigeren": "farbig",
    "farbigerer": "farbig",
    "farbigeres": "farbig",
    "farbiges": "farbig",
    "farbigste": "farbig",
    "farbigstem": "farbig",
    "farbigsten": "farbig",
    "farbigster": "farbig",
    "farbigstes": "farbig",
    "farblosem": "farblos",
    "farblosen": "farblos",
    "farbloser": "farblos",
    "farblosere": "farblos",
    "farbloserem": "farblos",
    "farbloseren": "farblos",
    "farbloserer": "farblos",
    "farbloseres": "farblos",
    "farbloses": "farblos",
    "farbloseste": "farblos",
    "farblosestem": "farblos",
    "farblosesten": "farblos",
    "farblosester": "farblos",
    "farblosestes": "farblos",
    "faschistischem": "faschistisch",
    "faschistischen": "faschistisch",
    "faschistischer": "faschistisch",
    "faschistisches": "faschistisch",
    "faschistoide": "faschistoid",
    "faschistoidem": "faschistoid",
    "faschistoiden": "faschistoid",
    "faschistoider": "faschistoid",
    "faschistoidere": "faschistoid",
    "faschistoiderem": "faschistoid",
    "faschistoideren": "faschistoid",
    "faschistoiderer": "faschistoid",
    "faschistoideres": "faschistoid",
    "faschistoides": "faschistoid",
    "faschistoideste": "faschistoid",
    "faschistoidestem": "faschistoid",
    "faschistoidesten": "faschistoid",
    "faschistoidester": "faschistoid",
    "faschistoidestes": "faschistoid",
    "fasele": "faseln",
    "faselnd": "faseln",
    "faselnde": "faselnd",
    "faselndem": "faselnd",
    "faselnden": "faselnd",
    "faselnder": "faselnd",
    "faselndere": "faselnd",
    "faselnderem": "faselnd",
    "faselnderen": "faselnd",
    "faselnderer": "faselnd",
    "faselnderes": "faselnd",
    "faselndes": "faselnd",
    "faselndste": "faselnd",
    "faselndstem": "faselnd",
    "faselndsten": "faselnd",
    "faselndster": "faselnd",
    "faselndstes": "faselnd",
    "faselst": "faseln",
    "faselt": "faseln",
    "faselte": "faseln",
    "faselten": "faseln",
    "faseltest": "faseln",
    "faseltet": "faseln",
    "fasere": "fasern",
    "faserige": "faserig",
    "faserigem": "faserig",
    "faserigen": "faserig",
    "faseriger": "faserig",
    "faserigere": "faserig",
    "faserigerem": "faserig",
    "faserigeren": "faserig",
    "faserigerer": "faserig",
    "faserigeres": "faserig",
    "faseriges": "faserig",
    "faserigste": "faserig",
    "faserigstem": "faserig",
    "faserigsten": "faserig",
    "faserigster": "faserig",
    "faserigstes": "faserig",
    "fasernacktem": "fasernackt",
    "fasernackten": "fasernackt",
    "fasernackter": "fasernackt",
    "fasernacktes": "fasernackt",
    "fasernd": "fasern",
    "fasernde": "fasernd",
    "faserndem": "fasernd",
    "fasernden": "fasernd",
    "fasernder": "fasernd",
    "faserndere": "fasernd",
    "fasernderem": "fasernd",
    "fasernderen": "fasernd",
    "fasernderer": "fasernd",
    "fasernderes": "fasernd",
    "faserndes": "fasernd",
    "faserndste": "fasernd",
    "faserndstem": "fasernd",
    "faserndsten": "fasernd",
    "faserndster": "fasernd",
    "faserndstes": "fasernd",
    "faserst": "fasern",
    "fasert": "fasern",
    "faserte": "fasern",
    "faserten": "fasern",
    "fasertest": "fasern",
    "fasertet": "fasern",
    "fasle": "faseln",
    "fassend": "fassen",
    "fassende": "fassend",
    "fassendem": "fassend",
    "fassenden": "fassend",
    "fassender": "fassend",
    "fassendes": "fassend",
    "fassest": "fassen",
    "fasset": "fassen",
    "fassungslosem": "fassungslos",
    "fassungslosen": "fassungslos",
    "fassungsloser": "fassungslos",
    "fassungslosere": "fassungslos",
    "fassungsloserem": "fassungslos",
    "fassungsloseren": "fassungslos",
    "fassungsloserer": "fassungslos",
    "fassungsloseres": "fassungslos",
    "fassungsloses": "fassungslos",
    "fassungsloseste": "fassungslos",
    "fassungslosestem": "fassungslos",
    "fassungslosesten": "fassungslos",
    "fassungslosester": "fassungslos",
    "fassungslosestes": "fassungslos",
    "faste": "fasten",
    "fastend": "fasten",
    "fastende": "fastend",
    "fastendem": "fastend",
    "fastenden": "fastend",
    "fastender": "fastend",
    "fastendere": "fastend",
    "fastenderem": "fastend",
    "fastenderen": "fastend",
    "fastenderer": "fastend",
    "fastenderes": "fastend",
    "fastendes": "fastend",
    "fastendste": "fastend",
    "fastendstem": "fastend",
    "fastendsten": "fastend",
    "fastendster": "fastend",
    "fastendstes": "fastend",
    "fastest": "fasten",
    "fastet": "fasten",
    "fastete": "fasten",
    "fasteten": "fasten",
    "fastetest": "fasten",
    "fastetet": "fasten",
    "fasziniere": "faszinieren",
    "faszinierend": "faszinieren",
    "faszinierende": "faszinierend",
    "faszinierendem": "faszinierend",
    "faszinierenden": "faszinierend",
    "faszinierender": "faszinierend",
    "faszinierendere": "faszinierend",
    "faszinierenderem": "faszinierend",
    "faszinierenderen": "faszinierend",
    "faszinierenderer": "faszinierend",
    "faszinierenderes": "faszinierend",
    "faszinierendes": "faszinierend",
    "faszinierendste": "faszinierend",
    "faszinierendstem": "faszinierend",
    "faszinierendsten": "faszinierend",
    "faszinierendster": "faszinierend",
    "faszinierendstes": "faszinierend",
    "faszinierest": "faszinieren",
    "faszinieret": "faszinieren",
    "faszinierst": "faszinieren",
    "fasziniert": "faszinieren",
    "faszinierte": "faszinieren",
    "fasziniertem": "fasziniert",
    "faszinierten": "faszinieren",
    "faszinierter": "fasziniert",
    "fasziniertere": "fasziniert",
    "faszinierterem": "fasziniert",
    "faszinierteren": "fasziniert",
    "faszinierterer": "fasziniert",
    "faszinierteres": "fasziniert",
    "fasziniertes": "fasziniert",
    "fasziniertest": "faszinieren",
    "faszinierteste": "fasziniert",
    "fasziniertestem": "fasziniert",
    "fasziniertesten": "fasziniert",
    "fasziniertester": "fasziniert",
    "fasziniertestes": "fasziniert",
    "fasziniertet": "faszinieren",
    "fatale": "fatal",
    "fatalem": "fatal",
    "fatalen": "fatal",
    "fataler": "fatal",
    "fatalere": "fatal",
    "fatalerem": "fatal",
    "fataleren": "fatal",
    "fatalerer": "fatal",
    "fataleres": "fatal",
    "fatales": "fatal",
    "fatalstem": "fatal",
    "fatalsten": "fatal",
    "fatalster": "fatal",
    "fatalstes": "fatal",
    "fatimidische": "fatimidisch",
    "fatimidischem": "fatimidisch",
    "fatimidischen": "fatimidisch",
    "fatimidischer": "fatimidisch",
    "fatimidischere": "fatimidisch",
    "fatimidischerem": "fatimidisch",
    "fatimidischeren": "fatimidisch",
    "fatimidischerer": "fatimidisch",
    "fatimidischeres": "fatimidisch",
    "fatimidisches": "fatimidisch",
    "fatimidischste": "fatimidisch",
    "fatimidischstem": "fatimidisch",
    "fatimidischsten": "fatimidisch",
    "fatimidischster": "fatimidisch",
    "fatimidischstes": "fatimidisch",
    "fauche": "fauchen",
    "fauchend": "fauchen",
    "fauchende": "fauchend",
    "fauchendem": "fauchend",
    "fauchenden": "fauchend",
    "fauchender": "fauchend",
    "fauchendere": "fauchend",
    "fauchenderem": "fauchend",
    "fauchenderen": "fauchend",
    "fauchenderer": "fauchend",
    "fauchenderes": "fauchend",
    "fauchendes": "fauchend",
    "fauchendste": "fauchend",
    "fauchendstem": "fauchend",
    "fauchendsten": "fauchend",
    "fauchendster": "fauchend",
    "fauchendstes": "fauchend",
    "fauchest": "fauchen",
    "fauchet": "fauchen",
    "fauchst": "fauchen",
    "faucht": "fauchen",
    "fauchte": "fauchen",
    "fauchten": "fauchen",
    "fauchtest": "fauchen",
    "fauchtet": "fauchen",
    "faul": "faulen",
    "faule": "faul",
    "faulem": "faul",
    "faulen": "faul",
    "faulend": "faulen",
    "faulende": "faulend",
    "faulendem": "faulend",
    "faulenden": "faulend",
    "faulender": "faulend",
    "faulendere": "faulend",
    "faulenderem": "faulend",
    "faulenderen": "faulend",
    "faulenderer": "faulend",
    "faulenderes": "faulend",
    "faulendes": "faulend",
    "faulendste": "faulend",
    "faulendstem": "faulend",
    "faulendsten": "faulend",
    "faulendster": "faulend",
    "faulendstes": "faulend",
    "faulenze": "faulenzen",
    "faulenzend": "faulenzen",
    "faulenzende": "faulenzend",
    "faulenzendem": "faulenzend",
    "faulenzenden": "faulenzend",
    "faulenzender": "faulenzend",
    "faulenzendere": "faulenzend",
    "faulenzenderem": "faulenzend",
    "faulenzenderen": "faulenzend",
    "faulenzenderer": "faulenzend",
    "faulenzenderes": "faulenzend",
    "faulenzendes": "faulenzend",
    "faulenzendste": "faulenzend",
    "faulenzendstem": "faulenzend",
    "faulenzendsten": "faulenzend",
    "faulenzendster": "faulenzend",
    "faulenzendstes": "faulenzend",
    "faulenzest": "faulenzen",
    "faulenzet": "faulenzen",
    "faulenzt": "faulenzen",
    "faulenzte": "faulenzen",
    "faulenzten": "faulenzen",
    "faulenztest": "faulenzen",
    "faulenztet": "faulenzen",
    "fauler": "faul",
    "faulere": "faul",
    "faulerem": "faul",
    "fauleren": "faul",
    "faulerer": "faul",
    "fauleres": "faul",
    "faules": "faul",
    "faulest": "faulen",
    "faulet": "faulen",
    "faulst": "faulen",
    "faulste": "faul",
    "faulstem": "faul",
    "faulsten": "faul",
    "faulster": "faul",
    "faulstes": "faul",
    "fault": "faulen",
    "faulte": "faulen",
    "faulten": "faulen",
    "faultest": "faulen",
    "faultet": "faulen",
    "faustdickem": "faustdick",
    "faustdicken": "faustdick",
    "faustdicker": "faustdick",
    "faustdickes": "faustdick",
    "fauste": "fausten",
    "faustend": "fausten",
    "faustende": "faustend",
    "faustendem": "faustend",
    "faustenden": "faustend",
    "faustender": "faustend",
    "faustendes": "faustend",
    "faustest": "fausten",
    "faustet": "fausten",
    "faustete": "fausten",
    "fausteten": "fausten",
    "faustetest": "fausten",
    "faustetet": "fausten",
    "faxend": "faxen",
    "faxende": "faxend",
    "faxendem": "faxend",
    "faxenden": "faxend",
    "faxender": "faxend",
    "faxendes": "faxend",
    "faxest": "faxen",
    "faxet": "faxen",
    "faxt": "faxen",
    "faxte": "faxen",
    "faxten": "faxen",
    "faxtest": "faxen",
    "faxtet": "faxen",
    "faßbarem": "faßbar",
    "faßbaren": "faßbar",
    "faßbarer": "faßbar",
    "faßbarere": "faßbar",
    "faßbarerem": "faßbar",
    "faßbareren": "faßbar",
    "faßbarerer": "faßbar",
    "faßbareres": "faßbar",
    "faßbares": "faßbar",
    "faßbarste": "faßbar",
    "faßbarstem": "faßbar",
    "faßbarsten": "faßbar",
    "faßbarster": "faßbar",
    "faßbarstes": "faßbar",
    "faßt": "fassen",
    "faßte": "fassen",
    "faßten": "fassen",
    "faßtest": "fassen",
    "faßtet": "fassen",
    "fechte": "fechten",
    "fechtend": "fechten",
    "fechtende": "fechtend",
    "fechtendem": "fechtend",
    "fechtenden": "fechtend",
    "fechtender": "fechtend",
    "fechtendes": "fechtend",
    "fechtest": "fechten",
    "fechtet": "fechten",
    "federe": "federn",
    "federführende": "federführend",
    "federführendem": "federführend",
    "federführenden": "federführend",
    "federführender": "federführend",
    "federführendere": "federführend",
    "federführenderem": "federführend",
    "federführenderen": "federführend",
    "federführenderer": "federführend",
    "federführenderes": "federführend",
    "federführendes": "federführend",
    "federführendste": "federführend",
    "federführendstem": "federführend",
    "federführendsten": "federführend",
    "federführendster": "federführend",
    "federführendstes": "federführend",
    "federleichtem": "federleicht",
    "federleichten": "federleicht",
    "federleichter": "federleicht",
    "federleichtere": "federleicht",
    "federleichterem": "federleicht",
    "federleichteren": "federleicht",
    "federleichterer": "federleicht",
    "federleichteres": "federleicht",
    "federleichtes": "federleicht",
    "federleichteste": "federleicht",
    "federleichtestem": "federleicht",
    "federleichtesten": "federleicht",
    "federleichtester": "federleicht",
    "federleichtestes": "federleicht",
    "federnd": "federn",
    "federnde": "federnd",
    "federndem": "federnd",
    "federnden": "federnd",
    "federnder": "federnd",
    "federndere": "federnd",
    "federnderem": "federnd",
    "federnderen": "federnd",
    "federnderer": "federnd",
    "federnderes": "federnd",
    "federndes": "federnd",
    "federndste": "federnd",
    "federndstem": "federnd",
    "federndsten": "federnd",
    "federndster": "federnd",
    "federndstes": "federnd",
    "federst": "federn",
    "federt": "federn",
    "federte": "federn",
    "federten": "federn",
    "federtest": "federn",
    "federtet": "federn",
    "fege": "fegen",
    "fegend": "fegen",
    "fegende": "fegend",
    "fegendem": "fegend",
    "fegenden": "fegend",
    "fegender": "fegend",
    "fegendes": "fegend",
    "fegest": "fegen",
    "feget": "fegen",
    "fegst": "fegen",
    "fegt": "fegen",
    "fegte": "fegen",
    "fegten": "fegen",
    "fegtest": "fegen",
    "fegtet": "fegen",
    "fehlbat": "fehlbitten",
    "fehlbaten": "fehlbitten",
    "fehlbatest": "fehlbitten",
    "fehlbatet": "fehlbitten",
    "fehlbittend": "fehlbitten",
    "fehlbittende": "fehlbittend",
    "fehlbittendem": "fehlbittend",
    "fehlbittenden": "fehlbittend",
    "fehlbittender": "fehlbittend",
    "fehlbittendes": "fehlbittend",
    "fehlbittest": "fehlbitten",
    "fehlbittet": "fehlbitten",
    "fehlbäte": "fehlbitten",
    "fehlbäten": "fehlbitten",
    "fehlbätest": "fehlbitten",
    "fehlbätet": "fehlbitten",
    "fehle": "fehlen",
    "fehlend": "fehlen",
    "fehlende": "fehlend",
    "fehlendem": "fehlend",
    "fehlenden": "fehlend",
    "fehlender": "fehlend",
    "fehlendere": "fehlend",
    "fehlenderem": "fehlend",
    "fehlenderen": "fehlend",
    "fehlenderer": "fehlend",
    "fehlenderes": "fehlend",
    "fehlendes": "fehlend",
    "fehlendste": "fehlend",
    "fehlendstem": "fehlend",
    "fehlendsten": "fehlend",
    "fehlendster": "fehlend",
    "fehlendstes": "fehlend",
    "fehlerfreiem": "fehlerfrei",
    "fehlerfreien": "fehlerfrei",
    "fehlerfreier": "fehlerfrei",
    "fehlerfreies": "fehlerfrei",
    "fehlerhafte": "fehlerhaft",
    "fehlerhaftem": "fehlerhaft",
    "fehlerhaften": "fehlerhaft",
    "fehlerhafter": "fehlerhaft",
    "fehlerhaftere": "fehlerhaft",
    "fehlerhafterem": "fehlerhaft",
    "fehlerhafteren": "fehlerhaft",
    "fehlerhafterer": "fehlerhaft",
    "fehlerhafteres": "fehlerhaft",
    "fehlerhaftes": "fehlerhaft",
    "fehlerhafteste": "fehlerhaft",
    "fehlerhaftestem": "fehlerhaft",
    "fehlerhaftesten": "fehlerhaft",
    "fehlerhaftester": "fehlerhaft",
    "fehlerhaftestes": "fehlerhaft",
    "fehlerlose": "fehlerlos",
    "fehlerlosem": "fehlerlos",
    "fehlerlosen": "fehlerlos",
    "fehlerloser": "fehlerlos",
    "fehlerloses": "fehlerlos",
    "fehlest": "fehlen",
    "fehlet": "fehlen",
    "fehlgebeten": "fehlbitten",
    "fehlgebetene": "fehlgebeten",
    "fehlgebetenem": "fehlgebeten",
    "fehlgebetenen": "fehlgebeten",
    "fehlgebetener": "fehlgebeten",
    "fehlgebetenes": "fehlgebeten",
    "fehlgegriffen": "fehlgreifen",
    "fehlgegriffene": "fehlgegriffen",
    "fehlgegriffenem": "fehlgegriffen",
    "fehlgegriffenen": "fehlgegriffen",
    "fehlgegriffener": "fehlgegriffen",
    "fehlgegriffenere": "fehlgegriffen",
    "fehlgegriffenerem": "fehlgegriffen",
    "fehlgegriffeneren": "fehlgegriffen",
    "fehlgegriffenerer": "fehlgegriffen",
    "fehlgegriffeneres": "fehlgegriffen",
    "fehlgegriffenes": "fehlgegriffen",
    "fehlgegriffenste": "fehlgegriffen",
    "fehlgegriffenstem": "fehlgegriffen",
    "fehlgegriffensten": "fehlgegriffen",
    "fehlgegriffenster": "fehlgegriffen",
    "fehlgegriffenstes": "fehlgegriffen",
    "fehlgeleitet": "fehlleiten",
    "fehlgeleitete": "fehlgeleitet",
    "fehlgeleitetem": "fehlgeleitet",
    "fehlgeleiteten": "fehlgeleitet",
    "fehlgeleiteter": "fehlgeleitet",
    "fehlgeleitetes": "fehlgeleitet",
    "fehlgeschlagen": "fehlschlagen",
    "fehlgeschlagene": "fehlgeschlagen",
    "fehlgeschlagenem": "fehlgeschlagen",
    "fehlgeschlagenen": "fehlgeschlagen",
    "fehlgeschlagener": "fehlgeschlagen",
    "fehlgeschlagenes": "fehlgeschlagen",
    "fehlgeschossen": "fehlschießen",
    "fehlgeschossene": "fehlgeschossen",
    "fehlgeschossenem": "fehlgeschossen",
    "fehlgeschossenen": "fehlgeschossen",
    "fehlgeschossener": "fehlgeschossen",
    "fehlgeschossenes": "fehlgeschossen",
    "fehlgreife": "fehlgreifen",
    "fehlgreifend": "fehlgreifen",
    "fehlgreifende": "fehlgreifend",
    "fehlgreifendem": "fehlgreifend",
    "fehlgreifenden": "fehlgreifend",
    "fehlgreifender": "fehlgreifend",
    "fehlgreifendere": "fehlgreifend",
    "fehlgreifenderem": "fehlgreifend",
    "fehlgreifenderen": "fehlgreifend",
    "fehlgreifenderer": "fehlgreifend",
    "fehlgreifenderes": "fehlgreifend",
    "fehlgreifendes": "fehlgreifend",
    "fehlgreifendste": "fehlgreifend",
    "fehlgreifendstem": "fehlgreifend",
    "fehlgreifendsten": "fehlgreifend",
    "fehlgreifendster": "fehlgreifend",
    "fehlgreifendstes": "fehlgreifend",
    "fehlgreifest": "fehlgreifen",
    "fehlgreifet": "fehlgreifen",
    "fehlgreifst": "fehlgreifen",
    "fehlgreift": "fehlgreifen",
    "fehlgriff": "fehlgreifen",
    "fehlgriffest": "fehlgreifen",
    "fehlgriffet": "fehlgreifen",
    "fehlgriffst": "fehlgreifen",
    "fehlgrifft": "fehlgreifen",
    "fehlinvestiere": "fehlinvestieren",
    "fehlinvestierend": "fehlinvestieren",
    "fehlinvestierende": "fehlinvestierend",
    "fehlinvestierendem": "fehlinvestierend",
    "fehlinvestierenden": "fehlinvestierend",
    "fehlinvestierender": "fehlinvestierend",
    "fehlinvestierendes": "fehlinvestierend",
    "fehlinvestierest": "fehlinvestieren",
    "fehlinvestieret": "fehlinvestieren",
    "fehlinvestierst": "fehlinvestieren",
    "fehlinvestiert": "fehlinvestieren",
    "fehlinvestierte": "fehlinvestieren",
    "fehlinvestiertem": "fehlinvestiert",
    "fehlinvestierten": "fehlinvestieren",
    "fehlinvestierter": "fehlinvestiert",
    "fehlinvestiertes": "fehlinvestiert",
    "fehlinvestiertest": "fehlinvestieren",
    "fehlinvestiertet": "fehlinvestieren",
    "fehlleite": "fehlleiten",
    "fehlleitend": "fehlleiten",
    "fehlleitende": "fehlleitend",
    "fehlleitendem": "fehlleitend",
    "fehlleitenden": "fehlleitend",
    "fehlleitender": "fehlleitend",
    "fehlleitendes": "fehlleitend",
    "fehlleitest": "fehlleiten",
    "fehlleitet": "fehlleiten",
    "fehlleitete": "fehlleiten",
    "fehlleiteten": "fehlleiten",
    "fehlleitetest": "fehlleiten",
    "fehlleitetet": "fehlleiten",
    "fehlschieße": "fehlschießen",
    "fehlschießend": "fehlschießen",
    "fehlschießende": "fehlschießend",
    "fehlschießendem": "fehlschießend",
    "fehlschießenden": "fehlschießend",
    "fehlschießender": "fehlschießend",
    "fehlschießendes": "fehlschießend",
    "fehlschießest": "fehlschießen",
    "fehlschießet": "fehlschießen",
    "fehlschießt": "fehlschießen",
    "fehlschlagend": "fehlschlagen",
    "fehlschlagende": "fehlschlagend",
    "fehlschlagendem": "fehlschlagend",
    "fehlschlagenden": "fehlschlagend",
    "fehlschlagender": "fehlschlagend",
    "fehlschlagendes": "fehlschlagend",
    "fehlschlagest": "fehlschlagen",
    "fehlschlaget": "fehlschlagen",
    "fehlschlagt": "fehlschlagen",
    "fehlschlug": "fehlschlagen",
    "fehlschlugen": "fehlschlagen",
    "fehlschlugst": "fehlschlagen",
    "fehlschlugt": "fehlschlagen",
    "fehlschlägst": "fehlschlagen",
    "fehlschlägt": "fehlschlagen",
    "fehlschlüge": "fehlschlagen",
    "fehlschlügen": "fehlschlagen",
    "fehlschlügest": "fehlschlagen",
    "fehlschlüget": "fehlschlagen",
    "fehlschossen": "fehlschießen",
    "fehlschoß": "fehlschießen",
    "fehlschoßt": "fehlschießen",
    "fehlschösse": "fehlschießen",
    "fehlschössen": "fehlschießen",
    "fehlschössest": "fehlschießen",
    "fehlschösset": "fehlschießen",
    "fehlst": "fehlen",
    "fehlt": "fehlen",
    "fehlte": "fehlen",
    "fehlten": "fehlen",
    "fehltest": "fehlen",
    "fehltet": "fehlen",
    "fehlzubitten": "fehlbitten",
    "fehlzugreifen": "fehlgreifen",
    "fehlzuleiten": "fehlleiten",
    "fehlzuschießen": "fehlschießen",
    "fehlzuschlagen": "fehlschlagen",
    "feie": "feien",
    "feiend": "feien",
    "feiende": "feiend",
    "feiendem": "feiend",
    "feienden": "feiend",
    "feiender": "feiend",
    "feiendere": "feiend",
    "feienderem": "feiend",
    "feienderen": "feiend",
    "feienderer": "feiend",
    "feienderes": "feiend",
    "feiendes": "feiend",
    "feiendste": "feiend",
    "feiendstem": "feiend",
    "feiendsten": "feiend",
    "feiendster": "feiend",
    "feiendstes": "feiend",
    "feiere": "feiern",
    "feierliche": "feierlich",
    "feierlichem": "feierlich",
    "feierlichen": "feierlich",
    "feierlicher": "feierlich",
    "feierlichere": "feierlich",
    "feierlicherem": "feierlich",
    "feierlicheren": "feierlich",
    "feierlicherer": "feierlich",
    "feierlicheres": "feierlich",
    "feierliches": "feierlich",
    "feierlichstem": "feierlich",
    "feierlichsten": "feierlich",
    "feierlichster": "feierlich",
    "feierlichstes": "feierlich",
    "feiernd": "feiern",
    "feiernde": "feiernd",
    "feierndem": "feiernd",
    "feiernden": "feiernd",
    "feiernder": "feiernd",
    "feierndes": "feiernd",
    "feierst": "feiern",
    "feiert": "feiern",
    "feierte": "feiern",
    "feierten": "feiern",
    "feiertest": "feiern",
    "feiertet": "feiern",
    "feiest": "feien",
    "feiet": "feien",
    "feigem": "feige",
    "feigen": "feige",
    "feiger": "feige",
    "feigere": "feige",
    "feigerem": "feige",
    "feigeren": "feige",
    "feigerer": "feige",
    "feigeres": "feige",
    "feiges": "feige",
    "feigeste": "feige",
    "feigestem": "feige",
    "feigesten": "feige",
    "feigester": "feige",
    "feigestes": "feige",
    "feilbiete": "feilbieten",
    "feilbietend": "feilbieten",
    "feilbietende": "feilbietend",
    "feilbietendem": "feilbietend",
    "feilbietenden": "feilbietend",
    "feilbietender": "feilbietend",
    "feilbietendes": "feilbietend",
    "feilbietest": "feilbieten",
    "feilbietet": "feilbieten",
    "feilbot": "feilbieten",
    "feilboten": "feilbieten",
    "feilbotest": "feilbieten",
    "feilbotet": "feilbieten",
    "feilböte": "feilbieten",
    "feilböten": "feilbieten",
    "feilbötest": "feilbieten",
    "feilbötet": "feilbieten",
    "feile": "feilen",
    "feilend": "feilen",
    "feilende": "feilend",
    "feilendem": "feilend",
    "feilenden": "feilend",
    "feilender": "feilend",
    "feilendes": "feilend",
    "feilest": "feilen",
    "feilet": "feilen",
    "feilgeboten": "feilbieten",
    "feilgebotene": "feilgeboten",
    "feilgebotenem": "feilgeboten",
    "feilgebotenen": "feilgeboten",
    "feilgebotener": "feilgeboten",
    "feilgebotenes": "feilgeboten",
    "feilsche": "feilschen",
    "feilschend": "feilschen",
    "feilschende": "feilschend",
    "feilschendem": "feilschend",
    "feilschenden": "feilschend",
    "feilschender": "feilschend",
    "feilschendere": "feilschend",
    "feilschenderem": "feilschend",
    "feilschenderen": "feilschend",
    "feilschenderer": "feilschend",
    "feilschenderes": "feilschend",
    "feilschendes": "feilschend",
    "feilschendste": "feilschend",
    "feilschendstem": "feilschend",
    "feilschendsten": "feilschend",
    "feilschendster": "feilschend",
    "feilschendstes": "feilschend",
    "feilschest": "feilschen",
    "feilschet": "feilschen",
    "feilschst": "feilschen",
    "feilscht": "feilschen",
    "feilschte": "feilschen",
    "feilschten": "feilschen",
    "feilschtest": "feilschen",
    "feilschtet": "feilschen",
    "feilst": "feilen",
    "feilt": "feilen",
    "feilte": "feilen",
    "feilten": "feilen",
    "feiltest": "feilen",
    "feiltet": "feilen",
    "feilzubieten": "feilbieten",
    "feindend": "feinden",
    "feindende": "feindend",
    "feindendem": "feindend",
    "feindenden": "feindend",
    "feindender": "feindend",
    "feindendes": "feindend",
    "feindest": "feinden",
    "feindet": "feinden",
    "feindete": "feinden",
    "feindeten": "feinden",
    "feindetest": "feinden",
    "feindetet": "feinden",
    "feindliche": "feindlich",
    "feindlichem": "feindlich",
    "feindlichen": "feindlich",
    "feindlicher": "feindlich",
    "feindlichere": "feindlich",
    "feindlicherem": "feindlich",
    "feindlicheren": "feindlich",
    "feindlicherer": "feindlich",
    "feindlicheres": "feindlich",
    "feindliches": "feindlich",
    "feindlichstem": "feindlich",
    "feindlichsten": "feindlich",
    "feindlichster": "feindlich",
    "feindlichstes": "feindlich",
    "feindseligem": "feindselig",
    "feindseligen": "feindselig",
    "feindseliger": "feindselig",
    "feindseligere": "feindselig",
    "feindseligerem": "feindselig",
    "feindseligeren": "feindselig",
    "feindseligerer": "feindselig",
    "feindseligeres": "feindselig",
    "feindseliges": "feindselig",
    "feindseligstem": "feindselig",
    "feindseligsten": "feindselig",
    "feindseligster": "feindselig",
    "feindseligstes": "feindselig",
    "feine": "fein",
    "feinem": "fein",
    "feinen": "fein",
    "feiner": "fein",
    "feinere": "fein",
    "feinerem": "fein",
    "feineren": "fein",
    "feinerer": "fein",
    "feineres": "fein",
    "feines": "fein",
    "feinfühlige": "feinfühlig",
    "feinfühligem": "feinfühlig",
    "feinfühligen": "feinfühlig",
    "feinfühliger": "feinfühlig",
    "feinfühligere": "feinfühlig",
    "feinfühligerem": "feinfühlig",
    "feinfühligeren": "feinfühlig",
    "feinfühligerer": "feinfühlig",
    "feinfühligeres": "feinfühlig",
    "feinfühliges": "feinfühlig",
    "feinfühligste": "feinfühlig",
    "feinfühligstem": "feinfühlig",
    "feinfühligsten": "feinfühlig",
    "feinfühligster": "feinfühlig",
    "feinfühligstes": "feinfühlig",
    "feingeschleift": "feinschleifen",
    "feingeschleifte": "feingeschleift",
    "feingeschleiftem": "feingeschleift",
    "feingeschleiften": "feingeschleift",
    "feingeschleifter": "feingeschleift",
    "feingeschleiftes": "feingeschleift",
    "feingeschliffen": "feinschleifen",
    "feingeschliffene": "feingeschliffen",
    "feingeschliffenem": "feingeschliffen",
    "feingeschliffenen": "feingeschliffen",
    "feingeschliffener": "feingeschliffen",
    "feingeschliffenere": "feingeschliffen",
    "feingeschliffenerem": "feingeschliffen",
    "feingeschliffeneren": "feingeschliffen",
    "feingeschliffenerer": "feingeschliffen",
    "feingeschliffeneres": "feingeschliffen",
    "feingeschliffenes": "feingeschliffen",
    "feingeschliffenste": "feingeschliffen",
    "feingeschliffenstem": "feingeschliffen",
    "feingeschliffensten": "feingeschliffen",
    "feingeschliffenster": "feingeschliffen",
    "feingeschliffenstes": "feingeschliffen",
    "feinkörnige": "feinkörnig",
    "feinkörnigem": "feinkörnig",
    "feinkörnigen": "feinkörnig",
    "feinkörniger": "feinkörnig",
    "feinkörnigere": "feinkörnig",
    "feinkörnigerem": "feinkörnig",
    "feinkörnigeren": "feinkörnig",
    "feinkörnigerer": "feinkörnig",
    "feinkörnigeres": "feinkörnig",
    "feinkörniges": "feinkörnig",
    "feinkörnigste": "feinkörnig",
    "feinkörnigstem": "feinkörnig",
    "feinkörnigsten": "feinkörnig",
    "feinkörnigster": "feinkörnig",
    "feinkörnigstes": "feinkörnig",
    "feinmaschige": "feinmaschig",
    "feinmaschigem": "feinmaschig",
    "feinmaschigen": "feinmaschig",
    "feinmaschiger": "feinmaschig",
    "feinmaschigere": "feinmaschig",
    "feinmaschigerem": "feinmaschig",
    "feinmaschigeren": "feinmaschig",
    "feinmaschigerer": "feinmaschig",
    "feinmaschigeres": "feinmaschig",
    "feinmaschiges": "feinmaschig",
    "feinmaschigste": "feinmaschig",
    "feinmaschigstem": "feinmaschig",
    "feinmaschigsten": "feinmaschig",
    "feinmaschigster": "feinmaschig",
    "feinmaschigstes": "feinmaschig",
    "feinschleife": "feinschleifen",
    "feinschleifend": "feinschleifen",
    "feinschleifende": "feinschleifend",
    "feinschleifendem": "feinschleifend",
    "feinschleifenden": "feinschleifend",
    "feinschleifender": "feinschleifend",
    "feinschleifendes": "feinschleifend",
    "feinschleifest": "feinschleifen",
    "feinschleifet": "feinschleifen",
    "feinschleifst": "feinschleifen",
    "feinschleift": "feinschleifen",
    "feinschleifte": "feinschleifen",
    "feinschleiften": "feinschleifen",
    "feinschleiftest": "feinschleifen",
    "feinschleiftet": "feinschleifen",
    "feinschliff": "feinschleifen",
    "feinschliffe": "feinschleifen",
    "feinschliffen": "feinschleifen",
    "feinschliffest": "feinschleifen",
    "feinschliffet": "feinschleifen",
    "feinschliffst": "feinschleifen",
    "feinschlifft": "feinschleifen",
    "feinstem": "fein",
    "feinsten": "fein",
    "feinster": "fein",
    "feinstes": "fein",
    "feinzuschleifen": "feinschleifen",
    "feist": "feien",
    "feit": "feien",
    "feite": "feien",
    "feiten": "feien",
    "feitest": "feien",
    "feitet": "feien",
    "felsenfestem": "felsenfest",
    "felsenfesten": "felsenfest",
    "felsenfester": "felsenfest",
    "felsenfestes": "felsenfest",
    "felsigem": "felsig",
    "felsigen": "felsig",
    "felsiger": "felsig",
    "felsigere": "felsig",
    "felsigerem": "felsig",
    "felsigeren": "felsig",
    "felsigerer": "felsig",
    "felsigeres": "felsig",
    "felsiges": "felsig",
    "felsigste": "felsig",
    "felsigstem": "felsig",
    "felsigsten": "felsig",
    "felsigster": "felsig",
    "felsigstes": "felsig",
    "feminine": "feminin",
    "femininem": "feminin",
    "femininen": "feminin",
    "femininer": "feminin",
    "feminines": "feminin",
    "feministischem": "feministisch",
    "feministischen": "feministisch",
    "feministischer": "feministisch",
    "feministischere": "feministisch",
    "feministischerem": "feministisch",
    "feministischeren": "feministisch",
    "feministischerer": "feministisch",
    "feministischeres": "feministisch",
    "feministisches": "feministisch",
    "feministischste": "feministisch",
    "feministischstem": "feministisch",
    "feministischsten": "feministisch",
    "feministischster": "feministisch",
    "feministischstes": "feministisch",
    "ferkele": "ferkeln",
    "ferkelnd": "ferkeln",
    "ferkelnde": "ferkelnd",
    "ferkelndem": "ferkelnd",
    "ferkelnden": "ferkelnd",
    "ferkelnder": "ferkelnd",
    "ferkelndere": "ferkelnd",
    "ferkelnderem": "ferkelnd",
    "ferkelnderen": "ferkelnd",
    "ferkelnderer": "ferkelnd",
    "ferkelnderes": "ferkelnd",
    "ferkelndes": "ferkelnd",
    "ferkelndste": "ferkelnd",
    "ferkelndstem": "ferkelnd",
    "ferkelndsten": "ferkelnd",
    "ferkelndster": "ferkelnd",
    "ferkelndstes": "ferkelnd",
    "ferkelst": "ferkeln",
    "ferkelt": "ferkeln",
    "ferkelte": "ferkeln",
    "ferkelten": "ferkeln",
    "ferkeltest": "ferkeln",
    "ferkeltet": "ferkeln",
    "ferkle": "ferkeln",
    "fernbleibe": "fernbleiben",
    "fernbleibend": "fernbleiben",
    "fernbleibende": "fernbleibend",
    "fernbleibendem": "fernbleibend",
    "fernbleibenden": "fernbleibend",
    "fernbleibender": "fernbleibend",
    "fernbleibendes": "fernbleibend",
    "fernbleibest": "fernbleiben",
    "fernbleibet": "fernbleiben",
    "fernbleibst": "fernbleiben",
    "fernbleibt": "fernbleiben",
    "fernblieb": "fernbleiben",
    "fernbliebe": "fernbleiben",
    "fernblieben": "fernbleiben",
    "fernbliebest": "fernbleiben",
    "fernbliebet": "fernbleiben",
    "fernbliebst": "fernbleiben",
    "fernbliebt": "fernbleiben",
    "ferne": "fern",
    "fernem": "fern",
    "fernen": "fern",
    "ferner": "fern",
    "fernere": "fern",
    "fernerem": "fern",
    "ferneren": "fern",
    "fernerer": "fern",
    "ferneres": "fern",
    "fernes": "fern",
    "ferngeblieben": "fernbleiben",
    "ferngebliebene": "ferngeblieben",
    "ferngebliebenem": "ferngeblieben",
    "ferngebliebenen": "ferngeblieben",
    "ferngebliebener": "ferngeblieben",
    "ferngebliebenes": "ferngeblieben",
    "ferngelenkt": "fernlenken",
    "ferngelenkte": "ferngelenkt",
    "ferngelenktem": "ferngelenkt",
    "ferngelenkten": "ferngelenkt",
    "ferngelenkter": "ferngelenkt",
    "ferngelenktes": "ferngelenkt",
    "ferngesehen": "fernsehen",
    "ferngesehene": "ferngesehen",
    "ferngesehenem": "ferngesehen",
    "ferngesehenen": "ferngesehen",
    "ferngesehener": "ferngesehen",
    "ferngesehenes": "ferngesehen",
    "ferngesprochen": "fernsprechen",
    "ferngesprochene": "ferngesprochen",
    "ferngesprochenem": "ferngesprochen",
    "ferngesprochenen": "ferngesprochen",
    "ferngesprochener": "ferngesprochen",
    "ferngesprochenes": "ferngesprochen",
    "ferngesteuert": "fernsteuern",
    "ferngesteuerte": "ferngesteuert",
    "ferngesteuertem": "ferngesteuert",
    "ferngesteuerten": "ferngesteuert",
    "ferngesteuerter": "ferngesteuert",
    "ferngesteuertes": "ferngesteuert",
    "fernlenke": "fernlenken",
    "fernlenkend": "fernlenken",
    "fernlenkende": "fernlenkend",
    "fernlenkendem": "fernlenkend",
    "fernlenkenden": "fernlenkend",
    "fernlenkender": "fernlenkend",
    "fernlenkendes": "fernlenkend",
    "fernlenkest": "fernlenken",
    "fernlenket": "fernlenken",
    "fernlenkst": "fernlenken",
    "fernlenkt": "fernlenken",
    "fernlenkte": "fernlenken",
    "fernlenkten": "fernlenken",
    "fernlenktest": "fernlenken",
    "fernlenktet": "fernlenken",
    "fernmündlichem": "fernmündlich",
    "fernmündlichen": "fernmündlich",
    "fernmündlicher": "fernmündlich",
    "fernmündliches": "fernmündlich",
    "fernsah": "fernsehen",
    "fernsahen": "fernsehen",
    "fernsahst": "fernsehen",
    "fernsaht": "fernsehen",
    "fernsehe": "fernsehen",
    "fernsehend": "fernsehen",
    "fernsehende": "fernsehend",
    "fernsehendem": "fernsehend",
    "fernsehenden": "fernsehend",
    "fernsehender": "fernsehend",
    "fernsehendes": "fernsehend",
    "fernsehest": "fernsehen",
    "fernsehet": "fernsehen",
    "fernsehgerechtem": "fernsehgerecht",
    "fernsehgerechten": "fernsehgerecht",
    "fernsehgerechter": "fernsehgerecht",
    "fernsehgerechtere": "fernsehgerecht",
    "fernsehgerechterem": "fernsehgerecht",
    "fernsehgerechteren": "fernsehgerecht",
    "fernsehgerechterer": "fernsehgerecht",
    "fernsehgerechteres": "fernsehgerecht",
    "fernsehgerechtes": "fernsehgerecht",
    "fernsehgerechteste": "fernsehgerecht",
    "fernsehgerechtestem": "fernsehgerecht",
    "fernsehgerechtesten": "fernsehgerecht",
    "fernsehgerechtester": "fernsehgerecht",
    "fernsehgerechtestes": "fernsehgerecht",
    "fernsehmüdem": "fernsehmüde",
    "fernsehmüden": "fernsehmüde",
    "fernsehmüder": "fernsehmüde",
    "fernsehmüdes": "fernsehmüde",
    "fernseht": "fernsehen",
    "fernsichtigem": "fernsichtig",
    "fernsichtigen": "fernsichtig",
    "fernsichtiger": "fernsichtig",
    "fernsichtigere": "fernsichtig",
    "fernsichtigerem": "fernsichtig",
    "fernsichtigeren": "fernsichtig",
    "fernsichtigerer": "fernsichtig",
    "fernsichtigeres": "fernsichtig",
    "fernsichtiges": "fernsichtig",
    "fernsichtigste": "fernsichtig",
    "fernsichtigstem": "fernsichtig",
    "fernsichtigsten": "fernsichtig",
    "fernsichtigster": "fernsichtig",
    "fernsichtigstes": "fernsichtig",
    "fernsiehst": "fernsehen",
    "fernsieht": "fernsehen",
    "fernsprach": "fernsprechen",
    "fernsprachen": "fernsprechen",
    "fernsprachst": "fernsprechen",
    "fernspracht": "fernsprechen",
    "fernspreche": "fernsprechen",
    "fernsprechend": "fernsprechen",
    "fernsprechende": "fernsprechend",
    "fernsprechendem": "fernsprechend",
    "fernsprechenden": "fernsprechend",
    "fernsprechender": "fernsprechend",
    "fernsprechendes": "fernsprechend",
    "fernsprechest": "fernsprechen",
    "fernsprechet": "fernsprechen",
    "fernsprecht": "fernsprechen",
    "fernsprichst": "fernsprechen",
    "fernspricht": "fernsprechen",
    "fernspräche": "fernsprechen",
    "fernsprächen": "fernsprechen",
    "fernsprächest": "fernsprechen",
    "fernsprächet": "fernsprechen",
    "fernstem": "fern",
    "fernsten": "fern",
    "fernster": "fern",
    "fernstes": "fern",
    "fernsteuere": "fernsteuern",
    "fernsteuernd": "fernsteuern",
    "fernsteuernde": "fernsteuernd",
    "fernsteuerndem": "fernsteuernd",
    "fernsteuernden": "fernsteuernd",
    "fernsteuernder": "fernsteuernd",
    "fernsteuerndes": "fernsteuernd",
    "fernsteuerst": "fernsteuern",
    "fernsteuert": "fernsteuern",
    "fernsteuerte": "fernsteuern",
    "fernsteuerten": "fernsteuern",
    "fernsteuertest": "fernsteuern",
    "fernsteuertet": "fernsteuern",
    "fernsähe": "fernsehen",
    "fernsähen": "fernsehen",
    "fernsähest": "fernsehen",
    "fernsähet": "fernsehen",
    "fernzubleiben": "fernbleiben",
    "fernzulenken": "fernlenken",
    "fernzusehen": "fernsehen",
    "fernzusprechen": "fernsprechen",
    "fernzusteuern": "fernsteuern",
    "fernöstlichem": "fernöstlich",
    "fernöstlichen": "fernöstlich",
    "fernöstlicher": "fernöstlich",
    "fernöstliches": "fernöstlich",
    "fertig": "fertigen",
    "fertigbekam": "fertigbekommen",
    "fertigbekamen": "fertigbekommen",
    "fertigbekamst": "fertigbekommen",
    "fertigbekamt": "fertigbekommen",
    "fertigbekomme": "fertigbekommen",
    "fertigbekommend": "fertigbekommen",
    "fertigbekommende": "fertigbekommend",
    "fertigbekommendem": "fertigbekommend",
    "fertigbekommenden": "fertigbekommend",
    "fertigbekommender": "fertigbekommend",
    "fertigbekommendes": "fertigbekommend",
    "fertigbekommene": "fertigbekommen",
    "fertigbekommenem": "fertigbekommen",
    "fertigbekommenen": "fertigbekommen",
    "fertigbekommener": "fertigbekommen",
    "fertigbekommenes": "fertigbekommen",
    "fertigbekommest": "fertigbekommen",
    "fertigbekommet": "fertigbekommen",
    "fertigbekommst": "fertigbekommen",
    "fertigbekommt": "fertigbekommen",
    "fertigbekäme": "fertigbekommen",
    "fertigbekämen": "fertigbekommen",
    "fertigbekämest": "fertigbekommen",
    "fertigbekämet": "fertigbekommen",
    "fertigbrachte": "fertigbringen",
    "fertigbrachten": "fertigbringen",
    "fertigbrachtest": "fertigbringen",
    "fertigbrachtet": "fertigbringen",
    "fertigbringe": "fertigbringen",
    "fertigbringend": "fertigbringen",
    "fertigbringende": "fertigbringend",
    "fertigbringendem": "fertigbringend",
    "fertigbringenden": "fertigbringend",
    "fertigbringender": "fertigbringend",
    "fertigbringendes": "fertigbringend",
    "fertigbringest": "fertigbringen",
    "fertigbringet": "fertigbringen",
    "fertigbringst": "fertigbringen",
    "fertigbringt": "fertigbringen",
    "fertigbrächte": "fertigbringen",
    "fertigbrächten": "fertigbringen",
    "fertigbrächtest": "fertigbringen",
    "fertigbrächtet": "fertigbringen",
    "fertige": "fertig",
    "fertigem": "fertig",
    "fertigen": "fertig",
    "fertigend": "fertigen",
    "fertigende": "fertigend",
    "fertigendem": "fertigend",
    "fertigenden": "fertigend",
    "fertigender": "fertigend",
    "fertigendes": "fertigend",
    "fertiger": "fertig",
    "fertiges": "fertig",
    "fertigest": "fertigen",
    "fertiget": "fertigen",
    "fertiggebracht": "fertigbringen",
    "fertiggebrachte": "fertiggebracht",
    "fertiggebrachtem": "fertiggebracht",
    "fertiggebrachten": "fertiggebracht",
    "fertiggebrachter": "fertiggebracht",
    "fertiggebrachtes": "fertiggebracht",
    "fertiggekocht": "fertigkochen",
    "fertiggekochte": "fertiggekocht",
    "fertiggekochtem": "fertiggekocht",
    "fertiggekochten": "fertiggekocht",
    "fertiggekochter": "fertiggekocht",
    "fertiggekochtes": "fertiggekocht",
    "fertiggemacht": "fertigmachen",
    "fertiggemachte": "fertiggemacht",
    "fertiggemachtem": "fertiggemacht",
    "fertiggemachten": "fertiggemacht",
    "fertiggemachter": "fertiggemacht",
    "fertiggemachtes": "fertiggemacht",
    "fertiggestellt": "fertigstellen",
    "fertiggestellte": "fertiggestellt",
    "fertiggestelltem": "fertiggestellt",
    "fertiggestellten": "fertiggestellt",
    "fertiggestellter": "fertiggestellt",
    "fertiggestelltes": "fertiggestellt",
    "fertigkoche": "fertigkochen",
    "fertigkochend": "fertigkochen",
    "fertigkochende": "fertigkochend",
    "fertigkochendem": "fertigkochend",
    "fertigkochenden": "fertigkochend",
    "fertigkochender": "fertigkochend",
    "fertigkochendes": "fertigkochend",
    "fertigkochest": "fertigkochen",
    "fertigkochet": "fertigkochen",
    "fertigkochst": "fertigkochen",
    "fertigkocht": "fertigkochen",
    "fertigkochte": "fertigkochen",
    "fertigkochten": "fertigkochen",
    "fertigkochtest": "fertigkochen",
    "fertigkochtet": "fertigkochen",
    "fertigmache": "fertigmachen",
    "fertigmachend": "fertigmachen",
    "fertigmachende": "fertigmachend",
    "fertigmachendem": "fertigmachend",
    "fertigmachenden": "fertigmachend",
    "fertigmachender": "fertigmachend",
    "fertigmachendes": "fertigmachend",
    "fertigmachest": "fertigmachen",
    "fertigmachet": "fertigmachen",
    "fertigmachst": "fertigmachen",
    "fertigmacht": "fertigmachen",
    "fertigmachte": "fertigmachen",
    "fertigmachten": "fertigmachen",
    "fertigmachtest": "fertigmachen",
    "fertigmachtet": "fertigmachen",
    "fertigst": "fertigen",
    "fertigstelle": "fertigstellen",
    "fertigstellend": "fertigstellen",
    "fertigstellende": "fertigstellend",
    "fertigstellendem": "fertigstellend",
    "fertigstellenden": "fertigstellend",
    "fertigstellender": "fertigstellend",
    "fertigstellendes": "fertigstellend",
    "fertigstellest": "fertigstellen",
    "fertigstellet": "fertigstellen",
    "fertigstellst": "fertigstellen",
    "fertigstellt": "fertigstellen",
    "fertigstellte": "fertigstellen",
    "fertigstellten": "fertigstellen",
    "fertigstelltest": "fertigstellen",
    "fertigstelltet": "fertigstellen",
    "fertigt": "fertigen",
    "fertigte": "fertigen",
    "fertigten": "fertigen",
    "fertigtest": "fertigen",
    "fertigtet": "fertigen",
    "fertigzubekommen": "fertigbekommen",
    "fertigzubringen": "fertigbringen",
    "fertigzukochen": "fertigkochen",
    "fertigzumachen": "fertigmachen",
    "fertigzustellen": "fertigstellen",
    "fessele": "fesseln",
    "fesselnd": "fesseln",
    "fesselnde": "fesselnd",
    "fesselndem": "fesselnd",
    "fesselnden": "fesselnd",
    "fesselnder": "fesselnd",
    "fesselndere": "fesselnd",
    "fesselnderem": "fesselnd",
    "fesselnderen": "fesselnd",
    "fesselnderer": "fesselnd",
    "fesselnderes": "fesselnd",
    "fesselndes": "fesselnd",
    "fesselndste": "fesselnd",
    "fesselndstem": "fesselnd",
    "fesselndsten": "fesselnd",
    "fesselndster": "fesselnd",
    "fesselndstes": "fesselnd",
    "fesselst": "fesseln",
    "fesselt": "fesseln",
    "fesselte": "fesseln",
    "fesselten": "fesseln",
    "fesseltest": "fesseln",
    "fesseltet": "fesseln",
    "fessle": "fesseln",
    "festangestelltem": "festangestellt",
    "festangestellten": "festangestellt",
    "festangestellter": "festangestellt",
    "festangestelltes": "festangestellt",
    "festbeiße": "festbeißen",
    "festbeißend": "festbeißen",
    "festbeißende": "festbeißend",
    "festbeißendem": "festbeißend",
    "festbeißenden": "festbeißend",
    "festbeißender": "festbeißend",
    "festbeißendes": "festbeißend",
    "festbeißest": "festbeißen",
    "festbeißet": "festbeißen",
    "festbeißt": "festbeißen",
    "festbisse": "festbeißen",
    "festbissen": "festbeißen",
    "festbissest": "festbeißen",
    "festbisset": "festbeißen",
    "festbiß": "festbeißen",
    "festbißt": "festbeißen",
    "festem": "fest",
    "festen": "fest",
    "fester": "fest",
    "festere": "fest",
    "festerem": "fest",
    "festeren": "fest",
    "festerer": "fest",
    "festeres": "fest",
    "festes": "fest",
    "festestem": "fest",
    "festesten": "fest",
    "festester": "fest",
    "festestes": "fest",
    "festfahre": "festfahren",
    "festfahrend": "festfahren",
    "festfahrende": "festfahrend",
    "festfahrendem": "festfahrend",
    "festfahrenden": "festfahrend",
    "festfahrender": "festfahrend",
    "festfahrendere": "festfahrend",
    "festfahrenderem": "festfahrend",
    "festfahrenderen": "festfahrend",
    "festfahrenderer": "festfahrend",
    "festfahrenderes": "festfahrend",
    "festfahrendes": "festfahrend",
    "festfahrendste": "festfahrend",
    "festfahrendstem": "festfahrend",
    "festfahrendsten": "festfahrend",
    "festfahrendster": "festfahrend",
    "festfahrendstes": "festfahrend",
    "festfahrest": "festfahren",
    "festfahret": "festfahren",
    "festfahrt": "festfahren",
    "festfraß": "festfressen",
    "festfraßen": "festfressen",
    "festfraßt": "festfressen",
    "festfresse": "festfressen",
    "festfressend": "festfressen",
    "festfressende": "festfressend",
    "festfressendem": "festfressend",
    "festfressenden": "festfressend",
    "festfressender": "festfressend",
    "festfressendes": "festfressend",
    "festfressest": "festfressen",
    "festfresset": "festfressen",
    "festfreßt": "festfressen",
    "festfrißt": "festfressen",
    "festfräße": "festfressen",
    "festfräßen": "festfressen",
    "festfräßest": "festfressen",
    "festfräßet": "festfressen",
    "festfuhr": "festfahren",
    "festfuhren": "festfahren",
    "festfuhrst": "festfahren",
    "festfuhrt": "festfahren",
    "festfährst": "festfahren",
    "festfährt": "festfahren",
    "festführe": "festfahren",
    "festführen": "festfahren",
    "festführest": "festfahren",
    "festführet": "festfahren",
    "festgebissen": "festbeißen",
    "festgebissene": "festgebissen",
    "festgebissenem": "festgebissen",
    "festgebissenen": "festgebissen",
    "festgebissener": "festgebissen",
    "festgebissenes": "festgebissen",
    "festgefahren": "festfahren",
    "festgefahrene": "festgefahren",
    "festgefahrenem": "festgefahren",
    "festgefahrenen": "festgefahren",
    "festgefahrener": "festgefahren",
    "festgefahrenere": "festgefahren",
    "festgefahrenerem": "festgefahren",
    "festgefahreneren": "festgefahren",
    "festgefahrenerer": "festgefahren",
    "festgefahreneres": "festgefahren",
    "festgefahrenes": "festgefahren",
    "festgefahrenste": "festgefahren",
    "festgefahrenstem": "festgefahren",
    "festgefahrensten": "festgefahren",
    "festgefahrenster": "festgefahren",
    "festgefahrenstes": "festgefahren",
    "festgefressen": "festfressen",
    "festgefressene": "festgefressen",
    "festgefressenem": "festgefressen",
    "festgefressenen": "festgefressen",
    "festgefressener": "festgefressen",
    "festgefressenes": "festgefressen",
    "festgehakt": "festhaken",
    "festgehakte": "festgehakt",
    "festgehaktem": "festgehakt",
    "festgehakten": "festgehakt",
    "festgehakter": "festgehakt",
    "festgehaktes": "festgehakt",
    "festgehalten": "festhalten",
    "festgehaltene": "festgehalten",
    "festgehaltenem": "festgehalten",
    "festgehaltenen": "festgehalten",
    "festgehaltener": "festgehalten",
    "festgehaltenes": "festgehalten",
    "festgeheftet": "festheften",
    "festgeheftete": "festgeheftet",
    "festgeheftetem": "festgeheftet",
    "festgehefteten": "festgeheftet",
    "festgehefteter": "festgeheftet",
    "festgeheftetes": "festgeheftet",
    "festgekeilt": "festkeilen",
    "festgekeilte": "festgekeilt",
    "festgekeiltem": "festgekeilt",
    "festgekeilten": "festgekeilt",
    "festgekeilter": "festgekeilt",
    "festgekeiltere": "festgekeilt",
    "festgekeilterem": "festgekeilt",
    "festgekeilteren": "festgekeilt",
    "festgekeilterer": "festgekeilt",
    "festgekeilteres": "festgekeilt",
    "festgekeiltes": "festgekeilt",
    "festgekeilteste": "festgekeilt",
    "festgekeiltestem": "festgekeilt",
    "festgekeiltesten": "festgekeilt",
    "festgekeiltester": "festgekeilt",
    "festgekeiltestes": "festgekeilt",
    "festgeklammert": "festklammern",
    "festgeklammerte": "festgeklammert",
    "festgeklammertem": "festgeklammert",
    "festgeklammerten": "festgeklammert",
    "festgeklammerter": "festgeklammert",
    "festgeklammertere": "festgeklammert",
    "festgeklammerterem": "festgeklammert",
    "festgeklammerteren": "festgeklammert",
    "festgeklammerterer": "festgeklammert",
    "festgeklammerteres": "festgeklammert",
    "festgeklammertes": "festgeklammert",
    "festgeklammerteste": "festgeklammert",
    "festgeklammertestem": "festgeklammert",
    "festgeklammertesten": "festgeklammert",
    "festgeklammertester": "festgeklammert",
    "festgeklammertestes": "festgeklammert",
    "festgeklebt": "festkleben",
    "festgeklebte": "festgeklebt",
    "festgeklebtem": "festgeklebt",
    "festgeklebten": "festgeklebt",
    "festgeklebter": "festgeklebt",
    "festgeklebtere": "festgeklebt",
    "festgeklebterem": "festgeklebt",
    "festgeklebteren": "festgeklebt",
    "festgeklebterer": "festgeklebt",
    "festgeklebteres": "festgeklebt",
    "festgeklebtes": "festgeklebt",
    "festgeklebteste": "festgeklebt",
    "festgeklebtestem": "festgeklebt",
    "festgeklebtesten": "festgeklebt",
    "festgeklebtester": "festgeklebt",
    "festgeklebtestes": "festgeklebt",
    "festgeklemmt": "festklemmen",
    "festgeklemmte": "festgeklemmt",
    "festgeklemmtem": "festgeklemmt",
    "festgeklemmten": "festgeklemmt",
    "festgeklemmter": "festgeklemmt",
    "festgeklemmtere": "festgeklemmt",
    "festgeklemmterem": "festgeklemmt",
    "festgeklemmteren": "festgeklemmt",
    "festgeklemmterer": "festgeklemmt",
    "festgeklemmteres": "festgeklemmt",
    "festgeklemmtes": "festgeklemmt",
    "festgeklemmteste": "festgeklemmt",
    "festgeklemmtestem": "festgeklemmt",
    "festgeklemmtesten": "festgeklemmt",
    "festgeklemmtester": "festgeklemmt",
    "festgeklemmtestes": "festgeklemmt",
    "festgeklopft": "festklopfen",
    "festgeklopfte": "festgeklopft",
    "festgeklopftem": "festgeklopft",
    "festgeklopften": "festgeklopft",
    "festgeklopfter": "festgeklopft",
    "festgeklopftere": "festgeklopft",
    "festgeklopfterem": "festgeklopft",
    "festgeklopfteren": "festgeklopft",
    "festgeklopfterer": "festgeklopft",
    "festgeklopfteres": "festgeklopft",
    "festgeklopftes": "festgeklopft",
    "festgeklopfteste": "festgeklopft",
    "festgeklopftestem": "festgeklopft",
    "festgeklopftesten": "festgeklopft",
    "festgeklopftester": "festgeklopft",
    "festgeklopftestes": "festgeklopft",
    "festgelaufen": "festlaufen",
    "festgelaufene": "festgelaufen",
    "festgelaufenem": "festgelaufen",
    "festgelaufenen": "festgelaufen",
    "festgelaufener": "festgelaufen",
    "festgelaufenere": "festgelaufen",
    "festgelaufenerem": "festgelaufen",
    "festgelaufeneren": "festgelaufen",
    "festgelaufenerer": "festgelaufen",
    "festgelaufeneres": "festgelaufen",
    "festgelaufenes": "festgelaufen",
    "festgelaufenste": "festgelaufen",
    "festgelaufenstem": "festgelaufen",
    "festgelaufensten": "festgelaufen",
    "festgelaufenster": "festgelaufen",
    "festgelaufenstes": "festgelaufen",
    "festgelegen": "festliegen",
    "festgelegene": "festgelegen",
    "festgelegenem": "festgelegen",
    "festgelegenen": "festgelegen",
    "festgelegener": "festgelegen",
    "festgelegenes": "festgelegen",
    "festgelegt": "festlegen",
    "festgelegte": "festgelegt",
    "festgelegtem": "festgelegt",
    "festgelegten": "festgelegt",
    "festgelegter": "festgelegt",
    "festgelegtere": "festgelegt",
    "festgelegterem": "festgelegt",
    "festgelegteren": "festgelegt",
    "festgelegterer": "festgelegt",
    "festgelegteres": "festgelegt",
    "festgelegtes": "festgelegt",
    "festgelegteste": "festgelegt",
    "festgelegtestem": "festgelegt",
    "festgelegtesten": "festgelegt",
    "festgelegtester": "festgelegt",
    "festgelegtestes": "festgelegt",
    "festgelesen": "festlesen",
    "festgelesene": "festgelesen",
    "festgelesenem": "festgelesen",
    "festgelesenen": "festgelesen",
    "festgelesener": "festgelesen",
    "festgelesenes": "festgelesen",
    "festgemacht": "festmachen",
    "festgemachte": "festgemacht",
    "festgemachtem": "festgemacht",
    "festgemachten": "festgemacht",
    "festgemachter": "festgemacht",
    "festgemachtes": "festgemacht",
    "festgenagelt": "festnageln",
    "festgenagelte": "festgenagelt",
    "festgenageltem": "festgenagelt",
    "festgenagelten": "festgenagelt",
    "festgenagelter": "festgenagelt",
    "festgenageltes": "festgenagelt",
    "festgenommen": "festnehmen",
    "festgenommene": "festgenommen",
    "festgenommenem": "festgenommen",
    "festgenommenen": "festgenommen",
    "festgenommener": "festgenommen",
    "festgenommenes": "festgenommen",
    "festgeschraubt": "festschrauben",
    "festgeschraubte": "festgeschraubt",
    "festgeschraubtem": "festgeschraubt",
    "festgeschraubten": "festgeschraubt",
    "festgeschraubter": "festgeschraubt",
    "festgeschraubtere": "festgeschraubt",
    "festgeschraubterem": "festgeschraubt",
    "festgeschraubteren": "festgeschraubt",
    "festgeschraubterer": "festgeschraubt",
    "festgeschraubteres": "festgeschraubt",
    "festgeschraubtes": "festgeschraubt",
    "festgeschraubteste": "festgeschraubt",
    "festgeschraubtestem": "festgeschraubt",
    "festgeschraubtesten": "festgeschraubt",
    "festgeschraubtester": "festgeschraubt",
    "festgeschraubtestes": "festgeschraubt",
    "festgeschrieben": "festschreiben",
    "festgeschriebene": "festgeschrieben",
    "festgeschriebenem": "festgeschrieben",
    "festgeschriebenen": "festgeschrieben",
    "festgeschriebener": "festgeschrieben",
    "festgeschriebenes": "festgeschrieben",
    "festgesessen": "festsitzen",
    "festgesessene": "festgesessen",
    "festgesessenem": "festgesessen",
    "festgesessenen": "festgesessen",
    "festgesessener": "festgesessen",
    "festgesessenes": "festgesessen",
    "festgesetzt": "festsetzen",
    "festgesetzte": "festgesetzt",
    "festgesetztem": "festgesetzt",
    "festgesetzten": "festgesetzt",
    "festgesetzter": "festgesetzt",
    "festgesetztes": "festgesetzt",
    "festgestanden": "feststehen",
    "festgestandene": "festgestanden",
    "festgestandenem": "festgestanden",
    "festgestandenen": "festgestanden",
    "festgestandener": "festgestanden",
    "festgestandenes": "festgestanden",
    "festgesteckt": "feststecken",
    "festgesteckte": "festgesteckt",
    "festgestecktem": "festgesteckt",
    "festgesteckten": "festgesteckt",
    "festgesteckter": "festgesteckt",
    "festgestecktere": "festgesteckt",
    "festgesteckterem": "festgesteckt",
    "festgesteckteren": "festgesteckt",
    "festgesteckterer": "festgesteckt",
    "festgesteckteres": "festgesteckt",
    "festgestecktes": "festgesteckt",
    "festgesteckteste": "festgesteckt",
    "festgestecktestem": "festgesteckt",
    "festgestecktesten": "festgesteckt",
    "festgestecktester": "festgesteckt",
    "festgestecktestes": "festgesteckt",
    "festgestellt": "feststellen",
    "festgestellte": "festgestellt",
    "festgestelltem": "festgestellt",
    "festgestellten": "festgestellt",
    "festgestellter": "festgestellt",
    "festgestelltes": "festgestellt",
    "festgetreten": "festtreten",
    "festgetretene": "festgetreten",
    "festgetretenem": "festgetreten",
    "festgetretenen": "festgetreten",
    "festgetretener": "festgetreten",
    "festgetretenere": "festgetreten",
    "festgetretenerem": "festgetreten",
    "festgetreteneren": "festgetreten",
    "festgetretenerer": "festgetreten",
    "festgetreteneres": "festgetreten",
    "festgetretenes": "festgetreten",
    "festgetretenste": "festgetreten",
    "festgetretenstem": "festgetreten",
    "festgetretensten": "festgetreten",
    "festgetretenster": "festgetreten",
    "festgetretenstes": "festgetreten",
    "festgewurzelt": "festwurzeln",
    "festgewurzelte": "festgewurzelt",
    "festgewurzeltem": "festgewurzelt",
    "festgewurzelten": "festgewurzelt",
    "festgewurzelter": "festgewurzelt",
    "festgewurzeltere": "festgewurzelt",
    "festgewurzelterem": "festgewurzelt",
    "festgewurzelteren": "festgewurzelt",
    "festgewurzelterer": "festgewurzelt",
    "festgewurzelteres": "festgewurzelt",
    "festgewurzeltes": "festgewurzelt",
    "festgewurzelteste": "festgewurzelt",
    "festgewurzeltestem": "festgewurzelt",
    "festgewurzeltesten": "festgewurzelt",
    "festgewurzeltester": "festgewurzelt",
    "festgewurzeltestes": "festgewurzelt",
    "festhake": "festhaken",
    "festhakend": "festhaken",
    "festhakende": "festhakend",
    "festhakendem": "festhakend",
    "festhakenden": "festhakend",
    "festhakender": "festhakend",
    "festhakendes": "festhakend",
    "festhakest": "festhaken",
    "festhaket": "festhaken",
    "festhakst": "festhaken",
    "festhakt": "festhaken",
    "festhakte": "festhaken",
    "festhakten": "festhaken",
    "festhaktest": "festhaken",
    "festhaktet": "festhaken",
    "festhalte": "festhalten",
    "festhaltend": "festhalten",
    "festhaltende": "festhaltend",
    "festhaltendem": "festhaltend",
    "festhaltenden": "festhaltend",
    "festhaltender": "festhaltend",
    "festhaltendes": "festhaltend",
    "festhaltest": "festhalten",
    "festhaltet": "festhalten",
    "festhefte": "festheften",
    "festheftend": "festheften",
    "festheftende": "festheftend",
    "festheftendem": "festheftend",
    "festheftenden": "festheftend",
    "festheftender": "festheftend",
    "festheftendes": "festheftend",
    "festheftest": "festheften",
    "festheftet": "festheften",
    "festheftete": "festheften",
    "festhefteten": "festheften",
    "festheftetest": "festheften",
    "festheftetet": "festheften",
    "festhielt": "festhalten",
    "festhielte": "festhalten",
    "festhielten": "festhalten",
    "festhieltest": "festhalten",
    "festhieltet": "festhalten",
    "festhält": "festhalten",
    "festhältst": "festhalten",
    "festige": "festigen",
    "festigend": "festigen",
    "festigende": "festigend",
    "festigendem": "festigend",
    "festigenden": "festigend",
    "festigender": "festigend",
    "festigendere": "festigend",
    "festigenderem": "festigend",
    "festigenderen": "festigend",
    "festigenderer": "festigend",
    "festigenderes": "festigend",
    "festigendes": "festigend",
    "festigendste": "festigend",
    "festigendstem": "festigend",
    "festigendsten": "festigend",
    "festigendster": "festigend",
    "festigendstes": "festigend",
    "festigest": "festigen",
    "festiget": "festigen",
    "festigst": "festigen",
    "festigt": "festigen",
    "festigte": "festigen",
    "festigten": "festigen",
    "festigtest": "festigen",
    "festigtet": "festigen",
    "festkeile": "festkeilen",
    "festkeilend": "festkeilen",
    "festkeilende": "festkeilend",
    "festkeilendem": "festkeilend",
    "festkeilenden": "festkeilend",
    "festkeilender": "festkeilend",
    "festkeilendere": "festkeilend",
    "festkeilenderem": "festkeilend",
    "festkeilenderen": "festkeilend",
    "festkeilenderer": "festkeilend",
    "festkeilenderes": "festkeilend",
    "festkeilendes": "festkeilend",
    "festkeilendste": "festkeilend",
    "festkeilendstem": "festkeilend",
    "festkeilendsten": "festkeilend",
    "festkeilendster": "festkeilend",
    "festkeilendstes": "festkeilend",
    "festkeilest": "festkeilen",
    "festkeilet": "festkeilen",
    "festkeilst": "festkeilen",
    "festkeilt": "festkeilen",
    "festkeilte": "festkeilen",
    "festkeilten": "festkeilen",
    "festkeiltest": "festkeilen",
    "festkeiltet": "festkeilen",
    "festklammere": "festklammern",
    "festklammernd": "festklammern",
    "festklammernde": "festklammernd",
    "festklammerndem": "festklammernd",
    "festklammernden": "festklammernd",
    "festklammernder": "festklammernd",
    "festklammerndere": "festklammernd",
    "festklammernderem": "festklammernd",
    "festklammernderen": "festklammernd",
    "festklammernderer": "festklammernd",
    "festklammernderes": "festklammernd",
    "festklammerndes": "festklammernd",
    "festklammerndste": "festklammernd",
    "festklammerndstem": "festklammernd",
    "festklammerndsten": "festklammernd",
    "festklammerndster": "festklammernd",
    "festklammerndstes": "festklammernd",
    "festklammerst": "festklammern",
    "festklammert": "festklammern",
    "festklammerte": "festklammern",
    "festklammerten": "festklammern",
    "festklammertest": "festklammern",
    "festklammertet": "festklammern",
    "festklebe": "festkleben",
    "festklebend": "festkleben",
    "festklebende": "festklebend",
    "festklebendem": "festklebend",
    "festklebenden": "festklebend",
    "festklebender": "festklebend",
    "festklebendere": "festklebend",
    "festklebenderem": "festklebend",
    "festklebenderen": "festklebend",
    "festklebenderer": "festklebend",
    "festklebenderes": "festklebend",
    "festklebendes": "festklebend",
    "festklebendste": "festklebend",
    "festklebendstem": "festklebend",
    "festklebendsten": "festklebend",
    "festklebendster": "festklebend",
    "festklebendstes": "festklebend",
    "festklebest": "festkleben",
    "festklebet": "festkleben",
    "festklebst": "festkleben",
    "festklebt": "festkleben",
    "festklebte": "festkleben",
    "festklebten": "festkleben",
    "festklebtest": "festkleben",
    "festklebtet": "festkleben",
    "festklemme": "festklemmen",
    "festklemmend": "festklemmen",
    "festklemmende": "festklemmend",
    "festklemmendem": "festklemmend",
    "festklemmenden": "festklemmend",
    "festklemmender": "festklemmend",
    "festklemmendere": "festklemmend",
    "festklemmenderem": "festklemmend",
    "festklemmenderen": "festklemmend",
    "festklemmenderer": "festklemmend",
    "festklemmenderes": "festklemmend",
    "festklemmendes": "festklemmend",
    "festklemmendste": "festklemmend",
    "festklemmendstem": "festklemmend",
    "festklemmendsten": "festklemmend",
    "festklemmendster": "festklemmend",
    "festklemmendstes": "festklemmend",
    "festklemmest": "festklemmen",
    "festklemmet": "festklemmen",
    "festklemmst": "festklemmen",
    "festklemmt": "festklemmen",
    "festklemmte": "festklemmen",
    "festklemmten": "festklemmen",
    "festklemmtest": "festklemmen",
    "festklemmtet": "festklemmen",
    "festklopfe": "festklopfen",
    "festklopfend": "festklopfen",
    "festklopfende": "festklopfend",
    "festklopfendem": "festklopfend",
    "festklopfenden": "festklopfend",
    "festklopfender": "festklopfend",
    "festklopfendere": "festklopfend",
    "festklopfenderem": "festklopfend",
    "festklopfenderen": "festklopfend",
    "festklopfenderer": "festklopfend",
    "festklopfenderes": "festklopfend",
    "festklopfendes": "festklopfend",
    "festklopfendste": "festklopfend",
    "festklopfendstem": "festklopfend",
    "festklopfendsten": "festklopfend",
    "festklopfendster": "festklopfend",
    "festklopfendstes": "festklopfend",
    "festklopfest": "festklopfen",
    "festklopfet": "festklopfen",
    "festklopfst": "festklopfen",
    "festklopft": "festklopfen",
    "festklopfte": "festklopfen",
    "festklopften": "festklopfen",
    "festklopftest": "festklopfen",
    "festklopftet": "festklopfen",
    "festlag": "festliegen",
    "festlagen": "festliegen",
    "festlagst": "festliegen",
    "festlagt": "festliegen",
    "festlas": "festlesen",
    "festlasen": "festlesen",
    "festlast": "festlesen",
    "festlaufe": "festlaufen",
    "festlaufend": "festlaufen",
    "festlaufende": "festlaufend",
    "festlaufendem": "festlaufend",
    "festlaufenden": "festlaufend",
    "festlaufender": "festlaufend",
    "festlaufendere": "festlaufend",
    "festlaufenderem": "festlaufend",
    "festlaufenderen": "festlaufend",
    "festlaufenderer": "festlaufend",
    "festlaufenderes": "festlaufend",
    "festlaufendes": "festlaufend",
    "festlaufendste": "festlaufend",
    "festlaufendstem": "festlaufend",
    "festlaufendsten": "festlaufend",
    "festlaufendster": "festlaufend",
    "festlaufendstes": "festlaufend",
    "festlaufest": "festlaufen",
    "festlaufet": "festlaufen",
    "festlauft": "festlaufen",
    "festlege": "festlegen",
    "festlegend": "festlegen",
    "festlegende": "festlegend",
    "festlegendem": "festlegend",
    "festlegenden": "festlegend",
    "festlegender": "festlegend",
    "festlegendes": "festlegend",
    "festlegest": "festlegen",
    "festleget": "festlegen",
    "festlegst": "festlegen",
    "festlegt": "festlegen",
    "festlegte": "festlegen",
    "festlegten": "festlegen",
    "festlegtest": "festlegen",
    "festlegtet": "festlegen",
    "festlese": "festlesen",
    "festlesend": "festlesen",
    "festlesende": "festlesend",
    "festlesendem": "festlesend",
    "festlesenden": "festlesend",
    "festlesender": "festlesend",
    "festlesendes": "festlesend",
    "festlesest": "festlesen",
    "festleset": "festlesen",
    "festlest": "festlesen",
    "festliche": "festlich",
    "festlichem": "festlich",
    "festlichen": "festlich",
    "festlicher": "festlich",
    "festlichere": "festlich",
    "festlicherem": "festlich",
    "festlicheren": "festlich",
    "festlicherer": "festlich",
    "festlicheres": "festlich",
    "festliches": "festlich",
    "festlichste": "festlich",
    "festlichstem": "festlich",
    "festlichsten": "festlich",
    "festlichster": "festlich",
    "festlichstes": "festlich",
    "festlief": "festlaufen",
    "festliefe": "festlaufen",
    "festliefen": "festlaufen",
    "festliefest": "festlaufen",
    "festliefet": "festlaufen",
    "festliefst": "festlaufen",
    "festlieft": "festlaufen",
    "festliege": "festliegen",
    "festliegend": "festliegen",
    "festliegende": "festliegend",
    "festliegendem": "festliegend",
    "festliegenden": "festliegend",
    "festliegender": "festliegend",
    "festliegendes": "festliegend",
    "festliegest": "festliegen",
    "festlieget": "festliegen",
    "festliegst": "festliegen",
    "festliegt": "festliegen",
    "festliest": "festlesen",
    "festläge": "festliegen",
    "festlägen": "festliegen",
    "festlägest": "festliegen",
    "festläget": "festliegen",
    "festläse": "festlesen",
    "festläsen": "festlesen",
    "festläsest": "festlesen",
    "festläset": "festlesen",
    "festläufst": "festlaufen",
    "festläuft": "festlaufen",
    "festmache": "festmachen",
    "festmachend": "festmachen",
    "festmachende": "festmachend",
    "festmachendem": "festmachend",
    "festmachenden": "festmachend",
    "festmachender": "festmachend",
    "festmachendes": "festmachend",
    "festmachest": "festmachen",
    "festmachet": "festmachen",
    "festmachst": "festmachen",
    "festmacht": "festmachen",
    "festmachte": "festmachen",
    "festmachten": "festmachen",
    "festmachtest": "festmachen",
    "festmachtet": "festmachen",
    "festnagele": "festnageln",
    "festnagelnd": "festnageln",
    "festnagelnde": "festnagelnd",
    "festnagelndem": "festnagelnd",
    "festnagelnden": "festnagelnd",
    "festnagelnder": "festnagelnd",
    "festnagelndes": "festnagelnd",
    "festnagelst": "festnageln",
    "festnagelt": "festnageln",
    "festnagelte": "festnageln",
    "festnagelten": "festnageln",
    "festnageltest": "festnageln",
    "festnageltet": "festnageln",
    "festnagle": "festnageln",
    "festnahm": "festnehmen",
    "festnahmst": "festnehmen",
    "festnahmt": "festnehmen",
    "festnehme": "festnehmen",
    "festnehmend": "festnehmen",
    "festnehmende": "festnehmend",
    "festnehmendem": "festnehmend",
    "festnehmenden": "festnehmend",
    "festnehmender": "festnehmend",
    "festnehmendes": "festnehmend",
    "festnehmest": "festnehmen",
    "festnehmet": "festnehmen",
    "festnehmt": "festnehmen",
    "festnimmst": "festnehmen",
    "festnimmt": "festnehmen",
    "festnähme": "festnehmen",
    "festnähmen": "festnehmen",
    "festnähmest": "festnehmen",
    "festnähmet": "festnehmen",
    "festsaß": "festsitzen",
    "festsaßen": "festsitzen",
    "festsaßt": "festsitzen",
    "festschraube": "festschrauben",
    "festschraubend": "festschrauben",
    "festschraubende": "festschraubend",
    "festschraubendem": "festschraubend",
    "festschraubenden": "festschraubend",
    "festschraubender": "festschraubend",
    "festschraubendere": "festschraubend",
    "festschraubenderem": "festschraubend",
    "festschraubenderen": "festschraubend",
    "festschraubenderer": "festschraubend",
    "festschraubenderes": "festschraubend",
    "festschraubendes": "festschraubend",
    "festschraubendste": "festschraubend",
    "festschraubendstem": "festschraubend",
    "festschraubendsten": "festschraubend",
    "festschraubendster": "festschraubend",
    "festschraubendstes": "festschraubend",
    "festschraubest": "festschrauben",
    "festschraubet": "festschrauben",
    "festschraubst": "festschrauben",
    "festschraubt": "festschrauben",
    "festschraubte": "festschrauben",
    "festschraubten": "festschrauben",
    "festschraubtest": "festschrauben",
    "festschraubtet": "festschrauben",
    "festschreibe": "festschreiben",
    "festschreibend": "festschreiben",
    "festschreibende": "festschreibend",
    "festschreibendem": "festschreibend",
    "festschreibenden": "festschreibend",
    "festschreibender": "festschreibend",
    "festschreibendes": "festschreibend",
    "festschreibest": "festschreiben",
    "festschreibet": "festschreiben",
    "festschreibst": "festschreiben",
    "festschreibt": "festschreiben",
    "festschrieb": "festschreiben",
    "festschriebe": "festschreiben",
    "festschrieben": "festschreiben",
    "festschriebest": "festschreiben",
    "festschriebet": "festschreiben",
    "festschriebst": "festschreiben",
    "festschriebt": "festschreiben",
    "festsetze": "festsetzen",
    "festsetzend": "festsetzen",
    "festsetzende": "festsetzend",
    "festsetzendem": "festsetzend",
    "festsetzenden": "festsetzend",
    "festsetzender": "festsetzend",
    "festsetzendes": "festsetzend",
    "festsetzest": "festsetzen",
    "festsetzet": "festsetzen",
    "festsetzt": "festsetzen",
    "festsetzte": "festsetzen",
    "festsetzten": "festsetzen",
    "festsetztest": "festsetzen",
    "festsetztet": "festsetzen",
    "festsitze": "festsitzen",
    "festsitzend": "festsitzen",
    "festsitzende": "festsitzend",
    "festsitzendem": "festsitzend",
    "festsitzenden": "festsitzend",
    "festsitzender": "festsitzend",
    "festsitzendes": "festsitzend",
    "festsitzest": "festsitzen",
    "festsitzet": "festsitzen",
    "festsitzt": "festsitzen",
    "feststand": "feststehen",
    "feststanden": "feststehen",
    "feststandest": "feststehen",
    "feststandet": "feststehen",
    "feststecke": "feststecken",
    "feststeckend": "feststecken",
    "feststeckende": "feststeckend",
    "feststeckendem": "feststeckend",
    "feststeckenden": "feststeckend",
    "feststeckender": "feststeckend",
    "feststeckendere": "feststeckend",
    "feststeckenderem": "feststeckend",
    "feststeckenderen": "feststeckend",
    "feststeckenderer": "feststeckend",
    "feststeckenderes": "feststeckend",
    "feststeckendes": "feststeckend",
    "feststeckendste": "feststeckend",
    "feststeckendstem": "feststeckend",
    "feststeckendsten": "feststeckend",
    "feststeckendster": "feststeckend",
    "feststeckendstes": "feststeckend",
    "feststeckest": "feststecken",
    "feststecket": "feststecken",
    "feststeckst": "feststecken",
    "feststeckt": "feststecken",
    "feststeckte": "feststecken",
    "feststeckten": "feststecken",
    "feststecktest": "feststecken",
    "feststecktet": "feststecken",
    "feststehe": "feststehen",
    "feststehend": "feststehen",
    "feststehende": "feststehend",
    "feststehendem": "feststehend",
    "feststehenden": "feststehend",
    "feststehender": "feststehend",
    "feststehendes": "feststehend",
    "feststehest": "feststehen",
    "feststehet": "feststehen",
    "feststehst": "feststehen",
    "feststeht": "feststehen",
    "feststelle": "feststellen",
    "feststellend": "feststellen",
    "feststellende": "feststellend",
    "feststellendem": "feststellend",
    "feststellenden": "feststellend",
    "feststellender": "feststellend",
    "feststellendere": "feststellend",
    "feststellenderem": "feststellend",
    "feststellenderen": "feststellend",
    "feststellenderer": "feststellend",
    "feststellenderes": "feststellend",
    "feststellendes": "feststellend",
    "feststellendste": "feststellend",
    "feststellendstem": "feststellend",
    "feststellendsten": "feststellend",
    "feststellendster": "feststellend",
    "feststellendstes": "feststellend",
    "feststellest": "feststellen",
    "feststellet": "feststellen",
    "feststellst": "feststellen",
    "feststellt": "feststellen",
    "feststellte": "feststellen",
    "feststellten": "feststellen",
    "feststelltest": "feststellen",
    "feststelltet": "feststellen",
    "feststünde": "feststehen",
    "feststünden": "feststehen",
    "feststündest": "feststehen",
    "feststündet": "feststehen",
    "festsäße": "festsitzen",
    "festsäßen": "festsitzen",
    "festsäßest": "festsitzen",
    "festsäßet": "festsitzen",
    "festtrat": "festtreten",
    "festtraten": "festtreten",
    "festtratest": "festtreten",
    "festtratet": "festtreten",
    "festtrete": "festtreten",
    "festtretend": "festtreten",
    "festtretende": "festtretend",
    "festtretendem": "festtretend",
    "festtretenden": "festtretend",
    "festtretender": "festtretend",
    "festtretendere": "festtretend",
    "festtretenderem": "festtretend",
    "festtretenderen": "festtretend",
    "festtretenderer": "festtretend",
    "festtretenderes": "festtretend",
    "festtretendes": "festtretend",
    "festtretendste": "festtretend",
    "festtretendstem": "festtretend",
    "festtretendsten": "festtretend",
    "festtretendster": "festtretend",
    "festtretendstes": "festtretend",
    "festtretest": "festtreten",
    "festtretet": "festtreten",
    "festtritt": "festtreten",
    "festtrittst": "festtreten",
    "festträte": "festtreten",
    "festträten": "festtreten",
    "festträtest": "festtreten",
    "festträtet": "festtreten",
    "festverzinslichem": "festverzinslich",
    "festverzinslichen": "festverzinslich",
    "festverzinslicher": "festverzinslich",
    "festverzinsliches": "festverzinslich",
    "festwurzele": "festwurzeln",
    "festwurzelnd": "festwurzeln",
    "festwurzelnde": "festwurzelnd",
    "festwurzelndem": "festwurzelnd",
    "festwurzelnden": "festwurzelnd",
    "festwurzelnder": "festwurzelnd",
    "festwurzelndere": "festwurzelnd",
    "festwurzelnderem": "festwurzelnd",
    "festwurzelnderen": "festwurzelnd",
    "festwurzelnderer": "festwurzelnd",
    "festwurzelnderes": "festwurzelnd",
    "festwurzelndes": "festwurzelnd",
    "festwurzelndste": "festwurzelnd",
    "festwurzelndstem": "festwurzelnd",
    "festwurzelndsten": "festwurzelnd",
    "festwurzelndster": "festwurzelnd",
    "festwurzelndstes": "festwurzelnd",
    "festwurzelst": "festwurzeln",
    "festwurzelt": "festwurzeln",
    "festwurzelte": "festwurzeln",
    "festwurzelten": "festwurzeln",
    "festwurzeltest": "festwurzeln",
    "festwurzeltet": "festwurzeln",
    "festwurzle": "festwurzeln",
    "festzubeißen": "festbeißen",
    "festzufahren": "festfahren",
    "festzufressen": "festfressen",
    "festzuhaken": "festhaken",
    "festzuhalten": "festhalten",
    "festzuheften": "festheften",
    "festzukeilen": "festkeilen",
    "festzuklammern": "festklammern",
    "festzukleben": "festkleben",
    "festzuklemmen": "festklemmen",
    "festzuklopfen": "festklopfen",
    "festzulaufen": "festlaufen",
    "festzulegen": "festlegen",
    "festzulesen": "festlesen",
    "festzuliegen": "festliegen",
    "festzumachen": "festmachen",
    "festzunageln": "festnageln",
    "festzunehmen": "festnehmen",
    "festzuschrauben": "festschrauben",
    "festzuschreiben": "festschreiben",
    "festzusetzen": "festsetzen",
    "festzusitzen": "festsitzen",
    "festzustecken": "feststecken",
    "festzustehen": "feststehen",
    "festzustellen": "feststellen",
    "festzutreten": "festtreten",
    "festzuwurzeln": "festwurzeln",
    "fetischisiere": "fetischisieren",
    "fetischisierend": "fetischisieren",
    "fetischisierende": "fetischisierend",
    "fetischisierendem": "fetischisierend",
    "fetischisierenden": "fetischisierend",
    "fetischisierender": "fetischisierend",
    "fetischisierendere": "fetischisierend",
    "fetischisierenderem": "fetischisierend",
    "fetischisierenderen": "fetischisierend",
    "fetischisierenderer": "fetischisierend",
    "fetischisierenderes": "fetischisierend",
    "fetischisierendes": "fetischisierend",
    "fetischisierendste": "fetischisierend",
    "fetischisierendstem": "fetischisierend",
    "fetischisierendsten": "fetischisierend",
    "fetischisierendster": "fetischisierend",
    "fetischisierendstes": "fetischisierend",
    "fetischisierest": "fetischisieren",
    "fetischisieret": "fetischisieren",
    "fetischisierst": "fetischisieren",
    "fetischisiert": "fetischisieren",
    "fetischisierte": "fetischisieren",
    "fetischisiertem": "fetischisiert",
    "fetischisierten": "fetischisieren",
    "fetischisierter": "fetischisiert",
    "fetischisiertere": "fetischisiert",
    "fetischisierterem": "fetischisiert",
    "fetischisierteren": "fetischisiert",
    "fetischisierterer": "fetischisiert",
    "fetischisierteres": "fetischisiert",
    "fetischisiertes": "fetischisiert",
    "fetischisiertest": "fetischisieren",
    "fetischisiertestem": "fetischisiert",
    "fetischisiertesten": "fetischisiert",
    "fetischisiertester": "fetischisiert",
    "fetischisiertestes": "fetischisiert",
    "fetischisiertet": "fetischisieren",
    "fetischistische": "fetischistisch",
    "fetischistischem": "fetischistisch",
    "fetischistischen": "fetischistisch",
    "fetischistischer": "fetischistisch",
    "fetischistisches": "fetischistisch",
    "fettarme": "fettarm",
    "fettarmem": "fettarm",
    "fettarmen": "fettarm",
    "fettarmer": "fettarm",
    "fettarmes": "fettarm",
    "fettbäuchige": "fettbäuchig",
    "fettbäuchigem": "fettbäuchig",
    "fettbäuchigen": "fettbäuchig",
    "fettbäuchiger": "fettbäuchig",
    "fettbäuchigere": "fettbäuchig",
    "fettbäuchigerem": "fettbäuchig",
    "fettbäuchigeren": "fettbäuchig",
    "fettbäuchigerer": "fettbäuchig",
    "fettbäuchigeres": "fettbäuchig",
    "fettbäuchiges": "fettbäuchig",
    "fettbäuchigste": "fettbäuchig",
    "fettbäuchigstem": "fettbäuchig",
    "fettbäuchigsten": "fettbäuchig",
    "fettbäuchigster": "fettbäuchig",
    "fettbäuchigstes": "fettbäuchig",
    "fette": "fett",
    "fettem": "fett",
    "fettend": "fetten",
    "fettende": "fettend",
    "fettendem": "fettend",
    "fettenden": "fettend",
    "fettender": "fettend",
    "fettendere": "fettend",
    "fettenderem": "fettend",
    "fettenderen": "fettend",
    "fettenderer": "fettend",
    "fettenderes": "fettend",
    "fettendes": "fettend",
    "fettendste": "fettend",
    "fettendstem": "fettend",
    "fettendsten": "fettend",
    "fettendster": "fettend",
    "fettendstes": "fettend",
    "fetter": "fett",
    "fettere": "fett",
    "fetterem": "fett",
    "fetteren": "fett",
    "fetterer": "fett",
    "fetteres": "fett",
    "fettes": "fett",
    "fettest": "fetten",
    "fetteste": "fett",
    "fettestem": "fett",
    "fettesten": "fett",
    "fettester": "fett",
    "fettestes": "fett",
    "fettet": "fetten",
    "fettete": "fetten",
    "fetteten": "fetten",
    "fettetest": "fetten",
    "fettetet": "fetten",
    "fettgedrucktem": "fettgedruckt",
    "fettgedruckten": "fettgedruckt",
    "fettgedruckter": "fettgedruckt",
    "fettgedrucktere": "fettgedruckt",
    "fettgedruckterem": "fettgedruckt",
    "fettgedruckteren": "fettgedruckt",
    "fettgedruckterer": "fettgedruckt",
    "fettgedruckteres": "fettgedruckt",
    "fettgedrucktes": "fettgedruckt",
    "fettgedruckteste": "fettgedruckt",
    "fettgedrucktestem": "fettgedruckt",
    "fettgedrucktesten": "fettgedruckt",
    "fettgedrucktester": "fettgedruckt",
    "fettgedrucktestes": "fettgedruckt",
    "fettige": "fettig",
    "fettigem": "fettig",
    "fettigen": "fettig",
    "fettiger": "fettig",
    "fettigere": "fettig",
    "fettigerem": "fettig",
    "fettigeren": "fettig",
    "fettigerer": "fettig",
    "fettigeres": "fettig",
    "fettiges": "fettig",
    "fettigste": "fettig",
    "fettigstem": "fettig",
    "fettigsten": "fettig",
    "fettigster": "fettig",
    "fettigstes": "fettig",
    "fettleibige": "fettleibig",
    "fettleibigem": "fettleibig",
    "fettleibigen": "fettleibig",
    "fettleibiger": "fettleibig",
    "fettleibigere": "fettleibig",
    "fettleibigerem": "fettleibig",
    "fettleibigeren": "fettleibig",
    "fettleibigerer": "fettleibig",
    "fettleibigeres": "fettleibig",
    "fettleibiges": "fettleibig",
    "fettleibigste": "fettleibig",
    "fettleibigstem": "fettleibig",
    "fettleibigsten": "fettleibig",
    "fettleibigster": "fettleibig",
    "fettleibigstes": "fettleibig",
    "fettlösliche": "fettlöslich",
    "fettlöslichem": "fettlöslich",
    "fettlöslichen": "fettlöslich",
    "fettlöslicher": "fettlöslich",
    "fettlöslichere": "fettlöslich",
    "fettlöslicherem": "fettlöslich",
    "fettlöslicheren": "fettlöslich",
    "fettlöslicherer": "fettlöslich",
    "fettlöslicheres": "fettlöslich",
    "fettlösliches": "fettlöslich",
    "fettlöslichste": "fettlöslich",
    "fettlöslichstem": "fettlöslich",
    "fettlöslichsten": "fettlöslich",
    "fettlöslichster": "fettlöslich",
    "fettlöslichstes": "fettlöslich",
    "fettreiche": "fettreich",
    "fettreichem": "fettreich",
    "fettreichen": "fettreich",
    "fettreicher": "fettreich",
    "fettreichere": "fettreich",
    "fettreicherem": "fettreich",
    "fettreicheren": "fettreich",
    "fettreicherer": "fettreich",
    "fettreicheres": "fettreich",
    "fettreiches": "fettreich",
    "fettreichste": "fettreich",
    "fettreichstem": "fettreich",
    "fettreichsten": "fettreich",
    "fettreichster": "fettreich",
    "fettreichstes": "fettreich",
    "fetttriefendem": "fetttriefend",
    "fetttriefenden": "fetttriefend",
    "fetttriefender": "fetttriefend",
    "fetttriefendere": "fetttriefend",
    "fetttriefenderem": "fetttriefend",
    "fetttriefenderen": "fetttriefend",
    "fetttriefenderer": "fetttriefend",
    "fetttriefenderes": "fetttriefend",
    "fetttriefendes": "fetttriefend",
    "fetttriefendste": "fetttriefend",
    "fetttriefendstem": "fetttriefend",
    "fetttriefendsten": "fetttriefend",
    "fetttriefendster": "fetttriefend",
    "fetttriefendstes": "fetttriefend",
    "fettärmer": "fettarm",
    "fettärmere": "fettarm",
    "fettärmerem": "fettarm",
    "fettärmeren": "fettarm",
    "fettärmerer": "fettarm",
    "fettärmeres": "fettarm",
    "fettärmste": "fettarm",
    "fettärmstem": "fettarm",
    "fettärmsten": "fettarm",
    "fettärmster": "fettarm",
    "fettärmstes": "fettarm",
    "fetze": "fetzen",
    "fetzend": "fetzen",
    "fetzende": "fetzend",
    "fetzendem": "fetzend",
    "fetzenden": "fetzend",
    "fetzender": "fetzend",
    "fetzendere": "fetzend",
    "fetzenderem": "fetzend",
    "fetzenderen": "fetzend",
    "fetzenderer": "fetzend",
    "fetzenderes": "fetzend",
    "fetzendes": "fetzend",
    "fetzendste": "fetzend",
    "fetzendstem": "fetzend",
    "fetzendsten": "fetzend",
    "fetzendster": "fetzend",
    "fetzendstes": "fetzend",
    "fetzest": "fetzen",
    "fetzet": "fetzen",
    "fetzige": "fetzig",
    "fetzigem": "fetzig",
    "fetzigen": "fetzig",
    "fetziger": "fetzig",
    "fetzigere": "fetzig",
    "fetzigerem": "fetzig",
    "fetzigeren": "fetzig",
    "fetzigerer": "fetzig",
    "fetzigeres": "fetzig",
    "fetziges": "fetzig",
    "fetzigste": "fetzig",
    "fetzigstem": "fetzig",
    "fetzigsten": "fetzig",
    "fetzigster": "fetzig",
    "fetzigstes": "fetzig",
    "fetzt": "fetzen",
    "fetzte": "fetzen",
    "fetzten": "fetzen",
    "fetztest": "fetzen",
    "fetztet": "fetzen",
    "feuchte": "feucht",
    "feuchtem": "feucht",
    "feuchten": "feucht",
    "feuchtend": "feuchten",
    "feuchtende": "feuchtend",
    "feuchtendem": "feuchtend",
    "feuchtenden": "feuchtend",
    "feuchtender": "feuchtend",
    "feuchtendere": "feuchtend",
    "feuchtenderem": "feuchtend",
    "feuchtenderen": "feuchtend",
    "feuchtenderer": "feuchtend",
    "feuchtenderes": "feuchtend",
    "feuchtendes": "feuchtend",
    "feuchtendste": "feuchtend",
    "feuchtendstem": "feuchtend",
    "feuchtendsten": "feuchtend",
    "feuchtendster": "feuchtend",
    "feuchtendstes": "feuchtend",
    "feuchter": "feucht",
    "feuchtere": "feucht",
    "feuchterem": "feucht",
    "feuchteren": "feucht",
    "feuchterer": "feucht",
    "feuchteres": "feucht",
    "feuchtes": "feucht",
    "feuchtest": "feuchten",
    "feuchteste": "feucht",
    "feuchtestem": "feucht",
    "feuchtesten": "feucht",
    "feuchtester": "feucht",
    "feuchtestes": "feucht",
    "feuchtet": "feuchten",
    "feuchtete": "feuchten",
    "feuchteten": "feuchten",
    "feuchtetest": "feuchten",
    "feuchtetet": "feuchten",
    "feuchtfröhliche": "feuchtfröhlich",
    "feuchtfröhlichem": "feuchtfröhlich",
    "feuchtfröhlichen": "feuchtfröhlich",
    "feuchtfröhlicher": "feuchtfröhlich",
    "feuchtfröhlichere": "feuchtfröhlich",
    "feuchtfröhlicherem": "feuchtfröhlich",
    "feuchtfröhlicheren": "feuchtfröhlich",
    "feuchtfröhlicherer": "feuchtfröhlich",
    "feuchtfröhlicheres": "feuchtfröhlich",
    "feuchtfröhliches": "feuchtfröhlich",
    "feuchtfröhlichste": "feuchtfröhlich",
    "feuchtfröhlichstem": "feuchtfröhlich",
    "feuchtfröhlichsten": "feuchtfröhlich",
    "feuchtfröhlichster": "feuchtfröhlich",
    "feuchtfröhlichstes": "feuchtfröhlich",
    "feuchtwarmem": "feuchtwarm",
    "feuchtwarmen": "feuchtwarm",
    "feuchtwarmer": "feuchtwarm",
    "feuchtwarmes": "feuchtwarm",
    "feudale": "feudal",
    "feudalem": "feudal",
    "feudalen": "feudal",
    "feudaler": "feudal",
    "feudalere": "feudal",
    "feudalerem": "feudal",
    "feudaleren": "feudal",
    "feudalerer": "feudal",
    "feudaleres": "feudal",
    "feudales": "feudal",
    "feudalistische": "feudalistisch",
    "feudalistischem": "feudalistisch",
    "feudalistischen": "feudalistisch",
    "feudalistischer": "feudalistisch",
    "feudalistischere": "feudalistisch",
    "feudalistischerem": "feudalistisch",
    "feudalistischeren": "feudalistisch",
    "feudalistischerer": "feudalistisch",
    "feudalistischeres": "feudalistisch",
    "feudalistisches": "feudalistisch",
    "feudalistischste": "feudalistisch",
    "feudalistischstem": "feudalistisch",
    "feudalistischsten": "feudalistisch",
    "feudalistischster": "feudalistisch",
    "feudalistischstes": "feudalistisch",
    "feudalstem": "feudal",
    "feudalsten": "feudal",
    "feudalster": "feudal",
    "feudalstes": "feudal",
    "feuerbeständigem": "feuerbeständig",
    "feuerbeständigen": "feuerbeständig",
    "feuerbeständiger": "feuerbeständig",
    "feuerbeständigere": "feuerbeständig",
    "feuerbeständigerem": "feuerbeständig",
    "feuerbeständigeren": "feuerbeständig",
    "feuerbeständigerer": "feuerbeständig",
    "feuerbeständigeres": "feuerbeständig",
    "feuerbeständiges": "feuerbeständig",
    "feuerbeständigste": "feuerbeständig",
    "feuerbeständigstem": "feuerbeständig",
    "feuerbeständigsten": "feuerbeständig",
    "feuerbeständigster": "feuerbeständig",
    "feuerbeständigstes": "feuerbeständig",
    "feuere": "feuern",
    "feuerfeste": "feuerfest",
    "feuerfestem": "feuerfest",
    "feuerfesten": "feuerfest",
    "feuerfester": "feuerfest",
    "feuerfestere": "feuerfest",
    "feuerfesterem": "feuerfest",
    "feuerfesteren": "feuerfest",
    "feuerfesterer": "feuerfest",
    "feuerfesteres": "feuerfest",
    "feuerfestes": "feuerfest",
    "feuerfesteste": "feuerfest",
    "feuerfestestem": "feuerfest",
    "feuerfestesten": "feuerfest",
    "feuerfestester": "feuerfest",
    "feuerfestestes": "feuerfest",
    "feuernd": "feuern",
    "feuernde": "feuernd",
    "feuerndem": "feuernd",
    "feuernden": "feuernd",
    "feuernder": "feuernd",
    "feuerndere": "feuernd",
    "feuernderem": "feuernd",
    "feuernderen": "feuernd",
    "feuernderer": "feuernd",
    "feuernderes": "feuernd",
    "feuerndes": "feuernd",
    "feuerndste": "feuernd",
    "feuerndstem": "feuernd",
    "feuerndsten": "feuernd",
    "feuerndster": "feuernd",
    "feuerndstes": "feuernd",
    "feuerspeiendem": "feuerspeiend",
    "feuerspeienden": "feuerspeiend",
    "feuerspeiender": "feuerspeiend",
    "feuerspeiendes": "feuerspeiend",
    "feuerst": "feuern",
    "feuert": "feuern",
    "feuerte": "feuern",
    "feuerten": "feuern",
    "feuertest": "feuern",
    "feuertet": "feuern",
    "feurigem": "feurig",
    "feurigen": "feurig",
    "feuriger": "feurig",
    "feurigere": "feurig",
    "feurigerem": "feurig",
    "feurigeren": "feurig",
    "feurigerer": "feurig",
    "feurigeres": "feurig",
    "feuriges": "feurig",
    "feurigste": "feurig",
    "feurigstem": "feurig",
    "feurigsten": "feurig",
    "feurigster": "feurig",
    "feurigstes": "feurig",
    "ficht": "fechten",
    "fichtenem": "fichten",
    "fichtenen": "fichten",
    "fichtener": "fichten",
    "fichtenes": "fichten",
    "fichtst": "fechten",
    "fickrigem": "fickrig",
    "fickrigen": "fickrig",
    "fickriger": "fickrig",
    "fickrigere": "fickrig",
    "fickrigerem": "fickrig",
    "fickrigeren": "fickrig",
    "fickrigerer": "fickrig",
    "fickrigeres": "fickrig",
    "fickriges": "fickrig",
    "fickrigste": "fickrig",
    "fickrigstem": "fickrig",
    "fickrigsten": "fickrig",
    "fickrigster": "fickrig",
    "fickrigstes": "fickrig",
    "fiebere": "fiebern",
    "fieberfreie": "fieberfrei",
    "fieberfreiem": "fieberfrei",
    "fieberfreien": "fieberfrei",
    "fieberfreier": "fieberfrei",
    "fieberfreies": "fieberfrei",
    "fieberhafte": "fieberhaft",
    "fieberhaftem": "fieberhaft",
    "fieberhaften": "fieberhaft",
    "fieberhafter": "fieberhaft",
    "fieberhaftere": "fieberhaft",
    "fieberhafterem": "fieberhaft",
    "fieberhafteren": "fieberhaft",
    "fieberhafterer": "fieberhaft",
    "fieberhafteres": "fieberhaft",
    "fieberhaftes": "fieberhaft",
    "fieberhafteste": "fieberhaft",
    "fieberhaftestem": "fieberhaft",
    "fieberhaftesten": "fieberhaft",
    "fieberhaftester": "fieberhaft",
    "fieberhaftestes": "fieberhaft",
    "fieberige": "fieberig",
    "fieberigem": "fieberig",
    "fieberigen": "fieberig",
    "fieberiger": "fieberig",
    "fieberigere": "fieberig",
    "fieberigerem": "fieberig",
    "fieberigeren": "fieberig",
    "fieberigerer": "fieberig",
    "fieberigeres": "fieberig",
    "fieberiges": "fieberig",
    "fieberigste": "fieberig",
    "fieberigstem": "fieberig",
    "fieberigsten": "fieberig",
    "fieberigster": "fieberig",
    "fieberigstes": "fieberig",
    "fiebernd": "fiebern",
    "fiebernde": "fiebernd",
    "fieberndem": "fiebernd",
    "fiebernden": "fiebernd",
    "fiebernder": "fiebernd",
    "fieberndere": "fiebernd",
    "fiebernderem": "fiebernd",
    "fiebernderen": "fiebernd",
    "fiebernderer": "fiebernd",
    "fiebernderes": "fiebernd",
    "fieberndes": "fiebernd",
    "fieberndste": "fiebernd",
    "fieberndstem": "fiebernd",
    "fieberndsten": "fiebernd",
    "fieberndster": "fiebernd",
    "fieberndstes": "fiebernd",
    "fieberst": "fiebern",
    "fiebert": "fiebern",
    "fieberte": "fiebern",
    "fieberten": "fiebern",
    "fiebertest": "fiebern",
    "fiebertet": "fiebern",
    "fiebrige": "fiebrig",
    "fiebrigem": "fiebrig",
    "fiebrigen": "fiebrig",
    "fiebriger": "fiebrig",
    "fiebrigere": "fiebrig",
    "fiebrigerem": "fiebrig",
    "fiebrigeren": "fiebrig",
    "fiebrigerer": "fiebrig",
    "fiebrigeres": "fiebrig",
    "fiebriges": "fiebrig",
    "fiebrigste": "fiebrig",
    "fiebrigstem": "fiebrig",
    "fiebrigsten": "fiebrig",
    "fiebrigster": "fiebrig",
    "fiebrigstes": "fiebrig",
    "fiedele": "fiedeln",
    "fiedelnd": "fiedeln",
    "fiedelnde": "fiedelnd",
    "fiedelndem": "fiedelnd",
    "fiedelnden": "fiedelnd",
    "fiedelnder": "fiedelnd",
    "fiedelndere": "fiedelnd",
    "fiedelnderem": "fiedelnd",
    "fiedelnderen": "fiedelnd",
    "fiedelnderer": "fiedelnd",
    "fiedelnderes": "fiedelnd",
    "fiedelndes": "fiedelnd",
    "fiedelndste": "fiedelnd",
    "fiedelndstem": "fiedelnd",
    "fiedelndsten": "fiedelnd",
    "fiedelndster": "fiedelnd",
    "fiedelndstes": "fiedelnd",
    "fiedelst": "fiedeln",
    "fiedelt": "fiedeln",
    "fiedelte": "fiedeln",
    "fiedelten": "fiedeln",
    "fiedeltest": "fiedeln",
    "fiedeltet": "fiedeln",
    "fiedere": "fiedern",
    "fiedernd": "fiedern",
    "fiedernde": "fiedernd",
    "fiederndem": "fiedernd",
    "fiedernden": "fiedernd",
    "fiedernder": "fiedernd",
    "fiederndere": "fiedernd",
    "fiedernderem": "fiedernd",
    "fiedernderen": "fiedernd",
    "fiedernderer": "fiedernd",
    "fiedernderes": "fiedernd",
    "fiederndes": "fiedernd",
    "fiederndste": "fiedernd",
    "fiederndstem": "fiedernd",
    "fiederndsten": "fiedernd",
    "fiederndster": "fiedernd",
    "fiederndstes": "fiedernd",
    "fiederst": "fiedern",
    "fiedert": "fiedern",
    "fiederte": "fiedern",
    "fiederten": "fiedern",
    "fiedertest": "fiedern",
    "fiedertet": "fiedern",
    "fiedle": "fiedeln",
    "fiel": "fallen",
    "fiele": "fallen",
    "fielen": "fallen",
    "fielest": "fallen",
    "fielet": "fallen",
    "fielst": "fallen",
    "fielt": "fallen",
    "fiese": "fies",
    "fiesem": "fies",
    "fiesen": "fies",
    "fieser": "fies",
    "fiesere": "fies",
    "fieserem": "fies",
    "fieseren": "fies",
    "fieserer": "fies",
    "fieseres": "fies",
    "fieses": "fies",
    "fieseste": "fies",
    "fiesestem": "fies",
    "fiesesten": "fies",
    "fiesester": "fies",
    "fiesestes": "fies",
    "figuralem": "figural",
    "figuralen": "figural",
    "figuraler": "figural",
    "figurales": "figural",
    "fiktionalem": "fiktional",
    "fiktionalen": "fiktional",
    "fiktionaler": "fiktional",
    "fiktionales": "fiktional",
    "fiktivem": "fiktiv",
    "fiktiven": "fiktiv",
    "fiktiver": "fiktiv",
    "fiktivere": "fiktiv",
    "fiktiverem": "fiktiv",
    "fiktiveren": "fiktiv",
    "fiktiverer": "fiktiv",
    "fiktiveres": "fiktiv",
    "fiktives": "fiktiv",
    "fiktivste": "fiktiv",
    "fiktivstem": "fiktiv",
    "fiktivsten": "fiktiv",
    "fiktivster": "fiktiv",
    "fiktivstes": "fiktiv",
    "filetiere": "filetieren",
    "filetierend": "filetieren",
    "filetierende": "filetierend",
    "filetierendem": "filetierend",
    "filetierenden": "filetierend",
    "filetierender": "filetierend",
    "filetierendes": "filetierend",
    "filetierest": "filetieren",
    "filetieret": "filetieren",
    "filetierst": "filetieren",
    "filetiert": "filetieren",
    "filetierte": "filetieren",
    "filetiertem": "filetiert",
    "filetierten": "filetieren",
    "filetierter": "filetiert",
    "filetiertes": "filetiert",
    "filetiertest": "filetieren",
    "filetiertet": "filetieren",
    "filmend": "filmen",
    "filmende": "filmend",
    "filmendem": "filmend",
    "filmenden": "filmend",
    "filmender": "filmend",
    "filmendes": "filmend",
    "filmest": "filmen",
    "filmet": "filmen",
    "filmischem": "filmisch",
    "filmischen": "filmisch",
    "filmischer": "filmisch",
    "filmisches": "filmisch",
    "filmst": "filmen",
    "filmt": "filmen",
    "filmte": "filmen",
    "filmten": "filmen",
    "filmtest": "filmen",
    "filmtet": "filmen",
    "filtere": "filtern",
    "filternd": "filtern",
    "filternde": "filternd",
    "filterndem": "filternd",
    "filternden": "filternd",
    "filternder": "filternd",
    "filterndes": "filternd",
    "filterst": "filtern",
    "filtert": "filtern",
    "filterte": "filtern",
    "filterten": "filtern",
    "filtertest": "filtern",
    "filtertet": "filtern",
    "filze": "filzen",
    "filzend": "filzen",
    "filzende": "filzend",
    "filzendem": "filzend",
    "filzenden": "filzend",
    "filzender": "filzend",
    "filzendere": "filzend",
    "filzenderem": "filzend",
    "filzenderen": "filzend",
    "filzenderer": "filzend",
    "filzenderes": "filzend",
    "filzendes": "filzend",
    "filzendste": "filzend",
    "filzendstem": "filzend",
    "filzendsten": "filzend",
    "filzendster": "filzend",
    "filzendstes": "filzend",
    "filzest": "filzen",
    "filzet": "filzen",
    "filzige": "filzig",
    "filzigem": "filzig",
    "filzigen": "filzig",
    "filziger": "filzig",
    "filzigere": "filzig",
    "filzigerem": "filzig",
    "filzigeren": "filzig",
    "filzigerer": "filzig",
    "filzigeres": "filzig",
    "filziges": "filzig",
    "filzigste": "filzig",
    "filzigstem": "filzig",
    "filzigsten": "filzig",
    "filzigster": "filzig",
    "filzigstes": "filzig",
    "filzt": "filzen",
    "filzte": "filzen",
    "filzten": "filzen",
    "filztest": "filzen",
    "filztet": "filzen",
    "fimmelige": "fimmelig",
    "fimmeligem": "fimmelig",
    "fimmeligen": "fimmelig",
    "fimmeliger": "fimmelig",
    "fimmeligere": "fimmelig",
    "fimmeligerem": "fimmelig",
    "fimmeligeren": "fimmelig",
    "fimmeligerer": "fimmelig",
    "fimmeligeres": "fimmelig",
    "fimmeliges": "fimmelig",
    "fimmeligste": "fimmelig",
    "fimmeligstem": "fimmelig",
    "fimmeligsten": "fimmelig",
    "fimmeligster": "fimmelig",
    "fimmeligstes": "fimmelig",
    "finalem": "final",
    "finalen": "final",
    "finaler": "final",
    "finales": "final",
    "finanziellem": "finanziell",
    "finanziellen": "finanziell",
    "finanzieller": "finanziell",
    "finanzielles": "finanziell",
    "finanziere": "finanzieren",
    "finanzierend": "finanzieren",
    "finanzierende": "finanzierend",
    "finanzierendem": "finanzierend",
    "finanzierenden": "finanzierend",
    "finanzierender": "finanzierend",
    "finanzierendes": "finanzierend",
    "finanzierest": "finanzieren",
    "finanzieret": "finanzieren",
    "finanzierst": "finanzieren",
    "finanziert": "finanzieren",
    "finanzierte": "finanzieren",
    "finanziertem": "finanziert",
    "finanzierten": "finanzieren",
    "finanzierter": "finanziert",
    "finanziertes": "finanziert",
    "finanziertest": "finanzieren",
    "finanziertet": "finanzieren",
    "finanzkräftigem": "finanzkräftig",
    "finanzkräftigen": "finanzkräftig",
    "finanzkräftiger": "finanzkräftig",
    "finanzkräftigere": "finanzkräftig",
    "finanzkräftigerem": "finanzkräftig",
    "finanzkräftigeren": "finanzkräftig",
    "finanzkräftigerer": "finanzkräftig",
    "finanzkräftigeres": "finanzkräftig",
    "finanzkräftiges": "finanzkräftig",
    "finanzkräftigste": "finanzkräftig",
    "finanzkräftigstem": "finanzkräftig",
    "finanzkräftigsten": "finanzkräftig",
    "finanzkräftigster": "finanzkräftig",
    "finanzkräftigstes": "finanzkräftig",
    "finde": "finden",
    "findend": "finden",
    "findende": "findend",
    "findendem": "findend",
    "findenden": "findend",
    "findender": "findend",
    "findendes": "findend",
    "findest": "finden",
    "findet": "finden",
    "findige": "findig",
    "findigem": "findig",
    "findigen": "findig",
    "findiger": "findig",
    "findigere": "findig",
    "findigerem": "findig",
    "findigeren": "findig",
    "findigerer": "findig",
    "findigeres": "findig",
    "findiges": "findig",
    "findigste": "findig",
    "findigstem": "findig",
    "findigsten": "findig",
    "findigster": "findig",
    "findigstes": "findig",
    "fing": "fangen",
    "finge": "fangen",
    "fingen": "fangen",
    "fingerfertige": "fingerfertig",
    "fingerfertigem": "fingerfertig",
    "fingerfertigen": "fingerfertig",
    "fingerfertiger": "fingerfertig",
    "fingerfertigere": "fingerfertig",
    "fingerfertigerem": "fingerfertig",
    "fingerfertigeren": "fingerfertig",
    "fingerfertigerer": "fingerfertig",
    "fingerfertigeres": "fingerfertig",
    "fingerfertiges": "fingerfertig",
    "fingerfertigste": "fingerfertig",
    "fingerfertigstem": "fingerfertig",
    "fingerfertigsten": "fingerfertig",
    "fingerfertigster": "fingerfertig",
    "fingerfertigstes": "fingerfertig",
    "fingest": "fangen",
    "finget": "fangen",
    "fingiere": "fingieren",
    "fingierend": "fingieren",
    "fingierende": "fingierend",
    "fingierendem": "fingierend",
    "fingierenden": "fingierend",
    "fingierender": "fingierend",
    "fingierendere": "fingierend",
    "fingierenderem": "fingierend",
    "fingierenderen": "fingierend",
    "fingierenderer": "fingierend",
    "fingierenderes": "fingierend",
    "fingierendes": "fingierend",
    "fingierendste": "fingierend",
    "fingierendstem": "fingierend",
    "fingierendsten": "fingierend",
    "fingierendster": "fingierend",
    "fingierendstes": "fingierend",
    "fingierest": "fingieren",
    "fingieret": "fingieren",
    "fingierst": "fingieren",
    "fingiert": "fingieren",
    "fingierte": "fingieren",
    "fingiertem": "fingiert",
    "fingierten": "fingieren",
    "fingierter": "fingiert",
    "fingiertere": "fingiert",
    "fingierterem": "fingiert",
    "fingierteren": "fingiert",
    "fingierterer": "fingiert",
    "fingierteres": "fingiert",
    "fingiertes": "fingiert",
    "fingiertest": "fingieren",
    "fingierteste": "fingiert",
    "fingiertestem": "fingiert",
    "fingiertesten": "fingiert",
    "fingiertester": "fingiert",
    "fingiertestes": "fingiert",
    "fingiertet": "fingieren",
    "fingst": "fangen",
    "fingt": "fangen",
    "finite": "finit",
    "finitem": "finit",
    "finiten": "finit",
    "finiter": "finit",
    "finites": "finit",
    "finnischem": "finnisch",
    "finnischen": "finnisch",
    "finnischer": "finnisch",
    "finnisches": "finnisch",
    "finsterem": "finster",
    "finsteren": "finster",
    "finsterer": "finster",
    "finsterere": "finster",
    "finstererem": "finster",
    "finstereren": "finster",
    "finstererer": "finster",
    "finstereres": "finster",
    "finsteres": "finster",
    "finsterstem": "finster",
    "finstersten": "finster",
    "finsterster": "finster",
    "finsterstes": "finster",
    "firme": "firmen",
    "firmend": "firmen",
    "firmende": "firmend",
    "firmendem": "firmend",
    "firmenden": "firmend",
    "firmender": "firmend",
    "firmendes": "firmend",
    "firmest": "firmen",
    "firmet": "firmen",
    "firmst": "firmen",
    "firmt": "firmen",
    "firmte": "firmen",
    "firmten": "firmen",
    "firmtest": "firmen",
    "firmtet": "firmen",
    "fischend": "fischen",
    "fischende": "fischend",
    "fischendem": "fischend",
    "fischenden": "fischend",
    "fischender": "fischend",
    "fischendes": "fischend",
    "fischest": "fischen",
    "fischet": "fischen",
    "fischreiche": "fischreich",
    "fischreichem": "fischreich",
    "fischreichen": "fischreich",
    "fischreicher": "fischreich",
    "fischreichere": "fischreich",
    "fischreicherem": "fischreich",
    "fischreicheren": "fischreich",
    "fischreicherer": "fischreich",
    "fischreicheres": "fischreich",
    "fischreiches": "fischreich",
    "fischreichste": "fischreich",
    "fischreichstem": "fischreich",
    "fischreichsten": "fischreich",
    "fischreichster": "fischreich",
    "fischreichstes": "fischreich",
    "fischst": "fischen",
    "fischt": "fischen",
    "fischte": "fischen",
    "fischten": "fischen",
    "fischtest": "fischen",
    "fischtet": "fischen",
    "fitem": "fit",
    "fiten": "fit",
    "fiter": "fit",
    "fitere": "fit",
    "fiterem": "fit",
    "fiteren": "fit",
    "fiterer": "fit",
    "fiteres": "fit",
    "fites": "fit",
    "fiteste": "fit",
    "fitestem": "fit",
    "fitesten": "fit",
    "fitester": "fit",
    "fitestes": "fit",
    "fix": "fixen",
    "fixe": "fix",
    "fixem": "fix",
    "fixen": "fix",
    "fixend": "fixen",
    "fixende": "fixend",
    "fixendem": "fixend",
    "fixenden": "fixend",
    "fixender": "fixend",
    "fixendes": "fixend",
    "fixere": "fix",
    "fixerem": "fix",
    "fixeren": "fix",
    "fixerer": "fix",
    "fixeres": "fix",
    "fixes": "fix",
    "fixest": "fixen",
    "fixeste": "fix",
    "fixestem": "fix",
    "fixesten": "fix",
    "fixester": "fix",
    "fixestes": "fix",
    "fixet": "fixen",
    "fixiere": "fixieren",
    "fixierend": "fixieren",
    "fixierende": "fixierend",
    "fixierendem": "fixierend",
    "fixierenden": "fixierend",
    "fixierender": "fixierend",
    "fixierendere": "fixierend",
    "fixierenderem": "fixierend",
    "fixierenderen": "fixierend",
    "fixierenderer": "fixierend",
    "fixierenderes": "fixierend",
    "fixierendes": "fixierend",
    "fixierendste": "fixierend",
    "fixierendstem": "fixierend",
    "fixierendsten": "fixierend",
    "fixierendster": "fixierend",
    "fixierendstes": "fixierend",
    "fixierest": "fixieren",
    "fixieret": "fixieren",
    "fixierst": "fixieren",
    "fixiert": "fixieren",
    "fixierte": "fixieren",
    "fixiertem": "fixiert",
    "fixierten": "fixieren",
    "fixierter": "fixiert",
    "fixiertere": "fixiert",
    "fixierterem": "fixiert",
    "fixierteren": "fixiert",
    "fixierterer": "fixiert",
    "fixierteres": "fixiert",
    "fixiertes": "fixiert",
    "fixiertest": "fixieren",
    "fixierteste": "fixiert",
    "fixiertestem": "fixiert",
    "fixiertesten": "fixiert",
    "fixiertester": "fixiert",
    "fixiertestes": "fixiert",
    "fixiertet": "fixieren",
    "fixt": "fixen",
    "fixte": "fixen",
    "fixten": "fixen",
    "fixtest": "fixen",
    "fixtet": "fixen",
    "flach": "flachen",
    "flachdrücke": "flachdrücken",
    "flachdrückend": "flachdrücken",
    "flachdrückende": "flachdrückend",
    "flachdrückendem": "flachdrückend",
    "flachdrückenden": "flachdrückend",
    "flachdrückender": "flachdrückend",
    "flachdrückendere": "flachdrückend",
    "flachdrückenderem": "flachdrückend",
    "flachdrückenderen": "flachdrückend",
    "flachdrückenderer": "flachdrückend",
    "flachdrückenderes": "flachdrückend",
    "flachdrückendes": "flachdrückend",
    "flachdrückendste": "flachdrückend",
    "flachdrückendstem": "flachdrückend",
    "flachdrückendsten": "flachdrückend",
    "flachdrückendster": "flachdrückend",
    "flachdrückendstes": "flachdrückend",
    "flachdrückest": "flachdrücken",
    "flachdrücket": "flachdrücken",
    "flachdrückst": "flachdrücken",
    "flachdrückt": "flachdrücken",
    "flachdrückte": "flachdrücken",
    "flachdrückten": "flachdrücken",
    "flachdrücktest": "flachdrücken",
    "flachdrücktet": "flachdrücken",
    "flache": "flach",
    "flachem": "flach",
    "flachen": "flach",
    "flachend": "flachen",
    "flachende": "flachend",
    "flachendem": "flachend",
    "flachenden": "flachend",
    "flachender": "flachend",
    "flachendes": "flachend",
    "flacher": "flach",
    "flachere": "flach",
    "flacherem": "flach",
    "flacheren": "flach",
    "flacherer": "flach",
    "flacheres": "flach",
    "flaches": "flach",
    "flachest": "flachen",
    "flachet": "flachen",
    "flachfalle": "flachfallen",
    "flachfallend": "flachfallen",
    "flachfallende": "flachfallend",
    "flachfallendem": "flachfallend",
    "flachfallenden": "flachfallend",
    "flachfallender": "flachfallend",
    "flachfallendes": "flachfallend",
    "flachfallest": "flachfallen",
    "flachfallet": "flachfallen",
    "flachfallt": "flachfallen",
    "flachfiel": "flachfallen",
    "flachfiele": "flachfallen",
    "flachfielen": "flachfallen",
    "flachfielest": "flachfallen",
    "flachfielet": "flachfallen",
    "flachfielst": "flachfallen",
    "flachfielt": "flachfallen",
    "flachfällst": "flachfallen",
    "flachfällt": "flachfallen",
    "flachgedrückt": "flachdrücken",
    "flachgedrückte": "flachgedrückt",
    "flachgedrücktem": "flachgedrückt",
    "flachgedrückten": "flachgedrückt",
    "flachgedrückter": "flachgedrückt",
    "flachgedrücktere": "flachgedrückt",
    "flachgedrückterem": "flachgedrückt",
    "flachgedrückteren": "flachgedrückt",
    "flachgedrückterer": "flachgedrückt",
    "flachgedrückteres": "flachgedrückt",
    "flachgedrücktes": "flachgedrückt",
    "flachgedrückteste": "flachgedrückt",
    "flachgedrücktestem": "flachgedrückt",
    "flachgedrücktesten": "flachgedrückt",
    "flachgedrücktester": "flachgedrückt",
    "flachgedrücktestes": "flachgedrückt",
    "flachgefallen": "flachfallen",
    "flachgefallene": "flachgefallen",
    "flachgefallenem": "flachgefallen",
    "flachgefallenen": "flachgefallen",
    "flachgefallener": "flachgefallen",
    "flachgefallenes": "flachgefallen",
    "flachst": "flachen",
    "flachste": "flach",
    "flachstem": "flach",
    "flachsten": "flach",
    "flachster": "flach",
    "flachstes": "flach",
    "flacht": "flachen",
    "flachte": "flachen",
    "flachten": "flachen",
    "flachtest": "flachen",
    "flachtet": "flachen",
    "flachzudrücken": "flachdrücken",
    "flachzufallen": "flachfallen",
    "flackere": "flackern",
    "flackernd": "flackern",
    "flackernde": "flackernd",
    "flackerndem": "flackernd",
    "flackernden": "flackernd",
    "flackernder": "flackernd",
    "flackerndere": "flackernd",
    "flackernderem": "flackernd",
    "flackernderen": "flackernd",
    "flackernderer": "flackernd",
    "flackernderes": "flackernd",
    "flackerndes": "flackernd",
    "flackerndste": "flackernd",
    "flackerndstem": "flackernd",
    "flackerndsten": "flackernd",
    "flackerndster": "flackernd",
    "flackerndstes": "flackernd",
    "flackerst": "flackern",
    "flackert": "flackern",
    "flackerte": "flackern",
    "flackerten": "flackern",
    "flackertest": "flackern",
    "flackertet": "flackern",
    "flaggend": "flaggen",
    "flaggende": "flaggend",
    "flaggendem": "flaggend",
    "flaggenden": "flaggend",
    "flaggender": "flaggend",
    "flaggendere": "flaggend",
    "flaggenderem": "flaggend",
    "flaggenderen": "flaggend",
    "flaggenderer": "flaggend",
    "flaggenderes": "flaggend",
    "flaggendes": "flaggend",
    "flaggendste": "flaggend",
    "flaggendstem": "flaggend",
    "flaggendsten": "flaggend",
    "flaggendster": "flaggend",
    "flaggendstes": "flaggend",
    "flaggest": "flaggen",
    "flagget": "flaggen",
    "flaggst": "flaggen",
    "flaggt": "flaggen",
    "flaggte": "flaggen",
    "flaggten": "flaggen",
    "flaggtest": "flaggen",
    "flaggtet": "flaggen",
    "flambiere": "flambieren",
    "flambierend": "flambieren",
    "flambierende": "flambierend",
    "flambierendem": "flambierend",
    "flambierenden": "flambierend",
    "flambierender": "flambierend",
    "flambierendes": "flambierend",
    "flambierest": "flambieren",
    "flambieret": "flambieren",
    "flambierst": "flambieren",
    "flambiert": "flambieren",
    "flambierte": "flambieren",
    "flambiertem": "flambiert",
    "flambierten": "flambieren",
    "flambierter": "flambiert",
    "flambiertes": "flambiert",
    "flambiertest": "flambieren",
    "flambiertet": "flambieren",
    "flammend": "flammen",
    "flammende": "flammend",
    "flammendem": "flammend",
    "flammenden": "flammend",
    "flammender": "flammend",
    "flammendere": "flammend",
    "flammenderem": "flammend",
    "flammenderen": "flammend",
    "flammenderer": "flammend",
    "flammenderes": "flammend",
    "flammendes": "flammend",
    "flammendste": "flammend",
    "flammendstem": "flammend",
    "flammendsten": "flammend",
    "flammendster": "flammend",
    "flammendstes": "flammend",
    "flammest": "flammen",
    "flammet": "flammen",
    "flammige": "flammig",
    "flammigem": "flammig",
    "flammigen": "flammig",
    "flammiger": "flammig",
    "flammiges": "flammig",
    "flammst": "flammen",
    "flammt": "flammen",
    "flammte": "flammen",
    "flammten": "flammen",
    "flammtest": "flammen",
    "flammtet": "flammen",
    "flaniere": "flanieren",
    "flanierend": "flanieren",
    "flanierende": "flanierend",
    "flanierendem": "flanierend",
    "flanierenden": "flanierend",
    "flanierender": "flanierend",
    "flanierendere": "flanierend",
    "flanierenderem": "flanierend",
    "flanierenderen": "flanierend",
    "flanierenderer": "flanierend",
    "flanierenderes": "flanierend",
    "flanierendes": "flanierend",
    "flanierendste": "flanierend",
    "flanierendstem": "flanierend",
    "flanierendsten": "flanierend",
    "flanierendster": "flanierend",
    "flanierendstes": "flanierend",
    "flanierest": "flanieren",
    "flanieret": "flanieren",
    "flanierst": "flanieren",
    "flaniert": "flanieren",
    "flanierte": "flanieren",
    "flaniertem": "flaniert",
    "flanierten": "flanieren",
    "flanierter": "flaniert",
    "flaniertere": "flaniert",
    "flanierterem": "flaniert",
    "flanierteren": "flaniert",
    "flanierterer": "flaniert",
    "flanierteres": "flaniert",
    "flaniertes": "flaniert",
    "flaniertest": "flanieren",
    "flanierteste": "flaniert",
    "flaniertestem": "flaniert",
    "flaniertesten": "flaniert",
    "flaniertester": "flaniert",
    "flaniertestes": "flaniert",
    "flaniertet": "flanieren",
    "flanke": "flanken",
    "flankend": "flanken",
    "flankende": "flankend",
    "flankendem": "flankend",
    "flankenden": "flankend",
    "flankender": "flankend",
    "flankendere": "flankend",
    "flankenderem": "flankend",
    "flankenderen": "flankend",
    "flankenderer": "flankend",
    "flankenderes": "flankend",
    "flankendes": "flankend",
    "flankendste": "flankend",
    "flankendstem": "flankend",
    "flankendsten": "flankend",
    "flankendster": "flankend",
    "flankendstes": "flankend",
    "flankest": "flanken",
    "flanket": "flanken",
    "flankiere": "flankieren",
    "flankierend": "flankieren",
    "flankierende": "flankierend",
    "flankierendem": "flankierend",
    "flankierenden": "flankierend",
    "flankierender": "flankierend",
    "flankierendere": "flankierend",
    "flankierenderem": "flankierend",
    "flankierenderen": "flankierend",
    "flankierenderer": "flankierend",
    "flankierenderes": "flankierend",
    "flankierendes": "flankierend",
    "flankierendste": "flankierend",
    "flankierendstem": "flankierend",
    "flankierendsten": "flankierend",
    "flankierendster": "flankierend",
    "flankierendstes": "flankierend",
    "flankierest": "flankieren",
    "flankieret": "flankieren",
    "flankierst": "flankieren",
    "flankiert": "flankieren",
    "flankierte": "flankieren",
    "flankiertem": "flankiert",
    "flankierten": "flankieren",
    "flankierter": "flankiert",
    "flankiertere": "flankiert",
    "flankierterem": "flankiert",
    "flankierteren": "flankiert",
    "flankierterer": "flankiert",
    "flankierteres": "flankiert",
    "flankiertes": "flankiert",
    "flankiertest": "flankieren",
    "flankierteste": "flankiert",
    "flankiertestem": "flankiert",
    "flankiertesten": "flankiert",
    "flankiertester": "flankiert",
    "flankiertestes": "flankiert",
    "flankiertet": "flankieren",
    "flankst": "flanken",
    "flankt": "flanken",
    "flankte": "flanken",
    "flankten": "flanken",
    "flanktest": "flanken",
    "flanktet": "flanken",
    "flansche": "flanschen",
    "flanschend": "flanschen",
    "flanschende": "flanschend",
    "flanschendem": "flanschend",
    "flanschenden": "flanschend",
    "flanschender": "flanschend",
    "flanschendes": "flanschend",
    "flanschest": "flanschen",
    "flanschet": "flanschen",
    "flanschst": "flanschen",
    "flanscht": "flanschen",
    "flanschte": "flanschen",
    "flanschten": "flanschen",
    "flanschtest": "flanschen",
    "flanschtet": "flanschen",
    "flapsigem": "flapsig",
    "flapsigen": "flapsig",
    "flapsiger": "flapsig",
    "flapsigere": "flapsig",
    "flapsigerem": "flapsig",
    "flapsigeren": "flapsig",
    "flapsigerer": "flapsig",
    "flapsigeres": "flapsig",
    "flapsiges": "flapsig",
    "flapsigste": "flapsig",
    "flapsigstem": "flapsig",
    "flapsigsten": "flapsig",
    "flapsigster": "flapsig",
    "flapsigstes": "flapsig",
    "flattere": "flattern",
    "flatterhaftem": "flatterhaft",
    "flatterhaften": "flatterhaft",
    "flatterhafter": "flatterhaft",
    "flatterhaftere": "flatterhaft",
    "flatterhafterem": "flatterhaft",
    "flatterhafteren": "flatterhaft",
    "flatterhafterer": "flatterhaft",
    "flatterhafteres": "flatterhaft",
    "flatterhaftes": "flatterhaft",
    "flatterhafteste": "flatterhaft",
    "flatterhaftestem": "flatterhaft",
    "flatterhaftesten": "flatterhaft",
    "flatterhaftester": "flatterhaft",
    "flatterhaftestes": "flatterhaft",
    "flatterige": "flatterig",
    "flatterigem": "flatterig",
    "flatterigen": "flatterig",
    "flatteriger": "flatterig",
    "flatterigere": "flatterig",
    "flatterigerem": "flatterig",
    "flatterigeren": "flatterig",
    "flatterigerer": "flatterig",
    "flatterigeres": "flatterig",
    "flatteriges": "flatterig",
    "flatterigste": "flatterig",
    "flatterigstem": "flatterig",
    "flatterigsten": "flatterig",
    "flatterigster": "flatterig",
    "flatterigstes": "flatterig",
    "flatternd": "flattern",
    "flatternde": "flatternd",
    "flatterndem": "flatternd",
    "flatternden": "flatternd",
    "flatternder": "flatternd",
    "flatterndes": "flatternd",
    "flatterst": "flattern",
    "flattert": "flattern",
    "flatterte": "flattern",
    "flatterten": "flattern",
    "flattertest": "flattern",
    "flattertet": "flattern",
    "flaue": "flauen",
    "flauend": "flauen",
    "flauende": "flauend",
    "flauendem": "flauend",
    "flauenden": "flauend",
    "flauender": "flauend",
    "flauendes": "flauend",
    "flauest": "flauen",
    "flauet": "flauen",
    "flaumweichem": "flaumweich",
    "flaumweichen": "flaumweich",
    "flaumweicher": "flaumweich",
    "flaumweichere": "flaumweich",
    "flaumweicherem": "flaumweich",
    "flaumweicheren": "flaumweich",
    "flaumweicherer": "flaumweich",
    "flaumweicheres": "flaumweich",
    "flaumweiches": "flaumweich",
    "flaumweichste": "flaumweich",
    "flaumweichstem": "flaumweich",
    "flaumweichsten": "flaumweich",
    "flaumweichster": "flaumweich",
    "flaumweichstes": "flaumweich",
    "flaust": "flauen",
    "flaut": "flauen",
    "flaute": "flauen",
    "flautest": "flauen",
    "flautet": "flauen",
    "flechte": "flechten",
    "flechtend": "flechten",
    "flechtende": "flechtend",
    "flechtendem": "flechtend",
    "flechtenden": "flechtend",
    "flechtender": "flechtend",
    "flechtendes": "flechtend",
    "flechtest": "flechten",
    "flechtet": "flechten",
    "fleckend": "flecken",
    "fleckende": "fleckend",
    "fleckendem": "fleckend",
    "fleckenden": "fleckend",
    "fleckender": "fleckend",
    "fleckendere": "fleckend",
    "fleckenderem": "fleckend",
    "fleckenderen": "fleckend",
    "fleckenderer": "fleckend",
    "fleckenderes": "fleckend",
    "fleckendes": "fleckend",
    "fleckendste": "fleckend",
    "fleckendstem": "fleckend",
    "fleckendsten": "fleckend",
    "fleckendster": "fleckend",
    "fleckendstes": "fleckend",
    "fleckest": "flecken",
    "flecket": "flecken",
    "fleckst": "flecken",
    "fleckt": "flecken",
    "fleckte": "flecken",
    "fleckten": "flecken",
    "flecktest": "flecken",
    "flecktet": "flecken",
    "fleddere": "fleddern",
    "fleddernd": "fleddern",
    "fleddernde": "fleddernd",
    "fledderndem": "fleddernd",
    "fleddernden": "fleddernd",
    "fleddernder": "fleddernd",
    "fledderndere": "fleddernd",
    "fleddernderem": "fleddernd",
    "fleddernderen": "fleddernd",
    "fleddernderer": "fleddernd",
    "fleddernderes": "fleddernd",
    "fledderndes": "fleddernd",
    "fledderndste": "fleddernd",
    "fledderndstem": "fleddernd",
    "fledderndsten": "fleddernd",
    "fledderndster": "fleddernd",
    "fledderndstes": "fleddernd",
    "fledderst": "fleddern",
    "fleddert": "fleddern",
    "fledderte": "fleddern",
    "fledderten": "fleddern",
    "fleddertest": "fleddern",
    "fleddertet": "fleddern",
    "flegele": "flegeln",
    "flegelnd": "flegeln",
    "flegelnde": "flegelnd",
    "flegelndem": "flegelnd",
    "flegelnden": "flegelnd",
    "flegelnder": "flegelnd",
    "flegelndere": "flegelnd",
    "flegelnderem": "flegelnd",
    "flegelnderen": "flegelnd",
    "flegelnderer": "flegelnd",
    "flegelnderes": "flegelnd",
    "flegelndes": "flegelnd",
    "flegelndste": "flegelnd",
    "flegelndstem": "flegelnd",
    "flegelndsten": "flegelnd",
    "flegelndster": "flegelnd",
    "flegelndstes": "flegelnd",
    "flegelst": "flegeln",
    "flegelt": "flegeln",
    "flegelte": "flegeln",
    "flegelten": "flegeln",
    "flegeltest": "flegeln",
    "flegeltet": "flegeln",
    "flegle": "flegeln",
    "flehe": "flehen",
    "flehend": "flehen",
    "flehende": "flehend",
    "flehendem": "flehend",
    "flehenden": "flehend",
    "flehender": "flehend",
    "flehendere": "flehend",
    "flehenderem": "flehend",
    "flehenderen": "flehend",
    "flehenderer": "flehend",
    "flehenderes": "flehend",
    "flehendes": "flehend",
    "flehendste": "flehend",
    "flehendstem": "flehend",
    "flehendsten": "flehend",
    "flehendster": "flehend",
    "flehendstes": "flehend",
    "flehest": "flehen",
    "flehet": "flehen",
    "flehst": "flehen",
    "fleht": "flehen",
    "flehte": "flehen",
    "flehten": "flehen",
    "flehtest": "flehen",
    "flehtet": "flehen",
    "fleischernem": "fleischern",
    "fleischernen": "fleischern",
    "fleischerner": "fleischern",
    "fleischernes": "fleischern",
    "fleischfarbenem": "fleischfarben",
    "fleischfarbenen": "fleischfarben",
    "fleischfarbener": "fleischfarben",
    "fleischfarbenes": "fleischfarben",
    "fleischigem": "fleischig",
    "fleischigen": "fleischig",
    "fleischiger": "fleischig",
    "fleischiges": "fleischig",
    "fleischlose": "fleischlos",
    "fleischlosem": "fleischlos",
    "fleischlosen": "fleischlos",
    "fleischloser": "fleischlos",
    "fleischlosere": "fleischlos",
    "fleischloserem": "fleischlos",
    "fleischloseren": "fleischlos",
    "fleischloserer": "fleischlos",
    "fleischloseres": "fleischlos",
    "fleischloses": "fleischlos",
    "fleischloseste": "fleischlos",
    "fleischlosestem": "fleischlos",
    "fleischlosesten": "fleischlos",
    "fleischlosester": "fleischlos",
    "fleischlosestes": "fleischlos",
    "fleißigem": "fleißig",
    "fleißigen": "fleißig",
    "fleißiger": "fleißig",
    "fleißigere": "fleißig",
    "fleißigerem": "fleißig",
    "fleißigeren": "fleißig",
    "fleißigerer": "fleißig",
    "fleißigeres": "fleißig",
    "fleißiges": "fleißig",
    "fleißigste": "fleißig",
    "fleißigstem": "fleißig",
    "fleißigsten": "fleißig",
    "fleißigster": "fleißig",
    "fleißigstes": "fleißig",
    "flektierbare": "flektierbar",
    "flektierbarem": "flektierbar",
    "flektierbaren": "flektierbar",
    "flektierbarer": "flektierbar",
    "flektierbares": "flektierbar",
    "flektiere": "flektieren",
    "flektierend": "flektieren",
    "flektierende": "flektierend",
    "flektierendem": "flektierend",
    "flektierenden": "flektierend",
    "flektierender": "flektierend",
    "flektierendes": "flektierend",
    "flektierest": "flektieren",
    "flektieret": "flektieren",
    "flektierst": "flektieren",
    "flektiert": "flektieren",
    "flektierte": "flektieren",
    "flektiertem": "flektiert",
    "flektierten": "flektieren",
    "flektierter": "flektiert",
    "flektiertes": "flektiert",
    "flektiertest": "flektieren",
    "flektiertet": "flektieren",
    "flenne": "flennen",
    "flennend": "flennen",
    "flennende": "flennend",
    "flennendem": "flennend",
    "flennenden": "flennend",
    "flennender": "flennend",
    "flennendere": "flennend",
    "flennenderem": "flennend",
    "flennenderen": "flennend",
    "flennenderer": "flennend",
    "flennenderes": "flennend",
    "flennendes": "flennend",
    "flennendste": "flennend",
    "flennendstem": "flennend",
    "flennendsten": "flennend",
    "flennendster": "flennend",
    "flennendstes": "flennend",
    "flennest": "flennen",
    "flennet": "flennen",
    "flennst": "flennen",
    "flennt": "flennen",
    "flennte": "flennen",
    "flennten": "flennen",
    "flenntest": "flennen",
    "flenntet": "flennen",
    "fletsche": "fletschen",
    "fletschend": "fletschen",
    "fletschende": "fletschend",
    "fletschendem": "fletschend",
    "fletschenden": "fletschend",
    "fletschender": "fletschend",
    "fletschendere": "fletschend",
    "fletschenderem": "fletschend",
    "fletschenderen": "fletschend",
    "fletschenderer": "fletschend",
    "fletschenderes": "fletschend",
    "fletschendes": "fletschend",
    "fletschendste": "fletschend",
    "fletschendstem": "fletschend",
    "fletschendsten": "fletschend",
    "fletschendster": "fletschend",
    "fletschendstes": "fletschend",
    "fletschest": "fletschen",
    "fletschet": "fletschen",
    "fletschst": "fletschen",
    "fletscht": "fletschen",
    "fletschte": "fletschen",
    "fletschten": "fletschen",
    "fletschtest": "fletschen",
    "fletschtet": "fletschen",
    "flexibelste": "flexibel",
    "flexibelstem": "flexibel",
    "flexibelsten": "flexibel",
    "flexibelster": "flexibel",
    "flexibelstes": "flexibel",
    "flexiblem": "flexibel",
    "flexiblen": "flexibel",
    "flexibler": "flexibel",
    "flexiblere": "flexibel",
    "flexiblerem": "flexibel",
    "flexibleren": "flexibel",
    "flexiblerer": "flexibel",
    "flexibleres": "flexibel",
    "flexibles": "flexibel",
    "flicht": "flechten",
    "flichtst": "flechten",
    "fliederfarbenem": "fliederfarben",
    "fliederfarbenen": "fliederfarben",
    "fliederfarbener": "fliederfarben",
    "fliederfarbenes": "fliederfarben",
    "fliegend": "fliegen",
    "fliegende": "fliegend",
    "fliegendem": "fliegend",
    "fliegenden": "fliegend",
    "fliegender": "fliegend",
    "fliegendes": "fliegend",
    "fliegest": "fliegen",
    "flieget": "fliegen",
    "fliegst": "fliegen",
    "fliegt": "fliegen",
    "fliehe": "fliehen",
    "fliehend": "fliehen",
    "fliehende": "fliehend",
    "fliehendem": "fliehend",
    "fliehenden": "fliehend",
    "fliehender": "fliehend",
    "fliehendes": "fliehend",
    "fliehest": "fliehen",
    "fliehet": "fliehen",
    "fliehst": "fliehen",
    "flieht": "fliehen",
    "fliese": "fliesen",
    "fliesend": "fliesen",
    "fliesende": "fliesend",
    "fliesendem": "fliesend",
    "fliesenden": "fliesend",
    "fliesender": "fliesend",
    "fliesendes": "fliesend",
    "fliesest": "fliesen",
    "flieset": "fliesen",
    "fliest": "fliesen",
    "flieste": "fliesen",
    "fliesten": "fliesen",
    "fliestest": "fliesen",
    "fliestet": "fliesen",
    "fließe": "fließen",
    "fließend": "fließen",
    "fließende": "fließend",
    "fließendem": "fließend",
    "fließenden": "fließend",
    "fließender": "fließend",
    "fließendes": "fließend",
    "fließest": "fließen",
    "fließet": "fließen",
    "fließt": "fließen",
    "flimmere": "flimmern",
    "flimmernd": "flimmern",
    "flimmernde": "flimmernd",
    "flimmerndem": "flimmernd",
    "flimmernden": "flimmernd",
    "flimmernder": "flimmernd",
    "flimmerndere": "flimmernd",
    "flimmernderem": "flimmernd",
    "flimmernderen": "flimmernd",
    "flimmernderer": "flimmernd",
    "flimmernderes": "flimmernd",
    "flimmerndes": "flimmernd",
    "flimmerndste": "flimmernd",
    "flimmerndstem": "flimmernd",
    "flimmerndsten": "flimmernd",
    "flimmerndster": "flimmernd",
    "flimmerndstes": "flimmernd",
    "flimmerst": "flimmern",
    "flimmert": "flimmern",
    "flimmerte": "flimmern",
    "flimmerten": "flimmern",
    "flimmertest": "flimmern",
    "flimmertet": "flimmern",
    "flinke": "flink",
    "flinkem": "flink",
    "flinken": "flink",
    "flinker": "flink",
    "flinkere": "flink",
    "flinkerem": "flink",
    "flinkeren": "flink",
    "flinkerer": "flink",
    "flinkeres": "flink",
    "flinkes": "flink",
    "flinkste": "flink",
    "flinkstem": "flink",
    "flinksten": "flink",
    "flinkster": "flink",
    "flinkstes": "flink",
    "flippe": "flippen",
    "flippend": "flippen",
    "flippende": "flippend",
    "flippendem": "flippend",
    "flippenden": "flippend",
    "flippender": "flippend",
    "flippendes": "flippend",
    "flippere": "flippern",
    "flippernd": "flippern",
    "flippernde": "flippernd",
    "flipperndem": "flippernd",
    "flippernden": "flippernd",
    "flippernder": "flippernd",
    "flipperndere": "flippernd",
    "flippernderem": "flippernd",
    "flippernderen": "flippernd",
    "flippernderer": "flippernd",
    "flippernderes": "flippernd",
    "flipperndes": "flippernd",
    "flipperndste": "flippernd",
    "flipperndstem": "flippernd",
    "flipperndsten": "flippernd",
    "flipperndster": "flippernd",
    "flipperndstes": "flippernd",
    "flipperst": "flippern",
    "flippert": "flippern",
    "flipperte": "flippern",
    "flipperten": "flippern",
    "flippertest": "flippern",
    "flippertet": "flippern",
    "flippest": "flippen",
    "flippet": "flippen",
    "flippige": "flippig",
    "flippigem": "flippig",
    "flippigen": "flippig",
    "flippiger": "flippig",
    "flippigere": "flippig",
    "flippigerem": "flippig",
    "flippigeren": "flippig",
    "flippigerer": "flippig",
    "flippigeres": "flippig",
    "flippiges": "flippig",
    "flippigste": "flippig",
    "flippigstem": "flippig",
    "flippigsten": "flippig",
    "flippigster": "flippig",
    "flippigstes": "flippig",
    "flippst": "flippen",
    "flippt": "flippen",
    "flippte": "flippen",
    "flippten": "flippen",
    "flipptest": "flippen",
    "flipptet": "flippen",
    "flittere": "flittern",
    "flitternd": "flittern",
    "flitternde": "flitternd",
    "flitterndem": "flitternd",
    "flitternden": "flitternd",
    "flitternder": "flitternd",
    "flitterndes": "flitternd",
    "flitterst": "flittern",
    "flittert": "flittern",
    "flitterte": "flittern",
    "flitterten": "flittern",
    "flittertest": "flittern",
    "flittertet": "flittern",
    "flitze": "flitzen",
    "flitzend": "flitzen",
    "flitzende": "flitzend",
    "flitzendem": "flitzend",
    "flitzenden": "flitzend",
    "flitzender": "flitzend",
    "flitzendere": "flitzend",
    "flitzenderem": "flitzend",
    "flitzenderen": "flitzend",
    "flitzenderer": "flitzend",
    "flitzenderes": "flitzend",
    "flitzendes": "flitzend",
    "flitzendste": "flitzend",
    "flitzendstem": "flitzend",
    "flitzendsten": "flitzend",
    "flitzendster": "flitzend",
    "flitzendstes": "flitzend",
    "flitzest": "flitzen",
    "flitzet": "flitzen",
    "flitzt": "flitzen",
    "flitzte": "flitzen",
    "flitzten": "flitzen",
    "flitztest": "flitzen",
    "flitztet": "flitzen",
    "flocht": "flechten",
    "flochten": "flechten",
    "flochtest": "flechten",
    "flochtet": "flechten",
    "flocke": "flocken",
    "flockend": "flocken",
    "flockende": "flockend",
    "flockendem": "flockend",
    "flockenden": "flockend",
    "flockender": "flockend",
    "flockendes": "flockend",
    "flockest": "flocken",
    "flocket": "flocken",
    "flockst": "flocken",
    "flockt": "flocken",
    "flockte": "flocken",
    "flockten": "flocken",
    "flocktest": "flocken",
    "flocktet": "flocken",
    "flog": "fliegen",
    "flogen": "fliegen",
    "flogst": "fliegen",
    "flogt": "fliegen",
    "floh": "fliehen",
    "flohen": "fliehen",
    "flohst": "fliehen",
    "floht": "fliehen",
    "floppe": "floppen",
    "floppend": "floppen",
    "floppende": "floppend",
    "floppendem": "floppend",
    "floppenden": "floppend",
    "floppender": "floppend",
    "floppendere": "floppend",
    "floppenderem": "floppend",
    "floppenderen": "floppend",
    "floppenderer": "floppend",
    "floppenderes": "floppend",
    "floppendes": "floppend",
    "floppendste": "floppend",
    "floppendstem": "floppend",
    "floppendsten": "floppend",
    "floppendster": "floppend",
    "floppendstes": "floppend",
    "floppest": "floppen",
    "floppet": "floppen",
    "floppst": "floppen",
    "floppt": "floppen",
    "floppte": "floppen",
    "floppten": "floppen",
    "flopptest": "floppen",
    "flopptet": "floppen",
    "floriere": "florieren",
    "florierend": "florieren",
    "florierende": "florierend",
    "florierendem": "florierend",
    "florierenden": "florierend",
    "florierender": "florierend",
    "florierendere": "florierend",
    "florierenderem": "florierend",
    "florierenderen": "florierend",
    "florierenderer": "florierend",
    "florierenderes": "florierend",
    "florierendes": "florierend",
    "florierendste": "florierend",
    "florierendstem": "florierend",
    "florierendsten": "florierend",
    "florierendster": "florierend",
    "florierendstes": "florierend",
    "florierest": "florieren",
    "florieret": "florieren",
    "florierst": "florieren",
    "floriert": "florieren",
    "florierte": "florieren",
    "floriertem": "floriert",
    "florierten": "florieren",
    "florierter": "floriert",
    "floriertere": "floriert",
    "florierterem": "floriert",
    "florierteren": "floriert",
    "florierterer": "floriert",
    "florierteres": "floriert",
    "floriertes": "floriert",
    "floriertest": "florieren",
    "florierteste": "floriert",
    "floriertestem": "floriert",
    "floriertesten": "floriert",
    "floriertester": "floriert",
    "floriertestes": "floriert",
    "floriertet": "florieren",
    "floristischem": "floristisch",
    "floristischen": "floristisch",
    "floristischer": "floristisch",
    "floristisches": "floristisch",
    "flossen": "fließen",
    "flottbekam": "flottbekommen",
    "flottbekamen": "flottbekommen",
    "flottbekamst": "flottbekommen",
    "flottbekamt": "flottbekommen",
    "flottbekomme": "flottbekommen",
    "flottbekommend": "flottbekommen",
    "flottbekommende": "flottbekommend",
    "flottbekommendem": "flottbekommend",
    "flottbekommenden": "flottbekommend",
    "flottbekommender": "flottbekommend",
    "flottbekommendes": "flottbekommend",
    "flottbekommene": "flottbekommen",
    "flottbekommenem": "flottbekommen",
    "flottbekommenen": "flottbekommen",
    "flottbekommener": "flottbekommen",
    "flottbekommenes": "flottbekommen",
    "flottbekommest": "flottbekommen",
    "flottbekommet": "flottbekommen",
    "flottbekommst": "flottbekommen",
    "flottbekommt": "flottbekommen",
    "flottbekäme": "flottbekommen",
    "flottbekämen": "flottbekommen",
    "flottbekämest": "flottbekommen",
    "flottbekämet": "flottbekommen",
    "flotte": "flott",
    "flottem": "flott",
    "flotten": "flott",
    "flotter": "flott",
    "flottere": "flott",
    "flotterem": "flott",
    "flotteren": "flott",
    "flotterer": "flott",
    "flotteres": "flott",
    "flottes": "flott",
    "flotteste": "flott",
    "flottestem": "flott",
    "flottesten": "flott",
    "flottester": "flott",
    "flottestes": "flott",
    "flottgekriegt": "flottkriegen",
    "flottgekriegte": "flottgekriegt",
    "flottgekriegtem": "flottgekriegt",
    "flottgekriegten": "flottgekriegt",
    "flottgekriegter": "flottgekriegt",
    "flottgekriegtes": "flottgekriegt",
    "flottkriege": "flottkriegen",
    "flottkriegend": "flottkriegen",
    "flottkriegende": "flottkriegend",
    "flottkriegendem": "flottkriegend",
    "flottkriegenden": "flottkriegend",
    "flottkriegender": "flottkriegend",
    "flottkriegendes": "flottkriegend",
    "flottkriegest": "flottkriegen",
    "flottkrieget": "flottkriegen",
    "flottkriegst": "flottkriegen",
    "flottkriegt": "flottkriegen",
    "flottkriegte": "flottkriegen",
    "flottkriegten": "flottkriegen",
    "flottkriegtest": "flottkriegen",
    "flottkriegtet": "flottkriegen",
    "flottzubekommen": "flottbekommen",
    "flottzukriegen": "flottkriegen",
    "floß": "fließen",
    "floßt": "fließen",
    "fluchend": "fluchen",
    "fluchende": "fluchend",
    "fluchendem": "fluchend",
    "fluchenden": "fluchend",
    "fluchender": "fluchend",
    "fluchendere": "fluchend",
    "fluchenderem": "fluchend",
    "fluchenderen": "fluchend",
    "fluchenderer": "fluchend",
    "fluchenderes": "fluchend",
    "fluchendes": "fluchend",
    "fluchendste": "fluchend",
    "fluchendstem": "fluchend",
    "fluchendsten": "fluchend",
    "fluchendster": "fluchend",
    "fluchendstes": "fluchend",
    "fluchest": "fluchen",
    "fluchet": "fluchen",
    "fluchst": "fluchen",
    "flucht": "fluchen",
    "fluchtartigem": "fluchtartig",
    "fluchtartigen": "fluchtartig",
    "fluchtartiger": "fluchtartig",
    "fluchtartiges": "fluchtartig",
    "fluchte": "fluchten",
    "fluchten": "fluchen",
    "fluchtend": "fluchten",
    "fluchtende": "fluchtend",
    "fluchtendem": "fluchtend",
    "fluchtenden": "fluchtend",
    "fluchtender": "fluchtend",
    "fluchtendes": "fluchtend",
    "fluchtest": "fluchten",
    "fluchtet": "fluchten",
    "fluchtete": "fluchten",
    "fluchteten": "fluchten",
    "fluchtetest": "fluchten",
    "fluchtetet": "fluchten",
    "fluchtverdächtigem": "fluchtverdächtig",
    "fluchtverdächtigen": "fluchtverdächtig",
    "fluchtverdächtiger": "fluchtverdächtig",
    "fluchtverdächtiges": "fluchtverdächtig",
    "flugunfähigem": "flugunfähig",
    "flugunfähigen": "flugunfähig",
    "flugunfähiger": "flugunfähig",
    "flugunfähigere": "flugunfähig",
    "flugunfähigerem": "flugunfähig",
    "flugunfähigeren": "flugunfähig",
    "flugunfähigerer": "flugunfähig",
    "flugunfähigeres": "flugunfähig",
    "flugunfähiges": "flugunfähig",
    "flugunfähigste": "flugunfähig",
    "flugunfähigstem": "flugunfähig",
    "flugunfähigsten": "flugunfähig",
    "flugunfähigster": "flugunfähig",
    "flugunfähigstes": "flugunfähig",
    "fluktuiere": "fluktuieren",
    "fluktuierend": "fluktuieren",
    "fluktuierende": "fluktuierend",
    "fluktuierendem": "fluktuierend",
    "fluktuierenden": "fluktuierend",
    "fluktuierender": "fluktuierend",
    "fluktuierendere": "fluktuierend",
    "fluktuierenderem": "fluktuierend",
    "fluktuierenderen": "fluktuierend",
    "fluktuierenderer": "fluktuierend",
    "fluktuierenderes": "fluktuierend",
    "fluktuierendes": "fluktuierend",
    "fluktuierendste": "fluktuierend",
    "fluktuierendstem": "fluktuierend",
    "fluktuierendsten": "fluktuierend",
    "fluktuierendster": "fluktuierend",
    "fluktuierendstes": "fluktuierend",
    "fluktuierest": "fluktuieren",
    "fluktuieret": "fluktuieren",
    "fluktuierst": "fluktuieren",
    "fluktuiert": "fluktuieren",
    "fluktuierte": "fluktuieren",
    "fluktuiertem": "fluktuiert",
    "fluktuierten": "fluktuieren",
    "fluktuierter": "fluktuiert",
    "fluktuiertere": "fluktuiert",
    "fluktuierterem": "fluktuiert",
    "fluktuierteren": "fluktuiert",
    "fluktuierterer": "fluktuiert",
    "fluktuierteres": "fluktuiert",
    "fluktuiertes": "fluktuiert",
    "fluktuiertest": "fluktuieren",
    "fluktuierteste": "fluktuiert",
    "fluktuiertestem": "fluktuiert",
    "fluktuiertesten": "fluktuiert",
    "fluktuiertester": "fluktuiert",
    "fluktuiertestes": "fluktuiert",
    "fluktuiertet": "fluktuieren",
    "flunkere": "flunkern",
    "flunkernd": "flunkern",
    "flunkernde": "flunkernd",
    "flunkerndem": "flunkernd",
    "flunkernden": "flunkernd",
    "flunkernder": "flunkernd",
    "flunkerndere": "flunkernd",
    "flunkernderem": "flunkernd",
    "flunkernderen": "flunkernd",
    "flunkernderer": "flunkernd",
    "flunkernderes": "flunkernd",
    "flunkerndes": "flunkernd",
    "flunkerndste": "flunkernd",
    "flunkerndstem": "flunkernd",
    "flunkerndsten": "flunkernd",
    "flunkerndster": "flunkernd",
    "flunkerndstes": "flunkernd",
    "flunkerst": "flunkern",
    "flunkert": "flunkern",
    "flunkerte": "flunkern",
    "flunkerten": "flunkern",
    "flunkertest": "flunkern",
    "flunkertet": "flunkern",
    "fluppe": "fluppen",
    "fluppend": "fluppen",
    "fluppende": "fluppend",
    "fluppendem": "fluppend",
    "fluppenden": "fluppend",
    "fluppender": "fluppend",
    "fluppendere": "fluppend",
    "fluppenderem": "fluppend",
    "fluppenderen": "fluppend",
    "fluppenderer": "fluppend",
    "fluppenderes": "fluppend",
    "fluppendes": "fluppend",
    "fluppendste": "fluppend",
    "fluppendstem": "fluppend",
    "fluppendsten": "fluppend",
    "fluppendster": "fluppend",
    "fluppendstes": "fluppend",
    "fluppest": "fluppen",
    "fluppet": "fluppen",
    "fluppst": "fluppen",
    "fluppt": "fluppen",
    "fluppte": "fluppen",
    "fluppten": "fluppen",
    "flupptest": "fluppen",
    "flupptet": "fluppen",
    "flute": "fluten",
    "flutend": "fluten",
    "flutende": "flutend",
    "flutendem": "flutend",
    "flutenden": "flutend",
    "flutender": "flutend",
    "flutendes": "flutend",
    "flutest": "fluten",
    "flutet": "fluten",
    "flutete": "fluten",
    "fluteten": "fluten",
    "flutetest": "fluten",
    "flutetet": "fluten",
    "flutsche": "flutschen",
    "flutschend": "flutschen",
    "flutschende": "flutschend",
    "flutschendem": "flutschend",
    "flutschenden": "flutschend",
    "flutschender": "flutschend",
    "flutschendere": "flutschend",
    "flutschenderem": "flutschend",
    "flutschenderen": "flutschend",
    "flutschenderer": "flutschend",
    "flutschenderes": "flutschend",
    "flutschendes": "flutschend",
    "flutschendste": "flutschend",
    "flutschendstem": "flutschend",
    "flutschendsten": "flutschend",
    "flutschendster": "flutschend",
    "flutschendstes": "flutschend",
    "flutschest": "flutschen",
    "flutschet": "flutschen",
    "flutschst": "flutschen",
    "flutscht": "flutschen",
    "flutschte": "flutschen",
    "flutschten": "flutschen",
    "flutschtest": "flutschen",
    "flutschtet": "flutschen",
    "flämischem": "flämisch",
    "flämischen": "flämisch",
    "flämischer": "flämisch",
    "flämisches": "flämisch",
    "flämme": "flämmen",
    "flämmend": "flämmen",
    "flämmendem": "flämmend",
    "flämmender": "flämmend",
    "flämmenderem": "flämmend",
    "flämmenderer": "flämmend",
    "flämmenderes": "flämmend",
    "flämmendes": "flämmend",
    "flämmendstem": "flämmend",
    "flämmendster": "flämmend",
    "flämmendstes": "flämmend",
    "flämmest": "flämmen",
    "flämmet": "flämmen",
    "flämmst": "flämmen",
    "flämmt": "flämmen",
    "flämmte": "flämmen",
    "flämmten": "flämmen",
    "flämmtest": "flämmen",
    "flämmtet": "flämmen",
    "fläze": "fläzen",
    "fläzend": "fläzen",
    "fläzende": "fläzend",
    "fläzendem": "fläzend",
    "fläzenden": "fläzend",
    "fläzender": "fläzend",
    "fläzendere": "fläzend",
    "fläzenderem": "fläzend",
    "fläzenderen": "fläzend",
    "fläzenderer": "fläzend",
    "fläzenderes": "fläzend",
    "fläzendes": "fläzend",
    "fläzendste": "fläzend",
    "fläzendstem": "fläzend",
    "fläzendsten": "fläzend",
    "fläzendster": "fläzend",
    "fläzendstes": "fläzend",
    "fläzest": "fläzen",
    "fläzet": "fläzen",
    "fläzt": "fläzen",
    "fläzte": "fläzen",
    "fläzten": "fläzen",
    "fläztest": "fläzen",
    "fläztet": "fläzen",
    "flöchte": "flechten",
    "flöchten": "flechten",
    "flöchtest": "flechten",
    "flöchtet": "flechten",
    "flöge": "fliegen",
    "flögen": "fliegen",
    "flögest": "fliegen",
    "flöget": "fliegen",
    "flöhen": "fliehen",
    "flöhest": "fliehen",
    "flöhet": "fliehen",
    "flösse": "fließen",
    "flössen": "fließen",
    "flössest": "fließen",
    "flösset": "fließen",
    "flöte": "flöten",
    "flötend": "flöten",
    "flötende": "flötend",
    "flötendem": "flötend",
    "flötenden": "flötend",
    "flötender": "flötend",
    "flötendere": "flötend",
    "flötenderem": "flötend",
    "flötenderen": "flötend",
    "flötenderer": "flötend",
    "flötenderes": "flötend",
    "flötendes": "flötend",
    "flötendste": "flötend",
    "flötendstem": "flötend",
    "flötendsten": "flötend",
    "flötendster": "flötend",
    "flötendstes": "flötend",
    "flötengegangen": "flötengehen",
    "flötengegangene": "flötengegangen",
    "flötengegangenem": "flötengegangen",
    "flötengegangenen": "flötengegangen",
    "flötengegangener": "flötengegangen",
    "flötengegangenes": "flötengegangen",
    "flötengehe": "flötengehen",
    "flötengehend": "flötengehen",
    "flötengehende": "flötengehend",
    "flötengehendem": "flötengehend",
    "flötengehenden": "flötengehend",
    "flötengehender": "flötengehend",
    "flötengehendes": "flötengehend",
    "flötengehest": "flötengehen",
    "flötengehet": "flötengehen",
    "flötengehst": "flötengehen",
    "flötengeht": "flötengehen",
    "flötenging": "flötengehen",
    "flötenginge": "flötengehen",
    "flötengingen": "flötengehen",
    "flötengingest": "flötengehen",
    "flötenginget": "flötengehen",
    "flötengingst": "flötengehen",
    "flötengingt": "flötengehen",
    "flötenzugehen": "flötengehen",
    "flötest": "flöten",
    "flötet": "flöten",
    "flötete": "flöten",
    "flöteten": "flöten",
    "flötetest": "flöten",
    "flötetet": "flöten",
    "flöße": "flößen",
    "flößend": "flößen",
    "flößende": "flößend",
    "flößendem": "flößend",
    "flößenden": "flößend",
    "flößender": "flößend",
    "flößendes": "flößend",
    "flößest": "flößen",
    "flößet": "flößen",
    "flößt": "flößen",
    "flößte": "flößen",
    "flößten": "flößen",
    "flößtest": "flößen",
    "flößtet": "flößen",
    "flüchtend": "flüchten",
    "flüchtendem": "flüchtend",
    "flüchtender": "flüchtend",
    "flüchtendes": "flüchtend",
    "flüchtest": "flüchten",
    "flüchtet": "flüchten",
    "flüchtete": "flüchten",
    "flüchteten": "flüchten",
    "flüchtetest": "flüchten",
    "flüchtetet": "flüchten",
    "flüchtigem": "flüchtig",
    "flüchtigen": "flüchtig",
    "flüchtiger": "flüchtig",
    "flüchtiges": "flüchtig",
    "flügellahmem": "flügellahm",
    "flügellahmen": "flügellahm",
    "flügellahmer": "flügellahm",
    "flügellahmere": "flügellahm",
    "flügellahmerem": "flügellahm",
    "flügellahmeren": "flügellahm",
    "flügellahmerer": "flügellahm",
    "flügellahmeres": "flügellahm",
    "flügellahmes": "flügellahm",
    "flügellahmste": "flügellahm",
    "flügellahmstem": "flügellahm",
    "flügellahmsten": "flügellahm",
    "flügellahmster": "flügellahm",
    "flügellahmstes": "flügellahm",
    "flüggem": "flügge",
    "flüggen": "flügge",
    "flügger": "flügge",
    "flügges": "flügge",
    "flüssigem": "flüssig",
    "flüssigen": "flüssig",
    "flüssiger": "flüssig",
    "flüssigere": "flüssig",
    "flüssigerem": "flüssig",
    "flüssigeren": "flüssig",
    "flüssigerer": "flüssig",
    "flüssigeres": "flüssig",
    "flüssiges": "flüssig",
    "flüssigstem": "flüssig",
    "flüssigsten": "flüssig",
    "flüssigster": "flüssig",
    "flüssigstes": "flüssig",
    "flüstere": "flüstern",
    "flüsternd": "flüstern",
    "flüsternde": "flüsternd",
    "flüsterndem": "flüsternd",
    "flüsternden": "flüsternd",
    "flüsternder": "flüsternd",
    "flüsterndes": "flüsternd",
    "flüsterst": "flüstern",
    "flüstert": "flüstern",
    "flüsterte": "flüstern",
    "flüsterten": "flüstern",
    "flüstertest": "flüstern",
    "flüstertet": "flüstern",
    "focht": "fechten",
    "fochten": "fechten",
    "fochtest": "fechten",
    "fochtet": "fechten",
    "fokussiere": "fokussieren",
    "fokussierend": "fokussieren",
    "fokussierende": "fokussierend",
    "fokussierendem": "fokussierend",
    "fokussierenden": "fokussierend",
    "fokussierender": "fokussierend",
    "fokussierendere": "fokussierend",
    "fokussierenderem": "fokussierend",
    "fokussierenderen": "fokussierend",
    "fokussierenderer": "fokussierend",
    "fokussierenderes": "fokussierend",
    "fokussierendes": "fokussierend",
    "fokussierendste": "fokussierend",
    "fokussierendstem": "fokussierend",
    "fokussierendsten": "fokussierend",
    "fokussierendster": "fokussierend",
    "fokussierendstes": "fokussierend",
    "fokussierest": "fokussieren",
    "fokussieret": "fokussieren",
    "fokussierst": "fokussieren",
    "fokussiert": "fokussieren",
    "fokussierte": "fokussieren",
    "fokussiertem": "fokussiert",
    "fokussierten": "fokussieren",
    "fokussierter": "fokussiert",
    "fokussiertere": "fokussiert",
    "fokussierterem": "fokussiert",
    "fokussierteren": "fokussiert",
    "fokussierterer": "fokussiert",
    "fokussierteres": "fokussiert",
    "fokussiertes": "fokussiert",
    "fokussiertest": "fokussieren",
    "fokussierteste": "fokussiert",
    "fokussiertestem": "fokussiert",
    "fokussiertesten": "fokussiert",
    "fokussiertester": "fokussiert",
    "fokussiertestes": "fokussiert",
    "fokussiertet": "fokussieren",
    "folge": "folgen",
    "folgend": "folgen",
    "folgende": "folgend",
    "folgendem": "folgend",
    "folgenden": "folgend",
    "folgender": "folgend",
    "folgendes": "folgend",
    "folgenlose": "folgenlos",
    "folgenlosem": "folgenlos",
    "folgenlosen": "folgenlos",
    "folgenloser": "folgenlos",
    "folgenlosere": "folgenlos",
    "folgenloserem": "folgenlos",
    "folgenloseren": "folgenlos",
    "folgenloserer": "folgenlos",
    "folgenloseres": "folgenlos",
    "folgenloses": "folgenlos",
    "folgenloseste": "folgenlos",
    "folgenlosestem": "folgenlos",
    "folgenlosesten": "folgenlos",
    "folgenlosester": "folgenlos",
    "folgenlosestes": "folgenlos",
    "folgenschwerem": "folgenschwer",
    "folgenschweren": "folgenschwer",
    "folgenschwerer": "folgenschwer",
    "folgenschwerere": "folgenschwer",
    "folgenschwererem": "folgenschwer",
    "folgenschwereren": "folgenschwer",
    "folgenschwererer": "folgenschwer",
    "folgenschwereres": "folgenschwer",
    "folgenschweres": "folgenschwer",
    "folgenschwerste": "folgenschwer",
    "folgenschwerstem": "folgenschwer",
    "folgenschwersten": "folgenschwer",
    "folgenschwerster": "folgenschwer",
    "folgenschwerstes": "folgenschwer",
    "folgere": "folgern",
    "folgerichtige": "folgerichtig",
    "folgerichtigem": "folgerichtig",
    "folgerichtigen": "folgerichtig",
    "folgerichtiger": "folgerichtig",
    "folgerichtiges": "folgerichtig",
    "folgernd": "folgern",
    "folgernde": "folgernd",
    "folgerndem": "folgernd",
    "folgernden": "folgernd",
    "folgernder": "folgernd",
    "folgerndes": "folgernd",
    "folgerst": "folgern",
    "folgert": "folgern",
    "folgerte": "folgern",
    "folgerten": "folgern",
    "folgertest": "folgern",
    "folgertet": "folgern",
    "folgest": "folgen",
    "folget": "folgen",
    "folgsame": "folgsam",
    "folgsamem": "folgsam",
    "folgsamen": "folgsam",
    "folgsamer": "folgsam",
    "folgsames": "folgsam",
    "folgst": "folgen",
    "folgt": "folgen",
    "folgte": "folgen",
    "folgten": "folgen",
    "folgtest": "folgen",
    "folgtet": "folgen",
    "foltere": "foltern",
    "folternd": "foltern",
    "folternde": "folternd",
    "folterndem": "folternd",
    "folternden": "folternd",
    "folternder": "folternd",
    "folterndere": "folternd",
    "folternderem": "folternd",
    "folternderen": "folternd",
    "folternderer": "folternd",
    "folternderes": "folternd",
    "folterndes": "folternd",
    "folterndste": "folternd",
    "folterndstem": "folternd",
    "folterndsten": "folternd",
    "folterndster": "folternd",
    "folterndstes": "folternd",
    "folterst": "foltern",
    "foltert": "foltern",
    "folterte": "foltern",
    "folterten": "foltern",
    "foltertest": "foltern",
    "foltertet": "foltern",
    "foppe": "foppen",
    "foppend": "foppen",
    "foppende": "foppend",
    "foppendem": "foppend",
    "foppenden": "foppend",
    "foppender": "foppend",
    "foppendere": "foppend",
    "foppenderem": "foppend",
    "foppenderen": "foppend",
    "foppenderer": "foppend",
    "foppenderes": "foppend",
    "foppendes": "foppend",
    "foppendste": "foppend",
    "foppendstem": "foppend",
    "foppendsten": "foppend",
    "foppendster": "foppend",
    "foppendstes": "foppend",
    "foppest": "foppen",
    "foppet": "foppen",
    "foppst": "foppen",
    "foppt": "foppen",
    "foppte": "foppen",
    "foppten": "foppen",
    "fopptest": "foppen",
    "fopptet": "foppen",
    "forciere": "forcieren",
    "forcierend": "forcieren",
    "forcierende": "forcierend",
    "forcierendem": "forcierend",
    "forcierenden": "forcierend",
    "forcierender": "forcierend",
    "forcierendere": "forcierend",
    "forcierenderem": "forcierend",
    "forcierenderen": "forcierend",
    "forcierenderer": "forcierend",
    "forcierenderes": "forcierend",
    "forcierendes": "forcierend",
    "forcierendste": "forcierend",
    "forcierendstem": "forcierend",
    "forcierendsten": "forcierend",
    "forcierendster": "forcierend",
    "forcierendstes": "forcierend",
    "forcierest": "forcieren",
    "forcieret": "forcieren",
    "forcierst": "forcieren",
    "forciert": "forcieren",
    "forcierte": "forcieren",
    "forciertem": "forciert",
    "forcierten": "forcieren",
    "forcierter": "forciert",
    "forciertere": "forciert",
    "forcierterem": "forciert",
    "forcierteren": "forciert",
    "forcierterer": "forciert",
    "forcierteres": "forciert",
    "forciertes": "forciert",
    "forciertest": "forcieren",
    "forcierteste": "forciert",
    "forciertestem": "forciert",
    "forciertesten": "forciert",
    "forciertester": "forciert",
    "forciertestes": "forciert",
    "forciertet": "forcieren",
    "fordere": "fordern",
    "fordernd": "fordern",
    "fordernde": "fordernd",
    "forderndem": "fordernd",
    "fordernden": "fordernd",
    "fordernder": "fordernd",
    "forderndere": "fordernd",
    "fordernderem": "fordernd",
    "fordernderen": "fordernd",
    "fordernderer": "fordernd",
    "fordernderes": "fordernd",
    "forderndes": "fordernd",
    "forderndste": "fordernd",
    "forderndstem": "fordernd",
    "forderndsten": "fordernd",
    "forderndster": "fordernd",
    "forderndstes": "fordernd",
    "forderst": "fordern",
    "fordert": "fordern",
    "forderte": "fordern",
    "forderten": "fordern",
    "fordertest": "fordern",
    "fordertet": "fordern",
    "forensischem": "forensisch",
    "forensischen": "forensisch",
    "forensischer": "forensisch",
    "forensisches": "forensisch",
    "formalem": "formal",
    "formalen": "formal",
    "formaler": "formal",
    "formalere": "formal",
    "formalerem": "formal",
    "formaleren": "formal",
    "formalerer": "formal",
    "formaleres": "formal",
    "formales": "formal",
    "formalisiere": "formalisieren",
    "formalisierend": "formalisieren",
    "formalisierende": "formalisierend",
    "formalisierendem": "formalisierend",
    "formalisierenden": "formalisierend",
    "formalisierender": "formalisierend",
    "formalisierendere": "formalisierend",
    "formalisierenderem": "formalisierend",
    "formalisierenderen": "formalisierend",
    "formalisierenderer": "formalisierend",
    "formalisierenderes": "formalisierend",
    "formalisierendes": "formalisierend",
    "formalisierendste": "formalisierend",
    "formalisierendstem": "formalisierend",
    "formalisierendsten": "formalisierend",
    "formalisierendster": "formalisierend",
    "formalisierendstes": "formalisierend",
    "formalisierest": "formalisieren",
    "formalisieret": "formalisieren",
    "formalisierst": "formalisieren",
    "formalisiert": "formalisieren",
    "formalisierte": "formalisieren",
    "formalisiertem": "formalisiert",
    "formalisierten": "formalisieren",
    "formalisierter": "formalisiert",
    "formalisiertere": "formalisiert",
    "formalisierterem": "formalisiert",
    "formalisierteren": "formalisiert",
    "formalisierterer": "formalisiert",
    "formalisierteres": "formalisiert",
    "formalisiertes": "formalisiert",
    "formalisiertest": "formalisieren",
    "formalisierteste": "formalisiert",
    "formalisiertestem": "formalisiert",
    "formalisiertesten": "formalisiert",
    "formalisiertester": "formalisiert",
    "formalisiertestes": "formalisiert",
    "formalisiertet": "formalisieren",
    "formalstem": "formal",
    "formalsten": "formal",
    "formalster": "formal",
    "formalstes": "formal",
    "formatiere": "formatieren",
    "formatierend": "formatieren",
    "formatierende": "formatierend",
    "formatierendem": "formatierend",
    "formatierenden": "formatierend",
    "formatierender": "formatierend",
    "formatierendere": "formatierend",
    "formatierenderem": "formatierend",
    "formatierenderen": "formatierend",
    "formatierenderer": "formatierend",
    "formatierenderes": "formatierend",
    "formatierendes": "formatierend",
    "formatierendste": "formatierend",
    "formatierendstem": "formatierend",
    "formatierendsten": "formatierend",
    "formatierendster": "formatierend",
    "formatierendstes": "formatierend",
    "formatierest": "formatieren",
    "formatieret": "formatieren",
    "formatierst": "formatieren",
    "formatiert": "formatieren",
    "formatierte": "formatieren",
    "formatiertem": "formatiert",
    "formatierten": "formatieren",
    "formatierter": "formatiert",
    "formatiertere": "formatiert",
    "formatierterem": "formatiert",
    "formatierteren": "formatiert",
    "formatierterer": "formatiert",
    "formatierteres": "formatiert",
    "formatiertes": "formatiert",
    "formatiertest": "formatieren",
    "formatierteste": "formatiert",
    "formatiertestem": "formatiert",
    "formatiertesten": "formatiert",
    "formatiertester": "formatiert",
    "formatiertestes": "formatiert",
    "formatiertet": "formatieren",
    "formativem": "formativ",
    "formativen": "formativ",
    "formativer": "formativ",
    "formatives": "formativ",
    "formbarem": "formbar",
    "formbaren": "formbar",
    "formbarer": "formbar",
    "formbarere": "formbar",
    "formbarerem": "formbar",
    "formbareren": "formbar",
    "formbarerer": "formbar",
    "formbareres": "formbar",
    "formbares": "formbar",
    "formbarste": "formbar",
    "formbarstem": "formbar",
    "formbarsten": "formbar",
    "formbarster": "formbar",
    "formbarstes": "formbar",
    "formbeständige": "formbeständig",
    "formbeständigem": "formbeständig",
    "formbeständigen": "formbeständig",
    "formbeständiger": "formbeständig",
    "formbeständigere": "formbeständig",
    "formbeständigerem": "formbeständig",
    "formbeständigeren": "formbeständig",
    "formbeständigerer": "formbeständig",
    "formbeständigeres": "formbeständig",
    "formbeständiges": "formbeständig",
    "formbeständigste": "formbeständig",
    "formbeständigstem": "formbeständig",
    "formbeständigsten": "formbeständig",
    "formbeständigster": "formbeständig",
    "formbeständigstes": "formbeständig",
    "forme": "formen",
    "formelhafte": "formelhaft",
    "formelhaftem": "formelhaft",
    "formelhaften": "formelhaft",
    "formelhafter": "formelhaft",
    "formelhaftere": "formelhaft",
    "formelhafterem": "formelhaft",
    "formelhafteren": "formelhaft",
    "formelhafterer": "formelhaft",
    "formelhafteres": "formelhaft",
    "formelhaftes": "formelhaft",
    "formelhafteste": "formelhaft",
    "formelhaftestem": "formelhaft",
    "formelhaftesten": "formelhaft",
    "formelhaftester": "formelhaft",
    "formelhaftestes": "formelhaft",
    "formelle": "formell",
    "formellem": "formell",
    "formellen": "formell",
    "formeller": "formell",
    "formellere": "formell",
    "formellerem": "formell",
    "formelleren": "formell",
    "formellerer": "formell",
    "formelleres": "formell",
    "formelles": "formell",
    "formellste": "formell",
    "formellstem": "formell",
    "formellsten": "formell",
    "formellster": "formell",
    "formellstes": "formell",
    "formend": "formen",
    "formende": "formend",
    "formendem": "formend",
    "formenden": "formend",
    "formender": "formend",
    "formendes": "formend",
    "formest": "formen",
    "formet": "formen",
    "formiere": "formieren",
    "formierend": "formieren",
    "formierende": "formierend",
    "formierendem": "formierend",
    "formierenden": "formierend",
    "formierender": "formierend",
    "formierendes": "formierend",
    "formierest": "formieren",
    "formieret": "formieren",
    "formierst": "formieren",
    "formiert": "formieren",
    "formierte": "formieren",
    "formiertem": "formiert",
    "formierten": "formieren",
    "formierter": "formiert",
    "formiertes": "formiert",
    "formiertest": "formieren",
    "formiertet": "formieren",
    "formlose": "formlos",
    "formlosem": "formlos",
    "formlosen": "formlos",
    "formloser": "formlos",
    "formloses": "formlos",
    "formschöne": "formschön",
    "formschönem": "formschön",
    "formschönen": "formschön",
    "formschöner": "formschön",
    "formschönere": "formschön",
    "formschönerem": "formschön",
    "formschöneren": "formschön",
    "formschönerer": "formschön",
    "formschöneres": "formschön",
    "formschönes": "formschön",
    "formschönste": "formschön",
    "formschönstem": "formschön",
    "formschönsten": "formschön",
    "formschönster": "formschön",
    "formschönstes": "formschön",
    "formst": "formen",
    "formt": "formen",
    "formte": "formen",
    "formten": "formen",
    "formtest": "formen",
    "formtet": "formen",
    "formuliere": "formulieren",
    "formulierend": "formulieren",
    "formulierende": "formulierend",
    "formulierendem": "formulierend",
    "formulierenden": "formulierend",
    "formulierender": "formulierend",
    "formulierendes": "formulierend",
    "formulierest": "formulieren",
    "formulieret": "formulieren",
    "formulierst": "formulieren",
    "formuliert": "formulieren",
    "formulierte": "formulieren",
    "formuliertem": "formuliert",
    "formulierten": "formulieren",
    "formulierter": "formuliert",
    "formuliertes": "formuliert",
    "formuliertest": "formulieren",
    "formuliertet": "formulieren",
    "formvollendetem": "formvollendet",
    "formvollendeten": "formvollendet",
    "formvollendeter": "formvollendet",
    "formvollendetes": "formvollendet",
    "forsche": "forschen",
    "forschend": "forschen",
    "forschende": "forschend",
    "forschendem": "forschend",
    "forschenden": "forschend",
    "forschender": "forschend",
    "forschendere": "forschend",
    "forschenderem": "forschend",
    "forschenderen": "forschend",
    "forschenderer": "forschend",
    "forschenderes": "forschend",
    "forschendes": "forschend",
    "forschendste": "forschend",
    "forschendstem": "forschend",
    "forschendsten": "forschend",
    "forschendster": "forschend",
    "forschendstes": "forschend",
    "forschest": "forschen",
    "forschet": "forschen",
    "forschst": "forschen",
    "forscht": "forschen",
    "forschte": "forschen",
    "forschten": "forschen",
    "forschtest": "forschen",
    "forschtet": "forschen",
    "forstend": "forsten",
    "forstende": "forstend",
    "forstendem": "forstend",
    "forstenden": "forstend",
    "forstender": "forstend",
    "forstendes": "forstend",
    "forstest": "forsten",
    "forstet": "forsten",
    "forstete": "forsten",
    "forsteten": "forsten",
    "forstetest": "forsten",
    "forstetet": "forsten",
    "forstrechtliche": "forstrechtlich",
    "forstrechtlichem": "forstrechtlich",
    "forstrechtlichen": "forstrechtlich",
    "forstrechtlicher": "forstrechtlich",
    "forstrechtliches": "forstrechtlich",
    "forsttechnische": "forsttechnisch",
    "forsttechnischem": "forsttechnisch",
    "forsttechnischen": "forsttechnisch",
    "forsttechnischer": "forsttechnisch",
    "forsttechnisches": "forsttechnisch",
    "fortbegab": "fortbegeben",
    "fortbegaben": "fortbegeben",
    "fortbegabst": "fortbegeben",
    "fortbegabt": "fortbegeben",
    "fortbegebe": "fortbegeben",
    "fortbegebend": "fortbegeben",
    "fortbegebende": "fortbegebend",
    "fortbegebendem": "fortbegebend",
    "fortbegebenden": "fortbegebend",
    "fortbegebender": "fortbegebend",
    "fortbegebendes": "fortbegebend",
    "fortbegebene": "fortbegeben",
    "fortbegebenem": "fortbegeben",
    "fortbegebenen": "fortbegeben",
    "fortbegebener": "fortbegeben",
    "fortbegebenes": "fortbegeben",
    "fortbegebest": "fortbegeben",
    "fortbegebet": "fortbegeben",
    "fortbegebt": "fortbegeben",
    "fortbegibst": "fortbegeben",
    "fortbegibt": "fortbegeben",
    "fortbegäbe": "fortbegeben",
    "fortbegäben": "fortbegeben",
    "fortbegäbest": "fortbegeben",
    "fortbegäbet": "fortbegeben",
    "fortbestand": "fortbestehen",
    "fortbestanden": "fortbestehen",
    "fortbestandene": "fortbestanden",
    "fortbestandenem": "fortbestanden",
    "fortbestandenen": "fortbestanden",
    "fortbestandener": "fortbestanden",
    "fortbestandenes": "fortbestanden",
    "fortbestandest": "fortbestehen",
    "fortbestandet": "fortbestehen",
    "fortbestehe": "fortbestehen",
    "fortbestehend": "fortbestehen",
    "fortbestehende": "fortbestehend",
    "fortbestehendem": "fortbestehend",
    "fortbestehenden": "fortbestehend",
    "fortbestehender": "fortbestehend",
    "fortbestehendes": "fortbestehend",
    "fortbestehest": "fortbestehen",
    "fortbestehet": "fortbestehen",
    "fortbestehst": "fortbestehen",
    "fortbesteht": "fortbestehen",
    "fortbestünde": "fortbestehen",
    "fortbestünden": "fortbestehen",
    "fortbestündest": "fortbestehen",
    "fortbestündet": "fortbestehen",
    "fortbewege": "fortbewegen",
    "fortbewegend": "fortbewegen",
    "fortbewegende": "fortbewegend",
    "fortbewegendem": "fortbewegend",
    "fortbewegenden": "fortbewegend",
    "fortbewegender": "fortbewegend",
    "fortbewegendes": "fortbewegend",
    "fortbewegest": "fortbewegen",
    "fortbeweget": "fortbewegen",
    "fortbewegst": "fortbewegen",
    "fortbewegt": "fortbewegen",
    "fortbewegte": "fortbewegen",
    "fortbewegtem": "fortbewegt",
    "fortbewegten": "fortbewegen",
    "fortbewegter": "fortbewegt",
    "fortbewegtes": "fortbewegt",
    "fortbewegtest": "fortbewegen",
    "fortbewegtet": "fortbewegen",
    "fortbewog": "fortbewegen",
    "fortbewogen": "fortbewegen",
    "fortbewogene": "fortbewogen",
    "fortbewogenem": "fortbewogen",
    "fortbewogenen": "fortbewogen",
    "fortbewogener": "fortbewogen",
    "fortbewogenes": "fortbewogen",
    "fortbewogst": "fortbewegen",
    "fortbewogt": "fortbewegen",
    "fortbewöge": "fortbewegen",
    "fortbewögen": "fortbewegen",
    "fortbewögest": "fortbewegen",
    "fortbewöget": "fortbewegen",
    "fortbilde": "fortbilden",
    "fortbildend": "fortbilden",
    "fortbildende": "fortbildend",
    "fortbildendem": "fortbildend",
    "fortbildenden": "fortbildend",
    "fortbildender": "fortbildend",
    "fortbildendes": "fortbildend",
    "fortbildest": "fortbilden",
    "fortbildet": "fortbilden",
    "fortbildete": "fortbilden",
    "fortbildeten": "fortbilden",
    "fortbildetest": "fortbilden",
    "fortbildetet": "fortbilden",
    "fortblase": "fortblasen",
    "fortblasend": "fortblasen",
    "fortblasende": "fortblasend",
    "fortblasendem": "fortblasend",
    "fortblasenden": "fortblasend",
    "fortblasender": "fortblasend",
    "fortblasendes": "fortblasend",
    "fortblasest": "fortblasen",
    "fortblaset": "fortblasen",
    "fortblast": "fortblasen",
    "fortbleibe": "fortbleiben",
    "fortbleibend": "fortbleiben",
    "fortbleibende": "fortbleibend",
    "fortbleibendem": "fortbleibend",
    "fortbleibenden": "fortbleibend",
    "fortbleibender": "fortbleibend",
    "fortbleibendes": "fortbleibend",
    "fortbleibest": "fortbleiben",
    "fortbleibet": "fortbleiben",
    "fortbleibst": "fortbleiben",
    "fortbleibt": "fortbleiben",
    "fortblieb": "fortbleiben",
    "fortbliebe": "fortbleiben",
    "fortblieben": "fortbleiben",
    "fortbliebest": "fortbleiben",
    "fortbliebet": "fortbleiben",
    "fortbliebst": "fortbleiben",
    "fortbliebt": "fortbleiben",
    "fortblies": "fortblasen",
    "fortbliese": "fortblasen",
    "fortbliesen": "fortblasen",
    "fortbliesest": "fortblasen",
    "fortblieset": "fortblasen",
    "fortbliest": "fortblasen",
    "fortbläst": "fortblasen",
    "fortbrachte": "fortbringen",
    "fortbrachten": "fortbringen",
    "fortbrachtest": "fortbringen",
    "fortbrachtet": "fortbringen",
    "fortbringe": "fortbringen",
    "fortbringend": "fortbringen",
    "fortbringende": "fortbringend",
    "fortbringendem": "fortbringend",
    "fortbringenden": "fortbringend",
    "fortbringender": "fortbringend",
    "fortbringendes": "fortbringend",
    "fortbringest": "fortbringen",
    "fortbringet": "fortbringen",
    "fortbringst": "fortbringen",
    "fortbringt": "fortbringen",
    "fortbrächte": "fortbringen",
    "fortbrächten": "fortbringen",
    "fortbrächtest": "fortbringen",
    "fortbrächtet": "fortbringen",
    "fortdachte": "fortdenken",
    "fortdachten": "fortdenken",
    "fortdachtest": "fortdenken",
    "fortdachtet": "fortdenken",
    "fortdauere": "fortdauern",
    "fortdauernd": "fortdauern",
    "fortdauernde": "fortdauernd",
    "fortdauerndem": "fortdauernd",
    "fortdauernden": "fortdauernd",
    "fortdauernder": "fortdauernd",
    "fortdauerndes": "fortdauernd",
    "fortdauerst": "fortdauern",
    "fortdauert": "fortdauern",
    "fortdauerte": "fortdauern",
    "fortdauerten": "fortdauern",
    "fortdauertest": "fortdauern",
    "fortdauertet": "fortdauern",
    "fortdenke": "fortdenken",
    "fortdenkend": "fortdenken",
    "fortdenkende": "fortdenkend",
    "fortdenkendem": "fortdenkend",
    "fortdenkenden": "fortdenkend",
    "fortdenkender": "fortdenkend",
    "fortdenkendes": "fortdenkend",
    "fortdenkest": "fortdenken",
    "fortdenket": "fortdenken",
    "fortdenkst": "fortdenken",
    "fortdenkt": "fortdenken",
    "fortdränge": "fortdrängen",
    "fortdrängend": "fortdrängen",
    "fortdrängende": "fortdrängend",
    "fortdrängendem": "fortdrängend",
    "fortdrängenden": "fortdrängend",
    "fortdrängender": "fortdrängend",
    "fortdrängendes": "fortdrängend",
    "fortdrängest": "fortdrängen",
    "fortdränget": "fortdrängen",
    "fortdrängst": "fortdrängen",
    "fortdrängt": "fortdrängen",
    "fortdrängte": "fortdrängen",
    "fortdrängten": "fortdrängen",
    "fortdrängtest": "fortdrängen",
    "fortdrängtet": "fortdrängen",
    "fortdächte": "fortdenken",
    "fortdächten": "fortdenken",
    "fortdächtest": "fortdenken",
    "fortdächtet": "fortdenken",
    "forteile": "forteilen",
    "forteilend": "forteilen",
    "forteilende": "forteilend",
    "forteilendem": "forteilend",
    "forteilenden": "forteilend",
    "forteilender": "forteilend",
    "forteilendes": "forteilend",
    "forteilest": "forteilen",
    "forteilet": "forteilen",
    "forteilst": "forteilen",
    "forteilt": "forteilen",
    "forteilte": "forteilen",
    "forteilten": "forteilen",
    "forteiltest": "forteilen",
    "forteiltet": "forteilen",
    "fortfalle": "fortfallen",
    "fortfallend": "fortfallen",
    "fortfallende": "fortfallend",
    "fortfallendem": "fortfallend",
    "fortfallenden": "fortfallend",
    "fortfallender": "fortfallend",
    "fortfallendes": "fortfallend",
    "fortfallest": "fortfallen",
    "fortfallet": "fortfallen",
    "fortfallt": "fortfallen",
    "fortfiel": "fortfallen",
    "fortfiele": "fortfallen",
    "fortfielen": "fortfallen",
    "fortfielest": "fortfallen",
    "fortfielet": "fortfallen",
    "fortfielst": "fortfallen",
    "fortfielt": "fortfallen",
    "fortfliege": "fortfliegen",
    "fortfliegend": "fortfliegen",
    "fortfliegende": "fortfliegend",
    "fortfliegendem": "fortfliegend",
    "fortfliegenden": "fortfliegend",
    "fortfliegender": "fortfliegend",
    "fortfliegendes": "fortfliegend",
    "fortfliegest": "fortfliegen",
    "fortflieget": "fortfliegen",
    "fortfliegst": "fortfliegen",
    "fortfliegt": "fortfliegen",
    "fortflog": "fortfliegen",
    "fortflogen": "fortfliegen",
    "fortflogst": "fortfliegen",
    "fortflogt": "fortfliegen",
    "fortflöge": "fortfliegen",
    "fortflögen": "fortfliegen",
    "fortflögest": "fortfliegen",
    "fortflöget": "fortfliegen",
    "fortfällst": "fortfallen",
    "fortfällt": "fortfallen",
    "fortführe": "fortführen",
    "fortführend": "fortführen",
    "fortführende": "fortführend",
    "fortführendem": "fortführend",
    "fortführenden": "fortführend",
    "fortführender": "fortführend",
    "fortführendes": "fortführend",
    "fortführest": "fortführen",
    "fortführet": "fortführen",
    "fortführst": "fortführen",
    "fortführt": "fortführen",
    "fortführte": "fortführen",
    "fortführten": "fortführen",
    "fortführtest": "fortführen",
    "fortführtet": "fortführen",
    "fortgab": "fortgeben",
    "fortgaben": "fortgeben",
    "fortgabst": "fortgeben",
    "fortgabt": "fortgeben",
    "fortgebe": "fortgeben",
    "fortgebend": "fortgeben",
    "fortgebende": "fortgebend",
    "fortgebendem": "fortgebend",
    "fortgebenden": "fortgebend",
    "fortgebender": "fortgebend",
    "fortgebendes": "fortgebend",
    "fortgebest": "fortgeben",
    "fortgebet": "fortgeben",
    "fortgebildet": "fortbilden",
    "fortgebildete": "fortgebildet",
    "fortgebildetem": "fortgebildet",
    "fortgebildeten": "fortgebildet",
    "fortgebildeter": "fortgebildet",
    "fortgebildetes": "fortgebildet",
    "fortgeblasen": "fortblasen",
    "fortgeblasene": "fortgeblasen",
    "fortgeblasenem": "fortgeblasen",
    "fortgeblasenen": "fortgeblasen",
    "fortgeblasener": "fortgeblasen",
    "fortgeblasenes": "fortgeblasen",
    "fortgeblieben": "fortbleiben",
    "fortgebliebene": "fortgeblieben",
    "fortgebliebenem": "fortgeblieben",
    "fortgebliebenen": "fortgeblieben",
    "fortgebliebener": "fortgeblieben",
    "fortgebliebenes": "fortgeblieben",
    "fortgebracht": "fortbringen",
    "fortgebrachte": "fortgebracht",
    "fortgebrachtem": "fortgebracht",
    "fortgebrachten": "fortgebracht",
    "fortgebrachter": "fortgebracht",
    "fortgebrachtes": "fortgebracht",
    "fortgebt": "fortgeben",
    "fortgedacht": "fortdenken",
    "fortgedachte": "fortgedacht",
    "fortgedachtem": "fortgedacht",
    "fortgedachten": "fortgedacht",
    "fortgedachter": "fortgedacht",
    "fortgedachtes": "fortgedacht",
    "fortgedauert": "fortdauern",
    "fortgedauerte": "fortgedauert",
    "fortgedauertem": "fortgedauert",
    "fortgedauerten": "fortgedauert",
    "fortgedauerter": "fortgedauert",
    "fortgedauertes": "fortgedauert",
    "fortgedrängt": "fortdrängen",
    "fortgedrängte": "fortgedrängt",
    "fortgedrängtem": "fortgedrängt",
    "fortgedrängten": "fortgedrängt",
    "fortgedrängter": "fortgedrängt",
    "fortgedrängtes": "fortgedrängt",
    "fortgeeilt": "forteilen",
    "fortgeeilte": "fortgeeilt",
    "fortgeeiltem": "fortgeeilt",
    "fortgeeilten": "fortgeeilt",
    "fortgeeilter": "fortgeeilt",
    "fortgeeiltes": "fortgeeilt",
    "fortgefallen": "fortfallen",
    "fortgefallene": "fortgefallen",
    "fortgefallenem": "fortgefallen",
    "fortgefallenen": "fortgefallen",
    "fortgefallener": "fortgefallen",
    "fortgefallenes": "fortgefallen",
    "fortgeflogen": "fortfliegen",
    "fortgeflogene": "fortgeflogen",
    "fortgeflogenem": "fortgeflogen",
    "fortgeflogenen": "fortgeflogen",
    "fortgeflogener": "fortgeflogen",
    "fortgeflogenes": "fortgeflogen",
    "fortgeführt": "fortführen",
    "fortgeführte": "fortgeführt",
    "fortgeführtem": "fortgeführt",
    "fortgeführten": "fortgeführt",
    "fortgeführter": "fortgeführt",
    "fortgeführtes": "fortgeführt",
    "fortgegeben": "fortgeben",
    "fortgegebene": "fortgegeben",
    "fortgegebenem": "fortgegeben",
    "fortgegebenen": "fortgegeben",
    "fortgegebener": "fortgegeben",
    "fortgegebenes": "fortgegeben",
    "fortgegossen": "fortgießen",
    "fortgegossene": "fortgegossen",
    "fortgegossenem": "fortgegossen",
    "fortgegossenen": "fortgegossen",
    "fortgegossener": "fortgegossen",
    "fortgegossenes": "fortgegossen",
    "fortgejagt": "fortjagen",
    "fortgejagte": "fortgejagt",
    "fortgejagtem": "fortgejagt",
    "fortgejagten": "fortgejagt",
    "fortgejagter": "fortgejagt",
    "fortgejagtes": "fortgejagt",
    "fortgekommen": "fortkommen",
    "fortgekommene": "fortgekommen",
    "fortgekommenem": "fortgekommen",
    "fortgekommenen": "fortgekommen",
    "fortgekommener": "fortgekommen",
    "fortgekommenes": "fortgekommen",
    "fortgekrochen": "fortkriechen",
    "fortgekrochene": "fortgekrochen",
    "fortgekrochenem": "fortgekrochen",
    "fortgekrochenen": "fortgekrochen",
    "fortgekrochener": "fortgekrochen",
    "fortgekrochenes": "fortgekrochen",
    "fortgelassen": "fortlassen",
    "fortgelassene": "fortgelassen",
    "fortgelassenem": "fortgelassen",
    "fortgelassenen": "fortgelassen",
    "fortgelassener": "fortgelassen",
    "fortgelassenes": "fortgelassen",
    "fortgelebt": "fortleben",
    "fortgelebte": "fortgelebt",
    "fortgelebtem": "fortgelebt",
    "fortgelebten": "fortgelebt",
    "fortgelebter": "fortgelebt",
    "fortgelebtes": "fortgelebt",
    "fortgemacht": "fortmachen",
    "fortgemachte": "fortgemacht",
    "fortgemachtem": "fortgemacht",
    "fortgemachten": "fortgemacht",
    "fortgemachter": "fortgemacht",
    "fortgemachtes": "fortgemacht",
    "fortgenommen": "fortnehmen",
    "fortgenommene": "fortgenommen",
    "fortgenommenem": "fortgenommen",
    "fortgenommenen": "fortgenommen",
    "fortgenommener": "fortgenommen",
    "fortgenommenes": "fortgenommen",
    "fortgepflanzt": "fortpflanzen",
    "fortgepflanzte": "fortgepflanzt",
    "fortgepflanztem": "fortgepflanzt",
    "fortgepflanzten": "fortgepflanzt",
    "fortgepflanzter": "fortgepflanzt",
    "fortgepflanztes": "fortgepflanzt",
    "fortgerannt": "fortrennen",
    "fortgerannte": "fortgerannt",
    "fortgeranntem": "fortgerannt",
    "fortgerannten": "fortgerannt",
    "fortgerannter": "fortgerannt",
    "fortgeranntes": "fortgerannt",
    "fortgereist": "fortreisen",
    "fortgereiste": "fortgereist",
    "fortgereistem": "fortgereist",
    "fortgereisten": "fortgereist",
    "fortgereister": "fortgereist",
    "fortgereistes": "fortgereist",
    "fortgerissen": "fortreißen",
    "fortgerissene": "fortgerissen",
    "fortgerissenem": "fortgerissen",
    "fortgerissenen": "fortgerissen",
    "fortgerissener": "fortgerissen",
    "fortgerissenes": "fortgerissen",
    "fortgeritten": "fortreiten",
    "fortgerittene": "fortgeritten",
    "fortgerittenem": "fortgeritten",
    "fortgerittenen": "fortgeritten",
    "fortgerittener": "fortgeritten",
    "fortgerittenes": "fortgeritten",
    "fortgeräumt": "forträumen",
    "fortgeräumte": "fortgeräumt",
    "fortgeräumtem": "fortgeräumt",
    "fortgeräumten": "fortgeräumt",
    "fortgeräumter": "fortgeräumt",
    "fortgeräumtes": "fortgeräumt",
    "fortgeschert": "fortscheren",
    "fortgescherte": "fortgeschert",
    "fortgeschertem": "fortgeschert",
    "fortgescherten": "fortgeschert",
    "fortgescherter": "fortgeschert",
    "fortgeschertes": "fortgeschert",
    "fortgescheucht": "fortscheuchen",
    "fortgescheuchte": "fortgescheucht",
    "fortgescheuchtem": "fortgescheucht",
    "fortgescheuchten": "fortgescheucht",
    "fortgescheuchter": "fortgescheucht",
    "fortgescheuchtes": "fortgescheucht",
    "fortgeschleppt": "fortschleppen",
    "fortgeschleppte": "fortgeschleppt",
    "fortgeschlepptem": "fortgeschleppt",
    "fortgeschleppten": "fortgeschleppt",
    "fortgeschleppter": "fortgeschleppt",
    "fortgeschlepptes": "fortgeschleppt",
    "fortgeschleudert": "fortschleudern",
    "fortgeschleuderte": "fortgeschleudert",
    "fortgeschleudertem": "fortgeschleudert",
    "fortgeschleuderten": "fortgeschleudert",
    "fortgeschleuderter": "fortgeschleudert",
    "fortgeschleudertes": "fortgeschleudert",
    "fortgeschlichen": "fortschleichen",
    "fortgeschlichene": "fortgeschlichen",
    "fortgeschlichenem": "fortgeschlichen",
    "fortgeschlichenen": "fortgeschlichen",
    "fortgeschlichener": "fortgeschlichen",
    "fortgeschlichenes": "fortgeschlichen",
    "fortgeschnellt": "fortschnellen",
    "fortgeschnellte": "fortgeschnellt",
    "fortgeschnelltem": "fortgeschnellt",
    "fortgeschnellten": "fortgeschnellt",
    "fortgeschnellter": "fortgeschnellt",
    "fortgeschnelltes": "fortgeschnellt",
    "fortgeschoben": "fortschieben",
    "fortgeschobene": "fortgeschoben",
    "fortgeschobenem": "fortgeschoben",
    "fortgeschobenen": "fortgeschoben",
    "fortgeschobener": "fortgeschoben",
    "fortgeschobenes": "fortgeschoben",
    "fortgeschoren": "fortscheren",
    "fortgeschorene": "fortgeschoren",
    "fortgeschorenem": "fortgeschoren",
    "fortgeschorenen": "fortgeschoren",
    "fortgeschorener": "fortgeschoren",
    "fortgeschorenes": "fortgeschoren",
    "fortgeschrieben": "fortschreiben",
    "fortgeschriebene": "fortgeschrieben",
    "fortgeschriebenem": "fortgeschrieben",
    "fortgeschriebenen": "fortgeschrieben",
    "fortgeschriebener": "fortgeschrieben",
    "fortgeschriebenes": "fortgeschrieben",
    "fortgeschritten": "fortschreiten",
    "fortgeschrittene": "fortgeschritten",
    "fortgeschrittenem": "fortgeschritten",
    "fortgeschrittenen": "fortgeschritten",
    "fortgeschrittener": "fortgeschritten",
    "fortgeschrittenere": "fortgeschritten",
    "fortgeschrittenerem": "fortgeschritten",
    "fortgeschritteneren": "fortgeschritten",
    "fortgeschrittenerer": "fortgeschritten",
    "fortgeschritteneres": "fortgeschritten",
    "fortgeschrittenes": "fortgeschritten",
    "fortgeschrittenste": "fortgeschritten",
    "fortgeschrittenstem": "fortgeschritten",
    "fortgeschrittensten": "fortgeschritten",
    "fortgeschrittenster": "fortgeschritten",
    "fortgeschrittenstes": "fortgeschritten",
    "fortgeschwommen": "fortschwimmen",
    "fortgeschwommene": "fortgeschwommen",
    "fortgeschwommenem": "fortgeschwommen",
    "fortgeschwommenen": "fortgeschwommen",
    "fortgeschwommener": "fortgeschwommen",
    "fortgeschwommenes": "fortgeschwommen",
    "fortgesehnt": "fortsehnen",
    "fortgesehnte": "fortgesehnt",
    "fortgesehntem": "fortgesehnt",
    "fortgesehnten": "fortgesehnt",
    "fortgesehnter": "fortgesehnt",
    "fortgesehntere": "fortgesehnt",
    "fortgesehnterem": "fortgesehnt",
    "fortgesehnteren": "fortgesehnt",
    "fortgesehnterer": "fortgesehnt",
    "fortgesehnteres": "fortgesehnt",
    "fortgesehntes": "fortgesehnt",
    "fortgesehnteste": "fortgesehnt",
    "fortgesehntestem": "fortgesehnt",
    "fortgesehntesten": "fortgesehnt",
    "fortgesehntester": "fortgesehnt",
    "fortgesehntestes": "fortgesehnt",
    "fortgesetzt": "fortsetzen",
    "fortgesetzte": "fortgesetzt",
    "fortgesetztem": "fortgesetzt",
    "fortgesetzten": "fortgesetzt",
    "fortgesetzter": "fortgesetzt",
    "fortgesetztes": "fortgesetzt",
    "fortgesprungen": "fortspringen",
    "fortgesprungene": "fortgesprungen",
    "fortgesprungenem": "fortgesprungen",
    "fortgesprungenen": "fortgesprungen",
    "fortgesprungener": "fortgesprungen",
    "fortgesprungenes": "fortgesprungen",
    "fortgestohlen": "fortstehlen",
    "fortgestohlene": "fortgestohlen",
    "fortgestohlenem": "fortgestohlen",
    "fortgestohlenen": "fortgestohlen",
    "fortgestohlener": "fortgestohlen",
    "fortgestohlenere": "fortgestohlen",
    "fortgestohlenerem": "fortgestohlen",
    "fortgestohleneren": "fortgestohlen",
    "fortgestohlenerer": "fortgestohlen",
    "fortgestohleneres": "fortgestohlen",
    "fortgestohlenes": "fortgestohlen",
    "fortgestohlenste": "fortgestohlen",
    "fortgestohlenstem": "fortgestohlen",
    "fortgestohlensten": "fortgestohlen",
    "fortgestohlenster": "fortgestohlen",
    "fortgestohlenstes": "fortgestohlen",
    "fortgestürmt": "fortstürmen",
    "fortgestürmte": "fortgestürmt",
    "fortgestürmtem": "fortgestürmt",
    "fortgestürmten": "fortgestürmt",
    "fortgestürmter": "fortgestürmt",
    "fortgestürmtes": "fortgestürmt",
    "fortgestürzt": "fortstürzen",
    "fortgestürzte": "fortgestürzt",
    "fortgestürztem": "fortgestürzt",
    "fortgestürzten": "fortgestürzt",
    "fortgestürzter": "fortgestürzt",
    "fortgestürztes": "fortgestürzt",
    "fortgetragen": "forttragen",
    "fortgetragene": "fortgetragen",
    "fortgetragenem": "fortgetragen",
    "fortgetragenen": "fortgetragen",
    "fortgetragener": "fortgetragen",
    "fortgetragenes": "fortgetragen",
    "fortgetrieben": "forttreiben",
    "fortgetriebene": "fortgetrieben",
    "fortgetriebenem": "fortgetrieben",
    "fortgetriebenen": "fortgetrieben",
    "fortgetriebener": "fortgetrieben",
    "fortgetriebenes": "fortgetrieben",
    "fortgewirkt": "fortwirken",
    "fortgewirkte": "fortgewirkt",
    "fortgewirktem": "fortgewirkt",
    "fortgewirkten": "fortgewirkt",
    "fortgewirkter": "fortgewirkt",
    "fortgewirktes": "fortgewirkt",
    "fortgewischt": "fortwischen",
    "fortgewischte": "fortgewischt",
    "fortgewischtem": "fortgewischt",
    "fortgewischten": "fortgewischt",
    "fortgewischter": "fortgewischt",
    "fortgewischtes": "fortgewischt",
    "fortgeworfen": "fortwerfen",
    "fortgeworfene": "fortgeworfen",
    "fortgeworfenem": "fortgeworfen",
    "fortgeworfenen": "fortgeworfen",
    "fortgeworfener": "fortgeworfen",
    "fortgeworfenes": "fortgeworfen",
    "fortgewährt": "fortwähren",
    "fortgewährte": "fortgewährt",
    "fortgewährtem": "fortgewährt",
    "fortgewährten": "fortgewährt",
    "fortgewährter": "fortgewährt",
    "fortgewährtes": "fortgewährt",
    "fortgewälzt": "fortwälzen",
    "fortgewälzte": "fortgewälzt",
    "fortgewälztem": "fortgewälzt",
    "fortgewälzten": "fortgewälzt",
    "fortgewälzter": "fortgewälzt",
    "fortgewälztes": "fortgewälzt",
    "fortgewünscht": "fortwünschen",
    "fortgewünschte": "fortgewünscht",
    "fortgewünschtem": "fortgewünscht",
    "fortgewünschten": "fortgewünscht",
    "fortgewünschter": "fortgewünscht",
    "fortgewünschtes": "fortgewünscht",
    "fortgezahlt": "fortzahlen",
    "fortgezahlte": "fortgezahlt",
    "fortgezahltem": "fortgezahlt",
    "fortgezahlten": "fortgezahlt",
    "fortgezahlter": "fortgezahlt",
    "fortgezahltes": "fortgezahlt",
    "fortgezerrt": "fortzerren",
    "fortgezerrte": "fortgezerrt",
    "fortgezerrtem": "fortgezerrt",
    "fortgezerrten": "fortgezerrt",
    "fortgezerrter": "fortgezerrt",
    "fortgezerrtes": "fortgezerrt",
    "fortgibst": "fortgeben",
    "fortgibt": "fortgeben",
    "fortgieße": "fortgießen",
    "fortgießend": "fortgießen",
    "fortgießende": "fortgießend",
    "fortgießendem": "fortgießend",
    "fortgießenden": "fortgießend",
    "fortgießender": "fortgießend",
    "fortgießendes": "fortgießend",
    "fortgießest": "fortgießen",
    "fortgießet": "fortgießen",
    "fortgießt": "fortgießen",
    "fortgossen": "fortgießen",
    "fortgoß": "fortgießen",
    "fortgoßt": "fortgießen",
    "fortgäbe": "fortgeben",
    "fortgäben": "fortgeben",
    "fortgäbest": "fortgeben",
    "fortgäbet": "fortgeben",
    "fortgösse": "fortgießen",
    "fortgössen": "fortgießen",
    "fortgössest": "fortgießen",
    "fortgösset": "fortgießen",
    "fortjage": "fortjagen",
    "fortjagend": "fortjagen",
    "fortjagende": "fortjagend",
    "fortjagendem": "fortjagend",
    "fortjagenden": "fortjagend",
    "fortjagender": "fortjagend",
    "fortjagendes": "fortjagend",
    "fortjagest": "fortjagen",
    "fortjaget": "fortjagen",
    "fortjagst": "fortjagen",
    "fortjagt": "fortjagen",
    "fortjagte": "fortjagen",
    "fortjagten": "fortjagen",
    "fortjagtest": "fortjagen",
    "fortjagtet": "fortjagen",
    "fortkam": "fortkommen",
    "fortkamen": "fortkommen",
    "fortkamst": "fortkommen",
    "fortkamt": "fortkommen",
    "fortkomme": "fortkommen",
    "fortkommend": "fortkommen",
    "fortkommende": "fortkommend",
    "fortkommendem": "fortkommend",
    "fortkommenden": "fortkommend",
    "fortkommender": "fortkommend",
    "fortkommendes": "fortkommend",
    "fortkommest": "fortkommen",
    "fortkommet": "fortkommen",
    "fortkommst": "fortkommen",
    "fortkommt": "fortkommen",
    "fortkrieche": "fortkriechen",
    "fortkriechend": "fortkriechen",
    "fortkriechende": "fortkriechend",
    "fortkriechendem": "fortkriechend",
    "fortkriechenden": "fortkriechend",
    "fortkriechender": "fortkriechend",
    "fortkriechendes": "fortkriechend",
    "fortkriechest": "fortkriechen",
    "fortkriechet": "fortkriechen",
    "fortkriechst": "fortkriechen",
    "fortkriecht": "fortkriechen",
    "fortkroch": "fortkriechen",
    "fortkrochen": "fortkriechen",
    "fortkrochst": "fortkriechen",
    "fortkrocht": "fortkriechen",
    "fortkröche": "fortkriechen",
    "fortkröchen": "fortkriechen",
    "fortkröchest": "fortkriechen",
    "fortkröchet": "fortkriechen",
    "fortkäme": "fortkommen",
    "fortkämen": "fortkommen",
    "fortkämest": "fortkommen",
    "fortkämet": "fortkommen",
    "fortlasse": "fortlassen",
    "fortlassend": "fortlassen",
    "fortlassende": "fortlassend",
    "fortlassendem": "fortlassend",
    "fortlassenden": "fortlassend",
    "fortlassender": "fortlassend",
    "fortlassendes": "fortlassend",
    "fortlassest": "fortlassen",
    "fortlasset": "fortlassen",
    "fortlaufende": "fortlaufend",
    "fortlaufendem": "fortlaufend",
    "fortlaufenden": "fortlaufend",
    "fortlaufender": "fortlaufend",
    "fortlaufendes": "fortlaufend",
    "fortlaßt": "fortlassen",
    "fortlebe": "fortleben",
    "fortlebend": "fortleben",
    "fortlebende": "fortlebend",
    "fortlebendem": "fortlebend",
    "fortlebenden": "fortlebend",
    "fortlebender": "fortlebend",
    "fortlebendes": "fortlebend",
    "fortlebest": "fortleben",
    "fortlebet": "fortleben",
    "fortlebst": "fortleben",
    "fortlebt": "fortleben",
    "fortlebte": "fortleben",
    "fortlebten": "fortleben",
    "fortlebtest": "fortleben",
    "fortlebtet": "fortleben",
    "fortließ": "fortlassen",
    "fortließe": "fortlassen",
    "fortließen": "fortlassen",
    "fortließest": "fortlassen",
    "fortließet": "fortlassen",
    "fortließt": "fortlassen",
    "fortläßt": "fortlassen",
    "fortmache": "fortmachen",
    "fortmachend": "fortmachen",
    "fortmachende": "fortmachend",
    "fortmachendem": "fortmachend",
    "fortmachenden": "fortmachend",
    "fortmachender": "fortmachend",
    "fortmachendes": "fortmachend",
    "fortmachest": "fortmachen",
    "fortmachet": "fortmachen",
    "fortmachst": "fortmachen",
    "fortmacht": "fortmachen",
    "fortmachte": "fortmachen",
    "fortmachten": "fortmachen",
    "fortmachtest": "fortmachen",
    "fortmachtet": "fortmachen",
    "fortmarschiere": "fortmarschieren",
    "fortmarschierend": "fortmarschieren",
    "fortmarschierende": "fortmarschierend",
    "fortmarschierendem": "fortmarschierend",
    "fortmarschierenden": "fortmarschierend",
    "fortmarschierender": "fortmarschierend",
    "fortmarschierendes": "fortmarschierend",
    "fortmarschierest": "fortmarschieren",
    "fortmarschieret": "fortmarschieren",
    "fortmarschierst": "fortmarschieren",
    "fortmarschiert": "fortmarschieren",
    "fortmarschierte": "fortmarschieren",
    "fortmarschiertem": "fortmarschiert",
    "fortmarschierten": "fortmarschieren",
    "fortmarschierter": "fortmarschiert",
    "fortmarschiertes": "fortmarschiert",
    "fortmarschiertest": "fortmarschieren",
    "fortmarschiertet": "fortmarschieren",
    "fortnahm": "fortnehmen",
    "fortnahmen": "fortnehmen",
    "fortnahmst": "fortnehmen",
    "fortnahmt": "fortnehmen",
    "fortnehme": "fortnehmen",
    "fortnehmend": "fortnehmen",
    "fortnehmende": "fortnehmend",
    "fortnehmendem": "fortnehmend",
    "fortnehmenden": "fortnehmend",
    "fortnehmender": "fortnehmend",
    "fortnehmendes": "fortnehmend",
    "fortnehmest": "fortnehmen",
    "fortnehmet": "fortnehmen",
    "fortnehmt": "fortnehmen",
    "fortnimmst": "fortnehmen",
    "fortnimmt": "fortnehmen",
    "fortnähme": "fortnehmen",
    "fortnähmen": "fortnehmen",
    "fortnähmest": "fortnehmen",
    "fortnähmet": "fortnehmen",
    "fortpflanze": "fortpflanzen",
    "fortpflanzend": "fortpflanzen",
    "fortpflanzende": "fortpflanzend",
    "fortpflanzendem": "fortpflanzend",
    "fortpflanzenden": "fortpflanzend",
    "fortpflanzender": "fortpflanzend",
    "fortpflanzendes": "fortpflanzend",
    "fortpflanzest": "fortpflanzen",
    "fortpflanzet": "fortpflanzen",
    "fortpflanzt": "fortpflanzen",
    "fortpflanzte": "fortpflanzen",
    "fortpflanzten": "fortpflanzen",
    "fortpflanztest": "fortpflanzen",
    "fortpflanztet": "fortpflanzen",
    "fortrannte": "fortrennen",
    "fortrannten": "fortrennen",
    "fortranntest": "fortrennen",
    "fortranntet": "fortrennen",
    "fortreise": "fortreisen",
    "fortreisend": "fortreisen",
    "fortreisende": "fortreisend",
    "fortreisendem": "fortreisend",
    "fortreisenden": "fortreisend",
    "fortreisender": "fortreisend",
    "fortreisendes": "fortreisend",
    "fortreisest": "fortreisen",
    "fortreiset": "fortreisen",
    "fortreist": "fortreisen",
    "fortreiste": "fortreisen",
    "fortreisten": "fortreisen",
    "fortreistest": "fortreisen",
    "fortreistet": "fortreisen",
    "fortreite": "fortreiten",
    "fortreitend": "fortreiten",
    "fortreitende": "fortreitend",
    "fortreitendem": "fortreitend",
    "fortreitenden": "fortreitend",
    "fortreitender": "fortreitend",
    "fortreitendes": "fortreitend",
    "fortreitest": "fortreiten",
    "fortreitet": "fortreiten",
    "fortreiße": "fortreißen",
    "fortreißend": "fortreißen",
    "fortreißende": "fortreißend",
    "fortreißendem": "fortreißend",
    "fortreißenden": "fortreißend",
    "fortreißender": "fortreißend",
    "fortreißendes": "fortreißend",
    "fortreißest": "fortreißen",
    "fortreißet": "fortreißen",
    "fortreißt": "fortreißen",
    "fortrenne": "fortrennen",
    "fortrennend": "fortrennen",
    "fortrennende": "fortrennend",
    "fortrennendem": "fortrennend",
    "fortrennenden": "fortrennend",
    "fortrennender": "fortrennend",
    "fortrennendes": "fortrennend",
    "fortrennest": "fortrennen",
    "fortrennet": "fortrennen",
    "fortrennst": "fortrennen",
    "fortrennt": "fortrennen",
    "fortrisse": "fortreißen",
    "fortrissen": "fortreißen",
    "fortrissest": "fortreißen",
    "fortrisset": "fortreißen",
    "fortritt": "fortreiten",
    "fortritte": "fortreiten",
    "fortritten": "fortreiten",
    "fortrittest": "fortreiten",
    "fortrittet": "fortreiten",
    "fortriß": "fortreißen",
    "fortrißt": "fortreißen",
    "forträume": "forträumen",
    "forträumend": "forträumen",
    "forträumende": "forträumend",
    "forträumendem": "forträumend",
    "forträumenden": "forträumend",
    "forträumender": "forträumend",
    "forträumendes": "forträumend",
    "forträumest": "forträumen",
    "forträumet": "forträumen",
    "forträumst": "forträumen",
    "forträumt": "forträumen",
    "forträumte": "forträumen",
    "forträumten": "forträumen",
    "forträumtest": "forträumen",
    "forträumtet": "forträumen",
    "fortschere": "fortscheren",
    "fortscherend": "fortscheren",
    "fortscherende": "fortscherend",
    "fortscherendem": "fortscherend",
    "fortscherenden": "fortscherend",
    "fortscherender": "fortscherend",
    "fortscherendes": "fortscherend",
    "fortscherest": "fortscheren",
    "fortscheret": "fortscheren",
    "fortscherst": "fortscheren",
    "fortschert": "fortscheren",
    "fortscherte": "fortscheren",
    "fortscherten": "fortscheren",
    "fortschertest": "fortscheren",
    "fortschertet": "fortscheren",
    "fortscheuche": "fortscheuchen",
    "fortscheuchend": "fortscheuchen",
    "fortscheuchende": "fortscheuchend",
    "fortscheuchendem": "fortscheuchend",
    "fortscheuchenden": "fortscheuchend",
    "fortscheuchender": "fortscheuchend",
    "fortscheuchendes": "fortscheuchend",
    "fortscheuchest": "fortscheuchen",
    "fortscheuchet": "fortscheuchen",
    "fortscheuchst": "fortscheuchen",
    "fortscheucht": "fortscheuchen",
    "fortscheuchte": "fortscheuchen",
    "fortscheuchten": "fortscheuchen",
    "fortscheuchtest": "fortscheuchen",
    "fortscheuchtet": "fortscheuchen",
    "fortschiebe": "fortschieben",
    "fortschiebend": "fortschieben",
    "fortschiebende": "fortschiebend",
    "fortschiebendem": "fortschiebend",
    "fortschiebenden": "fortschiebend",
    "fortschiebender": "fortschiebend",
    "fortschiebendes": "fortschiebend",
    "fortschiebest": "fortschieben",
    "fortschiebet": "fortschieben",
    "fortschiebst": "fortschieben",
    "fortschiebt": "fortschieben",
    "fortschleiche": "fortschleichen",
    "fortschleichend": "fortschleichen",
    "fortschleichende": "fortschleichend",
    "fortschleichendem": "fortschleichend",
    "fortschleichenden": "fortschleichend",
    "fortschleichender": "fortschleichend",
    "fortschleichendes": "fortschleichend",
    "fortschleichest": "fortschleichen",
    "fortschleichet": "fortschleichen",
    "fortschleichst": "fortschleichen",
    "fortschleicht": "fortschleichen",
    "fortschleppe": "fortschleppen",
    "fortschleppend": "fortschleppen",
    "fortschleppende": "fortschleppend",
    "fortschleppendem": "fortschleppend",
    "fortschleppenden": "fortschleppend",
    "fortschleppender": "fortschleppend",
    "fortschleppendes": "fortschleppend",
    "fortschleppest": "fortschleppen",
    "fortschleppet": "fortschleppen",
    "fortschleppst": "fortschleppen",
    "fortschleppt": "fortschleppen",
    "fortschleppte": "fortschleppen",
    "fortschleppten": "fortschleppen",
    "fortschlepptest": "fortschleppen",
    "fortschlepptet": "fortschleppen",
    "fortschleudere": "fortschleudern",
    "fortschleudernd": "fortschleudern",
    "fortschleudernde": "fortschleudernd",
    "fortschleuderndem": "fortschleudernd",
    "fortschleudernden": "fortschleudernd",
    "fortschleudernder": "fortschleudernd",
    "fortschleuderndes": "fortschleudernd",
    "fortschleuderst": "fortschleudern",
    "fortschleudert": "fortschleudern",
    "fortschleuderte": "fortschleudern",
    "fortschleuderten": "fortschleudern",
    "fortschleudertest": "fortschleudern",
    "fortschleudertet": "fortschleudern",
    "fortschlich": "fortschleichen",
    "fortschliche": "fortschleichen",
    "fortschlichen": "fortschleichen",
    "fortschlichest": "fortschleichen",
    "fortschlichet": "fortschleichen",
    "fortschlichst": "fortschleichen",
    "fortschlicht": "fortschleichen",
    "fortschnelle": "fortschnellen",
    "fortschnellend": "fortschnellen",
    "fortschnellende": "fortschnellend",
    "fortschnellendem": "fortschnellend",
    "fortschnellenden": "fortschnellend",
    "fortschnellender": "fortschnellend",
    "fortschnellendes": "fortschnellend",
    "fortschnellest": "fortschnellen",
    "fortschnellet": "fortschnellen",
    "fortschnellst": "fortschnellen",
    "fortschnellt": "fortschnellen",
    "fortschnellte": "fortschnellen",
    "fortschnellten": "fortschnellen",
    "fortschnelltest": "fortschnellen",
    "fortschnelltet": "fortschnellen",
    "fortschob": "fortschieben",
    "fortschoben": "fortschieben",
    "fortschobst": "fortschieben",
    "fortschobt": "fortschieben",
    "fortschor": "fortscheren",
    "fortschoren": "fortscheren",
    "fortschorst": "fortscheren",
    "fortschort": "fortscheren",
    "fortschreibe": "fortschreiben",
    "fortschreibend": "fortschreiben",
    "fortschreibende": "fortschreibend",
    "fortschreibendem": "fortschreibend",
    "fortschreibenden": "fortschreibend",
    "fortschreibender": "fortschreibend",
    "fortschreibendes": "fortschreibend",
    "fortschreibest": "fortschreiben",
    "fortschreibet": "fortschreiben",
    "fortschreibst": "fortschreiben",
    "fortschreibt": "fortschreiben",
    "fortschreitend": "fortschreiten",
    "fortschreitende": "fortschreitend",
    "fortschreitendem": "fortschreitend",
    "fortschreitenden": "fortschreitend",
    "fortschreitender": "fortschreitend",
    "fortschreitendere": "fortschreitend",
    "fortschreitenderem": "fortschreitend",
    "fortschreitenderen": "fortschreitend",
    "fortschreitenderer": "fortschreitend",
    "fortschreitenderes": "fortschreitend",
    "fortschreitendes": "fortschreitend",
    "fortschreitendste": "fortschreitend",
    "fortschreitendstem": "fortschreitend",
    "fortschreitendsten": "fortschreitend",
    "fortschreitendster": "fortschreitend",
    "fortschreitendstes": "fortschreitend",
    "fortschrieb": "fortschreiben",
    "fortschriebe": "fortschreiben",
    "fortschrieben": "fortschreiben",
    "fortschriebest": "fortschreiben",
    "fortschriebet": "fortschreiben",
    "fortschriebst": "fortschreiben",
    "fortschriebt": "fortschreiben",
    "fortschrittlichem": "fortschrittlich",
    "fortschrittlichen": "fortschrittlich",
    "fortschrittlicher": "fortschrittlich",
    "fortschrittlichere": "fortschrittlich",
    "fortschrittlicherem": "fortschrittlich",
    "fortschrittlicheren": "fortschrittlich",
    "fortschrittlicherer": "fortschrittlich",
    "fortschrittlicheres": "fortschrittlich",
    "fortschrittliches": "fortschrittlich",
    "fortschrittlichste": "fortschrittlich",
    "fortschrittlichstem": "fortschrittlich",
    "fortschrittlichsten": "fortschrittlich",
    "fortschrittlichster": "fortschrittlich",
    "fortschrittlichstes": "fortschrittlich",
    "fortschrittsgläubigem": "fortschrittsgläubig",
    "fortschrittsgläubigen": "fortschrittsgläubig",
    "fortschrittsgläubiger": "fortschrittsgläubig",
    "fortschrittsgläubigere": "fortschrittsgläubig",
    "fortschrittsgläubigerem": "fortschrittsgläubig",
    "fortschrittsgläubigeren": "fortschrittsgläubig",
    "fortschrittsgläubigerer": "fortschrittsgläubig",
    "fortschrittsgläubigeres": "fortschrittsgläubig",
    "fortschrittsgläubiges": "fortschrittsgläubig",
    "fortschrittsgläubigste": "fortschrittsgläubig",
    "fortschrittsgläubigstem": "fortschrittsgläubig",
    "fortschrittsgläubigsten": "fortschrittsgläubig",
    "fortschrittsgläubigster": "fortschrittsgläubig",
    "fortschrittsgläubigstes": "fortschrittsgläubig",
    "fortschwamm": "fortschwimmen",
    "fortschwammen": "fortschwimmen",
    "fortschwammst": "fortschwimmen",
    "fortschwammt": "fortschwimmen",
    "fortschwimme": "fortschwimmen",
    "fortschwimmend": "fortschwimmen",
    "fortschwimmende": "fortschwimmend",
    "fortschwimmendem": "fortschwimmend",
    "fortschwimmenden": "fortschwimmend",
    "fortschwimmender": "fortschwimmend",
    "fortschwimmendes": "fortschwimmend",
    "fortschwimmest": "fortschwimmen",
    "fortschwimmet": "fortschwimmen",
    "fortschwimmst": "fortschwimmen",
    "fortschwimmt": "fortschwimmen",
    "fortschwämme": "fortschwimmen",
    "fortschwämmen": "fortschwimmen",
    "fortschwämmest": "fortschwimmen",
    "fortschwämmet": "fortschwimmen",
    "fortschöbe": "fortschieben",
    "fortschöben": "fortschieben",
    "fortschöbest": "fortschieben",
    "fortschöbet": "fortschieben",
    "fortschöre": "fortscheren",
    "fortschören": "fortscheren",
    "fortschörest": "fortscheren",
    "fortschöret": "fortscheren",
    "fortsehne": "fortsehnen",
    "fortsehnend": "fortsehnen",
    "fortsehnende": "fortsehnend",
    "fortsehnendem": "fortsehnend",
    "fortsehnenden": "fortsehnend",
    "fortsehnender": "fortsehnend",
    "fortsehnendere": "fortsehnend",
    "fortsehnenderem": "fortsehnend",
    "fortsehnenderen": "fortsehnend",
    "fortsehnenderer": "fortsehnend",
    "fortsehnenderes": "fortsehnend",
    "fortsehnendes": "fortsehnend",
    "fortsehnendste": "fortsehnend",
    "fortsehnendstem": "fortsehnend",
    "fortsehnendsten": "fortsehnend",
    "fortsehnendster": "fortsehnend",
    "fortsehnendstes": "fortsehnend",
    "fortsehnest": "fortsehnen",
    "fortsehnet": "fortsehnen",
    "fortsehnst": "fortsehnen",
    "fortsehnt": "fortsehnen",
    "fortsehnte": "fortsehnen",
    "fortsehnten": "fortsehnen",
    "fortsehntest": "fortsehnen",
    "fortsehntet": "fortsehnen",
    "fortsetze": "fortsetzen",
    "fortsetzend": "fortsetzen",
    "fortsetzende": "fortsetzend",
    "fortsetzendem": "fortsetzend",
    "fortsetzenden": "fortsetzend",
    "fortsetzender": "fortsetzend",
    "fortsetzendes": "fortsetzend",
    "fortsetzest": "fortsetzen",
    "fortsetzet": "fortsetzen",
    "fortsetzt": "fortsetzen",
    "fortsetzte": "fortsetzen",
    "fortsetzten": "fortsetzen",
    "fortsetztest": "fortsetzen",
    "fortsetztet": "fortsetzen",
    "fortsprang": "fortspringen",
    "fortsprangen": "fortspringen",
    "fortsprangst": "fortspringen",
    "fortsprangt": "fortspringen",
    "fortspringe": "fortspringen",
    "fortspringend": "fortspringen",
    "fortspringende": "fortspringend",
    "fortspringendem": "fortspringend",
    "fortspringenden": "fortspringend",
    "fortspringender": "fortspringend",
    "fortspringendes": "fortspringend",
    "fortspringest": "fortspringen",
    "fortspringet": "fortspringen",
    "fortspringst": "fortspringen",
    "fortspringt": "fortspringen",
    "fortspränge": "fortspringen",
    "fortsprängen": "fortspringen",
    "fortsprängest": "fortspringen",
    "fortspränget": "fortspringen",
    "fortstahl": "fortstehlen",
    "fortstahlen": "fortstehlen",
    "fortstahlst": "fortstehlen",
    "fortstahlt": "fortstehlen",
    "fortstehle": "fortstehlen",
    "fortstehlend": "fortstehlen",
    "fortstehlende": "fortstehlend",
    "fortstehlendem": "fortstehlend",
    "fortstehlenden": "fortstehlend",
    "fortstehlender": "fortstehlend",
    "fortstehlendere": "fortstehlend",
    "fortstehlenderem": "fortstehlend",
    "fortstehlenderen": "fortstehlend",
    "fortstehlenderer": "fortstehlend",
    "fortstehlenderes": "fortstehlend",
    "fortstehlendes": "fortstehlend",
    "fortstehlendste": "fortstehlend",
    "fortstehlendstem": "fortstehlend",
    "fortstehlendsten": "fortstehlend",
    "fortstehlendster": "fortstehlend",
    "fortstehlendstes": "fortstehlend",
    "fortstehlest": "fortstehlen",
    "fortstehlet": "fortstehlen",
    "fortstehlt": "fortstehlen",
    "fortstiehlst": "fortstehlen",
    "fortstiehlt": "fortstehlen",
    "fortstähle": "fortstehlen",
    "fortstählen": "fortstehlen",
    "fortstählest": "fortstehlen",
    "fortstählet": "fortstehlen",
    "fortstürme": "fortstürmen",
    "fortstürmend": "fortstürmen",
    "fortstürmende": "fortstürmend",
    "fortstürmendem": "fortstürmend",
    "fortstürmenden": "fortstürmend",
    "fortstürmender": "fortstürmend",
    "fortstürmendes": "fortstürmend",
    "fortstürmest": "fortstürmen",
    "fortstürmet": "fortstürmen",
    "fortstürmst": "fortstürmen",
    "fortstürmt": "fortstürmen",
    "fortstürmte": "fortstürmen",
    "fortstürmten": "fortstürmen",
    "fortstürmtest": "fortstürmen",
    "fortstürmtet": "fortstürmen",
    "fortstürze": "fortstürzen",
    "fortstürzend": "fortstürzen",
    "fortstürzende": "fortstürzend",
    "fortstürzendem": "fortstürzend",
    "fortstürzenden": "fortstürzend",
    "fortstürzender": "fortstürzend",
    "fortstürzendes": "fortstürzend",
    "fortstürzest": "fortstürzen",
    "fortstürzet": "fortstürzen",
    "fortstürzt": "fortstürzen",
    "fortstürzte": "fortstürzen",
    "fortstürzten": "fortstürzen",
    "fortstürztest": "fortstürzen",
    "fortstürztet": "fortstürzen",
    "forttrage": "forttragen",
    "forttragend": "forttragen",
    "forttragende": "forttragend",
    "forttragendem": "forttragend",
    "forttragenden": "forttragend",
    "forttragender": "forttragend",
    "forttragendes": "forttragend",
    "forttragest": "forttragen",
    "forttraget": "forttragen",
    "forttragt": "forttragen",
    "forttreibe": "forttreiben",
    "forttreibend": "forttreiben",
    "forttreibende": "forttreibend",
    "forttreibendem": "forttreibend",
    "forttreibenden": "forttreibend",
    "forttreibender": "forttreibend",
    "forttreibendes": "forttreibend",
    "forttreibest": "forttreiben",
    "forttreibet": "forttreiben",
    "forttreibst": "forttreiben",
    "forttreibt": "forttreiben",
    "forttrieb": "forttreiben",
    "forttriebe": "forttreiben",
    "forttrieben": "forttreiben",
    "forttriebest": "forttreiben",
    "forttriebet": "forttreiben",
    "forttriebst": "forttreiben",
    "forttriebt": "forttreiben",
    "forttrug": "forttragen",
    "forttrugen": "forttragen",
    "forttrugst": "forttragen",
    "forttrugt": "forttragen",
    "fortträgst": "forttragen",
    "fortträgt": "forttragen",
    "forttrüge": "forttragen",
    "forttrügen": "forttragen",
    "forttrügest": "forttragen",
    "forttrüget": "forttragen",
    "fortwarf": "fortwerfen",
    "fortwarfen": "fortwerfen",
    "fortwarfst": "fortwerfen",
    "fortwarft": "fortwerfen",
    "fortwerfe": "fortwerfen",
    "fortwerfend": "fortwerfen",
    "fortwerfende": "fortwerfend",
    "fortwerfendem": "fortwerfend",
    "fortwerfenden": "fortwerfend",
    "fortwerfender": "fortwerfend",
    "fortwerfendes": "fortwerfend",
    "fortwerfest": "fortwerfen",
    "fortwerfet": "fortwerfen",
    "fortwerft": "fortwerfen",
    "fortwirfst": "fortwerfen",
    "fortwirft": "fortwerfen",
    "fortwirke": "fortwirken",
    "fortwirkend": "fortwirken",
    "fortwirkende": "fortwirkend",
    "fortwirkendem": "fortwirkend",
    "fortwirkenden": "fortwirkend",
    "fortwirkender": "fortwirkend",
    "fortwirkendes": "fortwirkend",
    "fortwirkest": "fortwirken",
    "fortwirket": "fortwirken",
    "fortwirkst": "fortwirken",
    "fortwirkt": "fortwirken",
    "fortwirkte": "fortwirken",
    "fortwirkten": "fortwirken",
    "fortwirktest": "fortwirken",
    "fortwirktet": "fortwirken",
    "fortwische": "fortwischen",
    "fortwischend": "fortwischen",
    "fortwischende": "fortwischend",
    "fortwischendem": "fortwischend",
    "fortwischenden": "fortwischend",
    "fortwischender": "fortwischend",
    "fortwischendes": "fortwischend",
    "fortwischest": "fortwischen",
    "fortwischet": "fortwischen",
    "fortwischst": "fortwischen",
    "fortwischt": "fortwischen",
    "fortwischte": "fortwischen",
    "fortwischten": "fortwischen",
    "fortwischtest": "fortwischen",
    "fortwischtet": "fortwischen",
    "fortwähre": "fortwähren",
    "fortwährend": "fortwähren",
    "fortwährende": "fortwährend",
    "fortwährendem": "fortwährend",
    "fortwährenden": "fortwährend",
    "fortwährender": "fortwährend",
    "fortwährendes": "fortwährend",
    "fortwährest": "fortwähren",
    "fortwähret": "fortwähren",
    "fortwährst": "fortwähren",
    "fortwährt": "fortwähren",
    "fortwährte": "fortwähren",
    "fortwährten": "fortwähren",
    "fortwährtest": "fortwähren",
    "fortwährtet": "fortwähren",
    "fortwälze": "fortwälzen",
    "fortwälzend": "fortwälzen",
    "fortwälzende": "fortwälzend",
    "fortwälzendem": "fortwälzend",
    "fortwälzenden": "fortwälzend",
    "fortwälzender": "fortwälzend",
    "fortwälzendes": "fortwälzend",
    "fortwälzest": "fortwälzen",
    "fortwälzet": "fortwälzen",
    "fortwälzt": "fortwälzen",
    "fortwälzte": "fortwälzen",
    "fortwälzten": "fortwälzen",
    "fortwälztest": "fortwälzen",
    "fortwälztet": "fortwälzen",
    "fortwärfe": "fortwerfen",
    "fortwärfen": "fortwerfen",
    "fortwärfest": "fortwerfen",
    "fortwärfet": "fortwerfen",
    "fortwünsche": "fortwünschen",
    "fortwünschend": "fortwünschen",
    "fortwünschende": "fortwünschend",
    "fortwünschendem": "fortwünschend",
    "fortwünschenden": "fortwünschend",
    "fortwünschender": "fortwünschend",
    "fortwünschendes": "fortwünschend",
    "fortwünschest": "fortwünschen",
    "fortwünschet": "fortwünschen",
    "fortwünschst": "fortwünschen",
    "fortwünscht": "fortwünschen",
    "fortwünschte": "fortwünschen",
    "fortwünschten": "fortwünschen",
    "fortwünschtest": "fortwünschen",
    "fortwünschtet": "fortwünschen",
    "fortzahle": "fortzahlen",
    "fortzahlend": "fortzahlen",
    "fortzahlende": "fortzahlend",
    "fortzahlendem": "fortzahlend",
    "fortzahlenden": "fortzahlend",
    "fortzahlender": "fortzahlend",
    "fortzahlendes": "fortzahlend",
    "fortzahlest": "fortzahlen",
    "fortzahlet": "fortzahlen",
    "fortzahlst": "fortzahlen",
    "fortzahlt": "fortzahlen",
    "fortzahlte": "fortzahlen",
    "fortzahlten": "fortzahlen",
    "fortzahltest": "fortzahlen",
    "fortzahltet": "fortzahlen",
    "fortzerre": "fortzerren",
    "fortzerrend": "fortzerren",
    "fortzerrende": "fortzerrend",
    "fortzerrendem": "fortzerrend",
    "fortzerrenden": "fortzerrend",
    "fortzerrender": "fortzerrend",
    "fortzerrendes": "fortzerrend",
    "fortzerrest": "fortzerren",
    "fortzerret": "fortzerren",
    "fortzerrst": "fortzerren",
    "fortzerrt": "fortzerren",
    "fortzerrte": "fortzerren",
    "fortzerrten": "fortzerren",
    "fortzerrtest": "fortzerren",
    "fortzerrtet": "fortzerren",
    "fortzubegeben": "fortbegeben",
    "fortzubestehen": "fortbestehen",
    "fortzubewegen": "fortbewegen",
    "fortzubilden": "fortbilden",
    "fortzublasen": "fortblasen",
    "fortzubleiben": "fortbleiben",
    "fortzubringen": "fortbringen",
    "fortzudauern": "fortdauern",
    "fortzudenken": "fortdenken",
    "fortzudrängen": "fortdrängen",
    "fortzueilen": "forteilen",
    "fortzufallen": "fortfallen",
    "fortzufliegen": "fortfliegen",
    "fortzuführen": "fortführen",
    "fortzugeben": "fortgeben",
    "fortzugießen": "fortgießen",
    "fortzujagen": "fortjagen",
    "fortzukommen": "fortkommen",
    "fortzukriechen": "fortkriechen",
    "fortzulassen": "fortlassen",
    "fortzuleben": "fortleben",
    "fortzumachen": "fortmachen",
    "fortzumarschieren": "fortmarschieren",
    "fortzunehmen": "fortnehmen",
    "fortzupflanzen": "fortpflanzen",
    "fortzureisen": "fortreisen",
    "fortzureiten": "fortreiten",
    "fortzureißen": "fortreißen",
    "fortzurennen": "fortrennen",
    "fortzuräumen": "forträumen",
    "fortzuscheren": "fortscheren",
    "fortzuscheuchen": "fortscheuchen",
    "fortzuschieben": "fortschieben",
    "fortzuschleichen": "fortschleichen",
    "fortzuschleppen": "fortschleppen",
    "fortzuschleudern": "fortschleudern",
    "fortzuschnellen": "fortschnellen",
    "fortzuschreiben": "fortschreiben",
    "fortzuschwimmen": "fortschwimmen",
    "fortzusehnen": "fortsehnen",
    "fortzusetzen": "fortsetzen",
    "fortzuspringen": "fortspringen",
    "fortzustehlen": "fortstehlen",
    "fortzustürmen": "fortstürmen",
    "fortzustürzen": "fortstürzen",
    "fortzutragen": "forttragen",
    "fortzutreiben": "forttreiben",
    "fortzuwerfen": "fortwerfen",
    "fortzuwirken": "fortwirken",
    "fortzuwischen": "fortwischen",
    "fortzuwähren": "fortwähren",
    "fortzuwälzen": "fortwälzen",
    "fortzuwünschen": "fortwünschen",
    "fortzuzahlen": "fortzahlen",
    "fortzuzerren": "fortzerren",
    "fossilem": "fossil",
    "fossilen": "fossil",
    "fossiler": "fossil",
    "fossiles": "fossil",
    "fotografiere": "fotografieren",
    "fotografierend": "fotografieren",
    "fotografierende": "fotografierend",
    "fotografierendem": "fotografierend",
    "fotografierenden": "fotografierend",
    "fotografierender": "fotografierend",
    "fotografierendes": "fotografierend",
    "fotografierest": "fotografieren",
    "fotografieret": "fotografieren",
    "fotografierst": "fotografieren",
    "fotografiert": "fotografieren",
    "fotografierte": "fotografieren",
    "fotografiertem": "fotografiert",
    "fotografierten": "fotografieren",
    "fotografierter": "fotografiert",
    "fotografiertere": "fotografiert",
    "fotografierterem": "fotografiert",
    "fotografierteren": "fotografiert",
    "fotografierterer": "fotografiert",
    "fotografierteres": "fotografiert",
    "fotografiertes": "fotografiert",
    "fotografiertest": "fotografieren",
    "fotografierteste": "fotografiert",
    "fotografiertestem": "fotografiert",
    "fotografiertesten": "fotografiert",
    "fotografiertester": "fotografiert",
    "fotografiertestes": "fotografiert",
    "fotografiertet": "fotografieren",
    "fotokopiere": "fotokopieren",
    "fotokopierend": "fotokopieren",
    "fotokopierende": "fotokopierend",
    "fotokopierendem": "fotokopierend",
    "fotokopierenden": "fotokopierend",
    "fotokopierender": "fotokopierend",
    "fotokopierendes": "fotokopierend",
    "fotokopierest": "fotokopieren",
    "fotokopieret": "fotokopieren",
    "fotokopierst": "fotokopieren",
    "fotokopiert": "fotokopieren",
    "fotokopierte": "fotokopieren",
    "fotokopiertem": "fotokopiert",
    "fotokopierten": "fotokopieren",
    "fotokopierter": "fotokopiert",
    "fotokopiertes": "fotokopiert",
    "fotokopiertest": "fotokopieren",
    "fotokopiertet": "fotokopieren",
    "foule": "foulen",
    "foulend": "foulen",
    "foulende": "foulend",
    "foulendem": "foulend",
    "foulenden": "foulend",
    "foulender": "foulend",
    "foulendere": "foulend",
    "foulenderem": "foulend",
    "foulenderen": "foulend",
    "foulenderer": "foulend",
    "foulenderes": "foulend",
    "foulendes": "foulend",
    "foulendste": "foulend",
    "foulendstem": "foulend",
    "foulendsten": "foulend",
    "foulendster": "foulend",
    "foulendstes": "foulend",
    "foulest": "foulen",
    "foulet": "foulen",
    "foulst": "foulen",
    "foult": "foulen",
    "foulte": "foulen",
    "foulten": "foulen",
    "foultest": "foulen",
    "foultet": "foulen",
    "frachte": "frachten",
    "frachtend": "frachten",
    "frachtende": "frachtend",
    "frachtendem": "frachtend",
    "frachtenden": "frachtend",
    "frachtender": "frachtend",
    "frachtendere": "frachtend",
    "frachtenderem": "frachtend",
    "frachtenderen": "frachtend",
    "frachtenderer": "frachtend",
    "frachtenderes": "frachtend",
    "frachtendes": "frachtend",
    "frachtendste": "frachtend",
    "frachtendstem": "frachtend",
    "frachtendsten": "frachtend",
    "frachtendster": "frachtend",
    "frachtendstes": "frachtend",
    "frachtest": "frachten",
    "frachtet": "frachten",
    "frachtete": "frachten",
    "frachteten": "frachten",
    "frachtetest": "frachten",
    "frachtetet": "frachten",
    "frachtfreie": "frachtfrei",
    "frachtfreiem": "frachtfrei",
    "frachtfreien": "frachtfrei",
    "frachtfreier": "frachtfrei",
    "frachtfreies": "frachtfrei",
    "frage": "fragen",
    "fragend": "fragen",
    "fragende": "fragend",
    "fragendem": "fragend",
    "fragenden": "fragend",
    "fragender": "fragend",
    "fragendere": "fragend",
    "fragenderem": "fragend",
    "fragenderen": "fragend",
    "fragenderer": "fragend",
    "fragenderes": "fragend",
    "fragendes": "fragend",
    "fragendste": "fragend",
    "fragendstem": "fragend",
    "fragendsten": "fragend",
    "fragendster": "fragend",
    "fragendstes": "fragend",
    "fragest": "fragen",
    "fraget": "fragen",
    "fragile": "fragil",
    "fragilem": "fragil",
    "fragilen": "fragil",
    "fragiler": "fragil",
    "fragilere": "fragil",
    "fragilerem": "fragil",
    "fragileren": "fragil",
    "fragilerer": "fragil",
    "fragileres": "fragil",
    "fragiles": "fragil",
    "fragilste": "fragil",
    "fragilstem": "fragil",
    "fragilsten": "fragil",
    "fragilster": "fragil",
    "fragilstes": "fragil",
    "fragliche": "fraglich",
    "fraglichem": "fraglich",
    "fraglichen": "fraglich",
    "fraglicher": "fraglich",
    "fraglichere": "fraglich",
    "fraglicherem": "fraglich",
    "fraglicheren": "fraglich",
    "fraglicherer": "fraglich",
    "fraglicheres": "fraglich",
    "fragliches": "fraglich",
    "fraglichste": "fraglich",
    "fraglichstem": "fraglich",
    "fraglichsten": "fraglich",
    "fraglichster": "fraglich",
    "fraglichstes": "fraglich",
    "fraglose": "fraglos",
    "fraglosem": "fraglos",
    "fraglosen": "fraglos",
    "fragloser": "fraglos",
    "fraglosere": "fraglos",
    "fragloserem": "fraglos",
    "fragloseren": "fraglos",
    "fragloserer": "fraglos",
    "fragloseres": "fraglos",
    "fragloses": "fraglos",
    "fragloseste": "fraglos",
    "fraglosestem": "fraglos",
    "fraglosesten": "fraglos",
    "fraglosester": "fraglos",
    "fraglosestes": "fraglos",
    "fragmentarische": "fragmentarisch",
    "fragmentarischem": "fragmentarisch",
    "fragmentarischen": "fragmentarisch",
    "fragmentarischer": "fragmentarisch",
    "fragmentarisches": "fragmentarisch",
    "fragst": "fragen",
    "fragt": "fragen",
    "fragte": "fragen",
    "fragten": "fragen",
    "fragtest": "fragen",
    "fragtet": "fragen",
    "fragwürdige": "fragwürdig",
    "fragwürdigem": "fragwürdig",
    "fragwürdigen": "fragwürdig",
    "fragwürdiger": "fragwürdig",
    "fragwürdigere": "fragwürdig",
    "fragwürdigerem": "fragwürdig",
    "fragwürdigeren": "fragwürdig",
    "fragwürdigerer": "fragwürdig",
    "fragwürdigeres": "fragwürdig",
    "fragwürdiges": "fragwürdig",
    "fragwürdigste": "fragwürdig",
    "fragwürdigstem": "fragwürdig",
    "fragwürdigsten": "fragwürdig",
    "fragwürdigster": "fragwürdig",
    "fragwürdigstes": "fragwürdig",
    "fraktale": "fraktal",
    "fraktalem": "fraktal",
    "fraktalen": "fraktal",
    "fraktaler": "fraktal",
    "fraktales": "fraktal",
    "fraktioniere": "fraktionieren",
    "fraktionierend": "fraktionieren",
    "fraktionierende": "fraktionierend",
    "fraktionierendem": "fraktionierend",
    "fraktionierenden": "fraktionierend",
    "fraktionierender": "fraktionierend",
    "fraktionierendes": "fraktionierend",
    "fraktionierest": "fraktionieren",
    "fraktionieret": "fraktionieren",
    "fraktionierst": "fraktionieren",
    "fraktioniert": "fraktionieren",
    "fraktionierte": "fraktionieren",
    "fraktioniertem": "fraktioniert",
    "fraktionierten": "fraktionieren",
    "fraktionierter": "fraktioniert",
    "fraktioniertes": "fraktioniert",
    "fraktioniertest": "fraktionieren",
    "fraktioniertet": "fraktionieren",
    "frankiere": "frankieren",
    "frankierend": "frankieren",
    "frankierende": "frankierend",
    "frankierendem": "frankierend",
    "frankierenden": "frankierend",
    "frankierender": "frankierend",
    "frankierendes": "frankierend",
    "frankierest": "frankieren",
    "frankieret": "frankieren",
    "frankierst": "frankieren",
    "frankiert": "frankieren",
    "frankierte": "frankieren",
    "frankiertem": "frankiert",
    "frankierten": "frankieren",
    "frankierter": "frankiert",
    "frankiertes": "frankiert",
    "frankiertest": "frankieren",
    "frankiertet": "frankieren",
    "fransend": "fransen",
    "fransende": "fransend",
    "fransendem": "fransend",
    "fransenden": "fransend",
    "fransender": "fransend",
    "fransendere": "fransend",
    "fransenderem": "fransend",
    "fransenderen": "fransend",
    "fransenderer": "fransend",
    "fransenderes": "fransend",
    "fransendes": "fransend",
    "fransendste": "fransend",
    "fransendstem": "fransend",
    "fransendsten": "fransend",
    "fransendster": "fransend",
    "fransendstes": "fransend",
    "fransest": "fransen",
    "franset": "fransen",
    "fransige": "fransig",
    "fransigem": "fransig",
    "fransigen": "fransig",
    "fransiger": "fransig",
    "fransigere": "fransig",
    "fransigerem": "fransig",
    "fransigeren": "fransig",
    "fransigerer": "fransig",
    "fransigeres": "fransig",
    "fransiges": "fransig",
    "fransigste": "fransig",
    "fransigstem": "fransig",
    "fransigsten": "fransig",
    "fransigster": "fransig",
    "fransigstes": "fransig",
    "franst": "fransen",
    "franste": "fransen",
    "fransten": "fransen",
    "franstest": "fransen",
    "franstet": "fransen",
    "franze": "franzen",
    "franzend": "franzen",
    "franzende": "franzend",
    "franzendem": "franzend",
    "franzenden": "franzend",
    "franzender": "franzend",
    "franzendere": "franzend",
    "franzenderem": "franzend",
    "franzenderen": "franzend",
    "franzenderer": "franzend",
    "franzenderes": "franzend",
    "franzendes": "franzend",
    "franzendste": "franzend",
    "franzendstem": "franzend",
    "franzendsten": "franzend",
    "franzendster": "franzend",
    "franzendstes": "franzend",
    "franzest": "franzen",
    "franzet": "franzen",
    "franzt": "franzen",
    "franzte": "franzen",
    "franzten": "franzen",
    "franztest": "franzen",
    "franztet": "franzen",
    "französischem": "französisch",
    "französischen": "französisch",
    "französischer": "französisch",
    "französisches": "französisch",
    "frappiere": "frappieren",
    "frappierend": "frappieren",
    "frappierende": "frappierend",
    "frappierendem": "frappierend",
    "frappierenden": "frappierend",
    "frappierender": "frappierend",
    "frappierendere": "frappierend",
    "frappierenderem": "frappierend",
    "frappierenderen": "frappierend",
    "frappierenderer": "frappierend",
    "frappierenderes": "frappierend",
    "frappierendes": "frappierend",
    "frappierendste": "frappierend",
    "frappierendstem": "frappierend",
    "frappierendsten": "frappierend",
    "frappierendster": "frappierend",
    "frappierendstes": "frappierend",
    "frappierest": "frappieren",
    "frappieret": "frappieren",
    "frappierst": "frappieren",
    "frappiert": "frappieren",
    "frappierte": "frappieren",
    "frappiertem": "frappiert",
    "frappierten": "frappieren",
    "frappierter": "frappiert",
    "frappiertere": "frappiert",
    "frappierterem": "frappiert",
    "frappierteren": "frappiert",
    "frappierterer": "frappiert",
    "frappierteres": "frappiert",
    "frappiertes": "frappiert",
    "frappiertest": "frappieren",
    "frappierteste": "frappiert",
    "frappiertestem": "frappiert",
    "frappiertesten": "frappiert",
    "frappiertester": "frappiert",
    "frappiertestes": "frappiert",
    "frappiertet": "frappieren",
    "fraternisiere": "fraternisieren",
    "fraternisierend": "fraternisieren",
    "fraternisierende": "fraternisierend",
    "fraternisierendem": "fraternisierend",
    "fraternisierenden": "fraternisierend",
    "fraternisierender": "fraternisierend",
    "fraternisierendere": "fraternisierend",
    "fraternisierenderem": "fraternisierend",
    "fraternisierenderen": "fraternisierend",
    "fraternisierenderer": "fraternisierend",
    "fraternisierenderes": "fraternisierend",
    "fraternisierendes": "fraternisierend",
    "fraternisierendste": "fraternisierend",
    "fraternisierendstem": "fraternisierend",
    "fraternisierendsten": "fraternisierend",
    "fraternisierendster": "fraternisierend",
    "fraternisierendstes": "fraternisierend",
    "fraternisierest": "fraternisieren",
    "fraternisieret": "fraternisieren",
    "fraternisierst": "fraternisieren",
    "fraternisiert": "fraternisieren",
    "fraternisierte": "fraternisieren",
    "fraternisiertem": "fraternisiert",
    "fraternisierten": "fraternisieren",
    "fraternisierter": "fraternisiert",
    "fraternisiertere": "fraternisiert",
    "fraternisierterem": "fraternisiert",
    "fraternisierteren": "fraternisiert",
    "fraternisierterer": "fraternisiert",
    "fraternisierteres": "fraternisiert",
    "fraternisiertes": "fraternisiert",
    "fraternisiertest": "fraternisieren",
    "fraternisiertestem": "fraternisiert",
    "fraternisiertesten": "fraternisiert",
    "fraternisiertester": "fraternisiert",
    "fraternisiertestes": "fraternisiert",
    "fraternisiertet": "fraternisieren",
    "fratzenhaftem": "fratzenhaft",
    "fratzenhaften": "fratzenhaft",
    "fratzenhafter": "fratzenhaft",
    "fratzenhaftere": "fratzenhaft",
    "fratzenhafterem": "fratzenhaft",
    "fratzenhafteren": "fratzenhaft",
    "fratzenhafterer": "fratzenhaft",
    "fratzenhafteres": "fratzenhaft",
    "fratzenhaftes": "fratzenhaft",
    "fratzenhafteste": "fratzenhaft",
    "fratzenhaftestem": "fratzenhaft",
    "fratzenhaftesten": "fratzenhaft",
    "fratzenhaftester": "fratzenhaft",
    "fratzenhaftestes": "fratzenhaft",
    "frauenhaftem": "frauenhaft",
    "frauenhaften": "frauenhaft",
    "frauenhafter": "frauenhaft",
    "frauenhaftere": "frauenhaft",
    "frauenhafterem": "frauenhaft",
    "frauenhafteren": "frauenhaft",
    "frauenhafterer": "frauenhaft",
    "frauenhafteres": "frauenhaft",
    "frauenhaftes": "frauenhaft",
    "frauenhafteste": "frauenhaft",
    "frauenhaftestem": "frauenhaft",
    "frauenhaftesten": "frauenhaft",
    "frauenhaftester": "frauenhaft",
    "frauenhaftestes": "frauenhaft",
    "frauenpolitische": "frauenpolitisch",
    "frauenpolitischem": "frauenpolitisch",
    "frauenpolitischen": "frauenpolitisch",
    "frauenpolitischer": "frauenpolitisch",
    "frauenpolitischere": "frauenpolitisch",
    "frauenpolitischerem": "frauenpolitisch",
    "frauenpolitischeren": "frauenpolitisch",
    "frauenpolitischerer": "frauenpolitisch",
    "frauenpolitischeres": "frauenpolitisch",
    "frauenpolitisches": "frauenpolitisch",
    "frauenpolitischste": "frauenpolitisch",
    "frauenpolitischstem": "frauenpolitisch",
    "frauenpolitischsten": "frauenpolitisch",
    "frauenpolitischster": "frauenpolitisch",
    "frauenpolitischstes": "frauenpolitisch",
    "fraulichem": "fraulich",
    "fraulichen": "fraulich",
    "fraulicher": "fraulich",
    "fraulichere": "fraulich",
    "fraulicherem": "fraulich",
    "fraulicheren": "fraulich",
    "fraulicherer": "fraulich",
    "fraulicheres": "fraulich",
    "frauliches": "fraulich",
    "fraulichste": "fraulich",
    "fraulichstem": "fraulich",
    "fraulichsten": "fraulich",
    "fraulichster": "fraulich",
    "fraulichstes": "fraulich",
    "fraß": "fressen",
    "fraßen": "fressen",
    "fraßt": "fressen",
    "freche": "frech",
    "frechem": "frech",
    "frechen": "frech",
    "frecher": "frech",
    "frechere": "frech",
    "frecherem": "frech",
    "frecheren": "frech",
    "frecherer": "frech",
    "frecheres": "frech",
    "freches": "frech",
    "frechstem": "frech",
    "frechsten": "frech",
    "frechster": "frech",
    "frechstes": "frech",
    "freiberuflichem": "freiberuflich",
    "freiberuflichen": "freiberuflich",
    "freiberuflicher": "freiberuflich",
    "freiberufliches": "freiberuflich",
    "freibeweglichem": "freibeweglich",
    "freibeweglichen": "freibeweglich",
    "freibeweglicher": "freibeweglich",
    "freibewegliches": "freibeweglich",
    "freibleibende": "freibleibend",
    "freibleibendem": "freibleibend",
    "freibleibenden": "freibleibend",
    "freibleibender": "freibleibend",
    "freibleibendes": "freibleibend",
    "freiem": "frei",
    "freien": "frei",
    "freiere": "frei",
    "freierem": "frei",
    "freieren": "frei",
    "freierer": "frei",
    "freieres": "frei",
    "freies": "frei",
    "freieste": "frei",
    "freiestem": "frei",
    "freiesten": "frei",
    "freiester": "frei",
    "freiestes": "frei",
    "freigab": "freigeben",
    "freigabst": "freigeben",
    "freigabt": "freigeben",
    "freigebe": "freigeben",
    "freigebend": "freigeben",
    "freigebende": "freigebend",
    "freigebendem": "freigebend",
    "freigebenden": "freigebend",
    "freigebender": "freigebend",
    "freigebendes": "freigebend",
    "freigebest": "freigeben",
    "freigebet": "freigeben",
    "freigebt": "freigeben",
    "freigegeben": "freigeben",
    "freigegebene": "freigegeben",
    "freigegebenem": "freigegeben",
    "freigegebenen": "freigegeben",
    "freigegebener": "freigegeben",
    "freigegebenes": "freigegeben",
    "freigehalten": "freihalten",
    "freigehaltene": "freigehalten",
    "freigehaltenem": "freigehalten",
    "freigehaltenen": "freigehalten",
    "freigehaltener": "freigehalten",
    "freigehaltenes": "freigehalten",
    "freigekauft": "freikaufen",
    "freigekaufte": "freigekauft",
    "freigekauftem": "freigekauft",
    "freigekauften": "freigekauft",
    "freigekaufter": "freigekauft",
    "freigekauftes": "freigekauft",
    "freigelassen": "freilassen",
    "freigelassene": "freigelassen",
    "freigelassenem": "freigelassen",
    "freigelassenen": "freigelassen",
    "freigelassener": "freigelassen",
    "freigelassenes": "freigelassen",
    "freigelegt": "freilegen",
    "freigelegte": "freigelegt",
    "freigelegtem": "freigelegt",
    "freigelegten": "freigelegt",
    "freigelegter": "freigelegt",
    "freigelegtere": "freigelegt",
    "freigelegterem": "freigelegt",
    "freigelegteren": "freigelegt",
    "freigelegterer": "freigelegt",
    "freigelegteres": "freigelegt",
    "freigelegtes": "freigelegt",
    "freigelegteste": "freigelegt",
    "freigelegtestem": "freigelegt",
    "freigelegtesten": "freigelegt",
    "freigelegtester": "freigelegt",
    "freigelegtestes": "freigelegt",
    "freigemacht": "freimachen",
    "freigemachte": "freigemacht",
    "freigemachtem": "freigemacht",
    "freigemachten": "freigemacht",
    "freigemachter": "freigemacht",
    "freigemachtere": "freigemacht",
    "freigemachterem": "freigemacht",
    "freigemachteren": "freigemacht",
    "freigemachterer": "freigemacht",
    "freigemachteres": "freigemacht",
    "freigemachtes": "freigemacht",
    "freigemachteste": "freigemacht",
    "freigemachtestem": "freigemacht",
    "freigemachtesten": "freigemacht",
    "freigemachtester": "freigemacht",
    "freigemachtestes": "freigemacht",
    "freigepreßt": "freipressen",
    "freigepreßte": "freigepreßt",
    "freigepreßtem": "freigepreßt",
    "freigepreßten": "freigepreßt",
    "freigepreßter": "freigepreßt",
    "freigepreßtes": "freigepreßt",
    "freigeschwommen": "freischwimmen",
    "freigeschwommene": "freigeschwommen",
    "freigeschwommenem": "freigeschwommen",
    "freigeschwommenen": "freigeschwommen",
    "freigeschwommener": "freigeschwommen",
    "freigeschwommenere": "freigeschwommen",
    "freigeschwommenerem": "freigeschwommen",
    "freigeschwommeneren": "freigeschwommen",
    "freigeschwommenerer": "freigeschwommen",
    "freigeschwommeneres": "freigeschwommen",
    "freigeschwommenes": "freigeschwommen",
    "freigeschwommenste": "freigeschwommen",
    "freigeschwommenstem": "freigeschwommen",
    "freigeschwommensten": "freigeschwommen",
    "freigeschwommenster": "freigeschwommen",
    "freigeschwommenstes": "freigeschwommen",
    "freigesetzt": "freisetzen",
    "freigesetzte": "freigesetzt",
    "freigesetztem": "freigesetzt",
    "freigesetzten": "freigesetzt",
    "freigesetzter": "freigesetzt",
    "freigesetztes": "freigesetzt",
    "freigespielt": "freispielen",
    "freigespielte": "freigespielt",
    "freigespieltem": "freigespielt",
    "freigespielten": "freigespielt",
    "freigespielter": "freigespielt",
    "freigespieltere": "freigespielt",
    "freigespielterem": "freigespielt",
    "freigespielteren": "freigespielt",
    "freigespielterer": "freigespielt",
    "freigespielteres": "freigespielt",
    "freigespieltes": "freigespielt",
    "freigespielteste": "freigespielt",
    "freigespieltestem": "freigespielt",
    "freigespieltesten": "freigespielt",
    "freigespieltester": "freigespielt",
    "freigespieltestes": "freigespielt",
    "freigesprochen": "freisprechen",
    "freigesprochene": "freigesprochen",
    "freigesprochenem": "freigesprochen",
    "freigesprochenen": "freigesprochen",
    "freigesprochener": "freigesprochen",
    "freigesprochenes": "freigesprochen",
    "freigestanden": "freistehen",
    "freigestandene": "freigestanden",
    "freigestandenem": "freigestanden",
    "freigestandenen": "freigestanden",
    "freigestandener": "freigestanden",
    "freigestandenes": "freigestanden",
    "freigestellt": "freistellen",
    "freigestellte": "freigestellt",
    "freigestelltem": "freigestellt",
    "freigestellten": "freigestellt",
    "freigestellter": "freigestellt",
    "freigestelltes": "freigestellt",
    "freigestempelt": "freistempeln",
    "freigestempelte": "freigestempelt",
    "freigestempeltem": "freigestempelt",
    "freigestempelten": "freigestempelt",
    "freigestempelter": "freigestempelt",
    "freigestempeltes": "freigestempelt",
    "freigibst": "freigeben",
    "freigibt": "freigeben",
    "freigiebige": "freigiebig",
    "freigiebigem": "freigiebig",
    "freigiebigen": "freigiebig",
    "freigiebiger": "freigiebig",
    "freigiebigere": "freigiebig",
    "freigiebigerem": "freigiebig",
    "freigiebigeren": "freigiebig",
    "freigiebigerer": "freigiebig",
    "freigiebigeres": "freigiebig",
    "freigiebiges": "freigiebig",
    "freigiebigste": "freigiebig",
    "freigiebigstem": "freigiebig",
    "freigiebigsten": "freigiebig",
    "freigiebigster": "freigiebig",
    "freigiebigstes": "freigiebig",
    "freigäbe": "freigeben",
    "freigäben": "freigeben",
    "freigäbest": "freigeben",
    "freigäbet": "freigeben",
    "freihalte": "freihalten",
    "freihaltend": "freihalten",
    "freihaltende": "freihaltend",
    "freihaltendem": "freihaltend",
    "freihaltenden": "freihaltend",
    "freihaltender": "freihaltend",
    "freihaltendes": "freihaltend",
    "freihaltest": "freihalten",
    "freihaltet": "freihalten",
    "freiheitlichem": "freiheitlich",
    "freiheitlichen": "freiheitlich",
    "freiheitlicher": "freiheitlich",
    "freiheitlichere": "freiheitlich",
    "freiheitlicherem": "freiheitlich",
    "freiheitlicheren": "freiheitlich",
    "freiheitlicherer": "freiheitlich",
    "freiheitlicheres": "freiheitlich",
    "freiheitliches": "freiheitlich",
    "freiheitlichste": "freiheitlich",
    "freiheitlichstem": "freiheitlich",
    "freiheitlichsten": "freiheitlich",
    "freiheitlichster": "freiheitlich",
    "freiheitlichstes": "freiheitlich",
    "freiheitsliebende": "freiheitsliebend",
    "freiheitsliebendem": "freiheitsliebend",
    "freiheitsliebenden": "freiheitsliebend",
    "freiheitsliebender": "freiheitsliebend",
    "freiheitsliebendere": "freiheitsliebend",
    "freiheitsliebenderem": "freiheitsliebend",
    "freiheitsliebenderen": "freiheitsliebend",
    "freiheitsliebenderer": "freiheitsliebend",
    "freiheitsliebenderes": "freiheitsliebend",
    "freiheitsliebendes": "freiheitsliebend",
    "freiheitsliebendste": "freiheitsliebend",
    "freiheitsliebendstem": "freiheitsliebend",
    "freiheitsliebendsten": "freiheitsliebend",
    "freiheitsliebendster": "freiheitsliebend",
    "freiheitsliebendstes": "freiheitsliebend",
    "freihielt": "freihalten",
    "freihielte": "freihalten",
    "freihielten": "freihalten",
    "freihieltest": "freihalten",
    "freihieltet": "freihalten",
    "freihält": "freihalten",
    "freihältst": "freihalten",
    "freihändige": "freihändig",
    "freihändigem": "freihändig",
    "freihändigen": "freihändig",
    "freihändiger": "freihändig",
    "freihändiges": "freihändig",
    "freikaufe": "freikaufen",
    "freikaufend": "freikaufen",
    "freikaufende": "freikaufend",
    "freikaufendem": "freikaufend",
    "freikaufenden": "freikaufend",
    "freikaufender": "freikaufend",
    "freikaufendes": "freikaufend",
    "freikaufest": "freikaufen",
    "freikaufet": "freikaufen",
    "freikaufst": "freikaufen",
    "freikauft": "freikaufen",
    "freikaufte": "freikaufen",
    "freikauften": "freikaufen",
    "freikauftest": "freikaufen",
    "freikauftet": "freikaufen",
    "freilasse": "freilassen",
    "freilassend": "freilassen",
    "freilassende": "freilassend",
    "freilassendem": "freilassend",
    "freilassenden": "freilassend",
    "freilassender": "freilassend",
    "freilassendes": "freilassend",
    "freilassest": "freilassen",
    "freilasset": "freilassen",
    "freilaßt": "freilassen",
    "freilebendem": "freilebend",
    "freilebenden": "freilebend",
    "freilebender": "freilebend",
    "freilebendes": "freilebend",
    "freilege": "freilegen",
    "freilegend": "freilegen",
    "freilegende": "freilegend",
    "freilegendem": "freilegend",
    "freilegenden": "freilegend",
    "freilegender": "freilegend",
    "freilegendere": "freilegend",
    "freilegenderem": "freilegend",
    "freilegenderen": "freilegend",
    "freilegenderer": "freilegend",
    "freilegenderes": "freilegend",
    "freilegendes": "freilegend",
    "freilegendste": "freilegend",
    "freilegendstem": "freilegend",
    "freilegendsten": "freilegend",
    "freilegendster": "freilegend",
    "freilegendstes": "freilegend",
    "freilegest": "freilegen",
    "freileget": "freilegen",
    "freilegst": "freilegen",
    "freilegt": "freilegen",
    "freilegte": "freilegen",
    "freilegten": "freilegen",
    "freilegtest": "freilegen",
    "freilegtet": "freilegen",
    "freiließ": "freilassen",
    "freiließe": "freilassen",
    "freiließen": "freilassen",
    "freiließest": "freilassen",
    "freiließet": "freilassen",
    "freiließt": "freilassen",
    "freiläßt": "freilassen",
    "freimache": "freimachen",
    "freimachend": "freimachen",
    "freimachende": "freimachend",
    "freimachendem": "freimachend",
    "freimachenden": "freimachend",
    "freimachender": "freimachend",
    "freimachendere": "freimachend",
    "freimachenderem": "freimachend",
    "freimachenderen": "freimachend",
    "freimachenderer": "freimachend",
    "freimachenderes": "freimachend",
    "freimachendes": "freimachend",
    "freimachendste": "freimachend",
    "freimachendstem": "freimachend",
    "freimachendsten": "freimachend",
    "freimachendster": "freimachend",
    "freimachendstes": "freimachend",
    "freimachest": "freimachen",
    "freimachet": "freimachen",
    "freimachst": "freimachen",
    "freimacht": "freimachen",
    "freimachte": "freimachen",
    "freimachten": "freimachen",
    "freimachtest": "freimachen",
    "freimachtet": "freimachen",
    "freimütigem": "freimütig",
    "freimütigen": "freimütig",
    "freimütiger": "freimütig",
    "freimütigere": "freimütig",
    "freimütigerem": "freimütig",
    "freimütigeren": "freimütig",
    "freimütigerer": "freimütig",
    "freimütigeres": "freimütig",
    "freimütiges": "freimütig",
    "freimütigste": "freimütig",
    "freimütigstem": "freimütig",
    "freimütigsten": "freimütig",
    "freimütigster": "freimütig",
    "freimütigstes": "freimütig",
    "freipresse": "freipressen",
    "freipressend": "freipressen",
    "freipressende": "freipressend",
    "freipressendem": "freipressend",
    "freipressenden": "freipressend",
    "freipressender": "freipressend",
    "freipressendes": "freipressend",
    "freipressest": "freipressen",
    "freipresset": "freipressen",
    "freipreßt": "freipressen",
    "freipreßte": "freipressen",
    "freipreßten": "freipressen",
    "freipreßtest": "freipressen",
    "freipreßtet": "freipressen",
    "freischaffendem": "freischaffend",
    "freischaffenden": "freischaffend",
    "freischaffender": "freischaffend",
    "freischaffendes": "freischaffend",
    "freischwamm": "freischwimmen",
    "freischwammen": "freischwimmen",
    "freischwammst": "freischwimmen",
    "freischwammt": "freischwimmen",
    "freischwimme": "freischwimmen",
    "freischwimmend": "freischwimmen",
    "freischwimmende": "freischwimmend",
    "freischwimmendem": "freischwimmend",
    "freischwimmenden": "freischwimmend",
    "freischwimmender": "freischwimmend",
    "freischwimmendere": "freischwimmend",
    "freischwimmenderem": "freischwimmend",
    "freischwimmenderen": "freischwimmend",
    "freischwimmenderer": "freischwimmend",
    "freischwimmenderes": "freischwimmend",
    "freischwimmendes": "freischwimmend",
    "freischwimmendste": "freischwimmend",
    "freischwimmendstem": "freischwimmend",
    "freischwimmendsten": "freischwimmend",
    "freischwimmendster": "freischwimmend",
    "freischwimmendstes": "freischwimmend",
    "freischwimmest": "freischwimmen",
    "freischwimmet": "freischwimmen",
    "freischwimmst": "freischwimmen",
    "freischwimmt": "freischwimmen",
    "freischwämme": "freischwimmen",
    "freischwämmen": "freischwimmen",
    "freischwämmest": "freischwimmen",
    "freischwämmet": "freischwimmen",
    "freisetze": "freisetzen",
    "freisetzend": "freisetzen",
    "freisetzende": "freisetzend",
    "freisetzendem": "freisetzend",
    "freisetzenden": "freisetzend",
    "freisetzender": "freisetzend",
    "freisetzendes": "freisetzend",
    "freisetzest": "freisetzen",
    "freisetzet": "freisetzen",
    "freisetzt": "freisetzen",
    "freisetzte": "freisetzen",
    "freisetzten": "freisetzen",
    "freisetztest": "freisetzen",
    "freisetztet": "freisetzen",
    "freispiele": "freispielen",
    "freispielend": "freispielen",
    "freispielende": "freispielend",
    "freispielendem": "freispielend",
    "freispielenden": "freispielend",
    "freispielender": "freispielend",
    "freispielendere": "freispielend",
    "freispielenderem": "freispielend",
    "freispielenderen": "freispielend",
    "freispielenderer": "freispielend",
    "freispielenderes": "freispielend",
    "freispielendes": "freispielend",
    "freispielendste": "freispielend",
    "freispielendstem": "freispielend",
    "freispielendsten": "freispielend",
    "freispielendster": "freispielend",
    "freispielendstes": "freispielend",
    "freispielest": "freispielen",
    "freispielet": "freispielen",
    "freispielst": "freispielen",
    "freispielt": "freispielen",
    "freispielte": "freispielen",
    "freispielten": "freispielen",
    "freispieltest": "freispielen",
    "freispieltet": "freispielen",
    "freisprach": "freisprechen",
    "freisprachen": "freisprechen",
    "freisprachst": "freisprechen",
    "freispracht": "freisprechen",
    "freispreche": "freisprechen",
    "freisprechend": "freisprechen",
    "freisprechende": "freisprechend",
    "freisprechendem": "freisprechend",
    "freisprechenden": "freisprechend",
    "freisprechender": "freisprechend",
    "freisprechendes": "freisprechend",
    "freisprechest": "freisprechen",
    "freisprechet": "freisprechen",
    "freisprecht": "freisprechen",
    "freisprichst": "freisprechen",
    "freispricht": "freisprechen",
    "freispräche": "freisprechen",
    "freisprächen": "freisprechen",
    "freisprächest": "freisprechen",
    "freisprächet": "freisprechen",
    "freistand": "freistehen",
    "freistanden": "freistehen",
    "freistandest": "freistehen",
    "freistandet": "freistehen",
    "freistehe": "freistehen",
    "freistehend": "freistehen",
    "freistehende": "freistehend",
    "freistehendem": "freistehend",
    "freistehenden": "freistehend",
    "freistehender": "freistehend",
    "freistehendere": "freistehend",
    "freistehenderem": "freistehend",
    "freistehenderen": "freistehend",
    "freistehenderer": "freistehend",
    "freistehenderes": "freistehend",
    "freistehendes": "freistehend",
    "freistehendste": "freistehend",
    "freistehendstem": "freistehend",
    "freistehendsten": "freistehend",
    "freistehendster": "freistehend",
    "freistehendstes": "freistehend",
    "freistehest": "freistehen",
    "freistehet": "freistehen",
    "freistehst": "freistehen",
    "freisteht": "freistehen",
    "freistelle": "freistellen",
    "freistellend": "freistellen",
    "freistellende": "freistellend",
    "freistellendem": "freistellend",
    "freistellenden": "freistellend",
    "freistellender": "freistellend",
    "freistellendes": "freistellend",
    "freistellest": "freistellen",
    "freistellet": "freistellen",
    "freistellst": "freistellen",
    "freistellt": "freistellen",
    "freistellte": "freistellen",
    "freistellten": "freistellen",
    "freistelltest": "freistellen",
    "freistelltet": "freistellen",
    "freistempele": "freistempeln",
    "freistempelnd": "freistempeln",
    "freistempelnde": "freistempelnd",
    "freistempelndem": "freistempelnd",
    "freistempelnden": "freistempelnd",
    "freistempelnder": "freistempelnd",
    "freistempelndes": "freistempelnd",
    "freistempelst": "freistempeln",
    "freistempelt": "freistempeln",
    "freistempelte": "freistempeln",
    "freistempelten": "freistempeln",
    "freistempeltest": "freistempeln",
    "freistempeltet": "freistempeln",
    "freistemple": "freistempeln",
    "freistünde": "freistehen",
    "freistünden": "freistehen",
    "freistündest": "freistehen",
    "freistündet": "freistehen",
    "freitragendem": "freitragend",
    "freitragenden": "freitragend",
    "freitragender": "freitragend",
    "freitragendere": "freitragend",
    "freitragenderem": "freitragend",
    "freitragenderen": "freitragend",
    "freitragenderer": "freitragend",
    "freitragenderes": "freitragend",
    "freitragendes": "freitragend",
    "freitragendste": "freitragend",
    "freitragendstem": "freitragend",
    "freitragendsten": "freitragend",
    "freitragendster": "freitragend",
    "freitragendstes": "freitragend",
    "freiwilligem": "freiwillig",
    "freiwilligen": "freiwillig",
    "freiwilliger": "freiwillig",
    "freiwilligere": "freiwillig",
    "freiwilligerem": "freiwillig",
    "freiwilligeren": "freiwillig",
    "freiwilligerer": "freiwillig",
    "freiwilligeres": "freiwillig",
    "freiwilliges": "freiwillig",
    "freiwilligste": "freiwillig",
    "freiwilligstem": "freiwillig",
    "freiwilligsten": "freiwillig",
    "freiwilligster": "freiwillig",
    "freiwilligstes": "freiwillig",
    "freizugeben": "freigeben",
    "freizuhalten": "freihalten",
    "freizukaufen": "freikaufen",
    "freizulassen": "freilassen",
    "freizulegen": "freilegen",
    "freizumachen": "freimachen",
    "freizupressen": "freipressen",
    "freizuschwimmen": "freischwimmen",
    "freizusetzen": "freisetzen",
    "freizuspielen": "freispielen",
    "freizusprechen": "freisprechen",
    "freizustehen": "freistehen",
    "freizustellen": "freistellen",
    "freizustempeln": "freistempeln",
    "freizügige": "freizügig",
    "freizügigem": "freizügig",
    "freizügigen": "freizügig",
    "freizügiger": "freizügig",
    "freizügigere": "freizügig",
    "freizügigerem": "freizügig",
    "freizügigeren": "freizügig",
    "freizügigerer": "freizügig",
    "freizügigeres": "freizügig",
    "freizügiges": "freizügig",
    "freizügigste": "freizügig",
    "freizügigstem": "freizügig",
    "freizügigsten": "freizügig",
    "freizügigster": "freizügig",
    "freizügigstes": "freizügig",
    "fremdartigem": "fremdartig",
    "fremdartigen": "fremdartig",
    "fremdartiger": "fremdartig",
    "fremdartiges": "fremdartig",
    "fremde": "fremd",
    "fremdele": "fremdeln",
    "fremdelnd": "fremdeln",
    "fremdelnde": "fremdelnd",
    "fremdelndem": "fremdelnd",
    "fremdelnden": "fremdelnd",
    "fremdelnder": "fremdelnd",
    "fremdelndere": "fremdelnd",
    "fremdelnderem": "fremdelnd",
    "fremdelnderen": "fremdelnd",
    "fremdelnderer": "fremdelnd",
    "fremdelnderes": "fremdelnd",
    "fremdelndes": "fremdelnd",
    "fremdelndste": "fremdelnd",
    "fremdelndstem": "fremdelnd",
    "fremdelndsten": "fremdelnd",
    "fremdelndster": "fremdelnd",
    "fremdelndstes": "fremdelnd",
    "fremdelst": "fremdeln",
    "fremdelt": "fremdeln",
    "fremdelte": "fremdeln",
    "fremdelten": "fremdeln",
    "fremdeltest": "fremdeln",
    "fremdeltet": "fremdeln",
    "fremdem": "fremd",
    "fremden": "fremd",
    "fremder": "fremd",
    "fremdes": "fremd",
    "fremdgegangen": "fremdgehen",
    "fremdgegangene": "fremdgegangen",
    "fremdgegangenem": "fremdgegangen",
    "fremdgegangenen": "fremdgegangen",
    "fremdgegangener": "fremdgegangen",
    "fremdgegangenes": "fremdgegangen",
    "fremdgehe": "fremdgehen",
    "fremdgehend": "fremdgehen",
    "fremdgehende": "fremdgehend",
    "fremdgehendem": "fremdgehend",
    "fremdgehenden": "fremdgehend",
    "fremdgehender": "fremdgehend",
    "fremdgehendes": "fremdgehend",
    "fremdgehest": "fremdgehen",
    "fremdgehet": "fremdgehen",
    "fremdgehst": "fremdgehen",
    "fremdgeht": "fremdgehen",
    "fremdging": "fremdgehen",
    "fremdginge": "fremdgehen",
    "fremdgingen": "fremdgehen",
    "fremdgingest": "fremdgehen",
    "fremdginget": "fremdgehen",
    "fremdgingst": "fremdgehen",
    "fremdgingt": "fremdgehen",
    "fremdle": "fremdeln",
    "fremdländischem": "fremdländisch",
    "fremdländischen": "fremdländisch",
    "fremdländischer": "fremdländisch",
    "fremdländisches": "fremdländisch",
    "fremdsprachige": "fremdsprachig",
    "fremdsprachigem": "fremdsprachig",
    "fremdsprachigen": "fremdsprachig",
    "fremdsprachiger": "fremdsprachig",
    "fremdsprachiges": "fremdsprachig",
    "fremdsprachliche": "fremdsprachlich",
    "fremdsprachlichem": "fremdsprachlich",
    "fremdsprachlichen": "fremdsprachlich",
    "fremdsprachlicher": "fremdsprachlich",
    "fremdsprachliches": "fremdsprachlich",
    "fremdstämmige": "fremdstämmig",
    "fremdstämmigem": "fremdstämmig",
    "fremdstämmigen": "fremdstämmig",
    "fremdstämmiger": "fremdstämmig",
    "fremdstämmiges": "fremdstämmig",
    "fremdwortfreiem": "fremdwortfrei",
    "fremdwortfreien": "fremdwortfrei",
    "fremdwortfreier": "fremdwortfrei",
    "fremdwortfreies": "fremdwortfrei",
    "fremdzugehen": "fremdgehen",
    "frenetische": "frenetisch",
    "frenetischem": "frenetisch",
    "frenetischen": "frenetisch",
    "frenetischer": "frenetisch",
    "frenetischere": "frenetisch",
    "frenetischerem": "frenetisch",
    "frenetischeren": "frenetisch",
    "frenetischerer": "frenetisch",
    "frenetischeres": "frenetisch",
    "frenetisches": "frenetisch",
    "frenetischste": "frenetisch",
    "frenetischstem": "frenetisch",
    "frenetischsten": "frenetisch",
    "frenetischster": "frenetisch",
    "frenetischstes": "frenetisch",
    "frequentem": "frequent",
    "frequenten": "frequent",
    "frequenter": "frequent",
    "frequentes": "frequent",
    "frequentiere": "frequentieren",
    "frequentierend": "frequentieren",
    "frequentierende": "frequentierend",
    "frequentierendem": "frequentierend",
    "frequentierenden": "frequentierend",
    "frequentierender": "frequentierend",
    "frequentierendere": "frequentierend",
    "frequentierenderem": "frequentierend",
    "frequentierenderen": "frequentierend",
    "frequentierenderer": "frequentierend",
    "frequentierenderes": "frequentierend",
    "frequentierendes": "frequentierend",
    "frequentierendste": "frequentierend",
    "frequentierendstem": "frequentierend",
    "frequentierendsten": "frequentierend",
    "frequentierendster": "frequentierend",
    "frequentierendstes": "frequentierend",
    "frequentierest": "frequentieren",
    "frequentieret": "frequentieren",
    "frequentierst": "frequentieren",
    "frequentiert": "frequentieren",
    "frequentierte": "frequentieren",
    "frequentiertem": "frequentiert",
    "frequentierten": "frequentieren",
    "frequentierter": "frequentiert",
    "frequentiertere": "frequentiert",
    "frequentierterem": "frequentiert",
    "frequentierteren": "frequentiert",
    "frequentierterer": "frequentiert",
    "frequentierteres": "frequentiert",
    "frequentiertes": "frequentiert",
    "frequentiertest": "frequentieren",
    "frequentierteste": "frequentiert",
    "frequentiertestem": "frequentiert",
    "frequentiertesten": "frequentiert",
    "frequentiertester": "frequentiert",
    "frequentiertestes": "frequentiert",
    "frequentiertet": "frequentieren",
    "fressend": "fressen",
    "fressende": "fressend",
    "fressendem": "fressend",
    "fressenden": "fressend",
    "fressender": "fressend",
    "fressendes": "fressend",
    "fressest": "fressen",
    "fresset": "fressen",
    "freudestrahlendem": "freudestrahlend",
    "freudestrahlenden": "freudestrahlend",
    "freudestrahlender": "freudestrahlend",
    "freudestrahlendere": "freudestrahlend",
    "freudestrahlenderem": "freudestrahlend",
    "freudestrahlenderen": "freudestrahlend",
    "freudestrahlenderer": "freudestrahlend",
    "freudestrahlenderes": "freudestrahlend",
    "freudestrahlendes": "freudestrahlend",
    "freudestrahlendste": "freudestrahlend",
    "freudestrahlendstem": "freudestrahlend",
    "freudestrahlendsten": "freudestrahlend",
    "freudestrahlendster": "freudestrahlend",
    "freudestrahlendstes": "freudestrahlend",
    "freudige": "freudig",
    "freudigem": "freudig",
    "freudigen": "freudig",
    "freudiger": "freudig",
    "freudigere": "freudig",
    "freudigerem": "freudig",
    "freudigeren": "freudig",
    "freudigerer": "freudig",
    "freudigeres": "freudig",
    "freudiges": "freudig",
    "freudigste": "freudig",
    "freudigstem": "freudig",
    "freudigsten": "freudig",
    "freudigster": "freudig",
    "freudigstes": "freudig",
    "freudvollem": "freudvoll",
    "freudvollen": "freudvoll",
    "freudvoller": "freudvoll",
    "freudvollere": "freudvoll",
    "freudvollerem": "freudvoll",
    "freudvolleren": "freudvoll",
    "freudvollerer": "freudvoll",
    "freudvolleres": "freudvoll",
    "freudvolles": "freudvoll",
    "freudvollste": "freudvoll",
    "freudvollstem": "freudvoll",
    "freudvollsten": "freudvoll",
    "freudvollster": "freudvoll",
    "freudvollstes": "freudvoll",
    "freue": "freuen",
    "freuend": "freuen",
    "freuende": "freuend",
    "freuendem": "freuend",
    "freuenden": "freuend",
    "freuender": "freuend",
    "freuendere": "freuend",
    "freuenderem": "freuend",
    "freuenderen": "freuend",
    "freuenderer": "freuend",
    "freuenderes": "freuend",
    "freuendes": "freuend",
    "freuendste": "freuend",
    "freuendstem": "freuend",
    "freuendsten": "freuend",
    "freuendster": "freuend",
    "freuendstes": "freuend",
    "freuest": "freuen",
    "freuet": "freuen",
    "freundend": "freunden",
    "freundende": "freundend",
    "freundendem": "freundend",
    "freundenden": "freundend",
    "freundender": "freundend",
    "freundendes": "freundend",
    "freundest": "freunden",
    "freundet": "freunden",
    "freundete": "freunden",
    "freundeten": "freunden",
    "freundetest": "freunden",
    "freundetet": "freunden",
    "freundlichem": "freundlich",
    "freundlichen": "freundlich",
    "freundlicher": "freundlich",
    "freundlichere": "freundlich",
    "freundlicherem": "freundlich",
    "freundlicheren": "freundlich",
    "freundlicherer": "freundlich",
    "freundlicheres": "freundlich",
    "freundliches": "freundlich",
    "freundlichste": "freundlich",
    "freundlichstem": "freundlich",
    "freundlichsten": "freundlich",
    "freundlichster": "freundlich",
    "freundlichstes": "freundlich",
    "freundschaftlichem": "freundschaftlich",
    "freundschaftlichen": "freundschaftlich",
    "freundschaftlicher": "freundschaftlich",
    "freundschaftlichere": "freundschaftlich",
    "freundschaftlicherem": "freundschaftlich",
    "freundschaftlicheren": "freundschaftlich",
    "freundschaftlicherer": "freundschaftlich",
    "freundschaftlicheres": "freundschaftlich",
    "freundschaftliches": "freundschaftlich",
    "freundschaftlichste": "freundschaftlich",
    "freundschaftlichstem": "freundschaftlich",
    "freundschaftlichsten": "freundschaftlich",
    "freundschaftlichster": "freundschaftlich",
    "freundschaftlichstes": "freundschaftlich",
    "freust": "freuen",
    "freut": "freuen",
    "freute": "freuen",
    "freuten": "freuen",
    "freutest": "freuen",
    "freutet": "freuen",
    "frevele": "freveln",
    "frevelhafte": "frevelhaft",
    "frevelhaftem": "frevelhaft",
    "frevelhaften": "frevelhaft",
    "frevelhafter": "frevelhaft",
    "frevelhaftere": "frevelhaft",
    "frevelhafterem": "frevelhaft",
    "frevelhafteren": "frevelhaft",
    "frevelhafterer": "frevelhaft",
    "frevelhafteres": "frevelhaft",
    "frevelhaftes": "frevelhaft",
    "frevelhafteste": "frevelhaft",
    "frevelhaftestem": "frevelhaft",
    "frevelhaftesten": "frevelhaft",
    "frevelhaftester": "frevelhaft",
    "frevelhaftestes": "frevelhaft",
    "frevelnd": "freveln",
    "frevelnde": "frevelnd",
    "frevelndem": "frevelnd",
    "frevelnden": "frevelnd",
    "frevelnder": "frevelnd",
    "frevelndere": "frevelnd",
    "frevelnderem": "frevelnd",
    "frevelnderen": "frevelnd",
    "frevelnderer": "frevelnd",
    "frevelnderes": "frevelnd",
    "frevelndes": "frevelnd",
    "frevelndste": "frevelnd",
    "frevelndstem": "frevelnd",
    "frevelndsten": "frevelnd",
    "frevelndster": "frevelnd",
    "frevelndstes": "frevelnd",
    "frevelst": "freveln",
    "frevelt": "freveln",
    "frevelte": "freveln",
    "frevelten": "freveln",
    "freveltest": "freveln",
    "freveltet": "freveln",
    "frevle": "freveln",
    "frevlerische": "frevlerisch",
    "frevlerischem": "frevlerisch",
    "frevlerischen": "frevlerisch",
    "frevlerischer": "frevlerisch",
    "frevlerischere": "frevlerisch",
    "frevlerischerem": "frevlerisch",
    "frevlerischeren": "frevlerisch",
    "frevlerischerer": "frevlerisch",
    "frevlerischeres": "frevlerisch",
    "frevlerisches": "frevlerisch",
    "frevlerischste": "frevlerisch",
    "frevlerischstem": "frevlerisch",
    "frevlerischsten": "frevlerisch",
    "frevlerischster": "frevlerisch",
    "frevlerischstes": "frevlerisch",
    "freßsüchtigem": "freßsüchtig",
    "freßsüchtigen": "freßsüchtig",
    "freßsüchtiger": "freßsüchtig",
    "freßsüchtigere": "freßsüchtig",
    "freßsüchtigerem": "freßsüchtig",
    "freßsüchtigeren": "freßsüchtig",
    "freßsüchtigerer": "freßsüchtig",
    "freßsüchtigeres": "freßsüchtig",
    "freßsüchtiges": "freßsüchtig",
    "freßsüchtigste": "freßsüchtig",
    "freßsüchtigstem": "freßsüchtig",
    "freßsüchtigsten": "freßsüchtig",
    "freßsüchtigster": "freßsüchtig",
    "freßsüchtigstes": "freßsüchtig",
    "freßt": "fressen",
    "friedfertigem": "friedfertig",
    "friedfertigen": "friedfertig",
    "friedfertiger": "friedfertig",
    "friedfertigere": "friedfertig",
    "friedfertigerem": "friedfertig",
    "friedfertigeren": "friedfertig",
    "friedfertigerer": "friedfertig",
    "friedfertigeres": "friedfertig",
    "friedfertiges": "friedfertig",
    "friedfertigste": "friedfertig",
    "friedfertigstem": "friedfertig",
    "friedfertigsten": "friedfertig",
    "friedfertigster": "friedfertig",
    "friedfertigstes": "friedfertig",
    "friedlichem": "friedlich",
    "friedlichen": "friedlich",
    "friedlicher": "friedlich",
    "friedlichere": "friedlich",
    "friedlicherem": "friedlich",
    "friedlicheren": "friedlich",
    "friedlicherer": "friedlich",
    "friedlicheres": "friedlich",
    "friedliches": "friedlich",
    "friedlichste": "friedlich",
    "friedlichstem": "friedlich",
    "friedlichsten": "friedlich",
    "friedlichster": "friedlich",
    "friedlichstes": "friedlich",
    "friedliebende": "friedliebend",
    "friedliebendem": "friedliebend",
    "friedliebenden": "friedliebend",
    "friedliebender": "friedliebend",
    "friedliebendere": "friedliebend",
    "friedliebenderem": "friedliebend",
    "friedliebenderen": "friedliebend",
    "friedliebenderer": "friedliebend",
    "friedliebenderes": "friedliebend",
    "friedliebendes": "friedliebend",
    "friedliebendste": "friedliebend",
    "friedliebendstem": "friedliebend",
    "friedliebendsten": "friedliebend",
    "friedliebendster": "friedliebend",
    "friedliebendstes": "friedliebend",
    "friedsamem": "friedsam",
    "friedsamen": "friedsam",
    "friedsamer": "friedsam",
    "friedsamere": "friedsam",
    "friedsamerem": "friedsam",
    "friedsameren": "friedsam",
    "friedsamerer": "friedsam",
    "friedsameres": "friedsam",
    "friedsames": "friedsam",
    "friedsamste": "friedsam",
    "friedsamstem": "friedsam",
    "friedsamsten": "friedsam",
    "friedsamster": "friedsam",
    "friedsamstes": "friedsam",
    "friere": "frieren",
    "frierend": "frieren",
    "frierende": "frierend",
    "frierendem": "frierend",
    "frierenden": "frierend",
    "frierender": "frierend",
    "frierendes": "frierend",
    "frierest": "frieren",
    "frieret": "frieren",
    "frierst": "frieren",
    "friert": "frieren",
    "friesländischem": "friesländisch",
    "friesländischen": "friesländisch",
    "friesländischer": "friesländisch",
    "friesländisches": "friesländisch",
    "frigide": "frigid",
    "frigidem": "frigid",
    "frigiden": "frigid",
    "frigider": "frigid",
    "frigidere": "frigid",
    "frigiderem": "frigid",
    "frigideren": "frigid",
    "frigiderer": "frigid",
    "frigideres": "frigid",
    "frigides": "frigid",
    "frigideste": "frigid",
    "frigidestem": "frigid",
    "frigidesten": "frigid",
    "frigidester": "frigid",
    "frigidestes": "frigid",
    "frisch": "frischen",
    "frische": "frisch",
    "frischem": "frisch",
    "frischen": "frisch",
    "frischend": "frischen",
    "frischende": "frischend",
    "frischendem": "frischend",
    "frischenden": "frischend",
    "frischender": "frischend",
    "frischendes": "frischend",
    "frischer": "frisch",
    "frischere": "frisch",
    "frischerem": "frisch",
    "frischeren": "frisch",
    "frischerer": "frisch",
    "frischeres": "frisch",
    "frisches": "frisch",
    "frischest": "frischen",
    "frischet": "frischen",
    "frischst": "frischen",
    "frischste": "frisch",
    "frischstem": "frisch",
    "frischsten": "frisch",
    "frischster": "frisch",
    "frischstes": "frisch",
    "frischt": "frischen",
    "frischte": "frischen",
    "frischten": "frischen",
    "frischtest": "frischen",
    "frischtet": "frischen",
    "frisiere": "frisieren",
    "frisierend": "frisieren",
    "frisierende": "frisierend",
    "frisierendem": "frisierend",
    "frisierenden": "frisierend",
    "frisierender": "frisierend",
    "frisierendes": "frisierend",
    "frisierest": "frisieren",
    "frisieret": "frisieren",
    "frisierst": "frisieren",
    "frisiert": "frisieren",
    "frisierte": "frisieren",
    "frisiertem": "frisiert",
    "frisierten": "frisieren",
    "frisierter": "frisiert",
    "frisiertere": "frisiert",
    "frisierterem": "frisiert",
    "frisierteren": "frisiert",
    "frisierterer": "frisiert",
    "frisierteres": "frisiert",
    "frisiertes": "frisiert",
    "frisiertest": "frisieren",
    "frisierteste": "frisiert",
    "frisiertestem": "frisiert",
    "frisiertesten": "frisiert",
    "frisiertester": "frisiert",
    "frisiertestes": "frisiert",
    "frisiertet": "frisieren",
    "friste": "fristen",
    "fristend": "fristen",
    "fristende": "fristend",
    "fristendem": "fristend",
    "fristenden": "fristend",
    "fristender": "fristend",
    "fristendes": "fristend",
    "fristest": "fristen",
    "fristet": "fristen",
    "fristete": "fristen",
    "fristeten": "fristen",
    "fristetest": "fristen",
    "fristetet": "fristen",
    "fristgerechte": "fristgerecht",
    "fristgerechtem": "fristgerecht",
    "fristgerechten": "fristgerecht",
    "fristgerechter": "fristgerecht",
    "fristgerechtes": "fristgerecht",
    "fristlose": "fristlos",
    "fristlosem": "fristlos",
    "fristlosen": "fristlos",
    "fristloser": "fristlos",
    "fristloses": "fristlos",
    "fritiere": "fritieren",
    "fritierend": "fritieren",
    "fritierende": "fritierend",
    "fritierendem": "fritierend",
    "fritierenden": "fritierend",
    "fritierender": "fritierend",
    "fritierendere": "fritierend",
    "fritierenderem": "fritierend",
    "fritierenderen": "fritierend",
    "fritierenderer": "fritierend",
    "fritierenderes": "fritierend",
    "fritierendes": "fritierend",
    "fritierendste": "fritierend",
    "fritierendstem": "fritierend",
    "fritierendsten": "fritierend",
    "fritierendster": "fritierend",
    "fritierendstes": "fritierend",
    "fritierest": "fritieren",
    "fritieret": "fritieren",
    "fritierst": "fritieren",
    "fritiert": "fritieren",
    "fritierte": "fritieren",
    "fritiertem": "fritiert",
    "fritierten": "fritieren",
    "fritierter": "fritiert",
    "fritiertere": "fritiert",
    "fritierterem": "fritiert",
    "fritierteren": "fritiert",
    "fritierterer": "fritiert",
    "fritierteres": "fritiert",
    "fritiertes": "fritiert",
    "fritiertest": "fritieren",
    "fritierteste": "fritiert",
    "fritiertestem": "fritiert",
    "fritiertesten": "fritiert",
    "fritiertester": "fritiert",
    "fritiertestes": "fritiert",
    "fritiertet": "fritieren",
    "frittiere": "frittieren",
    "frittierend": "frittieren",
    "frittierende": "frittierend",
    "frittierendem": "frittierend",
    "frittierenden": "frittierend",
    "frittierender": "frittierend",
    "frittierendere": "frittierend",
    "frittierenderem": "frittierend",
    "frittierenderen": "frittierend",
    "frittierenderer": "frittierend",
    "frittierenderes": "frittierend",
    "frittierendes": "frittierend",
    "frittierendste": "frittierend",
    "frittierendstem": "frittierend",
    "frittierendsten": "frittierend",
    "frittierendster": "frittierend",
    "frittierendstes": "frittierend",
    "frittierest": "frittieren",
    "frittieret": "frittieren",
    "frittierst": "frittieren",
    "frittiert": "frittieren",
    "frittierte": "frittieren",
    "frittiertem": "frittiert",
    "frittierten": "frittieren",
    "frittierter": "frittiert",
    "frittiertere": "frittiert",
    "frittierterem": "frittiert",
    "frittierteren": "frittiert",
    "frittierterer": "frittiert",
    "frittierteres": "frittiert",
    "frittiertes": "frittiert",
    "frittiertest": "frittieren",
    "frittierteste": "frittiert",
    "frittiertestem": "frittiert",
    "frittiertesten": "frittiert",
    "frittiertester": "frittiert",
    "frittiertestes": "frittiert",
    "frittiertet": "frittieren",
    "friß": "fressen",
    "frißt": "fressen",
    "frohem": "froh",
    "frohen": "froh",
    "froher": "froh",
    "frohere": "froh",
    "froherem": "froh",
    "froheren": "froh",
    "froherer": "froh",
    "froheres": "froh",
    "frohes": "froh",
    "froheste": "froh",
    "frohestem": "froh",
    "frohesten": "froh",
    "frohester": "froh",
    "frohestes": "froh",
    "frohmütige": "frohmütig",
    "frohmütigem": "frohmütig",
    "frohmütigen": "frohmütig",
    "frohmütiger": "frohmütig",
    "frohmütigere": "frohmütig",
    "frohmütigerem": "frohmütig",
    "frohmütigeren": "frohmütig",
    "frohmütigerer": "frohmütig",
    "frohmütigeres": "frohmütig",
    "frohmütiges": "frohmütig",
    "frohmütigste": "frohmütig",
    "frohmütigstem": "frohmütig",
    "frohmütigsten": "frohmütig",
    "frohmütigster": "frohmütig",
    "frohmütigstes": "frohmütig",
    "frommem": "fromm",
    "frommen": "fromm",
    "frommer": "fromm",
    "frommere": "fromm",
    "frommerem": "fromm",
    "frommeren": "fromm",
    "frommerer": "fromm",
    "frommeres": "fromm",
    "frommes": "fromm",
    "frommste": "fromm",
    "frommstem": "fromm",
    "frommsten": "fromm",
    "frommster": "fromm",
    "frommstes": "fromm",
    "frontalem": "frontal",
    "frontalen": "frontal",
    "frontaler": "frontal",
    "frontalere": "frontal",
    "frontalerem": "frontal",
    "frontaleren": "frontal",
    "frontalerer": "frontal",
    "frontaleres": "frontal",
    "frontales": "frontal",
    "frontalste": "frontal",
    "frontalstem": "frontal",
    "frontalsten": "frontal",
    "frontalster": "frontal",
    "frontalstes": "frontal",
    "fror": "frieren",
    "froren": "frieren",
    "frorst": "frieren",
    "frort": "frieren",
    "frostbeständigem": "frostbeständig",
    "frostbeständigen": "frostbeständig",
    "frostbeständiger": "frostbeständig",
    "frostbeständigere": "frostbeständig",
    "frostbeständigerem": "frostbeständig",
    "frostbeständigeren": "frostbeständig",
    "frostbeständigerer": "frostbeständig",
    "frostbeständigeres": "frostbeständig",
    "frostbeständiges": "frostbeständig",
    "frostbeständigste": "frostbeständig",
    "frostbeständigstem": "frostbeständig",
    "frostbeständigsten": "frostbeständig",
    "frostbeständigster": "frostbeständig",
    "frostbeständigstes": "frostbeständig",
    "frostigem": "frostig",
    "frostigen": "frostig",
    "frostiger": "frostig",
    "frostigere": "frostig",
    "frostigerem": "frostig",
    "frostigeren": "frostig",
    "frostigerer": "frostig",
    "frostigeres": "frostig",
    "frostiges": "frostig",
    "frostigste": "frostig",
    "frostigstem": "frostig",
    "frostigsten": "frostig",
    "frostigster": "frostig",
    "frostigstes": "frostig",
    "frotzele": "frotzeln",
    "frotzelnd": "frotzeln",
    "frotzelnde": "frotzelnd",
    "frotzelndem": "frotzelnd",
    "frotzelnden": "frotzelnd",
    "frotzelnder": "frotzelnd",
    "frotzelndere": "frotzelnd",
    "frotzelnderem": "frotzelnd",
    "frotzelnderen": "frotzelnd",
    "frotzelnderer": "frotzelnd",
    "frotzelnderes": "frotzelnd",
    "frotzelndes": "frotzelnd",
    "frotzelndste": "frotzelnd",
    "frotzelndstem": "frotzelnd",
    "frotzelndsten": "frotzelnd",
    "frotzelndster": "frotzelnd",
    "frotzelndstes": "frotzelnd",
    "frotzelst": "frotzeln",
    "frotzelt": "frotzeln",
    "frotzelte": "frotzeln",
    "frotzelten": "frotzeln",
    "frotzeltest": "frotzeln",
    "frotzeltet": "frotzeln",
    "frotzle": "frotzeln",
    "fruchtbare": "fruchtbar",
    "fruchtbarem": "fruchtbar",
    "fruchtbaren": "fruchtbar",
    "fruchtbarer": "fruchtbar",
    "fruchtbarere": "fruchtbar",
    "fruchtbarerem": "fruchtbar",
    "fruchtbareren": "fruchtbar",
    "fruchtbarerer": "fruchtbar",
    "fruchtbareres": "fruchtbar",
    "fruchtbares": "fruchtbar",
    "fruchtbarste": "fruchtbar",
    "fruchtbarstem": "fruchtbar",
    "fruchtbarsten": "fruchtbar",
    "fruchtbarster": "fruchtbar",
    "fruchtbarstes": "fruchtbar",
    "fruchte": "fruchten",
    "fruchtend": "fruchten",
    "fruchtende": "fruchtend",
    "fruchtendem": "fruchtend",
    "fruchtenden": "fruchtend",
    "fruchtender": "fruchtend",
    "fruchtendere": "fruchtend",
    "fruchtenderem": "fruchtend",
    "fruchtenderen": "fruchtend",
    "fruchtenderer": "fruchtend",
    "fruchtenderes": "fruchtend",
    "fruchtendes": "fruchtend",
    "fruchtendste": "fruchtend",
    "fruchtendstem": "fruchtend",
    "fruchtendsten": "fruchtend",
    "fruchtendster": "fruchtend",
    "fruchtendstes": "fruchtend",
    "fruchtest": "fruchten",
    "fruchtet": "fruchten",
    "fruchtete": "fruchten",
    "fruchteten": "fruchten",
    "fruchtetest": "fruchten",
    "fruchtetet": "fruchten",
    "fruchtige": "fruchtig",
    "fruchtigem": "fruchtig",
    "fruchtigen": "fruchtig",
    "fruchtiger": "fruchtig",
    "fruchtigere": "fruchtig",
    "fruchtigerem": "fruchtig",
    "fruchtigeren": "fruchtig",
    "fruchtigerer": "fruchtig",
    "fruchtigeres": "fruchtig",
    "fruchtiges": "fruchtig",
    "fruchtigste": "fruchtig",
    "fruchtigstem": "fruchtig",
    "fruchtigsten": "fruchtig",
    "fruchtigster": "fruchtig",
    "fruchtigstes": "fruchtig",
    "fruchtlose": "fruchtlos",
    "fruchtlosem": "fruchtlos",
    "fruchtlosen": "fruchtlos",
    "fruchtloser": "fruchtlos",
    "fruchtlosere": "fruchtlos",
    "fruchtloserem": "fruchtlos",
    "fruchtloseren": "fruchtlos",
    "fruchtloserer": "fruchtlos",
    "fruchtloseres": "fruchtlos",
    "fruchtloses": "fruchtlos",
    "fruchtloseste": "fruchtlos",
    "fruchtlosestem": "fruchtlos",
    "fruchtlosesten": "fruchtlos",
    "fruchtlosester": "fruchtlos",
    "fruchtlosestes": "fruchtlos",
    "frustend": "frusten",
    "frustende": "frustend",
    "frustendem": "frustend",
    "frustenden": "frustend",
    "frustender": "frustend",
    "frustendere": "frustend",
    "frustenderem": "frustend",
    "frustenderen": "frustend",
    "frustenderer": "frustend",
    "frustenderes": "frustend",
    "frustendes": "frustend",
    "frustendste": "frustend",
    "frustendstem": "frustend",
    "frustendsten": "frustend",
    "frustendster": "frustend",
    "frustendstes": "frustend",
    "frustest": "frusten",
    "frustet": "frusten",
    "frustete": "frusten",
    "frusteten": "frusten",
    "frustetest": "frusten",
    "frustetet": "frusten",
    "fränkischem": "fränkisch",
    "fränkischen": "fränkisch",
    "fränkischer": "fränkisch",
    "fränkisches": "fränkisch",
    "fräse": "fräsen",
    "fräsend": "fräsen",
    "fräsende": "fräsend",
    "fräsendem": "fräsend",
    "fräsenden": "fräsend",
    "fräsender": "fräsend",
    "fräsendes": "fräsend",
    "fräsest": "fräsen",
    "fräset": "fräsen",
    "fräst": "fräsen",
    "fräste": "fräsen",
    "frästen": "fräsen",
    "frästest": "fräsen",
    "frästet": "fräsen",
    "fräße": "fressen",
    "fräßen": "fressen",
    "fräßest": "fressen",
    "fräßet": "fressen",
    "fröhliche": "fröhlich",
    "fröhlichem": "fröhlich",
    "fröhlichen": "fröhlich",
    "fröhlicher": "fröhlich",
    "fröhlichere": "fröhlich",
    "fröhlicherem": "fröhlich",
    "fröhlicheren": "fröhlich",
    "fröhlicherer": "fröhlich",
    "fröhlicheres": "fröhlich",
    "fröhliches": "fröhlich",
    "fröhlichste": "fröhlich",
    "fröhlichstem": "fröhlich",
    "fröhlichsten": "fröhlich",
    "fröhlichster": "fröhlich",
    "fröhlichstes": "fröhlich",
    "fröre": "frieren",
    "frören": "frieren",
    "frörest": "frieren",
    "fröret": "frieren",
    "fröstele": "frösteln",
    "fröstelige": "fröstelig",
    "frösteligem": "fröstelig",
    "frösteligen": "fröstelig",
    "frösteliger": "fröstelig",
    "frösteligere": "fröstelig",
    "frösteligerem": "fröstelig",
    "frösteligeren": "fröstelig",
    "frösteligerer": "fröstelig",
    "frösteligeres": "fröstelig",
    "frösteliges": "fröstelig",
    "frösteligste": "fröstelig",
    "frösteligstem": "fröstelig",
    "frösteligsten": "fröstelig",
    "frösteligster": "fröstelig",
    "frösteligstes": "fröstelig",
    "fröstelnd": "frösteln",
    "fröstelnde": "fröstelnd",
    "fröstelndem": "fröstelnd",
    "fröstelnden": "fröstelnd",
    "fröstelnder": "fröstelnd",
    "fröstelndere": "fröstelnd",
    "fröstelnderem": "fröstelnd",
    "fröstelnderen": "fröstelnd",
    "fröstelnderer": "fröstelnd",
    "fröstelnderes": "fröstelnd",
    "fröstelndes": "fröstelnd",
    "fröstelndste": "fröstelnd",
    "fröstelndstem": "fröstelnd",
    "fröstelndsten": "fröstelnd",
    "fröstelndster": "fröstelnd",
    "fröstelndstes": "fröstelnd",
    "fröstelst": "frösteln",
    "fröstelt": "frösteln",
    "fröstelte": "frösteln",
    "fröstelten": "frösteln",
    "frösteltest": "frösteln",
    "frösteltet": "frösteln",
    "fröstle": "frösteln",
    "fröstlige": "fröstlig",
    "fröstligem": "fröstlig",
    "fröstligen": "fröstlig",
    "fröstliger": "fröstlig",
    "fröstligere": "fröstlig",
    "fröstligerem": "fröstlig",
    "fröstligeren": "fröstlig",
    "fröstligerer": "fröstlig",
    "fröstligeres": "fröstlig",
    "fröstliges": "fröstlig",
    "fröstligste": "fröstlig",
    "fröstligstem": "fröstlig",
    "fröstligsten": "fröstlig",
    "fröstligster": "fröstlig",
    "fröstligstes": "fröstlig",
    "frühem": "früh",
    "frühen": "früh",
    "früher": "früh",
    "frühere": "früh",
    "früherem": "früh",
    "früheren": "früh",
    "früherer": "früh",
    "früheres": "früh",
    "frühes": "früh",
    "früheste": "früh",
    "frühestem": "früh",
    "frühesten": "früh",
    "frühester": "früh",
    "frühestes": "früh",
    "frühkindlichem": "frühkindlich",
    "frühkindlichen": "frühkindlich",
    "frühkindlicher": "frühkindlich",
    "frühkindliches": "frühkindlich",
    "frühreifem": "frühreif",
    "frühreifen": "frühreif",
    "frühreifer": "frühreif",
    "frühreifere": "frühreif",
    "frühreiferem": "frühreif",
    "frühreiferen": "frühreif",
    "frühreiferer": "frühreif",
    "frühreiferes": "frühreif",
    "frühreifes": "frühreif",
    "frühreifste": "frühreif",
    "frühreifstem": "frühreif",
    "frühreifsten": "frühreif",
    "frühreifster": "frühreif",
    "frühreifstes": "frühreif",
    "frühsozialistischem": "frühsozialistisch",
    "frühsozialistischen": "frühsozialistisch",
    "frühsozialistischer": "frühsozialistisch",
    "frühsozialistischere": "frühsozialistisch",
    "frühsozialistischerem": "frühsozialistisch",
    "frühsozialistischeren": "frühsozialistisch",
    "frühsozialistischerer": "frühsozialistisch",
    "frühsozialistischeres": "frühsozialistisch",
    "frühsozialistisches": "frühsozialistisch",
    "frühsozialistischste": "frühsozialistisch",
    "frühsozialistischstem": "frühsozialistisch",
    "frühsozialistischsten": "frühsozialistisch",
    "frühsozialistischster": "frühsozialistisch",
    "frühsozialistischstes": "frühsozialistisch",
    "frühzeitigem": "frühzeitig",
    "frühzeitigen": "frühzeitig",
    "frühzeitiger": "frühzeitig",
    "frühzeitigere": "frühzeitig",
    "frühzeitigerem": "frühzeitig",
    "frühzeitigeren": "frühzeitig",
    "frühzeitigerer": "frühzeitig",
    "frühzeitigeres": "frühzeitig",
    "frühzeitiges": "frühzeitig",
    "frühzeitigste": "frühzeitig",
    "frühzeitigstem": "frühzeitig",
    "frühzeitigsten": "frühzeitig",
    "frühzeitigster": "frühzeitig",
    "frühzeitigstes": "frühzeitig",
    "fuchtele": "fuchteln",
    "fuchtelnd": "fuchteln",
    "fuchtelnde": "fuchtelnd",
    "fuchtelndem": "fuchtelnd",
    "fuchtelnden": "fuchtelnd",
    "fuchtelnder": "fuchtelnd",
    "fuchtelndere": "fuchtelnd",
    "fuchtelnderem": "fuchtelnd",
    "fuchtelnderen": "fuchtelnd",
    "fuchtelnderer": "fuchtelnd",
    "fuchtelnderes": "fuchtelnd",
    "fuchtelndes": "fuchtelnd",
    "fuchtelndste": "fuchtelnd",
    "fuchtelndstem": "fuchtelnd",
    "fuchtelndsten": "fuchtelnd",
    "fuchtelndster": "fuchtelnd",
    "fuchtelndstes": "fuchtelnd",
    "fuchtelst": "fuchteln",
    "fuchtelt": "fuchteln",
    "fuchtelte": "fuchteln",
    "fuchtelten": "fuchteln",
    "fuchteltest": "fuchteln",
    "fuchteltet": "fuchteln",
    "fuchtle": "fuchteln",
    "fugend": "fugen",
    "fugende": "fugend",
    "fugendem": "fugend",
    "fugenden": "fugend",
    "fugender": "fugend",
    "fugendes": "fugend",
    "fugest": "fugen",
    "fuget": "fugen",
    "fugst": "fugen",
    "fugt": "fugen",
    "fugte": "fugen",
    "fugten": "fugen",
    "fugtest": "fugen",
    "fugtet": "fugen",
    "fuhr": "fahren",
    "fuhren": "fahren",
    "fuhrst": "fahren",
    "fuhrt": "fahren",
    "fulminantem": "fulminant",
    "fulminanten": "fulminant",
    "fulminanter": "fulminant",
    "fulminantere": "fulminant",
    "fulminanterem": "fulminant",
    "fulminanteren": "fulminant",
    "fulminanterer": "fulminant",
    "fulminanteres": "fulminant",
    "fulminantes": "fulminant",
    "fulminanteste": "fulminant",
    "fulminantestem": "fulminant",
    "fulminantesten": "fulminant",
    "fulminantester": "fulminant",
    "fulminantestes": "fulminant",
    "fummele": "fummeln",
    "fummelnd": "fummeln",
    "fummelnde": "fummelnd",
    "fummelndem": "fummelnd",
    "fummelnden": "fummelnd",
    "fummelnder": "fummelnd",
    "fummelndere": "fummelnd",
    "fummelnderem": "fummelnd",
    "fummelnderen": "fummelnd",
    "fummelnderer": "fummelnd",
    "fummelnderes": "fummelnd",
    "fummelndes": "fummelnd",
    "fummelndste": "fummelnd",
    "fummelndstem": "fummelnd",
    "fummelndsten": "fummelnd",
    "fummelndster": "fummelnd",
    "fummelndstes": "fummelnd",
    "fummelst": "fummeln",
    "fummelt": "fummeln",
    "fummelte": "fummeln",
    "fummelten": "fummeln",
    "fummeltest": "fummeln",
    "fummeltet": "fummeln",
    "fummle": "fummeln",
    "fundamentale": "fundamental",
    "fundamentalem": "fundamental",
    "fundamentalen": "fundamental",
    "fundamentaler": "fundamental",
    "fundamentalere": "fundamental",
    "fundamentalerem": "fundamental",
    "fundamentaleren": "fundamental",
    "fundamentalerer": "fundamental",
    "fundamentaleres": "fundamental",
    "fundamentales": "fundamental",
    "fundamentalistischem": "fundamentalistisch",
    "fundamentalistischen": "fundamentalistisch",
    "fundamentalistischer": "fundamentalistisch",
    "fundamentalistisches": "fundamentalistisch",
    "fundamentalste": "fundamental",
    "fundamentalstem": "fundamental",
    "fundamentalsten": "fundamental",
    "fundamentalster": "fundamental",
    "fundamentalstes": "fundamental",
    "fundiere": "fundieren",
    "fundierend": "fundieren",
    "fundierende": "fundierend",
    "fundierendem": "fundierend",
    "fundierenden": "fundierend",
    "fundierender": "fundierend",
    "fundierendere": "fundierend",
    "fundierenderem": "fundierend",
    "fundierenderen": "fundierend",
    "fundierenderer": "fundierend",
    "fundierenderes": "fundierend",
    "fundierendes": "fundierend",
    "fundierendste": "fundierend",
    "fundierendstem": "fundierend",
    "fundierendsten": "fundierend",
    "fundierendster": "fundierend",
    "fundierendstes": "fundierend",
    "fundierest": "fundieren",
    "fundieret": "fundieren",
    "fundierst": "fundieren",
    "fundiert": "fundieren",
    "fundierte": "fundieren",
    "fundiertem": "fundiert",
    "fundierten": "fundieren",
    "fundierter": "fundiert",
    "fundiertere": "fundiert",
    "fundierterem": "fundiert",
    "fundierteren": "fundiert",
    "fundierterer": "fundiert",
    "fundierteres": "fundiert",
    "fundiertes": "fundiert",
    "fundiertest": "fundieren",
    "fundierteste": "fundiert",
    "fundiertestem": "fundiert",
    "fundiertesten": "fundiert",
    "fundiertester": "fundiert",
    "fundiertestes": "fundiert",
    "fundiertet": "fundieren",
    "fungiere": "fungieren",
    "fungierend": "fungieren",
    "fungierende": "fungierend",
    "fungierendem": "fungierend",
    "fungierenden": "fungierend",
    "fungierender": "fungierend",
    "fungierendes": "fungierend",
    "fungierest": "fungieren",
    "fungieret": "fungieren",
    "fungierst": "fungieren",
    "fungiert": "fungieren",
    "fungierte": "fungieren",
    "fungiertem": "fungiert",
    "fungierten": "fungieren",
    "fungierter": "fungiert",
    "fungiertes": "fungiert",
    "fungiertest": "fungieren",
    "fungiertet": "fungieren",
    "funkele": "funkeln",
    "funkelnagelneue": "funkelnagelneu",
    "funkelnagelneuem": "funkelnagelneu",
    "funkelnagelneuen": "funkelnagelneu",
    "funkelnagelneuer": "funkelnagelneu",
    "funkelnagelneues": "funkelnagelneu",
    "funkelnd": "funkeln",
    "funkelnde": "funkelnd",
    "funkelndem": "funkelnd",
    "funkelnden": "funkelnd",
    "funkelnder": "funkelnd",
    "funkelndere": "funkelnd",
    "funkelnderem": "funkelnd",
    "funkelnderen": "funkelnd",
    "funkelnderer": "funkelnd",
    "funkelnderes": "funkelnd",
    "funkelndes": "funkelnd",
    "funkelndste": "funkelnd",
    "funkelndstem": "funkelnd",
    "funkelndsten": "funkelnd",
    "funkelndster": "funkelnd",
    "funkelndstes": "funkelnd",
    "funkelst": "funkeln",
    "funkelt": "funkeln",
    "funkelte": "funkeln",
    "funkelten": "funkeln",
    "funkeltest": "funkeln",
    "funkeltet": "funkeln",
    "funkend": "funken",
    "funkende": "funkend",
    "funkendem": "funkend",
    "funkenden": "funkend",
    "funkender": "funkend",
    "funkendes": "funkend",
    "funkest": "funken",
    "funket": "funken",
    "funkle": "funkeln",
    "funkst": "funken",
    "funkt": "funken",
    "funkte": "funken",
    "funkten": "funken",
    "funktest": "funken",
    "funktet": "funken",
    "funktionale": "funktional",
    "funktionalem": "funktional",
    "funktionalen": "funktional",
    "funktionaler": "funktional",
    "funktionalere": "funktional",
    "funktionalerem": "funktional",
    "funktionaleren": "funktional",
    "funktionalerer": "funktional",
    "funktionaleres": "funktional",
    "funktionales": "funktional",
    "funktionalisiere": "funktionalisieren",
    "funktionalisierend": "funktionalisieren",
    "funktionalisierende": "funktionalisierend",
    "funktionalisierendem": "funktionalisierend",
    "funktionalisierenden": "funktionalisierend",
    "funktionalisierender": "funktionalisierend",
    "funktionalisierendes": "funktionalisierend",
    "funktionalisierest": "funktionalisieren",
    "funktionalisieret": "funktionalisieren",
    "funktionalisierst": "funktionalisieren",
    "funktionalisiert": "funktionalisieren",
    "funktionalisierte": "funktionalisieren",
    "funktionalisiertem": "funktionalisiert",
    "funktionalisierten": "funktionalisieren",
    "funktionalisierter": "funktionalisiert",
    "funktionalisiertes": "funktionalisiert",
    "funktionalisiertest": "funktionalisieren",
    "funktionalisiertet": "funktionalisieren",
    "funktionalste": "funktional",
    "funktionalstem": "funktional",
    "funktionalsten": "funktional",
    "funktionalster": "funktional",
    "funktionalstes": "funktional",
    "funktionellem": "funktionell",
    "funktionellen": "funktionell",
    "funktioneller": "funktionell",
    "funktionellere": "funktionell",
    "funktionellerem": "funktionell",
    "funktionelleren": "funktionell",
    "funktionellerer": "funktionell",
    "funktionelleres": "funktionell",
    "funktionelles": "funktionell",
    "funktionellste": "funktionell",
    "funktionellstem": "funktionell",
    "funktionellsten": "funktionell",
    "funktionellster": "funktionell",
    "funktionellstes": "funktionell",
    "funktionierend": "funktionieren",
    "funktionierende": "funktionierend",
    "funktionierendem": "funktionierend",
    "funktionierenden": "funktionierend",
    "funktionierender": "funktionierend",
    "funktionierendere": "funktionierend",
    "funktionierenderem": "funktionierend",
    "funktionierenderen": "funktionierend",
    "funktionierenderer": "funktionierend",
    "funktionierenderes": "funktionierend",
    "funktionierendes": "funktionierend",
    "funktionierendste": "funktionierend",
    "funktionierendstem": "funktionierend",
    "funktionierendsten": "funktionierend",
    "funktionierendster": "funktionierend",
    "funktionierendstes": "funktionierend",
    "funktionierest": "funktionieren",
    "funktionieret": "funktionieren",
    "funktionierst": "funktionieren",
    "funktioniert": "funktionieren",
    "funktionierte": "funktionieren",
    "funktioniertem": "funktioniert",
    "funktionierten": "funktionieren",
    "funktionierter": "funktioniert",
    "funktioniertes": "funktioniert",
    "funktioniertest": "funktionieren",
    "funktioniertet": "funktionieren",
    "funktionsfähige": "funktionsfähig",
    "funktionsfähigem": "funktionsfähig",
    "funktionsfähigen": "funktionsfähig",
    "funktionsfähiger": "funktionsfähig",
    "funktionsfähigere": "funktionsfähig",
    "funktionsfähigerem": "funktionsfähig",
    "funktionsfähigeren": "funktionsfähig",
    "funktionsfähigerer": "funktionsfähig",
    "funktionsfähigeres": "funktionsfähig",
    "funktionsfähiges": "funktionsfähig",
    "funktionsfähigste": "funktionsfähig",
    "funktionsfähigstem": "funktionsfähig",
    "funktionsfähigsten": "funktionsfähig",
    "funktionsfähigster": "funktionsfähig",
    "funktionsfähigstes": "funktionsfähig",
    "funktionstüchtige": "funktionstüchtig",
    "funktionstüchtigem": "funktionstüchtig",
    "funktionstüchtigen": "funktionstüchtig",
    "funktionstüchtiger": "funktionstüchtig",
    "funktionstüchtigere": "funktionstüchtig",
    "funktionstüchtigerem": "funktionstüchtig",
    "funktionstüchtigeren": "funktionstüchtig",
    "funktionstüchtigerer": "funktionstüchtig",
    "funktionstüchtigeres": "funktionstüchtig",
    "funktionstüchtiges": "funktionstüchtig",
    "funktionstüchtigste": "funktionstüchtig",
    "funktionstüchtigstem": "funktionstüchtig",
    "funktionstüchtigsten": "funktionstüchtig",
    "funktionstüchtigster": "funktionstüchtig",
    "funktionstüchtigstes": "funktionstüchtig",
    "furchigem": "furchig",
    "furchigen": "furchig",
    "furchiger": "furchig",
    "furchigere": "furchig",
    "furchigerem": "furchig",
    "furchigeren": "furchig",
    "furchigerer": "furchig",
    "furchigeres": "furchig",
    "furchiges": "furchig",
    "furchigste": "furchig",
    "furchigstem": "furchig",
    "furchigsten": "furchig",
    "furchigster": "furchig",
    "furchigstes": "furchig",
    "furchtbare": "furchtbar",
    "furchtbarem": "furchtbar",
    "furchtbaren": "furchtbar",
    "furchtbarer": "furchtbar",
    "furchtbarere": "furchtbar",
    "furchtbarerem": "furchtbar",
    "furchtbareren": "furchtbar",
    "furchtbarerer": "furchtbar",
    "furchtbareres": "furchtbar",
    "furchtbares": "furchtbar",
    "furchtbarste": "furchtbar",
    "furchtbarstem": "furchtbar",
    "furchtbarsten": "furchtbar",
    "furchtbarster": "furchtbar",
    "furchtbarstes": "furchtbar",
    "furchtlose": "furchtlos",
    "furchtlosem": "furchtlos",
    "furchtlosen": "furchtlos",
    "furchtloser": "furchtlos",
    "furchtlosere": "furchtlos",
    "furchtloserem": "furchtlos",
    "furchtloseren": "furchtlos",
    "furchtloserer": "furchtlos",
    "furchtloseres": "furchtlos",
    "furchtloses": "furchtlos",
    "furchtloseste": "furchtlos",
    "furchtlosestem": "furchtlos",
    "furchtlosesten": "furchtlos",
    "furchtlosester": "furchtlos",
    "furchtlosestes": "furchtlos",
    "furchtsame": "furchtsam",
    "furchtsamem": "furchtsam",
    "furchtsamen": "furchtsam",
    "furchtsamer": "furchtsam",
    "furchtsamere": "furchtsam",
    "furchtsamerem": "furchtsam",
    "furchtsameren": "furchtsam",
    "furchtsamerer": "furchtsam",
    "furchtsameres": "furchtsam",
    "furchtsames": "furchtsam",
    "furchtsamste": "furchtsam",
    "furchtsamstem": "furchtsam",
    "furchtsamsten": "furchtsam",
    "furchtsamster": "furchtsam",
    "furchtsamstes": "furchtsam",
    "furiosem": "furios",
    "furiosen": "furios",
    "furioser": "furios",
    "furiosere": "furios",
    "furioserem": "furios",
    "furioseren": "furios",
    "furioserer": "furios",
    "furioseres": "furios",
    "furioses": "furios",
    "furioseste": "furios",
    "furiosestem": "furios",
    "furiosesten": "furios",
    "furiosester": "furios",
    "furiosestes": "furios",
    "furnierend": "furnieren",
    "furnierende": "furnierend",
    "furnierendem": "furnierend",
    "furnierenden": "furnierend",
    "furnierender": "furnierend",
    "furnierendes": "furnierend",
    "furnierest": "furnieren",
    "furnieret": "furnieren",
    "furnierst": "furnieren",
    "furniert": "furnieren",
    "furnierte": "furnieren",
    "furniertem": "furniert",
    "furnierten": "furnieren",
    "furnierter": "furniert",
    "furniertes": "furniert",
    "furniertest": "furnieren",
    "furniertet": "furnieren",
    "furze": "furzen",
    "furzend": "furzen",
    "furzende": "furzend",
    "furzendem": "furzend",
    "furzenden": "furzend",
    "furzender": "furzend",
    "furzendes": "furzend",
    "furzest": "furzen",
    "furzet": "furzen",
    "furzt": "furzen",
    "furzte": "furzen",
    "furzten": "furzen",
    "furztest": "furzen",
    "furztet": "furzen",
    "fusioniere": "fusionieren",
    "fusionierend": "fusionieren",
    "fusionierende": "fusionierend",
    "fusionierendem": "fusionierend",
    "fusionierenden": "fusionierend",
    "fusionierender": "fusionierend",
    "fusionierendes": "fusionierend",
    "fusionierest": "fusionieren",
    "fusionieret": "fusionieren",
    "fusionierst": "fusionieren",
    "fusioniert": "fusionieren",
    "fusionierte": "fusionieren",
    "fusioniertem": "fusioniert",
    "fusionierten": "fusionieren",
    "fusionierter": "fusioniert",
    "fusioniertes": "fusioniert",
    "fusioniertest": "fusionieren",
    "fusioniertet": "fusionieren",
    "fussele": "fusseln",
    "fusselige": "fusselig",
    "fusseligem": "fusselig",
    "fusseligen": "fusselig",
    "fusseliger": "fusselig",
    "fusseligere": "fusselig",
    "fusseligerem": "fusselig",
    "fusseligeren": "fusselig",
    "fusseligerer": "fusselig",
    "fusseligeres": "fusselig",
    "fusseliges": "fusselig",
    "fusseligste": "fusselig",
    "fusseligstem": "fusselig",
    "fusseligsten": "fusselig",
    "fusseligster": "fusselig",
    "fusseligstes": "fusselig",
    "fusselnd": "fusseln",
    "fusselnde": "fusselnd",
    "fusselndem": "fusselnd",
    "fusselnden": "fusselnd",
    "fusselnder": "fusselnd",
    "fusselndere": "fusselnd",
    "fusselnderem": "fusselnd",
    "fusselnderen": "fusselnd",
    "fusselnderer": "fusselnd",
    "fusselnderes": "fusselnd",
    "fusselndes": "fusselnd",
    "fusselndste": "fusselnd",
    "fusselndstem": "fusselnd",
    "fusselndsten": "fusselnd",
    "fusselndster": "fusselnd",
    "fusselndstes": "fusselnd",
    "fusselst": "fusseln",
    "fusselt": "fusseln",
    "fusselte": "fusseln",
    "fusselten": "fusseln",
    "fusseltest": "fusseln",
    "fusseltet": "fusseln",
    "fussle": "fusseln",
    "futtere": "futtern",
    "futternd": "futtern",
    "futternde": "futternd",
    "futterndem": "futternd",
    "futternden": "futternd",
    "futternder": "futternd",
    "futterndere": "futternd",
    "futternderem": "futternd",
    "futternderen": "futternd",
    "futternderer": "futternd",
    "futternderes": "futternd",
    "futterndes": "futternd",
    "futterndste": "futternd",
    "futterndstem": "futternd",
    "futterndsten": "futternd",
    "futterndster": "futternd",
    "futterndstes": "futternd",
    "futterst": "futtern",
    "futtert": "futtern",
    "futterte": "futtern",
    "futterten": "futtern",
    "futtertest": "futtern",
    "futtertet": "futtern",
    "futurische": "futurisch",
    "futurischem": "futurisch",
    "futurischen": "futurisch",
    "futurischer": "futurisch",
    "futurischere": "futurisch",
    "futurischerem": "futurisch",
    "futurischeren": "futurisch",
    "futurischerer": "futurisch",
    "futurischeres": "futurisch",
    "futurisches": "futurisch",
    "futurischste": "futurisch",
    "futurischstem": "futurisch",
    "futurischsten": "futurisch",
    "futurischster": "futurisch",
    "futurischstes": "futurisch",
    "futuristische": "futuristisch",
    "futuristischem": "futuristisch",
    "futuristischen": "futuristisch",
    "futuristischer": "futuristisch",
    "futuristischere": "futuristisch",
    "futuristischerem": "futuristisch",
    "futuristischeren": "futuristisch",
    "futuristischerer": "futuristisch",
    "futuristischeres": "futuristisch",
    "futuristisches": "futuristisch",
    "futuristischste": "futuristisch",
    "futuristischstem": "futuristisch",
    "futuristischsten": "futuristisch",
    "futuristischster": "futuristisch",
    "futuristischstes": "futuristisch",
    "fußballerischem": "fußballerisch",
    "fußballerischen": "fußballerisch",
    "fußballerischer": "fußballerisch",
    "fußballerisches": "fußballerisch",
    "fußend": "fußen",
    "fußende": "fußend",
    "fußendem": "fußend",
    "fußenden": "fußend",
    "fußender": "fußend",
    "fußendere": "fußend",
    "fußenderem": "fußend",
    "fußenderen": "fußend",
    "fußenderer": "fußend",
    "fußenderes": "fußend",
    "fußendes": "fußend",
    "fußendste": "fußend",
    "fußendstem": "fußend",
    "fußendsten": "fußend",
    "fußendster": "fußend",
    "fußendstes": "fußend",
    "fußest": "fußen",
    "fußet": "fußen",
    "fußfreie": "fußfrei",
    "fußfreiem": "fußfrei",
    "fußfreien": "fußfrei",
    "fußfreier": "fußfrei",
    "fußfreies": "fußfrei",
    "fußt": "fußen",
    "fußte": "fußen",
    "fußten": "fußen",
    "fußtest": "fußen",
    "fußtet": "fußen",
    "fächele": "fächeln",
    "fächelnd": "fächeln",
    "fächelnde": "fächelnd",
    "fächelndem": "fächelnd",
    "fächelnden": "fächelnd",
    "fächelnder": "fächelnd",
    "fächelndes": "fächelnd",
    "fächelst": "fächeln",
    "fächelt": "fächeln",
    "fächelte": "fächeln",
    "fächelten": "fächeln",
    "fächeltest": "fächeln",
    "fächeltet": "fächeln",
    "fächere": "fächern",
    "fächernd": "fächern",
    "fächernde": "fächernd",
    "fächerndem": "fächernd",
    "fächernden": "fächernd",
    "fächernder": "fächernd",
    "fächerndere": "fächernd",
    "fächernderem": "fächernd",
    "fächernderen": "fächernd",
    "fächernderer": "fächernd",
    "fächernderes": "fächernd",
    "fächerndes": "fächernd",
    "fächerndste": "fächernd",
    "fächerndstem": "fächernd",
    "fächerndsten": "fächernd",
    "fächerndster": "fächernd",
    "fächerndstes": "fächernd",
    "fächerst": "fächern",
    "fächert": "fächern",
    "fächerte": "fächern",
    "fächerten": "fächern",
    "fächertest": "fächern",
    "fächertet": "fächern",
    "fächerübergreifende": "fächerübergreifend",
    "fächerübergreifendem": "fächerübergreifend",
    "fächerübergreifenden": "fächerübergreifend",
    "fächerübergreifender": "fächerübergreifend",
    "fächerübergreifendes": "fächerübergreifend",
    "fächle": "fächeln",
    "fädele": "fädeln",
    "fädelnd": "fädeln",
    "fädelnde": "fädelnd",
    "fädelndem": "fädelnd",
    "fädelnden": "fädelnd",
    "fädelnder": "fädelnd",
    "fädelndes": "fädelnd",
    "fädelst": "fädeln",
    "fädelt": "fädeln",
    "fädelte": "fädeln",
    "fädelten": "fädeln",
    "fädeltest": "fädeln",
    "fädeltet": "fädeln",
    "fädle": "fädeln",
    "fähige": "fähig",
    "fähigem": "fähig",
    "fähigen": "fähig",
    "fähiger": "fähig",
    "fähigere": "fähig",
    "fähigerem": "fähig",
    "fähigeren": "fähig",
    "fähigerer": "fähig",
    "fähigeres": "fähig",
    "fähiges": "fähig",
    "fähigstem": "fähig",
    "fähigsten": "fähig",
    "fähigster": "fähig",
    "fähigstes": "fähig",
    "fährst": "fahren",
    "fährt": "fahren",
    "fäkalem": "fäkal",
    "fäkalen": "fäkal",
    "fäkaler": "fäkal",
    "fäkales": "fäkal",
    "fällend": "fällen",
    "fällendem": "fällend",
    "fällender": "fällend",
    "fällendes": "fällend",
    "fällest": "fällen",
    "fället": "fällen",
    "fälligem": "fällig",
    "fälligen": "fällig",
    "fälliger": "fällig",
    "fälliges": "fällig",
    "fällst": "fällen",
    "fällt": "fällen",
    "fällte": "fällen",
    "fällten": "fällen",
    "fälltest": "fällen",
    "fälltet": "fällen",
    "fälsche": "fälschen",
    "fälschend": "fälschen",
    "fälschende": "fälschend",
    "fälschendem": "fälschend",
    "fälschenden": "fälschend",
    "fälschender": "fälschend",
    "fälschendes": "fälschend",
    "fälschest": "fälschen",
    "fälschet": "fälschen",
    "fälschliche": "fälschlich",
    "fälschlichem": "fälschlich",
    "fälschlichen": "fälschlich",
    "fälschlicher": "fälschlich",
    "fälschliches": "fälschlich",
    "fälschst": "fälschen",
    "fälscht": "fälschen",
    "fälschte": "fälschen",
    "fälschten": "fälschen",
    "fälschtest": "fälschen",
    "fälschtet": "fälschen",
    "fände": "finden",
    "fänden": "finden",
    "fändest": "finden",
    "fändet": "finden",
    "fängst": "fangen",
    "fängt": "fangen",
    "färbe": "färben",
    "färbend": "färben",
    "färbende": "färbend",
    "färbendem": "färbend",
    "färbenden": "färbend",
    "färbender": "färbend",
    "färbendere": "färbend",
    "färbenderem": "färbend",
    "färbenderen": "färbend",
    "färbenderer": "färbend",
    "färbenderes": "färbend",
    "färbendes": "färbend",
    "färbendste": "färbend",
    "färbendstem": "färbend",
    "färbendsten": "färbend",
    "färbendster": "färbend",
    "färbendstes": "färbend",
    "färbest": "färben",
    "färbet": "färben",
    "färbst": "färben",
    "färbt": "färben",
    "färbte": "färben",
    "färbten": "färben",
    "färbtest": "färben",
    "färbtet": "färben",
    "föchte": "fechten",
    "föchten": "fechten",
    "föchtest": "fechten",
    "föchtet": "fechten",
    "föderale": "föderal",
    "föderalem": "föderal",
    "föderalen": "föderal",
    "föderaler": "föderal",
    "föderales": "föderal",
    "föderalisiere": "föderalisieren",
    "föderalisierend": "föderalisieren",
    "föderalisierende": "föderalisierend",
    "föderalisierendem": "föderalisierend",
    "föderalisierenden": "föderalisierend",
    "föderalisierender": "föderalisierend",
    "föderalisierendere": "föderalisierend",
    "föderalisierenderem": "föderalisierend",
    "föderalisierenderen": "föderalisierend",
    "föderalisierenderer": "föderalisierend",
    "föderalisierenderes": "föderalisierend",
    "föderalisierendes": "föderalisierend",
    "föderalisierendste": "föderalisierend",
    "föderalisierendstem": "föderalisierend",
    "föderalisierendsten": "föderalisierend",
    "föderalisierendster": "föderalisierend",
    "föderalisierendstes": "föderalisierend",
    "föderalisierest": "föderalisieren",
    "föderalisieret": "föderalisieren",
    "föderalisierst": "föderalisieren",
    "föderalisiert": "föderalisieren",
    "föderalisierte": "föderalisieren",
    "föderalisiertem": "föderalisiert",
    "föderalisierten": "föderalisieren",
    "föderalisierter": "föderalisiert",
    "föderalisiertere": "föderalisiert",
    "föderalisierterem": "föderalisiert",
    "föderalisierteren": "föderalisiert",
    "föderalisierterer": "föderalisiert",
    "föderalisierteres": "föderalisiert",
    "föderalisiertes": "föderalisiert",
    "föderalisiertest": "föderalisieren",
    "föderalisiertestem": "föderalisiert",
    "föderalisiertesten": "föderalisiert",
    "föderalisiertester": "föderalisiert",
    "föderalisiertestes": "föderalisiert",
    "föderalisiertet": "föderalisieren",
    "föderalistische": "föderalistisch",
    "föderalistischem": "föderalistisch",
    "föderalistischen": "föderalistisch",
    "föderalistischer": "föderalistisch",
    "föderalistisches": "föderalistisch",
    "föderiere": "föderieren",
    "föderierend": "föderieren",
    "föderierende": "föderierend",
    "föderierendem": "föderierend",
    "föderierenden": "föderierend",
    "föderierender": "föderierend",
    "föderierendere": "föderierend",
    "föderierenderem": "föderierend",
    "föderierenderen": "föderierend",
    "föderierenderer": "föderierend",
    "föderierenderes": "föderierend",
    "föderierendes": "föderierend",
    "föderierendste": "föderierend",
    "föderierendstem": "föderierend",
    "föderierendsten": "föderierend",
    "föderierendster": "föderierend",
    "föderierendstes": "föderierend",
    "föderierest": "föderieren",
    "föderieret": "föderieren",
    "föderierst": "föderieren",
    "föderiert": "föderieren",
    "föderierte": "föderieren",
    "föderiertem": "föderiert",
    "föderierten": "föderieren",
    "föderierter": "föderiert",
    "föderiertes": "föderiert",
    "föderiertest": "föderieren",
    "föderiertet": "föderieren",
    "föhnend": "föhnen",
    "föhnende": "föhnend",
    "föhnendem": "föhnend",
    "föhnenden": "föhnend",
    "föhnender": "föhnend",
    "föhnendes": "föhnend",
    "föhnest": "föhnen",
    "föhnet": "föhnen",
    "föhnst": "föhnen",
    "föhnt": "föhnen",
    "föhnte": "föhnen",
    "föhnten": "föhnen",
    "föhntest": "föhnen",
    "föhntet": "föhnen",
    "fönend": "fönen",
    "fönende": "fönend",
    "fönendem": "fönend",
    "fönenden": "fönend",
    "fönender": "fönend",
    "fönendes": "fönend",
    "fönest": "fönen",
    "fönet": "fönen",
    "fönst": "fönen",
    "fönt": "fönen",
    "fönte": "fönen",
    "fönten": "fönen",
    "föntest": "fönen",
    "föntet": "fönen",
    "fördere": "fördern",
    "förderlichem": "förderlich",
    "förderlichen": "förderlich",
    "förderlicher": "förderlich",
    "förderliches": "förderlich",
    "fördernd": "fördern",
    "förderndem": "fördernd",
    "fördernder": "fördernd",
    "fördernderem": "fördernd",
    "fördernderer": "fördernd",
    "fördernderes": "fördernd",
    "förderndes": "fördernd",
    "förderndstem": "fördernd",
    "förderndster": "fördernd",
    "förderndstes": "fördernd",
    "förderst": "fördern",
    "fördert": "fördern",
    "förderte": "fördern",
    "förderten": "fördern",
    "fördertest": "fördern",
    "fördertet": "fördern",
    "förmigem": "förmig",
    "förmigen": "förmig",
    "förmiger": "förmig",
    "förmigere": "förmig",
    "förmigerem": "förmig",
    "förmigeren": "förmig",
    "förmigerer": "förmig",
    "förmigeres": "förmig",
    "förmiges": "förmig",
    "förmigste": "förmig",
    "förmigstem": "förmig",
    "förmigsten": "förmig",
    "förmigster": "förmig",
    "förmigstes": "förmig",
    "förmliche": "förmlich",
    "förmlichem": "förmlich",
    "förmlichen": "förmlich",
    "förmlicher": "förmlich",
    "förmlichere": "förmlich",
    "förmlicherem": "förmlich",
    "förmlicheren": "förmlich",
    "förmlicherer": "förmlich",
    "förmlicheres": "förmlich",
    "förmliches": "förmlich",
    "förmlichste": "förmlich",
    "förmlichstem": "förmlich",
    "förmlichsten": "förmlich",
    "förmlichster": "förmlich",
    "förmlichstes": "förmlich",
    "füge": "fügen",
    "fügend": "fügen",
    "fügendem": "fügend",
    "fügender": "fügend",
    "fügendes": "fügend",
    "fügest": "fügen",
    "füget": "fügen",
    "fügst": "fügen",
    "fügt": "fügen",
    "fügte": "fügen",
    "fügten": "fügen",
    "fügtest": "fügen",
    "fügtet": "fügen",
    "fühlbarem": "fühlbar",
    "fühlbaren": "fühlbar",
    "fühlbarer": "fühlbar",
    "fühlbares": "fühlbar",
    "fühle": "fühlen",
    "fühlend": "fühlen",
    "fühlende": "fühlend",
    "fühlendem": "fühlend",
    "fühlenden": "fühlend",
    "fühlender": "fühlend",
    "fühlendes": "fühlend",
    "fühlest": "fühlen",
    "fühlet": "fühlen",
    "fühlst": "fühlen",
    "fühlt": "fühlen",
    "fühlte": "fühlen",
    "fühlten": "fühlen",
    "fühltest": "fühlen",
    "fühltet": "fühlen",
    "führe": "führen",
    "führen": "fahren",
    "führend": "führen",
    "führende": "führend",
    "führendem": "führend",
    "führenden": "führend",
    "führender": "führend",
    "führendere": "führend",
    "führenderem": "führend",
    "führenderen": "führend",
    "führenderer": "führend",
    "führenderes": "führend",
    "führendes": "führend",
    "führendste": "führend",
    "führendstem": "führend",
    "führendsten": "führend",
    "führendster": "führend",
    "führendstes": "führend",
    "führest": "führen",
    "führet": "führen",
    "führst": "führen",
    "führt": "führen",
    "führte": "führen",
    "führten": "führen",
    "führtest": "führen",
    "führtet": "führen",
    "fülle": "füllen",
    "füllend": "füllen",
    "füllende": "füllend",
    "füllendem": "füllend",
    "füllenden": "füllend",
    "füllender": "füllend",
    "füllendes": "füllend",
    "füllest": "füllen",
    "füllet": "füllen",
    "füllst": "füllen",
    "füllt": "füllen",
    "füllte": "füllen",
    "füllten": "füllen",
    "fülltest": "füllen",
    "fülltet": "füllen",
    "fünftem": "fünft",
    "fünften": "fünft",
    "fünfter": "fünft",
    "fünftes": "fünft",
    "fürchte": "fürchten",
    "fürchtend": "fürchten",
    "fürchtende": "fürchtend",
    "fürchtendem": "fürchtend",
    "fürchtenden": "fürchtend",
    "fürchtender": "fürchtend",
    "fürchtendere": "fürchtend",
    "fürchtenderem": "fürchtend",
    "fürchtenderen": "fürchtend",
    "fürchtenderer": "fürchtend",
    "fürchtenderes": "fürchtend",
    "fürchtendes": "fürchtend",
    "fürchtendste": "fürchtend",
    "fürchtendstem": "fürchtend",
    "fürchtendsten": "fürchtend",
    "fürchtendster": "fürchtend",
    "fürchtendstes": "fürchtend",
    "fürchterlichem": "fürchterlich",
    "fürchterlichen": "fürchterlich",
    "fürchterlicher": "fürchterlich",
    "fürchterlichere": "fürchterlich",
    "fürchterlicherem": "fürchterlich",
    "fürchterlicheren": "fürchterlich",
    "fürchterlicherer": "fürchterlich",
    "fürchterlicheres": "fürchterlich",
    "fürchterliches": "fürchterlich",
    "fürchterlichste": "fürchterlich",
    "fürchterlichstem": "fürchterlich",
    "fürchterlichsten": "fürchterlich",
    "fürchterlichster": "fürchterlich",
    "fürchterlichstes": "fürchterlich",
    "fürchtest": "fürchten",
    "fürchtet": "fürchten",
    "fürchtete": "fürchten",
    "fürchteten": "fürchten",
    "fürchtetest": "fürchten",
    "fürchtetet": "fürchten",
    "fürsorglichem": "fürsorglich",
    "fürsorglichen": "fürsorglich",
    "fürsorglicher": "fürsorglich",
    "fürsorglichere": "fürsorglich",
    "fürsorglicherem": "fürsorglich",
    "fürsorglicheren": "fürsorglich",
    "fürsorglicherer": "fürsorglich",
    "fürsorglicheres": "fürsorglich",
    "fürsorgliches": "fürsorglich",
    "fürsorglichste": "fürsorglich",
    "fürsorglichstem": "fürsorglich",
    "fürsorglichsten": "fürsorglich",
    "fürsorglichster": "fürsorglich",
    "fürsorglichstes": "fürsorglich",
    "fürstlichem": "fürstlich",
    "fürstlichen": "fürstlich",
    "fürstlicher": "fürstlich",
    "fürstlichere": "fürstlich",
    "fürstlicherem": "fürstlich",
    "fürstlicheren": "fürstlich",
    "fürstlicherer": "fürstlich",
    "fürstlicheres": "fürstlich",
    "fürstliches": "fürstlich",
    "fürstlichste": "fürstlich",
    "fürstlichstem": "fürstlich",
    "fürstlichsten": "fürstlich",
    "fürstlichster": "fürstlich",
    "fürstlichstes": "fürstlich",
    "füttere": "füttern",
    "fütternd": "füttern",
    "fütterndem": "fütternd",
    "fütternder": "fütternd",
    "fütternderem": "fütternd",
    "fütternderer": "fütternd",
    "fütternderes": "fütternd",
    "fütterndes": "fütternd",
    "fütterndstem": "fütternd",
    "fütterndster": "fütternd",
    "fütterndstes": "fütternd",
    "fütterst": "füttern",
    "füttert": "füttern",
    "fütterte": "füttern",
    "fütterten": "füttern",
    "füttertest": "füttern",
    "füttertet": "füttern",
    "gab": "geben",
    "gabele": "gabeln",
    "gabelförmige": "gabelförmig",
    "gabelförmigem": "gabelförmig",
    "gabelförmigen": "gabelförmig",
    "gabelförmiger": "gabelförmig",
    "gabelförmiges": "gabelförmig",
    "gabelnd": "gabeln",
    "gabelnde": "gabelnd",
    "gabelndem": "gabelnd",
    "gabelnden": "gabelnd",
    "gabelnder": "gabelnd",
    "gabelndes": "gabelnd",
    "gabelst": "gabeln",
    "gabelt": "gabeln",
    "gabelte": "gabeln",
    "gabelten": "gabeln",
    "gabeltest": "gabeln",
    "gabeltet": "gabeln",
    "gable": "gabeln",
    "gabst": "geben",
    "gabt": "geben",
    "gaffe": "gaffen",
    "gaffend": "gaffen",
    "gaffende": "gaffend",
    "gaffendem": "gaffend",
    "gaffenden": "gaffend",
    "gaffender": "gaffend",
    "gaffendes": "gaffend",
    "gaffest": "gaffen",
    "gaffet": "gaffen",
    "gaffst": "gaffen",
    "gafft": "gaffen",
    "gaffte": "gaffen",
    "gafften": "gaffen",
    "gafftest": "gaffen",
    "gafftet": "gaffen",
    "galaktische": "galaktisch",
    "galaktischem": "galaktisch",
    "galaktischen": "galaktisch",
    "galaktischer": "galaktisch",
    "galaktisches": "galaktisch",
    "galante": "galant",
    "galantem": "galant",
    "galanten": "galant",
    "galanter": "galant",
    "galantere": "galant",
    "galanterem": "galant",
    "galanteren": "galant",
    "galanterer": "galant",
    "galanteres": "galant",
    "galantes": "galant",
    "galanteste": "galant",
    "galantestem": "galant",
    "galantesten": "galant",
    "galantester": "galant",
    "galantestes": "galant",
    "galoppiere": "galoppieren",
    "galoppierend": "galoppieren",
    "galoppierende": "galoppierend",
    "galoppierendem": "galoppierend",
    "galoppierenden": "galoppierend",
    "galoppierender": "galoppierend",
    "galoppierendes": "galoppierend",
    "galoppierest": "galoppieren",
    "galoppieret": "galoppieren",
    "galoppierst": "galoppieren",
    "galoppiert": "galoppieren",
    "galoppierte": "galoppieren",
    "galoppiertem": "galoppiert",
    "galoppierten": "galoppieren",
    "galoppierter": "galoppiert",
    "galoppiertes": "galoppiert",
    "galoppiertest": "galoppieren",
    "galoppiertet": "galoppieren",
    "galt": "gelten",
    "galten": "gelten",
    "galtest": "gelten",
    "galtet": "gelten",
    "gammele": "gammeln",
    "gammelige": "gammelig",
    "gammeligem": "gammelig",
    "gammeligen": "gammelig",
    "gammeliger": "gammelig",
    "gammeligere": "gammelig",
    "gammeligerem": "gammelig",
    "gammeligeren": "gammelig",
    "gammeligerer": "gammelig",
    "gammeligeres": "gammelig",
    "gammeliges": "gammelig",
    "gammeligste": "gammelig",
    "gammeligstem": "gammelig",
    "gammeligsten": "gammelig",
    "gammeligster": "gammelig",
    "gammeligstes": "gammelig",
    "gammelnd": "gammeln",
    "gammelnde": "gammelnd",
    "gammelndem": "gammelnd",
    "gammelnden": "gammelnd",
    "gammelnder": "gammelnd",
    "gammelndere": "gammelnd",
    "gammelnderem": "gammelnd",
    "gammelnderen": "gammelnd",
    "gammelnderer": "gammelnd",
    "gammelnderes": "gammelnd",
    "gammelndes": "gammelnd",
    "gammelndste": "gammelnd",
    "gammelndstem": "gammelnd",
    "gammelndsten": "gammelnd",
    "gammelndster": "gammelnd",
    "gammelndstes": "gammelnd",
    "gammelst": "gammeln",
    "gammelt": "gammeln",
    "gammelte": "gammeln",
    "gammelten": "gammeln",
    "gammeltest": "gammeln",
    "gammeltet": "gammeln",
    "gammle": "gammeln",
    "gangbarem": "gangbar",
    "gangbaren": "gangbar",
    "gangbarer": "gangbar",
    "gangbares": "gangbar",
    "ganzem": "ganz",
    "ganzen": "ganz",
    "ganzer": "ganz",
    "ganzes": "ganz",
    "ganzheitliche": "ganzheitlich",
    "ganzheitlichem": "ganzheitlich",
    "ganzheitlichen": "ganzheitlich",
    "ganzheitlicher": "ganzheitlich",
    "ganzheitliches": "ganzheitlich",
    "ganzjährigem": "ganzjährig",
    "ganzjährigen": "ganzjährig",
    "ganzjähriger": "ganzjährig",
    "ganzjähriges": "ganzjährig",
    "ganztägige": "ganztägig",
    "ganztägigem": "ganztägig",
    "ganztägigen": "ganztägig",
    "ganztägiger": "ganztägig",
    "ganztägiges": "ganztägig",
    "ganztätige": "ganztätig",
    "ganztätigem": "ganztätig",
    "ganztätigen": "ganztätig",
    "ganztätiger": "ganztätig",
    "ganztätiges": "ganztätig",
    "garantiere": "garantieren",
    "garantierend": "garantieren",
    "garantierende": "garantierend",
    "garantierendem": "garantierend",
    "garantierenden": "garantierend",
    "garantierender": "garantierend",
    "garantierendes": "garantierend",
    "garantierest": "garantieren",
    "garantieret": "garantieren",
    "garantierst": "garantieren",
    "garantiert": "garantieren",
    "garantierte": "garantieren",
    "garantiertem": "garantiert",
    "garantierten": "garantieren",
    "garantierter": "garantiert",
    "garantiertes": "garantiert",
    "garantiertest": "garantieren",
    "garantiertet": "garantieren",
    "gare": "garen",
    "garend": "garen",
    "garende": "garend",
    "garendem": "garend",
    "garenden": "garend",
    "garender": "garend",
    "garendere": "garend",
    "garenderem": "garend",
    "garenderen": "garend",
    "garenderer": "garend",
    "garenderes": "garend",
    "garendes": "garend",
    "garendste": "garend",
    "garendstem": "garend",
    "garendsten": "garend",
    "garendster": "garend",
    "garendstes": "garend",
    "garest": "garen",
    "garet": "garen",
    "gargekocht": "garkochen",
    "gargekochte": "gargekocht",
    "gargekochtem": "gargekocht",
    "gargekochten": "gargekocht",
    "gargekochter": "gargekocht",
    "gargekochtere": "gargekocht",
    "gargekochterem": "gargekocht",
    "gargekochteren": "gargekocht",
    "gargekochterer": "gargekocht",
    "gargekochteres": "gargekocht",
    "gargekochtes": "gargekocht",
    "gargekochteste": "gargekocht",
    "gargekochtestem": "gargekocht",
    "gargekochtesten": "gargekocht",
    "gargekochtester": "gargekocht",
    "gargekochtestes": "gargekocht",
    "garkoche": "garkochen",
    "garkochend": "garkochen",
    "garkochende": "garkochend",
    "garkochendem": "garkochend",
    "garkochenden": "garkochend",
    "garkochender": "garkochend",
    "garkochendere": "garkochend",
    "garkochenderem": "garkochend",
    "garkochenderen": "garkochend",
    "garkochenderer": "garkochend",
    "garkochenderes": "garkochend",
    "garkochendes": "garkochend",
    "garkochendste": "garkochend",
    "garkochendstem": "garkochend",
    "garkochendsten": "garkochend",
    "garkochendster": "garkochend",
    "garkochendstes": "garkochend",
    "garkochest": "garkochen",
    "garkochet": "garkochen",
    "garkochst": "garkochen",
    "garkocht": "garkochen",
    "garkochte": "garkochen",
    "garkochten": "garkochen",
    "garkochtest": "garkochen",
    "garkochtet": "garkochen",
    "garniere": "garnieren",
    "garnierend": "garnieren",
    "garnierende": "garnierend",
    "garnierendem": "garnierend",
    "garnierenden": "garnierend",
    "garnierender": "garnierend",
    "garnierendere": "garnierend",
    "garnierenderem": "garnierend",
    "garnierenderen": "garnierend",
    "garnierenderer": "garnierend",
    "garnierenderes": "garnierend",
    "garnierendes": "garnierend",
    "garnierendste": "garnierend",
    "garnierendstem": "garnierend",
    "garnierendsten": "garnierend",
    "garnierendster": "garnierend",
    "garnierendstes": "garnierend",
    "garnierest": "garnieren",
    "garnieret": "garnieren",
    "garnierst": "garnieren",
    "garniert": "garnieren",
    "garnierte": "garnieren",
    "garniertem": "garniert",
    "garnierten": "garnieren",
    "garnierter": "garniert",
    "garniertere": "garniert",
    "garnierterem": "garniert",
    "garnierteren": "garniert",
    "garnierterer": "garniert",
    "garnierteres": "garniert",
    "garniertes": "garniert",
    "garniertest": "garnieren",
    "garnierteste": "garniert",
    "garniertestem": "garniert",
    "garniertesten": "garniert",
    "garniertester": "garniert",
    "garniertestes": "garniert",
    "garniertet": "garnieren",
    "garst": "garen",
    "gart": "garen",
    "garte": "garen",
    "garten": "garen",
    "gartest": "garen",
    "gartet": "garen",
    "garzukochen": "garkochen",
    "gasend": "gasen",
    "gasende": "gasend",
    "gasendem": "gasend",
    "gasenden": "gasend",
    "gasender": "gasend",
    "gasendes": "gasend",
    "gasest": "gasen",
    "gaset": "gasen",
    "gasförmigem": "gasförmig",
    "gasförmigen": "gasförmig",
    "gasförmiger": "gasförmig",
    "gasförmiges": "gasförmig",
    "gaste": "gasen",
    "gastechnischem": "gastechnisch",
    "gastechnischen": "gastechnisch",
    "gastechnischer": "gastechnisch",
    "gastechnisches": "gastechnisch",
    "gasten": "gasen",
    "gastest": "gasen",
    "gastet": "gasen",
    "gastfreundliche": "gastfreundlich",
    "gastfreundlichem": "gastfreundlich",
    "gastfreundlichen": "gastfreundlich",
    "gastfreundlicher": "gastfreundlich",
    "gastfreundlichere": "gastfreundlich",
    "gastfreundlicherem": "gastfreundlich",
    "gastfreundlicheren": "gastfreundlich",
    "gastfreundlicherer": "gastfreundlich",
    "gastfreundlicheres": "gastfreundlich",
    "gastfreundliches": "gastfreundlich",
    "gastfreundlichste": "gastfreundlich",
    "gastfreundlichstem": "gastfreundlich",
    "gastfreundlichsten": "gastfreundlich",
    "gastfreundlichster": "gastfreundlich",
    "gastfreundlichstes": "gastfreundlich",
    "gastiere": "gastieren",
    "gastierend": "gastieren",
    "gastierende": "gastierend",
    "gastierendem": "gastierend",
    "gastierenden": "gastierend",
    "gastierender": "gastierend",
    "gastierendes": "gastierend",
    "gastierest": "gastieren",
    "gastieret": "gastieren",
    "gastierst": "gastieren",
    "gastiert": "gastieren",
    "gastierte": "gastieren",
    "gastiertem": "gastiert",
    "gastierten": "gastieren",
    "gastierter": "gastiert",
    "gastiertes": "gastiert",
    "gastiertest": "gastieren",
    "gastiertet": "gastieren",
    "gastronomische": "gastronomisch",
    "gastronomischem": "gastronomisch",
    "gastronomischen": "gastronomisch",
    "gastronomischer": "gastronomisch",
    "gastronomisches": "gastronomisch",
    "gaukele": "gaukeln",
    "gaukelnd": "gaukeln",
    "gaukelnde": "gaukelnd",
    "gaukelndem": "gaukelnd",
    "gaukelnden": "gaukelnd",
    "gaukelnder": "gaukelnd",
    "gaukelndes": "gaukelnd",
    "gaukelst": "gaukeln",
    "gaukelt": "gaukeln",
    "gaukelte": "gaukeln",
    "gaukelten": "gaukeln",
    "gaukeltest": "gaukeln",
    "gaukeltet": "gaukeln",
    "gaukle": "gaukeln",
    "gaunere": "gaunern",
    "gaunernd": "gaunern",
    "gaunernde": "gaunernd",
    "gaunerndem": "gaunernd",
    "gaunernden": "gaunernd",
    "gaunernder": "gaunernd",
    "gaunerndere": "gaunernd",
    "gaunernderem": "gaunernd",
    "gaunernderen": "gaunernd",
    "gaunernderer": "gaunernd",
    "gaunernderes": "gaunernd",
    "gaunerndes": "gaunernd",
    "gaunerndste": "gaunernd",
    "gaunerndstem": "gaunernd",
    "gaunerndsten": "gaunernd",
    "gaunerndster": "gaunernd",
    "gaunerndstes": "gaunernd",
    "gaunerst": "gaunern",
    "gaunert": "gaunern",
    "gaunerte": "gaunern",
    "gaunerten": "gaunern",
    "gaunertest": "gaunern",
    "gaunertet": "gaunern",
    "geaalt": "aalen",
    "geaalte": "geaalt",
    "geaaltem": "geaalt",
    "geaalten": "geaalt",
    "geaalter": "geaalt",
    "geaaltes": "geaalt",
    "geachtet": "achten",
    "geachtete": "geachtet",
    "geachtetem": "geachtet",
    "geachteten": "geachtet",
    "geachteter": "geachtet",
    "geachtetere": "geachtet",
    "geachteterem": "geachtet",
    "geachteteren": "geachtet",
    "geachteterer": "geachtet",
    "geachteteres": "geachtet",
    "geachtetes": "geachtet",
    "geachteteste": "geachtet",
    "geachtetestem": "geachtet",
    "geachtetesten": "geachtet",
    "geachtetester": "geachtet",
    "geachtetestes": "geachtet",
    "geadelt": "adeln",
    "geadelte": "geadelt",
    "geadeltem": "geadelt",
    "geadelten": "geadelt",
    "geadelter": "geadelt",
    "geadeltes": "geadelt",
    "geahmt": "ahmen",
    "geahmte": "geahmt",
    "geahmtem": "geahmt",
    "geahmten": "geahmt",
    "geahmter": "geahmt",
    "geahmtes": "geahmt",
    "geahndet": "ahnden",
    "geahndete": "geahndet",
    "geahndetem": "geahndet",
    "geahndeten": "geahndet",
    "geahndeter": "geahndet",
    "geahndetere": "geahndet",
    "geahndeterem": "geahndet",
    "geahndeteren": "geahndet",
    "geahndeterer": "geahndet",
    "geahndeteres": "geahndet",
    "geahndetes": "geahndet",
    "geahndeteste": "geahndet",
    "geahndetestem": "geahndet",
    "geahndetesten": "geahndet",
    "geahndetester": "geahndet",
    "geahndetestes": "geahndet",
    "geahnt": "ahnen",
    "geahnte": "geahnt",
    "geahntem": "geahnt",
    "geahnten": "geahnt",
    "geahnter": "geahnt",
    "geahntes": "geahnt",
    "gealbert": "albern",
    "gealberte": "gealbert",
    "gealbertem": "gealbert",
    "gealberten": "gealbert",
    "gealberter": "gealbert",
    "gealbertes": "gealbert",
    "gealtert": "altern",
    "gealterte": "gealtert",
    "gealtertem": "gealtert",
    "gealterten": "gealtert",
    "gealterter": "gealtert",
    "gealtertere": "gealtert",
    "gealterterem": "gealtert",
    "gealterteren": "gealtert",
    "gealterterer": "gealtert",
    "gealterteres": "gealtert",
    "gealtertes": "gealtert",
    "gealterteste": "gealtert",
    "gealtertestem": "gealtert",
    "gealtertesten": "gealtert",
    "gealtertester": "gealtert",
    "gealtertestes": "gealtert",
    "geangelt": "angeln",
    "geangelte": "geangelt",
    "geangeltem": "geangelt",
    "geangelten": "geangelt",
    "geangelter": "geangelt",
    "geangeltes": "geangelt",
    "geankert": "ankern",
    "geankerte": "geankert",
    "geankertem": "geankert",
    "geankerten": "geankert",
    "geankerter": "geankert",
    "geankertes": "geankert",
    "geantwortet": "antworten",
    "geantwortete": "geantwortet",
    "geantwortetem": "geantwortet",
    "geantworteten": "geantwortet",
    "geantworteter": "geantwortet",
    "geantwortetes": "geantwortet",
    "gearbeitet": "arbeiten",
    "gearbeitete": "gearbeitet",
    "gearbeitetem": "gearbeitet",
    "gearbeiteten": "gearbeitet",
    "gearbeiteter": "gearbeitet",
    "gearbeitetes": "gearbeitet",
    "geargwöhnt": "argwöhnen",
    "geargwöhnte": "geargwöhnt",
    "geargwöhntem": "geargwöhnt",
    "geargwöhnten": "geargwöhnt",
    "geargwöhnter": "geargwöhnt",
    "geargwöhntes": "geargwöhnt",
    "geartet": "arten",
    "geartete": "geartet",
    "geartetem": "geartet",
    "gearteten": "geartet",
    "gearteter": "geartet",
    "geartetes": "geartet",
    "geatmet": "atmen",
    "geatmete": "geatmet",
    "geatmetem": "geatmet",
    "geatmeten": "geatmet",
    "geatmeter": "geatmet",
    "geatmetes": "geatmet",
    "gebacken": "backen",
    "gebackenem": "gebacken",
    "gebackenen": "gebacken",
    "gebackener": "gebacken",
    "gebackenes": "gebacken",
    "gebadet": "baden",
    "gebadete": "gebadet",
    "gebadetem": "gebadet",
    "gebadeten": "gebadet",
    "gebadeter": "gebadet",
    "gebadetes": "gebadet",
    "gebaggert": "baggern",
    "gebaggerte": "gebaggert",
    "gebaggertem": "gebaggert",
    "gebaggerten": "gebaggert",
    "gebaggerter": "gebaggert",
    "gebaggertes": "gebaggert",
    "gebahnt": "bahnen",
    "gebahnte": "gebahnt",
    "gebahntem": "gebahnt",
    "gebahnten": "gebahnt",
    "gebahnter": "gebahnt",
    "gebahntes": "gebahnt",
    "gebahrt": "bahren",
    "gebahrte": "gebahrt",
    "gebahrtem": "gebahrt",
    "gebahrten": "gebahrt",
    "gebahrter": "gebahrt",
    "gebahrtes": "gebahrt",
    "gebalgt": "balgen",
    "gebalgte": "gebalgt",
    "gebalgtem": "gebalgt",
    "gebalgten": "gebalgt",
    "gebalgter": "gebalgt",
    "gebalgtes": "gebalgt",
    "geballert": "ballern",
    "geballerte": "geballert",
    "geballertem": "geballert",
    "geballerten": "geballert",
    "geballerter": "geballert",
    "geballertes": "geballert",
    "geballt": "ballen",
    "geballte": "geballt",
    "geballtem": "geballt",
    "geballten": "geballt",
    "geballter": "geballt",
    "geballtere": "geballt",
    "geballterem": "geballt",
    "geballteren": "geballt",
    "geballterer": "geballt",
    "geballteres": "geballt",
    "geballtes": "geballt",
    "geballteste": "geballt",
    "geballtestem": "geballt",
    "geballtesten": "geballt",
    "geballtester": "geballt",
    "geballtestes": "geballt",
    "gebalzt": "balzen",
    "gebalzte": "gebalzt",
    "gebalztem": "gebalzt",
    "gebalzten": "gebalzt",
    "gebalzter": "gebalzt",
    "gebalztes": "gebalzt",
    "gebandelt": "bandeln",
    "gebandelte": "gebandelt",
    "gebandeltem": "gebandelt",
    "gebandelten": "gebandelt",
    "gebandelter": "gebandelt",
    "gebandeltes": "gebandelt",
    "gebangt": "bangen",
    "gebangte": "gebangt",
    "gebangtem": "gebangt",
    "gebangten": "gebangt",
    "gebangter": "gebangt",
    "gebangtes": "gebangt",
    "gebannt": "bannen",
    "gebannte": "gebannt",
    "gebanntem": "gebannt",
    "gebannten": "gebannt",
    "gebannter": "gebannt",
    "gebanntere": "gebannt",
    "gebannterem": "gebannt",
    "gebannteren": "gebannt",
    "gebannterer": "gebannt",
    "gebannteres": "gebannt",
    "gebanntes": "gebannt",
    "gebannteste": "gebannt",
    "gebanntestem": "gebannt",
    "gebanntesten": "gebannt",
    "gebanntester": "gebannt",
    "gebanntestes": "gebannt",
    "gebar": "gebären",
    "gebaren": "gebären",
    "gebarrt": "barren",
    "gebarrte": "gebarrt",
    "gebarrtem": "gebarrt",
    "gebarrten": "gebarrt",
    "gebarrter": "gebarrt",
    "gebarrtere": "gebarrt",
    "gebarrterem": "gebarrt",
    "gebarrteren": "gebarrt",
    "gebarrterer": "gebarrt",
    "gebarrteres": "gebarrt",
    "gebarrtes": "gebarrt",
    "gebarrteste": "gebarrt",
    "gebarrtestem": "gebarrt",
    "gebarrtesten": "gebarrt",
    "gebarrtester": "gebarrt",
    "gebarrtestes": "gebarrt",
    "gebarst": "gebären",
    "gebart": "gebären",
    "gebastelt": "basteln",
    "gebastelte": "gebastelt",
    "gebasteltem": "gebastelt",
    "gebastelten": "gebastelt",
    "gebastelter": "gebastelt",
    "gebasteltes": "gebastelt",
    "gebauchredet": "bauchreden",
    "gebauchredete": "gebauchredet",
    "gebauchredetem": "gebauchredet",
    "gebauchredeten": "gebauchredet",
    "gebauchredeter": "gebauchredet",
    "gebauchredetes": "gebauchredet",
    "gebaucht": "bauchen",
    "gebauchte": "gebaucht",
    "gebauchtem": "gebaucht",
    "gebauchten": "gebaucht",
    "gebauchter": "gebaucht",
    "gebauchtere": "gebaucht",
    "gebauchterem": "gebaucht",
    "gebauchteren": "gebaucht",
    "gebauchterer": "gebaucht",
    "gebauchteres": "gebaucht",
    "gebauchtes": "gebaucht",
    "gebauchteste": "gebaucht",
    "gebauchtestem": "gebaucht",
    "gebauchtesten": "gebaucht",
    "gebauchtester": "gebaucht",
    "gebauchtestes": "gebaucht",
    "gebaumelt": "baumeln",
    "gebaumelte": "gebaumelt",
    "gebaumeltem": "gebaumelt",
    "gebaumelten": "gebaumelt",
    "gebaumelter": "gebaumelt",
    "gebaumeltes": "gebaumelt",
    "gebauscht": "bauschen",
    "gebauschte": "gebauscht",
    "gebauschtem": "gebauscht",
    "gebauschten": "gebauscht",
    "gebauschter": "gebauscht",
    "gebauschtes": "gebauscht",
    "gebauspart": "bausparen",
    "gebausparte": "gebauspart",
    "gebauspartem": "gebauspart",
    "gebausparten": "gebauspart",
    "gebausparter": "gebauspart",
    "gebauspartes": "gebauspart",
    "gebaut": "bauen",
    "gebaute": "gebaut",
    "gebautem": "gebaut",
    "gebauten": "gebaut",
    "gebauter": "gebaut",
    "gebautes": "gebaut",
    "gebe": "geben",
    "gebebt": "beben",
    "gebebte": "gebebt",
    "gebebtem": "gebebt",
    "gebebten": "gebebt",
    "gebebter": "gebebt",
    "gebebtes": "gebebt",
    "gebechert": "bechern",
    "gebecherte": "gebechert",
    "gebechertem": "gebechert",
    "gebecherten": "gebechert",
    "gebecherter": "gebechert",
    "gebechertes": "gebechert",
    "gebeichtet": "beichten",
    "gebeichtete": "gebeichtet",
    "gebeichtetem": "gebeichtet",
    "gebeichteten": "gebeichtet",
    "gebeichteter": "gebeichtet",
    "gebeichtetes": "gebeichtet",
    "gebeizt": "beizen",
    "gebeizte": "gebeizt",
    "gebeiztem": "gebeizt",
    "gebeizten": "gebeizt",
    "gebeizter": "gebeizt",
    "gebeiztes": "gebeizt",
    "gebellt": "bellen",
    "gebellte": "gebellt",
    "gebelltem": "gebellt",
    "gebellten": "gebellt",
    "gebellter": "gebellt",
    "gebelltes": "gebellt",
    "gebend": "geben",
    "gebende": "gebend",
    "gebendem": "gebend",
    "gebenden": "gebend",
    "gebender": "gebend",
    "gebendes": "gebend",
    "gebessert": "bessern",
    "gebesserte": "gebessert",
    "gebessertem": "gebessert",
    "gebesserten": "gebessert",
    "gebesserter": "gebessert",
    "gebessertes": "gebessert",
    "gebest": "geben",
    "gebet": "geben",
    "gebetenem": "gebeten",
    "gebetenen": "gebeten",
    "gebetener": "gebeten",
    "gebetenere": "gebeten",
    "gebetenerem": "gebeten",
    "gebeteneren": "gebeten",
    "gebetenerer": "gebeten",
    "gebeteneres": "gebeten",
    "gebetenes": "gebeten",
    "gebetenste": "gebeten",
    "gebetenstem": "gebeten",
    "gebetensten": "gebeten",
    "gebetenster": "gebeten",
    "gebetenstes": "gebeten",
    "gebetet": "beten",
    "gebetete": "gebetet",
    "gebetetem": "gebetet",
    "gebeteten": "gebetet",
    "gebeteter": "gebetet",
    "gebetetes": "gebetet",
    "gebettelt": "betteln",
    "gebettelte": "gebettelt",
    "gebetteltem": "gebettelt",
    "gebettelten": "gebettelt",
    "gebettelter": "gebettelt",
    "gebetteltes": "gebettelt",
    "gebettet": "betten",
    "gebettete": "gebettet",
    "gebettetem": "gebettet",
    "gebetteten": "gebettet",
    "gebetteter": "gebettet",
    "gebettetes": "gebettet",
    "gebeugt": "beugen",
    "gebeugte": "gebeugt",
    "gebeugtem": "gebeugt",
    "gebeugten": "gebeugt",
    "gebeugter": "gebeugt",
    "gebeugtere": "gebeugt",
    "gebeugterem": "gebeugt",
    "gebeugteren": "gebeugt",
    "gebeugterer": "gebeugt",
    "gebeugteres": "gebeugt",
    "gebeugtes": "gebeugt",
    "gebeugteste": "gebeugt",
    "gebeugtestem": "gebeugt",
    "gebeugtesten": "gebeugt",
    "gebeugtester": "gebeugt",
    "gebeugtestes": "gebeugt",
    "gebeult": "beulen",
    "gebeulte": "gebeult",
    "gebeultem": "gebeult",
    "gebeulten": "gebeult",
    "gebeulter": "gebeult",
    "gebeultes": "gebeult",
    "gebeutelt": "beuteln",
    "gebeutelte": "gebeutelt",
    "gebeuteltem": "gebeutelt",
    "gebeutelten": "gebeutelt",
    "gebeutelter": "gebeutelt",
    "gebeuteltes": "gebeutelt",
    "gebeutet": "beuten",
    "gebeutete": "gebeutet",
    "gebeutetem": "gebeutet",
    "gebeuteten": "gebeutet",
    "gebeuteter": "gebeutet",
    "gebeutetes": "gebeutet",
    "gebibbert": "bibbern",
    "gebibberte": "gebibbert",
    "gebibbertem": "gebibbert",
    "gebibberten": "gebibbert",
    "gebibberter": "gebibbert",
    "gebibbertes": "gebibbert",
    "gebiedert": "biedern",
    "gebiederte": "gebiedert",
    "gebiedertem": "gebiedert",
    "gebiederten": "gebiedert",
    "gebiederter": "gebiedert",
    "gebiedertes": "gebiedert",
    "gebietend": "gebieten",
    "gebietende": "gebietend",
    "gebietendem": "gebietend",
    "gebietenden": "gebietend",
    "gebietender": "gebietend",
    "gebietendes": "gebietend",
    "gebieterischem": "gebieterisch",
    "gebieterischen": "gebieterisch",
    "gebieterischer": "gebieterisch",
    "gebieterisches": "gebieterisch",
    "gebietest": "gebieten",
    "gebietet": "gebieten",
    "gebildet": "bilden",
    "gebildete": "gebildet",
    "gebildetem": "gebildet",
    "gebildeten": "gebildet",
    "gebildeter": "gebildet",
    "gebildetere": "gebildet",
    "gebildeterem": "gebildet",
    "gebildeteren": "gebildet",
    "gebildeterer": "gebildet",
    "gebildeteres": "gebildet",
    "gebildetes": "gebildet",
    "gebildeteste": "gebildet",
    "gebildetestem": "gebildet",
    "gebildetesten": "gebildet",
    "gebildetester": "gebildet",
    "gebildetestes": "gebildet",
    "gebildhauert": "bildhauern",
    "gebildhauerte": "gebildhauert",
    "gebildhauertem": "gebildhauert",
    "gebildhauerten": "gebildhauert",
    "gebildhauerter": "gebildhauert",
    "gebildhauertes": "gebildhauert",
    "gebilligt": "billigen",
    "gebilligte": "gebilligt",
    "gebilligtem": "gebilligt",
    "gebilligten": "gebilligt",
    "gebilligter": "gebilligt",
    "gebilligtes": "gebilligt",
    "gebimmelt": "bimmeln",
    "gebimmelte": "gebimmelt",
    "gebimmeltem": "gebimmelt",
    "gebimmelten": "gebimmelt",
    "gebimmelter": "gebimmelt",
    "gebimmeltes": "gebimmelt",
    "gebimst": "bimsen",
    "gebimste": "gebimst",
    "gebimstem": "gebimst",
    "gebimsten": "gebimst",
    "gebimster": "gebimst",
    "gebimstere": "gebimst",
    "gebimsterem": "gebimst",
    "gebimsteren": "gebimst",
    "gebimsterer": "gebimst",
    "gebimsteres": "gebimst",
    "gebimstes": "gebimst",
    "gebimsteste": "gebimst",
    "gebimstestem": "gebimst",
    "gebimstesten": "gebimst",
    "gebimstester": "gebimst",
    "gebimstestes": "gebimst",
    "gebirgigem": "gebirgig",
    "gebirgigen": "gebirgig",
    "gebirgiger": "gebirgig",
    "gebirgigere": "gebirgig",
    "gebirgigerem": "gebirgig",
    "gebirgigeren": "gebirgig",
    "gebirgigerer": "gebirgig",
    "gebirgigeres": "gebirgig",
    "gebirgiges": "gebirgig",
    "gebirgigste": "gebirgig",
    "gebirgigstem": "gebirgig",
    "gebirgigsten": "gebirgig",
    "gebirgigster": "gebirgig",
    "gebirgigstes": "gebirgig",
    "gebissenem": "gebissen",
    "gebissenen": "gebissen",
    "gebissener": "gebissen",
    "gebissenere": "gebissen",
    "gebissenerem": "gebissen",
    "gebisseneren": "gebissen",
    "gebissenerer": "gebissen",
    "gebisseneres": "gebissen",
    "gebissenes": "gebissen",
    "gebissenste": "gebissen",
    "gebissenstem": "gebissen",
    "gebissensten": "gebissen",
    "gebissenster": "gebissen",
    "gebissenstes": "gebissen",
    "geblafft": "blaffen",
    "geblaffte": "geblafft",
    "geblafftem": "geblafft",
    "geblafften": "geblafft",
    "geblaffter": "geblafft",
    "geblafftes": "geblafft",
    "geblasen": "blasen",
    "geblasenem": "geblasen",
    "geblasenen": "geblasen",
    "geblasener": "geblasen",
    "geblasenes": "geblasen",
    "geblaßt": "blassen",
    "geblaßte": "geblaßt",
    "geblaßtem": "geblaßt",
    "geblaßten": "geblaßt",
    "geblaßter": "geblaßt",
    "geblaßtes": "geblaßt",
    "geblecht": "blechen",
    "geblechte": "geblecht",
    "geblechtem": "geblecht",
    "geblechten": "geblecht",
    "geblechter": "geblecht",
    "geblechtes": "geblecht",
    "geblendet": "blenden",
    "geblendete": "geblendet",
    "geblendetem": "geblendet",
    "geblendeten": "geblendet",
    "geblendeter": "geblendet",
    "geblendetere": "geblendet",
    "geblendeterem": "geblendet",
    "geblendeteren": "geblendet",
    "geblendeterer": "geblendet",
    "geblendeteres": "geblendet",
    "geblendetes": "geblendet",
    "geblendeteste": "geblendet",
    "geblendetestem": "geblendet",
    "geblendetesten": "geblendet",
    "geblendetester": "geblendet",
    "geblendetestes": "geblendet",
    "gebleut": "bleuen",
    "gebleute": "gebleut",
    "gebleutem": "gebleut",
    "gebleuten": "gebleut",
    "gebleuter": "gebleut",
    "gebleutes": "gebleut",
    "geblichen": "bleichen",
    "geblichene": "geblichen",
    "geblichenem": "geblichen",
    "geblichenen": "geblichen",
    "geblichener": "geblichen",
    "geblichenere": "geblichen",
    "geblichenerem": "geblichen",
    "geblicheneren": "geblichen",
    "geblichenerer": "geblichen",
    "geblicheneres": "geblichen",
    "geblichenes": "geblichen",
    "geblichenste": "geblichen",
    "geblichenstem": "geblichen",
    "geblichensten": "geblichen",
    "geblichenster": "geblichen",
    "geblichenstes": "geblichen",
    "geblickt": "blicken",
    "geblickte": "geblickt",
    "geblicktem": "geblickt",
    "geblickten": "geblickt",
    "geblickter": "geblickt",
    "geblicktes": "geblickt",
    "geblieben": "bleiben",
    "gebliebene": "geblieben",
    "gebliebenem": "geblieben",
    "gebliebenen": "geblieben",
    "gebliebener": "geblieben",
    "gebliebenes": "geblieben",
    "geblinkt": "blinken",
    "geblinkte": "geblinkt",
    "geblinktem": "geblinkt",
    "geblinkten": "geblinkt",
    "geblinkter": "geblinkt",
    "geblinktes": "geblinkt",
    "geblinzelt": "blinzeln",
    "geblinzelte": "geblinzelt",
    "geblinzeltem": "geblinzelt",
    "geblinzelten": "geblinzelt",
    "geblinzelter": "geblinzelt",
    "geblinzeltes": "geblinzelt",
    "geblitzt": "blitzen",
    "geblitzte": "geblitzt",
    "geblitztem": "geblitzt",
    "geblitzten": "geblitzt",
    "geblitzter": "geblitzt",
    "geblitztes": "geblitzt",
    "geblubbert": "blubbern",
    "geblubberte": "geblubbert",
    "geblubbertem": "geblubbert",
    "geblubberten": "geblubbert",
    "geblubberter": "geblubbert",
    "geblubbertes": "geblubbert",
    "geblutet": "bluten",
    "geblutete": "geblutet",
    "geblutetem": "geblutet",
    "gebluteten": "geblutet",
    "gebluteter": "geblutet",
    "geblutetes": "geblutet",
    "gebläht": "blähen",
    "geblähte": "gebläht",
    "geblähtem": "gebläht",
    "geblähten": "gebläht",
    "geblähter": "gebläht",
    "geblähtere": "gebläht",
    "geblähterem": "gebläht",
    "geblähteren": "gebläht",
    "geblähterer": "gebläht",
    "geblähteres": "gebläht",
    "geblähtes": "gebläht",
    "geblähteste": "gebläht",
    "geblähtestem": "gebläht",
    "geblähtesten": "gebläht",
    "geblähtester": "gebläht",
    "geblähtestes": "gebläht",
    "geblättert": "blättern",
    "geblätterte": "geblättert",
    "geblättertem": "geblättert",
    "geblätterten": "geblättert",
    "geblätterter": "geblättert",
    "geblättertes": "geblättert",
    "gebläut": "bläuen",
    "gebläute": "gebläut",
    "gebläutem": "gebläut",
    "gebläuten": "gebläut",
    "gebläuter": "gebläut",
    "gebläutes": "gebläut",
    "geblödelt": "blödeln",
    "geblödelte": "geblödelt",
    "geblödeltem": "geblödelt",
    "geblödelten": "geblödelt",
    "geblödelter": "geblödelt",
    "geblödeltes": "geblödelt",
    "geblökt": "blöken",
    "geblökte": "geblökt",
    "geblöktem": "geblökt",
    "geblökten": "geblökt",
    "geblökter": "geblökt",
    "geblöktes": "geblökt",
    "geblüht": "blühen",
    "geblühte": "geblüht",
    "geblühtem": "geblüht",
    "geblühten": "geblüht",
    "geblühter": "geblüht",
    "geblühtes": "geblüht",
    "geblümte": "geblümt",
    "geblümtem": "geblümt",
    "geblümten": "geblümt",
    "geblümter": "geblümt",
    "geblümtere": "geblümt",
    "geblümterem": "geblümt",
    "geblümteren": "geblümt",
    "geblümterer": "geblümt",
    "geblümteres": "geblümt",
    "geblümtes": "geblümt",
    "geblümteste": "geblümt",
    "geblümtestem": "geblümt",
    "geblümtesten": "geblümt",
    "geblümtester": "geblümt",
    "geblümtestes": "geblümt",
    "gebogen": "biegen",
    "gebogene": "gebogen",
    "gebogenem": "gebogen",
    "gebogenen": "gebogen",
    "gebogener": "gebogen",
    "gebogenere": "gebogen",
    "gebogenerem": "gebogen",
    "gebogeneren": "gebogen",
    "gebogenerer": "gebogen",
    "gebogeneres": "gebogen",
    "gebogenes": "gebogen",
    "gebogenste": "gebogen",
    "gebogenstem": "gebogen",
    "gebogensten": "gebogen",
    "gebogenster": "gebogen",
    "gebogenstes": "gebogen",
    "gebohnert": "bohnern",
    "gebohnerte": "gebohnert",
    "gebohnertem": "gebohnert",
    "gebohnerten": "gebohnert",
    "gebohnerter": "gebohnert",
    "gebohnertere": "gebohnert",
    "gebohnerterem": "gebohnert",
    "gebohnerteren": "gebohnert",
    "gebohnerterer": "gebohnert",
    "gebohnerteres": "gebohnert",
    "gebohnertes": "gebohnert",
    "gebohnerteste": "gebohnert",
    "gebohnertestem": "gebohnert",
    "gebohnertesten": "gebohnert",
    "gebohnertester": "gebohnert",
    "gebohnertestes": "gebohnert",
    "gebohrt": "bohren",
    "gebohrte": "gebohrt",
    "gebohrtem": "gebohrt",
    "gebohrten": "gebohrt",
    "gebohrter": "gebohrt",
    "gebohrtes": "gebohrt",
    "gebolzt": "bolzen",
    "gebolzte": "gebolzt",
    "gebolztem": "gebolzt",
    "gebolzten": "gebolzt",
    "gebolzter": "gebolzt",
    "gebolztes": "gebolzt",
    "gebombt": "bomben",
    "gebombte": "gebombt",
    "gebombtem": "gebombt",
    "gebombten": "gebombt",
    "gebombter": "gebombt",
    "gebombtes": "gebombt",
    "geboomt": "boomen",
    "geboomte": "geboomt",
    "geboomtem": "geboomt",
    "geboomten": "geboomt",
    "geboomter": "geboomt",
    "geboomtes": "geboomt",
    "gebootet": "booten",
    "gebootete": "gebootet",
    "gebootetem": "gebootet",
    "gebooteten": "gebootet",
    "gebooteter": "gebootet",
    "gebootetes": "gebootet",
    "geboren": "gebären",
    "geborene": "geboren",
    "geborenem": "geboren",
    "geborenen": "geboren",
    "geborener": "geboren",
    "geborenes": "geboren",
    "geborgen": "bergen",
    "geborgene": "geborgen",
    "geborgenem": "geborgen",
    "geborgenen": "geborgen",
    "geborgener": "geborgen",
    "geborgenere": "geborgen",
    "geborgenerem": "geborgen",
    "geborgeneren": "geborgen",
    "geborgenerer": "geborgen",
    "geborgeneres": "geborgen",
    "geborgenes": "geborgen",
    "geborgenste": "geborgen",
    "geborgenstem": "geborgen",
    "geborgensten": "geborgen",
    "geborgenster": "geborgen",
    "geborgenstes": "geborgen",
    "geborgt": "borgen",
    "geborgte": "geborgt",
    "geborgtem": "geborgt",
    "geborgten": "geborgt",
    "geborgter": "geborgt",
    "geborgtes": "geborgt",
    "geborsten": "bersten",
    "geborstene": "geborsten",
    "geborstenem": "geborsten",
    "geborstenen": "geborsten",
    "geborstener": "geborsten",
    "geborstenes": "geborsten",
    "gebot": "gebieten",
    "geboten": "bieten",
    "gebotene": "geboten",
    "gebotenem": "geboten",
    "gebotenen": "geboten",
    "gebotener": "geboten",
    "gebotenes": "geboten",
    "gebotest": "gebieten",
    "gebotet": "gebieten",
    "geboxt": "boxen",
    "geboxte": "geboxt",
    "geboxtem": "geboxt",
    "geboxten": "geboxt",
    "geboxter": "geboxt",
    "geboxtes": "geboxt",
    "gebrabbelt": "brabbeln",
    "gebrabbelte": "gebrabbelt",
    "gebrabbeltem": "gebrabbelt",
    "gebrabbelten": "gebrabbelt",
    "gebrabbelter": "gebrabbelt",
    "gebrabbeltes": "gebrabbelt",
    "gebracht": "bringen",
    "gebrachte": "gebracht",
    "gebrachtem": "gebracht",
    "gebrachten": "gebracht",
    "gebrachter": "gebracht",
    "gebrachtes": "gebracht",
    "gebrandet": "branden",
    "gebrandete": "gebrandet",
    "gebrandetem": "gebrandet",
    "gebrandeten": "gebrandet",
    "gebrandeter": "gebrandet",
    "gebrandetes": "gebrandet",
    "gebrandmarkt": "brandmarken",
    "gebrandmarkte": "gebrandmarkt",
    "gebrandmarktem": "gebrandmarkt",
    "gebrandmarkten": "gebrandmarkt",
    "gebrandmarkter": "gebrandmarkt",
    "gebrandmarktere": "gebrandmarkt",
    "gebrandmarkterem": "gebrandmarkt",
    "gebrandmarkteren": "gebrandmarkt",
    "gebrandmarkterer": "gebrandmarkt",
    "gebrandmarkteres": "gebrandmarkt",
    "gebrandmarktes": "gebrandmarkt",
    "gebrandmarkteste": "gebrandmarkt",
    "gebrandmarktestem": "gebrandmarkt",
    "gebrandmarktesten": "gebrandmarkt",
    "gebrandmarktester": "gebrandmarkt",
    "gebrandmarktestes": "gebrandmarkt",
    "gebrannt": "brennen",
    "gebrannte": "gebrannt",
    "gebranntem": "gebrannt",
    "gebrannten": "gebrannt",
    "gebrannter": "gebrannt",
    "gebranntes": "gebrannt",
    "gebraten": "braten",
    "gebratene": "gebraten",
    "gebratenem": "gebraten",
    "gebratenen": "gebraten",
    "gebratener": "gebraten",
    "gebratenere": "gebraten",
    "gebratenerem": "gebraten",
    "gebrateneren": "gebraten",
    "gebratenerer": "gebraten",
    "gebrateneres": "gebraten",
    "gebratenes": "gebraten",
    "gebratenste": "gebraten",
    "gebratenstem": "gebraten",
    "gebratensten": "gebraten",
    "gebratenster": "gebraten",
    "gebratenstes": "gebraten",
    "gebrauche": "gebrauchen",
    "gebrauchend": "gebrauchen",
    "gebrauchende": "gebrauchend",
    "gebrauchendem": "gebrauchend",
    "gebrauchenden": "gebrauchend",
    "gebrauchender": "gebrauchend",
    "gebrauchendes": "gebrauchend",
    "gebrauchest": "gebrauchen",
    "gebrauchet": "gebrauchen",
    "gebrauchsfertige": "gebrauchsfertig",
    "gebrauchsfertigem": "gebrauchsfertig",
    "gebrauchsfertigen": "gebrauchsfertig",
    "gebrauchsfertiger": "gebrauchsfertig",
    "gebrauchsfertigere": "gebrauchsfertig",
    "gebrauchsfertigerem": "gebrauchsfertig",
    "gebrauchsfertigeren": "gebrauchsfertig",
    "gebrauchsfertigerer": "gebrauchsfertig",
    "gebrauchsfertigeres": "gebrauchsfertig",
    "gebrauchsfertiges": "gebrauchsfertig",
    "gebrauchsfertigste": "gebrauchsfertig",
    "gebrauchsfertigstem": "gebrauchsfertig",
    "gebrauchsfertigsten": "gebrauchsfertig",
    "gebrauchsfertigster": "gebrauchsfertig",
    "gebrauchsfertigstes": "gebrauchsfertig",
    "gebrauchsfähigem": "gebrauchsfähig",
    "gebrauchsfähigen": "gebrauchsfähig",
    "gebrauchsfähiger": "gebrauchsfähig",
    "gebrauchsfähigere": "gebrauchsfähig",
    "gebrauchsfähigerem": "gebrauchsfähig",
    "gebrauchsfähigeren": "gebrauchsfähig",
    "gebrauchsfähigerer": "gebrauchsfähig",
    "gebrauchsfähigeres": "gebrauchsfähig",
    "gebrauchsfähiges": "gebrauchsfähig",
    "gebrauchsfähigste": "gebrauchsfähig",
    "gebrauchsfähigstem": "gebrauchsfähig",
    "gebrauchsfähigsten": "gebrauchsfähig",
    "gebrauchsfähigster": "gebrauchsfähig",
    "gebrauchsfähigstes": "gebrauchsfähig",
    "gebrauchst": "gebrauchen",
    "gebraucht": "gebrauchen",
    "gebrauchte": "gebrauchen",
    "gebrauchtem": "gebraucht",
    "gebrauchten": "gebrauchen",
    "gebrauchter": "gebraucht",
    "gebrauchtes": "gebraucht",
    "gebrauchtest": "gebrauchen",
    "gebrauchtet": "gebrauchen",
    "gebraust": "brausen",
    "gebrauste": "gebraust",
    "gebraustem": "gebraust",
    "gebrausten": "gebraust",
    "gebrauster": "gebraust",
    "gebraustes": "gebraust",
    "gebraut": "brauen",
    "gebraute": "gebraut",
    "gebrautem": "gebraut",
    "gebrauten": "gebraut",
    "gebrauter": "gebraut",
    "gebrautes": "gebraut",
    "gebrechlichem": "gebrechlich",
    "gebrechlichen": "gebrechlich",
    "gebrechlicher": "gebrechlich",
    "gebrechlichere": "gebrechlich",
    "gebrechlicherem": "gebrechlich",
    "gebrechlicheren": "gebrechlich",
    "gebrechlicherer": "gebrechlich",
    "gebrechlicheres": "gebrechlich",
    "gebrechliches": "gebrechlich",
    "gebrechlichste": "gebrechlich",
    "gebrechlichstem": "gebrechlich",
    "gebrechlichsten": "gebrechlich",
    "gebrechlichster": "gebrechlich",
    "gebrechlichstes": "gebrechlich",
    "gebreitet": "breiten",
    "gebreitete": "gebreitet",
    "gebreitetem": "gebreitet",
    "gebreiteten": "gebreitet",
    "gebreiteter": "gebreitet",
    "gebreitetes": "gebreitet",
    "gebremst": "bremsen",
    "gebremste": "gebremst",
    "gebremstem": "gebremst",
    "gebremsten": "gebremst",
    "gebremster": "gebremst",
    "gebremstes": "gebremst",
    "gebrochen": "brechen",
    "gebrochene": "gebrochen",
    "gebrochenem": "gebrochen",
    "gebrochenen": "gebrochen",
    "gebrochener": "gebrochen",
    "gebrochenere": "gebrochen",
    "gebrochenerem": "gebrochen",
    "gebrocheneren": "gebrochen",
    "gebrochenerer": "gebrochen",
    "gebrocheneres": "gebrochen",
    "gebrochenes": "gebrochen",
    "gebrochenste": "gebrochen",
    "gebrochenstem": "gebrochen",
    "gebrochensten": "gebrochen",
    "gebrochenster": "gebrochen",
    "gebrochenstes": "gebrochen",
    "gebrodelt": "brodeln",
    "gebrodelte": "gebrodelt",
    "gebrodeltem": "gebrodelt",
    "gebrodelten": "gebrodelt",
    "gebrodelter": "gebrodelt",
    "gebrodeltes": "gebrodelt",
    "gebrummt": "brummen",
    "gebrummte": "gebrummt",
    "gebrummtem": "gebrummt",
    "gebrummten": "gebrummt",
    "gebrummter": "gebrummt",
    "gebrummtes": "gebrummt",
    "gebrutzelt": "brutzeln",
    "gebrutzelte": "gebrutzelt",
    "gebrutzeltem": "gebrutzelt",
    "gebrutzelten": "gebrutzelt",
    "gebrutzelter": "gebrutzelt",
    "gebrutzeltes": "gebrutzelt",
    "gebräuchliche": "gebräuchlich",
    "gebräuchlichem": "gebräuchlich",
    "gebräuchlichen": "gebräuchlich",
    "gebräuchlicher": "gebräuchlich",
    "gebräuchlichere": "gebräuchlich",
    "gebräuchlicherem": "gebräuchlich",
    "gebräuchlicheren": "gebräuchlich",
    "gebräuchlicherer": "gebräuchlich",
    "gebräuchlicheres": "gebräuchlich",
    "gebräuchliches": "gebräuchlich",
    "gebräuchlichste": "gebräuchlich",
    "gebräuchlichstem": "gebräuchlich",
    "gebräuchlichsten": "gebräuchlich",
    "gebräuchlichster": "gebräuchlich",
    "gebräuchlichstes": "gebräuchlich",
    "gebröckelt": "bröckeln",
    "gebröckelte": "gebröckelt",
    "gebröckeltem": "gebröckelt",
    "gebröckelten": "gebröckelt",
    "gebröckelter": "gebröckelt",
    "gebröckeltere": "gebröckelt",
    "gebröckelterem": "gebröckelt",
    "gebröckelteren": "gebröckelt",
    "gebröckelterer": "gebröckelt",
    "gebröckelteres": "gebröckelt",
    "gebröckeltes": "gebröckelt",
    "gebröckelteste": "gebröckelt",
    "gebröckeltestem": "gebröckelt",
    "gebröckeltesten": "gebröckelt",
    "gebröckeltester": "gebröckelt",
    "gebröckeltestes": "gebröckelt",
    "gebrüht": "brühen",
    "gebrühte": "gebrüht",
    "gebrühtem": "gebrüht",
    "gebrühten": "gebrüht",
    "gebrühter": "gebrüht",
    "gebrühtere": "gebrüht",
    "gebrühterem": "gebrüht",
    "gebrühteren": "gebrüht",
    "gebrühterer": "gebrüht",
    "gebrühteres": "gebrüht",
    "gebrühtes": "gebrüht",
    "gebrühteste": "gebrüht",
    "gebrühtestem": "gebrüht",
    "gebrühtesten": "gebrüht",
    "gebrühtester": "gebrüht",
    "gebrühtestes": "gebrüht",
    "gebrüllt": "brüllen",
    "gebrüllte": "gebrüllt",
    "gebrülltem": "gebrüllt",
    "gebrüllten": "gebrüllt",
    "gebrüllter": "gebrüllt",
    "gebrülltes": "gebrüllt",
    "gebrüstet": "brüsten",
    "gebrüstete": "gebrüstet",
    "gebrüstetem": "gebrüstet",
    "gebrüsteten": "gebrüstet",
    "gebrüsteter": "gebrüstet",
    "gebrüstetes": "gebrüstet",
    "gebrütet": "brüten",
    "gebrütete": "gebrütet",
    "gebrütetem": "gebrütet",
    "gebrüteten": "gebrütet",
    "gebrüteter": "gebrütet",
    "gebrütetere": "gebrütet",
    "gebrüteterem": "gebrütet",
    "gebrüteteren": "gebrütet",
    "gebrüteterer": "gebrütet",
    "gebrüteteres": "gebrütet",
    "gebrütetes": "gebrütet",
    "gebrüteteste": "gebrütet",
    "gebrütetestem": "gebrütet",
    "gebrütetesten": "gebrütet",
    "gebrütetester": "gebrütet",
    "gebrütetestes": "gebrütet",
    "gebt": "geben",
    "gebucht": "buchen",
    "gebuchte": "gebucht",
    "gebuchtem": "gebucht",
    "gebuchten": "gebucht",
    "gebuchter": "gebucht",
    "gebuchtes": "gebucht",
    "gebuchtet": "buchten",
    "gebuchtete": "gebuchtet",
    "gebuchtetem": "gebuchtet",
    "gebuchteten": "gebuchtet",
    "gebuchteter": "gebuchtet",
    "gebuchtetes": "gebuchtet",
    "gebuddelt": "buddeln",
    "gebuddelte": "gebuddelt",
    "gebuddeltem": "gebuddelt",
    "gebuddelten": "gebuddelt",
    "gebuddelter": "gebuddelt",
    "gebuddeltes": "gebuddelt",
    "gebuhlt": "buhlen",
    "gebuhlte": "gebuhlt",
    "gebuhltem": "gebuhlt",
    "gebuhlten": "gebuhlt",
    "gebuhlter": "gebuhlt",
    "gebuhltes": "gebuhlt",
    "gebuht": "buhen",
    "gebuhte": "gebuht",
    "gebuhtem": "gebuht",
    "gebuhten": "gebuht",
    "gebuhter": "gebuht",
    "gebuhtes": "gebuht",
    "gebullert": "bullern",
    "gebullerte": "gebullert",
    "gebullertem": "gebullert",
    "gebullerten": "gebullert",
    "gebullerter": "gebullert",
    "gebullertes": "gebullert",
    "gebummelt": "bummeln",
    "gebummelte": "gebummelt",
    "gebummeltem": "gebummelt",
    "gebummelten": "gebummelt",
    "gebummelter": "gebummelt",
    "gebummeltes": "gebummelt",
    "gebumst": "bumsen",
    "gebumste": "gebumst",
    "gebumstem": "gebumst",
    "gebumsten": "gebumst",
    "gebumster": "gebumst",
    "gebumstes": "gebumst",
    "gebunden": "binden",
    "gebundene": "gebunden",
    "gebundenem": "gebunden",
    "gebundenen": "gebunden",
    "gebundener": "gebunden",
    "gebundenere": "gebunden",
    "gebundenerem": "gebunden",
    "gebundeneren": "gebunden",
    "gebundenerer": "gebunden",
    "gebundeneres": "gebunden",
    "gebundenes": "gebunden",
    "gebundenste": "gebunden",
    "gebundenstem": "gebunden",
    "gebundensten": "gebunden",
    "gebundenster": "gebunden",
    "gebundenstes": "gebunden",
    "gebunkert": "bunkern",
    "gebunkerte": "gebunkert",
    "gebunkertem": "gebunkert",
    "gebunkerten": "gebunkert",
    "gebunkerter": "gebunkert",
    "gebunkertere": "gebunkert",
    "gebunkerterem": "gebunkert",
    "gebunkerteren": "gebunkert",
    "gebunkerterer": "gebunkert",
    "gebunkerteres": "gebunkert",
    "gebunkertes": "gebunkert",
    "gebunkerteste": "gebunkert",
    "gebunkertestem": "gebunkert",
    "gebunkertesten": "gebunkert",
    "gebunkertester": "gebunkert",
    "gebunkertestes": "gebunkert",
    "geburtenschwachem": "geburtenschwach",
    "geburtenschwachen": "geburtenschwach",
    "geburtenschwacher": "geburtenschwach",
    "geburtenschwaches": "geburtenschwach",
    "geburtenschwächer": "geburtenschwach",
    "geburtenschwächere": "geburtenschwach",
    "geburtenschwächerem": "geburtenschwach",
    "geburtenschwächeren": "geburtenschwach",
    "geburtenschwächerer": "geburtenschwach",
    "geburtenschwächeres": "geburtenschwach",
    "geburtenschwächsten": "geburtenschwach",
    "geburtenstarke": "geburtenstark",
    "geburtenstarkem": "geburtenstark",
    "geburtenstarken": "geburtenstark",
    "geburtenstarker": "geburtenstark",
    "geburtenstarkes": "geburtenstark",
    "geburtenstärker": "geburtenstark",
    "geburtenstärkere": "geburtenstark",
    "geburtenstärkerem": "geburtenstark",
    "geburtenstärkeren": "geburtenstark",
    "geburtenstärkerer": "geburtenstark",
    "geburtenstärkeres": "geburtenstark",
    "geburtenstärksten": "geburtenstark",
    "gebuttert": "buttern",
    "gebutterte": "gebuttert",
    "gebuttertem": "gebuttert",
    "gebutterten": "gebuttert",
    "gebutterter": "gebuttert",
    "gebuttertes": "gebuttert",
    "gebändigt": "bändigen",
    "gebändigte": "gebändigt",
    "gebändigtem": "gebändigt",
    "gebändigten": "gebändigt",
    "gebändigter": "gebändigt",
    "gebändigtes": "gebändigt",
    "gebärde": "gebärden",
    "gebärdend": "gebärden",
    "gebärdende": "gebärdend",
    "gebärdendem": "gebärdend",
    "gebärdenden": "gebärdend",
    "gebärdender": "gebärdend",
    "gebärdendes": "gebärdend",
    "gebärdest": "gebärden",
    "gebärdet": "gebärden",
    "gebärdete": "gebärden",
    "gebärdetem": "gebärdet",
    "gebärdeten": "gebärden",
    "gebärdeter": "gebärdet",
    "gebärdetes": "gebärdet",
    "gebärdetest": "gebärden",
    "gebärdetet": "gebärden",
    "gebäre": "gebären",
    "gebärend": "gebären",
    "gebärende": "gebärend",
    "gebärendem": "gebärend",
    "gebärenden": "gebärend",
    "gebärender": "gebärend",
    "gebärendere": "gebärend",
    "gebärenderem": "gebärend",
    "gebärenderen": "gebärend",
    "gebärenderer": "gebärend",
    "gebärenderes": "gebärend",
    "gebärendes": "gebärend",
    "gebärendste": "gebärend",
    "gebärendstem": "gebärend",
    "gebärendsten": "gebärend",
    "gebärendster": "gebärend",
    "gebärendstes": "gebärend",
    "gebärest": "gebären",
    "gebäret": "gebären",
    "gebärfreudige": "gebärfreudig",
    "gebärfreudigem": "gebärfreudig",
    "gebärfreudigen": "gebärfreudig",
    "gebärfreudiger": "gebärfreudig",
    "gebärfreudigere": "gebärfreudig",
    "gebärfreudigerem": "gebärfreudig",
    "gebärfreudigeren": "gebärfreudig",
    "gebärfreudigerer": "gebärfreudig",
    "gebärfreudigeres": "gebärfreudig",
    "gebärfreudiges": "gebärfreudig",
    "gebärfreudigste": "gebärfreudig",
    "gebärfreudigstem": "gebärfreudig",
    "gebärfreudigsten": "gebärfreudig",
    "gebärfreudigster": "gebärfreudig",
    "gebärfreudigstes": "gebärfreudig",
    "gebärfähige": "gebärfähig",
    "gebärfähigem": "gebärfähig",
    "gebärfähigen": "gebärfähig",
    "gebärfähiger": "gebärfähig",
    "gebärfähigere": "gebärfähig",
    "gebärfähigerem": "gebärfähig",
    "gebärfähigeren": "gebärfähig",
    "gebärfähigerer": "gebärfähig",
    "gebärfähigeres": "gebärfähig",
    "gebärfähiges": "gebärfähig",
    "gebärfähigste": "gebärfähig",
    "gebärfähigstem": "gebärfähig",
    "gebärfähigsten": "gebärfähig",
    "gebärfähigster": "gebärfähig",
    "gebärfähigstes": "gebärfähig",
    "gebärst": "gebären",
    "gebärt": "gebären",
    "gebäumt": "bäumen",
    "gebäumte": "gebäumt",
    "gebäumtem": "gebäumt",
    "gebäumten": "gebäumt",
    "gebäumter": "gebäumt",
    "gebäumtes": "gebäumt",
    "gebölkt": "bölken",
    "gebölkte": "gebölkt",
    "gebölktem": "gebölkt",
    "gebölkten": "gebölkt",
    "gebölkter": "gebölkt",
    "gebölktes": "gebölkt",
    "geböllert": "böllern",
    "geböllerte": "geböllert",
    "geböllertem": "geböllert",
    "geböllerten": "geböllert",
    "geböllerter": "geböllert",
    "geböllertes": "geböllert",
    "geböte": "gebieten",
    "geböten": "gebieten",
    "gebötest": "gebieten",
    "gebötet": "gebieten",
    "gebüffelt": "büffeln",
    "gebüffelte": "gebüffelt",
    "gebüffeltem": "gebüffelt",
    "gebüffelten": "gebüffelt",
    "gebüffelter": "gebüffelt",
    "gebüffeltes": "gebüffelt",
    "gebügelt": "bügeln",
    "gebügelte": "gebügelt",
    "gebügeltem": "gebügelt",
    "gebügelten": "gebügelt",
    "gebügelter": "gebügelt",
    "gebügeltes": "gebügelt",
    "gebühre": "gebühren",
    "gebührend": "gebühren",
    "gebührende": "gebührend",
    "gebührendem": "gebührend",
    "gebührenden": "gebührend",
    "gebührender": "gebührend",
    "gebührendes": "gebührend",
    "gebührenfreie": "gebührenfrei",
    "gebührenfreiem": "gebührenfrei",
    "gebührenfreien": "gebührenfrei",
    "gebührenfreier": "gebührenfrei",
    "gebührenfreies": "gebührenfrei",
    "gebührenpflichtige": "gebührenpflichtig",
    "gebührenpflichtigem": "gebührenpflichtig",
    "gebührenpflichtigen": "gebührenpflichtig",
    "gebührenpflichtiger": "gebührenpflichtig",
    "gebührenpflichtiges": "gebührenpflichtig",
    "gebührest": "gebühren",
    "gebühret": "gebühren",
    "gebührst": "gebühren",
    "gebührt": "gebühren",
    "gebührte": "gebühren",
    "gebührtem": "gebührt",
    "gebührten": "gebühren",
    "gebührter": "gebührt",
    "gebührtes": "gebührt",
    "gebührtest": "gebühren",
    "gebührtet": "gebühren",
    "gebündelt": "bündeln",
    "gebündelte": "gebündelt",
    "gebündeltem": "gebündelt",
    "gebündelten": "gebündelt",
    "gebündelter": "gebündelt",
    "gebündeltere": "gebündelt",
    "gebündelterem": "gebündelt",
    "gebündelteren": "gebündelt",
    "gebündelterer": "gebündelt",
    "gebündelteres": "gebündelt",
    "gebündeltes": "gebündelt",
    "gebündelteste": "gebündelt",
    "gebündeltestem": "gebündelt",
    "gebündeltesten": "gebündelt",
    "gebündeltester": "gebündelt",
    "gebündeltestes": "gebündelt",
    "gebürdet": "bürden",
    "gebürdete": "gebürdet",
    "gebürdetem": "gebürdet",
    "gebürdeten": "gebürdet",
    "gebürdeter": "gebürdet",
    "gebürdetes": "gebürdet",
    "gebürgert": "bürgern",
    "gebürgerte": "gebürgert",
    "gebürgertem": "gebürgert",
    "gebürgerten": "gebürgert",
    "gebürgerter": "gebürgert",
    "gebürgertes": "gebürgert",
    "gebürgt": "bürgen",
    "gebürgte": "gebürgt",
    "gebürgtem": "gebürgt",
    "gebürgten": "gebürgt",
    "gebürgter": "gebürgt",
    "gebürgtes": "gebürgt",
    "gebürstet": "bürsten",
    "gebürstete": "gebürstet",
    "gebürstetem": "gebürstet",
    "gebürsteten": "gebürstet",
    "gebürsteter": "gebürstet",
    "gebürstetes": "gebürstet",
    "gebürtige": "gebürtig",
    "gebürtigem": "gebürtig",
    "gebürtigen": "gebürtig",
    "gebürtiger": "gebürtig",
    "gebürtiges": "gebürtig",
    "gebüxt": "büxen",
    "gebüxte": "gebüxt",
    "gebüxtem": "gebüxt",
    "gebüxten": "gebüxt",
    "gebüxter": "gebüxt",
    "gebüxtes": "gebüxt",
    "gebüßt": "büßen",
    "gebüßte": "gebüßt",
    "gebüßtem": "gebüßt",
    "gebüßten": "gebüßt",
    "gebüßter": "gebüßt",
    "gebüßtes": "gebüßt",
    "gecheckt": "checken",
    "gecheckte": "gecheckt",
    "gechecktem": "gecheckt",
    "gecheckten": "gecheckt",
    "gecheckter": "gecheckt",
    "gechecktes": "gecheckt",
    "geclont": "clonen",
    "geclonte": "geclont",
    "geclontem": "geclont",
    "geclonten": "geclont",
    "geclonter": "geclont",
    "geclontere": "geclont",
    "geclonterem": "geclont",
    "geclonteren": "geclont",
    "geclonterer": "geclont",
    "geclonteres": "geclont",
    "geclontes": "geclont",
    "geclonteste": "geclont",
    "geclontestem": "geclont",
    "geclontesten": "geclont",
    "geclontester": "geclont",
    "geclontestes": "geclont",
    "gecremt": "cremen",
    "gecremte": "gecremt",
    "gecremtem": "gecremt",
    "gecremten": "gecremt",
    "gecremter": "gecremt",
    "gecremtes": "gecremt",
    "gedacht": "gedenken",
    "gedachte": "gedacht",
    "gedachtem": "gedacht",
    "gedachten": "gedacht",
    "gedachter": "gedacht",
    "gedachtere": "gedacht",
    "gedachterem": "gedacht",
    "gedachteren": "gedacht",
    "gedachterer": "gedacht",
    "gedachteres": "gedacht",
    "gedachtes": "gedacht",
    "gedachtest": "gedenken",
    "gedachteste": "gedacht",
    "gedachtestem": "gedacht",
    "gedachtesten": "gedacht",
    "gedachtester": "gedacht",
    "gedachtestes": "gedacht",
    "gedachtet": "gedenken",
    "gedamelt": "dameln",
    "gedamelte": "gedamelt",
    "gedameltem": "gedamelt",
    "gedamelten": "gedamelt",
    "gedamelter": "gedamelt",
    "gedameltes": "gedamelt",
    "gedampft": "dampfen",
    "gedampfte": "gedampft",
    "gedampftem": "gedampft",
    "gedampften": "gedampft",
    "gedampfter": "gedampft",
    "gedampftes": "gedampft",
    "gedankenlosem": "gedankenlos",
    "gedankenlosen": "gedankenlos",
    "gedankenloser": "gedankenlos",
    "gedankenlosere": "gedankenlos",
    "gedankenloserem": "gedankenlos",
    "gedankenloseren": "gedankenlos",
    "gedankenloserer": "gedankenlos",
    "gedankenloseres": "gedankenlos",
    "gedankenloses": "gedankenlos",
    "gedankenloseste": "gedankenlos",
    "gedankenlosestem": "gedankenlos",
    "gedankenlosesten": "gedankenlos",
    "gedankenlosester": "gedankenlos",
    "gedankenlosestes": "gedankenlos",
    "gedanklichem": "gedanklich",
    "gedanklichen": "gedanklich",
    "gedanklicher": "gedanklich",
    "gedankliches": "gedanklich",
    "gedankt": "danken",
    "gedankte": "gedankt",
    "gedanktem": "gedankt",
    "gedankten": "gedankt",
    "gedankter": "gedankt",
    "gedanktes": "gedankt",
    "gedarbt": "darben",
    "gedarbte": "gedarbt",
    "gedarbtem": "gedarbt",
    "gedarbten": "gedarbt",
    "gedarbter": "gedarbt",
    "gedarbtes": "gedarbt",
    "gedauert": "dauern",
    "gedauerte": "gedauert",
    "gedauertem": "gedauert",
    "gedauerten": "gedauert",
    "gedauerter": "gedauert",
    "gedauertes": "gedauert",
    "gedeckt": "decken",
    "gedeckte": "gedeckt",
    "gedecktem": "gedeckt",
    "gedeckten": "gedeckt",
    "gedeckter": "gedeckt",
    "gedecktes": "gedeckt",
    "gedehnt": "dehnen",
    "gedehnte": "gedehnt",
    "gedehntem": "gedehnt",
    "gedehnten": "gedehnt",
    "gedehnter": "gedehnt",
    "gedehntere": "gedehnt",
    "gedehnterem": "gedehnt",
    "gedehnteren": "gedehnt",
    "gedehnterer": "gedehnt",
    "gedehnteres": "gedehnt",
    "gedehntes": "gedehnt",
    "gedehnteste": "gedehnt",
    "gedehntestem": "gedehnt",
    "gedehntesten": "gedehnt",
    "gedehntester": "gedehnt",
    "gedehntestes": "gedehnt",
    "gedeichselt": "deichseln",
    "gedeichselte": "gedeichselt",
    "gedeichseltem": "gedeichselt",
    "gedeichselten": "gedeichselt",
    "gedeichselter": "gedeichselt",
    "gedeichseltes": "gedeichselt",
    "gedeicht": "deichen",
    "gedeichte": "gedeicht",
    "gedeichtem": "gedeicht",
    "gedeichten": "gedeicht",
    "gedeichter": "gedeicht",
    "gedeichtes": "gedeicht",
    "gedeihe": "gedeihen",
    "gedeihend": "gedeihen",
    "gedeihende": "gedeihend",
    "gedeihendem": "gedeihend",
    "gedeihenden": "gedeihend",
    "gedeihender": "gedeihend",
    "gedeihendere": "gedeihend",
    "gedeihenderem": "gedeihend",
    "gedeihenderen": "gedeihend",
    "gedeihenderer": "gedeihend",
    "gedeihenderes": "gedeihend",
    "gedeihendes": "gedeihend",
    "gedeihendste": "gedeihend",
    "gedeihendstem": "gedeihend",
    "gedeihendsten": "gedeihend",
    "gedeihendster": "gedeihend",
    "gedeihendstes": "gedeihend",
    "gedeihest": "gedeihen",
    "gedeihet": "gedeihen",
    "gedeihst": "gedeihen",
    "gedeiht": "gedeihen",
    "gedellt": "dellen",
    "gedellte": "gedellt",
    "gedelltem": "gedellt",
    "gedellten": "gedellt",
    "gedellter": "gedellt",
    "gedelltes": "gedellt",
    "gedemütigt": "demütigen",
    "gedemütigte": "gedemütigt",
    "gedemütigtem": "gedemütigt",
    "gedemütigten": "gedemütigt",
    "gedemütigter": "gedemütigt",
    "gedemütigtere": "gedemütigt",
    "gedemütigterem": "gedemütigt",
    "gedemütigteren": "gedemütigt",
    "gedemütigterer": "gedemütigt",
    "gedemütigteres": "gedemütigt",
    "gedemütigtes": "gedemütigt",
    "gedemütigteste": "gedemütigt",
    "gedemütigtestem": "gedemütigt",
    "gedemütigtesten": "gedemütigt",
    "gedemütigtester": "gedemütigt",
    "gedemütigtestes": "gedemütigt",
    "gedenke": "gedenken",
    "gedenkend": "gedenken",
    "gedenkende": "gedenkend",
    "gedenkendem": "gedenkend",
    "gedenkenden": "gedenkend",
    "gedenkender": "gedenkend",
    "gedenkendes": "gedenkend",
    "gedenkest": "gedenken",
    "gedenket": "gedenken",
    "gedenkst": "gedenken",
    "gedenkt": "gedenken",
    "gedeucht": "dünken",
    "gedeuchte": "gedeucht",
    "gedeuchtem": "gedeucht",
    "gedeuchten": "gedeucht",
    "gedeuchter": "gedeucht",
    "gedeuchtes": "gedeucht",
    "gedeutelt": "deuteln",
    "gedeutelte": "gedeutelt",
    "gedeuteltem": "gedeutelt",
    "gedeutelten": "gedeutelt",
    "gedeutelter": "gedeutelt",
    "gedeuteltes": "gedeutelt",
    "gedeutet": "deuten",
    "gedeutete": "gedeutet",
    "gedeutetem": "gedeutet",
    "gedeuteten": "gedeutet",
    "gedeuteter": "gedeutet",
    "gedeutetes": "gedeutet",
    "gedeutscht": "deutschen",
    "gedeutschte": "gedeutscht",
    "gedeutschtem": "gedeutscht",
    "gedeutschten": "gedeutscht",
    "gedeutschter": "gedeutscht",
    "gedeutschtes": "gedeutscht",
    "gedichtet": "dichten",
    "gedichtete": "gedichtet",
    "gedichtetem": "gedichtet",
    "gedichteten": "gedichtet",
    "gedichteter": "gedichtet",
    "gedichtetes": "gedichtet",
    "gediegenem": "gediegen",
    "gediegenen": "gediegen",
    "gediegener": "gediegen",
    "gediegenere": "gediegen",
    "gediegenerem": "gediegen",
    "gediegeneren": "gediegen",
    "gediegenerer": "gediegen",
    "gediegeneres": "gediegen",
    "gediegenes": "gediegen",
    "gediegenste": "gediegen",
    "gediegenstem": "gediegen",
    "gediegensten": "gediegen",
    "gediegenster": "gediegen",
    "gediegenstes": "gediegen",
    "gedieh": "gedeihen",
    "gediehe": "gedeihen",
    "gediehen": "gedeihen",
    "gediehene": "gediehen",
    "gediehenem": "gediehen",
    "gediehenen": "gediehen",
    "gediehener": "gediehen",
    "gediehenere": "gediehen",
    "gediehenerem": "gediehen",
    "gedieheneren": "gediehen",
    "gediehenerer": "gediehen",
    "gedieheneres": "gediehen",
    "gediehenes": "gediehen",
    "gediehenste": "gediehen",
    "gediehenstem": "gediehen",
    "gediehensten": "gediehen",
    "gediehenster": "gediehen",
    "gediehenstes": "gediehen",
    "gediehest": "gedeihen",
    "gediehet": "gedeihen",
    "gediehst": "gedeihen",
    "gedieht": "gedeihen",
    "gedient": "dienen",
    "gediente": "gedient",
    "gedientem": "gedient",
    "gedienten": "gedient",
    "gedienter": "gedient",
    "gedientes": "gedient",
    "gedippt": "dippen",
    "gedippte": "gedippt",
    "gedipptem": "gedippt",
    "gedippten": "gedippt",
    "gedippter": "gedippt",
    "gedipptes": "gedippt",
    "gedockt": "docken",
    "gedockte": "gedockt",
    "gedocktem": "gedockt",
    "gedockten": "gedockt",
    "gedockter": "gedockt",
    "gedocktes": "gedockt",
    "gedoktert": "doktern",
    "gedokterte": "gedoktert",
    "gedoktertem": "gedoktert",
    "gedokterten": "gedoktert",
    "gedokterter": "gedoktert",
    "gedoktertes": "gedoktert",
    "gedolmetscht": "dolmetschen",
    "gedolmetschte": "gedolmetscht",
    "gedolmetschtem": "gedolmetscht",
    "gedolmetschten": "gedolmetscht",
    "gedolmetschter": "gedolmetscht",
    "gedolmetschtes": "gedolmetscht",
    "gedonnert": "donnern",
    "gedonnerte": "gedonnert",
    "gedonnertem": "gedonnert",
    "gedonnerten": "gedonnert",
    "gedonnerter": "gedonnert",
    "gedonnertes": "gedonnert",
    "gedoppelt": "doppeln",
    "gedoppelte": "gedoppelt",
    "gedoppeltem": "gedoppelt",
    "gedoppelten": "gedoppelt",
    "gedoppelter": "gedoppelt",
    "gedoppeltere": "gedoppelt",
    "gedoppelterem": "gedoppelt",
    "gedoppelteren": "gedoppelt",
    "gedoppelterer": "gedoppelt",
    "gedoppelteres": "gedoppelt",
    "gedoppeltes": "gedoppelt",
    "gedoppelteste": "gedoppelt",
    "gedoppeltestem": "gedoppelt",
    "gedoppeltesten": "gedoppelt",
    "gedoppeltester": "gedoppelt",
    "gedoppeltestes": "gedoppelt",
    "gedopt": "dopen",
    "gedopte": "gedopt",
    "gedoptem": "gedopt",
    "gedopten": "gedopt",
    "gedopter": "gedopt",
    "gedoptere": "gedopt",
    "gedopterem": "gedopt",
    "gedopteren": "gedopt",
    "gedopterer": "gedopt",
    "gedopteres": "gedopt",
    "gedoptes": "gedopt",
    "gedopteste": "gedopt",
    "gedoptestem": "gedopt",
    "gedoptesten": "gedopt",
    "gedoptester": "gedopt",
    "gedoptestes": "gedopt",
    "gedost": "dosen",
    "gedoste": "gedost",
    "gedostem": "gedost",
    "gedosten": "gedost",
    "gedoster": "gedost",
    "gedostes": "gedost",
    "gedoubelt": "doubeln",
    "gedoubelte": "gedoubelt",
    "gedoubeltem": "gedoubelt",
    "gedoubelten": "gedoubelt",
    "gedoubelter": "gedoubelt",
    "gedoubeltes": "gedoubelt",
    "gedrahtet": "drahten",
    "gedrahtete": "gedrahtet",
    "gedrahtetem": "gedrahtet",
    "gedrahteten": "gedrahtet",
    "gedrahteter": "gedrahtet",
    "gedrahtetes": "gedrahtet",
    "gedreht": "drehen",
    "gedrehte": "gedreht",
    "gedrehtem": "gedreht",
    "gedrehten": "gedreht",
    "gedrehter": "gedreht",
    "gedrehtere": "gedreht",
    "gedrehterem": "gedreht",
    "gedrehteren": "gedreht",
    "gedrehterer": "gedreht",
    "gedrehteres": "gedreht",
    "gedrehtes": "gedreht",
    "gedrehteste": "gedreht",
    "gedrehtestem": "gedreht",
    "gedrehtesten": "gedreht",
    "gedrehtester": "gedreht",
    "gedrehtestes": "gedreht",
    "gedribbelt": "dribbeln",
    "gedribbelte": "gedribbelt",
    "gedribbeltem": "gedribbelt",
    "gedribbelten": "gedribbelt",
    "gedribbelter": "gedribbelt",
    "gedribbeltes": "gedribbelt",
    "gedriftet": "driften",
    "gedriftete": "gedriftet",
    "gedriftetem": "gedriftet",
    "gedrifteten": "gedriftet",
    "gedrifteter": "gedriftet",
    "gedriftetes": "gedriftet",
    "gedrillt": "drillen",
    "gedrillte": "gedrillt",
    "gedrilltem": "gedrillt",
    "gedrillten": "gedrillt",
    "gedrillter": "gedrillt",
    "gedrilltere": "gedrillt",
    "gedrillterem": "gedrillt",
    "gedrillteren": "gedrillt",
    "gedrillterer": "gedrillt",
    "gedrillteres": "gedrillt",
    "gedrilltes": "gedrillt",
    "gedrillteste": "gedrillt",
    "gedrilltestem": "gedrillt",
    "gedrilltesten": "gedrillt",
    "gedrilltester": "gedrillt",
    "gedrilltestes": "gedrillt",
    "gedrittelt": "dritteln",
    "gedrittelte": "gedrittelt",
    "gedritteltem": "gedrittelt",
    "gedrittelten": "gedrittelt",
    "gedrittelter": "gedrittelt",
    "gedritteltes": "gedrittelt",
    "gedroht": "drohen",
    "gedrohte": "gedroht",
    "gedrohtem": "gedroht",
    "gedrohten": "gedroht",
    "gedrohter": "gedroht",
    "gedrohtes": "gedroht",
    "gedroschen": "dreschen",
    "gedroschene": "gedroschen",
    "gedroschenem": "gedroschen",
    "gedroschenen": "gedroschen",
    "gedroschener": "gedroschen",
    "gedroschenere": "gedroschen",
    "gedroschenerem": "gedroschen",
    "gedroscheneren": "gedroschen",
    "gedroschenerer": "gedroschen",
    "gedroscheneres": "gedroschen",
    "gedroschenes": "gedroschen",
    "gedroschenste": "gedroschen",
    "gedroschenstem": "gedroschen",
    "gedroschensten": "gedroschen",
    "gedroschenster": "gedroschen",
    "gedroschenstes": "gedroschen",
    "gedrosselt": "drosseln",
    "gedrosselte": "gedrosselt",
    "gedrosseltem": "gedrosselt",
    "gedrosselten": "gedrosselt",
    "gedrosselter": "gedrosselt",
    "gedrosseltere": "gedrosselt",
    "gedrosselterem": "gedrosselt",
    "gedrosselteren": "gedrosselt",
    "gedrosselterer": "gedrosselt",
    "gedrosselteres": "gedrosselt",
    "gedrosseltes": "gedrosselt",
    "gedrosselteste": "gedrosselt",
    "gedrosseltestem": "gedrosselt",
    "gedrosseltesten": "gedrosselt",
    "gedrosseltester": "gedrosselt",
    "gedrosseltestes": "gedrosselt",
    "gedruckst": "drucksen",
    "gedruckste": "gedruckst",
    "gedruckstem": "gedruckst",
    "gedrucksten": "gedruckst",
    "gedruckster": "gedruckst",
    "gedruckstes": "gedruckst",
    "gedruckt": "drucken",
    "gedruckte": "gedruckt",
    "gedrucktem": "gedruckt",
    "gedruckten": "gedruckt",
    "gedruckter": "gedruckt",
    "gedrucktes": "gedruckt",
    "gedrungen": "dringen",
    "gedrungene": "gedrungen",
    "gedrungenem": "gedrungen",
    "gedrungenen": "gedrungen",
    "gedrungener": "gedrungen",
    "gedrungenere": "gedrungen",
    "gedrungenerem": "gedrungen",
    "gedrungeneren": "gedrungen",
    "gedrungenerer": "gedrungen",
    "gedrungeneres": "gedrungen",
    "gedrungenes": "gedrungen",
    "gedrungenste": "gedrungen",
    "gedrungenstem": "gedrungen",
    "gedrungensten": "gedrungen",
    "gedrungenster": "gedrungen",
    "gedrungenstes": "gedrungen",
    "gedrängelt": "drängeln",
    "gedrängelte": "gedrängelt",
    "gedrängeltem": "gedrängelt",
    "gedrängelten": "gedrängelt",
    "gedrängelter": "gedrängelt",
    "gedrängeltere": "gedrängelt",
    "gedrängelterem": "gedrängelt",
    "gedrängelteren": "gedrängelt",
    "gedrängelterer": "gedrängelt",
    "gedrängelteres": "gedrängelt",
    "gedrängeltes": "gedrängelt",
    "gedrängelteste": "gedrängelt",
    "gedrängeltestem": "gedrängelt",
    "gedrängeltesten": "gedrängelt",
    "gedrängeltester": "gedrängelt",
    "gedrängeltestes": "gedrängelt",
    "gedrängt": "drängen",
    "gedrängte": "gedrängt",
    "gedrängtem": "gedrängt",
    "gedrängten": "gedrängt",
    "gedrängter": "gedrängt",
    "gedrängtes": "gedrängt",
    "gedröhnt": "dröhnen",
    "gedröhnte": "gedröhnt",
    "gedröhntem": "gedröhnt",
    "gedröhnten": "gedröhnt",
    "gedröhnter": "gedröhnt",
    "gedröhntes": "gedröhnt",
    "gedröselt": "dröseln",
    "gedröselte": "gedröselt",
    "gedröseltem": "gedröselt",
    "gedröselten": "gedröselt",
    "gedröselter": "gedröselt",
    "gedröseltere": "gedröselt",
    "gedröselterem": "gedröselt",
    "gedröselteren": "gedröselt",
    "gedröselterer": "gedröselt",
    "gedröselteres": "gedröselt",
    "gedröseltes": "gedröselt",
    "gedröselteste": "gedröselt",
    "gedröseltestem": "gedröselt",
    "gedröseltesten": "gedröselt",
    "gedröseltester": "gedröselt",
    "gedröseltestes": "gedröselt",
    "gedrückt": "drücken",
    "gedrücktem": "gedrückt",
    "gedrückter": "gedrückt",
    "gedrücktere": "gedrückt",
    "gedrückterem": "gedrückt",
    "gedrückteren": "gedrückt",
    "gedrückterer": "gedrückt",
    "gedrückteres": "gedrückt",
    "gedrücktes": "gedrückt",
    "gedrückteste": "gedrückt",
    "gedrücktestem": "gedrückt",
    "gedrücktesten": "gedrückt",
    "gedrücktester": "gedrückt",
    "gedrücktestes": "gedrückt",
    "geduckt": "ducken",
    "geduckte": "geduckt",
    "geducktem": "geduckt",
    "geduckten": "geduckt",
    "geduckter": "geduckt",
    "geducktere": "geduckt",
    "geduckterem": "geduckt",
    "geduckteren": "geduckt",
    "geduckterer": "geduckt",
    "geduckteres": "geduckt",
    "geducktes": "geduckt",
    "geduckteste": "geduckt",
    "geducktestem": "geduckt",
    "geducktesten": "geduckt",
    "geducktester": "geduckt",
    "geducktestes": "geduckt",
    "gedudelt": "dudeln",
    "gedudelte": "gedudelt",
    "gedudeltem": "gedudelt",
    "gedudelten": "gedudelt",
    "gedudelter": "gedudelt",
    "gedudeltes": "gedudelt",
    "geduftet": "duften",
    "geduftete": "geduftet",
    "geduftetem": "geduftet",
    "gedufteten": "geduftet",
    "gedufteter": "geduftet",
    "geduftetes": "geduftet",
    "gedulde": "gedulden",
    "geduldend": "gedulden",
    "geduldende": "geduldend",
    "geduldendem": "geduldend",
    "geduldenden": "geduldend",
    "geduldender": "geduldend",
    "geduldendere": "geduldend",
    "geduldenderem": "geduldend",
    "geduldenderen": "geduldend",
    "geduldenderer": "geduldend",
    "geduldenderes": "geduldend",
    "geduldendes": "geduldend",
    "geduldendste": "geduldend",
    "geduldendstem": "geduldend",
    "geduldendsten": "geduldend",
    "geduldendster": "geduldend",
    "geduldendstes": "geduldend",
    "geduldest": "gedulden",
    "geduldet": "gedulden",
    "geduldete": "gedulden",
    "geduldetem": "geduldet",
    "geduldeten": "gedulden",
    "geduldeter": "geduldet",
    "geduldetere": "geduldet",
    "geduldeterem": "geduldet",
    "geduldeteren": "geduldet",
    "geduldeterer": "geduldet",
    "geduldeteres": "geduldet",
    "geduldetes": "geduldet",
    "geduldetest": "gedulden",
    "geduldeteste": "geduldet",
    "geduldetestem": "geduldet",
    "geduldetesten": "geduldet",
    "geduldetester": "geduldet",
    "geduldetestes": "geduldet",
    "geduldetet": "gedulden",
    "geduldige": "geduldig",
    "geduldigem": "geduldig",
    "geduldigen": "geduldig",
    "geduldiger": "geduldig",
    "geduldigere": "geduldig",
    "geduldigerem": "geduldig",
    "geduldigeren": "geduldig",
    "geduldigerer": "geduldig",
    "geduldigeres": "geduldig",
    "geduldiges": "geduldig",
    "geduldigste": "geduldig",
    "geduldigstem": "geduldig",
    "geduldigsten": "geduldig",
    "geduldigster": "geduldig",
    "geduldigstes": "geduldig",
    "gedungen": "dingen",
    "gedungene": "gedungen",
    "gedungenem": "gedungen",
    "gedungenen": "gedungen",
    "gedungener": "gedungen",
    "gedungenere": "gedungen",
    "gedungenerem": "gedungen",
    "gedungeneren": "gedungen",
    "gedungenerer": "gedungen",
    "gedungeneres": "gedungen",
    "gedungenes": "gedungen",
    "gedungenste": "gedungen",
    "gedungenstem": "gedungen",
    "gedungensten": "gedungen",
    "gedungenster": "gedungen",
    "gedungenstes": "gedungen",
    "gedunkelt": "dunkeln",
    "gedunkelte": "gedunkelt",
    "gedunkeltem": "gedunkelt",
    "gedunkelten": "gedunkelt",
    "gedunkelter": "gedunkelt",
    "gedunkeltere": "gedunkelt",
    "gedunkelterem": "gedunkelt",
    "gedunkelteren": "gedunkelt",
    "gedunkelterer": "gedunkelt",
    "gedunkelteres": "gedunkelt",
    "gedunkeltes": "gedunkelt",
    "gedunkelteste": "gedunkelt",
    "gedunkeltestem": "gedunkelt",
    "gedunkeltesten": "gedunkelt",
    "gedunkeltester": "gedunkelt",
    "gedunkeltestes": "gedunkelt",
    "gedunsene": "gedunsen",
    "gedunsenem": "gedunsen",
    "gedunsenen": "gedunsen",
    "gedunsener": "gedunsen",
    "gedunsenere": "gedunsen",
    "gedunsenerem": "gedunsen",
    "gedunseneren": "gedunsen",
    "gedunsenerer": "gedunsen",
    "gedunseneres": "gedunsen",
    "gedunsenes": "gedunsen",
    "gedunsenste": "gedunsen",
    "gedunsenstem": "gedunsen",
    "gedunsensten": "gedunsen",
    "gedunsenster": "gedunsen",
    "gedunsenstes": "gedunsen",
    "gedunstet": "dunsten",
    "gedunstete": "gedunstet",
    "gedunstetem": "gedunstet",
    "gedunsteten": "gedunstet",
    "gedunsteter": "gedunstet",
    "gedunstetere": "gedunstet",
    "gedunsteterem": "gedunstet",
    "gedunsteteren": "gedunstet",
    "gedunsteterer": "gedunstet",
    "gedunsteteres": "gedunstet",
    "gedunstetes": "gedunstet",
    "gedunsteteste": "gedunstet",
    "gedunstetestem": "gedunstet",
    "gedunstetesten": "gedunstet",
    "gedunstetester": "gedunstet",
    "gedunstetestes": "gedunstet",
    "gedurft": "dürfen",
    "gedurstet": "dursten",
    "gedurstete": "gedurstet",
    "gedurstetem": "gedurstet",
    "gedursteten": "gedurstet",
    "gedursteter": "gedurstet",
    "gedurstetes": "gedurstet",
    "geduscht": "duschen",
    "geduschte": "geduscht",
    "geduschtem": "geduscht",
    "geduschten": "geduscht",
    "geduschter": "geduscht",
    "geduschtes": "geduscht",
    "geduselt": "duseln",
    "geduselte": "geduselt",
    "geduseltem": "geduselt",
    "geduselten": "geduselt",
    "geduselter": "geduselt",
    "geduseltere": "geduselt",
    "geduselterem": "geduselt",
    "geduselteren": "geduselt",
    "geduselterer": "geduselt",
    "geduselteres": "geduselt",
    "geduseltes": "geduselt",
    "geduselteste": "geduselt",
    "geduseltestem": "geduselt",
    "geduseltesten": "geduselt",
    "geduseltester": "geduselt",
    "geduseltestes": "geduselt",
    "geduzt": "duzen",
    "geduzte": "geduzt",
    "geduztem": "geduzt",
    "geduzten": "geduzt",
    "geduzter": "geduzt",
    "geduztes": "geduzt",
    "gedächtnisschwache": "gedächtnisschwach",
    "gedächtnisschwachem": "gedächtnisschwach",
    "gedächtnisschwachen": "gedächtnisschwach",
    "gedächtnisschwacher": "gedächtnisschwach",
    "gedächtnisschwaches": "gedächtnisschwach",
    "gedächtnisschwächer": "gedächtnisschwach",
    "gedächtnisschwächere": "gedächtnisschwach",
    "gedächtnisschwächerem": "gedächtnisschwach",
    "gedächtnisschwächeren": "gedächtnisschwach",
    "gedächtnisschwächerer": "gedächtnisschwach",
    "gedächtnisschwächeres": "gedächtnisschwach",
    "gedächtnisschwächste": "gedächtnisschwach",
    "gedächtnisschwächstem": "gedächtnisschwach",
    "gedächtnisschwächsten": "gedächtnisschwach",
    "gedächtnisschwächster": "gedächtnisschwach",
    "gedächtnisschwächstes": "gedächtnisschwach",
    "gedämmert": "dämmern",
    "gedämmerte": "gedämmert",
    "gedämmertem": "gedämmert",
    "gedämmerten": "gedämmert",
    "gedämmerter": "gedämmert",
    "gedämmertes": "gedämmert",
    "gedämmt": "dämmen",
    "gedämmte": "gedämmt",
    "gedämmtem": "gedämmt",
    "gedämmten": "gedämmt",
    "gedämmter": "gedämmt",
    "gedämmtes": "gedämmt",
    "gedämpft": "dämpfen",
    "gedämpftem": "gedämpft",
    "gedämpfter": "gedämpft",
    "gedämpftes": "gedämpft",
    "gedörrt": "dörren",
    "gedörrte": "gedörrt",
    "gedörrtem": "gedörrt",
    "gedörrten": "gedörrt",
    "gedörrter": "gedörrt",
    "gedörrtes": "gedörrt",
    "gedöst": "dösen",
    "gedöstem": "gedöst",
    "gedöster": "gedöst",
    "gedöstes": "gedöst",
    "gedübelt": "dübeln",
    "gedübelte": "gedübelt",
    "gedübeltem": "gedübelt",
    "gedübelten": "gedübelt",
    "gedübelter": "gedübelt",
    "gedübeltes": "gedübelt",
    "gedümpelt": "dümpeln",
    "gedümpelte": "gedümpelt",
    "gedümpeltem": "gedümpelt",
    "gedümpelten": "gedümpelt",
    "gedümpelter": "gedümpelt",
    "gedümpeltes": "gedümpelt",
    "gedüngt": "düngen",
    "gedüngte": "gedüngt",
    "gedüngtem": "gedüngt",
    "gedüngten": "gedüngt",
    "gedüngter": "gedüngt",
    "gedüngtere": "gedüngt",
    "gedüngterem": "gedüngt",
    "gedüngteren": "gedüngt",
    "gedüngterer": "gedüngt",
    "gedüngteres": "gedüngt",
    "gedüngtes": "gedüngt",
    "gedüngteste": "gedüngt",
    "gedüngtestem": "gedüngt",
    "gedüngtesten": "gedüngt",
    "gedüngtester": "gedüngt",
    "gedüngtestes": "gedüngt",
    "gedünkt": "dünken",
    "gedünkte": "gedünkt",
    "gedünktem": "gedünkt",
    "gedünkten": "gedünkt",
    "gedünkter": "gedünkt",
    "gedünktes": "gedünkt",
    "gedünnt": "dünnen",
    "gedünnte": "gedünnt",
    "gedünntem": "gedünnt",
    "gedünnten": "gedünnt",
    "gedünnter": "gedünnt",
    "gedünntes": "gedünnt",
    "gedünstet": "dünsten",
    "gedünstetem": "gedünstet",
    "gedünsteter": "gedünstet",
    "gedünsteterem": "gedünstet",
    "gedünsteterer": "gedünstet",
    "gedünsteteres": "gedünstet",
    "gedünstetes": "gedünstet",
    "gedünstetestem": "gedünstet",
    "gedünstetester": "gedünstet",
    "gedünstetestes": "gedünstet",
    "gedürstet": "dürsten",
    "gedürstetem": "gedürstet",
    "gedürsteter": "gedürstet",
    "gedürstetes": "gedürstet",
    "gedüst": "düsen",
    "gedüste": "gedüst",
    "gedüstem": "gedüst",
    "gedüsten": "gedüst",
    "gedüster": "gedüst",
    "gedüstes": "gedüst",
    "geebbt": "ebben",
    "geebbte": "geebbt",
    "geebbtem": "geebbt",
    "geebbten": "geebbt",
    "geebbter": "geebbt",
    "geebbtes": "geebbt",
    "geebnet": "ebnen",
    "geebnete": "geebnet",
    "geebnetem": "geebnet",
    "geebneten": "geebnet",
    "geebneter": "geebnet",
    "geebnetes": "geebnet",
    "geehelicht": "ehelichen",
    "geehelichte": "geehelicht",
    "geehelichtem": "geehelicht",
    "geehelichten": "geehelicht",
    "geehelichter": "geehelicht",
    "geehelichtes": "geehelicht",
    "geehrt": "ehren",
    "geehrte": "geehrt",
    "geehrtem": "geehrt",
    "geehrten": "geehrt",
    "geehrter": "geehrt",
    "geehrtere": "geehrt",
    "geehrterem": "geehrt",
    "geehrteren": "geehrt",
    "geehrterer": "geehrt",
    "geehrteres": "geehrt",
    "geehrtes": "geehrt",
    "geehrteste": "geehrt",
    "geehrtestem": "geehrt",
    "geehrtesten": "geehrt",
    "geehrtester": "geehrt",
    "geehrtestes": "geehrt",
    "geeicht": "eichen",
    "geeichte": "geeicht",
    "geeichtem": "geeicht",
    "geeichten": "geeicht",
    "geeichter": "geeicht",
    "geeichtere": "geeicht",
    "geeichterem": "geeicht",
    "geeichteren": "geeicht",
    "geeichterer": "geeicht",
    "geeichteres": "geeicht",
    "geeichtes": "geeicht",
    "geeichteste": "geeicht",
    "geeichtestem": "geeicht",
    "geeichtesten": "geeicht",
    "geeichtester": "geeicht",
    "geeichtestes": "geeicht",
    "geeiert": "eiern",
    "geeierte": "geeiert",
    "geeiertem": "geeiert",
    "geeierten": "geeiert",
    "geeierter": "geeiert",
    "geeiertes": "geeiert",
    "geeifert": "eifern",
    "geeiferte": "geeifert",
    "geeifertem": "geeifert",
    "geeiferten": "geeifert",
    "geeiferter": "geeifert",
    "geeifertes": "geeifert",
    "geeignet": "eignen",
    "geeignete": "geeignet",
    "geeignetem": "geeignet",
    "geeigneten": "geeignet",
    "geeigneter": "geeignet",
    "geeignetere": "geeignet",
    "geeigneterem": "geeignet",
    "geeigneteren": "geeignet",
    "geeigneterer": "geeignet",
    "geeigneteres": "geeignet",
    "geeignetes": "geeignet",
    "geeigneteste": "geeignet",
    "geeignetestem": "geeignet",
    "geeignetesten": "geeignet",
    "geeignetester": "geeignet",
    "geeignetestes": "geeignet",
    "geeilt": "eilen",
    "geeilte": "geeilt",
    "geeiltem": "geeilt",
    "geeilten": "geeilt",
    "geeilter": "geeilt",
    "geeiltes": "geeilt",
    "geeinigt": "einigen",
    "geeinigte": "geeinigt",
    "geeinigtem": "geeinigt",
    "geeinigten": "geeinigt",
    "geeinigter": "geeinigt",
    "geeinigtes": "geeinigt",
    "geeint": "einen",
    "geeinte": "geeint",
    "geeintem": "geeint",
    "geeinten": "geeint",
    "geeinter": "geeint",
    "geeintes": "geeint",
    "geeist": "eisen",
    "geeiste": "geeist",
    "geeistem": "geeist",
    "geeisten": "geeist",
    "geeister": "geeist",
    "geeistes": "geeist",
    "geeitert": "eitern",
    "geeiterte": "geeitert",
    "geeitertem": "geeitert",
    "geeiterten": "geeitert",
    "geeiterter": "geeitert",
    "geeitertere": "geeitert",
    "geeiterterem": "geeitert",
    "geeiterteren": "geeitert",
    "geeiterterer": "geeitert",
    "geeiterteres": "geeitert",
    "geeitertes": "geeitert",
    "geeiterteste": "geeitert",
    "geeitertestem": "geeitert",
    "geeitertesten": "geeitert",
    "geeitertester": "geeitert",
    "geeitertestes": "geeitert",
    "geekelt": "ekeln",
    "geekelte": "geekelt",
    "geekeltem": "geekelt",
    "geekelten": "geekelt",
    "geekelter": "geekelt",
    "geekeltere": "geekelt",
    "geekelterem": "geekelt",
    "geekelteren": "geekelt",
    "geekelterer": "geekelt",
    "geekelteres": "geekelt",
    "geekeltes": "geekelt",
    "geekelteste": "geekelt",
    "geekeltestem": "geekelt",
    "geekeltesten": "geekelt",
    "geekeltester": "geekelt",
    "geekeltestes": "geekelt",
    "geendet": "enden",
    "geendete": "geendet",
    "geendetem": "geendet",
    "geendeten": "geendet",
    "geendeter": "geendet",
    "geendetes": "geendet",
    "geengt": "engen",
    "geengte": "geengt",
    "geengtem": "geengt",
    "geengten": "geengt",
    "geengter": "geengt",
    "geengtes": "geengt",
    "geerbt": "erben",
    "geerbte": "geerbt",
    "geerbtem": "geerbt",
    "geerbten": "geerbt",
    "geerbter": "geerbt",
    "geerbtes": "geerbt",
    "geerdet": "erden",
    "geerdete": "geerdet",
    "geerdetem": "geerdet",
    "geerdeten": "geerdet",
    "geerdeter": "geerdet",
    "geerdetes": "geerdet",
    "geerntet": "ernten",
    "geerntete": "geerntet",
    "geerntetem": "geerntet",
    "geernteten": "geerntet",
    "geernteter": "geerntet",
    "geerntetes": "geerntet",
    "gefacht": "fachen",
    "gefachte": "gefacht",
    "gefachtem": "gefacht",
    "gefachten": "gefacht",
    "gefachter": "gefacht",
    "gefachtere": "gefacht",
    "gefachterem": "gefacht",
    "gefachteren": "gefacht",
    "gefachterer": "gefacht",
    "gefachteres": "gefacht",
    "gefachtes": "gefacht",
    "gefachteste": "gefacht",
    "gefachtestem": "gefacht",
    "gefachtesten": "gefacht",
    "gefachtester": "gefacht",
    "gefachtestes": "gefacht",
    "gefahndet": "fahnden",
    "gefahndete": "gefahndet",
    "gefahndetem": "gefahndet",
    "gefahndeten": "gefahndet",
    "gefahndeter": "gefahndet",
    "gefahndetes": "gefahndet",
    "gefahrenem": "gefahren",
    "gefahrenen": "gefahren",
    "gefahrener": "gefahren",
    "gefahrenere": "gefahren",
    "gefahrenerem": "gefahren",
    "gefahreneren": "gefahren",
    "gefahrenerer": "gefahren",
    "gefahreneres": "gefahren",
    "gefahrenes": "gefahren",
    "gefahrenste": "gefahren",
    "gefahrenstem": "gefahren",
    "gefahrensten": "gefahren",
    "gefahrenster": "gefahren",
    "gefahrenstes": "gefahren",
    "gefahrlose": "gefahrlos",
    "gefahrlosem": "gefahrlos",
    "gefahrlosen": "gefahrlos",
    "gefahrloser": "gefahrlos",
    "gefahrlosere": "gefahrlos",
    "gefahrloserem": "gefahrlos",
    "gefahrloseren": "gefahrlos",
    "gefahrloserer": "gefahrlos",
    "gefahrloseres": "gefahrlos",
    "gefahrloses": "gefahrlos",
    "gefahrloseste": "gefahrlos",
    "gefahrlosestem": "gefahrlos",
    "gefahrlosesten": "gefahrlos",
    "gefahrlosester": "gefahrlos",
    "gefahrlosestes": "gefahrlos",
    "gefahrvolle": "gefahrvoll",
    "gefahrvollem": "gefahrvoll",
    "gefahrvollen": "gefahrvoll",
    "gefahrvoller": "gefahrvoll",
    "gefahrvollere": "gefahrvoll",
    "gefahrvollerem": "gefahrvoll",
    "gefahrvolleren": "gefahrvoll",
    "gefahrvollerer": "gefahrvoll",
    "gefahrvolleres": "gefahrvoll",
    "gefahrvolles": "gefahrvoll",
    "gefahrvollste": "gefahrvoll",
    "gefahrvollstem": "gefahrvoll",
    "gefahrvollsten": "gefahrvoll",
    "gefahrvollster": "gefahrvoll",
    "gefahrvollstes": "gefahrvoll",
    "gefalle": "gefallen",
    "gefallen": "fallen",
    "gefallend": "gefallen",
    "gefallende": "gefallend",
    "gefallendem": "gefallend",
    "gefallenden": "gefallend",
    "gefallender": "gefallend",
    "gefallendere": "gefallend",
    "gefallenderem": "gefallend",
    "gefallenderen": "gefallend",
    "gefallenderer": "gefallend",
    "gefallenderes": "gefallend",
    "gefallendes": "gefallend",
    "gefallendste": "gefallend",
    "gefallendstem": "gefallend",
    "gefallendsten": "gefallend",
    "gefallendster": "gefallend",
    "gefallendstes": "gefallend",
    "gefallene": "gefallen",
    "gefallenem": "gefallen",
    "gefallenen": "gefallen",
    "gefallener": "gefallen",
    "gefallenere": "gefallen",
    "gefallenerem": "gefallen",
    "gefalleneren": "gefallen",
    "gefallenerer": "gefallen",
    "gefalleneres": "gefallen",
    "gefallenes": "gefallen",
    "gefallenstem": "gefallen",
    "gefallensten": "gefallen",
    "gefallenster": "gefallen",
    "gefallenstes": "gefallen",
    "gefallest": "gefallen",
    "gefallet": "gefallen",
    "gefallt": "gefallen",
    "gefaltet": "falten",
    "gefaltete": "gefaltet",
    "gefaltetem": "gefaltet",
    "gefalteten": "gefaltet",
    "gefalteter": "gefaltet",
    "gefaltetere": "gefaltet",
    "gefalteterem": "gefaltet",
    "gefalteteren": "gefaltet",
    "gefalteterer": "gefaltet",
    "gefalteteres": "gefaltet",
    "gefaltetes": "gefaltet",
    "gefalteteste": "gefaltet",
    "gefaltetestem": "gefaltet",
    "gefaltetesten": "gefaltet",
    "gefaltetester": "gefaltet",
    "gefaltetestes": "gefaltet",
    "gefalzt": "falzen",
    "gefalzte": "gefalzt",
    "gefalztem": "gefalzt",
    "gefalzten": "gefalzt",
    "gefalzter": "gefalzt",
    "gefalztes": "gefalzt",
    "gefangen": "fangen",
    "gefangene": "gefangen",
    "gefangenem": "gefangen",
    "gefangenen": "gefangen",
    "gefangener": "gefangen",
    "gefangenere": "gefangen",
    "gefangenerem": "gefangen",
    "gefangeneren": "gefangen",
    "gefangenerer": "gefangen",
    "gefangeneres": "gefangen",
    "gefangenes": "gefangen",
    "gefangengehalten": "gefangenhalten",
    "gefangengehaltene": "gefangengehalten",
    "gefangengehaltenem": "gefangengehalten",
    "gefangengehaltenen": "gefangengehalten",
    "gefangengehaltener": "gefangengehalten",
    "gefangengehaltenes": "gefangengehalten",
    "gefangenhalte": "gefangenhalten",
    "gefangenhaltend": "gefangenhalten",
    "gefangenhaltende": "gefangenhaltend",
    "gefangenhaltendem": "gefangenhaltend",
    "gefangenhaltenden": "gefangenhaltend",
    "gefangenhaltender": "gefangenhaltend",
    "gefangenhaltendes": "gefangenhaltend",
    "gefangenhaltest": "gefangenhalten",
    "gefangenhaltet": "gefangenhalten",
    "gefangenhielt": "gefangenhalten",
    "gefangenhielte": "gefangenhalten",
    "gefangenhielten": "gefangenhalten",
    "gefangenhieltest": "gefangenhalten",
    "gefangenhieltet": "gefangenhalten",
    "gefangenhält": "gefangenhalten",
    "gefangenhältst": "gefangenhalten",
    "gefangenstem": "gefangen",
    "gefangensten": "gefangen",
    "gefangenster": "gefangen",
    "gefangenstes": "gefangen",
    "gefangenzuhalten": "gefangenhalten",
    "gefaselt": "faseln",
    "gefaselte": "gefaselt",
    "gefaseltem": "gefaselt",
    "gefaselten": "gefaselt",
    "gefaselter": "gefaselt",
    "gefaseltere": "gefaselt",
    "gefaselterem": "gefaselt",
    "gefaselteren": "gefaselt",
    "gefaselterer": "gefaselt",
    "gefaselteres": "gefaselt",
    "gefaseltes": "gefaselt",
    "gefaselteste": "gefaselt",
    "gefaseltestem": "gefaselt",
    "gefaseltesten": "gefaselt",
    "gefaseltester": "gefaselt",
    "gefaseltestes": "gefaselt",
    "gefasert": "fasern",
    "gefaserte": "gefasert",
    "gefasertem": "gefasert",
    "gefaserten": "gefasert",
    "gefaserter": "gefasert",
    "gefasertere": "gefasert",
    "gefaserterem": "gefasert",
    "gefaserteren": "gefasert",
    "gefaserterer": "gefasert",
    "gefaserteres": "gefasert",
    "gefasertes": "gefasert",
    "gefaserteste": "gefasert",
    "gefasertestem": "gefasert",
    "gefasertesten": "gefasert",
    "gefasertester": "gefasert",
    "gefasertestes": "gefasert",
    "gefastet": "fasten",
    "gefastete": "gefastet",
    "gefastetem": "gefastet",
    "gefasteten": "gefastet",
    "gefasteter": "gefastet",
    "gefastetes": "gefastet",
    "gefaucht": "fauchen",
    "gefauchte": "gefaucht",
    "gefauchtem": "gefaucht",
    "gefauchten": "gefaucht",
    "gefauchter": "gefaucht",
    "gefauchtes": "gefaucht",
    "gefaulenzt": "faulenzen",
    "gefaulenzte": "gefaulenzt",
    "gefaulenztem": "gefaulenzt",
    "gefaulenzten": "gefaulenzt",
    "gefaulenzter": "gefaulenzt",
    "gefaulenztes": "gefaulenzt",
    "gefault": "faulen",
    "gefaulte": "gefault",
    "gefaultem": "gefault",
    "gefaulten": "gefault",
    "gefaulter": "gefault",
    "gefaultere": "gefault",
    "gefaulterem": "gefault",
    "gefaulteren": "gefault",
    "gefaulterer": "gefault",
    "gefaulteres": "gefault",
    "gefaultes": "gefault",
    "gefaulteste": "gefault",
    "gefaultestem": "gefault",
    "gefaultesten": "gefault",
    "gefaultester": "gefault",
    "gefaultestes": "gefault",
    "gefaustet": "fausten",
    "gefaustete": "gefaustet",
    "gefaustetem": "gefaustet",
    "gefausteten": "gefaustet",
    "gefausteter": "gefaustet",
    "gefaustetes": "gefaustet",
    "gefaxt": "faxen",
    "gefaxte": "gefaxt",
    "gefaxtem": "gefaxt",
    "gefaxten": "gefaxt",
    "gefaxter": "gefaxt",
    "gefaxtes": "gefaxt",
    "gefaßt": "fassen",
    "gefaßte": "gefaßt",
    "gefaßtem": "gefaßt",
    "gefaßten": "gefaßt",
    "gefaßter": "gefaßt",
    "gefaßtere": "gefaßt",
    "gefaßterem": "gefaßt",
    "gefaßteren": "gefaßt",
    "gefaßterer": "gefaßt",
    "gefaßteres": "gefaßt",
    "gefaßtes": "gefaßt",
    "gefaßteste": "gefaßt",
    "gefaßtestem": "gefaßt",
    "gefaßtesten": "gefaßt",
    "gefaßtester": "gefaßt",
    "gefaßtestes": "gefaßt",
    "gefechtsbereitem": "gefechtsbereit",
    "gefechtsbereiten": "gefechtsbereit",
    "gefechtsbereiter": "gefechtsbereit",
    "gefechtsbereites": "gefechtsbereit",
    "gefedert": "federn",
    "gefederte": "gefedert",
    "gefedertem": "gefedert",
    "gefederten": "gefedert",
    "gefederter": "gefedert",
    "gefedertere": "gefedert",
    "gefederterem": "gefedert",
    "gefederteren": "gefedert",
    "gefederterer": "gefedert",
    "gefederteres": "gefedert",
    "gefedertes": "gefedert",
    "gefederteste": "gefedert",
    "gefedertestem": "gefedert",
    "gefedertesten": "gefedert",
    "gefedertester": "gefedert",
    "gefedertestes": "gefedert",
    "gefegt": "fegen",
    "gefegte": "gefegt",
    "gefegtem": "gefegt",
    "gefegten": "gefegt",
    "gefegter": "gefegt",
    "gefegtes": "gefegt",
    "gefehlt": "fehlen",
    "gefehlte": "gefehlt",
    "gefehltem": "gefehlt",
    "gefehlten": "gefehlt",
    "gefehlter": "gefehlt",
    "gefehltes": "gefehlt",
    "gefeiert": "feiern",
    "gefeierte": "gefeiert",
    "gefeiertem": "gefeiert",
    "gefeierten": "gefeiert",
    "gefeierter": "gefeiert",
    "gefeiertere": "gefeiert",
    "gefeierterem": "gefeiert",
    "gefeierteren": "gefeiert",
    "gefeierterer": "gefeiert",
    "gefeierteres": "gefeiert",
    "gefeiertes": "gefeiert",
    "gefeierteste": "gefeiert",
    "gefeiertestem": "gefeiert",
    "gefeiertesten": "gefeiert",
    "gefeiertester": "gefeiert",
    "gefeiertestes": "gefeiert",
    "gefeilscht": "feilschen",
    "gefeilschte": "gefeilscht",
    "gefeilschtem": "gefeilscht",
    "gefeilschten": "gefeilscht",
    "gefeilschter": "gefeilscht",
    "gefeilschtes": "gefeilscht",
    "gefeilt": "feilen",
    "gefeilte": "gefeilt",
    "gefeiltem": "gefeilt",
    "gefeilten": "gefeilt",
    "gefeilter": "gefeilt",
    "gefeiltes": "gefeilt",
    "gefeindet": "feinden",
    "gefeindete": "gefeindet",
    "gefeindetem": "gefeindet",
    "gefeindeten": "gefeindet",
    "gefeindeter": "gefeindet",
    "gefeindetes": "gefeindet",
    "gefeit": "feien",
    "gefeite": "gefeit",
    "gefeitem": "gefeit",
    "gefeiten": "gefeit",
    "gefeiter": "gefeit",
    "gefeitere": "gefeit",
    "gefeiterem": "gefeit",
    "gefeiteren": "gefeit",
    "gefeiterer": "gefeit",
    "gefeiteres": "gefeit",
    "gefeites": "gefeit",
    "gefeiteste": "gefeit",
    "gefeitestem": "gefeit",
    "gefeitesten": "gefeit",
    "gefeitester": "gefeit",
    "gefeitestes": "gefeit",
    "geferkelt": "ferkeln",
    "geferkelte": "geferkelt",
    "geferkeltem": "geferkelt",
    "geferkelten": "geferkelt",
    "geferkelter": "geferkelt",
    "geferkeltes": "geferkelt",
    "gefertigt": "fertigen",
    "gefertigte": "gefertigt",
    "gefertigtem": "gefertigt",
    "gefertigten": "gefertigt",
    "gefertigter": "gefertigt",
    "gefertigtes": "gefertigt",
    "gefesselt": "fesseln",
    "gefesselte": "gefesselt",
    "gefesseltem": "gefesselt",
    "gefesselten": "gefesselt",
    "gefesselter": "gefesselt",
    "gefesseltere": "gefesselt",
    "gefesselterem": "gefesselt",
    "gefesselteren": "gefesselt",
    "gefesselterer": "gefesselt",
    "gefesselteres": "gefesselt",
    "gefesseltes": "gefesselt",
    "gefesselteste": "gefesselt",
    "gefesseltestem": "gefesselt",
    "gefesseltesten": "gefesselt",
    "gefesseltester": "gefesselt",
    "gefesseltestes": "gefesselt",
    "gefestigt": "festigen",
    "gefestigte": "gefestigt",
    "gefestigtem": "gefestigt",
    "gefestigten": "gefestigt",
    "gefestigter": "gefestigt",
    "gefestigtere": "gefestigt",
    "gefestigterem": "gefestigt",
    "gefestigteren": "gefestigt",
    "gefestigterer": "gefestigt",
    "gefestigteres": "gefestigt",
    "gefestigtes": "gefestigt",
    "gefestigteste": "gefestigt",
    "gefestigtestem": "gefestigt",
    "gefestigtesten": "gefestigt",
    "gefestigtester": "gefestigt",
    "gefestigtestes": "gefestigt",
    "gefettet": "fetten",
    "gefettete": "gefettet",
    "gefettetem": "gefettet",
    "gefetteten": "gefettet",
    "gefetteter": "gefettet",
    "gefettetere": "gefettet",
    "gefetteterem": "gefettet",
    "gefetteteren": "gefettet",
    "gefetteterer": "gefettet",
    "gefetteteres": "gefettet",
    "gefettetes": "gefettet",
    "gefetteteste": "gefettet",
    "gefettetestem": "gefettet",
    "gefettetesten": "gefettet",
    "gefettetester": "gefettet",
    "gefettetestes": "gefettet",
    "gefetzt": "fetzen",
    "gefetzte": "gefetzt",
    "gefetztem": "gefetzt",
    "gefetzten": "gefetzt",
    "gefetzter": "gefetzt",
    "gefetztere": "gefetzt",
    "gefetzterem": "gefetzt",
    "gefetzteren": "gefetzt",
    "gefetzterer": "gefetzt",
    "gefetzteres": "gefetzt",
    "gefetztes": "gefetzt",
    "gefetzteste": "gefetzt",
    "gefetztestem": "gefetzt",
    "gefetztesten": "gefetzt",
    "gefetztester": "gefetzt",
    "gefetztestes": "gefetzt",
    "gefeuchtet": "feuchten",
    "gefeuchtete": "gefeuchtet",
    "gefeuchtetem": "gefeuchtet",
    "gefeuchteten": "gefeuchtet",
    "gefeuchteter": "gefeuchtet",
    "gefeuchtetere": "gefeuchtet",
    "gefeuchteterem": "gefeuchtet",
    "gefeuchteteren": "gefeuchtet",
    "gefeuchteterer": "gefeuchtet",
    "gefeuchteteres": "gefeuchtet",
    "gefeuchtetes": "gefeuchtet",
    "gefeuchteteste": "gefeuchtet",
    "gefeuchtetestem": "gefeuchtet",
    "gefeuchtetesten": "gefeuchtet",
    "gefeuchtetester": "gefeuchtet",
    "gefeuchtetestes": "gefeuchtet",
    "gefeuert": "feuern",
    "gefeuerte": "gefeuert",
    "gefeuertem": "gefeuert",
    "gefeuerten": "gefeuert",
    "gefeuerter": "gefeuert",
    "gefeuertes": "gefeuert",
    "gefiebert": "fiebern",
    "gefieberte": "gefiebert",
    "gefiebertem": "gefiebert",
    "gefieberten": "gefiebert",
    "gefieberter": "gefiebert",
    "gefiebertes": "gefiebert",
    "gefiedelt": "fiedeln",
    "gefiedelte": "gefiedelt",
    "gefiedeltem": "gefiedelt",
    "gefiedelten": "gefiedelt",
    "gefiedelter": "gefiedelt",
    "gefiedeltes": "gefiedelt",
    "gefiedert": "fiedern",
    "gefiederte": "gefiedert",
    "gefiedertem": "gefiedert",
    "gefiederten": "gefiedert",
    "gefiederter": "gefiedert",
    "gefiedertere": "gefiedert",
    "gefiederterem": "gefiedert",
    "gefiederteren": "gefiedert",
    "gefiederterer": "gefiedert",
    "gefiederteres": "gefiedert",
    "gefiedertes": "gefiedert",
    "gefiederteste": "gefiedert",
    "gefiedertestem": "gefiedert",
    "gefiedertesten": "gefiedert",
    "gefiedertester": "gefiedert",
    "gefiedertestes": "gefiedert",
    "gefiel": "gefallen",
    "gefiele": "gefallen",
    "gefielen": "gefallen",
    "gefielest": "gefallen",
    "gefielet": "gefallen",
    "gefielst": "gefallen",
    "gefielt": "gefallen",
    "gefilmt": "filmen",
    "gefilmte": "gefilmt",
    "gefilmtem": "gefilmt",
    "gefilmten": "gefilmt",
    "gefilmter": "gefilmt",
    "gefilmtes": "gefilmt",
    "gefiltert": "filtern",
    "gefilterte": "gefiltert",
    "gefiltertem": "gefiltert",
    "gefilterten": "gefiltert",
    "gefilterter": "gefiltert",
    "gefiltertes": "gefiltert",
    "gefilzt": "filzen",
    "gefilzte": "gefilzt",
    "gefilztem": "gefilzt",
    "gefilzten": "gefilzt",
    "gefilzter": "gefilzt",
    "gefilztes": "gefilzt",
    "gefirmt": "firmen",
    "gefirmte": "gefirmt",
    "gefirmtem": "gefirmt",
    "gefirmten": "gefirmt",
    "gefirmter": "gefirmt",
    "gefirmtes": "gefirmt",
    "gefischt": "fischen",
    "gefischte": "gefischt",
    "gefischtem": "gefischt",
    "gefischten": "gefischt",
    "gefischter": "gefischt",
    "gefischtes": "gefischt",
    "gefixt": "fixen",
    "gefixte": "gefixt",
    "gefixtem": "gefixt",
    "gefixten": "gefixt",
    "gefixter": "gefixt",
    "gefixtes": "gefixt",
    "geflacht": "flachen",
    "geflachte": "geflacht",
    "geflachtem": "geflacht",
    "geflachten": "geflacht",
    "geflachter": "geflacht",
    "geflachtes": "geflacht",
    "geflackert": "flackern",
    "geflackerte": "geflackert",
    "geflackertem": "geflackert",
    "geflackerten": "geflackert",
    "geflackerter": "geflackert",
    "geflackertes": "geflackert",
    "geflaggt": "flaggen",
    "geflaggte": "geflaggt",
    "geflaggtem": "geflaggt",
    "geflaggten": "geflaggt",
    "geflaggter": "geflaggt",
    "geflaggtere": "geflaggt",
    "geflaggterem": "geflaggt",
    "geflaggteren": "geflaggt",
    "geflaggterer": "geflaggt",
    "geflaggteres": "geflaggt",
    "geflaggtes": "geflaggt",
    "geflaggteste": "geflaggt",
    "geflaggtestem": "geflaggt",
    "geflaggtesten": "geflaggt",
    "geflaggtester": "geflaggt",
    "geflaggtestes": "geflaggt",
    "geflammt": "flammen",
    "geflammte": "geflammt",
    "geflammtem": "geflammt",
    "geflammten": "geflammt",
    "geflammter": "geflammt",
    "geflammtere": "geflammt",
    "geflammterem": "geflammt",
    "geflammteren": "geflammt",
    "geflammterer": "geflammt",
    "geflammteres": "geflammt",
    "geflammtes": "geflammt",
    "geflammteste": "geflammt",
    "geflammtestem": "geflammt",
    "geflammtesten": "geflammt",
    "geflammtester": "geflammt",
    "geflammtestes": "geflammt",
    "geflankt": "flanken",
    "geflankte": "geflankt",
    "geflanktem": "geflankt",
    "geflankten": "geflankt",
    "geflankter": "geflankt",
    "geflanktes": "geflankt",
    "geflanscht": "flanschen",
    "geflanschte": "geflanscht",
    "geflanschtem": "geflanscht",
    "geflanschten": "geflanscht",
    "geflanschter": "geflanscht",
    "geflanschtes": "geflanscht",
    "geflattert": "flattern",
    "geflatterte": "geflattert",
    "geflattertem": "geflattert",
    "geflatterten": "geflattert",
    "geflatterter": "geflattert",
    "geflattertes": "geflattert",
    "geflaut": "flauen",
    "geflaute": "geflaut",
    "geflautem": "geflaut",
    "geflauten": "geflaut",
    "geflauter": "geflaut",
    "geflautes": "geflaut",
    "gefleckt": "flecken",
    "gefleckte": "gefleckt",
    "geflecktem": "gefleckt",
    "gefleckten": "gefleckt",
    "gefleckter": "gefleckt",
    "geflecktere": "gefleckt",
    "gefleckterem": "gefleckt",
    "gefleckteren": "gefleckt",
    "gefleckterer": "gefleckt",
    "gefleckteres": "gefleckt",
    "geflecktes": "gefleckt",
    "gefleckteste": "gefleckt",
    "geflecktestem": "gefleckt",
    "geflecktesten": "gefleckt",
    "geflecktester": "gefleckt",
    "geflecktestes": "gefleckt",
    "gefleddert": "fleddern",
    "gefledderte": "gefleddert",
    "gefleddertem": "gefleddert",
    "gefledderten": "gefleddert",
    "gefledderter": "gefleddert",
    "gefleddertere": "gefleddert",
    "gefledderterem": "gefleddert",
    "gefledderteren": "gefleddert",
    "gefledderterer": "gefleddert",
    "gefledderteres": "gefleddert",
    "gefleddertes": "gefleddert",
    "gefledderteste": "gefleddert",
    "gefleddertestem": "gefleddert",
    "gefleddertesten": "gefleddert",
    "gefleddertester": "gefleddert",
    "gefleddertestes": "gefleddert",
    "geflegelt": "flegeln",
    "geflegelte": "geflegelt",
    "geflegeltem": "geflegelt",
    "geflegelten": "geflegelt",
    "geflegelter": "geflegelt",
    "geflegeltere": "geflegelt",
    "geflegelterem": "geflegelt",
    "geflegelteren": "geflegelt",
    "geflegelterer": "geflegelt",
    "geflegelteres": "geflegelt",
    "geflegeltes": "geflegelt",
    "geflegelteste": "geflegelt",
    "geflegeltestem": "geflegelt",
    "geflegeltesten": "geflegelt",
    "geflegeltester": "geflegelt",
    "geflegeltestes": "geflegelt",
    "gefleht": "flehen",
    "geflehte": "gefleht",
    "geflehtem": "gefleht",
    "geflehten": "gefleht",
    "geflehter": "gefleht",
    "geflehtes": "gefleht",
    "geflennt": "flennen",
    "geflennte": "geflennt",
    "geflenntem": "geflennt",
    "geflennten": "geflennt",
    "geflennter": "geflennt",
    "geflenntes": "geflennt",
    "gefletscht": "fletschen",
    "gefletschte": "gefletscht",
    "gefletschtem": "gefletscht",
    "gefletschten": "gefletscht",
    "gefletschter": "gefletscht",
    "gefletschtes": "gefletscht",
    "gefliest": "fliesen",
    "geflieste": "gefliest",
    "gefliestem": "gefliest",
    "gefliesten": "gefliest",
    "gefliester": "gefliest",
    "gefliestes": "gefliest",
    "geflimmert": "flimmern",
    "geflimmerte": "geflimmert",
    "geflimmertem": "geflimmert",
    "geflimmerten": "geflimmert",
    "geflimmerter": "geflimmert",
    "geflimmertes": "geflimmert",
    "geflippert": "flippern",
    "geflipperte": "geflippert",
    "geflippertem": "geflippert",
    "geflipperten": "geflippert",
    "geflipperter": "geflippert",
    "geflippertes": "geflippert",
    "geflippt": "flippen",
    "geflippte": "geflippt",
    "geflipptem": "geflippt",
    "geflippten": "geflippt",
    "geflippter": "geflippt",
    "geflipptes": "geflippt",
    "geflittert": "flittern",
    "geflitterte": "geflittert",
    "geflittertem": "geflittert",
    "geflitterten": "geflittert",
    "geflitterter": "geflittert",
    "geflittertes": "geflittert",
    "geflitzt": "flitzen",
    "geflitzte": "geflitzt",
    "geflitztem": "geflitzt",
    "geflitzten": "geflitzt",
    "geflitzter": "geflitzt",
    "geflitztes": "geflitzt",
    "geflochten": "flechten",
    "geflochtene": "geflochten",
    "geflochtenem": "geflochten",
    "geflochtenen": "geflochten",
    "geflochtener": "geflochten",
    "geflochtenere": "geflochten",
    "geflochtenerem": "geflochten",
    "geflochteneren": "geflochten",
    "geflochtenerer": "geflochten",
    "geflochteneres": "geflochten",
    "geflochtenes": "geflochten",
    "geflochtenste": "geflochten",
    "geflochtenstem": "geflochten",
    "geflochtensten": "geflochten",
    "geflochtenster": "geflochten",
    "geflochtenstes": "geflochten",
    "geflockt": "flocken",
    "geflockte": "geflockt",
    "geflocktem": "geflockt",
    "geflockten": "geflockt",
    "geflockter": "geflockt",
    "geflocktes": "geflockt",
    "geflogen": "fliegen",
    "geflogene": "geflogen",
    "geflogenem": "geflogen",
    "geflogenen": "geflogen",
    "geflogener": "geflogen",
    "geflogenes": "geflogen",
    "geflohen": "fliehen",
    "geflohene": "geflohen",
    "geflohenem": "geflohen",
    "geflohenen": "geflohen",
    "geflohener": "geflohen",
    "geflohenes": "geflohen",
    "gefloppt": "floppen",
    "gefloppte": "gefloppt",
    "geflopptem": "gefloppt",
    "gefloppten": "gefloppt",
    "gefloppter": "gefloppt",
    "geflopptes": "gefloppt",
    "geflossen": "fließen",
    "geflossene": "geflossen",
    "geflossenem": "geflossen",
    "geflossenen": "geflossen",
    "geflossener": "geflossen",
    "geflossenes": "geflossen",
    "geflucht": "fluchen",
    "gefluchte": "geflucht",
    "gefluchtem": "geflucht",
    "gefluchten": "geflucht",
    "gefluchter": "geflucht",
    "gefluchtes": "geflucht",
    "gefluchtet": "fluchten",
    "gefluchtete": "gefluchtet",
    "gefluchtetem": "gefluchtet",
    "gefluchteten": "gefluchtet",
    "gefluchteter": "gefluchtet",
    "gefluchtetes": "gefluchtet",
    "geflunkert": "flunkern",
    "geflunkerte": "geflunkert",
    "geflunkertem": "geflunkert",
    "geflunkerten": "geflunkert",
    "geflunkerter": "geflunkert",
    "geflunkertes": "geflunkert",
    "gefluppt": "fluppen",
    "gefluppte": "gefluppt",
    "geflupptem": "gefluppt",
    "gefluppten": "gefluppt",
    "gefluppter": "gefluppt",
    "geflupptes": "gefluppt",
    "geflutet": "fluten",
    "geflutete": "geflutet",
    "geflutetem": "geflutet",
    "gefluteten": "geflutet",
    "gefluteter": "geflutet",
    "geflutetes": "geflutet",
    "geflutscht": "flutschen",
    "geflutschte": "geflutscht",
    "geflutschtem": "geflutscht",
    "geflutschten": "geflutscht",
    "geflutschter": "geflutscht",
    "geflutschtere": "geflutscht",
    "geflutschterem": "geflutscht",
    "geflutschteren": "geflutscht",
    "geflutschterer": "geflutscht",
    "geflutschteres": "geflutscht",
    "geflutschtes": "geflutscht",
    "geflutschteste": "geflutscht",
    "geflutschtestem": "geflutscht",
    "geflutschtesten": "geflutscht",
    "geflutschtester": "geflutscht",
    "geflutschtestes": "geflutscht",
    "geflämmt": "flämmen",
    "geflämmtem": "geflämmt",
    "geflämmter": "geflämmt",
    "geflämmterem": "geflämmt",
    "geflämmterer": "geflämmt",
    "geflämmteres": "geflämmt",
    "geflämmtes": "geflämmt",
    "geflämmtestem": "geflämmt",
    "geflämmtester": "geflämmt",
    "geflämmtestes": "geflämmt",
    "gefläzt": "fläzen",
    "gefläzte": "gefläzt",
    "gefläztem": "gefläzt",
    "gefläzten": "gefläzt",
    "gefläzter": "gefläzt",
    "gefläztes": "gefläzt",
    "geflötet": "flöten",
    "geflötete": "geflötet",
    "geflötetem": "geflötet",
    "geflöteten": "geflötet",
    "geflöteter": "geflötet",
    "geflötetes": "geflötet",
    "geflößt": "flößen",
    "geflößte": "geflößt",
    "geflößtem": "geflößt",
    "geflößten": "geflößt",
    "geflößter": "geflößt",
    "geflößtes": "geflößt",
    "geflüchtet": "flüchten",
    "geflüchtetem": "geflüchtet",
    "geflüchteter": "geflüchtet",
    "geflüchtetes": "geflüchtet",
    "geflügeltem": "geflügelt",
    "geflügelten": "geflügelt",
    "geflügelter": "geflügelt",
    "geflügeltes": "geflügelt",
    "geflüstert": "flüstern",
    "geflüsterte": "geflüstert",
    "geflüstertem": "geflüstert",
    "geflüsterten": "geflüstert",
    "geflüsterter": "geflüstert",
    "geflüstertes": "geflüstert",
    "gefochten": "fechten",
    "gefochtene": "gefochten",
    "gefochtenem": "gefochten",
    "gefochtenen": "gefochten",
    "gefochtener": "gefochten",
    "gefochtenes": "gefochten",
    "gefolgert": "folgern",
    "gefolgerte": "gefolgert",
    "gefolgertem": "gefolgert",
    "gefolgerten": "gefolgert",
    "gefolgerter": "gefolgert",
    "gefolgertes": "gefolgert",
    "gefolgt": "folgen",
    "gefolgte": "gefolgt",
    "gefolgtem": "gefolgt",
    "gefolgten": "gefolgt",
    "gefolgter": "gefolgt",
    "gefolgtere": "gefolgt",
    "gefolgterem": "gefolgt",
    "gefolgteren": "gefolgt",
    "gefolgterer": "gefolgt",
    "gefolgteres": "gefolgt",
    "gefolgtes": "gefolgt",
    "gefolgteste": "gefolgt",
    "gefolgtestem": "gefolgt",
    "gefolgtesten": "gefolgt",
    "gefolgtester": "gefolgt",
    "gefolgtestes": "gefolgt",
    "gefoltert": "foltern",
    "gefolterte": "gefoltert",
    "gefoltertem": "gefoltert",
    "gefolterten": "gefoltert",
    "gefolterter": "gefoltert",
    "gefoltertere": "gefoltert",
    "gefolterterem": "gefoltert",
    "gefolterteren": "gefoltert",
    "gefolterterer": "gefoltert",
    "gefolterteres": "gefoltert",
    "gefoltertes": "gefoltert",
    "gefolterteste": "gefoltert",
    "gefoltertestem": "gefoltert",
    "gefoltertesten": "gefoltert",
    "gefoltertester": "gefoltert",
    "gefoltertestes": "gefoltert",
    "gefoppt": "foppen",
    "gefoppte": "gefoppt",
    "gefopptem": "gefoppt",
    "gefoppten": "gefoppt",
    "gefoppter": "gefoppt",
    "gefopptere": "gefoppt",
    "gefoppterem": "gefoppt",
    "gefoppteren": "gefoppt",
    "gefoppterer": "gefoppt",
    "gefoppteres": "gefoppt",
    "gefopptes": "gefoppt",
    "gefoppteste": "gefoppt",
    "gefopptestem": "gefoppt",
    "gefopptesten": "gefoppt",
    "gefopptester": "gefoppt",
    "gefopptestes": "gefoppt",
    "gefordert": "fordern",
    "geforderte": "gefordert",
    "gefordertem": "gefordert",
    "geforderten": "gefordert",
    "geforderter": "gefordert",
    "gefordertere": "gefordert",
    "geforderterem": "gefordert",
    "geforderteren": "gefordert",
    "geforderterer": "gefordert",
    "geforderteres": "gefordert",
    "gefordertes": "gefordert",
    "geforderteste": "gefordert",
    "gefordertestem": "gefordert",
    "gefordertesten": "gefordert",
    "gefordertester": "gefordert",
    "gefordertestes": "gefordert",
    "geformt": "formen",
    "geformte": "geformt",
    "geformtem": "geformt",
    "geformten": "geformt",
    "geformter": "geformt",
    "geformtere": "geformt",
    "geformterem": "geformt",
    "geformteren": "geformt",
    "geformterer": "geformt",
    "geformteres": "geformt",
    "geformtes": "geformt",
    "geformteste": "geformt",
    "geformtestem": "geformt",
    "geformtesten": "geformt",
    "geformtester": "geformt",
    "geformtestes": "geformt",
    "geforscht": "forschen",
    "geforschte": "geforscht",
    "geforschtem": "geforscht",
    "geforschten": "geforscht",
    "geforschter": "geforscht",
    "geforschtes": "geforscht",
    "geforstet": "forsten",
    "geforstete": "geforstet",
    "geforstetem": "geforstet",
    "geforsteten": "geforstet",
    "geforsteter": "geforstet",
    "geforstetes": "geforstet",
    "gefoult": "foulen",
    "gefoulte": "gefoult",
    "gefoultem": "gefoult",
    "gefoulten": "gefoult",
    "gefoulter": "gefoult",
    "gefoultere": "gefoult",
    "gefoulterem": "gefoult",
    "gefoulteren": "gefoult",
    "gefoulterer": "gefoult",
    "gefoulteres": "gefoult",
    "gefoultes": "gefoult",
    "gefoulteste": "gefoult",
    "gefoultestem": "gefoult",
    "gefoultesten": "gefoult",
    "gefoultester": "gefoult",
    "gefoultestes": "gefoult",
    "gefrachtet": "frachten",
    "gefrachtete": "gefrachtet",
    "gefrachtetem": "gefrachtet",
    "gefrachteten": "gefrachtet",
    "gefrachteter": "gefrachtet",
    "gefrachtetere": "gefrachtet",
    "gefrachteterem": "gefrachtet",
    "gefrachteteren": "gefrachtet",
    "gefrachteterer": "gefrachtet",
    "gefrachteteres": "gefrachtet",
    "gefrachtetes": "gefrachtet",
    "gefrachteteste": "gefrachtet",
    "gefrachtetestem": "gefrachtet",
    "gefrachtetesten": "gefrachtet",
    "gefrachtetester": "gefrachtet",
    "gefrachtetestes": "gefrachtet",
    "gefragt": "fragen",
    "gefragte": "gefragt",
    "gefragtem": "gefragt",
    "gefragten": "gefragt",
    "gefragter": "gefragt",
    "gefragtere": "gefragt",
    "gefragterem": "gefragt",
    "gefragteren": "gefragt",
    "gefragterer": "gefragt",
    "gefragteres": "gefragt",
    "gefragtes": "gefragt",
    "gefragteste": "gefragt",
    "gefragtestem": "gefragt",
    "gefragtesten": "gefragt",
    "gefragtester": "gefragt",
    "gefragtestes": "gefragt",
    "gefranst": "fransen",
    "gefranste": "gefranst",
    "gefranstem": "gefranst",
    "gefransten": "gefranst",
    "gefranster": "gefranst",
    "gefranstere": "gefranst",
    "gefransterem": "gefranst",
    "gefransteren": "gefranst",
    "gefransterer": "gefranst",
    "gefransteres": "gefranst",
    "gefranstes": "gefranst",
    "gefransteste": "gefranst",
    "gefranstestem": "gefranst",
    "gefranstesten": "gefranst",
    "gefranstester": "gefranst",
    "gefranstestes": "gefranst",
    "gefranzt": "franzen",
    "gefranzte": "gefranzt",
    "gefranztem": "gefranzt",
    "gefranzten": "gefranzt",
    "gefranzter": "gefranzt",
    "gefranztere": "gefranzt",
    "gefranzterem": "gefranzt",
    "gefranzteren": "gefranzt",
    "gefranzterer": "gefranzt",
    "gefranzteres": "gefranzt",
    "gefranztes": "gefranzt",
    "gefranzteste": "gefranzt",
    "gefranztestem": "gefranzt",
    "gefranztesten": "gefranzt",
    "gefranztester": "gefranzt",
    "gefranztestes": "gefranzt",
    "gefremdelt": "fremdeln",
    "gefremdelte": "gefremdelt",
    "gefremdeltem": "gefremdelt",
    "gefremdelten": "gefremdelt",
    "gefremdelter": "gefremdelt",
    "gefremdeltes": "gefremdelt",
    "gefressen": "fressen",
    "gefressene": "gefressen",
    "gefressenem": "gefressen",
    "gefressenen": "gefressen",
    "gefressener": "gefressen",
    "gefressenes": "gefressen",
    "gefreundet": "freunden",
    "gefreundete": "gefreundet",
    "gefreundetem": "gefreundet",
    "gefreundeten": "gefreundet",
    "gefreundeter": "gefreundet",
    "gefreundetes": "gefreundet",
    "gefreut": "freuen",
    "gefreute": "gefreut",
    "gefreutem": "gefreut",
    "gefreuten": "gefreut",
    "gefreuter": "gefreut",
    "gefreutes": "gefreut",
    "gefrevelt": "freveln",
    "gefrevelte": "gefrevelt",
    "gefreveltem": "gefrevelt",
    "gefrevelten": "gefrevelt",
    "gefrevelter": "gefrevelt",
    "gefreveltere": "gefrevelt",
    "gefrevelterem": "gefrevelt",
    "gefrevelteren": "gefrevelt",
    "gefrevelterer": "gefrevelt",
    "gefrevelteres": "gefrevelt",
    "gefreveltes": "gefrevelt",
    "gefrevelteste": "gefrevelt",
    "gefreveltestem": "gefrevelt",
    "gefreveltesten": "gefrevelt",
    "gefreveltester": "gefrevelt",
    "gefreveltestes": "gefrevelt",
    "gefriere": "gefrieren",
    "gefrierend": "gefrieren",
    "gefrierende": "gefrierend",
    "gefrierendem": "gefrierend",
    "gefrierenden": "gefrierend",
    "gefrierender": "gefrierend",
    "gefrierendes": "gefrierend",
    "gefrierest": "gefrieren",
    "gefrieret": "gefrieren",
    "gefrierst": "gefrieren",
    "gefriert": "gefrieren",
    "gefrischt": "frischen",
    "gefrischte": "gefrischt",
    "gefrischtem": "gefrischt",
    "gefrischten": "gefrischt",
    "gefrischter": "gefrischt",
    "gefrischtes": "gefrischt",
    "gefristet": "fristen",
    "gefristete": "gefristet",
    "gefristetem": "gefristet",
    "gefristeten": "gefristet",
    "gefristeter": "gefristet",
    "gefristetes": "gefristet",
    "gefror": "gefrieren",
    "gefroren": "gefrieren",
    "gefrorene": "gefroren",
    "gefrorenem": "gefroren",
    "gefrorenen": "gefroren",
    "gefrorener": "gefroren",
    "gefrorenere": "gefroren",
    "gefrorenerem": "gefroren",
    "gefroreneren": "gefroren",
    "gefrorenerer": "gefroren",
    "gefroreneres": "gefroren",
    "gefrorenes": "gefroren",
    "gefrorenste": "gefroren",
    "gefrorenstem": "gefroren",
    "gefrorensten": "gefroren",
    "gefrorenster": "gefroren",
    "gefrorenstes": "gefroren",
    "gefrorst": "gefrieren",
    "gefrort": "gefrieren",
    "gefrotzelt": "frotzeln",
    "gefrotzelte": "gefrotzelt",
    "gefrotzeltem": "gefrotzelt",
    "gefrotzelten": "gefrotzelt",
    "gefrotzelter": "gefrotzelt",
    "gefrotzeltere": "gefrotzelt",
    "gefrotzelterem": "gefrotzelt",
    "gefrotzelteren": "gefrotzelt",
    "gefrotzelterer": "gefrotzelt",
    "gefrotzelteres": "gefrotzelt",
    "gefrotzeltes": "gefrotzelt",
    "gefrotzelteste": "gefrotzelt",
    "gefrotzeltestem": "gefrotzelt",
    "gefrotzeltesten": "gefrotzelt",
    "gefrotzeltester": "gefrotzelt",
    "gefrotzeltestes": "gefrotzelt",
    "gefruchtet": "fruchten",
    "gefruchtete": "gefruchtet",
    "gefruchtetem": "gefruchtet",
    "gefruchteten": "gefruchtet",
    "gefruchteter": "gefruchtet",
    "gefruchtetere": "gefruchtet",
    "gefruchteterem": "gefruchtet",
    "gefruchteteren": "gefruchtet",
    "gefruchteterer": "gefruchtet",
    "gefruchteteres": "gefruchtet",
    "gefruchtetes": "gefruchtet",
    "gefruchteteste": "gefruchtet",
    "gefruchtetestem": "gefruchtet",
    "gefruchtetesten": "gefruchtet",
    "gefruchtetester": "gefruchtet",
    "gefruchtetestes": "gefruchtet",
    "gefrustet": "frusten",
    "gefrustete": "gefrustet",
    "gefrustetem": "gefrustet",
    "gefrusteten": "gefrustet",
    "gefrusteter": "gefrustet",
    "gefrustetere": "gefrustet",
    "gefrusteterem": "gefrustet",
    "gefrusteteren": "gefrustet",
    "gefrusteterer": "gefrustet",
    "gefrusteteres": "gefrustet",
    "gefrustetes": "gefrustet",
    "gefrusteteste": "gefrustet",
    "gefrustetestem": "gefrustet",
    "gefrustetesten": "gefrustet",
    "gefrustetester": "gefrustet",
    "gefrustetestes": "gefrustet",
    "gefräst": "fräsen",
    "gefräste": "gefräst",
    "gefrästem": "gefräst",
    "gefrästen": "gefräst",
    "gefräster": "gefräst",
    "gefrästes": "gefräst",
    "gefröre": "gefrieren",
    "gefrören": "gefrieren",
    "gefrörest": "gefrieren",
    "gefröret": "gefrieren",
    "gefröstelt": "frösteln",
    "gefröstelte": "gefröstelt",
    "gefrösteltem": "gefröstelt",
    "gefröstelten": "gefröstelt",
    "gefröstelter": "gefröstelt",
    "gefrösteltere": "gefröstelt",
    "gefröstelterem": "gefröstelt",
    "gefröstelteren": "gefröstelt",
    "gefröstelterer": "gefröstelt",
    "gefröstelteres": "gefröstelt",
    "gefrösteltes": "gefröstelt",
    "gefröstelteste": "gefröstelt",
    "gefrösteltestem": "gefröstelt",
    "gefrösteltesten": "gefröstelt",
    "gefrösteltester": "gefröstelt",
    "gefrösteltestes": "gefröstelt",
    "gefuchtelt": "fuchteln",
    "gefuchtelte": "gefuchtelt",
    "gefuchteltem": "gefuchtelt",
    "gefuchtelten": "gefuchtelt",
    "gefuchtelter": "gefuchtelt",
    "gefuchteltes": "gefuchtelt",
    "gefugt": "fugen",
    "gefugte": "gefugt",
    "gefugtem": "gefugt",
    "gefugten": "gefugt",
    "gefugter": "gefugt",
    "gefugtere": "gefugt",
    "gefugterem": "gefugt",
    "gefugteren": "gefugt",
    "gefugterer": "gefugt",
    "gefugteres": "gefugt",
    "gefugtes": "gefugt",
    "gefugteste": "gefugt",
    "gefugtestem": "gefugt",
    "gefugtesten": "gefugt",
    "gefugtester": "gefugt",
    "gefugtestes": "gefugt",
    "gefummelt": "fummeln",
    "gefummelte": "gefummelt",
    "gefummeltem": "gefummelt",
    "gefummelten": "gefummelt",
    "gefummelter": "gefummelt",
    "gefummeltere": "gefummelt",
    "gefummelterem": "gefummelt",
    "gefummelteren": "gefummelt",
    "gefummelterer": "gefummelt",
    "gefummelteres": "gefummelt",
    "gefummeltes": "gefummelt",
    "gefummelteste": "gefummelt",
    "gefummeltestem": "gefummelt",
    "gefummeltesten": "gefummelt",
    "gefummeltester": "gefummelt",
    "gefummeltestes": "gefummelt",
    "gefunden": "finden",
    "gefundene": "gefunden",
    "gefundenem": "gefunden",
    "gefundenen": "gefunden",
    "gefundener": "gefunden",
    "gefundenere": "gefunden",
    "gefundenerem": "gefunden",
    "gefundeneren": "gefunden",
    "gefundenerer": "gefunden",
    "gefundeneres": "gefunden",
    "gefundenes": "gefunden",
    "gefundenste": "gefunden",
    "gefundenstem": "gefunden",
    "gefundensten": "gefunden",
    "gefundenster": "gefunden",
    "gefundenstes": "gefunden",
    "gefunkelt": "funkeln",
    "gefunkelte": "gefunkelt",
    "gefunkeltem": "gefunkelt",
    "gefunkelten": "gefunkelt",
    "gefunkelter": "gefunkelt",
    "gefunkeltes": "gefunkelt",
    "gefunkt": "funken",
    "gefunkte": "gefunkt",
    "gefunktem": "gefunkt",
    "gefunkten": "gefunkt",
    "gefunkter": "gefunkt",
    "gefunktes": "gefunkt",
    "gefurzt": "furzen",
    "gefurzte": "gefurzt",
    "gefurztem": "gefurzt",
    "gefurzten": "gefurzt",
    "gefurzter": "gefurzt",
    "gefurztes": "gefurzt",
    "gefusselt": "fusseln",
    "gefusselte": "gefusselt",
    "gefusseltem": "gefusselt",
    "gefusselten": "gefusselt",
    "gefusselter": "gefusselt",
    "gefusseltes": "gefusselt",
    "gefuttert": "futtern",
    "gefutterte": "gefuttert",
    "gefuttertem": "gefuttert",
    "gefutterten": "gefuttert",
    "gefutterter": "gefuttert",
    "gefuttertes": "gefuttert",
    "gefußt": "fußen",
    "gefußte": "gefußt",
    "gefußtem": "gefußt",
    "gefußten": "gefußt",
    "gefußter": "gefußt",
    "gefußtes": "gefußt",
    "gefächelt": "fächeln",
    "gefächelte": "gefächelt",
    "gefächeltem": "gefächelt",
    "gefächelten": "gefächelt",
    "gefächelter": "gefächelt",
    "gefächeltes": "gefächelt",
    "gefächert": "fächern",
    "gefächerte": "gefächert",
    "gefächertem": "gefächert",
    "gefächerten": "gefächert",
    "gefächerter": "gefächert",
    "gefächertes": "gefächert",
    "gefädelt": "fädeln",
    "gefädelte": "gefädelt",
    "gefädeltem": "gefädelt",
    "gefädelten": "gefädelt",
    "gefädelter": "gefädelt",
    "gefädeltes": "gefädelt",
    "gefährde": "gefährden",
    "gefährdend": "gefährden",
    "gefährdende": "gefährdend",
    "gefährdendem": "gefährdend",
    "gefährdenden": "gefährdend",
    "gefährdender": "gefährdend",
    "gefährdendere": "gefährdend",
    "gefährdenderem": "gefährdend",
    "gefährdenderen": "gefährdend",
    "gefährdenderer": "gefährdend",
    "gefährdenderes": "gefährdend",
    "gefährdendes": "gefährdend",
    "gefährdendste": "gefährdend",
    "gefährdendstem": "gefährdend",
    "gefährdendsten": "gefährdend",
    "gefährdendster": "gefährdend",
    "gefährdendstes": "gefährdend",
    "gefährdest": "gefährden",
    "gefährdet": "gefährden",
    "gefährdete": "gefährden",
    "gefährdetem": "gefährdet",
    "gefährdeten": "gefährden",
    "gefährdeter": "gefährdet",
    "gefährdetere": "gefährdet",
    "gefährdeterem": "gefährdet",
    "gefährdeteren": "gefährdet",
    "gefährdeterer": "gefährdet",
    "gefährdeteres": "gefährdet",
    "gefährdetes": "gefährdet",
    "gefährdetest": "gefährden",
    "gefährdeteste": "gefährdet",
    "gefährdetestem": "gefährdet",
    "gefährdetesten": "gefährdet",
    "gefährdetester": "gefährdet",
    "gefährdetestes": "gefährdet",
    "gefährdetet": "gefährden",
    "gefährliche": "gefährlich",
    "gefährlichem": "gefährlich",
    "gefährlichen": "gefährlich",
    "gefährlicher": "gefährlich",
    "gefährlichere": "gefährlich",
    "gefährlicherem": "gefährlich",
    "gefährlicheren": "gefährlich",
    "gefährlicherer": "gefährlich",
    "gefährlicheres": "gefährlich",
    "gefährliches": "gefährlich",
    "gefährlichste": "gefährlich",
    "gefährlichstem": "gefährlich",
    "gefährlichsten": "gefährlich",
    "gefährlichster": "gefährlich",
    "gefährlichstes": "gefährlich",
    "gefällige": "gefällig",
    "gefälligem": "gefällig",
    "gefälligen": "gefällig",
    "gefälliger": "gefällig",
    "gefälligere": "gefällig",
    "gefälligerem": "gefällig",
    "gefälligeren": "gefällig",
    "gefälligerer": "gefällig",
    "gefälligeres": "gefällig",
    "gefälliges": "gefällig",
    "gefälligstem": "gefällig",
    "gefälligsten": "gefällig",
    "gefälligster": "gefällig",
    "gefälligstes": "gefällig",
    "gefällst": "gefallen",
    "gefällt": "gefallen",
    "gefällte": "gefällt",
    "gefälltem": "gefällt",
    "gefällten": "gefällt",
    "gefällter": "gefällt",
    "gefälltes": "gefällt",
    "gefälscht": "fälschen",
    "gefälschte": "gefälscht",
    "gefälschtem": "gefälscht",
    "gefälschten": "gefälscht",
    "gefälschter": "gefälscht",
    "gefälschtes": "gefälscht",
    "gefärbt": "färben",
    "gefärbte": "gefärbt",
    "gefärbtem": "gefärbt",
    "gefärbten": "gefärbt",
    "gefärbter": "gefärbt",
    "gefärbtere": "gefärbt",
    "gefärbterem": "gefärbt",
    "gefärbteren": "gefärbt",
    "gefärbterer": "gefärbt",
    "gefärbteres": "gefärbt",
    "gefärbtes": "gefärbt",
    "gefärbteste": "gefärbt",
    "gefärbtestem": "gefärbt",
    "gefärbtesten": "gefärbt",
    "gefärbtester": "gefärbt",
    "gefärbtestes": "gefärbt",
    "geföhnt": "föhnen",
    "geföhnte": "geföhnt",
    "geföhntem": "geföhnt",
    "geföhnten": "geföhnt",
    "geföhnter": "geföhnt",
    "geföhntes": "geföhnt",
    "gefönt": "fönen",
    "gefönte": "gefönt",
    "geföntem": "gefönt",
    "gefönten": "gefönt",
    "gefönter": "gefönt",
    "geföntes": "gefönt",
    "gefördert": "fördern",
    "gefördertem": "gefördert",
    "geförderter": "gefördert",
    "geförderterem": "gefördert",
    "geförderterer": "gefördert",
    "geförderteres": "gefördert",
    "gefördertes": "gefördert",
    "gefördertestem": "gefördert",
    "gefördertester": "gefördert",
    "gefördertestes": "gefördert",
    "gefügigem": "gefügig",
    "gefügigen": "gefügig",
    "gefügiger": "gefügig",
    "gefügigere": "gefügig",
    "gefügigerem": "gefügig",
    "gefügigeren": "gefügig",
    "gefügigerer": "gefügig",
    "gefügigeres": "gefügig",
    "gefügiges": "gefügig",
    "gefügigste": "gefügig",
    "gefügigstem": "gefügig",
    "gefügigsten": "gefügig",
    "gefügigster": "gefügig",
    "gefügigstes": "gefügig",
    "gefügt": "fügen",
    "gefügtem": "gefügt",
    "gefügter": "gefügt",
    "gefügtes": "gefügt",
    "gefühllosem": "gefühllos",
    "gefühllosen": "gefühllos",
    "gefühlloser": "gefühllos",
    "gefühllosere": "gefühllos",
    "gefühlloserem": "gefühllos",
    "gefühlloseren": "gefühllos",
    "gefühlloserer": "gefühllos",
    "gefühlloseres": "gefühllos",
    "gefühlloses": "gefühllos",
    "gefühlloseste": "gefühllos",
    "gefühllosestem": "gefühllos",
    "gefühllosesten": "gefühllos",
    "gefühllosester": "gefühllos",
    "gefühllosestes": "gefühllos",
    "gefühlsbetontem": "gefühlsbetont",
    "gefühlsbetonten": "gefühlsbetont",
    "gefühlsbetonter": "gefühlsbetont",
    "gefühlsbetontere": "gefühlsbetont",
    "gefühlsbetonterem": "gefühlsbetont",
    "gefühlsbetonteren": "gefühlsbetont",
    "gefühlsbetonterer": "gefühlsbetont",
    "gefühlsbetonteres": "gefühlsbetont",
    "gefühlsbetontes": "gefühlsbetont",
    "gefühlsbetonteste": "gefühlsbetont",
    "gefühlsbetontestem": "gefühlsbetont",
    "gefühlsbetontesten": "gefühlsbetont",
    "gefühlsbetontester": "gefühlsbetont",
    "gefühlsbetontestes": "gefühlsbetont",
    "gefühlskalte": "gefühlskalt",
    "gefühlskaltem": "gefühlskalt",
    "gefühlskalten": "gefühlskalt",
    "gefühlskalter": "gefühlskalt",
    "gefühlskaltes": "gefühlskalt",
    "gefühlskälter": "gefühlskalt",
    "gefühlskältere": "gefühlskalt",
    "gefühlskälterem": "gefühlskalt",
    "gefühlskälteren": "gefühlskalt",
    "gefühlskälterer": "gefühlskalt",
    "gefühlskälteres": "gefühlskalt",
    "gefühlskälteste": "gefühlskalt",
    "gefühlskältestem": "gefühlskalt",
    "gefühlskältesten": "gefühlskalt",
    "gefühlskältester": "gefühlskalt",
    "gefühlskältestes": "gefühlskalt",
    "gefühlsmäßige": "gefühlsmäßig",
    "gefühlsmäßigem": "gefühlsmäßig",
    "gefühlsmäßigen": "gefühlsmäßig",
    "gefühlsmäßiger": "gefühlsmäßig",
    "gefühlsmäßiges": "gefühlsmäßig",
    "gefühlt": "fühlen",
    "gefühlte": "gefühlt",
    "gefühltem": "gefühlt",
    "gefühlten": "gefühlt",
    "gefühlter": "gefühlt",
    "gefühltes": "gefühlt",
    "gefühlvolle": "gefühlvoll",
    "gefühlvollem": "gefühlvoll",
    "gefühlvollen": "gefühlvoll",
    "gefühlvoller": "gefühlvoll",
    "gefühlvollere": "gefühlvoll",
    "gefühlvollerem": "gefühlvoll",
    "gefühlvolleren": "gefühlvoll",
    "gefühlvollerer": "gefühlvoll",
    "gefühlvolleres": "gefühlvoll",
    "gefühlvolles": "gefühlvoll",
    "gefühlvollste": "gefühlvoll",
    "gefühlvollstem": "gefühlvoll",
    "gefühlvollsten": "gefühlvoll",
    "gefühlvollster": "gefühlvoll",
    "gefühlvollstes": "gefühlvoll",
    "geführt": "führen",
    "geführte": "geführt",
    "geführtem": "geführt",
    "geführten": "geführt",
    "geführter": "geführt",
    "geführtere": "geführt",
    "geführterem": "geführt",
    "geführteren": "geführt",
    "geführterer": "geführt",
    "geführteres": "geführt",
    "geführtes": "geführt",
    "geführteste": "geführt",
    "geführtestem": "geführt",
    "geführtesten": "geführt",
    "geführtester": "geführt",
    "geführtestes": "geführt",
    "gefüllt": "füllen",
    "gefüllte": "gefüllt",
    "gefülltem": "gefüllt",
    "gefüllten": "gefüllt",
    "gefüllter": "gefüllt",
    "gefülltere": "gefüllt",
    "gefüllterem": "gefüllt",
    "gefüllteren": "gefüllt",
    "gefüllterer": "gefüllt",
    "gefüllteres": "gefüllt",
    "gefülltes": "gefüllt",
    "gefüllteste": "gefüllt",
    "gefülltestem": "gefüllt",
    "gefülltesten": "gefüllt",
    "gefülltester": "gefüllt",
    "gefülltestes": "gefüllt",
    "gefürchtet": "fürchten",
    "gefürchtete": "gefürchtet",
    "gefürchtetem": "gefürchtet",
    "gefürchteten": "gefürchtet",
    "gefürchteter": "gefürchtet",
    "gefürchtetere": "gefürchtet",
    "gefürchteterem": "gefürchtet",
    "gefürchteteren": "gefürchtet",
    "gefürchteterer": "gefürchtet",
    "gefürchteteres": "gefürchtet",
    "gefürchtetes": "gefürchtet",
    "gefürchteteste": "gefürchtet",
    "gefürchtetestem": "gefürchtet",
    "gefürchtetesten": "gefürchtet",
    "gefürchtetester": "gefürchtet",
    "gefürchtetestes": "gefürchtet",
    "gefüttert": "füttern",
    "gefüttertem": "gefüttert",
    "gefütterter": "gefüttert",
    "gefüttertes": "gefüttert",
    "gegabelt": "gabeln",
    "gegabelte": "gegabelt",
    "gegabeltem": "gegabelt",
    "gegabelten": "gegabelt",
    "gegabelter": "gegabelt",
    "gegabeltes": "gegabelt",
    "gegafft": "gaffen",
    "gegaffte": "gegafft",
    "gegafftem": "gegafft",
    "gegafften": "gegafft",
    "gegaffter": "gegafft",
    "gegafftes": "gegafft",
    "gegammelt": "gammeln",
    "gegammelte": "gegammelt",
    "gegammeltem": "gegammelt",
    "gegammelten": "gegammelt",
    "gegammelter": "gegammelt",
    "gegammeltes": "gegammelt",
    "gegangen": "gehen",
    "gegangene": "gegangen",
    "gegangenem": "gegangen",
    "gegangenen": "gegangen",
    "gegangener": "gegangen",
    "gegangenes": "gegangen",
    "gegart": "garen",
    "gegarte": "gegart",
    "gegartem": "gegart",
    "gegarten": "gegart",
    "gegarter": "gegart",
    "gegartere": "gegart",
    "gegarterem": "gegart",
    "gegarteren": "gegart",
    "gegarterer": "gegart",
    "gegarteres": "gegart",
    "gegartes": "gegart",
    "gegarteste": "gegart",
    "gegartestem": "gegart",
    "gegartesten": "gegart",
    "gegartester": "gegart",
    "gegartestes": "gegart",
    "gegast": "gasen",
    "gegaste": "gegast",
    "gegastem": "gegast",
    "gegasten": "gegast",
    "gegaster": "gegast",
    "gegastes": "gegast",
    "gegaukelt": "gaukeln",
    "gegaukelte": "gegaukelt",
    "gegaukeltem": "gegaukelt",
    "gegaukelten": "gegaukelt",
    "gegaukelter": "gegaukelt",
    "gegaukeltes": "gegaukelt",
    "gegaunert": "gaunern",
    "gegaunerte": "gegaunert",
    "gegaunertem": "gegaunert",
    "gegaunerten": "gegaunert",
    "gegaunerter": "gegaunert",
    "gegaunertes": "gegaunert",
    "gegeben": "geben",
    "gegebene": "gegeben",
    "gegebenem": "gegeben",
    "gegebenen": "gegeben",
    "gegebener": "gegeben",
    "gegebenes": "gegeben",
    "gegehrt": "gehren",
    "gegehrte": "gegehrt",
    "gegehrtem": "gegehrt",
    "gegehrten": "gegehrt",
    "gegehrter": "gegehrt",
    "gegehrtes": "gegehrt",
    "gegeigt": "geigen",
    "gegeigte": "gegeigt",
    "gegeigtem": "gegeigt",
    "gegeigten": "gegeigt",
    "gegeigter": "gegeigt",
    "gegeigtes": "gegeigt",
    "gegeilt": "geilen",
    "gegeilte": "gegeilt",
    "gegeiltem": "gegeilt",
    "gegeilten": "gegeilt",
    "gegeilter": "gegeilt",
    "gegeiltes": "gegeilt",
    "gegeistert": "geistern",
    "gegeisterte": "gegeistert",
    "gegeistertem": "gegeistert",
    "gegeisterten": "gegeistert",
    "gegeisterter": "gegeistert",
    "gegeistertes": "gegeistert",
    "gegeizt": "geizen",
    "gegeizte": "gegeizt",
    "gegeiztem": "gegeizt",
    "gegeizten": "gegeizt",
    "gegeizter": "gegeizt",
    "gegeiztes": "gegeizt",
    "gegeißelt": "geißeln",
    "gegeißelte": "gegeißelt",
    "gegeißeltem": "gegeißelt",
    "gegeißelten": "gegeißelt",
    "gegeißelter": "gegeißelt",
    "gegeißeltere": "gegeißelt",
    "gegeißelterem": "gegeißelt",
    "gegeißelteren": "gegeißelt",
    "gegeißelterer": "gegeißelt",
    "gegeißelteres": "gegeißelt",
    "gegeißeltes": "gegeißelt",
    "gegeißelteste": "gegeißelt",
    "gegeißeltestem": "gegeißelt",
    "gegeißeltesten": "gegeißelt",
    "gegeißeltester": "gegeißelt",
    "gegeißeltestes": "gegeißelt",
    "gegenbuche": "gegenbuchen",
    "gegenbuchend": "gegenbuchen",
    "gegenbuchende": "gegenbuchend",
    "gegenbuchendem": "gegenbuchend",
    "gegenbuchenden": "gegenbuchend",
    "gegenbuchender": "gegenbuchend",
    "gegenbuchendes": "gegenbuchend",
    "gegenbuchest": "gegenbuchen",
    "gegenbuchet": "gegenbuchen",
    "gegenbuchst": "gegenbuchen",
    "gegenbucht": "gegenbuchen",
    "gegenbuchte": "gegenbuchen",
    "gegenbuchten": "gegenbuchen",
    "gegenbuchtest": "gegenbuchen",
    "gegenbuchtet": "gegenbuchen",
    "gegengebucht": "gegenbuchen",
    "gegengebuchte": "gegengebucht",
    "gegengebuchtem": "gegengebucht",
    "gegengebuchten": "gegengebucht",
    "gegengebuchter": "gegengebucht",
    "gegengebuchtes": "gegengebucht",
    "gegengelenkt": "gegenlenken",
    "gegengelenkte": "gegengelenkt",
    "gegengelenktem": "gegengelenkt",
    "gegengelenkten": "gegengelenkt",
    "gegengelenkter": "gegengelenkt",
    "gegengelenktes": "gegengelenkt",
    "gegengelesen": "gegenlesen",
    "gegengelesene": "gegengelesen",
    "gegengelesenem": "gegengelesen",
    "gegengelesenen": "gegengelesen",
    "gegengelesener": "gegengelesen",
    "gegengelesenes": "gegengelesen",
    "gegengesteuert": "gegensteuern",
    "gegengesteuerte": "gegengesteuert",
    "gegengesteuertem": "gegengesteuert",
    "gegengesteuerten": "gegengesteuert",
    "gegengesteuerter": "gegengesteuert",
    "gegengesteuertes": "gegengesteuert",
    "gegengezeichnet": "gegenzeichnen",
    "gegengezeichnete": "gegengezeichnet",
    "gegengezeichnetem": "gegengezeichnet",
    "gegengezeichneten": "gegengezeichnet",
    "gegengezeichneter": "gegengezeichnet",
    "gegengezeichnetes": "gegengezeichnet",
    "gegenlas": "gegenlesen",
    "gegenlasen": "gegenlesen",
    "gegenlast": "gegenlesen",
    "gegenlenke": "gegenlenken",
    "gegenlenkend": "gegenlenken",
    "gegenlenkende": "gegenlenkend",
    "gegenlenkendem": "gegenlenkend",
    "gegenlenkenden": "gegenlenkend",
    "gegenlenkender": "gegenlenkend",
    "gegenlenkendes": "gegenlenkend",
    "gegenlenkest": "gegenlenken",
    "gegenlenket": "gegenlenken",
    "gegenlenkst": "gegenlenken",
    "gegenlenkt": "gegenlenken",
    "gegenlenkte": "gegenlenken",
    "gegenlenkten": "gegenlenken",
    "gegenlenktest": "gegenlenken",
    "gegenlenktet": "gegenlenken",
    "gegenlese": "gegenlesen",
    "gegenlesend": "gegenlesen",
    "gegenlesende": "gegenlesend",
    "gegenlesendem": "gegenlesend",
    "gegenlesenden": "gegenlesend",
    "gegenlesender": "gegenlesend",
    "gegenlesendes": "gegenlesend",
    "gegenlesest": "gegenlesen",
    "gegenleset": "gegenlesen",
    "gegenlest": "gegenlesen",
    "gegenliest": "gegenlesen",
    "gegenläse": "gegenlesen",
    "gegenläsen": "gegenlesen",
    "gegenläsest": "gegenlesen",
    "gegenläset": "gegenlesen",
    "gegenläufigem": "gegenläufig",
    "gegenläufigen": "gegenläufig",
    "gegenläufiger": "gegenläufig",
    "gegenläufiges": "gegenläufig",
    "gegenseitigem": "gegenseitig",
    "gegenseitigen": "gegenseitig",
    "gegenseitiger": "gegenseitig",
    "gegenseitiges": "gegenseitig",
    "gegensteuere": "gegensteuern",
    "gegensteuernd": "gegensteuern",
    "gegensteuernde": "gegensteuernd",
    "gegensteuerndem": "gegensteuernd",
    "gegensteuernden": "gegensteuernd",
    "gegensteuernder": "gegensteuernd",
    "gegensteuerndes": "gegensteuernd",
    "gegensteuerst": "gegensteuern",
    "gegensteuert": "gegensteuern",
    "gegensteuerte": "gegensteuern",
    "gegensteuerten": "gegensteuern",
    "gegensteuertest": "gegensteuern",
    "gegensteuertet": "gegensteuern",
    "gegenständigem": "gegenständig",
    "gegenständigen": "gegenständig",
    "gegenständiger": "gegenständig",
    "gegenständiges": "gegenständig",
    "gegenständliche": "gegenständlich",
    "gegenständlichem": "gegenständlich",
    "gegenständlichen": "gegenständlich",
    "gegenständlicher": "gegenständlich",
    "gegenständliches": "gegenständlich",
    "gegensätzlichem": "gegensätzlich",
    "gegensätzlichen": "gegensätzlich",
    "gegensätzlicher": "gegensätzlich",
    "gegensätzliches": "gegensätzlich",
    "gegenteiligem": "gegenteilig",
    "gegenteiligen": "gegenteilig",
    "gegenteiliger": "gegenteilig",
    "gegenteiliges": "gegenteilig",
    "gegenwärtigem": "gegenwärtig",
    "gegenwärtigen": "gegenwärtig",
    "gegenwärtiger": "gegenwärtig",
    "gegenwärtiges": "gegenwärtig",
    "gegenzeichne": "gegenzeichnen",
    "gegenzeichnend": "gegenzeichnen",
    "gegenzeichnende": "gegenzeichnend",
    "gegenzeichnendem": "gegenzeichnend",
    "gegenzeichnenden": "gegenzeichnend",
    "gegenzeichnender": "gegenzeichnend",
    "gegenzeichnendes": "gegenzeichnend",
    "gegenzeichnest": "gegenzeichnen",
    "gegenzeichnet": "gegenzeichnen",
    "gegenzeichnete": "gegenzeichnen",
    "gegenzeichneten": "gegenzeichnen",
    "gegenzeichnetest": "gegenzeichnen",
    "gegenzeichnetet": "gegenzeichnen",
    "gegenzubuchen": "gegenbuchen",
    "gegenzulenken": "gegenlenken",
    "gegenzulesen": "gegenlesen",
    "gegenzusteuern": "gegensteuern",
    "gegenzuzeichnen": "gegenzeichnen",
    "gegenübergestanden": "gegenüberstehen",
    "gegenübergestandene": "gegenübergestanden",
    "gegenübergestandenem": "gegenübergestanden",
    "gegenübergestandenen": "gegenübergestanden",
    "gegenübergestandener": "gegenübergestanden",
    "gegenübergestandenes": "gegenübergestanden",
    "gegenübergestellt": "gegenüberstellen",
    "gegenübergestellte": "gegenübergestellt",
    "gegenübergestelltem": "gegenübergestellt",
    "gegenübergestellten": "gegenübergestellt",
    "gegenübergestellter": "gegenübergestellt",
    "gegenübergestelltes": "gegenübergestellt",
    "gegenübergetreten": "gegenübertreten",
    "gegenübergetretene": "gegenübergetreten",
    "gegenübergetretenem": "gegenübergetreten",
    "gegenübergetretenen": "gegenübergetreten",
    "gegenübergetretener": "gegenübergetreten",
    "gegenübergetretenes": "gegenübergetreten",
    "gegenüberstand": "gegenüberstehen",
    "gegenüberstanden": "gegenüberstehen",
    "gegenüberstandest": "gegenüberstehen",
    "gegenüberstandet": "gegenüberstehen",
    "gegenüberstehe": "gegenüberstehen",
    "gegenüberstehend": "gegenüberstehen",
    "gegenüberstehende": "gegenüberstehend",
    "gegenüberstehendem": "gegenüberstehend",
    "gegenüberstehenden": "gegenüberstehend",
    "gegenüberstehender": "gegenüberstehend",
    "gegenüberstehendes": "gegenüberstehend",
    "gegenüberstehest": "gegenüberstehen",
    "gegenüberstehet": "gegenüberstehen",
    "gegenüberstehst": "gegenüberstehen",
    "gegenübersteht": "gegenüberstehen",
    "gegenüberstelle": "gegenüberstellen",
    "gegenüberstellend": "gegenüberstellen",
    "gegenüberstellende": "gegenüberstellend",
    "gegenüberstellendem": "gegenüberstellend",
    "gegenüberstellenden": "gegenüberstellend",
    "gegenüberstellender": "gegenüberstellend",
    "gegenüberstellendes": "gegenüberstellend",
    "gegenüberstellest": "gegenüberstellen",
    "gegenüberstellet": "gegenüberstellen",
    "gegenüberstellst": "gegenüberstellen",
    "gegenüberstellt": "gegenüberstellen",
    "gegenüberstellte": "gegenüberstellen",
    "gegenüberstellten": "gegenüberstellen",
    "gegenüberstelltest": "gegenüberstellen",
    "gegenüberstelltet": "gegenüberstellen",
    "gegenüberstünde": "gegenüberstehen",
    "gegenüberstünden": "gegenüberstehen",
    "gegenüberstündest": "gegenüberstehen",
    "gegenüberstündet": "gegenüberstehen",
    "gegenübertrat": "gegenübertreten",
    "gegenübertraten": "gegenübertreten",
    "gegenübertratest": "gegenübertreten",
    "gegenübertratet": "gegenübertreten",
    "gegenübertrete": "gegenübertreten",
    "gegenübertretend": "gegenübertreten",
    "gegenübertretende": "gegenübertretend",
    "gegenübertretendem": "gegenübertretend",
    "gegenübertretenden": "gegenübertretend",
    "gegenübertretender": "gegenübertretend",
    "gegenübertretendes": "gegenübertretend",
    "gegenübertretest": "gegenübertreten",
    "gegenübertretet": "gegenübertreten",
    "gegenübertritt": "gegenübertreten",
    "gegenübertrittst": "gegenübertreten",
    "gegenüberträte": "gegenübertreten",
    "gegenüberträten": "gegenübertreten",
    "gegenüberträtest": "gegenübertreten",
    "gegenüberträtet": "gegenübertreten",
    "gegenüberzustehen": "gegenüberstehen",
    "gegenüberzustellen": "gegenüberstellen",
    "gegenüberzutreten": "gegenübertreten",
    "gegerbt": "gerben",
    "gegerbte": "gegerbt",
    "gegerbtem": "gegerbt",
    "gegerbten": "gegerbt",
    "gegerbter": "gegerbt",
    "gegerbtere": "gegerbt",
    "gegerbterem": "gegerbt",
    "gegerbteren": "gegerbt",
    "gegerbterer": "gegerbt",
    "gegerbteres": "gegerbt",
    "gegerbtes": "gegerbt",
    "gegerbteste": "gegerbt",
    "gegerbtestem": "gegerbt",
    "gegerbtesten": "gegerbt",
    "gegerbtester": "gegerbt",
    "gegerbtestes": "gegerbt",
    "gegessen": "essen",
    "gegessene": "gegessen",
    "gegessenem": "gegessen",
    "gegessenen": "gegessen",
    "gegessener": "gegessen",
    "gegessenes": "gegessen",
    "gegiert": "gieren",
    "gegierte": "gegiert",
    "gegiertem": "gegiert",
    "gegierten": "gegiert",
    "gegierter": "gegiert",
    "gegiertes": "gegiert",
    "gegiftet": "giften",
    "gegiftete": "gegiftet",
    "gegiftetem": "gegiftet",
    "gegifteten": "gegiftet",
    "gegifteter": "gegiftet",
    "gegiftetes": "gegiftet",
    "gegipfelt": "gipfeln",
    "gegipfelte": "gegipfelt",
    "gegipfeltem": "gegipfelt",
    "gegipfelten": "gegipfelt",
    "gegipfelter": "gegipfelt",
    "gegipfeltes": "gegipfelt",
    "gegipst": "gipsen",
    "gegipste": "gegipst",
    "gegipstem": "gegipst",
    "gegipsten": "gegipst",
    "gegipster": "gegipst",
    "gegipstes": "gegipst",
    "gegittert": "gittern",
    "gegitterte": "gegittert",
    "gegittertem": "gegittert",
    "gegitterten": "gegittert",
    "gegitterter": "gegittert",
    "gegittertes": "gegittert",
    "geglast": "glasen",
    "geglaste": "geglast",
    "geglastem": "geglast",
    "geglasten": "geglast",
    "geglaster": "geglast",
    "geglastes": "geglast",
    "geglaubt": "glauben",
    "geglaubte": "geglaubt",
    "geglaubtem": "geglaubt",
    "geglaubten": "geglaubt",
    "geglaubter": "geglaubt",
    "geglaubtes": "geglaubt",
    "gegleist": "gleisen",
    "gegleiste": "gegleist",
    "gegleistem": "gegleist",
    "gegleisten": "gegleist",
    "gegleister": "gegleist",
    "gegleistes": "gegleist",
    "geglibbert": "glibbern",
    "geglibberte": "geglibbert",
    "geglibbertem": "geglibbert",
    "geglibberten": "geglibbert",
    "geglibberter": "geglibbert",
    "geglibbertes": "geglibbert",
    "geglichen": "gleichen",
    "geglichene": "geglichen",
    "geglichenem": "geglichen",
    "geglichenen": "geglichen",
    "geglichener": "geglichen",
    "geglichenes": "geglichen",
    "gegliedert": "gliedern",
    "gegliederte": "gegliedert",
    "gegliedertem": "gegliedert",
    "gegliederten": "gegliedert",
    "gegliederter": "gegliedert",
    "gegliedertes": "gegliedert",
    "geglimmert": "glimmern",
    "geglimmerte": "geglimmert",
    "geglimmertem": "geglimmert",
    "geglimmerten": "geglimmert",
    "geglimmerter": "geglimmert",
    "geglimmertere": "geglimmert",
    "geglimmerterem": "geglimmert",
    "geglimmerteren": "geglimmert",
    "geglimmerterer": "geglimmert",
    "geglimmerteres": "geglimmert",
    "geglimmertes": "geglimmert",
    "geglimmerteste": "geglimmert",
    "geglimmertestem": "geglimmert",
    "geglimmertesten": "geglimmert",
    "geglimmertester": "geglimmert",
    "geglimmertestes": "geglimmert",
    "geglitscht": "glitschen",
    "geglitschte": "geglitscht",
    "geglitschtem": "geglitscht",
    "geglitschten": "geglitscht",
    "geglitschter": "geglitscht",
    "geglitschtes": "geglitscht",
    "geglitten": "gleiten",
    "geglittene": "geglitten",
    "geglittenem": "geglitten",
    "geglittenen": "geglitten",
    "geglittener": "geglitten",
    "geglittenes": "geglitten",
    "geglommen": "glimmen",
    "geglommene": "geglommen",
    "geglommenem": "geglommen",
    "geglommenen": "geglommen",
    "geglommener": "geglommen",
    "geglommenes": "geglommen",
    "geglotzt": "glotzen",
    "geglotzte": "geglotzt",
    "geglotztem": "geglotzt",
    "geglotzten": "geglotzt",
    "geglotzter": "geglotzt",
    "geglotztes": "geglotzt",
    "gegluckst": "glucksen",
    "gegluckste": "gegluckst",
    "gegluckstem": "gegluckst",
    "geglucksten": "gegluckst",
    "gegluckster": "gegluckst",
    "gegluckstes": "gegluckst",
    "geglupscht": "glupschen",
    "geglupschte": "geglupscht",
    "geglupschtem": "geglupscht",
    "geglupschten": "geglupscht",
    "geglupschter": "geglupscht",
    "geglupschtes": "geglupscht",
    "geglänzt": "glänzen",
    "geglänzte": "geglänzt",
    "geglänztem": "geglänzt",
    "geglänzten": "geglänzt",
    "geglänzter": "geglänzt",
    "geglänztes": "geglänzt",
    "geglättet": "glätten",
    "geglättete": "geglättet",
    "geglättetem": "geglättet",
    "geglätteten": "geglättet",
    "geglätteter": "geglättet",
    "geglättetere": "geglättet",
    "geglätteterem": "geglättet",
    "geglätteteren": "geglättet",
    "geglätteterer": "geglättet",
    "geglätteteres": "geglättet",
    "geglättetes": "geglättet",
    "geglätteteste": "geglättet",
    "geglättetestem": "geglättet",
    "geglättetesten": "geglättet",
    "geglättetester": "geglättet",
    "geglättetestes": "geglättet",
    "geglückt": "glücken",
    "geglückte": "geglückt",
    "geglücktem": "geglückt",
    "geglückten": "geglückt",
    "geglückter": "geglückt",
    "geglücktere": "geglückt",
    "geglückterem": "geglückt",
    "geglückteren": "geglückt",
    "geglückterer": "geglückt",
    "geglückteres": "geglückt",
    "geglücktes": "geglückt",
    "geglückteste": "geglückt",
    "geglücktestem": "geglückt",
    "geglücktesten": "geglückt",
    "geglücktester": "geglückt",
    "geglücktestes": "geglückt",
    "geglüht": "glühen",
    "geglühte": "geglüht",
    "geglühtem": "geglüht",
    "geglühten": "geglüht",
    "geglühter": "geglüht",
    "geglühtes": "geglüht",
    "gegnerischem": "gegnerisch",
    "gegnerischen": "gegnerisch",
    "gegnerischer": "gegnerisch",
    "gegnerisches": "gegnerisch",
    "gegolft": "golfen",
    "gegolfte": "gegolft",
    "gegolftem": "gegolft",
    "gegolften": "gegolft",
    "gegolfter": "gegolft",
    "gegolftes": "gegolft",
    "gegolten": "gelten",
    "gegoltene": "gegolten",
    "gegoltenem": "gegolten",
    "gegoltenen": "gegolten",
    "gegoltener": "gegolten",
    "gegoltenes": "gegolten",
    "gegondelt": "gondeln",
    "gegondelte": "gegondelt",
    "gegondeltem": "gegondelt",
    "gegondelten": "gegondelt",
    "gegondelter": "gegondelt",
    "gegondeltes": "gegondelt",
    "gegongt": "gongen",
    "gegongte": "gegongt",
    "gegongtem": "gegongt",
    "gegongten": "gegongt",
    "gegongter": "gegongt",
    "gegongtes": "gegongt",
    "gegoren": "gären",
    "gegorene": "gegoren",
    "gegorenem": "gegoren",
    "gegorenen": "gegoren",
    "gegorener": "gegoren",
    "gegorenere": "gegoren",
    "gegorenerem": "gegoren",
    "gegoreneren": "gegoren",
    "gegorenerer": "gegoren",
    "gegoreneres": "gegoren",
    "gegorenes": "gegoren",
    "gegorenste": "gegoren",
    "gegorenstem": "gegoren",
    "gegorensten": "gegoren",
    "gegorenster": "gegoren",
    "gegorenstes": "gegoren",
    "gegossen": "gießen",
    "gegossene": "gegossen",
    "gegossenem": "gegossen",
    "gegossenen": "gegossen",
    "gegossener": "gegossen",
    "gegossenes": "gegossen",
    "gegraben": "graben",
    "gegrabene": "gegraben",
    "gegrabenem": "gegraben",
    "gegrabenen": "gegraben",
    "gegrabener": "gegraben",
    "gegrabenes": "gegraben",
    "gegrabscht": "grabschen",
    "gegrabschte": "gegrabscht",
    "gegrabschtem": "gegrabscht",
    "gegrabschten": "gegrabscht",
    "gegrabschter": "gegrabscht",
    "gegrabschtes": "gegrabscht",
    "gegrast": "grasen",
    "gegraste": "gegrast",
    "gegrastem": "gegrast",
    "gegrasten": "gegrast",
    "gegraster": "gegrast",
    "gegrastes": "gegrast",
    "gegrault": "graulen",
    "gegraulte": "gegrault",
    "gegraultem": "gegrault",
    "gegraulten": "gegrault",
    "gegraulter": "gegrault",
    "gegraultes": "gegrault",
    "gegraupelt": "graupeln",
    "gegraupelte": "gegraupelt",
    "gegraupeltem": "gegraupelt",
    "gegraupelten": "gegraupelt",
    "gegraupelter": "gegraupelt",
    "gegraupeltere": "gegraupelt",
    "gegraupelterem": "gegraupelt",
    "gegraupelteren": "gegraupelt",
    "gegraupelterer": "gegraupelt",
    "gegraupelteres": "gegraupelt",
    "gegraupeltes": "gegraupelt",
    "gegraupelteste": "gegraupelt",
    "gegraupeltestem": "gegraupelt",
    "gegraupeltesten": "gegraupelt",
    "gegraupeltester": "gegraupelt",
    "gegraupeltestes": "gegraupelt",
    "gegraust": "grausen",
    "gegrauste": "gegraust",
    "gegraustem": "gegraust",
    "gegrausten": "gegraust",
    "gegrauster": "gegraust",
    "gegraustes": "gegraust",
    "gegrenzt": "grenzen",
    "gegrenzte": "gegrenzt",
    "gegrenztem": "gegrenzt",
    "gegrenzten": "gegrenzt",
    "gegrenzter": "gegrenzt",
    "gegrenztes": "gegrenzt",
    "gegriffen": "greifen",
    "gegriffene": "gegriffen",
    "gegriffenem": "gegriffen",
    "gegriffenen": "gegriffen",
    "gegriffener": "gegriffen",
    "gegriffenes": "gegriffen",
    "gegrillt": "grillen",
    "gegrillte": "gegrillt",
    "gegrilltem": "gegrillt",
    "gegrillten": "gegrillt",
    "gegrillter": "gegrillt",
    "gegrilltes": "gegrillt",
    "gegrinst": "grinsen",
    "gegrinste": "gegrinst",
    "gegrinstem": "gegrinst",
    "gegrinsten": "gegrinst",
    "gegrinster": "gegrinst",
    "gegrinstes": "gegrinst",
    "gegrummelt": "grummeln",
    "gegrummelte": "gegrummelt",
    "gegrummeltem": "gegrummelt",
    "gegrummelten": "gegrummelt",
    "gegrummelter": "gegrummelt",
    "gegrummeltes": "gegrummelt",
    "gegrunzt": "grunzen",
    "gegrunzte": "gegrunzt",
    "gegrunztem": "gegrunzt",
    "gegrunzten": "gegrunzt",
    "gegrunzter": "gegrunzt",
    "gegrunztes": "gegrunzt",
    "gegruselt": "gruseln",
    "gegruselte": "gegruselt",
    "gegruseltem": "gegruselt",
    "gegruselten": "gegruselt",
    "gegruselter": "gegruselt",
    "gegruseltes": "gegruselt",
    "gegrämt": "grämen",
    "gegrämte": "gegrämt",
    "gegrämtem": "gegrämt",
    "gegrämten": "gegrämt",
    "gegrämter": "gegrämt",
    "gegrämtes": "gegrämt",
    "gegrätscht": "grätschen",
    "gegrätschte": "gegrätscht",
    "gegrätschtem": "gegrätscht",
    "gegrätschten": "gegrätscht",
    "gegrätschter": "gegrätscht",
    "gegrätschtes": "gegrätscht",
    "gegrölt": "grölen",
    "gegrölte": "gegrölt",
    "gegröltem": "gegrölt",
    "gegrölten": "gegrölt",
    "gegrölter": "gegrölt",
    "gegröltere": "gegrölt",
    "gegrölterem": "gegrölt",
    "gegrölteren": "gegrölt",
    "gegrölterer": "gegrölt",
    "gegrölteres": "gegrölt",
    "gegröltes": "gegrölt",
    "gegrölteste": "gegrölt",
    "gegröltestem": "gegrölt",
    "gegröltesten": "gegrölt",
    "gegröltester": "gegrölt",
    "gegröltestes": "gegrölt",
    "gegrübelt": "grübeln",
    "gegrübelte": "gegrübelt",
    "gegrübeltem": "gegrübelt",
    "gegrübelten": "gegrübelt",
    "gegrübelter": "gegrübelt",
    "gegrübeltes": "gegrübelt",
    "gegründet": "gründen",
    "gegründete": "gegründet",
    "gegründetem": "gegründet",
    "gegründeten": "gegründet",
    "gegründeter": "gegründet",
    "gegründetes": "gegründet",
    "gegrüßt": "grüßen",
    "gegrüßte": "gegrüßt",
    "gegrüßtem": "gegrüßt",
    "gegrüßten": "gegrüßt",
    "gegrüßter": "gegrüßt",
    "gegrüßtes": "gegrüßt",
    "geguckt": "gucken",
    "geguckte": "geguckt",
    "gegucktem": "geguckt",
    "geguckten": "geguckt",
    "geguckter": "geguckt",
    "gegucktes": "geguckt",
    "gegurgelt": "gurgeln",
    "gegurgelte": "gegurgelt",
    "gegurgeltem": "gegurgelt",
    "gegurgelten": "gegurgelt",
    "gegurgelter": "gegurgelt",
    "gegurgeltes": "gegurgelt",
    "gegurrt": "gurren",
    "gegurrte": "gegurrt",
    "gegurrtem": "gegurrt",
    "gegurrten": "gegurrt",
    "gegurrter": "gegurrt",
    "gegurrtes": "gegurrt",
    "gegurtet": "gurten",
    "gegurtete": "gegurtet",
    "gegurtetem": "gegurtet",
    "gegurteten": "gegurtet",
    "gegurteter": "gegurtet",
    "gegurtetes": "gegurtet",
    "gegähnt": "gähnen",
    "gegähnte": "gegähnt",
    "gegähntem": "gegähnt",
    "gegähnten": "gegähnt",
    "gegähnter": "gegähnt",
    "gegähntes": "gegähnt",
    "gegängelt": "gängeln",
    "gegängelte": "gegängelt",
    "gegängeltem": "gegängelt",
    "gegängelten": "gegängelt",
    "gegängelter": "gegängelt",
    "gegängeltere": "gegängelt",
    "gegängelterem": "gegängelt",
    "gegängelteren": "gegängelt",
    "gegängelterer": "gegängelt",
    "gegängelteres": "gegängelt",
    "gegängeltes": "gegängelt",
    "gegängelteste": "gegängelt",
    "gegängeltestem": "gegängelt",
    "gegängeltesten": "gegängelt",
    "gegängeltester": "gegängelt",
    "gegängeltestes": "gegängelt",
    "gegärtnert": "gärtnern",
    "gegärtnerte": "gegärtnert",
    "gegärtnertem": "gegärtnert",
    "gegärtnerten": "gegärtnert",
    "gegärtnerter": "gegärtnert",
    "gegärtnertes": "gegärtnert",
    "gegönnt": "gönnen",
    "gegönnte": "gegönnt",
    "gegönntem": "gegönnt",
    "gegönnten": "gegönnt",
    "gegönnter": "gegönnt",
    "gegönntes": "gegönnt",
    "gehaart": "haaren",
    "gehaarte": "gehaart",
    "gehaartem": "gehaart",
    "gehaarten": "gehaart",
    "gehaarter": "gehaart",
    "gehaartes": "gehaart",
    "gehabt": "haben",
    "gehabte": "gehabt",
    "gehabtem": "gehabt",
    "gehabten": "gehabt",
    "gehabter": "gehabt",
    "gehabtes": "gehabt",
    "gehackt": "hacken",
    "gehackte": "gehackt",
    "gehacktem": "gehackt",
    "gehackten": "gehackt",
    "gehackter": "gehackt",
    "gehacktes": "gehackt",
    "gehadert": "hadern",
    "gehaderte": "gehadert",
    "gehadertem": "gehadert",
    "gehaderten": "gehadert",
    "gehaderter": "gehadert",
    "gehadertes": "gehadert",
    "gehaftet": "haften",
    "gehaftete": "gehaftet",
    "gehaftetem": "gehaftet",
    "gehafteten": "gehaftet",
    "gehafteter": "gehaftet",
    "gehaftetes": "gehaftet",
    "gehagelt": "hageln",
    "gehagelte": "gehagelt",
    "gehageltem": "gehagelt",
    "gehagelten": "gehagelt",
    "gehagelter": "gehagelt",
    "gehageltes": "gehagelt",
    "gehakt": "haken",
    "gehakte": "gehakt",
    "gehaktem": "gehakt",
    "gehakten": "gehakt",
    "gehakter": "gehakt",
    "gehaktes": "gehakt",
    "gehalftert": "halftern",
    "gehalfterte": "gehalftert",
    "gehalftertem": "gehalftert",
    "gehalfterten": "gehalftert",
    "gehalfterter": "gehalftert",
    "gehalftertes": "gehalftert",
    "gehallt": "hallen",
    "gehallte": "gehallt",
    "gehalltem": "gehallt",
    "gehallten": "gehallt",
    "gehallter": "gehallt",
    "gehalltes": "gehallt",
    "gehalst": "halsen",
    "gehalste": "gehalst",
    "gehalstem": "gehalst",
    "gehalsten": "gehalst",
    "gehalster": "gehalst",
    "gehalstes": "gehalst",
    "gehalten": "halten",
    "gehaltene": "gehalten",
    "gehaltenem": "gehalten",
    "gehaltenen": "gehalten",
    "gehaltener": "gehalten",
    "gehaltenes": "gehalten",
    "gehaltvollem": "gehaltvoll",
    "gehaltvollen": "gehaltvoll",
    "gehaltvoller": "gehaltvoll",
    "gehaltvollere": "gehaltvoll",
    "gehaltvollerem": "gehaltvoll",
    "gehaltvolleren": "gehaltvoll",
    "gehaltvollerer": "gehaltvoll",
    "gehaltvolleres": "gehaltvoll",
    "gehaltvolles": "gehaltvoll",
    "gehaltvollste": "gehaltvoll",
    "gehaltvollstem": "gehaltvoll",
    "gehaltvollsten": "gehaltvoll",
    "gehaltvollster": "gehaltvoll",
    "gehaltvollstes": "gehaltvoll",
    "gehampelt": "hampeln",
    "gehampelte": "gehampelt",
    "gehampeltem": "gehampelt",
    "gehampelten": "gehampelt",
    "gehampelter": "gehampelt",
    "gehampeltes": "gehampelt",
    "gehamstert": "hamstern",
    "gehamsterte": "gehamstert",
    "gehamstertem": "gehamstert",
    "gehamsterten": "gehamstert",
    "gehamsterter": "gehamstert",
    "gehamstertes": "gehamstert",
    "gehandelt": "handeln",
    "gehandelte": "gehandelt",
    "gehandeltem": "gehandelt",
    "gehandelten": "gehandelt",
    "gehandelter": "gehandelt",
    "gehandeltes": "gehandelt",
    "gehandhabt": "handhaben",
    "gehandhabte": "gehandhabt",
    "gehandhabtem": "gehandhabt",
    "gehandhabten": "gehandhabt",
    "gehandhabter": "gehandhabt",
    "gehandhabtes": "gehandhabt",
    "gehangelt": "hangeln",
    "gehangelte": "gehangelt",
    "gehangeltem": "gehangelt",
    "gehangelten": "gehangelt",
    "gehangelter": "gehangelt",
    "gehangeltes": "gehangelt",
    "gehangen": "hängen",
    "gehangenem": "gehangen",
    "gehangenen": "gehangen",
    "gehangener": "gehangen",
    "gehangenes": "gehangen",
    "gehapert": "hapern",
    "gehaperte": "gehapert",
    "gehapertem": "gehapert",
    "gehaperten": "gehapert",
    "gehaperter": "gehapert",
    "gehapertes": "gehapert",
    "geharrt": "harren",
    "geharrte": "geharrt",
    "geharrtem": "geharrt",
    "geharrten": "geharrt",
    "geharrter": "geharrt",
    "geharrtes": "geharrt",
    "geharzt": "harzen",
    "geharzte": "geharzt",
    "geharztem": "geharzt",
    "geharzten": "geharzt",
    "geharzter": "geharzt",
    "geharztes": "geharzt",
    "gehascht": "haschen",
    "gehaschte": "gehascht",
    "gehaschtem": "gehascht",
    "gehaschten": "gehascht",
    "gehaschter": "gehascht",
    "gehaschtes": "gehascht",
    "gehaspelt": "haspeln",
    "gehaspelte": "gehaspelt",
    "gehaspeltem": "gehaspelt",
    "gehaspelten": "gehaspelt",
    "gehaspelter": "gehaspelt",
    "gehaspeltes": "gehaspelt",
    "gehastet": "hasten",
    "gehastete": "gehastet",
    "gehastetem": "gehastet",
    "gehasteten": "gehastet",
    "gehasteter": "gehastet",
    "gehastetes": "gehastet",
    "gehaucht": "hauchen",
    "gehauchte": "gehaucht",
    "gehauchtem": "gehaucht",
    "gehauchten": "gehaucht",
    "gehauchter": "gehaucht",
    "gehauchtes": "gehaucht",
    "gehauen": "hauen",
    "gehauene": "gehauen",
    "gehauenem": "gehauen",
    "gehauenen": "gehauen",
    "gehauener": "gehauen",
    "gehauenes": "gehauen",
    "gehaust": "hausen",
    "gehauste": "gehaust",
    "gehaustem": "gehaust",
    "gehausten": "gehaust",
    "gehauster": "gehaust",
    "gehaustes": "gehaust",
    "gehaßt": "hassen",
    "gehaßte": "gehaßt",
    "gehaßtem": "gehaßt",
    "gehaßten": "gehaßt",
    "gehaßter": "gehaßt",
    "gehaßtere": "gehaßt",
    "gehaßterem": "gehaßt",
    "gehaßteren": "gehaßt",
    "gehaßterer": "gehaßt",
    "gehaßteres": "gehaßt",
    "gehaßtes": "gehaßt",
    "gehaßteste": "gehaßt",
    "gehaßtestem": "gehaßt",
    "gehaßtesten": "gehaßt",
    "gehaßtester": "gehaßt",
    "gehaßtestes": "gehaßt",
    "gehbehinderte": "gehbehindert",
    "gehbehindertem": "gehbehindert",
    "gehbehinderten": "gehbehindert",
    "gehbehinderter": "gehbehindert",
    "gehbehindertes": "gehbehindert",
    "gehe": "gehen",
    "gehechelt": "hecheln",
    "gehechelte": "gehechelt",
    "gehecheltem": "gehechelt",
    "gehechelten": "gehechelt",
    "gehechelter": "gehechelt",
    "gehecheltes": "gehechelt",
    "gehechtet": "hechten",
    "gehechtete": "gehechtet",
    "gehechtetem": "gehechtet",
    "gehechteten": "gehechtet",
    "gehechteter": "gehechtet",
    "gehechtetes": "gehechtet",
    "geheftet": "heften",
    "geheftete": "geheftet",
    "geheftetem": "geheftet",
    "gehefteten": "geheftet",
    "gehefteter": "geheftet",
    "geheftetes": "geheftet",
    "gehegt": "hegen",
    "gehegte": "gehegt",
    "gehegtem": "gehegt",
    "gehegten": "gehegt",
    "gehegter": "gehegt",
    "gehegtere": "gehegt",
    "gehegterem": "gehegt",
    "gehegteren": "gehegt",
    "gehegterer": "gehegt",
    "gehegteres": "gehegt",
    "gehegtes": "gehegt",
    "gehegteste": "gehegt",
    "gehegtestem": "gehegt",
    "gehegtesten": "gehegt",
    "gehegtester": "gehegt",
    "gehegtestes": "gehegt",
    "geheilt": "heilen",
    "geheilte": "geheilt",
    "geheiltem": "geheilt",
    "geheilten": "geheilt",
    "geheilter": "geheilt",
    "geheiltes": "geheilt",
    "geheimelt": "heimeln",
    "geheimelte": "geheimelt",
    "geheimeltem": "geheimelt",
    "geheimelten": "geheimelt",
    "geheimelter": "geheimelt",
    "geheimeltes": "geheimelt",
    "geheimem": "geheim",
    "geheimen": "geheim",
    "geheimer": "geheim",
    "geheimere": "geheim",
    "geheimerem": "geheim",
    "geheimeren": "geheim",
    "geheimerer": "geheim",
    "geheimeres": "geheim",
    "geheimes": "geheim",
    "geheimgehalten": "geheimhalten",
    "geheimgehaltene": "geheimgehalten",
    "geheimgehaltenem": "geheimgehalten",
    "geheimgehaltenen": "geheimgehalten",
    "geheimgehaltener": "geheimgehalten",
    "geheimgehaltenere": "geheimgehalten",
    "geheimgehaltenerem": "geheimgehalten",
    "geheimgehalteneren": "geheimgehalten",
    "geheimgehaltenerer": "geheimgehalten",
    "geheimgehalteneres": "geheimgehalten",
    "geheimgehaltenes": "geheimgehalten",
    "geheimgehaltenste": "geheimgehalten",
    "geheimgehaltenstem": "geheimgehalten",
    "geheimgehaltensten": "geheimgehalten",
    "geheimgehaltenster": "geheimgehalten",
    "geheimgehaltenstes": "geheimgehalten",
    "geheimhalte": "geheimhalten",
    "geheimhaltend": "geheimhalten",
    "geheimhaltende": "geheimhaltend",
    "geheimhaltendem": "geheimhaltend",
    "geheimhaltenden": "geheimhaltend",
    "geheimhaltender": "geheimhaltend",
    "geheimhaltendere": "geheimhaltend",
    "geheimhaltenderem": "geheimhaltend",
    "geheimhaltenderen": "geheimhaltend",
    "geheimhaltenderer": "geheimhaltend",
    "geheimhaltenderes": "geheimhaltend",
    "geheimhaltendes": "geheimhaltend",
    "geheimhaltendste": "geheimhaltend",
    "geheimhaltendstem": "geheimhaltend",
    "geheimhaltendsten": "geheimhaltend",
    "geheimhaltendster": "geheimhaltend",
    "geheimhaltendstes": "geheimhaltend",
    "geheimhaltest": "geheimhalten",
    "geheimhaltet": "geheimhalten",
    "geheimhielt": "geheimhalten",
    "geheimhielte": "geheimhalten",
    "geheimhielten": "geheimhalten",
    "geheimhieltest": "geheimhalten",
    "geheimhieltet": "geheimhalten",
    "geheimhält": "geheimhalten",
    "geheimhältst": "geheimhalten",
    "geheimnisvollem": "geheimnisvoll",
    "geheimnisvollen": "geheimnisvoll",
    "geheimnisvoller": "geheimnisvoll",
    "geheimnisvollere": "geheimnisvoll",
    "geheimnisvollerem": "geheimnisvoll",
    "geheimnisvolleren": "geheimnisvoll",
    "geheimnisvollerer": "geheimnisvoll",
    "geheimnisvolleres": "geheimnisvoll",
    "geheimnisvolles": "geheimnisvoll",
    "geheimnisvollste": "geheimnisvoll",
    "geheimnisvollstem": "geheimnisvoll",
    "geheimnisvollsten": "geheimnisvoll",
    "geheimnisvollster": "geheimnisvoll",
    "geheimnisvollstes": "geheimnisvoll",
    "geheimst": "heimsen",
    "geheimste": "geheim",
    "geheimstem": "geheim",
    "geheimsten": "geheim",
    "geheimster": "geheim",
    "geheimstes": "geheim",
    "geheimzuhalten": "geheimhalten",
    "geheiratet": "heiraten",
    "geheiratete": "geheiratet",
    "geheiratetem": "geheiratet",
    "geheirateten": "geheiratet",
    "geheirateter": "geheiratet",
    "geheiratetes": "geheiratet",
    "geheitert": "heitern",
    "geheiterte": "geheitert",
    "geheitertem": "geheitert",
    "geheiterten": "geheitert",
    "geheiterter": "geheitert",
    "geheitertes": "geheitert",
    "geheizt": "heizen",
    "geheizte": "geheizt",
    "geheiztem": "geheizt",
    "geheizten": "geheizt",
    "geheizter": "geheizt",
    "geheiztere": "geheizt",
    "geheizterem": "geheizt",
    "geheizteren": "geheizt",
    "geheizterer": "geheizt",
    "geheizteres": "geheizt",
    "geheiztes": "geheizt",
    "geheizteste": "geheizt",
    "geheiztestem": "geheizt",
    "geheiztesten": "geheizt",
    "geheiztester": "geheizt",
    "geheiztestes": "geheizt",
    "geheißen": "heißen",
    "geheißene": "geheißen",
    "geheißenem": "geheißen",
    "geheißenen": "geheißen",
    "geheißener": "geheißen",
    "geheißenes": "geheißen",
    "gehellt": "hellen",
    "gehellte": "gehellt",
    "gehelltem": "gehellt",
    "gehellten": "gehellt",
    "gehellter": "gehellt",
    "gehelltes": "gehellt",
    "gehemmt": "hemmen",
    "gehemmte": "gehemmt",
    "gehemmtem": "gehemmt",
    "gehemmten": "gehemmt",
    "gehemmter": "gehemmt",
    "gehemmtere": "gehemmt",
    "gehemmterem": "gehemmt",
    "gehemmteren": "gehemmt",
    "gehemmterer": "gehemmt",
    "gehemmteres": "gehemmt",
    "gehemmtes": "gehemmt",
    "gehemmteste": "gehemmt",
    "gehemmtestem": "gehemmt",
    "gehemmtesten": "gehemmt",
    "gehemmtester": "gehemmt",
    "gehemmtestes": "gehemmt",
    "gehend": "gehen",
    "gehende": "gehend",
    "gehendem": "gehend",
    "gehenden": "gehend",
    "gehender": "gehend",
    "gehendes": "gehend",
    "geherrscht": "herrschen",
    "geherrschte": "geherrscht",
    "geherrschtem": "geherrscht",
    "geherrschten": "geherrscht",
    "geherrschter": "geherrscht",
    "geherrschtes": "geherrscht",
    "geherzt": "herzen",
    "geherzte": "geherzt",
    "geherztem": "geherzt",
    "geherzten": "geherzt",
    "geherzter": "geherzt",
    "geherztere": "geherzt",
    "geherzterem": "geherzt",
    "geherzteren": "geherzt",
    "geherzterer": "geherzt",
    "geherzteres": "geherzt",
    "geherztes": "geherzt",
    "geherzteste": "geherzt",
    "geherztestem": "geherzt",
    "geherztesten": "geherzt",
    "geherztester": "geherzt",
    "geherztestes": "geherzt",
    "gehest": "gehen",
    "gehet": "gehen",
    "gehetzt": "hetzen",
    "gehetzte": "gehetzt",
    "gehetztem": "gehetzt",
    "gehetzten": "gehetzt",
    "gehetzter": "gehetzt",
    "gehetztere": "gehetzt",
    "gehetzterem": "gehetzt",
    "gehetzteren": "gehetzt",
    "gehetzterer": "gehetzt",
    "gehetzteres": "gehetzt",
    "gehetztes": "gehetzt",
    "gehetzteste": "gehetzt",
    "gehetztestem": "gehetzt",
    "gehetztesten": "gehetzt",
    "gehetztester": "gehetzt",
    "gehetztestes": "gehetzt",
    "geheuchelt": "heucheln",
    "geheuchelte": "geheuchelt",
    "geheucheltem": "geheuchelt",
    "geheuchelten": "geheuchelt",
    "geheuchelter": "geheuchelt",
    "geheucheltes": "geheuchelt",
    "geheuert": "heuern",
    "geheuerte": "geheuert",
    "geheuertem": "geheuert",
    "geheuerten": "geheuert",
    "geheuerter": "geheuert",
    "geheuertes": "geheuert",
    "geheult": "heulen",
    "geheulte": "geheult",
    "geheultem": "geheult",
    "geheulten": "geheult",
    "geheulter": "geheult",
    "geheultes": "geheult",
    "gehext": "hexen",
    "gehexte": "gehext",
    "gehextem": "gehext",
    "gehexten": "gehext",
    "gehexter": "gehext",
    "gehextes": "gehext",
    "gehievt": "hieven",
    "gehievte": "gehievt",
    "gehievtem": "gehievt",
    "gehievten": "gehievt",
    "gehievter": "gehievt",
    "gehievtes": "gehievt",
    "gehimmelt": "himmeln",
    "gehimmelte": "gehimmelt",
    "gehimmeltem": "gehimmelt",
    "gehimmelten": "gehimmelt",
    "gehimmelter": "gehimmelt",
    "gehimmeltes": "gehimmelt",
    "gehindert": "hindern",
    "gehinderte": "gehindert",
    "gehindertem": "gehindert",
    "gehinderten": "gehindert",
    "gehinderter": "gehindert",
    "gehindertes": "gehindert",
    "gehinkt": "hinken",
    "gehinkte": "gehinkt",
    "gehinktem": "gehinkt",
    "gehinkten": "gehinkt",
    "gehinkter": "gehinkt",
    "gehinktes": "gehinkt",
    "gehobelt": "hobeln",
    "gehobelte": "gehobelt",
    "gehobeltem": "gehobelt",
    "gehobelten": "gehobelt",
    "gehobelter": "gehobelt",
    "gehobeltes": "gehobelt",
    "gehoben": "heben",
    "gehobene": "gehoben",
    "gehobenem": "gehoben",
    "gehobenen": "gehoben",
    "gehobener": "gehoben",
    "gehobenere": "gehoben",
    "gehobenerem": "gehoben",
    "gehobeneren": "gehoben",
    "gehobenerer": "gehoben",
    "gehobeneres": "gehoben",
    "gehobenes": "gehoben",
    "gehobenste": "gehoben",
    "gehobenstem": "gehoben",
    "gehobensten": "gehoben",
    "gehobenster": "gehoben",
    "gehobenstes": "gehoben",
    "gehockt": "hocken",
    "gehockte": "gehockt",
    "gehocktem": "gehockt",
    "gehockten": "gehockt",
    "gehockter": "gehockt",
    "gehocktere": "gehockt",
    "gehockterem": "gehockt",
    "gehockteren": "gehockt",
    "gehockterer": "gehockt",
    "gehockteres": "gehockt",
    "gehocktes": "gehockt",
    "gehockteste": "gehockt",
    "gehocktestem": "gehockt",
    "gehocktesten": "gehockt",
    "gehocktester": "gehockt",
    "gehocktestes": "gehockt",
    "gehofft": "hoffen",
    "gehoffte": "gehofft",
    "gehofftem": "gehofft",
    "gehofften": "gehofft",
    "gehoffter": "gehofft",
    "gehofftes": "gehofft",
    "geholfen": "helfen",
    "geholfene": "geholfen",
    "geholfenem": "geholfen",
    "geholfenen": "geholfen",
    "geholfener": "geholfen",
    "geholfenere": "geholfen",
    "geholfenerem": "geholfen",
    "geholfeneren": "geholfen",
    "geholfenerer": "geholfen",
    "geholfeneres": "geholfen",
    "geholfenes": "geholfen",
    "geholfenste": "geholfen",
    "geholfenstem": "geholfen",
    "geholfensten": "geholfen",
    "geholfenster": "geholfen",
    "geholfenstes": "geholfen",
    "geholpert": "holpern",
    "geholperte": "geholpert",
    "geholpertem": "geholpert",
    "geholperten": "geholpert",
    "geholperter": "geholpert",
    "geholpertere": "geholpert",
    "geholperterem": "geholpert",
    "geholperteren": "geholpert",
    "geholperterer": "geholpert",
    "geholperteres": "geholpert",
    "geholpertes": "geholpert",
    "geholperteste": "geholpert",
    "geholpertestem": "geholpert",
    "geholpertesten": "geholpert",
    "geholpertester": "geholpert",
    "geholpertestes": "geholpert",
    "geholt": "holen",
    "geholte": "geholt",
    "geholtem": "geholt",
    "geholten": "geholt",
    "geholter": "geholt",
    "geholtes": "geholt",
    "geholzt": "holzen",
    "geholzte": "geholzt",
    "geholztem": "geholzt",
    "geholzten": "geholzt",
    "geholzter": "geholzt",
    "geholztes": "geholzt",
    "gehoppelt": "hoppeln",
    "gehoppelte": "gehoppelt",
    "gehoppeltem": "gehoppelt",
    "gehoppelten": "gehoppelt",
    "gehoppelter": "gehoppelt",
    "gehoppeltere": "gehoppelt",
    "gehoppelterem": "gehoppelt",
    "gehoppelteren": "gehoppelt",
    "gehoppelterer": "gehoppelt",
    "gehoppelteres": "gehoppelt",
    "gehoppeltes": "gehoppelt",
    "gehoppelteste": "gehoppelt",
    "gehoppeltestem": "gehoppelt",
    "gehoppeltesten": "gehoppelt",
    "gehoppeltester": "gehoppelt",
    "gehoppeltestes": "gehoppelt",
    "gehoppt": "hoppen",
    "gehoppte": "gehoppt",
    "gehopptem": "gehoppt",
    "gehoppten": "gehoppt",
    "gehoppter": "gehoppt",
    "gehopptes": "gehoppt",
    "gehopst": "hopsen",
    "gehopste": "gehopst",
    "gehopstem": "gehopst",
    "gehopsten": "gehopst",
    "gehopster": "gehopst",
    "gehopstes": "gehopst",
    "gehorche": "gehorchen",
    "gehorchend": "gehorchen",
    "gehorchende": "gehorchend",
    "gehorchendem": "gehorchend",
    "gehorchenden": "gehorchend",
    "gehorchender": "gehorchend",
    "gehorchendere": "gehorchend",
    "gehorchenderem": "gehorchend",
    "gehorchenderen": "gehorchend",
    "gehorchenderer": "gehorchend",
    "gehorchenderes": "gehorchend",
    "gehorchendes": "gehorchend",
    "gehorchendste": "gehorchend",
    "gehorchendstem": "gehorchend",
    "gehorchendsten": "gehorchend",
    "gehorchendster": "gehorchend",
    "gehorchendstes": "gehorchend",
    "gehorchest": "gehorchen",
    "gehorchet": "gehorchen",
    "gehorchst": "gehorchen",
    "gehorcht": "horchen",
    "gehorchte": "gehorchen",
    "gehorchtem": "gehorcht",
    "gehorchten": "gehorchen",
    "gehorchter": "gehorcht",
    "gehorchtes": "gehorcht",
    "gehorchtest": "gehorchen",
    "gehorchtet": "gehorchen",
    "gehorsamem": "gehorsam",
    "gehorsamen": "gehorsam",
    "gehorsamer": "gehorsam",
    "gehorsamere": "gehorsam",
    "gehorsamerem": "gehorsam",
    "gehorsameren": "gehorsam",
    "gehorsamerer": "gehorsam",
    "gehorsameres": "gehorsam",
    "gehorsames": "gehorsam",
    "gehorsamste": "gehorsam",
    "gehorsamstem": "gehorsam",
    "gehorsamsten": "gehorsam",
    "gehorsamster": "gehorsam",
    "gehorsamstes": "gehorsam",
    "gehortet": "horten",
    "gehortete": "gehortet",
    "gehortetem": "gehortet",
    "gehorteten": "gehortet",
    "gehorteter": "gehortet",
    "gehortetere": "gehortet",
    "gehorteterem": "gehortet",
    "gehorteteren": "gehortet",
    "gehorteterer": "gehortet",
    "gehorteteres": "gehortet",
    "gehortetes": "gehortet",
    "gehorteteste": "gehortet",
    "gehortetestem": "gehortet",
    "gehortetesten": "gehortet",
    "gehortetester": "gehortet",
    "gehortetestes": "gehortet",
    "gehre": "gehren",
    "gehrend": "gehren",
    "gehrende": "gehrend",
    "gehrendem": "gehrend",
    "gehrenden": "gehrend",
    "gehrender": "gehrend",
    "gehrendere": "gehrend",
    "gehrenderem": "gehrend",
    "gehrenderen": "gehrend",
    "gehrenderer": "gehrend",
    "gehrenderes": "gehrend",
    "gehrendes": "gehrend",
    "gehrendste": "gehrend",
    "gehrendstem": "gehrend",
    "gehrendsten": "gehrend",
    "gehrendster": "gehrend",
    "gehrendstes": "gehrend",
    "gehrest": "gehren",
    "gehret": "gehren",
    "gehrst": "gehren",
    "gehrt": "gehren",
    "gehrte": "gehren",
    "gehrten": "gehren",
    "gehrtest": "gehren",
    "gehrtet": "gehren",
    "gehst": "gehen",
    "geht": "gehen",
    "gehuldigt": "huldigen",
    "gehuldigte": "gehuldigt",
    "gehuldigtem": "gehuldigt",
    "gehuldigten": "gehuldigt",
    "gehuldigter": "gehuldigt",
    "gehuldigtes": "gehuldigt",
    "gehungert": "hungern",
    "gehungerte": "gehungert",
    "gehungertem": "gehungert",
    "gehungerten": "gehungert",
    "gehungerter": "gehungert",
    "gehungertes": "gehungert",
    "gehupt": "hupen",
    "gehupte": "gehupt",
    "gehuptem": "gehupt",
    "gehupten": "gehupt",
    "gehupter": "gehupt",
    "gehuptes": "gehupt",
    "gehuscht": "huschen",
    "gehuschte": "gehuscht",
    "gehuschtem": "gehuscht",
    "gehuschten": "gehuscht",
    "gehuschter": "gehuscht",
    "gehuschtes": "gehuscht",
    "gehustet": "husten",
    "gehustete": "gehustet",
    "gehustetem": "gehustet",
    "gehusteten": "gehustet",
    "gehusteter": "gehustet",
    "gehustetes": "gehustet",
    "gehäckselt": "häckseln",
    "gehäckselte": "gehäckselt",
    "gehäckseltem": "gehäckselt",
    "gehäckselten": "gehäckselt",
    "gehäckselter": "gehäckselt",
    "gehäckseltes": "gehäckselt",
    "gehäkelt": "häkeln",
    "gehäkelte": "gehäkelt",
    "gehäkeltem": "gehäkelt",
    "gehäkelten": "gehäkelt",
    "gehäkelter": "gehäkelt",
    "gehäkeltes": "gehäkelt",
    "gehämmert": "hämmern",
    "gehämmerte": "gehämmert",
    "gehämmertem": "gehämmert",
    "gehämmerten": "gehämmert",
    "gehämmerter": "gehämmert",
    "gehämmertere": "gehämmert",
    "gehämmerterem": "gehämmert",
    "gehämmerteren": "gehämmert",
    "gehämmerterer": "gehämmert",
    "gehämmerteres": "gehämmert",
    "gehämmertes": "gehämmert",
    "gehämmerteste": "gehämmert",
    "gehämmertestem": "gehämmert",
    "gehämmertesten": "gehämmert",
    "gehämmertester": "gehämmert",
    "gehämmertestes": "gehämmert",
    "gehändigt": "händigen",
    "gehändigte": "gehändigt",
    "gehändigtem": "gehändigt",
    "gehändigten": "gehändigt",
    "gehändigter": "gehändigt",
    "gehändigtes": "gehändigt",
    "gehängt": "hängen",
    "gehängte": "gehängt",
    "gehängtem": "gehängt",
    "gehängten": "gehängt",
    "gehängter": "gehängt",
    "gehängtes": "gehängt",
    "gehänselt": "hänseln",
    "gehänselte": "gehänselt",
    "gehänseltem": "gehänselt",
    "gehänselten": "gehänselt",
    "gehänselter": "gehänselt",
    "gehänseltere": "gehänselt",
    "gehänselterem": "gehänselt",
    "gehänselteren": "gehänselt",
    "gehänselterer": "gehänselt",
    "gehänselteres": "gehänselt",
    "gehänseltes": "gehänselt",
    "gehänselteste": "gehänselt",
    "gehänseltestem": "gehänselt",
    "gehänseltesten": "gehänselt",
    "gehänseltester": "gehänselt",
    "gehänseltestes": "gehänselt",
    "gehärtet": "härten",
    "gehärtete": "gehärtet",
    "gehärtetem": "gehärtet",
    "gehärteten": "gehärtet",
    "gehärteter": "gehärtet",
    "gehärtetere": "gehärtet",
    "gehärteterem": "gehärtet",
    "gehärteteren": "gehärtet",
    "gehärteterer": "gehärtet",
    "gehärteteres": "gehärtet",
    "gehärtetes": "gehärtet",
    "gehärteteste": "gehärtet",
    "gehärtetestem": "gehärtet",
    "gehärtetesten": "gehärtet",
    "gehärtetester": "gehärtet",
    "gehärtetestes": "gehärtet",
    "gehässige": "gehässig",
    "gehässigem": "gehässig",
    "gehässigen": "gehässig",
    "gehässiger": "gehässig",
    "gehässigere": "gehässig",
    "gehässigerem": "gehässig",
    "gehässigeren": "gehässig",
    "gehässigerer": "gehässig",
    "gehässigeres": "gehässig",
    "gehässiges": "gehässig",
    "gehässigste": "gehässig",
    "gehässigstem": "gehässig",
    "gehässigsten": "gehässig",
    "gehässigster": "gehässig",
    "gehässigstes": "gehässig",
    "gehätschelt": "hätscheln",
    "gehätschelte": "gehätschelt",
    "gehätscheltem": "gehätschelt",
    "gehätschelten": "gehätschelt",
    "gehätschelter": "gehätschelt",
    "gehätscheltere": "gehätschelt",
    "gehätschelterem": "gehätschelt",
    "gehätschelteren": "gehätschelt",
    "gehätschelterer": "gehätschelt",
    "gehätschelteres": "gehätschelt",
    "gehätscheltes": "gehätschelt",
    "gehätschelteste": "gehätschelt",
    "gehätscheltestem": "gehätschelt",
    "gehätscheltesten": "gehätschelt",
    "gehätscheltester": "gehätschelt",
    "gehätscheltestes": "gehätschelt",
    "gehäuft": "häufen",
    "gehäufte": "gehäuft",
    "gehäuftem": "gehäuft",
    "gehäuften": "gehäuft",
    "gehäufter": "gehäuft",
    "gehäuftere": "gehäuft",
    "gehäufterem": "gehäuft",
    "gehäufteren": "gehäuft",
    "gehäufterer": "gehäuft",
    "gehäufteres": "gehäuft",
    "gehäuftes": "gehäuft",
    "gehäufteste": "gehäuft",
    "gehäuftestem": "gehäuft",
    "gehäuftesten": "gehäuft",
    "gehäuftester": "gehäuft",
    "gehäuftestes": "gehäuft",
    "gehäutet": "häuten",
    "gehäutete": "gehäutet",
    "gehäutetem": "gehäutet",
    "gehäuteten": "gehäutet",
    "gehäuteter": "gehäutet",
    "gehäutetes": "gehäutet",
    "gehöhlt": "höhlen",
    "gehöhlte": "gehöhlt",
    "gehöhltem": "gehöhlt",
    "gehöhlten": "gehöhlt",
    "gehöhlter": "gehöhlt",
    "gehöhltes": "gehöhlt",
    "gehölzkundliche": "gehölzkundlich",
    "gehölzkundlichem": "gehölzkundlich",
    "gehölzkundlichen": "gehölzkundlich",
    "gehölzkundlicher": "gehölzkundlich",
    "gehölzkundliches": "gehölzkundlich",
    "gehöre": "gehören",
    "gehörend": "gehören",
    "gehörende": "gehörend",
    "gehörendem": "gehörend",
    "gehörenden": "gehörend",
    "gehörender": "gehörend",
    "gehörendes": "gehörend",
    "gehörest": "gehören",
    "gehöret": "gehören",
    "gehörige": "gehörig",
    "gehörigem": "gehörig",
    "gehörigen": "gehörig",
    "gehöriger": "gehörig",
    "gehöriges": "gehörig",
    "gehörntem": "gehörnt",
    "gehörnten": "gehörnt",
    "gehörnter": "gehörnt",
    "gehörntere": "gehörnt",
    "gehörnterem": "gehörnt",
    "gehörnteren": "gehörnt",
    "gehörnterer": "gehörnt",
    "gehörnteres": "gehörnt",
    "gehörntes": "gehörnt",
    "gehörnteste": "gehörnt",
    "gehörntestem": "gehörnt",
    "gehörntesten": "gehörnt",
    "gehörntester": "gehörnt",
    "gehörntestes": "gehörnt",
    "gehörst": "gehören",
    "gehört": "hören",
    "gehörte": "gehören",
    "gehörtem": "gehört",
    "gehörten": "gehören",
    "gehörter": "gehört",
    "gehörtes": "gehört",
    "gehörtest": "gehören",
    "gehörtet": "gehören",
    "gehüllt": "hüllen",
    "gehüllte": "gehüllt",
    "gehülltem": "gehüllt",
    "gehüllten": "gehüllt",
    "gehüllter": "gehüllt",
    "gehülltes": "gehüllt",
    "gehülst": "hülsen",
    "gehülste": "gehülst",
    "gehülstem": "gehülst",
    "gehülsten": "gehülst",
    "gehülster": "gehülst",
    "gehülstes": "gehülst",
    "gehüpft": "hüpfen",
    "gehüpfte": "gehüpft",
    "gehüpftem": "gehüpft",
    "gehüpften": "gehüpft",
    "gehüpfter": "gehüpft",
    "gehüpftes": "gehüpft",
    "gehütet": "hüten",
    "gehütete": "gehütet",
    "gehütetem": "gehütet",
    "gehüteten": "gehütet",
    "gehüteter": "gehütet",
    "gehütetere": "gehütet",
    "gehüteterem": "gehütet",
    "gehüteteren": "gehütet",
    "gehüteterer": "gehütet",
    "gehüteteres": "gehütet",
    "gehütetes": "gehütet",
    "gehüteteste": "gehütet",
    "gehütetestem": "gehütet",
    "gehütetesten": "gehütet",
    "gehütetester": "gehütet",
    "gehütetestes": "gehütet",
    "geigelt": "igeln",
    "geigelte": "geigelt",
    "geigeltem": "geigelt",
    "geigelten": "geigelt",
    "geigelter": "geigelt",
    "geigeltes": "geigelt",
    "geigend": "geigen",
    "geigende": "geigend",
    "geigendem": "geigend",
    "geigenden": "geigend",
    "geigender": "geigend",
    "geigendes": "geigend",
    "geigest": "geigen",
    "geiget": "geigen",
    "geigst": "geigen",
    "geigt": "geigen",
    "geigte": "geigen",
    "geigten": "geigen",
    "geigtest": "geigen",
    "geigtet": "geigen",
    "geile": "geilen",
    "geilend": "geilen",
    "geilende": "geilend",
    "geilendem": "geilend",
    "geilenden": "geilend",
    "geilender": "geilend",
    "geilendere": "geilend",
    "geilenderem": "geilend",
    "geilenderen": "geilend",
    "geilenderer": "geilend",
    "geilenderes": "geilend",
    "geilendes": "geilend",
    "geilendste": "geilend",
    "geilendstem": "geilend",
    "geilendsten": "geilend",
    "geilendster": "geilend",
    "geilendstes": "geilend",
    "geilest": "geilen",
    "geilet": "geilen",
    "geilst": "geilen",
    "geilt": "geilen",
    "geilte": "geilen",
    "geilten": "geilen",
    "geiltest": "geilen",
    "geiltet": "geilen",
    "geimkert": "imkern",
    "geimkerte": "geimkert",
    "geimkertem": "geimkert",
    "geimkerten": "geimkert",
    "geimkerter": "geimkert",
    "geimkertes": "geimkert",
    "geimpft": "impfen",
    "geimpfte": "geimpft",
    "geimpftem": "geimpft",
    "geimpften": "geimpft",
    "geimpfter": "geimpft",
    "geimpftes": "geimpft",
    "geirrt": "irren",
    "geirrte": "geirrt",
    "geirrtem": "geirrt",
    "geirrten": "geirrt",
    "geirrter": "geirrt",
    "geirrtes": "geirrt",
    "geistere": "geistern",
    "geisterhaftem": "geisterhaft",
    "geisterhaften": "geisterhaft",
    "geisterhafter": "geisterhaft",
    "geisterhaftere": "geisterhaft",
    "geisterhafterem": "geisterhaft",
    "geisterhafteren": "geisterhaft",
    "geisterhafterer": "geisterhaft",
    "geisterhafteres": "geisterhaft",
    "geisterhaftes": "geisterhaft",
    "geisterhafteste": "geisterhaft",
    "geisterhaftestem": "geisterhaft",
    "geisterhaftesten": "geisterhaft",
    "geisterhaftester": "geisterhaft",
    "geisterhaftestes": "geisterhaft",
    "geisternd": "geistern",
    "geisternde": "geisternd",
    "geisterndem": "geisternd",
    "geisternden": "geisternd",
    "geisternder": "geisternd",
    "geisterndes": "geisternd",
    "geisterst": "geistern",
    "geistert": "geistern",
    "geisterte": "geistern",
    "geisterten": "geistern",
    "geistertest": "geistern",
    "geistertet": "geistern",
    "geistesgegenwärtigem": "geistesgegenwärtig",
    "geistesgegenwärtigen": "geistesgegenwärtig",
    "geistesgegenwärtiger": "geistesgegenwärtig",
    "geistesgegenwärtiges": "geistesgegenwärtig",
    "geistesgestörte": "geistesgestört",
    "geistesgestörtem": "geistesgestört",
    "geistesgestörten": "geistesgestört",
    "geistesgestörter": "geistesgestört",
    "geistesgestörtes": "geistesgestört",
    "geisteskranke": "geisteskrank",
    "geisteskrankem": "geisteskrank",
    "geisteskranken": "geisteskrank",
    "geisteskranker": "geisteskrank",
    "geisteskrankes": "geisteskrank",
    "geistesschwache": "geistesschwach",
    "geistesschwachem": "geistesschwach",
    "geistesschwachen": "geistesschwach",
    "geistesschwacher": "geistesschwach",
    "geistesschwaches": "geistesschwach",
    "geistesschwächer": "geistesschwach",
    "geistesschwächere": "geistesschwach",
    "geistesschwächerem": "geistesschwach",
    "geistesschwächeren": "geistesschwach",
    "geistesschwächerer": "geistesschwach",
    "geistesschwächeres": "geistesschwach",
    "geistesschwächste": "geistesschwach",
    "geistesschwächstem": "geistesschwach",
    "geistesschwächsten": "geistesschwach",
    "geistesschwächster": "geistesschwach",
    "geistesschwächstes": "geistesschwach",
    "geistige": "geistig",
    "geistigem": "geistig",
    "geistigen": "geistig",
    "geistiger": "geistig",
    "geistiges": "geistig",
    "geistliche": "geistlich",
    "geistlichem": "geistlich",
    "geistlichen": "geistlich",
    "geistlicher": "geistlich",
    "geistlichere": "geistlich",
    "geistlicherem": "geistlich",
    "geistlicheren": "geistlich",
    "geistlicherer": "geistlich",
    "geistlicheres": "geistlich",
    "geistliches": "geistlich",
    "geistlichste": "geistlich",
    "geistlichstem": "geistlich",
    "geistlichsten": "geistlich",
    "geistlichster": "geistlich",
    "geistlichstes": "geistlich",
    "geistlose": "geistlos",
    "geistlosem": "geistlos",
    "geistlosen": "geistlos",
    "geistloser": "geistlos",
    "geistlosere": "geistlos",
    "geistloserem": "geistlos",
    "geistloseren": "geistlos",
    "geistloserer": "geistlos",
    "geistloseres": "geistlos",
    "geistloses": "geistlos",
    "geistloseste": "geistlos",
    "geistlosestem": "geistlos",
    "geistlosesten": "geistlos",
    "geistlosester": "geistlos",
    "geistlosestes": "geistlos",
    "geistreichem": "geistreich",
    "geistreichen": "geistreich",
    "geistreicher": "geistreich",
    "geistreichere": "geistreich",
    "geistreicherem": "geistreich",
    "geistreicheren": "geistreich",
    "geistreicherer": "geistreich",
    "geistreicheres": "geistreich",
    "geistreiches": "geistreich",
    "geistreichste": "geistreich",
    "geistreichstem": "geistreich",
    "geistreichsten": "geistreich",
    "geistreichster": "geistreich",
    "geistreichstes": "geistreich",
    "geizend": "geizen",
    "geizende": "geizend",
    "geizendem": "geizend",
    "geizenden": "geizend",
    "geizender": "geizend",
    "geizendere": "geizend",
    "geizenderem": "geizend",
    "geizenderen": "geizend",
    "geizenderer": "geizend",
    "geizenderes": "geizend",
    "geizendes": "geizend",
    "geizendste": "geizend",
    "geizendstem": "geizend",
    "geizendsten": "geizend",
    "geizendster": "geizend",
    "geizendstes": "geizend",
    "geizest": "geizen",
    "geizet": "geizen",
    "geizige": "geizig",
    "geizigem": "geizig",
    "geizigen": "geizig",
    "geiziger": "geizig",
    "geizigere": "geizig",
    "geizigerem": "geizig",
    "geizigeren": "geizig",
    "geizigerer": "geizig",
    "geizigeres": "geizig",
    "geiziges": "geizig",
    "geizigste": "geizig",
    "geizigstem": "geizig",
    "geizigsten": "geizig",
    "geizigster": "geizig",
    "geizigstes": "geizig",
    "geizt": "geizen",
    "geizte": "geizen",
    "geizten": "geizen",
    "geiztest": "geizen",
    "geiztet": "geizen",
    "geißele": "geißeln",
    "geißelnd": "geißeln",
    "geißelnde": "geißelnd",
    "geißelndem": "geißelnd",
    "geißelnden": "geißelnd",
    "geißelnder": "geißelnd",
    "geißelndere": "geißelnd",
    "geißelnderem": "geißelnd",
    "geißelnderen": "geißelnd",
    "geißelnderer": "geißelnd",
    "geißelnderes": "geißelnd",
    "geißelndes": "geißelnd",
    "geißelndste": "geißelnd",
    "geißelndstem": "geißelnd",
    "geißelndsten": "geißelnd",
    "geißelndster": "geißelnd",
    "geißelndstes": "geißelnd",
    "geißelst": "geißeln",
    "geißelt": "geißeln",
    "geißelte": "geißeln",
    "geißelten": "geißeln",
    "geißeltest": "geißeln",
    "geißeltet": "geißeln",
    "geißle": "geißeln",
    "gejagt": "jagen",
    "gejagte": "gejagt",
    "gejagtem": "gejagt",
    "gejagten": "gejagt",
    "gejagter": "gejagt",
    "gejagtere": "gejagt",
    "gejagterem": "gejagt",
    "gejagteren": "gejagt",
    "gejagterer": "gejagt",
    "gejagteres": "gejagt",
    "gejagtes": "gejagt",
    "gejagteste": "gejagt",
    "gejagtestem": "gejagt",
    "gejagtesten": "gejagt",
    "gejagtester": "gejagt",
    "gejagtestes": "gejagt",
    "gejammert": "jammern",
    "gejammerte": "gejammert",
    "gejammertem": "gejammert",
    "gejammerten": "gejammert",
    "gejammerter": "gejammert",
    "gejammertes": "gejammert",
    "gejapst": "japsen",
    "gejapste": "gejapst",
    "gejapstem": "gejapst",
    "gejapsten": "gejapst",
    "gejapster": "gejapst",
    "gejapstes": "gejapst",
    "gejauchzt": "jauchzen",
    "gejauchzte": "gejauchzt",
    "gejauchztem": "gejauchzt",
    "gejauchzten": "gejauchzt",
    "gejauchzter": "gejauchzt",
    "gejauchztes": "gejauchzt",
    "gejault": "jaulen",
    "gejaulte": "gejault",
    "gejaultem": "gejault",
    "gejaulten": "gejault",
    "gejaulter": "gejault",
    "gejaultes": "gejault",
    "gejobbt": "jobben",
    "gejobbte": "gejobbt",
    "gejobbtem": "gejobbt",
    "gejobbten": "gejobbt",
    "gejobbter": "gejobbt",
    "gejobbtes": "gejobbt",
    "gejodelt": "jodeln",
    "gejodelte": "gejodelt",
    "gejodeltem": "gejodelt",
    "gejodelten": "gejodelt",
    "gejodelter": "gejodelt",
    "gejodeltes": "gejodelt",
    "gejohlt": "johlen",
    "gejohlte": "gejohlt",
    "gejohltem": "gejohlt",
    "gejohlten": "gejohlt",
    "gejohlter": "gejohlt",
    "gejohltes": "gejohlt",
    "gejubelt": "jubeln",
    "gejubelte": "gejubelt",
    "gejubeltem": "gejubelt",
    "gejubelten": "gejubelt",
    "gejubelter": "gejubelt",
    "gejubeltere": "gejubelt",
    "gejubelterem": "gejubelt",
    "gejubelteren": "gejubelt",
    "gejubelterer": "gejubelt",
    "gejubelteres": "gejubelt",
    "gejubeltes": "gejubelt",
    "gejubelteste": "gejubelt",
    "gejubeltestem": "gejubelt",
    "gejubeltesten": "gejubelt",
    "gejubeltester": "gejubelt",
    "gejubeltestes": "gejubelt",
    "gejuchzt": "juchzen",
    "gejuchzte": "gejuchzt",
    "gejuchztem": "gejuchzt",
    "gejuchzten": "gejuchzt",
    "gejuchzter": "gejuchzt",
    "gejuchztes": "gejuchzt",
    "gejätet": "jäten",
    "gejätete": "gejätet",
    "gejätetem": "gejätet",
    "gejäteten": "gejätet",
    "gejäteter": "gejätet",
    "gejätetes": "gejätet",
    "gekachelt": "kacheln",
    "gekachelte": "gekachelt",
    "gekacheltem": "gekachelt",
    "gekachelten": "gekachelt",
    "gekachelter": "gekachelt",
    "gekacheltere": "gekachelt",
    "gekachelterem": "gekachelt",
    "gekachelteren": "gekachelt",
    "gekachelterer": "gekachelt",
    "gekachelteres": "gekachelt",
    "gekacheltes": "gekachelt",
    "gekachelteste": "gekachelt",
    "gekacheltestem": "gekachelt",
    "gekacheltesten": "gekachelt",
    "gekacheltester": "gekachelt",
    "gekacheltestes": "gekachelt",
    "gekakelt": "kakeln",
    "gekakelte": "gekakelt",
    "gekakeltem": "gekakelt",
    "gekakelten": "gekakelt",
    "gekakelter": "gekakelt",
    "gekakeltere": "gekakelt",
    "gekakelterem": "gekakelt",
    "gekakelteren": "gekakelt",
    "gekakelterer": "gekakelt",
    "gekakelteres": "gekakelt",
    "gekakeltes": "gekakelt",
    "gekakelteste": "gekakelt",
    "gekakeltestem": "gekakelt",
    "gekakeltesten": "gekakelt",
    "gekakeltester": "gekakelt",
    "gekakeltestes": "gekakelt",
    "gekalbt": "kalben",
    "gekalbte": "gekalbt",
    "gekalbtem": "gekalbt",
    "gekalbten": "gekalbt",
    "gekalbter": "gekalbt",
    "gekalbtes": "gekalbt",
    "gekalkt": "kalken",
    "gekalkte": "gekalkt",
    "gekalktem": "gekalkt",
    "gekalkten": "gekalkt",
    "gekalkter": "gekalkt",
    "gekalktes": "gekalkt",
    "gekannt": "kennen",
    "gekannte": "gekannt",
    "gekanntem": "gekannt",
    "gekannten": "gekannt",
    "gekannter": "gekannt",
    "gekanntes": "gekannt",
    "gekantet": "kanten",
    "gekantete": "gekantet",
    "gekantetem": "gekantet",
    "gekanteten": "gekantet",
    "gekanteter": "gekantet",
    "gekantetere": "gekantet",
    "gekanteterem": "gekantet",
    "gekanteteren": "gekantet",
    "gekanteterer": "gekantet",
    "gekanteteres": "gekantet",
    "gekantetes": "gekantet",
    "gekanteteste": "gekantet",
    "gekantetestem": "gekantet",
    "gekantetesten": "gekantet",
    "gekantetester": "gekantet",
    "gekantetestes": "gekantet",
    "gekanzelt": "kanzeln",
    "gekanzelte": "gekanzelt",
    "gekanzeltem": "gekanzelt",
    "gekanzelten": "gekanzelt",
    "gekanzelter": "gekanzelt",
    "gekanzeltes": "gekanzelt",
    "gekapert": "kapern",
    "gekaperte": "gekapert",
    "gekapertem": "gekapert",
    "gekaperten": "gekapert",
    "gekaperter": "gekapert",
    "gekapertes": "gekapert",
    "gekappt": "kappen",
    "gekappte": "gekappt",
    "gekapptem": "gekappt",
    "gekappten": "gekappt",
    "gekappter": "gekappt",
    "gekapptes": "gekappt",
    "gekapselt": "kapseln",
    "gekapselte": "gekapselt",
    "gekapseltem": "gekapselt",
    "gekapselten": "gekapselt",
    "gekapselter": "gekapselt",
    "gekapseltes": "gekapselt",
    "gekarrt": "karren",
    "gekarrte": "gekarrt",
    "gekarrtem": "gekarrt",
    "gekarrten": "gekarrt",
    "gekarrter": "gekarrt",
    "gekarrtes": "gekarrt",
    "gekartet": "karten",
    "gekartete": "gekartet",
    "gekartetem": "gekartet",
    "gekarteten": "gekartet",
    "gekarteter": "gekartet",
    "gekartetes": "gekartet",
    "gekaspert": "kaspern",
    "gekasperte": "gekaspert",
    "gekaspertem": "gekaspert",
    "gekasperten": "gekaspert",
    "gekasperter": "gekaspert",
    "gekaspertes": "gekaspert",
    "gekauert": "kauern",
    "gekauerte": "gekauert",
    "gekauertem": "gekauert",
    "gekauerten": "gekauert",
    "gekauerter": "gekauert",
    "gekauertes": "gekauert",
    "gekauft": "kaufen",
    "gekaufte": "gekauft",
    "gekauftem": "gekauft",
    "gekauften": "gekauft",
    "gekaufter": "gekauft",
    "gekauftes": "gekauft",
    "gekaut": "kauen",
    "gekaute": "gekaut",
    "gekautem": "gekaut",
    "gekauten": "gekaut",
    "gekauter": "gekaut",
    "gekautes": "gekaut",
    "gekegelt": "kegeln",
    "gekegelte": "gekegelt",
    "gekegeltem": "gekegelt",
    "gekegelten": "gekegelt",
    "gekegelter": "gekegelt",
    "gekegeltere": "gekegelt",
    "gekegelterem": "gekegelt",
    "gekegelteren": "gekegelt",
    "gekegelterer": "gekegelt",
    "gekegelteres": "gekegelt",
    "gekegeltes": "gekegelt",
    "gekegelteste": "gekegelt",
    "gekegeltestem": "gekegelt",
    "gekegeltesten": "gekegelt",
    "gekegeltester": "gekegelt",
    "gekegeltestes": "gekegelt",
    "gekehrt": "kehren",
    "gekehrte": "gekehrt",
    "gekehrtem": "gekehrt",
    "gekehrten": "gekehrt",
    "gekehrter": "gekehrt",
    "gekehrtes": "gekehrt",
    "gekeift": "keifen",
    "gekeifte": "gekeift",
    "gekeiftem": "gekeift",
    "gekeiften": "gekeift",
    "gekeifter": "gekeift",
    "gekeiftes": "gekeift",
    "gekeilt": "keilen",
    "gekeilte": "gekeilt",
    "gekeiltem": "gekeilt",
    "gekeilten": "gekeilt",
    "gekeilter": "gekeilt",
    "gekeiltes": "gekeilt",
    "gekeimt": "keimen",
    "gekeimte": "gekeimt",
    "gekeimtem": "gekeimt",
    "gekeimten": "gekeimt",
    "gekeimter": "gekeimt",
    "gekeimtes": "gekeimt",
    "gekellert": "kellern",
    "gekellerte": "gekellert",
    "gekellertem": "gekellert",
    "gekellerten": "gekellert",
    "gekellerter": "gekellert",
    "gekellertes": "gekellert",
    "gekellnert": "kellnern",
    "gekellnerte": "gekellnert",
    "gekellnertem": "gekellnert",
    "gekellnerten": "gekellnert",
    "gekellnerter": "gekellnert",
    "gekellnertes": "gekellnert",
    "gekeltert": "keltern",
    "gekelterte": "gekeltert",
    "gekeltertem": "gekeltert",
    "gekelterten": "gekeltert",
    "gekelterter": "gekeltert",
    "gekeltertes": "gekeltert",
    "gekennzeichnet": "kennzeichnen",
    "gekennzeichnete": "gekennzeichnet",
    "gekennzeichnetem": "gekennzeichnet",
    "gekennzeichneten": "gekennzeichnet",
    "gekennzeichneter": "gekennzeichnet",
    "gekennzeichnetes": "gekennzeichnet",
    "gekentert": "kentern",
    "gekenterte": "gekentert",
    "gekentertem": "gekentert",
    "gekenterten": "gekentert",
    "gekenterter": "gekentert",
    "gekentertes": "gekentert",
    "gekerbt": "kerben",
    "gekerbte": "gekerbt",
    "gekerbtem": "gekerbt",
    "gekerbten": "gekerbt",
    "gekerbter": "gekerbt",
    "gekerbtes": "gekerbt",
    "gekerkert": "kerkern",
    "gekerkerte": "gekerkert",
    "gekerkertem": "gekerkert",
    "gekerkerten": "gekerkert",
    "gekerkerter": "gekerkert",
    "gekerkertes": "gekerkert",
    "gekernt": "kernen",
    "gekernte": "gekernt",
    "gekerntem": "gekernt",
    "gekernten": "gekernt",
    "gekernter": "gekernt",
    "gekerntes": "gekernt",
    "gekesselt": "kesseln",
    "gekesselte": "gekesselt",
    "gekesseltem": "gekesselt",
    "gekesselten": "gekesselt",
    "gekesselter": "gekesselt",
    "gekesseltes": "gekesselt",
    "gekettet": "ketten",
    "gekettete": "gekettet",
    "gekettetem": "gekettet",
    "geketteten": "gekettet",
    "geketteter": "gekettet",
    "gekettetes": "gekettet",
    "gekeucht": "keuchen",
    "gekeuchte": "gekeucht",
    "gekeuchtem": "gekeucht",
    "gekeuchten": "gekeucht",
    "gekeuchter": "gekeucht",
    "gekeuchtes": "gekeucht",
    "gekichert": "kichern",
    "gekicherte": "gekichert",
    "gekichertem": "gekichert",
    "gekicherten": "gekichert",
    "gekicherter": "gekichert",
    "gekichertes": "gekichert",
    "gekickt": "kicken",
    "gekickte": "gekickt",
    "gekicktem": "gekickt",
    "gekickten": "gekickt",
    "gekickter": "gekickt",
    "gekicktes": "gekickt",
    "gekiekt": "kieken",
    "gekiekte": "gekiekt",
    "gekiektem": "gekiekt",
    "gekiekten": "gekiekt",
    "gekiekter": "gekiekt",
    "gekiektes": "gekiekt",
    "gekifft": "kiffen",
    "gekiffte": "gekifft",
    "gekifftem": "gekifft",
    "gekifften": "gekifft",
    "gekiffter": "gekifft",
    "gekifftes": "gekifft",
    "gekillt": "killen",
    "gekillte": "gekillt",
    "gekilltem": "gekillt",
    "gekillten": "gekillt",
    "gekillter": "gekillt",
    "gekilltes": "gekillt",
    "gekippt": "kippen",
    "gekippte": "gekippt",
    "gekipptem": "gekippt",
    "gekippten": "gekippt",
    "gekippter": "gekippt",
    "gekipptes": "gekippt",
    "gekittet": "kitten",
    "gekittete": "gekittet",
    "gekittetem": "gekittet",
    "gekitteten": "gekittet",
    "gekitteter": "gekittet",
    "gekittetere": "gekittet",
    "gekitteterem": "gekittet",
    "gekitteteren": "gekittet",
    "gekitteterer": "gekittet",
    "gekitteteres": "gekittet",
    "gekittetes": "gekittet",
    "gekitteteste": "gekittet",
    "gekittetestem": "gekittet",
    "gekittetesten": "gekittet",
    "gekittetester": "gekittet",
    "gekittetestes": "gekittet",
    "gekitzelt": "kitzeln",
    "gekitzelte": "gekitzelt",
    "gekitzeltem": "gekitzelt",
    "gekitzelten": "gekitzelt",
    "gekitzelter": "gekitzelt",
    "gekitzeltere": "gekitzelt",
    "gekitzelterem": "gekitzelt",
    "gekitzelteren": "gekitzelt",
    "gekitzelterer": "gekitzelt",
    "gekitzelteres": "gekitzelt",
    "gekitzeltes": "gekitzelt",
    "gekitzelteste": "gekitzelt",
    "gekitzeltestem": "gekitzelt",
    "gekitzeltesten": "gekitzelt",
    "gekitzeltester": "gekitzelt",
    "gekitzeltestes": "gekitzelt",
    "geklackert": "klackern",
    "geklackerte": "geklackert",
    "geklackertem": "geklackert",
    "geklackerten": "geklackert",
    "geklackerter": "geklackert",
    "geklackertes": "geklackert",
    "geklafft": "klaffen",
    "geklaffte": "geklafft",
    "geklafftem": "geklafft",
    "geklafften": "geklafft",
    "geklaffter": "geklafft",
    "geklafftes": "geklafft",
    "geklagt": "klagen",
    "geklagte": "geklagt",
    "geklagtem": "geklagt",
    "geklagten": "geklagt",
    "geklagter": "geklagt",
    "geklagtes": "geklagt",
    "geklammert": "klammern",
    "geklammerte": "geklammert",
    "geklammertem": "geklammert",
    "geklammerten": "geklammert",
    "geklammerter": "geklammert",
    "geklammertere": "geklammert",
    "geklammerterem": "geklammert",
    "geklammerteren": "geklammert",
    "geklammerterer": "geklammert",
    "geklammerteres": "geklammert",
    "geklammertes": "geklammert",
    "geklammerteste": "geklammert",
    "geklammertestem": "geklammert",
    "geklammertesten": "geklammert",
    "geklammertester": "geklammert",
    "geklammertestes": "geklammert",
    "geklappert": "klappern",
    "geklapperte": "geklappert",
    "geklappertem": "geklappert",
    "geklapperten": "geklappert",
    "geklapperter": "geklappert",
    "geklappertes": "geklappert",
    "geklappt": "klappen",
    "geklappte": "geklappt",
    "geklapptem": "geklappt",
    "geklappten": "geklappt",
    "geklappter": "geklappt",
    "geklapptes": "geklappt",
    "geklart": "klaren",
    "geklarte": "geklart",
    "geklartem": "geklart",
    "geklarten": "geklart",
    "geklarter": "geklart",
    "geklartes": "geklart",
    "geklatscht": "klatschen",
    "geklatschte": "geklatscht",
    "geklatschtem": "geklatscht",
    "geklatschten": "geklatscht",
    "geklatschter": "geklatscht",
    "geklatschtere": "geklatscht",
    "geklatschterem": "geklatscht",
    "geklatschteren": "geklatscht",
    "geklatschterer": "geklatscht",
    "geklatschteres": "geklatscht",
    "geklatschtes": "geklatscht",
    "geklatschteste": "geklatscht",
    "geklatschtestem": "geklatscht",
    "geklatschtesten": "geklatscht",
    "geklatschtester": "geklatscht",
    "geklatschtestes": "geklatscht",
    "geklaubt": "klauben",
    "geklaubte": "geklaubt",
    "geklaubtem": "geklaubt",
    "geklaubten": "geklaubt",
    "geklaubter": "geklaubt",
    "geklaubtes": "geklaubt",
    "geklaut": "klauen",
    "geklaute": "geklaut",
    "geklautem": "geklaut",
    "geklauten": "geklaut",
    "geklauter": "geklaut",
    "geklautes": "geklaut",
    "geklebt": "kleben",
    "geklebte": "geklebt",
    "geklebtem": "geklebt",
    "geklebten": "geklebt",
    "geklebter": "geklebt",
    "geklebtere": "geklebt",
    "geklebterem": "geklebt",
    "geklebteren": "geklebt",
    "geklebterer": "geklebt",
    "geklebteres": "geklebt",
    "geklebtes": "geklebt",
    "geklebteste": "geklebt",
    "geklebtestem": "geklebt",
    "geklebtesten": "geklebt",
    "geklebtester": "geklebt",
    "geklebtestes": "geklebt",
    "gekleckert": "kleckern",
    "gekleckerte": "gekleckert",
    "gekleckertem": "gekleckert",
    "gekleckerten": "gekleckert",
    "gekleckerter": "gekleckert",
    "gekleckertes": "gekleckert",
    "gekleckst": "klecksen",
    "gekleckste": "gekleckst",
    "gekleckstem": "gekleckst",
    "geklecksten": "gekleckst",
    "gekleckster": "gekleckst",
    "gekleckstes": "gekleckst",
    "gekleidet": "kleiden",
    "gekleidete": "gekleidet",
    "gekleidetem": "gekleidet",
    "gekleideten": "gekleidet",
    "gekleideter": "gekleidet",
    "gekleidetere": "gekleidet",
    "gekleideterem": "gekleidet",
    "gekleideteren": "gekleidet",
    "gekleideterer": "gekleidet",
    "gekleideteres": "gekleidet",
    "gekleidetes": "gekleidet",
    "gekleideteste": "gekleidet",
    "gekleidetestem": "gekleidet",
    "gekleidetesten": "gekleidet",
    "gekleidetester": "gekleidet",
    "gekleidetestes": "gekleidet",
    "gekleistert": "kleistern",
    "gekleisterte": "gekleistert",
    "gekleistertem": "gekleistert",
    "gekleisterten": "gekleistert",
    "gekleisterter": "gekleistert",
    "gekleistertes": "gekleistert",
    "geklemmt": "klemmen",
    "geklemmte": "geklemmt",
    "geklemmtem": "geklemmt",
    "geklemmten": "geklemmt",
    "geklemmter": "geklemmt",
    "geklemmtes": "geklemmt",
    "geklempnert": "klempnern",
    "geklempnerte": "geklempnert",
    "geklempnertem": "geklempnert",
    "geklempnerten": "geklempnert",
    "geklempnerter": "geklempnert",
    "geklempnertes": "geklempnert",
    "geklettert": "klettern",
    "gekletterte": "geklettert",
    "geklettertem": "geklettert",
    "gekletterten": "geklettert",
    "gekletterter": "geklettert",
    "geklettertes": "geklettert",
    "geklimpert": "klimpern",
    "geklimperte": "geklimpert",
    "geklimpertem": "geklimpert",
    "geklimperten": "geklimpert",
    "geklimperter": "geklimpert",
    "geklimpertes": "geklimpert",
    "geklingelt": "klingeln",
    "geklingelte": "geklingelt",
    "geklingeltem": "geklingelt",
    "geklingelten": "geklingelt",
    "geklingelter": "geklingelt",
    "geklingeltes": "geklingelt",
    "geklinkt": "klinken",
    "geklinkte": "geklinkt",
    "geklinktem": "geklinkt",
    "geklinkten": "geklinkt",
    "geklinkter": "geklinkt",
    "geklinktes": "geklinkt",
    "geklirrt": "klirren",
    "geklirrte": "geklirrt",
    "geklirrtem": "geklirrt",
    "geklirrten": "geklirrt",
    "geklirrter": "geklirrt",
    "geklirrtes": "geklirrt",
    "geklommen": "klimmen",
    "geklommene": "geklommen",
    "geklommenem": "geklommen",
    "geklommenen": "geklommen",
    "geklommener": "geklommen",
    "geklommenes": "geklommen",
    "geklont": "klonen",
    "geklonte": "geklont",
    "geklontem": "geklont",
    "geklonten": "geklont",
    "geklonter": "geklont",
    "geklontes": "geklont",
    "geklopft": "klopfen",
    "geklopfte": "geklopft",
    "geklopftem": "geklopft",
    "geklopften": "geklopft",
    "geklopfter": "geklopft",
    "geklopftes": "geklopft",
    "gekloppt": "kloppen",
    "gekloppte": "gekloppt",
    "geklopptem": "gekloppt",
    "gekloppten": "gekloppt",
    "gekloppter": "gekloppt",
    "geklopptes": "gekloppt",
    "geklotzt": "klotzen",
    "geklotzte": "geklotzt",
    "geklotztem": "geklotzt",
    "geklotzten": "geklotzt",
    "geklotzter": "geklotzt",
    "geklotztere": "geklotzt",
    "geklotzterem": "geklotzt",
    "geklotzteren": "geklotzt",
    "geklotzterer": "geklotzt",
    "geklotzteres": "geklotzt",
    "geklotztes": "geklotzt",
    "geklotzteste": "geklotzt",
    "geklotztestem": "geklotzt",
    "geklotztesten": "geklotzt",
    "geklotztester": "geklotzt",
    "geklotztestes": "geklotzt",
    "geklumpt": "klumpen",
    "geklumpte": "geklumpt",
    "geklumptem": "geklumpt",
    "geklumpten": "geklumpt",
    "geklumpter": "geklumpt",
    "geklumptere": "geklumpt",
    "geklumpterem": "geklumpt",
    "geklumpteren": "geklumpt",
    "geklumpterer": "geklumpt",
    "geklumpteres": "geklumpt",
    "geklumptes": "geklumpt",
    "geklumpteste": "geklumpt",
    "geklumptestem": "geklumpt",
    "geklumptesten": "geklumpt",
    "geklumptester": "geklumpt",
    "geklumptestes": "geklumpt",
    "geklungen": "klingen",
    "geklungene": "geklungen",
    "geklungenem": "geklungen",
    "geklungenen": "geklungen",
    "geklungener": "geklungen",
    "geklungenere": "geklungen",
    "geklungenerem": "geklungen",
    "geklungeneren": "geklungen",
    "geklungenerer": "geklungen",
    "geklungeneres": "geklungen",
    "geklungenes": "geklungen",
    "geklungenste": "geklungen",
    "geklungenstem": "geklungen",
    "geklungensten": "geklungen",
    "geklungenster": "geklungen",
    "geklungenstes": "geklungen",
    "gekläfft": "kläffen",
    "gekläfftem": "gekläfft",
    "gekläffter": "gekläfft",
    "gekläfftes": "gekläfft",
    "geklärt": "klären",
    "geklärtem": "geklärt",
    "geklärter": "geklärt",
    "geklärtere": "geklärt",
    "geklärterem": "geklärt",
    "geklärteren": "geklärt",
    "geklärterer": "geklärt",
    "geklärteres": "geklärt",
    "geklärtes": "geklärt",
    "geklärteste": "geklärt",
    "geklärtestem": "geklärt",
    "geklärtesten": "geklärt",
    "geklärtester": "geklärt",
    "geklärtestes": "geklärt",
    "geklöhnt": "klöhnen",
    "geklöhnte": "geklöhnt",
    "geklöhntem": "geklöhnt",
    "geklöhnten": "geklöhnt",
    "geklöhnter": "geklöhnt",
    "geklöhntes": "geklöhnt",
    "geklönt": "klönen",
    "geklöntem": "geklönt",
    "geklönter": "geklönt",
    "geklöntes": "geklönt",
    "geklügelt": "klügeln",
    "geklügelte": "geklügelt",
    "geklügeltem": "geklügelt",
    "geklügelten": "geklügelt",
    "geklügelter": "geklügelt",
    "geklügeltes": "geklügelt",
    "geklüngelt": "klüngeln",
    "geklüngelte": "geklüngelt",
    "geklüngeltem": "geklüngelt",
    "geklüngelten": "geklüngelt",
    "geklüngelter": "geklüngelt",
    "geklüngeltes": "geklüngelt",
    "geknabbert": "knabbern",
    "geknabberte": "geknabbert",
    "geknabbertem": "geknabbert",
    "geknabberten": "geknabbert",
    "geknabberter": "geknabbert",
    "geknabbertes": "geknabbert",
    "geknackst": "knacksen",
    "geknackste": "geknackst",
    "geknackstem": "geknackst",
    "geknacksten": "geknackst",
    "geknackster": "geknackst",
    "geknackstere": "geknackst",
    "geknacksterem": "geknackst",
    "geknacksteren": "geknackst",
    "geknacksterer": "geknackst",
    "geknacksteres": "geknackst",
    "geknackstes": "geknackst",
    "geknacksteste": "geknackst",
    "geknackstestem": "geknackst",
    "geknackstesten": "geknackst",
    "geknackstester": "geknackst",
    "geknackstestes": "geknackst",
    "geknackt": "knacken",
    "geknackte": "geknackt",
    "geknacktem": "geknackt",
    "geknackten": "geknackt",
    "geknackter": "geknackt",
    "geknacktere": "geknackt",
    "geknackterem": "geknackt",
    "geknackteren": "geknackt",
    "geknackterer": "geknackt",
    "geknackteres": "geknackt",
    "geknacktes": "geknackt",
    "geknackteste": "geknackt",
    "geknacktestem": "geknackt",
    "geknacktesten": "geknackt",
    "geknacktester": "geknackt",
    "geknacktestes": "geknackt",
    "geknallt": "knallen",
    "geknallte": "geknallt",
    "geknalltem": "geknallt",
    "geknallten": "geknallt",
    "geknallter": "geknallt",
    "geknalltes": "geknallt",
    "geknapst": "knapsen",
    "geknapste": "geknapst",
    "geknapstem": "geknapst",
    "geknapsten": "geknapst",
    "geknapster": "geknapst",
    "geknapstes": "geknapst",
    "geknarrt": "knarren",
    "geknarrte": "geknarrt",
    "geknarrtem": "geknarrt",
    "geknarrten": "geknarrt",
    "geknarrter": "geknarrt",
    "geknarrtes": "geknarrt",
    "geknarzt": "knarzen",
    "geknarzte": "geknarzt",
    "geknarztem": "geknarzt",
    "geknarzten": "geknarzt",
    "geknarzter": "geknarzt",
    "geknarztere": "geknarzt",
    "geknarzterem": "geknarzt",
    "geknarzteren": "geknarzt",
    "geknarzterer": "geknarzt",
    "geknarzteres": "geknarzt",
    "geknarztes": "geknarzt",
    "geknarzteste": "geknarzt",
    "geknarztestem": "geknarzt",
    "geknarztesten": "geknarzt",
    "geknarztester": "geknarzt",
    "geknarztestes": "geknarzt",
    "geknattert": "knattern",
    "geknatterte": "geknattert",
    "geknattertem": "geknattert",
    "geknatterten": "geknattert",
    "geknatterter": "geknattert",
    "geknattertes": "geknattert",
    "geknausert": "knausern",
    "geknauserte": "geknausert",
    "geknausertem": "geknausert",
    "geknauserten": "geknausert",
    "geknauserter": "geknausert",
    "geknausertes": "geknausert",
    "geknautscht": "knautschen",
    "geknautschte": "geknautscht",
    "geknautschtem": "geknautscht",
    "geknautschten": "geknautscht",
    "geknautschter": "geknautscht",
    "geknautschtere": "geknautscht",
    "geknautschterem": "geknautscht",
    "geknautschteren": "geknautscht",
    "geknautschterer": "geknautscht",
    "geknautschteres": "geknautscht",
    "geknautschtes": "geknautscht",
    "geknautschteste": "geknautscht",
    "geknautschtestem": "geknautscht",
    "geknautschtesten": "geknautscht",
    "geknautschtester": "geknautscht",
    "geknautschtestes": "geknautscht",
    "geknebelt": "knebeln",
    "geknebelte": "geknebelt",
    "geknebeltem": "geknebelt",
    "geknebelten": "geknebelt",
    "geknebelter": "geknebelt",
    "geknebeltere": "geknebelt",
    "geknebelterem": "geknebelt",
    "geknebelteren": "geknebelt",
    "geknebelterer": "geknebelt",
    "geknebelteres": "geknebelt",
    "geknebeltes": "geknebelt",
    "geknebelteste": "geknebelt",
    "geknebeltestem": "geknebelt",
    "geknebeltesten": "geknebelt",
    "geknebeltester": "geknebelt",
    "geknebeltestes": "geknebelt",
    "geknechtet": "knechten",
    "geknechtete": "geknechtet",
    "geknechtetem": "geknechtet",
    "geknechteten": "geknechtet",
    "geknechteter": "geknechtet",
    "geknechtetes": "geknechtet",
    "geknetet": "kneten",
    "geknetete": "geknetet",
    "geknetetem": "geknetet",
    "gekneteten": "geknetet",
    "gekneteter": "geknetet",
    "geknetetes": "geknetet",
    "geknickst": "knicksen",
    "geknickste": "geknickst",
    "geknickstem": "geknickst",
    "geknicksten": "geknickst",
    "geknickster": "geknickst",
    "geknickstes": "geknickst",
    "geknickt": "knicken",
    "geknickte": "geknickt",
    "geknicktem": "geknickt",
    "geknickten": "geknickt",
    "geknickter": "geknickt",
    "geknicktere": "geknickt",
    "geknickterem": "geknickt",
    "geknickteren": "geknickt",
    "geknickterer": "geknickt",
    "geknickteres": "geknickt",
    "geknicktes": "geknickt",
    "geknickteste": "geknickt",
    "geknicktestem": "geknickt",
    "geknicktesten": "geknickt",
    "geknicktester": "geknickt",
    "geknicktestes": "geknickt",
    "gekniet": "knien",
    "gekniete": "gekniet",
    "geknietem": "gekniet",
    "geknieten": "gekniet",
    "geknieter": "gekniet",
    "geknietes": "gekniet",
    "gekniffen": "kneifen",
    "gekniffene": "gekniffen",
    "gekniffenem": "gekniffen",
    "gekniffenen": "gekniffen",
    "gekniffener": "gekniffen",
    "gekniffenes": "gekniffen",
    "geknipst": "knipsen",
    "geknipste": "geknipst",
    "geknipstem": "geknipst",
    "geknipsten": "geknipst",
    "geknipster": "geknipst",
    "geknipstes": "geknipst",
    "geknirscht": "knirschen",
    "geknirschte": "geknirscht",
    "geknirschtem": "geknirscht",
    "geknirschten": "geknirscht",
    "geknirschter": "geknirscht",
    "geknirschtes": "geknirscht",
    "geknistert": "knistern",
    "geknisterte": "geknistert",
    "geknistertem": "geknistert",
    "geknisterten": "geknistert",
    "geknisterter": "geknistert",
    "geknistertes": "geknistert",
    "geknittert": "knittern",
    "geknitterte": "geknittert",
    "geknittertem": "geknittert",
    "geknitterten": "geknittert",
    "geknitterter": "geknittert",
    "geknittertere": "geknittert",
    "geknitterterem": "geknittert",
    "geknitterteren": "geknittert",
    "geknitterterer": "geknittert",
    "geknitterteres": "geknittert",
    "geknittertes": "geknittert",
    "geknitterteste": "geknittert",
    "geknittertestem": "geknittert",
    "geknittertesten": "geknittert",
    "geknittertester": "geknittert",
    "geknittertestes": "geknittert",
    "geknobelt": "knobeln",
    "geknobelte": "geknobelt",
    "geknobeltem": "geknobelt",
    "geknobelten": "geknobelt",
    "geknobelter": "geknobelt",
    "geknobeltes": "geknobelt",
    "geknotet": "knoten",
    "geknotete": "geknotet",
    "geknotetem": "geknotet",
    "geknoteten": "geknotet",
    "geknoteter": "geknotet",
    "geknotetes": "geknotet",
    "geknufft": "knuffen",
    "geknuffte": "geknufft",
    "geknufftem": "geknufft",
    "geknufften": "geknufft",
    "geknuffter": "geknufft",
    "geknufftes": "geknufft",
    "geknurrt": "knurren",
    "geknurrte": "geknurrt",
    "geknurrtem": "geknurrt",
    "geknurrten": "geknurrt",
    "geknurrter": "geknurrt",
    "geknurrtes": "geknurrt",
    "geknuspert": "knuspern",
    "geknusperte": "geknuspert",
    "geknuspertem": "geknuspert",
    "geknusperten": "geknuspert",
    "geknusperter": "geknuspert",
    "geknuspertes": "geknuspert",
    "geknutscht": "knutschen",
    "geknutschte": "geknutscht",
    "geknutschtem": "geknutscht",
    "geknutschten": "geknutscht",
    "geknutschter": "geknutscht",
    "geknutschtes": "geknutscht",
    "geknöpft": "knöpfen",
    "geknöpfte": "geknöpft",
    "geknöpftem": "geknöpft",
    "geknöpften": "geknöpft",
    "geknöpfter": "geknöpft",
    "geknöpftes": "geknöpft",
    "geknüllt": "knüllen",
    "geknüllte": "geknüllt",
    "geknülltem": "geknüllt",
    "geknüllten": "geknüllt",
    "geknüllter": "geknüllt",
    "geknülltere": "geknüllt",
    "geknüllterem": "geknüllt",
    "geknüllteren": "geknüllt",
    "geknüllterer": "geknüllt",
    "geknüllteres": "geknüllt",
    "geknülltes": "geknüllt",
    "geknüllteste": "geknüllt",
    "geknülltestem": "geknüllt",
    "geknülltesten": "geknüllt",
    "geknülltester": "geknüllt",
    "geknülltestes": "geknüllt",
    "geknüpft": "knüpfen",
    "geknüpfte": "geknüpft",
    "geknüpftem": "geknüpft",
    "geknüpften": "geknüpft",
    "geknüpfter": "geknüpft",
    "geknüpftes": "geknüpft",
    "geknüppelt": "knüppeln",
    "geknüppelte": "geknüppelt",
    "geknüppeltem": "geknüppelt",
    "geknüppelten": "geknüppelt",
    "geknüppelter": "geknüppelt",
    "geknüppeltere": "geknüppelt",
    "geknüppelterem": "geknüppelt",
    "geknüppelteren": "geknüppelt",
    "geknüppelterer": "geknüppelt",
    "geknüppelteres": "geknüppelt",
    "geknüppeltes": "geknüppelt",
    "geknüppelteste": "geknüppelt",
    "geknüppeltestem": "geknüppelt",
    "geknüppeltesten": "geknüppelt",
    "geknüppeltester": "geknüppelt",
    "geknüppeltestes": "geknüppelt",
    "gekocht": "kochen",
    "gekochte": "gekocht",
    "gekochtem": "gekocht",
    "gekochten": "gekocht",
    "gekochter": "gekocht",
    "gekochtere": "gekocht",
    "gekochterem": "gekocht",
    "gekochteren": "gekocht",
    "gekochterer": "gekocht",
    "gekochteres": "gekocht",
    "gekochtes": "gekocht",
    "gekochteste": "gekocht",
    "gekochtestem": "gekocht",
    "gekochtesten": "gekocht",
    "gekochtester": "gekocht",
    "gekochtestes": "gekocht",
    "gekohlt": "kohlen",
    "gekohlte": "gekohlt",
    "gekohltem": "gekohlt",
    "gekohlten": "gekohlt",
    "gekohlter": "gekohlt",
    "gekohltes": "gekohlt",
    "gekokelt": "kokeln",
    "gekokelte": "gekokelt",
    "gekokeltem": "gekokelt",
    "gekokelten": "gekokelt",
    "gekokelter": "gekokelt",
    "gekokeltes": "gekokelt",
    "gekokst": "koksen",
    "gekokste": "gekokst",
    "gekokstem": "gekokst",
    "gekoksten": "gekokst",
    "gekokster": "gekokst",
    "gekokstes": "gekokst",
    "gekommen": "kommen",
    "gekommene": "gekommen",
    "gekommenem": "gekommen",
    "gekommenen": "gekommen",
    "gekommener": "gekommen",
    "gekommenes": "gekommen",
    "gekonnt": "können",
    "gekontert": "kontern",
    "gekonterte": "gekontert",
    "gekontertem": "gekontert",
    "gekonterten": "gekontert",
    "gekonterter": "gekontert",
    "gekontertere": "gekontert",
    "gekonterterem": "gekontert",
    "gekonterteren": "gekontert",
    "gekonterterer": "gekontert",
    "gekonterteres": "gekontert",
    "gekontertes": "gekontert",
    "gekonterteste": "gekontert",
    "gekontertestem": "gekontert",
    "gekontertesten": "gekontert",
    "gekontertester": "gekontert",
    "gekontertestes": "gekontert",
    "gekoppelt": "koppeln",
    "gekoppelte": "gekoppelt",
    "gekoppeltem": "gekoppelt",
    "gekoppelten": "gekoppelt",
    "gekoppelter": "gekoppelt",
    "gekoppeltes": "gekoppelt",
    "gekorkt": "korken",
    "gekorkte": "gekorkt",
    "gekorktem": "gekorkt",
    "gekorkten": "gekorkt",
    "gekorkter": "gekorkt",
    "gekorktes": "gekorkt",
    "gekostet": "kosten",
    "gekostete": "gekostet",
    "gekostetem": "gekostet",
    "gekosteten": "gekostet",
    "gekosteter": "gekostet",
    "gekostetes": "gekostet",
    "gekotzt": "kotzen",
    "gekotzte": "gekotzt",
    "gekotztem": "gekotzt",
    "gekotzten": "gekotzt",
    "gekotzter": "gekotzt",
    "gekotztes": "gekotzt",
    "gekrabbelt": "krabbeln",
    "gekrabbelte": "gekrabbelt",
    "gekrabbeltem": "gekrabbelt",
    "gekrabbelten": "gekrabbelt",
    "gekrabbelter": "gekrabbelt",
    "gekrabbeltes": "gekrabbelt",
    "gekracht": "krachen",
    "gekrachte": "gekracht",
    "gekrachtem": "gekracht",
    "gekrachten": "gekracht",
    "gekrachter": "gekracht",
    "gekrachtes": "gekracht",
    "gekrallt": "krallen",
    "gekrallte": "gekrallt",
    "gekralltem": "gekrallt",
    "gekrallten": "gekrallt",
    "gekrallter": "gekrallt",
    "gekralltere": "gekrallt",
    "gekrallterem": "gekrallt",
    "gekrallteren": "gekrallt",
    "gekrallterer": "gekrallt",
    "gekrallteres": "gekrallt",
    "gekralltes": "gekrallt",
    "gekrallteste": "gekrallt",
    "gekralltestem": "gekrallt",
    "gekralltesten": "gekrallt",
    "gekralltester": "gekrallt",
    "gekralltestes": "gekrallt",
    "gekrampft": "krampfen",
    "gekrampfte": "gekrampft",
    "gekrampftem": "gekrampft",
    "gekrampften": "gekrampft",
    "gekrampfter": "gekrampft",
    "gekrampftes": "gekrampft",
    "gekramt": "kramen",
    "gekramte": "gekramt",
    "gekramtem": "gekramt",
    "gekramten": "gekramt",
    "gekramter": "gekramt",
    "gekramtes": "gekramt",
    "gekrankt": "kranken",
    "gekrankte": "gekrankt",
    "gekranktem": "gekrankt",
    "gekrankten": "gekrankt",
    "gekrankter": "gekrankt",
    "gekranktes": "gekrankt",
    "gekratzt": "kratzen",
    "gekratzte": "gekratzt",
    "gekratztem": "gekratzt",
    "gekratzten": "gekratzt",
    "gekratzter": "gekratzt",
    "gekratztes": "gekratzt",
    "gekrault": "kraulen",
    "gekraulte": "gekrault",
    "gekraultem": "gekrault",
    "gekraulten": "gekrault",
    "gekraulter": "gekrault",
    "gekraultes": "gekrault",
    "gekraust": "krausen",
    "gekrauste": "gekraust",
    "gekraustem": "gekraust",
    "gekrausten": "gekraust",
    "gekrauster": "gekraust",
    "gekraustere": "gekraust",
    "gekrausterem": "gekraust",
    "gekrausteren": "gekraust",
    "gekrausterer": "gekraust",
    "gekrausteres": "gekraust",
    "gekraustes": "gekraust",
    "gekrausteste": "gekraust",
    "gekraustestem": "gekraust",
    "gekraustesten": "gekraust",
    "gekraustester": "gekraust",
    "gekraustestes": "gekraust",
    "gekreidet": "kreiden",
    "gekreidete": "gekreidet",
    "gekreidetem": "gekreidet",
    "gekreideten": "gekreidet",
    "gekreideter": "gekreidet",
    "gekreidetes": "gekreidet",
    "gekreischt": "kreischen",
    "gekreischte": "gekreischt",
    "gekreischtem": "gekreischt",
    "gekreischten": "gekreischt",
    "gekreischter": "gekreischt",
    "gekreischtes": "gekreischt",
    "gekreist": "kreisen",
    "gekreiste": "gekreist",
    "gekreistem": "gekreist",
    "gekreisten": "gekreist",
    "gekreister": "gekreist",
    "gekreistes": "gekreist",
    "gekrempelt": "krempeln",
    "gekrempelte": "gekrempelt",
    "gekrempeltem": "gekrempelt",
    "gekrempelten": "gekrempelt",
    "gekrempelter": "gekrempelt",
    "gekrempeltes": "gekrempelt",
    "gekreuzigt": "kreuzigen",
    "gekreuzigte": "gekreuzigt",
    "gekreuzigtem": "gekreuzigt",
    "gekreuzigten": "gekreuzigt",
    "gekreuzigter": "gekreuzigt",
    "gekreuzigtes": "gekreuzigt",
    "gekreuzt": "kreuzen",
    "gekreuzte": "gekreuzt",
    "gekreuztem": "gekreuzt",
    "gekreuzten": "gekreuzt",
    "gekreuzter": "gekreuzt",
    "gekreuztes": "gekreuzt",
    "gekribbelt": "kribbeln",
    "gekribbelte": "gekribbelt",
    "gekribbeltem": "gekribbelt",
    "gekribbelten": "gekribbelt",
    "gekribbelter": "gekribbelt",
    "gekribbeltes": "gekribbelt",
    "gekriegt": "kriegen",
    "gekriegte": "gekriegt",
    "gekriegtem": "gekriegt",
    "gekriegten": "gekriegt",
    "gekriegter": "gekriegt",
    "gekriegtes": "gekriegt",
    "gekringelt": "kringeln",
    "gekringelte": "gekringelt",
    "gekringeltem": "gekringelt",
    "gekringelten": "gekringelt",
    "gekringelter": "gekringelt",
    "gekringeltere": "gekringelt",
    "gekringelterem": "gekringelt",
    "gekringelteren": "gekringelt",
    "gekringelterer": "gekringelt",
    "gekringelteres": "gekringelt",
    "gekringeltes": "gekringelt",
    "gekringelteste": "gekringelt",
    "gekringeltestem": "gekringelt",
    "gekringeltesten": "gekringelt",
    "gekringeltester": "gekringelt",
    "gekringeltestes": "gekringelt",
    "gekriselt": "kriseln",
    "gekriselte": "gekriselt",
    "gekriseltem": "gekriselt",
    "gekriselten": "gekriselt",
    "gekriselter": "gekriselt",
    "gekriseltes": "gekriselt",
    "gekritzelt": "kritzeln",
    "gekritzelte": "gekritzelt",
    "gekritzeltem": "gekritzelt",
    "gekritzelten": "gekritzelt",
    "gekritzelter": "gekritzelt",
    "gekritzeltes": "gekritzelt",
    "gekrochen": "kriechen",
    "gekrochene": "gekrochen",
    "gekrochenem": "gekrochen",
    "gekrochenen": "gekrochen",
    "gekrochener": "gekrochen",
    "gekrochenes": "gekrochen",
    "gekrächzt": "krächzen",
    "gekrächzte": "gekrächzt",
    "gekrächztem": "gekrächzt",
    "gekrächzten": "gekrächzt",
    "gekrächzter": "gekrächzt",
    "gekrächztere": "gekrächzt",
    "gekrächzterem": "gekrächzt",
    "gekrächzteren": "gekrächzt",
    "gekrächzterer": "gekrächzt",
    "gekrächzteres": "gekrächzt",
    "gekrächztes": "gekrächzt",
    "gekrächzteste": "gekrächzt",
    "gekrächztestem": "gekrächzt",
    "gekrächztesten": "gekrächzt",
    "gekrächztester": "gekrächzt",
    "gekrächztestes": "gekrächzt",
    "gekräftigt": "kräftigen",
    "gekräftigte": "gekräftigt",
    "gekräftigtem": "gekräftigt",
    "gekräftigten": "gekräftigt",
    "gekräftigter": "gekräftigt",
    "gekräftigtes": "gekräftigt",
    "gekräht": "krähen",
    "gekrähte": "gekräht",
    "gekrähtem": "gekräht",
    "gekrähten": "gekräht",
    "gekrähter": "gekräht",
    "gekrähtes": "gekräht",
    "gekränzt": "kränzen",
    "gekränzte": "gekränzt",
    "gekränztem": "gekränzt",
    "gekränzten": "gekränzt",
    "gekränzter": "gekränzt",
    "gekränztes": "gekränzt",
    "gekräuselt": "kräuseln",
    "gekräuselte": "gekräuselt",
    "gekräuseltem": "gekräuselt",
    "gekräuselten": "gekräuselt",
    "gekräuselter": "gekräuselt",
    "gekräuseltere": "gekräuselt",
    "gekräuselterem": "gekräuselt",
    "gekräuselteren": "gekräuselt",
    "gekräuselterer": "gekräuselt",
    "gekräuselteres": "gekräuselt",
    "gekräuseltes": "gekräuselt",
    "gekräuselteste": "gekräuselt",
    "gekräuseltestem": "gekräuselt",
    "gekräuseltesten": "gekräuselt",
    "gekräuseltester": "gekräuselt",
    "gekräuseltestes": "gekräuselt",
    "gekrönt": "krönen",
    "gekrönte": "gekrönt",
    "gekröntem": "gekrönt",
    "gekrönten": "gekrönt",
    "gekrönter": "gekrönt",
    "gekröntes": "gekrönt",
    "gekrümelt": "krümeln",
    "gekrümelte": "gekrümelt",
    "gekrümeltem": "gekrümelt",
    "gekrümelten": "gekrümelt",
    "gekrümelter": "gekrümelt",
    "gekrümeltere": "gekrümelt",
    "gekrümelterem": "gekrümelt",
    "gekrümelteren": "gekrümelt",
    "gekrümelterer": "gekrümelt",
    "gekrümelteres": "gekrümelt",
    "gekrümeltes": "gekrümelt",
    "gekrümelteste": "gekrümelt",
    "gekrümeltestem": "gekrümelt",
    "gekrümeltesten": "gekrümelt",
    "gekrümeltester": "gekrümelt",
    "gekrümeltestes": "gekrümelt",
    "gekrümmt": "krümmen",
    "gekrümmte": "gekrümmt",
    "gekrümmtem": "gekrümmt",
    "gekrümmten": "gekrümmt",
    "gekrümmter": "gekrümmt",
    "gekrümmtere": "gekrümmt",
    "gekrümmterem": "gekrümmt",
    "gekrümmteren": "gekrümmt",
    "gekrümmterer": "gekrümmt",
    "gekrümmteres": "gekrümmt",
    "gekrümmtes": "gekrümmt",
    "gekrümmteste": "gekrümmt",
    "gekrümmtestem": "gekrümmt",
    "gekrümmtesten": "gekrümmt",
    "gekrümmtester": "gekrümmt",
    "gekrümmtestes": "gekrümmt",
    "gekugelt": "kugeln",
    "gekugelte": "gekugelt",
    "gekugeltem": "gekugelt",
    "gekugelten": "gekugelt",
    "gekugelter": "gekugelt",
    "gekugeltes": "gekugelt",
    "gekundschaftet": "kundschaften",
    "gekundschaftete": "gekundschaftet",
    "gekundschaftetem": "gekundschaftet",
    "gekundschafteten": "gekundschaftet",
    "gekundschafteter": "gekundschaftet",
    "gekundschaftetes": "gekundschaftet",
    "gekungelt": "kungeln",
    "gekungelte": "gekungelt",
    "gekungeltem": "gekungelt",
    "gekungelten": "gekungelt",
    "gekungelter": "gekungelt",
    "gekungeltere": "gekungelt",
    "gekungelterem": "gekungelt",
    "gekungelteren": "gekungelt",
    "gekungelterer": "gekungelt",
    "gekungelteres": "gekungelt",
    "gekungeltes": "gekungelt",
    "gekungelteste": "gekungelt",
    "gekungeltestem": "gekungelt",
    "gekungeltesten": "gekungelt",
    "gekungeltester": "gekungelt",
    "gekungeltestes": "gekungelt",
    "gekuppelt": "kuppeln",
    "gekuppelte": "gekuppelt",
    "gekuppeltem": "gekuppelt",
    "gekuppelten": "gekuppelt",
    "gekuppelter": "gekuppelt",
    "gekuppeltes": "gekuppelt",
    "gekurbelt": "kurbeln",
    "gekurbelte": "gekurbelt",
    "gekurbeltem": "gekurbelt",
    "gekurbelten": "gekurbelt",
    "gekurbelter": "gekurbelt",
    "gekurbeltes": "gekurbelt",
    "gekurvt": "kurven",
    "gekurvte": "gekurvt",
    "gekurvtem": "gekurvt",
    "gekurvten": "gekurvt",
    "gekurvter": "gekurvt",
    "gekurvtes": "gekurvt",
    "gekuschelt": "kuscheln",
    "gekuschelte": "gekuschelt",
    "gekuscheltem": "gekuschelt",
    "gekuschelten": "gekuschelt",
    "gekuschelter": "gekuschelt",
    "gekuscheltere": "gekuschelt",
    "gekuschelterem": "gekuschelt",
    "gekuschelteren": "gekuschelt",
    "gekuschelterer": "gekuschelt",
    "gekuschelteres": "gekuschelt",
    "gekuscheltes": "gekuschelt",
    "gekuschelteste": "gekuschelt",
    "gekuscheltestem": "gekuschelt",
    "gekuscheltesten": "gekuschelt",
    "gekuscheltester": "gekuschelt",
    "gekuscheltestes": "gekuschelt",
    "gekuscht": "kuschen",
    "gekuschte": "gekuscht",
    "gekuschtem": "gekuscht",
    "gekuschten": "gekuscht",
    "gekuschter": "gekuscht",
    "gekuschtes": "gekuscht",
    "gekämmt": "kämmen",
    "gekämmte": "gekämmt",
    "gekämmtem": "gekämmt",
    "gekämmten": "gekämmt",
    "gekämmter": "gekämmt",
    "gekämmtes": "gekämmt",
    "gekämpft": "kämpfen",
    "gekämpfte": "gekämpft",
    "gekämpftem": "gekämpft",
    "gekämpften": "gekämpft",
    "gekämpfter": "gekämpft",
    "gekämpftes": "gekämpft",
    "gekäut": "käuen",
    "gekäutem": "gekäut",
    "gekäuter": "gekäut",
    "gekäutes": "gekäut",
    "geködert": "ködern",
    "geköderte": "geködert",
    "geködertem": "geködert",
    "geköderten": "geködert",
    "geköderter": "geködert",
    "geködertes": "geködert",
    "geköpft": "köpfen",
    "geköpfte": "geköpft",
    "geköpftem": "geköpft",
    "geköpften": "geköpft",
    "geköpfter": "geköpft",
    "geköpftes": "geköpft",
    "gekübelt": "kübeln",
    "gekübelte": "gekübelt",
    "gekübeltem": "gekübelt",
    "gekübelten": "gekübelt",
    "gekübelter": "gekübelt",
    "gekübeltes": "gekübelt",
    "gekühlt": "kühlen",
    "gekühlte": "gekühlt",
    "gekühltem": "gekühlt",
    "gekühlten": "gekühlt",
    "gekühlter": "gekühlt",
    "gekühltere": "gekühlt",
    "gekühlterem": "gekühlt",
    "gekühlteren": "gekühlt",
    "gekühlterer": "gekühlt",
    "gekühlteres": "gekühlt",
    "gekühltes": "gekühlt",
    "gekühlteste": "gekühlt",
    "gekühltestem": "gekühlt",
    "gekühltesten": "gekühlt",
    "gekühltester": "gekühlt",
    "gekühltestes": "gekühlt",
    "gekümmert": "kümmern",
    "gekümmerte": "gekümmert",
    "gekümmertem": "gekümmert",
    "gekümmerten": "gekümmert",
    "gekümmerter": "gekümmert",
    "gekümmertes": "gekümmert",
    "gekündigt": "kündigen",
    "gekündigte": "gekündigt",
    "gekündigtem": "gekündigt",
    "gekündigten": "gekündigt",
    "gekündigter": "gekündigt",
    "gekündigtes": "gekündigt",
    "gekürt": "küren",
    "gekürte": "gekürt",
    "gekürtem": "gekürt",
    "gekürten": "gekürt",
    "gekürter": "gekürt",
    "gekürtes": "gekürt",
    "gekürzt": "kürzen",
    "gekürzte": "gekürzt",
    "gekürztem": "gekürzt",
    "gekürzten": "gekürzt",
    "gekürzter": "gekürzt",
    "gekürztere": "gekürzt",
    "gekürzterem": "gekürzt",
    "gekürzteren": "gekürzt",
    "gekürzterer": "gekürzt",
    "gekürzteres": "gekürzt",
    "gekürztes": "gekürzt",
    "gekürzteste": "gekürzt",
    "gekürztestem": "gekürzt",
    "gekürztesten": "gekürzt",
    "gekürztester": "gekürzt",
    "gekürztestes": "gekürzt",
    "geküßt": "küssen",
    "geküßte": "geküßt",
    "geküßtem": "geküßt",
    "geküßten": "geküßt",
    "geküßter": "geküßt",
    "geküßtes": "geküßt",
    "gelabbert": "labbern",
    "gelabberte": "gelabbert",
    "gelabbertem": "gelabbert",
    "gelabberten": "gelabbert",
    "gelabberter": "gelabbert",
    "gelabbertes": "gelabbert",
    "gelabert": "labern",
    "gelaberte": "gelabert",
    "gelabertem": "gelabert",
    "gelaberten": "gelabert",
    "gelaberter": "gelabert",
    "gelabertes": "gelabert",
    "gelabt": "laben",
    "gelabte": "gelabt",
    "gelabtem": "gelabt",
    "gelabten": "gelabt",
    "gelabter": "gelabt",
    "gelabtere": "gelabt",
    "gelabterem": "gelabt",
    "gelabteren": "gelabt",
    "gelabterer": "gelabt",
    "gelabteres": "gelabt",
    "gelabtes": "gelabt",
    "gelabteste": "gelabt",
    "gelabtestem": "gelabt",
    "gelabtesten": "gelabt",
    "gelabtester": "gelabt",
    "gelabtestes": "gelabt",
    "gelacht": "lachen",
    "gelachte": "gelacht",
    "gelachtem": "gelacht",
    "gelachten": "gelacht",
    "gelachter": "gelacht",
    "gelachtes": "gelacht",
    "gelackmeierte": "gelackmeiert",
    "gelackmeiertem": "gelackmeiert",
    "gelackmeierten": "gelackmeiert",
    "gelackmeierter": "gelackmeiert",
    "gelackmeiertes": "gelackmeiert",
    "geladen": "laden",
    "geladene": "geladen",
    "geladenem": "geladen",
    "geladenen": "geladen",
    "geladener": "geladen",
    "geladenes": "geladen",
    "gelagert": "lagern",
    "gelagerte": "gelagert",
    "gelagertem": "gelagert",
    "gelagerten": "gelagert",
    "gelagerter": "gelagert",
    "gelagertes": "gelagert",
    "gelahmt": "lahmen",
    "gelahmte": "gelahmt",
    "gelahmtem": "gelahmt",
    "gelahmten": "gelahmt",
    "gelahmter": "gelahmt",
    "gelahmtes": "gelahmt",
    "gelallt": "lallen",
    "gelallte": "gelallt",
    "gelalltem": "gelallt",
    "gelallten": "gelallt",
    "gelallter": "gelallt",
    "gelalltere": "gelallt",
    "gelallterem": "gelallt",
    "gelallteren": "gelallt",
    "gelallterer": "gelallt",
    "gelallteres": "gelallt",
    "gelalltes": "gelallt",
    "gelallteste": "gelallt",
    "gelalltestem": "gelallt",
    "gelalltesten": "gelallt",
    "gelalltester": "gelallt",
    "gelalltestes": "gelallt",
    "gelandet": "landen",
    "gelandete": "gelandet",
    "gelandetem": "gelandet",
    "gelandeten": "gelandet",
    "gelandeter": "gelandet",
    "gelandetes": "gelandet",
    "gelang": "gelingen",
    "gelangen": "gelingen",
    "gelangst": "gelingen",
    "gelangt": "langen",
    "gelangte": "gelangt",
    "gelangtem": "gelangt",
    "gelangten": "gelangt",
    "gelangter": "gelangt",
    "gelangtes": "gelangt",
    "gelangweilt": "langweilen",
    "gelangweilte": "gelangweilt",
    "gelangweiltem": "gelangweilt",
    "gelangweilten": "gelangweilt",
    "gelangweilter": "gelangweilt",
    "gelangweiltere": "gelangweilt",
    "gelangweilterem": "gelangweilt",
    "gelangweilteren": "gelangweilt",
    "gelangweilterer": "gelangweilt",
    "gelangweilteres": "gelangweilt",
    "gelangweiltes": "gelangweilt",
    "gelangweilteste": "gelangweilt",
    "gelangweiltestem": "gelangweilt",
    "gelangweiltesten": "gelangweilt",
    "gelangweiltester": "gelangweilt",
    "gelangweiltestes": "gelangweilt",
    "gelappt": "lappen",
    "gelappte": "gelappt",
    "gelapptem": "gelappt",
    "gelappten": "gelappt",
    "gelappter": "gelappt",
    "gelapptes": "gelappt",
    "gelassen": "lassen",
    "gelassene": "gelassen",
    "gelassenem": "gelassen",
    "gelassenen": "gelassen",
    "gelassener": "gelassen",
    "gelassenes": "gelassen",
    "gelastet": "lasten",
    "gelastete": "gelastet",
    "gelastetem": "gelastet",
    "gelasteten": "gelastet",
    "gelasteter": "gelastet",
    "gelastetes": "gelastet",
    "gelatscht": "latschen",
    "gelatschte": "gelatscht",
    "gelatschtem": "gelatscht",
    "gelatschten": "gelatscht",
    "gelatschter": "gelatscht",
    "gelatschtes": "gelatscht",
    "gelauert": "lauern",
    "gelauerte": "gelauert",
    "gelauertem": "gelauert",
    "gelauerten": "gelauert",
    "gelauerter": "gelauert",
    "gelauertes": "gelauert",
    "gelaufen": "laufen",
    "gelaufene": "gelaufen",
    "gelaufenem": "gelaufen",
    "gelaufenen": "gelaufen",
    "gelaufener": "gelaufen",
    "gelaufenes": "gelaufen",
    "gelaugt": "laugen",
    "gelaugte": "gelaugt",
    "gelaugtem": "gelaugt",
    "gelaugten": "gelaugt",
    "gelaugter": "gelaugt",
    "gelaugtes": "gelaugt",
    "gelaunte": "gelaunt",
    "gelauntem": "gelaunt",
    "gelaunten": "gelaunt",
    "gelaunter": "gelaunt",
    "gelauntere": "gelaunt",
    "gelaunterem": "gelaunt",
    "gelaunteren": "gelaunt",
    "gelaunterer": "gelaunt",
    "gelaunteres": "gelaunt",
    "gelauntes": "gelaunt",
    "gelaunteste": "gelaunt",
    "gelauntestem": "gelaunt",
    "gelauntesten": "gelaunt",
    "gelauntester": "gelaunt",
    "gelauntestes": "gelaunt",
    "gelauscht": "lauschen",
    "gelauschte": "gelauscht",
    "gelauschtem": "gelauscht",
    "gelauschten": "gelauscht",
    "gelauschter": "gelauscht",
    "gelauschtes": "gelauscht",
    "gelaust": "lausen",
    "gelauste": "gelaust",
    "gelaustem": "gelaust",
    "gelausten": "gelaust",
    "gelauster": "gelaust",
    "gelaustere": "gelaust",
    "gelausterem": "gelaust",
    "gelausteren": "gelaust",
    "gelausterer": "gelaust",
    "gelausteres": "gelaust",
    "gelaustes": "gelaust",
    "gelausteste": "gelaust",
    "gelaustestem": "gelaust",
    "gelaustesten": "gelaust",
    "gelaustester": "gelaust",
    "gelaustestes": "gelaust",
    "gelautet": "lauten",
    "gelautete": "gelautet",
    "gelautetem": "gelautet",
    "gelauteten": "gelautet",
    "gelauteter": "gelautet",
    "gelautetes": "gelautet",
    "gelbem": "gelb",
    "gelben": "gelb",
    "gelber": "gelb",
    "gelbes": "gelb",
    "gelebt": "leben",
    "gelebte": "gelebt",
    "gelebtem": "gelebt",
    "gelebten": "gelebt",
    "gelebter": "gelebt",
    "gelebtes": "gelebt",
    "geledert": "ledern",
    "gelederte": "geledert",
    "geledertem": "geledert",
    "gelederten": "geledert",
    "gelederter": "geledert",
    "geledertes": "geledert",
    "geleert": "leeren",
    "geleerte": "geleert",
    "geleertem": "geleert",
    "geleerten": "geleert",
    "geleerter": "geleert",
    "geleertere": "geleert",
    "geleerterem": "geleert",
    "geleerteren": "geleert",
    "geleerterer": "geleert",
    "geleerteres": "geleert",
    "geleertes": "geleert",
    "geleerteste": "geleert",
    "geleertestem": "geleert",
    "geleertesten": "geleert",
    "geleertester": "geleert",
    "geleertestes": "geleert",
    "gelegene": "gelegen",
    "gelegenem": "gelegen",
    "gelegenen": "gelegen",
    "gelegener": "gelegen",
    "gelegenere": "gelegen",
    "gelegenerem": "gelegen",
    "gelegeneren": "gelegen",
    "gelegenerer": "gelegen",
    "gelegeneres": "gelegen",
    "gelegenes": "gelegen",
    "gelegenstem": "gelegen",
    "gelegensten": "gelegen",
    "gelegenster": "gelegen",
    "gelegenstes": "gelegen",
    "gelegentliche": "gelegentlich",
    "gelegentlichem": "gelegentlich",
    "gelegentlichen": "gelegentlich",
    "gelegentlicher": "gelegentlich",
    "gelegentliches": "gelegentlich",
    "gelegt": "legen",
    "gelegte": "gelegt",
    "gelegtem": "gelegt",
    "gelegten": "gelegt",
    "gelegter": "gelegt",
    "gelegtes": "gelegt",
    "gelehnt": "lehnen",
    "gelehnte": "gelehnt",
    "gelehntem": "gelehnt",
    "gelehnten": "gelehnt",
    "gelehnter": "gelehnt",
    "gelehntes": "gelehnt",
    "gelehrige": "gelehrig",
    "gelehrigem": "gelehrig",
    "gelehrigen": "gelehrig",
    "gelehriger": "gelehrig",
    "gelehrigere": "gelehrig",
    "gelehrigerem": "gelehrig",
    "gelehrigeren": "gelehrig",
    "gelehrigerer": "gelehrig",
    "gelehrigeres": "gelehrig",
    "gelehriges": "gelehrig",
    "gelehrigste": "gelehrig",
    "gelehrigstem": "gelehrig",
    "gelehrigsten": "gelehrig",
    "gelehrigster": "gelehrig",
    "gelehrigstes": "gelehrig",
    "gelehrt": "lehren",
    "gelehrte": "gelehrt",
    "gelehrtem": "gelehrt",
    "gelehrten": "gelehrt",
    "gelehrter": "gelehrt",
    "gelehrtere": "gelehrt",
    "gelehrterem": "gelehrt",
    "gelehrteren": "gelehrt",
    "gelehrterer": "gelehrt",
    "gelehrteres": "gelehrt",
    "gelehrtes": "gelehrt",
    "gelehrteste": "gelehrt",
    "gelehrtestem": "gelehrt",
    "gelehrtesten": "gelehrt",
    "gelehrtester": "gelehrt",
    "gelehrtestes": "gelehrt",
    "geleibt": "leiben",
    "geleibte": "geleibt",
    "geleibtem": "geleibt",
    "geleibten": "geleibt",
    "geleibter": "geleibt",
    "geleibtes": "geleibt",
    "geleiert": "leiern",
    "geleierte": "geleiert",
    "geleiertem": "geleiert",
    "geleierten": "geleiert",
    "geleierter": "geleiert",
    "geleiertes": "geleiert",
    "geleimt": "leimen",
    "geleimte": "geleimt",
    "geleimtem": "geleimt",
    "geleimten": "geleimt",
    "geleimter": "geleimt",
    "geleimtes": "geleimt",
    "geleint": "leinen",
    "geleinte": "geleint",
    "geleintem": "geleint",
    "geleinten": "geleint",
    "geleinter": "geleint",
    "geleintes": "geleint",
    "geleistet": "leisten",
    "geleistete": "geleistet",
    "geleistetem": "geleistet",
    "geleisteten": "geleistet",
    "geleisteter": "geleistet",
    "geleistetes": "geleistet",
    "geleite": "geleiten",
    "geleitend": "geleiten",
    "geleitende": "geleitend",
    "geleitendem": "geleitend",
    "geleitenden": "geleitend",
    "geleitender": "geleitend",
    "geleitendes": "geleitend",
    "geleitest": "geleiten",
    "geleitet": "leiten",
    "geleitete": "geleiten",
    "geleitetem": "geleitet",
    "geleiteten": "geleiten",
    "geleiteter": "geleitet",
    "geleitetes": "geleitet",
    "geleitetest": "geleiten",
    "geleitetet": "geleiten",
    "gelenkigem": "gelenkig",
    "gelenkigen": "gelenkig",
    "gelenkiger": "gelenkig",
    "gelenkigere": "gelenkig",
    "gelenkigerem": "gelenkig",
    "gelenkigeren": "gelenkig",
    "gelenkigerer": "gelenkig",
    "gelenkigeres": "gelenkig",
    "gelenkiges": "gelenkig",
    "gelenkigste": "gelenkig",
    "gelenkigstem": "gelenkig",
    "gelenkigsten": "gelenkig",
    "gelenkigster": "gelenkig",
    "gelenkigstes": "gelenkig",
    "gelenkt": "lenken",
    "gelenkte": "gelenkt",
    "gelenktem": "gelenkt",
    "gelenkten": "gelenkt",
    "gelenkter": "gelenkt",
    "gelenktes": "gelenkt",
    "gelernt": "lernen",
    "gelernte": "gelernt",
    "gelerntem": "gelernt",
    "gelernten": "gelernt",
    "gelernter": "gelernt",
    "gelerntes": "gelernt",
    "gelesen": "lesen",
    "gelesene": "gelesen",
    "gelesenem": "gelesen",
    "gelesenen": "gelesen",
    "gelesener": "gelesen",
    "gelesenes": "gelesen",
    "geleuchtet": "leuchten",
    "geleuchtete": "geleuchtet",
    "geleuchtetem": "geleuchtet",
    "geleuchteten": "geleuchtet",
    "geleuchteter": "geleuchtet",
    "geleuchtetes": "geleuchtet",
    "geleugnet": "leugnen",
    "geleugnete": "geleugnet",
    "geleugnetem": "geleugnet",
    "geleugneten": "geleugnet",
    "geleugneter": "geleugnet",
    "geleugnetes": "geleugnet",
    "gelichtet": "lichten",
    "gelichtete": "gelichtet",
    "gelichtetem": "gelichtet",
    "gelichteten": "gelichtet",
    "gelichteter": "gelichtet",
    "gelichtetes": "gelichtet",
    "geliebt": "lieben",
    "geliebte": "geliebt",
    "geliebtem": "geliebt",
    "geliebten": "geliebt",
    "geliebter": "geliebt",
    "geliebtere": "geliebt",
    "geliebterem": "geliebt",
    "geliebteren": "geliebt",
    "geliebterer": "geliebt",
    "geliebteres": "geliebt",
    "geliebtes": "geliebt",
    "geliebteste": "geliebt",
    "geliebtestem": "geliebt",
    "geliebtesten": "geliebt",
    "geliebtester": "geliebt",
    "geliebtestes": "geliebt",
    "geliebäugelt": "liebäugeln",
    "geliebäugelte": "geliebäugelt",
    "geliebäugeltem": "geliebäugelt",
    "geliebäugelten": "geliebäugelt",
    "geliebäugelter": "geliebäugelt",
    "geliebäugeltes": "geliebäugelt",
    "geliefert": "liefern",
    "gelieferte": "geliefert",
    "geliefertem": "geliefert",
    "gelieferten": "geliefert",
    "gelieferter": "geliefert",
    "geliefertes": "geliefert",
    "geliehen": "leihen",
    "geliehene": "geliehen",
    "geliehenem": "geliehen",
    "geliehenen": "geliehen",
    "geliehener": "geliehen",
    "geliehenes": "geliehen",
    "geliftet": "liften",
    "geliftete": "geliftet",
    "geliftetem": "geliftet",
    "gelifteten": "geliftet",
    "gelifteter": "geliftet",
    "geliftetere": "geliftet",
    "gelifteterem": "geliftet",
    "gelifteteren": "geliftet",
    "gelifteterer": "geliftet",
    "gelifteteres": "geliftet",
    "geliftetes": "geliftet",
    "gelifteteste": "geliftet",
    "geliftetestem": "geliftet",
    "geliftetesten": "geliftet",
    "geliftetester": "geliftet",
    "geliftetestes": "geliftet",
    "gelindert": "lindern",
    "gelinderte": "gelindert",
    "gelindertem": "gelindert",
    "gelinderten": "gelindert",
    "gelinderter": "gelindert",
    "gelindertere": "gelindert",
    "gelinderterem": "gelindert",
    "gelinderteren": "gelindert",
    "gelinderterer": "gelindert",
    "gelinderteres": "gelindert",
    "gelindertes": "gelindert",
    "gelinderteste": "gelindert",
    "gelindertestem": "gelindert",
    "gelindertesten": "gelindert",
    "gelindertester": "gelindert",
    "gelindertestes": "gelindert",
    "gelinge": "gelingen",
    "gelingend": "gelingen",
    "gelingende": "gelingend",
    "gelingendem": "gelingend",
    "gelingenden": "gelingend",
    "gelingender": "gelingend",
    "gelingendes": "gelingend",
    "gelingest": "gelingen",
    "gelinget": "gelingen",
    "gelingst": "gelingen",
    "gelingt": "gelingen",
    "gelispelt": "lispeln",
    "gelispelte": "gelispelt",
    "gelispeltem": "gelispelt",
    "gelispelten": "gelispelt",
    "gelispelter": "gelispelt",
    "gelispeltes": "gelispelt",
    "gelistet": "listen",
    "gelistete": "gelistet",
    "gelistetem": "gelistet",
    "gelisteten": "gelistet",
    "gelisteter": "gelistet",
    "gelistetes": "gelistet",
    "gelitten": "leiden",
    "gelittene": "gelitten",
    "gelittenem": "gelitten",
    "gelittenen": "gelitten",
    "gelittener": "gelitten",
    "gelittenes": "gelitten",
    "gelobe": "geloben",
    "gelobend": "geloben",
    "gelobende": "gelobend",
    "gelobendem": "gelobend",
    "gelobenden": "gelobend",
    "gelobender": "gelobend",
    "gelobendes": "gelobend",
    "gelobest": "geloben",
    "gelobet": "geloben",
    "gelobst": "geloben",
    "gelobt": "loben",
    "gelobte": "geloben",
    "gelobtem": "gelobt",
    "gelobten": "geloben",
    "gelobter": "gelobt",
    "gelobtere": "gelobt",
    "gelobterem": "gelobt",
    "gelobteren": "gelobt",
    "gelobterer": "gelobt",
    "gelobteres": "gelobt",
    "gelobtes": "gelobt",
    "gelobtest": "geloben",
    "gelobteste": "gelobt",
    "gelobtestem": "gelobt",
    "gelobtesten": "gelobt",
    "gelobtester": "gelobt",
    "gelobtestes": "gelobt",
    "gelobtet": "geloben",
    "gelocht": "lochen",
    "gelochte": "gelocht",
    "gelochtem": "gelocht",
    "gelochten": "gelocht",
    "gelochter": "gelocht",
    "gelochtes": "gelocht",
    "gelockert": "lockern",
    "gelockerte": "gelockert",
    "gelockertem": "gelockert",
    "gelockerten": "gelockert",
    "gelockerter": "gelockert",
    "gelockertes": "gelockert",
    "gelockt": "locken",
    "gelockte": "gelockt",
    "gelocktem": "gelockt",
    "gelockten": "gelockt",
    "gelockter": "gelockt",
    "gelocktes": "gelockt",
    "gelodert": "lodern",
    "geloderte": "gelodert",
    "gelodertem": "gelodert",
    "geloderten": "gelodert",
    "geloderter": "gelodert",
    "gelodertes": "gelodert",
    "gelogen": "lügen",
    "gelogene": "gelogen",
    "gelogenem": "gelogen",
    "gelogenen": "gelogen",
    "gelogener": "gelogen",
    "gelogenere": "gelogen",
    "gelogenerem": "gelogen",
    "gelogeneren": "gelogen",
    "gelogenerer": "gelogen",
    "gelogeneres": "gelogen",
    "gelogenes": "gelogen",
    "gelogenste": "gelogen",
    "gelogenstem": "gelogen",
    "gelogensten": "gelogen",
    "gelogenster": "gelogen",
    "gelogenstes": "gelogen",
    "geloggt": "loggen",
    "geloggte": "geloggt",
    "geloggtem": "geloggt",
    "geloggten": "geloggt",
    "geloggter": "geloggt",
    "geloggtes": "geloggt",
    "gelohnt": "lohnen",
    "gelohnte": "gelohnt",
    "gelohntem": "gelohnt",
    "gelohnten": "gelohnt",
    "gelohnter": "gelohnt",
    "gelohntes": "gelohnt",
    "geloschen": "löschen",
    "geloschene": "geloschen",
    "geloschenem": "geloschen",
    "geloschenen": "geloschen",
    "geloschener": "geloschen",
    "geloschenes": "geloschen",
    "gelost": "losen",
    "geloste": "gelost",
    "gelostem": "gelost",
    "gelosten": "gelost",
    "geloster": "gelost",
    "gelostes": "gelost",
    "gelotet": "loten",
    "gelotete": "gelotet",
    "gelotetem": "gelotet",
    "geloteten": "gelotet",
    "geloteter": "gelotet",
    "gelotetes": "gelotet",
    "gelotst": "lotsen",
    "gelotste": "gelotst",
    "gelotstem": "gelotst",
    "gelotsten": "gelotst",
    "gelotster": "gelotst",
    "gelotstes": "gelotst",
    "gelottert": "lottern",
    "gelotterte": "gelottert",
    "gelottertem": "gelottert",
    "gelotterten": "gelottert",
    "gelotterter": "gelottert",
    "gelottertere": "gelottert",
    "gelotterterem": "gelottert",
    "gelotterteren": "gelottert",
    "gelotterterer": "gelottert",
    "gelotterteres": "gelottert",
    "gelottertes": "gelottert",
    "gelotterteste": "gelottert",
    "gelottertestem": "gelottert",
    "gelottertesten": "gelottert",
    "gelottertester": "gelottert",
    "gelottertestes": "gelottert",
    "gelte": "gelten",
    "geltend": "gelten",
    "geltende": "geltend",
    "geltendem": "geltend",
    "geltenden": "geltend",
    "geltender": "geltend",
    "geltendere": "geltend",
    "geltenderem": "geltend",
    "geltenderen": "geltend",
    "geltenderer": "geltend",
    "geltenderes": "geltend",
    "geltendes": "geltend",
    "geltendste": "geltend",
    "geltendstem": "geltend",
    "geltendsten": "geltend",
    "geltendster": "geltend",
    "geltendstes": "geltend",
    "geltest": "gelten",
    "geltet": "gelten",
    "gelugt": "lugen",
    "gelugte": "gelugt",
    "gelugtem": "gelugt",
    "gelugten": "gelugt",
    "gelugter": "gelugt",
    "gelugtes": "gelugt",
    "gelullt": "lullen",
    "gelullte": "gelullt",
    "gelulltem": "gelullt",
    "gelullten": "gelullt",
    "gelullter": "gelullt",
    "gelulltes": "gelullt",
    "gelungen": "gelingen",
    "gelungene": "gelungen",
    "gelungenem": "gelungen",
    "gelungenen": "gelungen",
    "gelungener": "gelungen",
    "gelungenere": "gelungen",
    "gelungenerem": "gelungen",
    "gelungeneren": "gelungen",
    "gelungenerer": "gelungen",
    "gelungeneres": "gelungen",
    "gelungenes": "gelungen",
    "gelungenste": "gelungen",
    "gelungenstem": "gelungen",
    "gelungensten": "gelungen",
    "gelungenster": "gelungen",
    "gelungenstes": "gelungen",
    "gelungert": "lungern",
    "gelungerte": "gelungert",
    "gelungertem": "gelungert",
    "gelungerten": "gelungert",
    "gelungerter": "gelungert",
    "gelungertes": "gelungert",
    "gelupft": "lupfen",
    "gelupfte": "gelupft",
    "gelupftem": "gelupft",
    "gelupften": "gelupft",
    "gelupfter": "gelupft",
    "gelupftes": "gelupft",
    "gelutscht": "lutschen",
    "gelutschte": "gelutscht",
    "gelutschtem": "gelutscht",
    "gelutschten": "gelutscht",
    "gelutschter": "gelutscht",
    "gelutschtes": "gelutscht",
    "gelächelt": "lächeln",
    "gelächelte": "gelächelt",
    "gelächeltem": "gelächelt",
    "gelächelten": "gelächelt",
    "gelächelter": "gelächelt",
    "gelächeltes": "gelächelt",
    "gelähmt": "lähmen",
    "gelähmtem": "gelähmt",
    "gelähmter": "gelähmt",
    "gelähmtes": "gelähmt",
    "geländegängige": "geländegängig",
    "geländegängigem": "geländegängig",
    "geländegängigen": "geländegängig",
    "geländegängiger": "geländegängig",
    "geländegängigere": "geländegängig",
    "geländegängigerem": "geländegängig",
    "geländegängigeren": "geländegängig",
    "geländegängigerer": "geländegängig",
    "geländegängigeres": "geländegängig",
    "geländegängiges": "geländegängig",
    "geländegängigste": "geländegängig",
    "geländegängigstem": "geländegängig",
    "geländegängigsten": "geländegängig",
    "geländegängigster": "geländegängig",
    "geländegängigstes": "geländegängig",
    "gelänge": "gelingen",
    "gelängen": "gelingen",
    "gelängest": "gelingen",
    "gelänget": "gelingen",
    "geläppert": "läppern",
    "geläpperte": "geläppert",
    "geläppertem": "geläppert",
    "geläpperten": "geläppert",
    "geläpperter": "geläppert",
    "geläppertes": "geläppert",
    "gelärmt": "lärmen",
    "gelärmte": "gelärmt",
    "gelärmtem": "gelärmt",
    "gelärmten": "gelärmt",
    "gelärmter": "gelärmt",
    "gelärmtes": "gelärmt",
    "gelästert": "lästern",
    "gelästerte": "gelästert",
    "gelästertem": "gelästert",
    "gelästerten": "gelästert",
    "gelästerter": "gelästert",
    "gelästertere": "gelästert",
    "gelästerterem": "gelästert",
    "gelästerteren": "gelästert",
    "gelästerterer": "gelästert",
    "gelästerteres": "gelästert",
    "gelästertes": "gelästert",
    "gelästerteste": "gelästert",
    "gelästertestem": "gelästert",
    "gelästertesten": "gelästert",
    "gelästertester": "gelästert",
    "gelästertestes": "gelästert",
    "geläufigem": "geläufig",
    "geläufigen": "geläufig",
    "geläufiger": "geläufig",
    "geläufigere": "geläufig",
    "geläufigerem": "geläufig",
    "geläufigeren": "geläufig",
    "geläufigerer": "geläufig",
    "geläufigeres": "geläufig",
    "geläufiges": "geläufig",
    "geläufigste": "geläufig",
    "geläufigstem": "geläufig",
    "geläufigsten": "geläufig",
    "geläufigster": "geläufig",
    "geläufigstes": "geläufig",
    "geläutet": "läuten",
    "geläutetem": "geläutet",
    "geläuteter": "geläutet",
    "geläutetes": "geläutet",
    "gelöchert": "löchern",
    "gelöcherte": "gelöchert",
    "gelöchertem": "gelöchert",
    "gelöcherten": "gelöchert",
    "gelöcherter": "gelöchert",
    "gelöchertes": "gelöchert",
    "gelöffelt": "löffeln",
    "gelöffelte": "gelöffelt",
    "gelöffeltem": "gelöffelt",
    "gelöffelten": "gelöffelt",
    "gelöffelter": "gelöffelt",
    "gelöffeltes": "gelöffelt",
    "gelöhnt": "löhnen",
    "gelöhntem": "gelöhnt",
    "gelöhnter": "gelöhnt",
    "gelöhntes": "gelöhnt",
    "gelöscht": "löschen",
    "gelöschte": "gelöscht",
    "gelöschtem": "gelöscht",
    "gelöschten": "gelöscht",
    "gelöschter": "gelöscht",
    "gelöschtes": "gelöscht",
    "gelöst": "lösen",
    "gelöstem": "gelöst",
    "gelöster": "gelöst",
    "gelöstere": "gelöst",
    "gelösterem": "gelöst",
    "gelösteren": "gelöst",
    "gelösterer": "gelöst",
    "gelösteres": "gelöst",
    "gelöstes": "gelöst",
    "gelösteste": "gelöst",
    "gelöstestem": "gelöst",
    "gelöstesten": "gelöst",
    "gelöstester": "gelöst",
    "gelöstestes": "gelöst",
    "gelötet": "löten",
    "gelötetem": "gelötet",
    "gelöteter": "gelötet",
    "gelötetes": "gelötet",
    "gelüftet": "lüften",
    "gelüftete": "gelüftet",
    "gelüftetem": "gelüftet",
    "gelüfteten": "gelüftet",
    "gelüfteter": "gelüftet",
    "gelüftetere": "gelüftet",
    "gelüfteterem": "gelüftet",
    "gelüfteteren": "gelüftet",
    "gelüfteterer": "gelüftet",
    "gelüfteteres": "gelüftet",
    "gelüftetes": "gelüftet",
    "gelüfteteste": "gelüftet",
    "gelüftetestem": "gelüftet",
    "gelüftetesten": "gelüftet",
    "gelüftetester": "gelüftet",
    "gelüftetestes": "gelüftet",
    "gelümmelt": "lümmeln",
    "gelümmelte": "gelümmelt",
    "gelümmeltem": "gelümmelt",
    "gelümmelten": "gelümmelt",
    "gelümmelter": "gelümmelt",
    "gelümmeltes": "gelümmelt",
    "gelüste": "gelüsten",
    "gelüstend": "gelüsten",
    "gelüstende": "gelüstend",
    "gelüstendem": "gelüstend",
    "gelüstenden": "gelüstend",
    "gelüstender": "gelüstend",
    "gelüstendere": "gelüstend",
    "gelüstenderem": "gelüstend",
    "gelüstenderen": "gelüstend",
    "gelüstenderer": "gelüstend",
    "gelüstenderes": "gelüstend",
    "gelüstendes": "gelüstend",
    "gelüstendste": "gelüstend",
    "gelüstendstem": "gelüstend",
    "gelüstendsten": "gelüstend",
    "gelüstendster": "gelüstend",
    "gelüstendstes": "gelüstend",
    "gelüstest": "gelüsten",
    "gelüstet": "gelüsten",
    "gelüstete": "gelüsten",
    "gelüstetem": "gelüstet",
    "gelüsteten": "gelüsten",
    "gelüsteter": "gelüstet",
    "gelüstetere": "gelüstet",
    "gelüsteterem": "gelüstet",
    "gelüsteteren": "gelüstet",
    "gelüsteterer": "gelüstet",
    "gelüsteteres": "gelüstet",
    "gelüstetes": "gelüstet",
    "gelüstetest": "gelüsten",
    "gelüsteteste": "gelüstet",
    "gelüstetestem": "gelüstet",
    "gelüstetesten": "gelüstet",
    "gelüstetester": "gelüstet",
    "gelüstetestes": "gelüstet",
    "gelüstetet": "gelüsten",
    "gemacht": "machen",
    "gemachte": "gemacht",
    "gemachtem": "gemacht",
    "gemachten": "gemacht",
    "gemachter": "gemacht",
    "gemachtes": "gemacht",
    "gemagert": "magern",
    "gemagerte": "gemagert",
    "gemagertem": "gemagert",
    "gemagerten": "gemagert",
    "gemagerter": "gemagert",
    "gemagertes": "gemagert",
    "gemahlene": "gemahlen",
    "gemahlenem": "gemahlen",
    "gemahlenen": "gemahlen",
    "gemahlener": "gemahlen",
    "gemahlenere": "gemahlen",
    "gemahlenerem": "gemahlen",
    "gemahleneren": "gemahlen",
    "gemahlenerer": "gemahlen",
    "gemahleneres": "gemahlen",
    "gemahlenes": "gemahlen",
    "gemahlenste": "gemahlen",
    "gemahlenstem": "gemahlen",
    "gemahlensten": "gemahlen",
    "gemahlenster": "gemahlen",
    "gemahlenstes": "gemahlen",
    "gemahnt": "mahnen",
    "gemahnte": "gemahnt",
    "gemahntem": "gemahnt",
    "gemahnten": "gemahnt",
    "gemahnter": "gemahnt",
    "gemahntes": "gemahnt",
    "gemalt": "malen",
    "gemalte": "gemalt",
    "gemaltem": "gemalt",
    "gemalten": "gemalt",
    "gemalter": "gemalt",
    "gemaltes": "gemalt",
    "gemampft": "mampfen",
    "gemampfte": "gemampft",
    "gemampftem": "gemampft",
    "gemampften": "gemampft",
    "gemampfter": "gemampft",
    "gemampftes": "gemampft",
    "gemanagt": "managen",
    "gemanagte": "gemanagt",
    "gemanagtem": "gemanagt",
    "gemanagten": "gemanagt",
    "gemanagter": "gemanagt",
    "gemanagtes": "gemanagt",
    "gemangelt": "mangeln",
    "gemangelte": "gemangelt",
    "gemangeltem": "gemangelt",
    "gemangelten": "gemangelt",
    "gemangelter": "gemangelt",
    "gemangeltes": "gemangelt",
    "gemartert": "martern",
    "gemarterte": "gemartert",
    "gemartertem": "gemartert",
    "gemarterten": "gemartert",
    "gemarterter": "gemartert",
    "gemartertere": "gemartert",
    "gemarterterem": "gemartert",
    "gemarterteren": "gemartert",
    "gemarterterer": "gemartert",
    "gemarterteres": "gemartert",
    "gemartertes": "gemartert",
    "gemarterteste": "gemartert",
    "gemartertestem": "gemartert",
    "gemartertesten": "gemartert",
    "gemartertester": "gemartert",
    "gemartertestes": "gemartert",
    "gemasert": "masern",
    "gemaserte": "gemasert",
    "gemasertem": "gemasert",
    "gemaserten": "gemasert",
    "gemaserter": "gemasert",
    "gemasertes": "gemasert",
    "gemauert": "mauern",
    "gemauerte": "gemauert",
    "gemauertem": "gemauert",
    "gemauerten": "gemauert",
    "gemauerter": "gemauert",
    "gemauertes": "gemauert",
    "gemault": "maulen",
    "gemaulte": "gemault",
    "gemaultem": "gemault",
    "gemaulten": "gemault",
    "gemaulter": "gemault",
    "gemaultes": "gemault",
    "gemauschelt": "mauscheln",
    "gemauschelte": "gemauschelt",
    "gemauscheltem": "gemauschelt",
    "gemauschelten": "gemauschelt",
    "gemauschelter": "gemauschelt",
    "gemauscheltere": "gemauschelt",
    "gemauschelterem": "gemauschelt",
    "gemauschelteren": "gemauschelt",
    "gemauschelterer": "gemauschelt",
    "gemauschelteres": "gemauschelt",
    "gemauscheltes": "gemauschelt",
    "gemauschelteste": "gemauschelt",
    "gemauscheltestem": "gemauschelt",
    "gemauscheltesten": "gemauschelt",
    "gemauscheltester": "gemauschelt",
    "gemauscheltestes": "gemauschelt",
    "gemausert": "mausern",
    "gemauserte": "gemausert",
    "gemausertem": "gemausert",
    "gemauserten": "gemausert",
    "gemauserter": "gemausert",
    "gemausertere": "gemausert",
    "gemauserterem": "gemausert",
    "gemauserteren": "gemausert",
    "gemauserterer": "gemausert",
    "gemauserteres": "gemausert",
    "gemausertes": "gemausert",
    "gemauserteste": "gemausert",
    "gemausertestem": "gemausert",
    "gemausertesten": "gemausert",
    "gemausertester": "gemausert",
    "gemausertestes": "gemausert",
    "gemaßt": "maßen",
    "gemaßte": "gemaßt",
    "gemaßtem": "gemaßt",
    "gemaßten": "gemaßt",
    "gemaßter": "gemaßt",
    "gemaßtes": "gemaßt",
    "gemeckert": "meckern",
    "gemeckerte": "gemeckert",
    "gemeckertem": "gemeckert",
    "gemeckerten": "gemeckert",
    "gemeckerter": "gemeckert",
    "gemeckertes": "gemeckert",
    "gemehrt": "mehren",
    "gemehrte": "gemehrt",
    "gemehrtem": "gemehrt",
    "gemehrten": "gemehrt",
    "gemehrter": "gemehrt",
    "gemehrtes": "gemehrt",
    "gemeinde": "gemeinden",
    "gemeindend": "gemeinden",
    "gemeindende": "gemeindend",
    "gemeindendem": "gemeindend",
    "gemeindenden": "gemeindend",
    "gemeindender": "gemeindend",
    "gemeindendes": "gemeindend",
    "gemeindest": "gemeinden",
    "gemeindet": "gemeinden",
    "gemeindete": "gemeinden",
    "gemeindetem": "gemeindet",
    "gemeindeten": "gemeinden",
    "gemeindeter": "gemeindet",
    "gemeindetes": "gemeindet",
    "gemeindetest": "gemeinden",
    "gemeindetet": "gemeinden",
    "gemeine": "gemein",
    "gemeinem": "gemein",
    "gemeinen": "gemein",
    "gemeiner": "gemein",
    "gemeinere": "gemein",
    "gemeinerem": "gemein",
    "gemeineren": "gemein",
    "gemeinerer": "gemein",
    "gemeineres": "gemein",
    "gemeines": "gemein",
    "gemeingefährliche": "gemeingefährlich",
    "gemeingefährlichem": "gemeingefährlich",
    "gemeingefährlichen": "gemeingefährlich",
    "gemeingefährlicher": "gemeingefährlich",
    "gemeingefährlichere": "gemeingefährlich",
    "gemeingefährlicherem": "gemeingefährlich",
    "gemeingefährlicheren": "gemeingefährlich",
    "gemeingefährlicherer": "gemeingefährlich",
    "gemeingefährlicheres": "gemeingefährlich",
    "gemeingefährliches": "gemeingefährlich",
    "gemeingefährlichste": "gemeingefährlich",
    "gemeingefährlichstem": "gemeingefährlich",
    "gemeingefährlichsten": "gemeingefährlich",
    "gemeingefährlichster": "gemeingefährlich",
    "gemeingefährlichstes": "gemeingefährlich",
    "gemeinnützige": "gemeinnützig",
    "gemeinnützigem": "gemeinnützig",
    "gemeinnützigen": "gemeinnützig",
    "gemeinnütziger": "gemeinnützig",
    "gemeinnütziges": "gemeinnützig",
    "gemeinsame": "gemeinsam",
    "gemeinsamem": "gemeinsam",
    "gemeinsamen": "gemeinsam",
    "gemeinsamer": "gemeinsam",
    "gemeinsamere": "gemeinsam",
    "gemeinsamerem": "gemeinsam",
    "gemeinsameren": "gemeinsam",
    "gemeinsamerer": "gemeinsam",
    "gemeinsameres": "gemeinsam",
    "gemeinsames": "gemeinsam",
    "gemeinsamstem": "gemeinsam",
    "gemeinsamsten": "gemeinsam",
    "gemeinsamster": "gemeinsam",
    "gemeinsamstes": "gemeinsam",
    "gemeinschaftlichem": "gemeinschaftlich",
    "gemeinschaftlichen": "gemeinschaftlich",
    "gemeinschaftlicher": "gemeinschaftlich",
    "gemeinschaftliches": "gemeinschaftlich",
    "gemeinstem": "gemein",
    "gemeinsten": "gemein",
    "gemeinster": "gemein",
    "gemeinstes": "gemein",
    "gemeint": "meinen",
    "gemeinte": "gemeint",
    "gemeintem": "gemeint",
    "gemeinten": "gemeint",
    "gemeinter": "gemeint",
    "gemeintes": "gemeint",
    "gemeistert": "meistern",
    "gemeisterte": "gemeistert",
    "gemeistertem": "gemeistert",
    "gemeisterten": "gemeistert",
    "gemeisterter": "gemeistert",
    "gemeistertere": "gemeistert",
    "gemeisterterem": "gemeistert",
    "gemeisterteren": "gemeistert",
    "gemeisterterer": "gemeistert",
    "gemeisterteres": "gemeistert",
    "gemeistertes": "gemeistert",
    "gemeisterteste": "gemeistert",
    "gemeistertestem": "gemeistert",
    "gemeistertesten": "gemeistert",
    "gemeistertester": "gemeistert",
    "gemeistertestes": "gemeistert",
    "gemeißelt": "meißeln",
    "gemeißelte": "gemeißelt",
    "gemeißeltem": "gemeißelt",
    "gemeißelten": "gemeißelt",
    "gemeißelter": "gemeißelt",
    "gemeißeltes": "gemeißelt",
    "gemeldet": "melden",
    "gemeldete": "gemeldet",
    "gemeldetem": "gemeldet",
    "gemeldeten": "gemeldet",
    "gemeldeter": "gemeldet",
    "gemeldetes": "gemeldet",
    "gemelkt": "melken",
    "gemelkte": "gemelkt",
    "gemelktem": "gemelkt",
    "gemelkten": "gemelkt",
    "gemelkter": "gemelkt",
    "gemelktes": "gemelkt",
    "gemengt": "mengen",
    "gemengte": "gemengt",
    "gemengtem": "gemengt",
    "gemengten": "gemengt",
    "gemengter": "gemengt",
    "gemengtes": "gemengt",
    "gemerkt": "merken",
    "gemerkte": "gemerkt",
    "gemerktem": "gemerkt",
    "gemerkten": "gemerkt",
    "gemerkter": "gemerkt",
    "gemerktes": "gemerkt",
    "gemerzt": "merzen",
    "gemerzte": "gemerzt",
    "gemerztem": "gemerzt",
    "gemerzten": "gemerzt",
    "gemerzter": "gemerzt",
    "gemerztes": "gemerzt",
    "gemessen": "messen",
    "gemessene": "gemessen",
    "gemessenem": "gemessen",
    "gemessenen": "gemessen",
    "gemessener": "gemessen",
    "gemessenes": "gemessen",
    "gemetzelt": "metzeln",
    "gemetzelte": "gemetzelt",
    "gemetzeltem": "gemetzelt",
    "gemetzelten": "gemetzelt",
    "gemetzelter": "gemetzelt",
    "gemetzeltere": "gemetzelt",
    "gemetzelterem": "gemetzelt",
    "gemetzelteren": "gemetzelt",
    "gemetzelterer": "gemetzelt",
    "gemetzelteres": "gemetzelt",
    "gemetzeltes": "gemetzelt",
    "gemetzelteste": "gemetzelt",
    "gemetzeltestem": "gemetzelt",
    "gemetzeltesten": "gemetzelt",
    "gemetzeltester": "gemetzelt",
    "gemetzeltestes": "gemetzelt",
    "gemeutert": "meutern",
    "gemeuterte": "gemeutert",
    "gemeutertem": "gemeutert",
    "gemeuterten": "gemeutert",
    "gemeuterter": "gemeutert",
    "gemeutertes": "gemeutert",
    "gemieden": "meiden",
    "gemiedene": "gemieden",
    "gemiedenem": "gemieden",
    "gemiedenen": "gemieden",
    "gemiedener": "gemieden",
    "gemiedenere": "gemieden",
    "gemiedenerem": "gemieden",
    "gemiedeneren": "gemieden",
    "gemiedenerer": "gemieden",
    "gemiedeneres": "gemieden",
    "gemiedenes": "gemieden",
    "gemiedenste": "gemieden",
    "gemiedenstem": "gemieden",
    "gemiedensten": "gemieden",
    "gemiedenster": "gemieden",
    "gemiedenstes": "gemieden",
    "gemieft": "miefen",
    "gemiefte": "gemieft",
    "gemieftem": "gemieft",
    "gemieften": "gemieft",
    "gemiefter": "gemieft",
    "gemieftes": "gemieft",
    "gemietet": "mieten",
    "gemietete": "gemietet",
    "gemietetem": "gemietet",
    "gemieteten": "gemietet",
    "gemieteter": "gemietet",
    "gemietetes": "gemietet",
    "gemildert": "mildern",
    "gemilderte": "gemildert",
    "gemildertem": "gemildert",
    "gemilderten": "gemildert",
    "gemilderter": "gemildert",
    "gemildertere": "gemildert",
    "gemilderterem": "gemildert",
    "gemilderteren": "gemildert",
    "gemilderterer": "gemildert",
    "gemilderteres": "gemildert",
    "gemildertes": "gemildert",
    "gemilderteste": "gemildert",
    "gemildertestem": "gemildert",
    "gemildertesten": "gemildert",
    "gemildertester": "gemildert",
    "gemildertestes": "gemildert",
    "gemimt": "mimen",
    "gemimte": "gemimt",
    "gemimtem": "gemimt",
    "gemimten": "gemimt",
    "gemimter": "gemimt",
    "gemimtes": "gemimt",
    "gemindert": "mindern",
    "geminderte": "gemindert",
    "gemindertem": "gemindert",
    "geminderten": "gemindert",
    "geminderter": "gemindert",
    "gemindertere": "gemindert",
    "geminderterem": "gemindert",
    "geminderteren": "gemindert",
    "geminderterer": "gemindert",
    "geminderteres": "gemindert",
    "gemindertes": "gemindert",
    "geminderteste": "gemindert",
    "gemindertestem": "gemindert",
    "gemindertesten": "gemindert",
    "gemindertester": "gemindert",
    "gemindertestes": "gemindert",
    "gemischt": "mischen",
    "gemischte": "gemischt",
    "gemischtem": "gemischt",
    "gemischten": "gemischt",
    "gemischter": "gemischt",
    "gemischtere": "gemischt",
    "gemischterem": "gemischt",
    "gemischteren": "gemischt",
    "gemischterer": "gemischt",
    "gemischteres": "gemischt",
    "gemischtes": "gemischt",
    "gemischteste": "gemischt",
    "gemischtestem": "gemischt",
    "gemischtesten": "gemischt",
    "gemischtester": "gemischt",
    "gemischtestes": "gemischt",
    "gemistet": "misten",
    "gemistete": "gemistet",
    "gemistetem": "gemistet",
    "gemisteten": "gemistet",
    "gemisteter": "gemistet",
    "gemistetes": "gemistet",
    "gemittelt": "mitteln",
    "gemittelte": "gemittelt",
    "gemitteltem": "gemittelt",
    "gemittelten": "gemittelt",
    "gemittelter": "gemittelt",
    "gemitteltes": "gemittelt",
    "gemixt": "mixen",
    "gemixte": "gemixt",
    "gemixtem": "gemixt",
    "gemixten": "gemixt",
    "gemixter": "gemixt",
    "gemixtes": "gemixt",
    "gemißt": "missen",
    "gemißte": "gemißt",
    "gemißtem": "gemißt",
    "gemißten": "gemißt",
    "gemißter": "gemißt",
    "gemißtes": "gemißt",
    "gemocht": "mögen",
    "gemodelt": "modeln",
    "gemodelte": "gemodelt",
    "gemodeltem": "gemodelt",
    "gemodelten": "gemodelt",
    "gemodelter": "gemodelt",
    "gemodeltes": "gemodelt",
    "gemogelt": "mogeln",
    "gemogelte": "gemogelt",
    "gemogeltem": "gemogelt",
    "gemogelten": "gemogelt",
    "gemogelter": "gemogelt",
    "gemogeltes": "gemogelt",
    "gemolken": "melken",
    "gemolkene": "gemolken",
    "gemolkenem": "gemolken",
    "gemolkenen": "gemolken",
    "gemolkener": "gemolken",
    "gemolkenes": "gemolken",
    "gemopst": "mopsen",
    "gemopste": "gemopst",
    "gemopstem": "gemopst",
    "gemopsten": "gemopst",
    "gemopster": "gemopst",
    "gemopstes": "gemopst",
    "gemordet": "morden",
    "gemordete": "gemordet",
    "gemordetem": "gemordet",
    "gemordeten": "gemordet",
    "gemordeter": "gemordet",
    "gemordetes": "gemordet",
    "gemorst": "morsen",
    "gemorste": "gemorst",
    "gemorstem": "gemorst",
    "gemorsten": "gemorst",
    "gemorster": "gemorst",
    "gemorstes": "gemorst",
    "gemosert": "mosern",
    "gemoserte": "gemosert",
    "gemosertem": "gemosert",
    "gemoserten": "gemosert",
    "gemoserter": "gemosert",
    "gemosertes": "gemosert",
    "gemottet": "motten",
    "gemottete": "gemottet",
    "gemottetem": "gemottet",
    "gemotteten": "gemottet",
    "gemotteter": "gemottet",
    "gemottetes": "gemottet",
    "gemotzt": "motzen",
    "gemotzte": "gemotzt",
    "gemotztem": "gemotzt",
    "gemotzten": "gemotzt",
    "gemotzter": "gemotzt",
    "gemotztes": "gemotzt",
    "gemuckst": "mucksen",
    "gemuckste": "gemuckst",
    "gemuckstem": "gemuckst",
    "gemucksten": "gemuckst",
    "gemuckster": "gemuckst",
    "gemuckstes": "gemuckst",
    "gemuffelt": "muffeln",
    "gemuffelte": "gemuffelt",
    "gemuffeltem": "gemuffelt",
    "gemuffelten": "gemuffelt",
    "gemuffelter": "gemuffelt",
    "gemuffeltes": "gemuffelt",
    "gemufft": "muffen",
    "gemuffte": "gemufft",
    "gemufftem": "gemufft",
    "gemufften": "gemufft",
    "gemuffter": "gemufft",
    "gemufftes": "gemufft",
    "gemundet": "munden",
    "gemundete": "gemundet",
    "gemundetem": "gemundet",
    "gemundeten": "gemundet",
    "gemundeter": "gemundet",
    "gemundetes": "gemundet",
    "gemunkelt": "munkeln",
    "gemunkelte": "gemunkelt",
    "gemunkeltem": "gemunkelt",
    "gemunkelten": "gemunkelt",
    "gemunkelter": "gemunkelt",
    "gemunkeltes": "gemunkelt",
    "gemuntert": "muntern",
    "gemunterte": "gemuntert",
    "gemuntertem": "gemuntert",
    "gemunterten": "gemuntert",
    "gemunterter": "gemuntert",
    "gemuntertes": "gemuntert",
    "gemurkst": "murksen",
    "gemurkste": "gemurkst",
    "gemurkstem": "gemurkst",
    "gemurksten": "gemurkst",
    "gemurkster": "gemurkst",
    "gemurkstes": "gemurkst",
    "gemurmelt": "murmeln",
    "gemurmelte": "gemurmelt",
    "gemurmeltem": "gemurmelt",
    "gemurmelten": "gemurmelt",
    "gemurmelter": "gemurmelt",
    "gemurmeltes": "gemurmelt",
    "gemurrt": "murren",
    "gemurrte": "gemurrt",
    "gemurrtem": "gemurrt",
    "gemurrten": "gemurrt",
    "gemurrter": "gemurrt",
    "gemurrtes": "gemurrt",
    "gemustert": "mustern",
    "gemusterte": "gemustert",
    "gemustertem": "gemustert",
    "gemusterten": "gemustert",
    "gemusterter": "gemustert",
    "gemustertere": "gemustert",
    "gemusterterem": "gemustert",
    "gemusterteren": "gemustert",
    "gemusterterer": "gemustert",
    "gemusterteres": "gemustert",
    "gemustertes": "gemustert",
    "gemusterteste": "gemustert",
    "gemustertestem": "gemustert",
    "gemustertesten": "gemustert",
    "gemustertester": "gemustert",
    "gemustertestes": "gemustert",
    "gemutet": "muten",
    "gemutete": "gemutet",
    "gemutetem": "gemutet",
    "gemuteten": "gemutet",
    "gemuteter": "gemutet",
    "gemutetes": "gemutet",
    "gemutmaßt": "mutmaßen",
    "gemutmaßte": "gemutmaßt",
    "gemutmaßtem": "gemutmaßt",
    "gemutmaßten": "gemutmaßt",
    "gemutmaßter": "gemutmaßt",
    "gemutmaßtes": "gemutmaßt",
    "gemußt": "müssen",
    "gemächliche": "gemächlich",
    "gemächlichem": "gemächlich",
    "gemächlichen": "gemächlich",
    "gemächlicher": "gemächlich",
    "gemächlichere": "gemächlich",
    "gemächlicherem": "gemächlich",
    "gemächlicheren": "gemächlich",
    "gemächlicherer": "gemächlich",
    "gemächlicheres": "gemächlich",
    "gemächliches": "gemächlich",
    "gemächlichste": "gemächlich",
    "gemächlichstem": "gemächlich",
    "gemächlichsten": "gemächlich",
    "gemächlichster": "gemächlich",
    "gemächlichstes": "gemächlich",
    "gemähdrescht": "mähdreschen",
    "gemähdreschte": "gemähdrescht",
    "gemähdreschtem": "gemähdrescht",
    "gemähdreschten": "gemähdrescht",
    "gemähdreschter": "gemähdrescht",
    "gemähdreschtes": "gemähdrescht",
    "gemäht": "mähen",
    "gemähte": "gemäht",
    "gemähtem": "gemäht",
    "gemähten": "gemäht",
    "gemähter": "gemäht",
    "gemähtes": "gemäht",
    "gemäkelt": "mäkeln",
    "gemäkelte": "gemäkelt",
    "gemäkeltem": "gemäkelt",
    "gemäkelten": "gemäkelt",
    "gemäkelter": "gemäkelt",
    "gemäkeltere": "gemäkelt",
    "gemäkelterem": "gemäkelt",
    "gemäkelteren": "gemäkelt",
    "gemäkelterer": "gemäkelt",
    "gemäkelteres": "gemäkelt",
    "gemäkeltes": "gemäkelt",
    "gemäkelteste": "gemäkelt",
    "gemäkeltestem": "gemäkelt",
    "gemäkeltesten": "gemäkelt",
    "gemäkeltester": "gemäkelt",
    "gemäkeltestes": "gemäkelt",
    "gemästet": "mästen",
    "gemästete": "gemästet",
    "gemästetem": "gemästet",
    "gemästeten": "gemästet",
    "gemästeter": "gemästet",
    "gemästetere": "gemästet",
    "gemästeterem": "gemästet",
    "gemästeteren": "gemästet",
    "gemästeterer": "gemästet",
    "gemästeteres": "gemästet",
    "gemästetes": "gemästet",
    "gemästeteste": "gemästet",
    "gemästetestem": "gemästet",
    "gemästetesten": "gemästet",
    "gemästetester": "gemästet",
    "gemästetestes": "gemästet",
    "gemäßigt": "mäßigen",
    "gemäßigte": "gemäßigt",
    "gemäßigtem": "gemäßigt",
    "gemäßigten": "gemäßigt",
    "gemäßigter": "gemäßigt",
    "gemäßigtere": "gemäßigt",
    "gemäßigterem": "gemäßigt",
    "gemäßigteren": "gemäßigt",
    "gemäßigterer": "gemäßigt",
    "gemäßigteres": "gemäßigt",
    "gemäßigtes": "gemäßigt",
    "gemäßigteste": "gemäßigt",
    "gemäßigtestem": "gemäßigt",
    "gemäßigtesten": "gemäßigt",
    "gemäßigtester": "gemäßigt",
    "gemäßigtestes": "gemäßigt",
    "gemöbelt": "möbeln",
    "gemöbelte": "gemöbelt",
    "gemöbeltem": "gemöbelt",
    "gemöbelten": "gemöbelt",
    "gemöbelter": "gemöbelt",
    "gemöbeltes": "gemöbelt",
    "gemörtelt": "mörteln",
    "gemörtelte": "gemörtelt",
    "gemörteltem": "gemörtelt",
    "gemörtelten": "gemörtelt",
    "gemörtelter": "gemörtelt",
    "gemörteltes": "gemörtelt",
    "gemüht": "mühen",
    "gemühte": "gemüht",
    "gemühtem": "gemüht",
    "gemühten": "gemüht",
    "gemühter": "gemüht",
    "gemühtes": "gemüht",
    "gemümmelt": "mümmeln",
    "gemümmelte": "gemümmelt",
    "gemümmeltem": "gemümmelt",
    "gemümmelten": "gemümmelt",
    "gemümmelter": "gemümmelt",
    "gemümmeltere": "gemümmelt",
    "gemümmelterem": "gemümmelt",
    "gemümmelteren": "gemümmelt",
    "gemümmelterer": "gemümmelt",
    "gemümmelteres": "gemümmelt",
    "gemümmeltes": "gemümmelt",
    "gemümmelteste": "gemümmelt",
    "gemümmeltestem": "gemümmelt",
    "gemümmeltesten": "gemümmelt",
    "gemümmeltester": "gemümmelt",
    "gemümmeltestes": "gemümmelt",
    "gemündet": "münden",
    "gemündetem": "gemündet",
    "gemündeter": "gemündet",
    "gemündetes": "gemündet",
    "gemünzt": "münzen",
    "gemünzte": "gemünzt",
    "gemünztem": "gemünzt",
    "gemünzten": "gemünzt",
    "gemünzter": "gemünzt",
    "gemünztes": "gemünzt",
    "gemütliche": "gemütlich",
    "gemütlichem": "gemütlich",
    "gemütlichen": "gemütlich",
    "gemütlicher": "gemütlich",
    "gemütlichere": "gemütlich",
    "gemütlicherem": "gemütlich",
    "gemütlicheren": "gemütlich",
    "gemütlicherer": "gemütlich",
    "gemütlicheres": "gemütlich",
    "gemütliches": "gemütlich",
    "gemütlichste": "gemütlich",
    "gemütlichstem": "gemütlich",
    "gemütlichsten": "gemütlich",
    "gemütlichster": "gemütlich",
    "gemütlichstes": "gemütlich",
    "gemütserfreulichem": "gemütserfreulich",
    "gemütserfreulichen": "gemütserfreulich",
    "gemütserfreulicher": "gemütserfreulich",
    "gemütserfreulichere": "gemütserfreulich",
    "gemütserfreulicherem": "gemütserfreulich",
    "gemütserfreulicheren": "gemütserfreulich",
    "gemütserfreulicherer": "gemütserfreulich",
    "gemütserfreulicheres": "gemütserfreulich",
    "gemütserfreuliches": "gemütserfreulich",
    "gemütserfreulichste": "gemütserfreulich",
    "gemütserfreulichstem": "gemütserfreulich",
    "gemütserfreulichsten": "gemütserfreulich",
    "gemütserfreulichster": "gemütserfreulich",
    "gemütserfreulichstes": "gemütserfreulich",
    "genabelt": "nabeln",
    "genabelte": "genabelt",
    "genabeltem": "genabelt",
    "genabelten": "genabelt",
    "genabelter": "genabelt",
    "genabeltes": "genabelt",
    "genagelt": "nageln",
    "genagelte": "genagelt",
    "genageltem": "genagelt",
    "genagelten": "genagelt",
    "genagelter": "genagelt",
    "genageltes": "genagelt",
    "genagt": "nagen",
    "genagte": "genagt",
    "genagtem": "genagt",
    "genagten": "genagt",
    "genagter": "genagt",
    "genagtere": "genagt",
    "genagterem": "genagt",
    "genagteren": "genagt",
    "genagterer": "genagt",
    "genagteres": "genagt",
    "genagtes": "genagt",
    "genagteste": "genagt",
    "genagtestem": "genagt",
    "genagtesten": "genagt",
    "genagtester": "genagt",
    "genagtestes": "genagt",
    "genannt": "nennen",
    "genannte": "genannt",
    "genanntem": "genannt",
    "genannten": "genannt",
    "genannter": "genannt",
    "genanntere": "genannt",
    "genannterem": "genannt",
    "genannteren": "genannt",
    "genannterer": "genannt",
    "genannteres": "genannt",
    "genanntes": "genannt",
    "genannteste": "genannt",
    "genanntestem": "genannt",
    "genanntesten": "genannt",
    "genanntester": "genannt",
    "genanntestes": "genannt",
    "genarrt": "narren",
    "genarrte": "genarrt",
    "genarrtem": "genarrt",
    "genarrten": "genarrt",
    "genarrter": "genarrt",
    "genarrtere": "genarrt",
    "genarrterem": "genarrt",
    "genarrteren": "genarrt",
    "genarrterer": "genarrt",
    "genarrteres": "genarrt",
    "genarrtes": "genarrt",
    "genarrteste": "genarrt",
    "genarrtestem": "genarrt",
    "genarrtesten": "genarrt",
    "genarrtester": "genarrt",
    "genarrtestes": "genarrt",
    "genas": "genesen",
    "genascht": "naschen",
    "genaschte": "genascht",
    "genaschtem": "genascht",
    "genaschten": "genascht",
    "genaschter": "genascht",
    "genaschtes": "genascht",
    "genasen": "genesen",
    "genast": "genesen",
    "genaue": "genau",
    "genauem": "genau",
    "genauen": "genau",
    "genauer": "genau",
    "genauere": "genau",
    "genauerem": "genau",
    "genaueren": "genau",
    "genauerer": "genau",
    "genaueres": "genau",
    "genaues": "genau",
    "genaueste": "genau",
    "genauestem": "genau",
    "genauesten": "genau",
    "genauester": "genau",
    "genauestes": "genau",
    "genebelt": "nebeln",
    "genebelte": "genebelt",
    "genebeltem": "genebelt",
    "genebelten": "genebelt",
    "genebelter": "genebelt",
    "genebeltes": "genebelt",
    "genehmige": "genehmigen",
    "genehmigend": "genehmigen",
    "genehmigende": "genehmigend",
    "genehmigendem": "genehmigend",
    "genehmigenden": "genehmigend",
    "genehmigender": "genehmigend",
    "genehmigendes": "genehmigend",
    "genehmigest": "genehmigen",
    "genehmiget": "genehmigen",
    "genehmigst": "genehmigen",
    "genehmigt": "genehmigen",
    "genehmigte": "genehmigen",
    "genehmigtem": "genehmigt",
    "genehmigten": "genehmigen",
    "genehmigter": "genehmigt",
    "genehmigtes": "genehmigt",
    "genehmigtest": "genehmigen",
    "genehmigtet": "genehmigen",
    "geneidet": "neiden",
    "geneidete": "geneidet",
    "geneidetem": "geneidet",
    "geneideten": "geneidet",
    "geneideter": "geneidet",
    "geneidetes": "geneidet",
    "geneigt": "neigen",
    "geneigte": "geneigt",
    "geneigtem": "geneigt",
    "geneigten": "geneigt",
    "geneigter": "geneigt",
    "geneigtere": "geneigt",
    "geneigterem": "geneigt",
    "geneigteren": "geneigt",
    "geneigterer": "geneigt",
    "geneigteres": "geneigt",
    "geneigtes": "geneigt",
    "geneigteste": "geneigt",
    "geneigtestem": "geneigt",
    "geneigtesten": "geneigt",
    "geneigtester": "geneigt",
    "geneigtestes": "geneigt",
    "geneppt": "neppen",
    "geneppte": "geneppt",
    "genepptem": "geneppt",
    "geneppten": "geneppt",
    "geneppter": "geneppt",
    "genepptes": "geneppt",
    "generalisiere": "generalisieren",
    "generalisierend": "generalisieren",
    "generalisierende": "generalisierend",
    "generalisierendem": "generalisierend",
    "generalisierenden": "generalisierend",
    "generalisierender": "generalisierend",
    "generalisierendere": "generalisierend",
    "generalisierenderem": "generalisierend",
    "generalisierenderen": "generalisierend",
    "generalisierenderer": "generalisierend",
    "generalisierenderes": "generalisierend",
    "generalisierendes": "generalisierend",
    "generalisierendste": "generalisierend",
    "generalisierendstem": "generalisierend",
    "generalisierendsten": "generalisierend",
    "generalisierendster": "generalisierend",
    "generalisierendstes": "generalisierend",
    "generalisierest": "generalisieren",
    "generalisieret": "generalisieren",
    "generalisierst": "generalisieren",
    "generalisiert": "generalisieren",
    "generalisierte": "generalisieren",
    "generalisiertem": "generalisiert",
    "generalisierten": "generalisieren",
    "generalisierter": "generalisiert",
    "generalisiertere": "generalisiert",
    "generalisierterem": "generalisiert",
    "generalisierteren": "generalisiert",
    "generalisierterer": "generalisiert",
    "generalisierteres": "generalisiert",
    "generalisiertes": "generalisiert",
    "generalisiertest": "generalisieren",
    "generalisiertestem": "generalisiert",
    "generalisiertesten": "generalisiert",
    "generalisiertester": "generalisiert",
    "generalisiertestes": "generalisiert",
    "generalisiertet": "generalisieren",
    "generellem": "generell",
    "generellen": "generell",
    "genereller": "generell",
    "generellere": "generell",
    "generellerem": "generell",
    "generelleren": "generell",
    "generellerer": "generell",
    "generelleres": "generell",
    "generelles": "generell",
    "generellste": "generell",
    "generellstem": "generell",
    "generellsten": "generell",
    "generellster": "generell",
    "generellstes": "generell",
    "generiere": "generieren",
    "generierend": "generieren",
    "generierende": "generierend",
    "generierendem": "generierend",
    "generierenden": "generierend",
    "generierender": "generierend",
    "generierendes": "generierend",
    "generierest": "generieren",
    "generieret": "generieren",
    "generierst": "generieren",
    "generiert": "generieren",
    "generierte": "generieren",
    "generiertem": "generiert",
    "generierten": "generieren",
    "generierter": "generiert",
    "generiertes": "generiert",
    "generiertest": "generieren",
    "generiertet": "generieren",
    "generischem": "generisch",
    "generischen": "generisch",
    "generischer": "generisch",
    "generisches": "generisch",
    "genervt": "nerven",
    "genervte": "genervt",
    "genervtem": "genervt",
    "genervten": "genervt",
    "genervter": "genervt",
    "genervtere": "genervt",
    "genervterem": "genervt",
    "genervteren": "genervt",
    "genervterer": "genervt",
    "genervteres": "genervt",
    "genervtes": "genervt",
    "genervteste": "genervt",
    "genervtestem": "genervt",
    "genervtesten": "genervt",
    "genervtester": "genervt",
    "genervtestes": "genervt",
    "generöse": "generös",
    "generösem": "generös",
    "generösen": "generös",
    "generöser": "generös",
    "generösere": "generös",
    "generöserem": "generös",
    "generöseren": "generös",
    "generöserer": "generös",
    "generöseres": "generös",
    "generöses": "generös",
    "generöseste": "generös",
    "generösestem": "generös",
    "generösesten": "generös",
    "generösester": "generös",
    "generösestes": "generös",
    "genese": "genesen",
    "genesend": "genesen",
    "genesende": "genesend",
    "genesendem": "genesend",
    "genesenden": "genesend",
    "genesender": "genesend",
    "genesendere": "genesend",
    "genesenderem": "genesend",
    "genesenderen": "genesend",
    "genesenderer": "genesend",
    "genesenderes": "genesend",
    "genesendes": "genesend",
    "genesendste": "genesend",
    "genesendstem": "genesend",
    "genesendsten": "genesend",
    "genesendster": "genesend",
    "genesendstes": "genesend",
    "genesene": "genesen",
    "genesenem": "genesen",
    "genesenen": "genesen",
    "genesener": "genesen",
    "genesenere": "genesen",
    "genesenerem": "genesen",
    "geneseneren": "genesen",
    "genesenerer": "genesen",
    "geneseneres": "genesen",
    "genesenes": "genesen",
    "genesenstem": "genesen",
    "genesensten": "genesen",
    "genesenster": "genesen",
    "genesenstes": "genesen",
    "genesest": "genesen",
    "geneset": "genesen",
    "genest": "genesen",
    "genestelt": "nesteln",
    "genestelte": "genestelt",
    "genesteltem": "genestelt",
    "genestelten": "genestelt",
    "genestelter": "genestelt",
    "genesteltere": "genestelt",
    "genestelterem": "genestelt",
    "genestelteren": "genestelt",
    "genestelterer": "genestelt",
    "genestelteres": "genestelt",
    "genesteltes": "genestelt",
    "genestelteste": "genestelt",
    "genesteltestem": "genestelt",
    "genesteltesten": "genestelt",
    "genesteltester": "genestelt",
    "genesteltestes": "genestelt",
    "genetische": "genetisch",
    "genetischem": "genetisch",
    "genetischen": "genetisch",
    "genetischer": "genetisch",
    "genetisches": "genetisch",
    "genialem": "genial",
    "genialen": "genial",
    "genialer": "genial",
    "genialere": "genial",
    "genialerem": "genial",
    "genialeren": "genial",
    "genialerer": "genial",
    "genialeres": "genial",
    "geniales": "genial",
    "genialste": "genial",
    "genialstem": "genial",
    "genialsten": "genial",
    "genialster": "genial",
    "genialstes": "genial",
    "genickt": "nicken",
    "genickte": "genickt",
    "genicktem": "genickt",
    "genickten": "genickt",
    "genickter": "genickt",
    "genicktes": "genickt",
    "geniere": "genieren",
    "genierend": "genieren",
    "genierende": "genierend",
    "genierendem": "genierend",
    "genierenden": "genierend",
    "genierender": "genierend",
    "genierendere": "genierend",
    "genierenderem": "genierend",
    "genierenderen": "genierend",
    "genierenderer": "genierend",
    "genierenderes": "genierend",
    "genierendes": "genierend",
    "genierendste": "genierend",
    "genierendstem": "genierend",
    "genierendsten": "genierend",
    "genierendster": "genierend",
    "genierendstes": "genierend",
    "genierest": "genieren",
    "genieret": "genieren",
    "genierst": "genieren",
    "geniert": "genieren",
    "genierte": "genieren",
    "geniertem": "geniert",
    "genierten": "genieren",
    "genierter": "geniert",
    "geniertes": "geniert",
    "geniertest": "genieren",
    "geniertet": "genieren",
    "genieselt": "nieseln",
    "genieselte": "genieselt",
    "genieseltem": "genieselt",
    "genieselten": "genieselt",
    "genieselter": "genieselt",
    "genieseltes": "genieselt",
    "geniest": "niesen",
    "genieste": "geniest",
    "geniestem": "geniest",
    "geniesten": "geniest",
    "geniester": "geniest",
    "geniestes": "geniest",
    "genietet": "nieten",
    "genietete": "genietet",
    "genietetem": "genietet",
    "genieteten": "genietet",
    "genieteter": "genietet",
    "genietetes": "genietet",
    "genießbare": "genießbar",
    "genießbarem": "genießbar",
    "genießbaren": "genießbar",
    "genießbarer": "genießbar",
    "genießbares": "genießbar",
    "genieße": "genießen",
    "genießend": "genießen",
    "genießende": "genießend",
    "genießendem": "genießend",
    "genießenden": "genießend",
    "genießender": "genießend",
    "genießendere": "genießend",
    "genießenderem": "genießend",
    "genießenderen": "genießend",
    "genießenderer": "genießend",
    "genießenderes": "genießend",
    "genießendes": "genießend",
    "genießendste": "genießend",
    "genießendstem": "genießend",
    "genießendsten": "genießend",
    "genießendster": "genießend",
    "genießendstes": "genießend",
    "genießerischem": "genießerisch",
    "genießerischen": "genießerisch",
    "genießerischer": "genießerisch",
    "genießerischere": "genießerisch",
    "genießerischerem": "genießerisch",
    "genießerischeren": "genießerisch",
    "genießerischerer": "genießerisch",
    "genießerischeres": "genießerisch",
    "genießerisches": "genießerisch",
    "genießerischste": "genießerisch",
    "genießerischstem": "genießerisch",
    "genießerischsten": "genießerisch",
    "genießerischster": "genießerisch",
    "genießerischstes": "genießerisch",
    "genießest": "genießen",
    "genießet": "genießen",
    "genießt": "genießen",
    "genippt": "nippen",
    "genippte": "genippt",
    "genipptem": "genippt",
    "genippten": "genippt",
    "genippter": "genippt",
    "genipptes": "genippt",
    "genistet": "nisten",
    "genistete": "genistet",
    "genistetem": "genistet",
    "genisteten": "genistet",
    "genisteter": "genistet",
    "genistetes": "genistet",
    "genitalem": "genital",
    "genitalen": "genital",
    "genitaler": "genital",
    "genitales": "genital",
    "genitalische": "genitalisch",
    "genitalischem": "genitalisch",
    "genitalischen": "genitalisch",
    "genitalischer": "genitalisch",
    "genitalisches": "genitalisch",
    "genommen": "nehmen",
    "genommene": "genommen",
    "genommenem": "genommen",
    "genommenen": "genommen",
    "genommener": "genommen",
    "genommenere": "genommen",
    "genommenerem": "genommen",
    "genommeneren": "genommen",
    "genommenerer": "genommen",
    "genommeneres": "genommen",
    "genommenes": "genommen",
    "genommenste": "genommen",
    "genommenstem": "genommen",
    "genommensten": "genommen",
    "genommenster": "genommen",
    "genommenstes": "genommen",
    "genordet": "norden",
    "genordete": "genordet",
    "genordetem": "genordet",
    "genordeten": "genordet",
    "genordeter": "genordet",
    "genordetes": "genordet",
    "genormt": "normen",
    "genormte": "genormt",
    "genormtem": "genormt",
    "genormten": "genormt",
    "genormter": "genormt",
    "genormtere": "genormt",
    "genormterem": "genormt",
    "genormteren": "genormt",
    "genormterer": "genormt",
    "genormteres": "genormt",
    "genormtes": "genormt",
    "genormteste": "genormt",
    "genormtestem": "genormt",
    "genormtesten": "genormt",
    "genormtester": "genormt",
    "genormtestes": "genormt",
    "genossen": "genießen",
    "genossene": "genossen",
    "genossenem": "genossen",
    "genossenen": "genossen",
    "genossener": "genossen",
    "genossenere": "genossen",
    "genossenerem": "genossen",
    "genosseneren": "genossen",
    "genossenerer": "genossen",
    "genosseneres": "genossen",
    "genossenes": "genossen",
    "genossenschaftlichem": "genossenschaftlich",
    "genossenschaftlichen": "genossenschaftlich",
    "genossenschaftlicher": "genossenschaftlich",
    "genossenschaftliches": "genossenschaftlich",
    "genossenste": "genossen",
    "genossenstem": "genossen",
    "genossensten": "genossen",
    "genossenster": "genossen",
    "genossenstes": "genossen",
    "genoß": "genießen",
    "genoßt": "genießen",
    "genudelt": "nudeln",
    "genudelte": "genudelt",
    "genudeltem": "genudelt",
    "genudelten": "genudelt",
    "genudelter": "genudelt",
    "genudeltes": "genudelt",
    "genullt": "nullen",
    "genullte": "genullt",
    "genulltem": "genullt",
    "genullten": "genullt",
    "genullter": "genullt",
    "genulltes": "genullt",
    "genuschelt": "nuscheln",
    "genuschelte": "genuschelt",
    "genuscheltem": "genuschelt",
    "genuschelten": "genuschelt",
    "genuschelter": "genuschelt",
    "genuscheltes": "genuschelt",
    "genutzt": "nutzen",
    "genutzte": "genutzt",
    "genutztem": "genutzt",
    "genutzten": "genutzt",
    "genutzter": "genutzt",
    "genutztere": "genutzt",
    "genutzterem": "genutzt",
    "genutzteren": "genutzt",
    "genutzterer": "genutzt",
    "genutzteres": "genutzt",
    "genutztes": "genutzt",
    "genutzteste": "genutzt",
    "genutztestem": "genutzt",
    "genutztesten": "genutzt",
    "genutztester": "genutzt",
    "genutztestes": "genutzt",
    "genußreiche": "genußreich",
    "genußreichem": "genußreich",
    "genußreichen": "genußreich",
    "genußreicher": "genußreich",
    "genußreichere": "genußreich",
    "genußreicherem": "genußreich",
    "genußreicheren": "genußreich",
    "genußreicherer": "genußreich",
    "genußreicheres": "genußreich",
    "genußreiches": "genußreich",
    "genußreichste": "genußreich",
    "genußreichstem": "genußreich",
    "genußreichsten": "genußreich",
    "genußreichster": "genußreich",
    "genußreichstes": "genußreich",
    "genächtigt": "nächtigen",
    "genächtigte": "genächtigt",
    "genächtigtem": "genächtigt",
    "genächtigten": "genächtigt",
    "genächtigter": "genächtigt",
    "genächtigtes": "genächtigt",
    "genähert": "nähern",
    "genäherte": "genähert",
    "genähertem": "genähert",
    "genäherten": "genähert",
    "genäherter": "genähert",
    "genähertes": "genähert",
    "genährt": "nähren",
    "genährte": "genährt",
    "genährtem": "genährt",
    "genährten": "genährt",
    "genährter": "genährt",
    "genährtere": "genährt",
    "genährterem": "genährt",
    "genährteren": "genährt",
    "genährterer": "genährt",
    "genährteres": "genährt",
    "genährtes": "genährt",
    "genährteste": "genährt",
    "genährtestem": "genährt",
    "genährtesten": "genährt",
    "genährtester": "genährt",
    "genährtestes": "genährt",
    "genäht": "nähen",
    "genähte": "genäht",
    "genähtem": "genäht",
    "genähten": "genäht",
    "genähter": "genäht",
    "genähtes": "genäht",
    "genäse": "genesen",
    "genäselt": "näseln",
    "genäselte": "genäselt",
    "genäseltem": "genäselt",
    "genäselten": "genäselt",
    "genäselter": "genäselt",
    "genäseltes": "genäselt",
    "genäsen": "genesen",
    "genäsest": "genesen",
    "genäset": "genesen",
    "genässelt": "nässeln",
    "genässelte": "genässelt",
    "genässeltem": "genässelt",
    "genässelten": "genässelt",
    "genässelter": "genässelt",
    "genässeltes": "genässelt",
    "genäßt": "nässen",
    "genäßte": "genäßt",
    "genäßtem": "genäßt",
    "genäßten": "genäßt",
    "genäßter": "genäßt",
    "genäßtes": "genäßt",
    "genölt": "nölen",
    "genölte": "genölt",
    "genöltem": "genölt",
    "genölten": "genölt",
    "genölter": "genölt",
    "genöltes": "genölt",
    "genörgelt": "nörgeln",
    "genörgelte": "genörgelt",
    "genörgeltem": "genörgelt",
    "genörgelten": "genörgelt",
    "genörgelter": "genörgelt",
    "genörgeltes": "genörgelt",
    "genösse": "genießen",
    "genössen": "genießen",
    "genössest": "genießen",
    "genösset": "genießen",
    "genötigt": "nötigen",
    "genötigte": "genötigt",
    "genötigtem": "genötigt",
    "genötigten": "genötigt",
    "genötigter": "genötigt",
    "genötigtes": "genötigt",
    "genüge": "genügen",
    "genügend": "genügen",
    "genügende": "genügend",
    "genügendem": "genügend",
    "genügenden": "genügend",
    "genügender": "genügend",
    "genügendere": "genügend",
    "genügenderem": "genügend",
    "genügenderen": "genügend",
    "genügenderer": "genügend",
    "genügenderes": "genügend",
    "genügendes": "genügend",
    "genügendste": "genügend",
    "genügendstem": "genügend",
    "genügendsten": "genügend",
    "genügendster": "genügend",
    "genügendstes": "genügend",
    "genügest": "genügen",
    "genüget": "genügen",
    "genügsame": "genügsam",
    "genügsamem": "genügsam",
    "genügsamen": "genügsam",
    "genügsamer": "genügsam",
    "genügsamere": "genügsam",
    "genügsamerem": "genügsam",
    "genügsameren": "genügsam",
    "genügsamerer": "genügsam",
    "genügsameres": "genügsam",
    "genügsames": "genügsam",
    "genügsamste": "genügsam",
    "genügsamstem": "genügsam",
    "genügsamsten": "genügsam",
    "genügsamster": "genügsam",
    "genügsamstes": "genügsam",
    "genügst": "genügen",
    "genügt": "genügen",
    "genügte": "genügen",
    "genügtem": "genügt",
    "genügten": "genügen",
    "genügter": "genügt",
    "genügtes": "genügt",
    "genügtest": "genügen",
    "genügtet": "genügen",
    "genützt": "nützen",
    "genütztem": "genützt",
    "genützter": "genützt",
    "genütztes": "genützt",
    "genüßlichem": "genüßlich",
    "genüßlichen": "genüßlich",
    "genüßlicher": "genüßlich",
    "genüßlichere": "genüßlich",
    "genüßlicherem": "genüßlich",
    "genüßlicheren": "genüßlich",
    "genüßlicherer": "genüßlich",
    "genüßlicheres": "genüßlich",
    "genüßliches": "genüßlich",
    "genüßlichste": "genüßlich",
    "genüßlichstem": "genüßlich",
    "genüßlichsten": "genüßlich",
    "genüßlichster": "genüßlich",
    "genüßlichstes": "genüßlich",
    "geodätische": "geodätisch",
    "geodätischem": "geodätisch",
    "geodätischen": "geodätisch",
    "geodätischer": "geodätisch",
    "geodätisches": "geodätisch",
    "geographische": "geographisch",
    "geographischem": "geographisch",
    "geographischen": "geographisch",
    "geographischer": "geographisch",
    "geographisches": "geographisch",
    "geohrfeigt": "ohrfeigen",
    "geohrfeigte": "geohrfeigt",
    "geohrfeigtem": "geohrfeigt",
    "geohrfeigten": "geohrfeigt",
    "geohrfeigter": "geohrfeigt",
    "geohrfeigtes": "geohrfeigt",
    "geologischem": "geologisch",
    "geologischen": "geologisch",
    "geologischer": "geologisch",
    "geologisches": "geologisch",
    "geopfert": "opfern",
    "geopferte": "geopfert",
    "geopfertem": "geopfert",
    "geopferten": "geopfert",
    "geopferter": "geopfert",
    "geopfertes": "geopfert",
    "geophysikalische": "geophysikalisch",
    "geophysikalischem": "geophysikalisch",
    "geophysikalischen": "geophysikalisch",
    "geophysikalischer": "geophysikalisch",
    "geophysikalisches": "geophysikalisch",
    "geordert": "ordern",
    "georderte": "geordert",
    "geordertem": "geordert",
    "georderten": "geordert",
    "georderter": "geordert",
    "geordertere": "geordert",
    "georderterem": "geordert",
    "georderteren": "geordert",
    "georderterer": "geordert",
    "georderteres": "geordert",
    "geordertes": "geordert",
    "georderteste": "geordert",
    "geordertestem": "geordert",
    "geordertesten": "geordert",
    "geordertester": "geordert",
    "geordertestes": "geordert",
    "geordnet": "ordnen",
    "geordnete": "geordnet",
    "geordnetem": "geordnet",
    "geordneten": "geordnet",
    "geordneter": "geordnet",
    "geordnetere": "geordnet",
    "geordneterem": "geordnet",
    "geordneteren": "geordnet",
    "geordneterer": "geordnet",
    "geordneteres": "geordnet",
    "geordnetes": "geordnet",
    "geordneteste": "geordnet",
    "geordnetestem": "geordnet",
    "geordnetesten": "geordnet",
    "geordnetester": "geordnet",
    "geordnetestes": "geordnet",
    "georgelt": "orgeln",
    "georgelte": "georgelt",
    "georgeltem": "georgelt",
    "georgelten": "georgelt",
    "georgelter": "georgelt",
    "georgeltes": "georgelt",
    "georgischem": "georgisch",
    "georgischen": "georgisch",
    "georgischer": "georgisch",
    "georgisches": "georgisch",
    "geortet": "orten",
    "geortete": "geortet",
    "geortetem": "geortet",
    "georteten": "geortet",
    "georteter": "geortet",
    "geortetes": "geortet",
    "gepaart": "paaren",
    "gepaarte": "gepaart",
    "gepaartem": "gepaart",
    "gepaarten": "gepaart",
    "gepaarter": "gepaart",
    "gepaartes": "gepaart",
    "gepachtet": "pachten",
    "gepachtete": "gepachtet",
    "gepachtetem": "gepachtet",
    "gepachteten": "gepachtet",
    "gepachteter": "gepachtet",
    "gepachtetes": "gepachtet",
    "gepackt": "packen",
    "gepackte": "gepackt",
    "gepacktem": "gepackt",
    "gepackten": "gepackt",
    "gepackter": "gepackt",
    "gepacktes": "gepackt",
    "gepaddelt": "paddeln",
    "gepaddelte": "gepaddelt",
    "gepaddeltem": "gepaddelt",
    "gepaddelten": "gepaddelt",
    "gepaddelter": "gepaddelt",
    "gepaddeltes": "gepaddelt",
    "gepafft": "paffen",
    "gepaffte": "gepafft",
    "gepafftem": "gepafft",
    "gepafften": "gepafft",
    "gepaffter": "gepafft",
    "gepafftes": "gepafft",
    "gepanscht": "panschen",
    "gepanschte": "gepanscht",
    "gepanschtem": "gepanscht",
    "gepanschten": "gepanscht",
    "gepanschter": "gepanscht",
    "gepanschtere": "gepanscht",
    "gepanschterem": "gepanscht",
    "gepanschteren": "gepanscht",
    "gepanschterer": "gepanscht",
    "gepanschteres": "gepanscht",
    "gepanschtes": "gepanscht",
    "gepanschteste": "gepanscht",
    "gepanschtestem": "gepanscht",
    "gepanschtesten": "gepanscht",
    "gepanschtester": "gepanscht",
    "gepanschtestes": "gepanscht",
    "gepantscht": "pantschen",
    "gepantschte": "gepantscht",
    "gepantschtem": "gepantscht",
    "gepantschten": "gepantscht",
    "gepantschter": "gepantscht",
    "gepantschtes": "gepantscht",
    "gepanzert": "panzern",
    "gepanzerte": "gepanzert",
    "gepanzertem": "gepanzert",
    "gepanzerten": "gepanzert",
    "gepanzerter": "gepanzert",
    "gepanzertere": "gepanzert",
    "gepanzerterem": "gepanzert",
    "gepanzerteren": "gepanzert",
    "gepanzerterer": "gepanzert",
    "gepanzerteres": "gepanzert",
    "gepanzertes": "gepanzert",
    "gepanzerteste": "gepanzert",
    "gepanzertestem": "gepanzert",
    "gepanzertesten": "gepanzert",
    "gepanzertester": "gepanzert",
    "gepanzertestes": "gepanzert",
    "gepappt": "pappen",
    "gepappte": "gepappt",
    "gepapptem": "gepappt",
    "gepappten": "gepappt",
    "gepappter": "gepappt",
    "gepapptes": "gepappt",
    "geparkt": "parken",
    "geparkte": "geparkt",
    "geparktem": "geparkt",
    "geparkten": "geparkt",
    "geparkter": "geparkt",
    "geparktes": "geparkt",
    "geparst": "parsen",
    "geparste": "geparst",
    "geparstem": "geparst",
    "geparsten": "geparst",
    "geparster": "geparst",
    "geparstes": "geparst",
    "gepatscht": "patschen",
    "gepatschte": "gepatscht",
    "gepatschtem": "gepatscht",
    "gepatschten": "gepatscht",
    "gepatschter": "gepatscht",
    "gepatschtes": "gepatscht",
    "gepatzt": "patzen",
    "gepatzte": "gepatzt",
    "gepatztem": "gepatzt",
    "gepatzten": "gepatzt",
    "gepatzter": "gepatzt",
    "gepatztes": "gepatzt",
    "gepaukt": "pauken",
    "gepaukte": "gepaukt",
    "gepauktem": "gepaukt",
    "gepaukten": "gepaukt",
    "gepaukter": "gepaukt",
    "gepauktes": "gepaukt",
    "gepaust": "pausen",
    "gepauste": "gepaust",
    "gepaustem": "gepaust",
    "gepausten": "gepaust",
    "gepauster": "gepaust",
    "gepaustes": "gepaust",
    "gepaßt": "passen",
    "gepaßte": "gepaßt",
    "gepaßtem": "gepaßt",
    "gepaßten": "gepaßt",
    "gepaßter": "gepaßt",
    "gepaßtes": "gepaßt",
    "gepeilt": "peilen",
    "gepeilte": "gepeilt",
    "gepeiltem": "gepeilt",
    "gepeilten": "gepeilt",
    "gepeilter": "gepeilt",
    "gepeiltes": "gepeilt",
    "gepeinigt": "peinigen",
    "gepeinigte": "gepeinigt",
    "gepeinigtem": "gepeinigt",
    "gepeinigten": "gepeinigt",
    "gepeinigter": "gepeinigt",
    "gepeinigtere": "gepeinigt",
    "gepeinigterem": "gepeinigt",
    "gepeinigteren": "gepeinigt",
    "gepeinigterer": "gepeinigt",
    "gepeinigteres": "gepeinigt",
    "gepeinigtes": "gepeinigt",
    "gepeinigteste": "gepeinigt",
    "gepeinigtestem": "gepeinigt",
    "gepeinigtesten": "gepeinigt",
    "gepeinigtester": "gepeinigt",
    "gepeinigtestes": "gepeinigt",
    "gepeitscht": "peitschen",
    "gepeitschte": "gepeitscht",
    "gepeitschtem": "gepeitscht",
    "gepeitschten": "gepeitscht",
    "gepeitschter": "gepeitscht",
    "gepeitschtes": "gepeitscht",
    "gepellt": "pellen",
    "gepellte": "gepellt",
    "gepelltem": "gepellt",
    "gepellten": "gepellt",
    "gepellter": "gepellt",
    "gepelltere": "gepellt",
    "gepellterem": "gepellt",
    "gepellteren": "gepellt",
    "gepellterer": "gepellt",
    "gepellteres": "gepellt",
    "gepelltes": "gepellt",
    "gepellteste": "gepellt",
    "gepelltestem": "gepellt",
    "gepelltesten": "gepellt",
    "gepelltester": "gepellt",
    "gepelltestes": "gepellt",
    "gependelt": "pendeln",
    "gependelte": "gependelt",
    "gependeltem": "gependelt",
    "gependelten": "gependelt",
    "gependelter": "gependelt",
    "gependeltes": "gependelt",
    "gepennt": "pennen",
    "gepennte": "gepennt",
    "gepenntem": "gepennt",
    "gepennten": "gepennt",
    "gepennter": "gepennt",
    "gepenntes": "gepennt",
    "geperlt": "perlen",
    "geperlte": "geperlt",
    "geperltem": "geperlt",
    "geperlten": "geperlt",
    "geperlter": "geperlt",
    "geperltes": "geperlt",
    "gepest": "pesen",
    "gepeste": "gepest",
    "gepestem": "gepest",
    "gepesten": "gepest",
    "gepester": "gepest",
    "gepestes": "gepest",
    "gepetzt": "petzen",
    "gepetzte": "gepetzt",
    "gepetztem": "gepetzt",
    "gepetzten": "gepetzt",
    "gepetzter": "gepetzt",
    "gepetztes": "gepetzt",
    "gepfeffert": "pfeffern",
    "gepfefferte": "gepfeffert",
    "gepfeffertem": "gepfeffert",
    "gepfefferten": "gepfeffert",
    "gepfefferter": "gepfeffert",
    "gepfeffertere": "gepfeffert",
    "gepfefferterem": "gepfeffert",
    "gepfefferteren": "gepfeffert",
    "gepfefferterer": "gepfeffert",
    "gepfefferteres": "gepfeffert",
    "gepfeffertes": "gepfeffert",
    "gepfefferteste": "gepfeffert",
    "gepfeffertestem": "gepfeffert",
    "gepfeffertesten": "gepfeffert",
    "gepfeffertester": "gepfeffert",
    "gepfeffertestes": "gepfeffert",
    "gepfercht": "pferchen",
    "gepferchte": "gepfercht",
    "gepferchtem": "gepfercht",
    "gepferchten": "gepfercht",
    "gepferchter": "gepfercht",
    "gepferchtere": "gepfercht",
    "gepferchterem": "gepfercht",
    "gepferchteren": "gepfercht",
    "gepferchterer": "gepfercht",
    "gepferchteres": "gepfercht",
    "gepferchtes": "gepfercht",
    "gepferchteste": "gepfercht",
    "gepferchtestem": "gepfercht",
    "gepferchtesten": "gepfercht",
    "gepferchtester": "gepfercht",
    "gepferchtestes": "gepfercht",
    "gepfiffen": "pfeifen",
    "gepfiffene": "gepfiffen",
    "gepfiffenem": "gepfiffen",
    "gepfiffenen": "gepfiffen",
    "gepfiffener": "gepfiffen",
    "gepfiffenes": "gepfiffen",
    "gepflanzt": "pflanzen",
    "gepflanzte": "gepflanzt",
    "gepflanztem": "gepflanzt",
    "gepflanzten": "gepflanzt",
    "gepflanzter": "gepflanzt",
    "gepflanztes": "gepflanzt",
    "gepflaumt": "pflaumen",
    "gepflaumte": "gepflaumt",
    "gepflaumtem": "gepflaumt",
    "gepflaumten": "gepflaumt",
    "gepflaumter": "gepflaumt",
    "gepflaumtes": "gepflaumt",
    "gepflegt": "pflegen",
    "gepflegte": "gepflegt",
    "gepflegtem": "gepflegt",
    "gepflegten": "gepflegt",
    "gepflegter": "gepflegt",
    "gepflegtere": "gepflegt",
    "gepflegterem": "gepflegt",
    "gepflegteren": "gepflegt",
    "gepflegterer": "gepflegt",
    "gepflegteres": "gepflegt",
    "gepflegtes": "gepflegt",
    "gepflegteste": "gepflegt",
    "gepflegtestem": "gepflegt",
    "gepflegtesten": "gepflegt",
    "gepflegtester": "gepflegt",
    "gepflegtestes": "gepflegt",
    "gepflichtet": "pflichten",
    "gepflichtete": "gepflichtet",
    "gepflichtetem": "gepflichtet",
    "gepflichteten": "gepflichtet",
    "gepflichteter": "gepflichtet",
    "gepflichtetes": "gepflichtet",
    "gepflückt": "pflücken",
    "gepflückte": "gepflückt",
    "gepflücktem": "gepflückt",
    "gepflückten": "gepflückt",
    "gepflückter": "gepflückt",
    "gepflücktes": "gepflückt",
    "gepflügt": "pflügen",
    "gepflügte": "gepflügt",
    "gepflügtem": "gepflügt",
    "gepflügten": "gepflügt",
    "gepflügter": "gepflügt",
    "gepflügtes": "gepflügt",
    "gepfropft": "pfropfen",
    "gepfropfte": "gepfropft",
    "gepfropftem": "gepfropft",
    "gepfropften": "gepfropft",
    "gepfropfter": "gepfropft",
    "gepfropftes": "gepfropft",
    "gepfuscht": "pfuschen",
    "gepfuschte": "gepfuscht",
    "gepfuschtem": "gepfuscht",
    "gepfuschten": "gepfuscht",
    "gepfuschter": "gepfuscht",
    "gepfuschtere": "gepfuscht",
    "gepfuschterem": "gepfuscht",
    "gepfuschteren": "gepfuscht",
    "gepfuschterer": "gepfuscht",
    "gepfuschteres": "gepfuscht",
    "gepfuschtes": "gepfuscht",
    "gepfuschteste": "gepfuscht",
    "gepfuschtestem": "gepfuscht",
    "gepfuschtesten": "gepfuscht",
    "gepfuschtester": "gepfuscht",
    "gepfuschtestes": "gepfuscht",
    "gepfändet": "pfänden",
    "gepfändete": "gepfändet",
    "gepfändetem": "gepfändet",
    "gepfändeten": "gepfändet",
    "gepfändeter": "gepfändet",
    "gepfändetes": "gepfändet",
    "gepichelt": "picheln",
    "gepichelte": "gepichelt",
    "gepicheltem": "gepichelt",
    "gepichelten": "gepichelt",
    "gepichelter": "gepichelt",
    "gepicheltes": "gepichelt",
    "gepickt": "picken",
    "gepickte": "gepickt",
    "gepicktem": "gepickt",
    "gepickten": "gepickt",
    "gepickter": "gepickt",
    "gepicktes": "gepickt",
    "gepiepst": "piepsen",
    "gepiepste": "gepiepst",
    "gepiepstem": "gepiepst",
    "gepiepsten": "gepiepst",
    "gepiepster": "gepiepst",
    "gepiepstes": "gepiepst",
    "gepiept": "piepen",
    "gepiepte": "gepiept",
    "gepieptem": "gepiept",
    "gepiepten": "gepiept",
    "gepiepter": "gepiept",
    "gepieptes": "gepiept",
    "gepieselt": "pieseln",
    "gepieselte": "gepieselt",
    "gepieseltem": "gepieselt",
    "gepieselten": "gepieselt",
    "gepieselter": "gepieselt",
    "gepieseltes": "gepieselt",
    "gepilgert": "pilgern",
    "gepilgerte": "gepilgert",
    "gepilgertem": "gepilgert",
    "gepilgerten": "gepilgert",
    "gepilgerter": "gepilgert",
    "gepilgertes": "gepilgert",
    "gepinkelt": "pinkeln",
    "gepinkelte": "gepinkelt",
    "gepinkeltem": "gepinkelt",
    "gepinkelten": "gepinkelt",
    "gepinkelter": "gepinkelt",
    "gepinkeltes": "gepinkelt",
    "gepinnt": "pinnen",
    "gepinnte": "gepinnt",
    "gepinntem": "gepinnt",
    "gepinnten": "gepinnt",
    "gepinnter": "gepinnt",
    "gepinntes": "gepinnt",
    "gepinselt": "pinseln",
    "gepinselte": "gepinselt",
    "gepinseltem": "gepinselt",
    "gepinselten": "gepinselt",
    "gepinselter": "gepinselt",
    "gepinseltes": "gepinselt",
    "gepirscht": "pirschen",
    "gepirschte": "gepirscht",
    "gepirschtem": "gepirscht",
    "gepirschten": "gepirscht",
    "gepirschter": "gepirscht",
    "gepirschtes": "gepirscht",
    "gepißt": "pissen",
    "gepißte": "gepißt",
    "gepißtem": "gepißt",
    "gepißten": "gepißt",
    "gepißter": "gepißt",
    "gepißtes": "gepißt",
    "geplagt": "plagen",
    "geplagte": "geplagt",
    "geplagtem": "geplagt",
    "geplagten": "geplagt",
    "geplagter": "geplagt",
    "geplagtere": "geplagt",
    "geplagterem": "geplagt",
    "geplagteren": "geplagt",
    "geplagterer": "geplagt",
    "geplagteres": "geplagt",
    "geplagtes": "geplagt",
    "geplagteste": "geplagt",
    "geplagtestem": "geplagt",
    "geplagtesten": "geplagt",
    "geplagtester": "geplagt",
    "geplagtestes": "geplagt",
    "geplanscht": "planschen",
    "geplanschte": "geplanscht",
    "geplanschtem": "geplanscht",
    "geplanschten": "geplanscht",
    "geplanschter": "geplanscht",
    "geplanschtes": "geplanscht",
    "geplant": "planen",
    "geplante": "geplant",
    "geplantem": "geplant",
    "geplanten": "geplant",
    "geplanter": "geplant",
    "geplantere": "geplant",
    "geplanterem": "geplant",
    "geplanteren": "geplant",
    "geplanterer": "geplant",
    "geplanteres": "geplant",
    "geplantes": "geplant",
    "geplanteste": "geplant",
    "geplantestem": "geplant",
    "geplantesten": "geplant",
    "geplantester": "geplant",
    "geplantestes": "geplant",
    "geplappert": "plappern",
    "geplapperte": "geplappert",
    "geplappertem": "geplappert",
    "geplapperten": "geplappert",
    "geplapperter": "geplappert",
    "geplappertes": "geplappert",
    "geplatscht": "platschen",
    "geplatschte": "geplatscht",
    "geplatschtem": "geplatscht",
    "geplatschten": "geplatscht",
    "geplatschter": "geplatscht",
    "geplatschtes": "geplatscht",
    "geplatzt": "platzen",
    "geplatzte": "geplatzt",
    "geplatztem": "geplatzt",
    "geplatzten": "geplatzt",
    "geplatzter": "geplatzt",
    "geplatztes": "geplatzt",
    "geplaudert": "plaudern",
    "geplauderte": "geplaudert",
    "geplaudertem": "geplaudert",
    "geplauderten": "geplaudert",
    "geplauderter": "geplaudert",
    "geplaudertes": "geplaudert",
    "geplauscht": "plauschen",
    "geplauschte": "geplauscht",
    "geplauschtem": "geplauscht",
    "geplauschten": "geplauscht",
    "geplauschter": "geplauscht",
    "geplauschtes": "geplauscht",
    "geplempert": "plempern",
    "geplemperte": "geplempert",
    "geplempertem": "geplempert",
    "geplemperten": "geplempert",
    "geplemperter": "geplempert",
    "geplempertes": "geplempert",
    "geplottet": "plotten",
    "geplottete": "geplottet",
    "geplottetem": "geplottet",
    "geplotteten": "geplottet",
    "geplotteter": "geplottet",
    "geplottetes": "geplottet",
    "geplumpst": "plumpsen",
    "geplumpste": "geplumpst",
    "geplumpstem": "geplumpst",
    "geplumpsten": "geplumpst",
    "geplumpster": "geplumpst",
    "geplumpstes": "geplumpst",
    "geplustert": "plustern",
    "geplusterte": "geplustert",
    "geplustertem": "geplustert",
    "geplusterten": "geplustert",
    "geplusterter": "geplustert",
    "geplustertes": "geplustert",
    "geplätschert": "plätschern",
    "geplätscherte": "geplätschert",
    "geplätschertem": "geplätschert",
    "geplätscherten": "geplätschert",
    "geplätscherter": "geplätschert",
    "geplätschertes": "geplätschert",
    "geplättet": "plätten",
    "geplättete": "geplättet",
    "geplättetem": "geplättet",
    "geplätteten": "geplättet",
    "geplätteter": "geplättet",
    "geplättetere": "geplättet",
    "geplätteterem": "geplättet",
    "geplätteteren": "geplättet",
    "geplätteterer": "geplättet",
    "geplätteteres": "geplättet",
    "geplättetes": "geplättet",
    "geplätteteste": "geplättet",
    "geplättetestem": "geplättet",
    "geplättetesten": "geplättet",
    "geplättetester": "geplättet",
    "geplättetestes": "geplättet",
    "geplündert": "plündern",
    "geplünderte": "geplündert",
    "geplündertem": "geplündert",
    "geplünderten": "geplündert",
    "geplünderter": "geplündert",
    "geplündertere": "geplündert",
    "geplünderterem": "geplündert",
    "geplünderteren": "geplündert",
    "geplünderterer": "geplündert",
    "geplünderteres": "geplündert",
    "geplündertes": "geplündert",
    "geplünderteste": "geplündert",
    "geplündertestem": "geplündert",
    "geplündertesten": "geplündert",
    "geplündertester": "geplündert",
    "geplündertestes": "geplündert",
    "gepocht": "pochen",
    "gepochte": "gepocht",
    "gepochtem": "gepocht",
    "gepochten": "gepocht",
    "gepochter": "gepocht",
    "gepochtes": "gepocht",
    "gepokert": "pokern",
    "gepokerte": "gepokert",
    "gepokertem": "gepokert",
    "gepokerten": "gepokert",
    "gepokerter": "gepokert",
    "gepokertes": "gepokert",
    "gepolstert": "polstern",
    "gepolsterte": "gepolstert",
    "gepolstertem": "gepolstert",
    "gepolsterten": "gepolstert",
    "gepolsterter": "gepolstert",
    "gepolstertere": "gepolstert",
    "gepolsterterem": "gepolstert",
    "gepolsterteren": "gepolstert",
    "gepolsterterer": "gepolstert",
    "gepolsterteres": "gepolstert",
    "gepolstertes": "gepolstert",
    "gepolsterteste": "gepolstert",
    "gepolstertestem": "gepolstert",
    "gepolstertesten": "gepolstert",
    "gepolstertester": "gepolstert",
    "gepolstertestes": "gepolstert",
    "gepolt": "polen",
    "gepolte": "gepolt",
    "gepoltem": "gepolt",
    "gepolten": "gepolt",
    "gepolter": "gepolt",
    "gepoltert": "poltern",
    "gepolterte": "gepoltert",
    "gepoltertem": "gepoltert",
    "gepolterten": "gepoltert",
    "gepolterter": "gepoltert",
    "gepoltertes": "gepoltert",
    "gepoltes": "gepolt",
    "gepopelt": "popeln",
    "gepopelte": "gepopelt",
    "gepopeltem": "gepopelt",
    "gepopelten": "gepopelt",
    "gepopelter": "gepopelt",
    "gepopeltes": "gepopelt",
    "gepoppt": "poppen",
    "gepoppte": "gepoppt",
    "gepopptem": "gepoppt",
    "gepoppten": "gepoppt",
    "gepoppter": "gepoppt",
    "gepopptes": "gepoppt",
    "gepowert": "powern",
    "gepowerte": "gepowert",
    "gepowertem": "gepowert",
    "gepowerten": "gepowert",
    "gepowerter": "gepowert",
    "gepowertere": "gepowert",
    "gepowerterem": "gepowert",
    "gepowerteren": "gepowert",
    "gepowerterer": "gepowert",
    "gepowerteres": "gepowert",
    "gepowertes": "gepowert",
    "gepowerteste": "gepowert",
    "gepowertestem": "gepowert",
    "gepowertesten": "gepowert",
    "gepowertester": "gepowert",
    "gepowertestes": "gepowert",
    "geprahlt": "prahlen",
    "geprahlte": "geprahlt",
    "geprahltem": "geprahlt",
    "geprahlten": "geprahlt",
    "geprahlter": "geprahlt",
    "geprahltes": "geprahlt",
    "geprallt": "prallen",
    "geprallte": "geprallt",
    "gepralltem": "geprallt",
    "geprallten": "geprallt",
    "geprallter": "geprallt",
    "gepralltes": "geprallt",
    "geprangert": "prangern",
    "geprangerte": "geprangert",
    "geprangertem": "geprangert",
    "geprangerten": "geprangert",
    "geprangerter": "geprangert",
    "geprangertere": "geprangert",
    "geprangerterem": "geprangert",
    "geprangerteren": "geprangert",
    "geprangerterer": "geprangert",
    "geprangerteres": "geprangert",
    "geprangertes": "geprangert",
    "geprangerteste": "geprangert",
    "geprangertestem": "geprangert",
    "geprangertesten": "geprangert",
    "geprangertester": "geprangert",
    "geprangertestes": "geprangert",
    "geprangt": "prangen",
    "geprangte": "geprangt",
    "geprangtem": "geprangt",
    "geprangten": "geprangt",
    "geprangter": "geprangt",
    "geprangtes": "geprangt",
    "geprasselt": "prasseln",
    "geprasselte": "geprasselt",
    "geprasseltem": "geprasselt",
    "geprasselten": "geprasselt",
    "geprasselter": "geprasselt",
    "geprasseltes": "geprasselt",
    "gepredigt": "predigen",
    "gepredigte": "gepredigt",
    "gepredigtem": "gepredigt",
    "gepredigten": "gepredigt",
    "gepredigter": "gepredigt",
    "gepredigtes": "gepredigt",
    "geprellt": "prellen",
    "geprellte": "geprellt",
    "geprelltem": "geprellt",
    "geprellten": "geprellt",
    "geprellter": "geprellt",
    "geprelltere": "geprellt",
    "geprellterem": "geprellt",
    "geprellteren": "geprellt",
    "geprellterer": "geprellt",
    "geprellteres": "geprellt",
    "geprelltes": "geprellt",
    "geprellteste": "geprellt",
    "geprelltestem": "geprellt",
    "geprelltesten": "geprellt",
    "geprelltester": "geprellt",
    "geprelltestes": "geprellt",
    "geprescht": "preschen",
    "gepreschte": "geprescht",
    "gepreschtem": "geprescht",
    "gepreschten": "geprescht",
    "gepreschter": "geprescht",
    "gepreschtes": "geprescht",
    "gepreßt": "pressen",
    "gepreßte": "gepreßt",
    "gepreßtem": "gepreßt",
    "gepreßten": "gepreßt",
    "gepreßter": "gepreßt",
    "gepreßtes": "gepreßt",
    "gepriesen": "preisen",
    "gepriesene": "gepriesen",
    "gepriesenem": "gepriesen",
    "gepriesenen": "gepriesen",
    "gepriesener": "gepriesen",
    "gepriesenere": "gepriesen",
    "gepriesenerem": "gepriesen",
    "geprieseneren": "gepriesen",
    "gepriesenerer": "gepriesen",
    "geprieseneres": "gepriesen",
    "gepriesenes": "gepriesen",
    "gepriesenste": "gepriesen",
    "gepriesenstem": "gepriesen",
    "gepriesensten": "gepriesen",
    "gepriesenster": "gepriesen",
    "gepriesenstes": "gepriesen",
    "gepritscht": "pritschen",
    "gepritschte": "gepritscht",
    "gepritschtem": "gepritscht",
    "gepritschten": "gepritscht",
    "gepritschter": "gepritscht",
    "gepritschtes": "gepritscht",
    "geprobt": "proben",
    "geprobte": "geprobt",
    "geprobtem": "geprobt",
    "geprobten": "geprobt",
    "geprobter": "geprobt",
    "geprobtere": "geprobt",
    "geprobterem": "geprobt",
    "geprobteren": "geprobt",
    "geprobterer": "geprobt",
    "geprobteres": "geprobt",
    "geprobtes": "geprobt",
    "geprobteste": "geprobt",
    "geprobtestem": "geprobt",
    "geprobtesten": "geprobt",
    "geprobtester": "geprobt",
    "geprobtestes": "geprobt",
    "geprostet": "prosten",
    "geprostete": "geprostet",
    "geprostetem": "geprostet",
    "geprosteten": "geprostet",
    "geprosteter": "geprostet",
    "geprostetes": "geprostet",
    "geprotzt": "protzen",
    "geprotzte": "geprotzt",
    "geprotztem": "geprotzt",
    "geprotzten": "geprotzt",
    "geprotzter": "geprotzt",
    "geprotztere": "geprotzt",
    "geprotzterem": "geprotzt",
    "geprotzteren": "geprotzt",
    "geprotzterer": "geprotzt",
    "geprotzteres": "geprotzt",
    "geprotztes": "geprotzt",
    "geprotzteste": "geprotzt",
    "geprotztestem": "geprotzt",
    "geprotztesten": "geprotzt",
    "geprotztester": "geprotzt",
    "geprotztestes": "geprotzt",
    "geprustet": "prusten",
    "geprustete": "geprustet",
    "geprustetem": "geprustet",
    "geprusteten": "geprustet",
    "geprusteter": "geprustet",
    "geprustetes": "geprustet",
    "geprägt": "prägen",
    "geprägte": "geprägt",
    "geprägtem": "geprägt",
    "geprägten": "geprägt",
    "geprägter": "geprägt",
    "geprägtere": "geprägt",
    "geprägterem": "geprägt",
    "geprägteren": "geprägt",
    "geprägterer": "geprägt",
    "geprägteres": "geprägt",
    "geprägtes": "geprägt",
    "geprägteste": "geprägt",
    "geprägtestem": "geprägt",
    "geprägtesten": "geprägt",
    "geprägtester": "geprägt",
    "geprägtestes": "geprägt",
    "geprüft": "prüfen",
    "geprüfte": "geprüft",
    "geprüftem": "geprüft",
    "geprüften": "geprüft",
    "geprüfter": "geprüft",
    "geprüftere": "geprüft",
    "geprüfterem": "geprüft",
    "geprüfteren": "geprüft",
    "geprüfterer": "geprüft",
    "geprüfteres": "geprüft",
    "geprüftes": "geprüft",
    "geprüfteste": "geprüft",
    "geprüftestem": "geprüft",
    "geprüftesten": "geprüft",
    "geprüftester": "geprüft",
    "geprüftestes": "geprüft",
    "geprügelt": "prügeln",
    "geprügelte": "geprügelt",
    "geprügeltem": "geprügelt",
    "geprügelten": "geprügelt",
    "geprügelter": "geprügelt",
    "geprügeltes": "geprügelt",
    "gepudert": "pudern",
    "gepuderte": "gepudert",
    "gepudertem": "gepudert",
    "gepuderten": "gepudert",
    "gepuderter": "gepudert",
    "gepudertere": "gepudert",
    "gepuderterem": "gepudert",
    "gepuderteren": "gepudert",
    "gepuderterer": "gepudert",
    "gepuderteres": "gepudert",
    "gepudertes": "gepudert",
    "gepuderteste": "gepudert",
    "gepudertestem": "gepudert",
    "gepudertesten": "gepudert",
    "gepudertester": "gepudert",
    "gepudertestes": "gepudert",
    "gepufft": "puffen",
    "gepuffte": "gepufft",
    "gepufftem": "gepufft",
    "gepufften": "gepufft",
    "gepuffter": "gepufft",
    "gepufftes": "gepufft",
    "gepult": "pulen",
    "gepulte": "gepult",
    "gepultem": "gepult",
    "gepulten": "gepult",
    "gepulter": "gepult",
    "gepultes": "gepult",
    "gepulvert": "pulvern",
    "gepulverte": "gepulvert",
    "gepulvertem": "gepulvert",
    "gepulverten": "gepulvert",
    "gepulverter": "gepulvert",
    "gepulvertes": "gepulvert",
    "gepumpt": "pumpen",
    "gepumpte": "gepumpt",
    "gepumptem": "gepumpt",
    "gepumpten": "gepumpt",
    "gepumpter": "gepumpt",
    "gepumptes": "gepumpt",
    "gepunktet": "punkten",
    "gepunktete": "gepunktet",
    "gepunktetem": "gepunktet",
    "gepunkteten": "gepunktet",
    "gepunkteter": "gepunktet",
    "gepunktetes": "gepunktet",
    "gepupt": "pupen",
    "gepupte": "gepupt",
    "gepuptem": "gepupt",
    "gepupten": "gepupt",
    "gepupter": "gepupt",
    "gepuptes": "gepupt",
    "gepurzelt": "purzeln",
    "gepurzelte": "gepurzelt",
    "gepurzeltem": "gepurzelt",
    "gepurzelten": "gepurzelt",
    "gepurzelter": "gepurzelt",
    "gepurzeltes": "gepurzelt",
    "gepuscht": "puschen",
    "gepuschte": "gepuscht",
    "gepuschtem": "gepuscht",
    "gepuschten": "gepuscht",
    "gepuschter": "gepuscht",
    "gepuschtere": "gepuscht",
    "gepuschterem": "gepuscht",
    "gepuschteren": "gepuscht",
    "gepuschterer": "gepuscht",
    "gepuschteres": "gepuscht",
    "gepuschtes": "gepuscht",
    "gepuschteste": "gepuscht",
    "gepuschtestem": "gepuscht",
    "gepuschtesten": "gepuscht",
    "gepuschtester": "gepuscht",
    "gepuschtestes": "gepuscht",
    "gepustet": "pusten",
    "gepustete": "gepustet",
    "gepustetem": "gepustet",
    "gepusteten": "gepustet",
    "gepusteter": "gepustet",
    "gepustetes": "gepustet",
    "geputscht": "putschen",
    "geputschte": "geputscht",
    "geputschtem": "geputscht",
    "geputschten": "geputscht",
    "geputschter": "geputscht",
    "geputschtes": "geputscht",
    "geputtet": "putten",
    "geputtete": "geputtet",
    "geputtetem": "geputtet",
    "geputteten": "geputtet",
    "geputteter": "geputtet",
    "geputtetes": "geputtet",
    "geputzt": "putzen",
    "geputzte": "geputzt",
    "geputztem": "geputzt",
    "geputzten": "geputzt",
    "geputzter": "geputzt",
    "geputztere": "geputzt",
    "geputzterem": "geputzt",
    "geputzteren": "geputzt",
    "geputzterer": "geputzt",
    "geputzteres": "geputzt",
    "geputztes": "geputzt",
    "geputzteste": "geputzt",
    "geputztestem": "geputzt",
    "geputztesten": "geputzt",
    "geputztester": "geputzt",
    "geputztestes": "geputzt",
    "gepäppelt": "päppeln",
    "gepäppelte": "gepäppelt",
    "gepäppeltem": "gepäppelt",
    "gepäppelten": "gepäppelt",
    "gepäppelter": "gepäppelt",
    "gepäppeltes": "gepäppelt",
    "gepöbelt": "pöbeln",
    "gepöbelte": "gepöbelt",
    "gepöbeltem": "gepöbelt",
    "gepöbelten": "gepöbelt",
    "gepöbelter": "gepöbelt",
    "gepöbeltes": "gepöbelt",
    "gepökelt": "pökeln",
    "gepökelte": "gepökelt",
    "gepökeltem": "gepökelt",
    "gepökelten": "gepökelt",
    "gepökelter": "gepökelt",
    "gepökeltes": "gepökelt",
    "gequakt": "quaken",
    "gequakte": "gequakt",
    "gequaktem": "gequakt",
    "gequakten": "gequakt",
    "gequakter": "gequakt",
    "gequaktes": "gequakt",
    "gequalmt": "qualmen",
    "gequalmte": "gequalmt",
    "gequalmtem": "gequalmt",
    "gequalmten": "gequalmt",
    "gequalmter": "gequalmt",
    "gequalmtes": "gequalmt",
    "gequarzt": "quarzen",
    "gequarzte": "gequarzt",
    "gequarztem": "gequarzt",
    "gequarzten": "gequarzt",
    "gequarzter": "gequarzt",
    "gequarztes": "gequarzt",
    "gequasselt": "quasseln",
    "gequasselte": "gequasselt",
    "gequasseltem": "gequasselt",
    "gequasselten": "gequasselt",
    "gequasselter": "gequasselt",
    "gequasseltes": "gequasselt",
    "gequatscht": "quatschen",
    "gequatschte": "gequatscht",
    "gequatschtem": "gequatscht",
    "gequatschten": "gequatscht",
    "gequatschter": "gequatscht",
    "gequatschtes": "gequatscht",
    "gequellt": "quellen",
    "gequellte": "gequellt",
    "gequelltem": "gequellt",
    "gequellten": "gequellt",
    "gequellter": "gequellt",
    "gequelltes": "gequellt",
    "gequengelt": "quengeln",
    "gequengelte": "gequengelt",
    "gequengeltem": "gequengelt",
    "gequengelten": "gequengelt",
    "gequengelter": "gequengelt",
    "gequengeltes": "gequengelt",
    "gequetscht": "quetschen",
    "gequetschte": "gequetscht",
    "gequetschtem": "gequetscht",
    "gequetschten": "gequetscht",
    "gequetschter": "gequetscht",
    "gequetschtere": "gequetscht",
    "gequetschterem": "gequetscht",
    "gequetschteren": "gequetscht",
    "gequetschterer": "gequetscht",
    "gequetschteres": "gequetscht",
    "gequetschtes": "gequetscht",
    "gequetschteste": "gequetscht",
    "gequetschtestem": "gequetscht",
    "gequetschtesten": "gequetscht",
    "gequetschtester": "gequetscht",
    "gequetschtestes": "gequetscht",
    "gequieckt": "quiecken",
    "gequieckte": "gequieckt",
    "gequiecktem": "gequieckt",
    "gequieckten": "gequieckt",
    "gequieckter": "gequieckt",
    "gequiecktes": "gequieckt",
    "gequietscht": "quietschen",
    "gequietschte": "gequietscht",
    "gequietschtem": "gequietscht",
    "gequietschten": "gequietscht",
    "gequietschter": "gequietscht",
    "gequietschtes": "gequietscht",
    "gequirlt": "quirlen",
    "gequirlte": "gequirlt",
    "gequirltem": "gequirlt",
    "gequirlten": "gequirlt",
    "gequirlter": "gequirlt",
    "gequirltes": "gequirlt",
    "gequollen": "quellen",
    "gequollene": "gequollen",
    "gequollenem": "gequollen",
    "gequollenen": "gequollen",
    "gequollener": "gequollen",
    "gequollenere": "gequollen",
    "gequollenerem": "gequollen",
    "gequolleneren": "gequollen",
    "gequollenerer": "gequollen",
    "gequolleneres": "gequollen",
    "gequollenes": "gequollen",
    "gequollenste": "gequollen",
    "gequollenstem": "gequollen",
    "gequollensten": "gequollen",
    "gequollenster": "gequollen",
    "gequollenstes": "gequollen",
    "gequält": "quälen",
    "gequälte": "gequält",
    "gequältem": "gequält",
    "gequälten": "gequält",
    "gequälter": "gequält",
    "gequältere": "gequält",
    "gequälterem": "gequält",
    "gequälteren": "gequält",
    "gequälterer": "gequält",
    "gequälteres": "gequält",
    "gequältes": "gequält",
    "gequälteste": "gequält",
    "gequältestem": "gequält",
    "gequältesten": "gequält",
    "gequältester": "gequält",
    "gequältestes": "gequält",
    "geradebiege": "geradebiegen",
    "geradebiegend": "geradebiegen",
    "geradebiegende": "geradebiegend",
    "geradebiegendem": "geradebiegend",
    "geradebiegenden": "geradebiegend",
    "geradebiegender": "geradebiegend",
    "geradebiegendes": "geradebiegend",
    "geradebiegest": "geradebiegen",
    "geradebieget": "geradebiegen",
    "geradebiegst": "geradebiegen",
    "geradebiegt": "geradebiegen",
    "geradebog": "geradebiegen",
    "geradebogen": "geradebiegen",
    "geradebogst": "geradebiegen",
    "geradebogt": "geradebiegen",
    "geradeböge": "geradebiegen",
    "geradebögen": "geradebiegen",
    "geradebögest": "geradebiegen",
    "geradeböget": "geradebiegen",
    "geradegebogen": "geradebiegen",
    "geradegebogene": "geradegebogen",
    "geradegebogenem": "geradegebogen",
    "geradegebogenen": "geradegebogen",
    "geradegebogener": "geradegebogen",
    "geradegebogenere": "geradegebogen",
    "geradegebogenerem": "geradegebogen",
    "geradegebogeneren": "geradegebogen",
    "geradegebogenerer": "geradegebogen",
    "geradegebogeneres": "geradegebogen",
    "geradegebogenes": "geradegebogen",
    "geradegebogenste": "geradegebogen",
    "geradegebogenstem": "geradegebogen",
    "geradegebogensten": "geradegebogen",
    "geradegebogenster": "geradegebogen",
    "geradegebogenstes": "geradegebogen",
    "geradegerichtet": "geraderichten",
    "geradegerichtete": "geradegerichtet",
    "geradegerichtetem": "geradegerichtet",
    "geradegerichteten": "geradegerichtet",
    "geradegerichteter": "geradegerichtet",
    "geradegerichtetes": "geradegerichtet",
    "geradegesessen": "geradesitzen",
    "geradegesessene": "geradegesessen",
    "geradegesessenem": "geradegesessen",
    "geradegesessenen": "geradegesessen",
    "geradegesessener": "geradegesessen",
    "geradegesessenes": "geradegesessen",
    "geradegesetzt": "geradesetzen",
    "geradegesetzte": "geradegesetzt",
    "geradegesetztem": "geradegesetzt",
    "geradegesetzten": "geradegesetzt",
    "geradegesetzter": "geradegesetzt",
    "geradegesetztes": "geradegesetzt",
    "geradelt": "radeln",
    "geradelte": "geradelt",
    "geradeltem": "geradelt",
    "geradelten": "geradelt",
    "geradelter": "geradelt",
    "geradeltes": "geradelt",
    "geradem": "gerade",
    "geraden": "gerade",
    "gerader": "gerade",
    "geradere": "gerade",
    "geraderem": "gerade",
    "geraderen": "gerade",
    "geraderer": "gerade",
    "geraderes": "gerade",
    "geraderichte": "geraderichten",
    "geraderichtend": "geraderichten",
    "geraderichtende": "geraderichtend",
    "geraderichtendem": "geraderichtend",
    "geraderichtenden": "geraderichtend",
    "geraderichtender": "geraderichtend",
    "geraderichtendes": "geraderichtend",
    "geraderichtest": "geraderichten",
    "geraderichtet": "geraderichten",
    "geraderichtete": "geraderichten",
    "geraderichteten": "geraderichten",
    "geraderichtetest": "geraderichten",
    "geraderichtetet": "geraderichten",
    "gerades": "gerade",
    "geradesaß": "geradesitzen",
    "geradesaßen": "geradesitzen",
    "geradesaßt": "geradesitzen",
    "geradesetze": "geradesetzen",
    "geradesetzend": "geradesetzen",
    "geradesetzende": "geradesetzend",
    "geradesetzendem": "geradesetzend",
    "geradesetzenden": "geradesetzend",
    "geradesetzender": "geradesetzend",
    "geradesetzendes": "geradesetzend",
    "geradesetzest": "geradesetzen",
    "geradesetzet": "geradesetzen",
    "geradesetzt": "geradesetzen",
    "geradesetzte": "geradesetzen",
    "geradesetzten": "geradesetzen",
    "geradesetztest": "geradesetzen",
    "geradesetztet": "geradesetzen",
    "geradesitze": "geradesitzen",
    "geradesitzend": "geradesitzen",
    "geradesitzende": "geradesitzend",
    "geradesitzendem": "geradesitzend",
    "geradesitzenden": "geradesitzend",
    "geradesitzender": "geradesitzend",
    "geradesitzendes": "geradesitzend",
    "geradesitzest": "geradesitzen",
    "geradesitzet": "geradesitzen",
    "geradesitzt": "geradesitzen",
    "geradeste": "gerade",
    "geradestem": "gerade",
    "geradesten": "gerade",
    "geradester": "gerade",
    "geradestes": "gerade",
    "geradesäße": "geradesitzen",
    "geradesäßen": "geradesitzen",
    "geradesäßest": "geradesitzen",
    "geradesäßet": "geradesitzen",
    "geradezubiegen": "geradebiegen",
    "geradezurichten": "geraderichten",
    "geradezusetzen": "geradesetzen",
    "geradezusitzen": "geradesitzen",
    "gerafft": "raffen",
    "geraffte": "gerafft",
    "gerafftem": "gerafft",
    "gerafften": "gerafft",
    "geraffter": "gerafft",
    "gerafftere": "gerafft",
    "geraffterem": "gerafft",
    "geraffteren": "gerafft",
    "geraffterer": "gerafft",
    "geraffteres": "gerafft",
    "gerafftes": "gerafft",
    "geraffteste": "gerafft",
    "gerafftestem": "gerafft",
    "gerafftesten": "gerafft",
    "gerafftester": "gerafft",
    "gerafftestes": "gerafft",
    "geragt": "ragen",
    "geragte": "geragt",
    "geragtem": "geragt",
    "geragten": "geragt",
    "geragter": "geragt",
    "geragtes": "geragt",
    "gerahmt": "rahmen",
    "gerahmte": "gerahmt",
    "gerahmtem": "gerahmt",
    "gerahmten": "gerahmt",
    "gerahmter": "gerahmt",
    "gerahmtes": "gerahmt",
    "gerammelt": "rammeln",
    "gerammelte": "gerammelt",
    "gerammeltem": "gerammelt",
    "gerammelten": "gerammelt",
    "gerammelter": "gerammelt",
    "gerammeltes": "gerammelt",
    "gerammt": "rammen",
    "gerammte": "gerammt",
    "gerammtem": "gerammt",
    "gerammten": "gerammt",
    "gerammter": "gerammt",
    "gerammtes": "gerammt",
    "geramscht": "ramschen",
    "geramschte": "geramscht",
    "geramschtem": "geramscht",
    "geramschten": "geramscht",
    "geramschter": "geramscht",
    "geramschtes": "geramscht",
    "gerankt": "ranken",
    "gerankte": "gerankt",
    "geranktem": "gerankt",
    "gerankten": "gerankt",
    "gerankter": "gerankt",
    "geranktes": "gerankt",
    "gerann": "gerinnen",
    "gerannen": "gerinnen",
    "gerannst": "gerinnen",
    "gerannt": "rennen",
    "gerannte": "gerannt",
    "geranntem": "gerannt",
    "gerannten": "gerannt",
    "gerannter": "gerannt",
    "geranntes": "gerannt",
    "geranzt": "ranzen",
    "geranzte": "geranzt",
    "geranztem": "geranzt",
    "geranzten": "geranzt",
    "geranzter": "geranzt",
    "geranztes": "geranzt",
    "gerappelt": "rappeln",
    "gerappelte": "gerappelt",
    "gerappeltem": "gerappelt",
    "gerappelten": "gerappelt",
    "gerappelter": "gerappelt",
    "gerappeltes": "gerappelt",
    "geraschelt": "rascheln",
    "geraschelte": "geraschelt",
    "gerascheltem": "geraschelt",
    "geraschelten": "geraschelt",
    "geraschelter": "geraschelt",
    "gerascheltes": "geraschelt",
    "geraspelt": "raspeln",
    "geraspelte": "geraspelt",
    "geraspeltem": "geraspelt",
    "geraspelten": "geraspelt",
    "geraspelter": "geraspelt",
    "geraspeltes": "geraspelt",
    "gerasselt": "rasseln",
    "gerasselte": "gerasselt",
    "gerasseltem": "gerasselt",
    "gerasselten": "gerasselt",
    "gerasselter": "gerasselt",
    "gerasseltes": "gerasselt",
    "gerast": "rasen",
    "geraste": "gerast",
    "gerastem": "gerast",
    "gerasten": "gerast",
    "geraster": "gerast",
    "gerastert": "rastern",
    "gerasterte": "gerastert",
    "gerastertem": "gerastert",
    "gerasterten": "gerastert",
    "gerasterter": "gerastert",
    "gerastertes": "gerastert",
    "gerastes": "gerast",
    "gerastet": "rasten",
    "gerastete": "gerastet",
    "gerastetem": "gerastet",
    "gerasteten": "gerastet",
    "gerasteter": "gerastet",
    "gerastetere": "gerastet",
    "gerasteterem": "gerastet",
    "gerasteteren": "gerastet",
    "gerasteterer": "gerastet",
    "gerasteteres": "gerastet",
    "gerastetes": "gerastet",
    "gerasteteste": "gerastet",
    "gerastetestem": "gerastet",
    "gerastetesten": "gerastet",
    "gerastetester": "gerastet",
    "gerastetestes": "gerastet",
    "gerate": "geraten",
    "geratend": "geraten",
    "geratende": "geratend",
    "geratendem": "geratend",
    "geratenden": "geratend",
    "geratender": "geratend",
    "geratendes": "geratend",
    "geratene": "geraten",
    "geratenem": "geraten",
    "geratenen": "geraten",
    "geratener": "geraten",
    "geratenes": "geraten",
    "geratest": "geraten",
    "geratet": "geraten",
    "gerattert": "rattern",
    "geratterte": "gerattert",
    "gerattertem": "gerattert",
    "geratterten": "gerattert",
    "geratterter": "gerattert",
    "gerattertes": "gerattert",
    "geratzt": "ratzen",
    "geratzte": "geratzt",
    "geratztem": "geratzt",
    "geratzten": "geratzt",
    "geratzter": "geratzt",
    "geratztes": "geratzt",
    "geraubt": "rauben",
    "geraubte": "geraubt",
    "geraubtem": "geraubt",
    "geraubten": "geraubt",
    "geraubter": "geraubt",
    "geraubtes": "geraubt",
    "geraucht": "rauchen",
    "gerauchte": "geraucht",
    "gerauchtem": "geraucht",
    "gerauchten": "geraucht",
    "gerauchter": "geraucht",
    "gerauchtes": "geraucht",
    "gerauft": "raufen",
    "geraufte": "gerauft",
    "gerauftem": "gerauft",
    "gerauften": "gerauft",
    "geraufter": "gerauft",
    "gerauftes": "gerauft",
    "gerauht": "rauhen",
    "gerauhte": "gerauht",
    "gerauhtem": "gerauht",
    "gerauhten": "gerauht",
    "gerauhter": "gerauht",
    "gerauhtes": "gerauht",
    "geraume": "geraum",
    "geraumem": "geraum",
    "geraumen": "geraum",
    "geraumer": "geraum",
    "geraumes": "geraum",
    "geraunt": "raunen",
    "geraunte": "geraunt",
    "gerauntem": "geraunt",
    "geraunten": "geraunt",
    "geraunter": "geraunt",
    "gerauntes": "geraunt",
    "gerauscht": "rauschen",
    "gerauschte": "gerauscht",
    "gerauschtem": "gerauscht",
    "gerauschten": "gerauscht",
    "gerauschter": "gerauscht",
    "gerauschtes": "gerauscht",
    "geraut": "rauen",
    "geraute": "geraut",
    "gerautem": "geraut",
    "gerauten": "geraut",
    "gerauter": "geraut",
    "gerautes": "geraut",
    "gerbe": "gerben",
    "gerbend": "gerben",
    "gerbende": "gerbend",
    "gerbendem": "gerbend",
    "gerbenden": "gerbend",
    "gerbender": "gerbend",
    "gerbendere": "gerbend",
    "gerbenderem": "gerbend",
    "gerbenderen": "gerbend",
    "gerbenderer": "gerbend",
    "gerbenderes": "gerbend",
    "gerbendes": "gerbend",
    "gerbendste": "gerbend",
    "gerbendstem": "gerbend",
    "gerbendsten": "gerbend",
    "gerbendster": "gerbend",
    "gerbendstes": "gerbend",
    "gerbest": "gerben",
    "gerbet": "gerben",
    "gerbst": "gerben",
    "gerbt": "gerben",
    "gerbte": "gerben",
    "gerbten": "gerben",
    "gerbtest": "gerben",
    "gerbtet": "gerben",
    "gerechnet": "rechnen",
    "gerechnete": "gerechnet",
    "gerechnetem": "gerechnet",
    "gerechneten": "gerechnet",
    "gerechneter": "gerechnet",
    "gerechnetes": "gerechnet",
    "gerechte": "gerecht",
    "gerechtem": "gerecht",
    "gerechten": "gerecht",
    "gerechter": "gerecht",
    "gerechtere": "gerecht",
    "gerechterem": "gerecht",
    "gerechteren": "gerecht",
    "gerechterer": "gerecht",
    "gerechteres": "gerecht",
    "gerechtes": "gerecht",
    "gerechteste": "gerecht",
    "gerechtestem": "gerecht",
    "gerechtesten": "gerecht",
    "gerechtester": "gerecht",
    "gerechtestes": "gerecht",
    "gerechtfertigt": "rechtfertigen",
    "gerechtfertigte": "gerechtfertigt",
    "gerechtfertigtem": "gerechtfertigt",
    "gerechtfertigten": "gerechtfertigt",
    "gerechtfertigter": "gerechtfertigt",
    "gerechtfertigtere": "gerechtfertigt",
    "gerechtfertigterem": "gerechtfertigt",
    "gerechtfertigteren": "gerechtfertigt",
    "gerechtfertigterer": "gerechtfertigt",
    "gerechtfertigteres": "gerechtfertigt",
    "gerechtfertigtes": "gerechtfertigt",
    "gerechtfertigteste": "gerechtfertigt",
    "gerechtfertigtestem": "gerechtfertigt",
    "gerechtfertigtesten": "gerechtfertigt",
    "gerechtfertigtester": "gerechtfertigt",
    "gerechtfertigtestes": "gerechtfertigt",
    "geredet": "reden",
    "geredete": "geredet",
    "geredetem": "geredet",
    "geredeten": "geredet",
    "geredeter": "geredet",
    "geredetes": "geredet",
    "geregelt": "regeln",
    "geregelte": "geregelt",
    "geregeltem": "geregelt",
    "geregelten": "geregelt",
    "geregelter": "geregelt",
    "geregeltere": "geregelt",
    "geregelterem": "geregelt",
    "geregelteren": "geregelt",
    "geregelterer": "geregelt",
    "geregelteres": "geregelt",
    "geregeltes": "geregelt",
    "geregelteste": "geregelt",
    "geregeltestem": "geregelt",
    "geregeltesten": "geregelt",
    "geregeltester": "geregelt",
    "geregeltestes": "geregelt",
    "geregnet": "regnen",
    "geregnete": "geregnet",
    "geregnetem": "geregnet",
    "geregneten": "geregnet",
    "geregneter": "geregnet",
    "geregnetes": "geregnet",
    "geregt": "regen",
    "geregte": "geregt",
    "geregtem": "geregt",
    "geregten": "geregt",
    "geregter": "geregt",
    "geregtes": "geregt",
    "gereiche": "gereichen",
    "gereichend": "gereichen",
    "gereichende": "gereichend",
    "gereichendem": "gereichend",
    "gereichenden": "gereichend",
    "gereichender": "gereichend",
    "gereichendes": "gereichend",
    "gereichert": "reichern",
    "gereicherte": "gereichert",
    "gereichertem": "gereichert",
    "gereicherten": "gereichert",
    "gereicherter": "gereichert",
    "gereichertes": "gereichert",
    "gereichest": "gereichen",
    "gereichet": "gereichen",
    "gereichst": "gereichen",
    "gereicht": "reichen",
    "gereichte": "gereichen",
    "gereichtem": "gereicht",
    "gereichten": "gereichen",
    "gereichter": "gereicht",
    "gereichtes": "gereicht",
    "gereichtest": "gereichen",
    "gereichtet": "gereichen",
    "gereift": "reifen",
    "gereifte": "gereift",
    "gereiftem": "gereift",
    "gereiften": "gereift",
    "gereifter": "gereift",
    "gereiftere": "gereift",
    "gereifterem": "gereift",
    "gereifteren": "gereift",
    "gereifterer": "gereift",
    "gereifteres": "gereift",
    "gereiftes": "gereift",
    "gereifteste": "gereift",
    "gereiftestem": "gereift",
    "gereiftesten": "gereift",
    "gereiftester": "gereift",
    "gereiftestes": "gereift",
    "gereihert": "reihern",
    "gereiherte": "gereihert",
    "gereihertem": "gereihert",
    "gereiherten": "gereihert",
    "gereiherter": "gereihert",
    "gereihertes": "gereihert",
    "gereiht": "reihen",
    "gereihte": "gereiht",
    "gereihtem": "gereiht",
    "gereihten": "gereiht",
    "gereihter": "gereiht",
    "gereihtes": "gereiht",
    "gereimt": "reimen",
    "gereimte": "gereimt",
    "gereimtem": "gereimt",
    "gereimten": "gereimt",
    "gereimter": "gereimt",
    "gereimtere": "gereimt",
    "gereimterem": "gereimt",
    "gereimteren": "gereimt",
    "gereimterer": "gereimt",
    "gereimteres": "gereimt",
    "gereimtes": "gereimt",
    "gereimteste": "gereimt",
    "gereimtestem": "gereimt",
    "gereimtesten": "gereimt",
    "gereimtester": "gereimt",
    "gereimtestes": "gereimt",
    "gereinigt": "reinigen",
    "gereinigte": "gereinigt",
    "gereinigtem": "gereinigt",
    "gereinigten": "gereinigt",
    "gereinigter": "gereinigt",
    "gereinigtere": "gereinigt",
    "gereinigterem": "gereinigt",
    "gereinigteren": "gereinigt",
    "gereinigterer": "gereinigt",
    "gereinigteres": "gereinigt",
    "gereinigtes": "gereinigt",
    "gereinigteste": "gereinigt",
    "gereinigtestem": "gereinigt",
    "gereinigtesten": "gereinigt",
    "gereinigtester": "gereinigt",
    "gereinigtestes": "gereinigt",
    "gereist": "reisen",
    "gereiste": "gereist",
    "gereistem": "gereist",
    "gereisten": "gereist",
    "gereister": "gereist",
    "gereistes": "gereist",
    "gereizt": "reizen",
    "gereizte": "gereizt",
    "gereiztem": "gereizt",
    "gereizten": "gereizt",
    "gereizter": "gereizt",
    "gereiztes": "gereizt",
    "gerempelt": "rempeln",
    "gerempelte": "gerempelt",
    "gerempeltem": "gerempelt",
    "gerempelten": "gerempelt",
    "gerempelter": "gerempelt",
    "gerempeltes": "gerempelt",
    "gerenkt": "renken",
    "gerenkte": "gerenkt",
    "gerenktem": "gerenkt",
    "gerenkten": "gerenkt",
    "gerenkter": "gerenkt",
    "gerenktes": "gerenkt",
    "gerettet": "retten",
    "gerettete": "gerettet",
    "gerettetem": "gerettet",
    "geretteten": "gerettet",
    "geretteter": "gerettet",
    "gerettetes": "gerettet",
    "geribbelt": "ribbeln",
    "geribbelte": "geribbelt",
    "geribbeltem": "geribbelt",
    "geribbelten": "geribbelt",
    "geribbelter": "geribbelt",
    "geribbeltes": "geribbelt",
    "gerichtet": "richten",
    "gerichtete": "gerichtet",
    "gerichtetem": "gerichtet",
    "gerichteten": "gerichtet",
    "gerichteter": "gerichtet",
    "gerichtetere": "gerichtet",
    "gerichteterem": "gerichtet",
    "gerichteteren": "gerichtet",
    "gerichteterer": "gerichtet",
    "gerichteteres": "gerichtet",
    "gerichtetes": "gerichtet",
    "gerichteteste": "gerichtet",
    "gerichtetestem": "gerichtet",
    "gerichtetesten": "gerichtet",
    "gerichtetester": "gerichtet",
    "gerichtetestes": "gerichtet",
    "gerichtliche": "gerichtlich",
    "gerichtlichem": "gerichtlich",
    "gerichtlichen": "gerichtlich",
    "gerichtlicher": "gerichtlich",
    "gerichtliches": "gerichtlich",
    "gerieben": "reiben",
    "geriebene": "gerieben",
    "geriebenem": "gerieben",
    "geriebenen": "gerieben",
    "geriebener": "gerieben",
    "geriebenere": "gerieben",
    "geriebenerem": "gerieben",
    "geriebeneren": "gerieben",
    "geriebenerer": "gerieben",
    "geriebeneres": "gerieben",
    "geriebenes": "gerieben",
    "geriebenste": "gerieben",
    "geriebenstem": "gerieben",
    "geriebensten": "gerieben",
    "geriebenster": "gerieben",
    "geriebenstes": "gerieben",
    "geriegelt": "riegeln",
    "geriegelte": "geriegelt",
    "geriegeltem": "geriegelt",
    "geriegelten": "geriegelt",
    "geriegelter": "geriegelt",
    "geriegeltes": "geriegelt",
    "gerieselt": "rieseln",
    "gerieselte": "gerieselt",
    "gerieseltem": "gerieselt",
    "gerieselten": "gerieselt",
    "gerieselter": "gerieselt",
    "gerieseltes": "gerieselt",
    "geriet": "geraten",
    "geriete": "geraten",
    "gerieten": "geraten",
    "gerietest": "geraten",
    "gerietet": "geraten",
    "geriffelt": "riffeln",
    "geriffelte": "geriffelt",
    "geriffeltem": "geriffelt",
    "geriffelten": "geriffelt",
    "geriffelter": "geriffelt",
    "geriffeltere": "geriffelt",
    "geriffelterem": "geriffelt",
    "geriffelteren": "geriffelt",
    "geriffelterer": "geriffelt",
    "geriffelteres": "geriffelt",
    "geriffeltes": "geriffelt",
    "geriffelteste": "geriffelt",
    "geriffeltestem": "geriffelt",
    "geriffeltesten": "geriffelt",
    "geriffeltester": "geriffelt",
    "geriffeltestes": "geriffelt",
    "gerillt": "rillen",
    "gerillte": "gerillt",
    "gerilltem": "gerillt",
    "gerillten": "gerillt",
    "gerillter": "gerillt",
    "gerilltere": "gerillt",
    "gerillterem": "gerillt",
    "gerillteren": "gerillt",
    "gerillterer": "gerillt",
    "gerillteres": "gerillt",
    "gerilltes": "gerillt",
    "gerillteste": "gerillt",
    "gerilltestem": "gerillt",
    "gerilltesten": "gerillt",
    "gerilltester": "gerillt",
    "gerilltestes": "gerillt",
    "gerindet": "rinden",
    "gerindete": "gerindet",
    "gerindetem": "gerindet",
    "gerindeten": "gerindet",
    "gerindeter": "gerindet",
    "gerindetes": "gerindet",
    "geringachte": "geringachten",
    "geringachtend": "geringachten",
    "geringachtende": "geringachtend",
    "geringachtendem": "geringachtend",
    "geringachtenden": "geringachtend",
    "geringachtender": "geringachtend",
    "geringachtendere": "geringachtend",
    "geringachtenderem": "geringachtend",
    "geringachtenderen": "geringachtend",
    "geringachtenderer": "geringachtend",
    "geringachtenderes": "geringachtend",
    "geringachtendes": "geringachtend",
    "geringachtendste": "geringachtend",
    "geringachtendstem": "geringachtend",
    "geringachtendsten": "geringachtend",
    "geringachtendster": "geringachtend",
    "geringachtendstes": "geringachtend",
    "geringachtest": "geringachten",
    "geringachtet": "geringachten",
    "geringachtete": "geringachten",
    "geringachteten": "geringachten",
    "geringachtetest": "geringachten",
    "geringachtetet": "geringachten",
    "geringe": "gering",
    "geringelt": "ringeln",
    "geringelte": "geringelt",
    "geringeltem": "geringelt",
    "geringelten": "geringelt",
    "geringelter": "geringelt",
    "geringeltere": "geringelt",
    "geringelterem": "geringelt",
    "geringelteren": "geringelt",
    "geringelterer": "geringelt",
    "geringelteres": "geringelt",
    "geringeltes": "geringelt",
    "geringelteste": "geringelt",
    "geringeltestem": "geringelt",
    "geringeltesten": "geringelt",
    "geringeltester": "geringelt",
    "geringeltestes": "geringelt",
    "geringem": "gering",
    "geringen": "gering",
    "geringer": "gering",
    "geringere": "gering",
    "geringerem": "gering",
    "geringeren": "gering",
    "geringerer": "gering",
    "geringeres": "gering",
    "geringes": "gering",
    "geringfügige": "geringfügig",
    "geringfügigem": "geringfügig",
    "geringfügigen": "geringfügig",
    "geringfügiger": "geringfügig",
    "geringfügiges": "geringfügig",
    "geringgeachtet": "geringachten",
    "geringgeachtete": "geringgeachtet",
    "geringgeachtetem": "geringgeachtet",
    "geringgeachteten": "geringgeachtet",
    "geringgeachteter": "geringgeachtet",
    "geringgeachtetere": "geringgeachtet",
    "geringgeachteterem": "geringgeachtet",
    "geringgeachteteren": "geringgeachtet",
    "geringgeachteterer": "geringgeachtet",
    "geringgeachteteres": "geringgeachtet",
    "geringgeachtetes": "geringgeachtet",
    "geringgeachteteste": "geringgeachtet",
    "geringgeachtetestem": "geringgeachtet",
    "geringgeachtetesten": "geringgeachtet",
    "geringgeachtetester": "geringgeachtet",
    "geringgeachtetestes": "geringgeachtet",
    "geringgeschätzt": "geringschätzen",
    "geringgeschätzte": "geringgeschätzt",
    "geringgeschätztem": "geringgeschätzt",
    "geringgeschätzten": "geringgeschätzt",
    "geringgeschätzter": "geringgeschätzt",
    "geringgeschätztere": "geringgeschätzt",
    "geringgeschätzterem": "geringgeschätzt",
    "geringgeschätzteren": "geringgeschätzt",
    "geringgeschätzterer": "geringgeschätzt",
    "geringgeschätzteres": "geringgeschätzt",
    "geringgeschätztes": "geringgeschätzt",
    "geringgeschätzteste": "geringgeschätzt",
    "geringgeschätztestem": "geringgeschätzt",
    "geringgeschätztesten": "geringgeschätzt",
    "geringgeschätztester": "geringgeschätzt",
    "geringgeschätztestes": "geringgeschätzt",
    "geringschätze": "geringschätzen",
    "geringschätzend": "geringschätzen",
    "geringschätzende": "geringschätzend",
    "geringschätzendem": "geringschätzend",
    "geringschätzenden": "geringschätzend",
    "geringschätzender": "geringschätzend",
    "geringschätzendere": "geringschätzend",
    "geringschätzenderem": "geringschätzend",
    "geringschätzenderen": "geringschätzend",
    "geringschätzenderer": "geringschätzend",
    "geringschätzenderes": "geringschätzend",
    "geringschätzendes": "geringschätzend",
    "geringschätzendste": "geringschätzend",
    "geringschätzendstem": "geringschätzend",
    "geringschätzendsten": "geringschätzend",
    "geringschätzendster": "geringschätzend",
    "geringschätzendstes": "geringschätzend",
    "geringschätzest": "geringschätzen",
    "geringschätzet": "geringschätzen",
    "geringschätzige": "geringschätzig",
    "geringschätzigem": "geringschätzig",
    "geringschätzigen": "geringschätzig",
    "geringschätziger": "geringschätzig",
    "geringschätzigere": "geringschätzig",
    "geringschätzigerem": "geringschätzig",
    "geringschätzigeren": "geringschätzig",
    "geringschätzigerer": "geringschätzig",
    "geringschätzigeres": "geringschätzig",
    "geringschätziges": "geringschätzig",
    "geringschätzigste": "geringschätzig",
    "geringschätzigstem": "geringschätzig",
    "geringschätzigsten": "geringschätzig",
    "geringschätzigster": "geringschätzig",
    "geringschätzigstes": "geringschätzig",
    "geringschätzt": "geringschätzen",
    "geringschätzte": "geringschätzen",
    "geringschätzten": "geringschätzen",
    "geringschätztest": "geringschätzen",
    "geringschätztet": "geringschätzen",
    "geringste": "gering",
    "geringstem": "gering",
    "geringsten": "gering",
    "geringster": "gering",
    "geringstes": "gering",
    "geringwertige": "geringwertig",
    "geringwertigem": "geringwertig",
    "geringwertigen": "geringwertig",
    "geringwertiger": "geringwertig",
    "geringwertigere": "geringwertig",
    "geringwertigerem": "geringwertig",
    "geringwertigeren": "geringwertig",
    "geringwertigerer": "geringwertig",
    "geringwertigeres": "geringwertig",
    "geringwertiges": "geringwertig",
    "geringwertigste": "geringwertig",
    "geringwertigstem": "geringwertig",
    "geringwertigsten": "geringwertig",
    "geringwertigster": "geringwertig",
    "geringwertigstes": "geringwertig",
    "geringzuachten": "geringachten",
    "geringzuschätzen": "geringschätzen",
    "gerinne": "gerinnen",
    "gerinnend": "gerinnen",
    "gerinnende": "gerinnend",
    "gerinnendem": "gerinnend",
    "gerinnenden": "gerinnend",
    "gerinnender": "gerinnend",
    "gerinnendes": "gerinnend",
    "gerinnest": "gerinnen",
    "gerinnet": "gerinnen",
    "gerinnst": "gerinnen",
    "gerinnt": "gerinnen",
    "gerinnungsfähige": "gerinnungsfähig",
    "gerinnungsfähigem": "gerinnungsfähig",
    "gerinnungsfähigen": "gerinnungsfähig",
    "gerinnungsfähiger": "gerinnungsfähig",
    "gerinnungsfähigere": "gerinnungsfähig",
    "gerinnungsfähigerem": "gerinnungsfähig",
    "gerinnungsfähigeren": "gerinnungsfähig",
    "gerinnungsfähigerer": "gerinnungsfähig",
    "gerinnungsfähigeres": "gerinnungsfähig",
    "gerinnungsfähiges": "gerinnungsfähig",
    "gerinnungsfähigste": "gerinnungsfähig",
    "gerinnungsfähigstem": "gerinnungsfähig",
    "gerinnungsfähigsten": "gerinnungsfähig",
    "gerinnungsfähigster": "gerinnungsfähig",
    "gerinnungsfähigstes": "gerinnungsfähig",
    "gerippt": "rippen",
    "gerippte": "gerippt",
    "geripptem": "gerippt",
    "gerippten": "gerippt",
    "gerippter": "gerippt",
    "geripptere": "gerippt",
    "gerippterem": "gerippt",
    "gerippteren": "gerippt",
    "gerippterer": "gerippt",
    "gerippteres": "gerippt",
    "geripptes": "gerippt",
    "gerippteste": "gerippt",
    "geripptestem": "gerippt",
    "geripptesten": "gerippt",
    "geripptester": "gerippt",
    "geripptestes": "gerippt",
    "gerissen": "reißen",
    "gerissene": "gerissen",
    "gerissenem": "gerissen",
    "gerissenen": "gerissen",
    "gerissener": "gerissen",
    "gerissenere": "gerissen",
    "gerissenerem": "gerissen",
    "gerisseneren": "gerissen",
    "gerissenerer": "gerissen",
    "gerisseneres": "gerissen",
    "gerissenes": "gerissen",
    "gerissenste": "gerissen",
    "gerissenstem": "gerissen",
    "gerissensten": "gerissen",
    "gerissenster": "gerissen",
    "gerissenstes": "gerissen",
    "geritten": "reiten",
    "gerittene": "geritten",
    "gerittenem": "geritten",
    "gerittenen": "geritten",
    "gerittener": "geritten",
    "gerittenes": "geritten",
    "geritzt": "ritzen",
    "geritzte": "geritzt",
    "geritztem": "geritzt",
    "geritzten": "geritzt",
    "geritzter": "geritzt",
    "geritztes": "geritzt",
    "germanischem": "germanisch",
    "germanischen": "germanisch",
    "germanischer": "germanisch",
    "germanisches": "germanisch",
    "germanisiere": "germanisieren",
    "germanisierend": "germanisieren",
    "germanisierende": "germanisierend",
    "germanisierendem": "germanisierend",
    "germanisierenden": "germanisierend",
    "germanisierender": "germanisierend",
    "germanisierendere": "germanisierend",
    "germanisierenderem": "germanisierend",
    "germanisierenderen": "germanisierend",
    "germanisierenderer": "germanisierend",
    "germanisierenderes": "germanisierend",
    "germanisierendes": "germanisierend",
    "germanisierendste": "germanisierend",
    "germanisierendstem": "germanisierend",
    "germanisierendsten": "germanisierend",
    "germanisierendster": "germanisierend",
    "germanisierendstes": "germanisierend",
    "germanisierest": "germanisieren",
    "germanisieret": "germanisieren",
    "germanisierst": "germanisieren",
    "germanisiert": "germanisieren",
    "germanisierte": "germanisieren",
    "germanisiertem": "germanisiert",
    "germanisierten": "germanisieren",
    "germanisierter": "germanisiert",
    "germanisiertere": "germanisiert",
    "germanisierterem": "germanisiert",
    "germanisierteren": "germanisiert",
    "germanisierterer": "germanisiert",
    "germanisierteres": "germanisiert",
    "germanisiertes": "germanisiert",
    "germanisiertest": "germanisieren",
    "germanisierteste": "germanisiert",
    "germanisiertestem": "germanisiert",
    "germanisiertesten": "germanisiert",
    "germanisiertester": "germanisiert",
    "germanisiertestes": "germanisiert",
    "germanisiertet": "germanisieren",
    "germanistische": "germanistisch",
    "germanistischem": "germanistisch",
    "germanistischen": "germanistisch",
    "germanistischer": "germanistisch",
    "germanistisches": "germanistisch",
    "gerobbt": "robben",
    "gerobbte": "gerobbt",
    "gerobbtem": "gerobbt",
    "gerobbten": "gerobbt",
    "gerobbter": "gerobbt",
    "gerobbtes": "gerobbt",
    "gerochen": "riechen",
    "gerochene": "gerochen",
    "gerochenem": "gerochen",
    "gerochenen": "gerochen",
    "gerochener": "gerochen",
    "gerochenes": "gerochen",
    "gerodelt": "rodeln",
    "gerodelte": "gerodelt",
    "gerodeltem": "gerodelt",
    "gerodelten": "gerodelt",
    "gerodelter": "gerodelt",
    "gerodeltes": "gerodelt",
    "gerodet": "roden",
    "gerodete": "gerodet",
    "gerodetem": "gerodet",
    "gerodeten": "gerodet",
    "gerodeter": "gerodet",
    "gerodetere": "gerodet",
    "gerodeterem": "gerodet",
    "gerodeteren": "gerodet",
    "gerodeterer": "gerodet",
    "gerodeteres": "gerodet",
    "gerodetes": "gerodet",
    "gerodeteste": "gerodet",
    "gerodetestem": "gerodet",
    "gerodetesten": "gerodet",
    "gerodetester": "gerodet",
    "gerodetestes": "gerodet",
    "gerollt": "rollen",
    "gerollte": "gerollt",
    "gerolltem": "gerollt",
    "gerollten": "gerollt",
    "gerollter": "gerollt",
    "gerolltere": "gerollt",
    "gerollterem": "gerollt",
    "gerollteren": "gerollt",
    "gerollterer": "gerollt",
    "gerollteres": "gerollt",
    "gerolltes": "gerollt",
    "gerollteste": "gerollt",
    "gerolltestem": "gerollt",
    "gerolltesten": "gerollt",
    "gerolltester": "gerollt",
    "gerolltestes": "gerollt",
    "geronnen": "rinnen",
    "geronnene": "geronnen",
    "geronnenem": "geronnen",
    "geronnenen": "geronnen",
    "geronnener": "geronnen",
    "geronnenere": "geronnen",
    "geronnenerem": "geronnen",
    "geronneneren": "geronnen",
    "geronnenerer": "geronnen",
    "geronneneres": "geronnen",
    "geronnenes": "geronnen",
    "geronnenste": "geronnen",
    "geronnenstem": "geronnen",
    "geronnensten": "geronnen",
    "geronnenster": "geronnen",
    "geronnenstes": "geronnen",
    "gerostet": "rosten",
    "gerostete": "gerostet",
    "gerostetem": "gerostet",
    "gerosteten": "gerostet",
    "gerosteter": "gerostet",
    "gerostetere": "gerostet",
    "gerosteterem": "gerostet",
    "gerosteteren": "gerostet",
    "gerosteterer": "gerostet",
    "gerosteteres": "gerostet",
    "gerostetes": "gerostet",
    "gerosteteste": "gerostet",
    "gerostetestem": "gerostet",
    "gerostetesten": "gerostet",
    "gerostetester": "gerostet",
    "gerostetestes": "gerostet",
    "gerottet": "rotten",
    "gerottete": "gerottet",
    "gerottetem": "gerottet",
    "gerotteten": "gerottet",
    "gerotteter": "gerottet",
    "gerottetes": "gerottet",
    "gerotzt": "rotzen",
    "gerotzte": "gerotzt",
    "gerotztem": "gerotzt",
    "gerotzten": "gerotzt",
    "gerotzter": "gerotzt",
    "gerotztes": "gerotzt",
    "gertenschlankem": "gertenschlank",
    "gertenschlanken": "gertenschlank",
    "gertenschlanker": "gertenschlank",
    "gertenschlankere": "gertenschlank",
    "gertenschlankerem": "gertenschlank",
    "gertenschlankeren": "gertenschlank",
    "gertenschlankerer": "gertenschlank",
    "gertenschlankeres": "gertenschlank",
    "gertenschlankes": "gertenschlank",
    "gertenschlankeste": "gertenschlank",
    "gertenschlankestem": "gertenschlank",
    "gertenschlankesten": "gertenschlank",
    "gertenschlankester": "gertenschlank",
    "gertenschlankestes": "gertenschlank",
    "gerubbelt": "rubbeln",
    "gerubbelte": "gerubbelt",
    "gerubbeltem": "gerubbelt",
    "gerubbelten": "gerubbelt",
    "gerubbelter": "gerubbelt",
    "gerubbeltes": "gerubbelt",
    "geruchlosem": "geruchlos",
    "geruchlosen": "geruchlos",
    "geruchloser": "geruchlos",
    "geruchlosere": "geruchlos",
    "geruchloserem": "geruchlos",
    "geruchloseren": "geruchlos",
    "geruchloserer": "geruchlos",
    "geruchloseres": "geruchlos",
    "geruchloses": "geruchlos",
    "geruchloseste": "geruchlos",
    "geruchlosestem": "geruchlos",
    "geruchlosesten": "geruchlos",
    "geruchlosester": "geruchlos",
    "geruchlosestes": "geruchlos",
    "geruckelt": "ruckeln",
    "geruckelte": "geruckelt",
    "geruckeltem": "geruckelt",
    "geruckelten": "geruckelt",
    "geruckelter": "geruckelt",
    "geruckeltes": "geruckelt",
    "gerudert": "rudern",
    "geruderte": "gerudert",
    "gerudertem": "gerudert",
    "geruderten": "gerudert",
    "geruderter": "gerudert",
    "gerudertes": "gerudert",
    "gerufen": "rufen",
    "gerufene": "gerufen",
    "gerufenem": "gerufen",
    "gerufenen": "gerufen",
    "gerufener": "gerufen",
    "gerufenes": "gerufen",
    "geruhsame": "geruhsam",
    "geruhsamem": "geruhsam",
    "geruhsamen": "geruhsam",
    "geruhsamer": "geruhsam",
    "geruhsamere": "geruhsam",
    "geruhsamerem": "geruhsam",
    "geruhsameren": "geruhsam",
    "geruhsamerer": "geruhsam",
    "geruhsameres": "geruhsam",
    "geruhsames": "geruhsam",
    "geruhsamste": "geruhsam",
    "geruhsamstem": "geruhsam",
    "geruhsamsten": "geruhsam",
    "geruhsamster": "geruhsam",
    "geruhsamstes": "geruhsam",
    "geruht": "ruhen",
    "geruhte": "geruht",
    "geruhtem": "geruht",
    "geruhten": "geruht",
    "geruhter": "geruht",
    "geruhtes": "geruht",
    "gerundet": "runden",
    "gerundete": "gerundet",
    "gerundetem": "gerundet",
    "gerundeten": "gerundet",
    "gerundeter": "gerundet",
    "gerundetes": "gerundet",
    "gerungen": "ringen",
    "gerungene": "gerungen",
    "gerungenem": "gerungen",
    "gerungenen": "gerungen",
    "gerungener": "gerungen",
    "gerungenes": "gerungen",
    "gerunzelt": "runzeln",
    "gerunzelte": "gerunzelt",
    "gerunzeltem": "gerunzelt",
    "gerunzelten": "gerunzelt",
    "gerunzelter": "gerunzelt",
    "gerunzeltes": "gerunzelt",
    "gerupft": "rupfen",
    "gerupfte": "gerupft",
    "gerupftem": "gerupft",
    "gerupften": "gerupft",
    "gerupfter": "gerupft",
    "gerupftere": "gerupft",
    "gerupfterem": "gerupft",
    "gerupfteren": "gerupft",
    "gerupfterer": "gerupft",
    "gerupfteres": "gerupft",
    "gerupftes": "gerupft",
    "gerupfteste": "gerupft",
    "gerupftestem": "gerupft",
    "gerupftesten": "gerupft",
    "gerupftester": "gerupft",
    "gerupftestes": "gerupft",
    "gerutscht": "rutschen",
    "gerutschte": "gerutscht",
    "gerutschtem": "gerutscht",
    "gerutschten": "gerutscht",
    "gerutschter": "gerutscht",
    "gerutschtes": "gerutscht",
    "gerächt": "rächen",
    "gerächte": "gerächt",
    "gerächtem": "gerächt",
    "gerächten": "gerächt",
    "gerächter": "gerächt",
    "gerächtes": "gerächt",
    "gerädert": "rädern",
    "geräderte": "gerädert",
    "gerädertem": "gerädert",
    "geräderten": "gerädert",
    "geräderter": "gerädert",
    "gerädertere": "gerädert",
    "geräderterem": "gerädert",
    "geräderteren": "gerädert",
    "geräderterer": "gerädert",
    "geräderteres": "gerädert",
    "gerädertes": "gerädert",
    "geräderteste": "gerädert",
    "gerädertestem": "gerädert",
    "gerädertesten": "gerädert",
    "gerädertester": "gerädert",
    "gerädertestes": "gerädert",
    "geräkelt": "räkeln",
    "geräkelte": "geräkelt",
    "geräkeltem": "geräkelt",
    "geräkelten": "geräkelt",
    "geräkelter": "geräkelt",
    "geräkeltes": "geräkelt",
    "geränne": "gerinnen",
    "gerännen": "gerinnen",
    "gerännest": "gerinnen",
    "gerännet": "gerinnen",
    "gerät": "geraten",
    "gerätselt": "rätseln",
    "gerätselte": "gerätselt",
    "gerätseltem": "gerätselt",
    "gerätselten": "gerätselt",
    "gerätselter": "gerätselt",
    "gerätseltes": "gerätselt",
    "gerätst": "geraten",
    "geräuchert": "räuchern",
    "geräucherte": "geräuchert",
    "geräuchertem": "geräuchert",
    "geräucherten": "geräuchert",
    "geräucherter": "geräuchert",
    "geräuchertes": "geräuchert",
    "geräumige": "geräumig",
    "geräumigem": "geräumig",
    "geräumigen": "geräumig",
    "geräumiger": "geräumig",
    "geräumigere": "geräumig",
    "geräumigerem": "geräumig",
    "geräumigeren": "geräumig",
    "geräumigerer": "geräumig",
    "geräumigeres": "geräumig",
    "geräumiges": "geräumig",
    "geräumigste": "geräumig",
    "geräumigstem": "geräumig",
    "geräumigsten": "geräumig",
    "geräumigster": "geräumig",
    "geräumigstes": "geräumig",
    "geräumt": "räumen",
    "geräumte": "geräumt",
    "geräumtem": "geräumt",
    "geräumten": "geräumt",
    "geräumter": "geräumt",
    "geräumtes": "geräumt",
    "geräuschlosem": "geräuschlos",
    "geräuschlosen": "geräuschlos",
    "geräuschloser": "geräuschlos",
    "geräuschlosere": "geräuschlos",
    "geräuschloserem": "geräuschlos",
    "geräuschloseren": "geräuschlos",
    "geräuschloserer": "geräuschlos",
    "geräuschloseres": "geräuschlos",
    "geräuschloses": "geräuschlos",
    "geräuschloseste": "geräuschlos",
    "geräuschlosestem": "geräuschlos",
    "geräuschlosesten": "geräuschlos",
    "geräuschlosester": "geräuschlos",
    "geräuschlosestes": "geräuschlos",
    "geräuschvolle": "geräuschvoll",
    "geräuschvollem": "geräuschvoll",
    "geräuschvollen": "geräuschvoll",
    "geräuschvoller": "geräuschvoll",
    "geräuschvollere": "geräuschvoll",
    "geräuschvollerem": "geräuschvoll",
    "geräuschvolleren": "geräuschvoll",
    "geräuschvollerer": "geräuschvoll",
    "geräuschvolleres": "geräuschvoll",
    "geräuschvolles": "geräuschvoll",
    "geräuschvollste": "geräuschvoll",
    "geräuschvollstem": "geräuschvoll",
    "geräuschvollsten": "geräuschvoll",
    "geräuschvollster": "geräuschvoll",
    "geräuschvollstes": "geräuschvoll",
    "geräuspert": "räuspern",
    "geräusperte": "geräuspert",
    "geräuspertem": "geräuspert",
    "geräusperten": "geräuspert",
    "geräusperter": "geräuspert",
    "geräuspertes": "geräuspert",
    "geröchelt": "röcheln",
    "geröchelte": "geröchelt",
    "geröcheltem": "geröchelt",
    "geröchelten": "geröchelt",
    "geröchelter": "geröchelt",
    "geröcheltes": "geröchelt",
    "geröntgt": "röntgen",
    "geröntgte": "geröntgt",
    "geröntgtem": "geröntgt",
    "geröntgten": "geröntgt",
    "geröntgter": "geröntgt",
    "geröntgtes": "geröntgt",
    "geröstet": "rösten",
    "geröstetem": "geröstet",
    "gerösteter": "geröstet",
    "gerösteterem": "geröstet",
    "gerösteterer": "geröstet",
    "gerösteteres": "geröstet",
    "geröstetes": "geröstet",
    "geröstetestem": "geröstet",
    "geröstetester": "geröstet",
    "geröstetestes": "geröstet",
    "gerötet": "röten",
    "gerötete": "gerötet",
    "gerötetem": "gerötet",
    "geröteten": "gerötet",
    "geröteter": "gerötet",
    "gerötetere": "gerötet",
    "geröteterem": "gerötet",
    "geröteteren": "gerötet",
    "geröteterer": "gerötet",
    "geröteteres": "gerötet",
    "gerötetes": "gerötet",
    "geröteteste": "gerötet",
    "gerötetestem": "gerötet",
    "gerötetesten": "gerötet",
    "gerötetester": "gerötet",
    "gerötetestes": "gerötet",
    "gerückt": "rücken",
    "gerückte": "gerückt",
    "gerücktem": "gerückt",
    "gerückten": "gerückt",
    "gerückter": "gerückt",
    "gerücktes": "gerückt",
    "gerügt": "rügen",
    "gerügte": "gerügt",
    "gerügtem": "gerügt",
    "gerügten": "gerügt",
    "gerügter": "gerügt",
    "gerügtere": "gerügt",
    "gerügterem": "gerügt",
    "gerügteren": "gerügt",
    "gerügterer": "gerügt",
    "gerügteres": "gerügt",
    "gerügtes": "gerügt",
    "gerügteste": "gerügt",
    "gerügtestem": "gerügt",
    "gerügtesten": "gerügt",
    "gerügtester": "gerügt",
    "gerügtestes": "gerügt",
    "gerühmt": "rühmen",
    "gerühmte": "gerühmt",
    "gerühmtem": "gerühmt",
    "gerühmten": "gerühmt",
    "gerühmter": "gerühmt",
    "gerühmtere": "gerühmt",
    "gerühmterem": "gerühmt",
    "gerühmteren": "gerühmt",
    "gerühmterer": "gerühmt",
    "gerühmteres": "gerühmt",
    "gerühmtes": "gerühmt",
    "gerühmteste": "gerühmt",
    "gerühmtestem": "gerühmt",
    "gerühmtesten": "gerühmt",
    "gerühmtester": "gerühmt",
    "gerühmtestes": "gerühmt",
    "gerührt": "rühren",
    "gerührte": "gerührt",
    "gerührtem": "gerührt",
    "gerührten": "gerührt",
    "gerührter": "gerührt",
    "gerührtes": "gerührt",
    "gerülpst": "rülpsen",
    "gerülpste": "gerülpst",
    "gerülpstem": "gerülpst",
    "gerülpsten": "gerülpst",
    "gerülpster": "gerülpst",
    "gerülpstes": "gerülpst",
    "gerümpft": "rümpfen",
    "gerümpfte": "gerümpft",
    "gerümpftem": "gerümpft",
    "gerümpften": "gerümpft",
    "gerümpfter": "gerümpft",
    "gerümpftes": "gerümpft",
    "gerüstet": "rüsten",
    "gerüstete": "gerüstet",
    "gerüstetem": "gerüstet",
    "gerüsteten": "gerüstet",
    "gerüsteter": "gerüstet",
    "gerüstetes": "gerüstet",
    "gerüttelt": "rütteln",
    "gerüttelte": "gerüttelt",
    "gerütteltem": "gerüttelt",
    "gerüttelten": "gerüttelt",
    "gerüttelter": "gerüttelt",
    "gerütteltes": "gerüttelt",
    "gesabbelt": "sabbeln",
    "gesabbelte": "gesabbelt",
    "gesabbeltem": "gesabbelt",
    "gesabbelten": "gesabbelt",
    "gesabbelter": "gesabbelt",
    "gesabbeltes": "gesabbelt",
    "gesabbert": "sabbern",
    "gesabberte": "gesabbert",
    "gesabbertem": "gesabbert",
    "gesabberten": "gesabbert",
    "gesabberter": "gesabbert",
    "gesabbertes": "gesabbert",
    "gesaftet": "saften",
    "gesaftete": "gesaftet",
    "gesaftetem": "gesaftet",
    "gesafteten": "gesaftet",
    "gesafteter": "gesaftet",
    "gesaftetes": "gesaftet",
    "gesagt": "sagen",
    "gesagte": "gesagt",
    "gesagtem": "gesagt",
    "gesagten": "gesagt",
    "gesagter": "gesagt",
    "gesagtes": "gesagt",
    "gesahnt": "sahnen",
    "gesahnte": "gesahnt",
    "gesahntem": "gesahnt",
    "gesahnten": "gesahnt",
    "gesahnter": "gesahnt",
    "gesahntes": "gesahnt",
    "gesalbt": "salben",
    "gesalbte": "gesalbt",
    "gesalbtem": "gesalbt",
    "gesalbten": "gesalbt",
    "gesalbter": "gesalbt",
    "gesalbtes": "gesalbt",
    "gesalzen": "salzen",
    "gesalzene": "gesalzen",
    "gesalzenem": "gesalzen",
    "gesalzenen": "gesalzen",
    "gesalzener": "gesalzen",
    "gesalzenere": "gesalzen",
    "gesalzenerem": "gesalzen",
    "gesalzeneren": "gesalzen",
    "gesalzenerer": "gesalzen",
    "gesalzeneres": "gesalzen",
    "gesalzenes": "gesalzen",
    "gesalzenste": "gesalzen",
    "gesalzenstem": "gesalzen",
    "gesalzensten": "gesalzen",
    "gesalzenster": "gesalzen",
    "gesalzenstes": "gesalzen",
    "gesammelt": "sammeln",
    "gesammelte": "gesammelt",
    "gesammeltem": "gesammelt",
    "gesammelten": "gesammelt",
    "gesammelter": "gesammelt",
    "gesammeltes": "gesammelt",
    "gesamt": "samen",
    "gesamtdeutsche": "gesamtdeutsch",
    "gesamtdeutschem": "gesamtdeutsch",
    "gesamtdeutschen": "gesamtdeutsch",
    "gesamtdeutscher": "gesamtdeutsch",
    "gesamtdeutsches": "gesamtdeutsch",
    "gesamte": "gesamt",
    "gesamtem": "gesamt",
    "gesamten": "gesamt",
    "gesamter": "gesamt",
    "gesamtes": "gesamt",
    "gesamthaftem": "gesamthaft",
    "gesamthaften": "gesamthaft",
    "gesamthafter": "gesamthaft",
    "gesamthaftes": "gesamthaft",
    "gesandt": "senden",
    "gesandte": "gesandt",
    "gesandtem": "gesandt",
    "gesandten": "gesandt",
    "gesandter": "gesandt",
    "gesandtes": "gesandt",
    "gesanglichem": "gesanglich",
    "gesanglichen": "gesanglich",
    "gesanglicher": "gesanglich",
    "gesangliches": "gesanglich",
    "gesargt": "sargen",
    "gesargte": "gesargt",
    "gesargtem": "gesargt",
    "gesargten": "gesargt",
    "gesargter": "gesargt",
    "gesargtes": "gesargt",
    "gesattelt": "satteln",
    "gesattelte": "gesattelt",
    "gesatteltem": "gesattelt",
    "gesattelten": "gesattelt",
    "gesattelter": "gesattelt",
    "gesatteltes": "gesattelt",
    "gesauert": "sauern",
    "gesauerte": "gesauert",
    "gesauertem": "gesauert",
    "gesauerten": "gesauert",
    "gesauerter": "gesauert",
    "gesauertere": "gesauert",
    "gesauerterem": "gesauert",
    "gesauerteren": "gesauert",
    "gesauerterer": "gesauert",
    "gesauerteres": "gesauert",
    "gesauertes": "gesauert",
    "gesauerteste": "gesauert",
    "gesauertestem": "gesauert",
    "gesauertesten": "gesauert",
    "gesauertester": "gesauert",
    "gesauertestes": "gesauert",
    "gesaugbohnert": "saugbohnern",
    "gesaugbohnerte": "gesaugbohnert",
    "gesaugbohnertem": "gesaugbohnert",
    "gesaugbohnerten": "gesaugbohnert",
    "gesaugbohnerter": "gesaugbohnert",
    "gesaugbohnertes": "gesaugbohnert",
    "gesaugt": "saugen",
    "gesaugte": "gesaugt",
    "gesaugtem": "gesaugt",
    "gesaugten": "gesaugt",
    "gesaugter": "gesaugt",
    "gesaugtere": "gesaugt",
    "gesaugterem": "gesaugt",
    "gesaugteren": "gesaugt",
    "gesaugterer": "gesaugt",
    "gesaugteres": "gesaugt",
    "gesaugtes": "gesaugt",
    "gesaugteste": "gesaugt",
    "gesaugtestem": "gesaugt",
    "gesaugtesten": "gesaugt",
    "gesaugtester": "gesaugt",
    "gesaugtestes": "gesaugt",
    "gesaunt": "saunen",
    "gesaunte": "gesaunt",
    "gesauntem": "gesaunt",
    "gesaunten": "gesaunt",
    "gesaunter": "gesaunt",
    "gesauntes": "gesaunt",
    "gesaust": "sausen",
    "gesauste": "gesaust",
    "gesaustem": "gesaust",
    "gesausten": "gesaust",
    "gesauster": "gesaust",
    "gesaustes": "gesaust",
    "gesaut": "sauen",
    "gesaute": "gesaut",
    "gesautem": "gesaut",
    "gesauten": "gesaut",
    "gesauter": "gesaut",
    "gesautes": "gesaut",
    "geschabt": "schaben",
    "geschabte": "geschabt",
    "geschabtem": "geschabt",
    "geschabten": "geschabt",
    "geschabter": "geschabt",
    "geschabtes": "geschabt",
    "geschachert": "schachern",
    "geschacherte": "geschachert",
    "geschachertem": "geschachert",
    "geschacherten": "geschachert",
    "geschacherter": "geschachert",
    "geschachertes": "geschachert",
    "geschachtelt": "schachteln",
    "geschachtelte": "geschachtelt",
    "geschachteltem": "geschachtelt",
    "geschachtelten": "geschachtelt",
    "geschachtelter": "geschachtelt",
    "geschachteltere": "geschachtelt",
    "geschachtelterem": "geschachtelt",
    "geschachtelteren": "geschachtelt",
    "geschachtelterer": "geschachtelt",
    "geschachtelteres": "geschachtelt",
    "geschachteltes": "geschachtelt",
    "geschachtelteste": "geschachtelt",
    "geschachteltestem": "geschachtelt",
    "geschachteltesten": "geschachtelt",
    "geschachteltester": "geschachtelt",
    "geschachteltestes": "geschachtelt",
    "geschachtet": "schachten",
    "geschachtete": "geschachtet",
    "geschachtetem": "geschachtet",
    "geschachteten": "geschachtet",
    "geschachteter": "geschachtet",
    "geschachtetes": "geschachtet",
    "geschadet": "schaden",
    "geschadete": "geschadet",
    "geschadetem": "geschadet",
    "geschadeten": "geschadet",
    "geschadeter": "geschadet",
    "geschadetes": "geschadet",
    "geschaffen": "schaffen",
    "geschaffene": "geschaffen",
    "geschaffenem": "geschaffen",
    "geschaffenen": "geschaffen",
    "geschaffener": "geschaffen",
    "geschaffenes": "geschaffen",
    "geschafft": "schaffen",
    "geschaffte": "geschafft",
    "geschafftem": "geschafft",
    "geschafften": "geschafft",
    "geschaffter": "geschafft",
    "geschafftere": "geschafft",
    "geschaffterem": "geschafft",
    "geschaffteren": "geschafft",
    "geschaffterer": "geschafft",
    "geschaffteres": "geschafft",
    "geschafftes": "geschafft",
    "geschaffteste": "geschafft",
    "geschafftestem": "geschafft",
    "geschafftesten": "geschafft",
    "geschafftester": "geschafft",
    "geschafftestes": "geschafft",
    "geschah": "geschehen",
    "geschahen": "geschehen",
    "geschahst": "geschehen",
    "geschaht": "geschehen",
    "geschallt": "schallen",
    "geschallte": "geschallt",
    "geschalltem": "geschallt",
    "geschallten": "geschallt",
    "geschallter": "geschallt",
    "geschalltes": "geschallt",
    "geschalt": "schalen",
    "geschalte": "geschalt",
    "geschaltem": "geschalt",
    "geschalten": "geschalt",
    "geschalter": "geschalt",
    "geschaltes": "geschalt",
    "geschaltet": "schalten",
    "geschaltete": "geschaltet",
    "geschaltetem": "geschaltet",
    "geschalteten": "geschaltet",
    "geschalteter": "geschaltet",
    "geschaltetes": "geschaltet",
    "geschanzt": "schanzen",
    "geschanzte": "geschanzt",
    "geschanztem": "geschanzt",
    "geschanzten": "geschanzt",
    "geschanzter": "geschanzt",
    "geschanztes": "geschanzt",
    "gescharrt": "scharren",
    "gescharrte": "gescharrt",
    "gescharrtem": "gescharrt",
    "gescharrten": "gescharrt",
    "gescharrter": "gescharrt",
    "gescharrtes": "gescharrt",
    "geschart": "scharen",
    "gescharte": "geschart",
    "geschartem": "geschart",
    "gescharten": "geschart",
    "gescharter": "geschart",
    "geschartes": "geschart",
    "geschaudert": "schaudern",
    "geschauderte": "geschaudert",
    "geschaudertem": "geschaudert",
    "geschauderten": "geschaudert",
    "geschauderter": "geschaudert",
    "geschaudertes": "geschaudert",
    "geschaufelt": "schaufeln",
    "geschaufelte": "geschaufelt",
    "geschaufeltem": "geschaufelt",
    "geschaufelten": "geschaufelt",
    "geschaufelter": "geschaufelt",
    "geschaufeltes": "geschaufelt",
    "geschaukelt": "schaukeln",
    "geschaukelte": "geschaukelt",
    "geschaukeltem": "geschaukelt",
    "geschaukelten": "geschaukelt",
    "geschaukelter": "geschaukelt",
    "geschaukeltes": "geschaukelt",
    "geschauspielert": "schauspielern",
    "geschauspielerte": "geschauspielert",
    "geschauspielertem": "geschauspielert",
    "geschauspielerten": "geschauspielert",
    "geschauspielerter": "geschauspielert",
    "geschauspielertes": "geschauspielert",
    "geschaut": "schauen",
    "geschaute": "geschaut",
    "geschautem": "geschaut",
    "geschauten": "geschaut",
    "geschauter": "geschaut",
    "geschautes": "geschaut",
    "gescheffelt": "scheffeln",
    "gescheffelte": "gescheffelt",
    "gescheffeltem": "gescheffelt",
    "gescheffelten": "gescheffelt",
    "gescheffelter": "gescheffelt",
    "gescheffeltes": "gescheffelt",
    "geschehe": "geschehen",
    "geschehend": "geschehen",
    "geschehende": "geschehend",
    "geschehendem": "geschehend",
    "geschehenden": "geschehend",
    "geschehender": "geschehend",
    "geschehendes": "geschehend",
    "geschehene": "geschehen",
    "geschehenem": "geschehen",
    "geschehenen": "geschehen",
    "geschehener": "geschehen",
    "geschehenes": "geschehen",
    "geschehest": "geschehen",
    "geschehet": "geschehen",
    "gescheht": "geschehen",
    "gescheite": "gescheit",
    "gescheitem": "gescheit",
    "gescheiten": "gescheit",
    "gescheiter": "gescheit",
    "gescheitere": "gescheit",
    "gescheiterem": "gescheit",
    "gescheiteren": "gescheit",
    "gescheiterer": "gescheit",
    "gescheiteres": "gescheit",
    "gescheitert": "scheitern",
    "gescheiterte": "gescheitert",
    "gescheitertem": "gescheitert",
    "gescheiterten": "gescheitert",
    "gescheiterter": "gescheitert",
    "gescheitertere": "gescheitert",
    "gescheiterterem": "gescheitert",
    "gescheiterteren": "gescheitert",
    "gescheiterterer": "gescheitert",
    "gescheiterteres": "gescheitert",
    "gescheitertes": "gescheitert",
    "gescheiterteste": "gescheitert",
    "gescheitertestem": "gescheitert",
    "gescheitertesten": "gescheitert",
    "gescheitertester": "gescheitert",
    "gescheitertestes": "gescheitert",
    "gescheites": "gescheit",
    "gescheiteste": "gescheit",
    "gescheitestem": "gescheit",
    "gescheitesten": "gescheit",
    "gescheitester": "gescheit",
    "gescheitestes": "gescheit",
    "geschellt": "schellen",
    "geschellte": "geschellt",
    "geschelltem": "geschellt",
    "geschellten": "geschellt",
    "geschellter": "geschellt",
    "geschelltes": "geschellt",
    "geschenkt": "schenken",
    "geschenkte": "geschenkt",
    "geschenktem": "geschenkt",
    "geschenkten": "geschenkt",
    "geschenkter": "geschenkt",
    "geschenktes": "geschenkt",
    "gescheppert": "scheppern",
    "geschepperte": "gescheppert",
    "gescheppertem": "gescheppert",
    "geschepperten": "gescheppert",
    "geschepperter": "gescheppert",
    "gescheppertes": "gescheppert",
    "geschert": "scheren",
    "gescherte": "geschert",
    "geschertem": "geschert",
    "gescherten": "geschert",
    "gescherter": "geschert",
    "geschertes": "geschert",
    "gescherzt": "scherzen",
    "gescherzte": "gescherzt",
    "gescherztem": "gescherzt",
    "gescherzten": "gescherzt",
    "gescherzter": "gescherzt",
    "gescherztes": "gescherzt",
    "gescheucht": "scheuchen",
    "gescheuchte": "gescheucht",
    "gescheuchtem": "gescheucht",
    "gescheuchten": "gescheucht",
    "gescheuchter": "gescheucht",
    "gescheuchtes": "gescheucht",
    "gescheuert": "scheuern",
    "gescheuerte": "gescheuert",
    "gescheuertem": "gescheuert",
    "gescheuerten": "gescheuert",
    "gescheuerter": "gescheuert",
    "gescheuertes": "gescheuert",
    "gescheut": "scheuen",
    "gescheute": "gescheut",
    "gescheutem": "gescheut",
    "gescheuten": "gescheut",
    "gescheuter": "gescheut",
    "gescheutes": "gescheut",
    "geschichtet": "schichten",
    "geschichtete": "geschichtet",
    "geschichtetem": "geschichtet",
    "geschichteten": "geschichtet",
    "geschichteter": "geschichtet",
    "geschichtetere": "geschichtet",
    "geschichteterem": "geschichtet",
    "geschichteteren": "geschichtet",
    "geschichteterer": "geschichtet",
    "geschichteteres": "geschichtet",
    "geschichtetes": "geschichtet",
    "geschichteteste": "geschichtet",
    "geschichtetestem": "geschichtet",
    "geschichtetesten": "geschichtet",
    "geschichtetester": "geschichtet",
    "geschichtetestes": "geschichtet",
    "geschichtliche": "geschichtlich",
    "geschichtlichem": "geschichtlich",
    "geschichtlichen": "geschichtlich",
    "geschichtlicher": "geschichtlich",
    "geschichtliches": "geschichtlich",
    "geschichtsträchtigem": "geschichtsträchtig",
    "geschichtsträchtigen": "geschichtsträchtig",
    "geschichtsträchtiger": "geschichtsträchtig",
    "geschichtsträchtigere": "geschichtsträchtig",
    "geschichtsträchtigerem": "geschichtsträchtig",
    "geschichtsträchtigeren": "geschichtsträchtig",
    "geschichtsträchtigerer": "geschichtsträchtig",
    "geschichtsträchtigeres": "geschichtsträchtig",
    "geschichtsträchtiges": "geschichtsträchtig",
    "geschichtsträchtigste": "geschichtsträchtig",
    "geschichtsträchtigstem": "geschichtsträchtig",
    "geschichtsträchtigsten": "geschichtsträchtig",
    "geschichtsträchtigster": "geschichtsträchtig",
    "geschichtsträchtigstes": "geschichtsträchtig",
    "geschickt": "schicken",
    "geschickte": "geschickt",
    "geschicktem": "geschickt",
    "geschickten": "geschickt",
    "geschickter": "geschickt",
    "geschicktere": "geschickt",
    "geschickterem": "geschickt",
    "geschickteren": "geschickt",
    "geschickterer": "geschickt",
    "geschickteres": "geschickt",
    "geschicktes": "geschickt",
    "geschickteste": "geschickt",
    "geschicktestem": "geschickt",
    "geschicktesten": "geschickt",
    "geschicktester": "geschickt",
    "geschicktestes": "geschickt",
    "geschieden": "scheiden",
    "geschiedene": "geschieden",
    "geschiedenem": "geschieden",
    "geschiedenen": "geschieden",
    "geschiedener": "geschieden",
    "geschiedenere": "geschieden",
    "geschiedenerem": "geschieden",
    "geschiedeneren": "geschieden",
    "geschiedenerer": "geschieden",
    "geschiedeneres": "geschieden",
    "geschiedenes": "geschieden",
    "geschiedenste": "geschieden",
    "geschiedenstem": "geschieden",
    "geschiedensten": "geschieden",
    "geschiedenster": "geschieden",
    "geschiedenstes": "geschieden",
    "geschiefert": "schiefern",
    "geschieferte": "geschiefert",
    "geschiefertem": "geschiefert",
    "geschieferten": "geschiefert",
    "geschieferter": "geschiefert",
    "geschiefertes": "geschiefert",
    "geschieh": "geschehen",
    "geschiehst": "geschehen",
    "geschieht": "geschehen",
    "geschielt": "schielen",
    "geschielte": "geschielt",
    "geschieltem": "geschielt",
    "geschielten": "geschielt",
    "geschielter": "geschielt",
    "geschieltes": "geschielt",
    "geschienen": "scheinen",
    "geschienene": "geschienen",
    "geschienenem": "geschienen",
    "geschienenen": "geschienen",
    "geschienener": "geschienen",
    "geschienenes": "geschienen",
    "geschifft": "schiffen",
    "geschiffte": "geschifft",
    "geschifftem": "geschifft",
    "geschifften": "geschifft",
    "geschiffter": "geschifft",
    "geschifftes": "geschifft",
    "geschildert": "schildern",
    "geschilderte": "geschildert",
    "geschildertem": "geschildert",
    "geschilderten": "geschildert",
    "geschilderter": "geschildert",
    "geschildertes": "geschildert",
    "geschillert": "schillern",
    "geschillerte": "geschillert",
    "geschillertem": "geschillert",
    "geschillerten": "geschillert",
    "geschillerter": "geschillert",
    "geschillertes": "geschillert",
    "geschimmelt": "schimmeln",
    "geschimmelte": "geschimmelt",
    "geschimmeltem": "geschimmelt",
    "geschimmelten": "geschimmelt",
    "geschimmelter": "geschimmelt",
    "geschimmeltes": "geschimmelt",
    "geschimmert": "schimmern",
    "geschimmerte": "geschimmert",
    "geschimmertem": "geschimmert",
    "geschimmerten": "geschimmert",
    "geschimmerter": "geschimmert",
    "geschimmertes": "geschimmert",
    "geschimpft": "schimpfen",
    "geschimpfte": "geschimpft",
    "geschimpftem": "geschimpft",
    "geschimpften": "geschimpft",
    "geschimpfter": "geschimpft",
    "geschimpftes": "geschimpft",
    "geschirmt": "schirmen",
    "geschirmte": "geschirmt",
    "geschirmtem": "geschirmt",
    "geschirmten": "geschirmt",
    "geschirmter": "geschirmt",
    "geschirmtes": "geschirmt",
    "geschirrt": "schirren",
    "geschirrte": "geschirrt",
    "geschirrtem": "geschirrt",
    "geschirrten": "geschirrt",
    "geschirrter": "geschirrt",
    "geschirrtes": "geschirrt",
    "geschissen": "scheißen",
    "geschissene": "geschissen",
    "geschissenem": "geschissen",
    "geschissenen": "geschissen",
    "geschissener": "geschissen",
    "geschissenes": "geschissen",
    "geschlabbert": "schlabbern",
    "geschlabberte": "geschlabbert",
    "geschlabbertem": "geschlabbert",
    "geschlabberten": "geschlabbert",
    "geschlabberter": "geschlabbert",
    "geschlabbertes": "geschlabbert",
    "geschlachtet": "schlachten",
    "geschlachtete": "geschlachtet",
    "geschlachtetem": "geschlachtet",
    "geschlachteten": "geschlachtet",
    "geschlachteter": "geschlachtet",
    "geschlachtetes": "geschlachtet",
    "geschlafen": "schlafen",
    "geschlafene": "geschlafen",
    "geschlafenem": "geschlafen",
    "geschlafenen": "geschlafen",
    "geschlafener": "geschlafen",
    "geschlafenes": "geschlafen",
    "geschlafft": "schlaffen",
    "geschlaffte": "geschlafft",
    "geschlafftem": "geschlafft",
    "geschlafften": "geschlafft",
    "geschlaffter": "geschlafft",
    "geschlafftes": "geschlafft",
    "geschlafwandelt": "schlafwandeln",
    "geschlafwandelte": "geschlafwandelt",
    "geschlafwandeltem": "geschlafwandelt",
    "geschlafwandelten": "geschlafwandelt",
    "geschlafwandelter": "geschlafwandelt",
    "geschlafwandeltes": "geschlafwandelt",
    "geschlagen": "schlagen",
    "geschlagene": "geschlagen",
    "geschlagenem": "geschlagen",
    "geschlagenen": "geschlagen",
    "geschlagener": "geschlagen",
    "geschlagenere": "geschlagen",
    "geschlagenerem": "geschlagen",
    "geschlageneren": "geschlagen",
    "geschlagenerer": "geschlagen",
    "geschlageneres": "geschlagen",
    "geschlagenes": "geschlagen",
    "geschlagenste": "geschlagen",
    "geschlagenstem": "geschlagen",
    "geschlagensten": "geschlagen",
    "geschlagenster": "geschlagen",
    "geschlagenstes": "geschlagen",
    "geschlampt": "schlampen",
    "geschlampte": "geschlampt",
    "geschlamptem": "geschlampt",
    "geschlampten": "geschlampt",
    "geschlampter": "geschlampt",
    "geschlamptere": "geschlampt",
    "geschlampterem": "geschlampt",
    "geschlampteren": "geschlampt",
    "geschlampterer": "geschlampt",
    "geschlampteres": "geschlampt",
    "geschlamptes": "geschlampt",
    "geschlampteste": "geschlampt",
    "geschlamptestem": "geschlampt",
    "geschlamptesten": "geschlampt",
    "geschlamptester": "geschlampt",
    "geschlamptestes": "geschlampt",
    "geschlappt": "schlappen",
    "geschlappte": "geschlappt",
    "geschlapptem": "geschlappt",
    "geschlappten": "geschlappt",
    "geschlappter": "geschlappt",
    "geschlapptes": "geschlappt",
    "geschlaucht": "schlauchen",
    "geschlauchte": "geschlaucht",
    "geschlauchtem": "geschlaucht",
    "geschlauchten": "geschlaucht",
    "geschlauchter": "geschlaucht",
    "geschlauchtes": "geschlaucht",
    "geschlechtlichem": "geschlechtlich",
    "geschlechtlichen": "geschlechtlich",
    "geschlechtlicher": "geschlechtlich",
    "geschlechtliches": "geschlechtlich",
    "geschlechtskrankem": "geschlechtskrank",
    "geschlechtskranken": "geschlechtskrank",
    "geschlechtskranker": "geschlechtskrank",
    "geschlechtskrankes": "geschlechtskrank",
    "geschlechtsreife": "geschlechtsreif",
    "geschlechtsreifem": "geschlechtsreif",
    "geschlechtsreifen": "geschlechtsreif",
    "geschlechtsreifer": "geschlechtsreif",
    "geschlechtsreifere": "geschlechtsreif",
    "geschlechtsreiferem": "geschlechtsreif",
    "geschlechtsreiferen": "geschlechtsreif",
    "geschlechtsreiferer": "geschlechtsreif",
    "geschlechtsreiferes": "geschlechtsreif",
    "geschlechtsreifes": "geschlechtsreif",
    "geschlechtsreifste": "geschlechtsreif",
    "geschlechtsreifstem": "geschlechtsreif",
    "geschlechtsreifsten": "geschlechtsreif",
    "geschlechtsreifster": "geschlechtsreif",
    "geschlechtsreifstes": "geschlechtsreif",
    "geschleckert": "schleckern",
    "geschleckerte": "geschleckert",
    "geschleckertem": "geschleckert",
    "geschleckerten": "geschleckert",
    "geschleckerter": "geschleckert",
    "geschleckertes": "geschleckert",
    "geschleift": "schleifen",
    "geschleifte": "geschleift",
    "geschleiftem": "geschleift",
    "geschleiften": "geschleift",
    "geschleifter": "geschleift",
    "geschleiftes": "geschleift",
    "geschleimt": "schleimen",
    "geschleimte": "geschleimt",
    "geschleimtem": "geschleimt",
    "geschleimten": "geschleimt",
    "geschleimter": "geschleimt",
    "geschleimtere": "geschleimt",
    "geschleimterem": "geschleimt",
    "geschleimteren": "geschleimt",
    "geschleimterer": "geschleimt",
    "geschleimteres": "geschleimt",
    "geschleimtes": "geschleimt",
    "geschleimteste": "geschleimt",
    "geschleimtestem": "geschleimt",
    "geschleimtesten": "geschleimt",
    "geschleimtester": "geschleimt",
    "geschleimtestes": "geschleimt",
    "geschleißt": "schleißen",
    "geschleißte": "geschleißt",
    "geschleißtem": "geschleißt",
    "geschleißten": "geschleißt",
    "geschleißter": "geschleißt",
    "geschleißtes": "geschleißt",
    "geschlemmt": "schlemmen",
    "geschlemmte": "geschlemmt",
    "geschlemmtem": "geschlemmt",
    "geschlemmten": "geschlemmt",
    "geschlemmter": "geschlemmt",
    "geschlemmtes": "geschlemmt",
    "geschlendert": "schlendern",
    "geschlenderte": "geschlendert",
    "geschlendertem": "geschlendert",
    "geschlenderten": "geschlendert",
    "geschlenderter": "geschlendert",
    "geschlendertes": "geschlendert",
    "geschlenkert": "schlenkern",
    "geschlenkerte": "geschlenkert",
    "geschlenkertem": "geschlenkert",
    "geschlenkerten": "geschlenkert",
    "geschlenkerter": "geschlenkert",
    "geschlenkertes": "geschlenkert",
    "geschlenzt": "schlenzen",
    "geschlenzte": "geschlenzt",
    "geschlenztem": "geschlenzt",
    "geschlenzten": "geschlenzt",
    "geschlenzter": "geschlenzt",
    "geschlenztes": "geschlenzt",
    "geschleppt": "schleppen",
    "geschleppte": "geschleppt",
    "geschlepptem": "geschleppt",
    "geschleppten": "geschleppt",
    "geschleppter": "geschleppt",
    "geschlepptes": "geschleppt",
    "geschleudert": "schleudern",
    "geschleuderte": "geschleudert",
    "geschleudertem": "geschleudert",
    "geschleuderten": "geschleudert",
    "geschleuderter": "geschleudert",
    "geschleudertere": "geschleudert",
    "geschleuderterem": "geschleudert",
    "geschleuderteren": "geschleudert",
    "geschleuderterer": "geschleudert",
    "geschleuderteres": "geschleudert",
    "geschleudertes": "geschleudert",
    "geschleuderteste": "geschleudert",
    "geschleudertestem": "geschleudert",
    "geschleudertesten": "geschleudert",
    "geschleudertester": "geschleudert",
    "geschleudertestes": "geschleudert",
    "geschleust": "schleusen",
    "geschleuste": "geschleust",
    "geschleustem": "geschleust",
    "geschleusten": "geschleust",
    "geschleuster": "geschleust",
    "geschleustes": "geschleust",
    "geschlichen": "schleichen",
    "geschlichene": "geschlichen",
    "geschlichenem": "geschlichen",
    "geschlichenen": "geschlichen",
    "geschlichener": "geschlichen",
    "geschlichenere": "geschlichen",
    "geschlichenerem": "geschlichen",
    "geschlicheneren": "geschlichen",
    "geschlichenerer": "geschlichen",
    "geschlicheneres": "geschlichen",
    "geschlichenes": "geschlichen",
    "geschlichenste": "geschlichen",
    "geschlichenstem": "geschlichen",
    "geschlichensten": "geschlichen",
    "geschlichenster": "geschlichen",
    "geschlichenstes": "geschlichen",
    "geschliffen": "schleifen",
    "geschliffene": "geschliffen",
    "geschliffenem": "geschliffen",
    "geschliffenen": "geschliffen",
    "geschliffener": "geschliffen",
    "geschliffenere": "geschliffen",
    "geschliffenerem": "geschliffen",
    "geschliffeneren": "geschliffen",
    "geschliffenerer": "geschliffen",
    "geschliffeneres": "geschliffen",
    "geschliffenes": "geschliffen",
    "geschliffenste": "geschliffen",
    "geschliffenstem": "geschliffen",
    "geschliffensten": "geschliffen",
    "geschliffenster": "geschliffen",
    "geschliffenstes": "geschliffen",
    "geschlingert": "schlingern",
    "geschlingerte": "geschlingert",
    "geschlingertem": "geschlingert",
    "geschlingerten": "geschlingert",
    "geschlingerter": "geschlingert",
    "geschlingertes": "geschlingert",
    "geschlissen": "schleißen",
    "geschlissene": "geschlissen",
    "geschlissenem": "geschlissen",
    "geschlissenen": "geschlissen",
    "geschlissener": "geschlissen",
    "geschlissenere": "geschlissen",
    "geschlissenerem": "geschlissen",
    "geschlisseneren": "geschlissen",
    "geschlissenerer": "geschlissen",
    "geschlisseneres": "geschlissen",
    "geschlissenes": "geschlissen",
    "geschlissenste": "geschlissen",
    "geschlissenstem": "geschlissen",
    "geschlissensten": "geschlissen",
    "geschlissenster": "geschlissen",
    "geschlissenstes": "geschlissen",
    "geschlittert": "schlittern",
    "geschlitterte": "geschlittert",
    "geschlittertem": "geschlittert",
    "geschlitterten": "geschlittert",
    "geschlitterter": "geschlittert",
    "geschlittertes": "geschlittert",
    "geschlitzt": "schlitzen",
    "geschlitzte": "geschlitzt",
    "geschlitztem": "geschlitzt",
    "geschlitzten": "geschlitzt",
    "geschlitzter": "geschlitzt",
    "geschlitztes": "geschlitzt",
    "geschlossen": "schließen",
    "geschlossene": "geschlossen",
    "geschlossenem": "geschlossen",
    "geschlossenen": "geschlossen",
    "geschlossener": "geschlossen",
    "geschlossenere": "geschlossen",
    "geschlossenerem": "geschlossen",
    "geschlosseneren": "geschlossen",
    "geschlossenerer": "geschlossen",
    "geschlosseneres": "geschlossen",
    "geschlossenes": "geschlossen",
    "geschlossenste": "geschlossen",
    "geschlossenstem": "geschlossen",
    "geschlossensten": "geschlossen",
    "geschlossenster": "geschlossen",
    "geschlossenstes": "geschlossen",
    "geschlossert": "schlossern",
    "geschlosserte": "geschlossert",
    "geschlossertem": "geschlossert",
    "geschlosserten": "geschlossert",
    "geschlosserter": "geschlossert",
    "geschlossertes": "geschlossert",
    "geschlottert": "schlottern",
    "geschlotterte": "geschlottert",
    "geschlottertem": "geschlottert",
    "geschlotterten": "geschlottert",
    "geschlotterter": "geschlottert",
    "geschlottertes": "geschlottert",
    "geschluchzt": "schluchzen",
    "geschluchzte": "geschluchzt",
    "geschluchztem": "geschluchzt",
    "geschluchzten": "geschluchzt",
    "geschluchzter": "geschluchzt",
    "geschluchztes": "geschluchzt",
    "geschluckt": "schlucken",
    "geschluckte": "geschluckt",
    "geschlucktem": "geschluckt",
    "geschluckten": "geschluckt",
    "geschluckter": "geschluckt",
    "geschlucktes": "geschluckt",
    "geschludert": "schludern",
    "geschluderte": "geschludert",
    "geschludertem": "geschludert",
    "geschluderten": "geschludert",
    "geschluderter": "geschludert",
    "geschludertes": "geschludert",
    "geschlummert": "schlummern",
    "geschlummerte": "geschlummert",
    "geschlummertem": "geschlummert",
    "geschlummerten": "geschlummert",
    "geschlummerter": "geschlummert",
    "geschlummertes": "geschlummert",
    "geschlungen": "schlingen",
    "geschlungene": "geschlungen",
    "geschlungenem": "geschlungen",
    "geschlungenen": "geschlungen",
    "geschlungener": "geschlungen",
    "geschlungenere": "geschlungen",
    "geschlungenerem": "geschlungen",
    "geschlungeneren": "geschlungen",
    "geschlungenerer": "geschlungen",
    "geschlungeneres": "geschlungen",
    "geschlungenes": "geschlungen",
    "geschlungenste": "geschlungen",
    "geschlungenstem": "geschlungen",
    "geschlungensten": "geschlungen",
    "geschlungenster": "geschlungen",
    "geschlungenstes": "geschlungen",
    "geschläfert": "schläfern",
    "geschläferte": "geschläfert",
    "geschläfertem": "geschläfert",
    "geschläferten": "geschläfert",
    "geschläferter": "geschläfert",
    "geschläfertes": "geschläfert",
    "geschlämmt": "schlämmen",
    "geschlämmte": "geschlämmt",
    "geschlämmtem": "geschlämmt",
    "geschlämmten": "geschlämmt",
    "geschlämmter": "geschlämmt",
    "geschlämmtes": "geschlämmt",
    "geschlängelt": "schlängeln",
    "geschlängelte": "geschlängelt",
    "geschlängeltem": "geschlängelt",
    "geschlängelten": "geschlängelt",
    "geschlängelter": "geschlängelt",
    "geschlängeltes": "geschlängelt",
    "geschlüpft": "schlüpfen",
    "geschlüpfte": "geschlüpft",
    "geschlüpftem": "geschlüpft",
    "geschlüpften": "geschlüpft",
    "geschlüpfter": "geschlüpft",
    "geschlüpftes": "geschlüpft",
    "geschlürft": "schlürfen",
    "geschlürfte": "geschlürft",
    "geschlürftem": "geschlürft",
    "geschlürften": "geschlürft",
    "geschlürfter": "geschlürft",
    "geschlürftes": "geschlürft",
    "geschlüsselt": "schlüsseln",
    "geschlüsselte": "geschlüsselt",
    "geschlüsseltem": "geschlüsselt",
    "geschlüsselten": "geschlüsselt",
    "geschlüsselter": "geschlüsselt",
    "geschlüsseltes": "geschlüsselt",
    "geschmachtet": "schmachten",
    "geschmachtete": "geschmachtet",
    "geschmachtetem": "geschmachtet",
    "geschmachteten": "geschmachtet",
    "geschmachteter": "geschmachtet",
    "geschmachtetere": "geschmachtet",
    "geschmachteterem": "geschmachtet",
    "geschmachteteren": "geschmachtet",
    "geschmachteterer": "geschmachtet",
    "geschmachteteres": "geschmachtet",
    "geschmachtetes": "geschmachtet",
    "geschmachteteste": "geschmachtet",
    "geschmachtetestem": "geschmachtet",
    "geschmachtetesten": "geschmachtet",
    "geschmachtetester": "geschmachtet",
    "geschmachtetestes": "geschmachtet",
    "geschmacklichem": "geschmacklich",
    "geschmacklichen": "geschmacklich",
    "geschmacklicher": "geschmacklich",
    "geschmackliches": "geschmacklich",
    "geschmacklose": "geschmacklos",
    "geschmacklosem": "geschmacklos",
    "geschmacklosen": "geschmacklos",
    "geschmackloser": "geschmacklos",
    "geschmacklosere": "geschmacklos",
    "geschmackloserem": "geschmacklos",
    "geschmackloseren": "geschmacklos",
    "geschmackloserer": "geschmacklos",
    "geschmackloseres": "geschmacklos",
    "geschmackloses": "geschmacklos",
    "geschmackloseste": "geschmacklos",
    "geschmacklosestem": "geschmacklos",
    "geschmacklosesten": "geschmacklos",
    "geschmacklosester": "geschmacklos",
    "geschmacklosestes": "geschmacklos",
    "geschmackvollem": "geschmackvoll",
    "geschmackvollen": "geschmackvoll",
    "geschmackvoller": "geschmackvoll",
    "geschmackvollere": "geschmackvoll",
    "geschmackvollerem": "geschmackvoll",
    "geschmackvolleren": "geschmackvoll",
    "geschmackvollerer": "geschmackvoll",
    "geschmackvolleres": "geschmackvoll",
    "geschmackvolles": "geschmackvoll",
    "geschmackvollste": "geschmackvoll",
    "geschmackvollstem": "geschmackvoll",
    "geschmackvollsten": "geschmackvoll",
    "geschmackvollster": "geschmackvoll",
    "geschmackvollstes": "geschmackvoll",
    "geschmatzt": "schmatzen",
    "geschmatzte": "geschmatzt",
    "geschmatztem": "geschmatzt",
    "geschmatzten": "geschmatzt",
    "geschmatzter": "geschmatzt",
    "geschmatztes": "geschmatzt",
    "geschmeckt": "schmecken",
    "geschmeckte": "geschmeckt",
    "geschmecktem": "geschmeckt",
    "geschmeckten": "geschmeckt",
    "geschmeckter": "geschmeckt",
    "geschmecktes": "geschmeckt",
    "geschmeichelt": "schmeicheln",
    "geschmeichelte": "geschmeichelt",
    "geschmeicheltem": "geschmeichelt",
    "geschmeichelten": "geschmeichelt",
    "geschmeichelter": "geschmeichelt",
    "geschmeicheltes": "geschmeichelt",
    "geschmeidige": "geschmeidig",
    "geschmeidigem": "geschmeidig",
    "geschmeidigen": "geschmeidig",
    "geschmeidiger": "geschmeidig",
    "geschmeidigere": "geschmeidig",
    "geschmeidigerem": "geschmeidig",
    "geschmeidigeren": "geschmeidig",
    "geschmeidigerer": "geschmeidig",
    "geschmeidigeres": "geschmeidig",
    "geschmeidiges": "geschmeidig",
    "geschmeidigste": "geschmeidig",
    "geschmeidigstem": "geschmeidig",
    "geschmeidigsten": "geschmeidig",
    "geschmeidigster": "geschmeidig",
    "geschmeidigstes": "geschmeidig",
    "geschmerzt": "schmerzen",
    "geschmerzte": "geschmerzt",
    "geschmerztem": "geschmerzt",
    "geschmerzten": "geschmerzt",
    "geschmerzter": "geschmerzt",
    "geschmerztes": "geschmerzt",
    "geschmettert": "schmettern",
    "geschmetterte": "geschmettert",
    "geschmettertem": "geschmettert",
    "geschmetterten": "geschmettert",
    "geschmetterter": "geschmettert",
    "geschmettertes": "geschmettert",
    "geschmiedet": "schmieden",
    "geschmiedete": "geschmiedet",
    "geschmiedetem": "geschmiedet",
    "geschmiedeten": "geschmiedet",
    "geschmiedeter": "geschmiedet",
    "geschmiedetes": "geschmiedet",
    "geschmiegt": "schmiegen",
    "geschmiegte": "geschmiegt",
    "geschmiegtem": "geschmiegt",
    "geschmiegten": "geschmiegt",
    "geschmiegter": "geschmiegt",
    "geschmiegtes": "geschmiegt",
    "geschmiert": "schmieren",
    "geschmierte": "geschmiert",
    "geschmiertem": "geschmiert",
    "geschmierten": "geschmiert",
    "geschmierter": "geschmiert",
    "geschmiertes": "geschmiert",
    "geschminkt": "schminken",
    "geschminkte": "geschminkt",
    "geschminktem": "geschminkt",
    "geschminkten": "geschminkt",
    "geschminkter": "geschminkt",
    "geschminktes": "geschminkt",
    "geschmirgelt": "schmirgeln",
    "geschmirgelte": "geschmirgelt",
    "geschmirgeltem": "geschmirgelt",
    "geschmirgelten": "geschmirgelt",
    "geschmirgelter": "geschmirgelt",
    "geschmirgeltes": "geschmirgelt",
    "geschmissen": "schmeißen",
    "geschmissene": "geschmissen",
    "geschmissenem": "geschmissen",
    "geschmissenen": "geschmissen",
    "geschmissener": "geschmissen",
    "geschmissenes": "geschmissen",
    "geschmollt": "schmollen",
    "geschmollte": "geschmollt",
    "geschmolltem": "geschmollt",
    "geschmollten": "geschmollt",
    "geschmollter": "geschmollt",
    "geschmolltes": "geschmollt",
    "geschmolzen": "schmelzen",
    "geschmolzene": "geschmolzen",
    "geschmolzenem": "geschmolzen",
    "geschmolzenen": "geschmolzen",
    "geschmolzener": "geschmolzen",
    "geschmolzenere": "geschmolzen",
    "geschmolzenerem": "geschmolzen",
    "geschmolzeneren": "geschmolzen",
    "geschmolzenerer": "geschmolzen",
    "geschmolzeneres": "geschmolzen",
    "geschmolzenes": "geschmolzen",
    "geschmolzenste": "geschmolzen",
    "geschmolzenstem": "geschmolzen",
    "geschmolzensten": "geschmolzen",
    "geschmolzenster": "geschmolzen",
    "geschmolzenstes": "geschmolzen",
    "geschmort": "schmoren",
    "geschmorte": "geschmort",
    "geschmortem": "geschmort",
    "geschmorten": "geschmort",
    "geschmorter": "geschmort",
    "geschmortes": "geschmort",
    "geschmuddelt": "schmuddeln",
    "geschmuddelte": "geschmuddelt",
    "geschmuddeltem": "geschmuddelt",
    "geschmuddelten": "geschmuddelt",
    "geschmuddelter": "geschmuddelt",
    "geschmuddeltes": "geschmuddelt",
    "geschmuggelt": "schmuggeln",
    "geschmuggelte": "geschmuggelt",
    "geschmuggeltem": "geschmuggelt",
    "geschmuggelten": "geschmuggelt",
    "geschmuggelter": "geschmuggelt",
    "geschmuggeltes": "geschmuggelt",
    "geschmunzelt": "schmunzeln",
    "geschmunzelte": "geschmunzelt",
    "geschmunzeltem": "geschmunzelt",
    "geschmunzelten": "geschmunzelt",
    "geschmunzelter": "geschmunzelt",
    "geschmunzeltes": "geschmunzelt",
    "geschmust": "schmusen",
    "geschmuste": "geschmust",
    "geschmustem": "geschmust",
    "geschmusten": "geschmust",
    "geschmuster": "geschmust",
    "geschmustes": "geschmust",
    "geschmälert": "schmälern",
    "geschmälerte": "geschmälert",
    "geschmälertem": "geschmälert",
    "geschmälerten": "geschmälert",
    "geschmälerter": "geschmälert",
    "geschmälertes": "geschmälert",
    "geschmökert": "schmökern",
    "geschmökerte": "geschmökert",
    "geschmökertem": "geschmökert",
    "geschmökerten": "geschmökert",
    "geschmökerter": "geschmökert",
    "geschmökertes": "geschmökert",
    "geschmückt": "schmücken",
    "geschmückte": "geschmückt",
    "geschmücktem": "geschmückt",
    "geschmückten": "geschmückt",
    "geschmückter": "geschmückt",
    "geschmücktere": "geschmückt",
    "geschmückterem": "geschmückt",
    "geschmückteren": "geschmückt",
    "geschmückterer": "geschmückt",
    "geschmückteres": "geschmückt",
    "geschmücktes": "geschmückt",
    "geschmückteste": "geschmückt",
    "geschmücktestem": "geschmückt",
    "geschmücktesten": "geschmückt",
    "geschmücktester": "geschmückt",
    "geschmücktestes": "geschmückt",
    "geschnallt": "schnallen",
    "geschnallte": "geschnallt",
    "geschnalltem": "geschnallt",
    "geschnallten": "geschnallt",
    "geschnallter": "geschnallt",
    "geschnalltes": "geschnallt",
    "geschnalzt": "schnalzen",
    "geschnalzte": "geschnalzt",
    "geschnalztem": "geschnalzt",
    "geschnalzten": "geschnalzt",
    "geschnalzter": "geschnalzt",
    "geschnalztes": "geschnalzt",
    "geschnappt": "schnappen",
    "geschnappte": "geschnappt",
    "geschnapptem": "geschnappt",
    "geschnappten": "geschnappt",
    "geschnappter": "geschnappt",
    "geschnapptes": "geschnappt",
    "geschnarcht": "schnarchen",
    "geschnarchte": "geschnarcht",
    "geschnarchtem": "geschnarcht",
    "geschnarchten": "geschnarcht",
    "geschnarchter": "geschnarcht",
    "geschnarchtes": "geschnarcht",
    "geschnattert": "schnattern",
    "geschnatterte": "geschnattert",
    "geschnattertem": "geschnattert",
    "geschnatterten": "geschnattert",
    "geschnatterter": "geschnattert",
    "geschnattertes": "geschnattert",
    "geschnaubt": "schnauben",
    "geschnaubte": "geschnaubt",
    "geschnaubtem": "geschnaubt",
    "geschnaubten": "geschnaubt",
    "geschnaubter": "geschnaubt",
    "geschnaubtes": "geschnaubt",
    "geschnauft": "schnaufen",
    "geschnaufte": "geschnauft",
    "geschnauftem": "geschnauft",
    "geschnauften": "geschnauft",
    "geschnaufter": "geschnauft",
    "geschnauftes": "geschnauft",
    "geschnauzt": "schnauzen",
    "geschnauzte": "geschnauzt",
    "geschnauztem": "geschnauzt",
    "geschnauzten": "geschnauzt",
    "geschnauzter": "geschnauzt",
    "geschnauztes": "geschnauzt",
    "geschneidert": "schneidern",
    "geschneiderte": "geschneidert",
    "geschneidertem": "geschneidert",
    "geschneiderten": "geschneidert",
    "geschneiderter": "geschneidert",
    "geschneidertes": "geschneidert",
    "geschneit": "schneien",
    "geschneite": "geschneit",
    "geschneitem": "geschneit",
    "geschneiten": "geschneit",
    "geschneiter": "geschneit",
    "geschneites": "geschneit",
    "geschnellt": "schnellen",
    "geschnellte": "geschnellt",
    "geschnelltem": "geschnellt",
    "geschnellten": "geschnellt",
    "geschnellter": "geschnellt",
    "geschnelltes": "geschnellt",
    "geschneuzt": "schneuzen",
    "geschneuzte": "geschneuzt",
    "geschneuztem": "geschneuzt",
    "geschneuzten": "geschneuzt",
    "geschneuzter": "geschneuzt",
    "geschneuztes": "geschneuzt",
    "geschnieft": "schniefen",
    "geschniefte": "geschnieft",
    "geschnieftem": "geschnieft",
    "geschnieften": "geschnieft",
    "geschniefter": "geschnieft",
    "geschnieftes": "geschnieft",
    "geschniegelte": "geschniegelt",
    "geschniegeltem": "geschniegelt",
    "geschniegelten": "geschniegelt",
    "geschniegelter": "geschniegelt",
    "geschniegeltere": "geschniegelt",
    "geschniegelterem": "geschniegelt",
    "geschniegelteren": "geschniegelt",
    "geschniegelterer": "geschniegelt",
    "geschniegelteres": "geschniegelt",
    "geschniegeltes": "geschniegelt",
    "geschniegelteste": "geschniegelt",
    "geschniegeltestem": "geschniegelt",
    "geschniegeltesten": "geschniegelt",
    "geschniegeltester": "geschniegelt",
    "geschniegeltestes": "geschniegelt",
    "geschnippt": "schnippen",
    "geschnippte": "geschnippt",
    "geschnipptem": "geschnippt",
    "geschnippten": "geschnippt",
    "geschnippter": "geschnippt",
    "geschnipptes": "geschnippt",
    "geschnipselt": "schnipseln",
    "geschnipselte": "geschnipselt",
    "geschnipseltem": "geschnipselt",
    "geschnipselten": "geschnipselt",
    "geschnipselter": "geschnipselt",
    "geschnipseltes": "geschnipselt",
    "geschnitten": "schneiden",
    "geschnittene": "geschnitten",
    "geschnittenem": "geschnitten",
    "geschnittenen": "geschnitten",
    "geschnittener": "geschnitten",
    "geschnittenes": "geschnitten",
    "geschnitzt": "schnitzen",
    "geschnitzte": "geschnitzt",
    "geschnitztem": "geschnitzt",
    "geschnitzten": "geschnitzt",
    "geschnitzter": "geschnitzt",
    "geschnitztes": "geschnitzt",
    "geschnorchelt": "schnorcheln",
    "geschnorchelte": "geschnorchelt",
    "geschnorcheltem": "geschnorchelt",
    "geschnorchelten": "geschnorchelt",
    "geschnorchelter": "geschnorchelt",
    "geschnorcheltes": "geschnorchelt",
    "geschnorrt": "schnorren",
    "geschnorrte": "geschnorrt",
    "geschnorrtem": "geschnorrt",
    "geschnorrten": "geschnorrt",
    "geschnorrter": "geschnorrt",
    "geschnorrtes": "geschnorrt",
    "geschnuppert": "schnuppern",
    "geschnupperte": "geschnuppert",
    "geschnuppertem": "geschnuppert",
    "geschnupperten": "geschnuppert",
    "geschnupperter": "geschnuppert",
    "geschnuppertes": "geschnuppert",
    "geschnurrt": "schnurren",
    "geschnurrte": "geschnurrt",
    "geschnurrtem": "geschnurrt",
    "geschnurrten": "geschnurrt",
    "geschnurrter": "geschnurrt",
    "geschnurrtes": "geschnurrt",
    "geschnäuzt": "schnäuzen",
    "geschnäuztem": "geschnäuzt",
    "geschnäuzter": "geschnäuzt",
    "geschnäuztes": "geschnäuzt",
    "geschnüffelt": "schnüffeln",
    "geschnüffelte": "geschnüffelt",
    "geschnüffeltem": "geschnüffelt",
    "geschnüffelten": "geschnüffelt",
    "geschnüffelter": "geschnüffelt",
    "geschnüffeltes": "geschnüffelt",
    "geschnürt": "schnüren",
    "geschnürte": "geschnürt",
    "geschnürtem": "geschnürt",
    "geschnürten": "geschnürt",
    "geschnürter": "geschnürt",
    "geschnürtes": "geschnürt",
    "geschoben": "schieben",
    "geschobene": "geschoben",
    "geschobenem": "geschoben",
    "geschobenen": "geschoben",
    "geschobener": "geschoben",
    "geschobenere": "geschoben",
    "geschobenerem": "geschoben",
    "geschobeneren": "geschoben",
    "geschobenerer": "geschoben",
    "geschobeneres": "geschoben",
    "geschobenes": "geschoben",
    "geschobenste": "geschoben",
    "geschobenstem": "geschoben",
    "geschobensten": "geschoben",
    "geschobenster": "geschoben",
    "geschobenstes": "geschoben",
    "geschockt": "schocken",
    "geschockte": "geschockt",
    "geschocktem": "geschockt",
    "geschockten": "geschockt",
    "geschockter": "geschockt",
    "geschocktere": "geschockt",
    "geschockterem": "geschockt",
    "geschockteren": "geschockt",
    "geschockterer": "geschockt",
    "geschockteres": "geschockt",
    "geschocktes": "geschockt",
    "geschockteste": "geschockt",
    "geschocktestem": "geschockt",
    "geschocktesten": "geschockt",
    "geschocktester": "geschockt",
    "geschocktestes": "geschockt",
    "gescholten": "schelten",
    "gescholtene": "gescholten",
    "gescholtenem": "gescholten",
    "gescholtenen": "gescholten",
    "gescholtener": "gescholten",
    "gescholtenere": "gescholten",
    "gescholtenerem": "gescholten",
    "gescholteneren": "gescholten",
    "gescholtenerer": "gescholten",
    "gescholteneres": "gescholten",
    "gescholtenes": "gescholten",
    "gescholtenste": "gescholten",
    "gescholtenstem": "gescholten",
    "gescholtensten": "gescholten",
    "gescholtenster": "gescholten",
    "gescholtenstes": "gescholten",
    "geschont": "schonen",
    "geschonte": "geschont",
    "geschontem": "geschont",
    "geschonten": "geschont",
    "geschonter": "geschont",
    "geschontere": "geschont",
    "geschonterem": "geschont",
    "geschonteren": "geschont",
    "geschonterer": "geschont",
    "geschonteres": "geschont",
    "geschontes": "geschont",
    "geschonteste": "geschont",
    "geschontestem": "geschont",
    "geschontesten": "geschont",
    "geschontester": "geschont",
    "geschontestes": "geschont",
    "geschoppt": "schoppen",
    "geschoppte": "geschoppt",
    "geschopptem": "geschoppt",
    "geschoppten": "geschoppt",
    "geschoppter": "geschoppt",
    "geschopptes": "geschoppt",
    "geschoren": "scheren",
    "geschorene": "geschoren",
    "geschorenem": "geschoren",
    "geschorenen": "geschoren",
    "geschorener": "geschoren",
    "geschorenere": "geschoren",
    "geschorenerem": "geschoren",
    "geschoreneren": "geschoren",
    "geschorenerer": "geschoren",
    "geschoreneres": "geschoren",
    "geschorenes": "geschoren",
    "geschorenste": "geschoren",
    "geschorenstem": "geschoren",
    "geschorensten": "geschoren",
    "geschorenster": "geschoren",
    "geschorenstes": "geschoren",
    "geschossen": "schießen",
    "geschossene": "geschossen",
    "geschossenem": "geschossen",
    "geschossenen": "geschossen",
    "geschossener": "geschossen",
    "geschossenes": "geschossen",
    "geschottert": "schottern",
    "geschotterte": "geschottert",
    "geschottertem": "geschottert",
    "geschotterten": "geschottert",
    "geschotterter": "geschottert",
    "geschottertes": "geschottert",
    "geschrammt": "schrammen",
    "geschrammte": "geschrammt",
    "geschrammtem": "geschrammt",
    "geschrammten": "geschrammt",
    "geschrammter": "geschrammt",
    "geschrammtes": "geschrammt",
    "geschraubt": "schrauben",
    "geschraubte": "geschraubt",
    "geschraubtem": "geschraubt",
    "geschraubten": "geschraubt",
    "geschraubter": "geschraubt",
    "geschraubtes": "geschraubt",
    "geschreckt": "schrecken",
    "geschreckte": "geschreckt",
    "geschrecktem": "geschreckt",
    "geschreckten": "geschreckt",
    "geschreckter": "geschreckt",
    "geschrecktes": "geschreckt",
    "geschreinert": "schreinern",
    "geschreinerte": "geschreinert",
    "geschreinertem": "geschreinert",
    "geschreinerten": "geschreinert",
    "geschreinerter": "geschreinert",
    "geschreinertes": "geschreinert",
    "geschrieben": "schreiben",
    "geschriebene": "geschrieben",
    "geschriebenem": "geschrieben",
    "geschriebenen": "geschrieben",
    "geschriebener": "geschrieben",
    "geschriebenes": "geschrieben",
    "geschrien": "schreien",
    "geschriene": "geschrien",
    "geschrienem": "geschrien",
    "geschrienen": "geschrien",
    "geschriener": "geschrien",
    "geschrienes": "geschrien",
    "geschritten": "schreiten",
    "geschrittene": "geschritten",
    "geschrittenem": "geschritten",
    "geschrittenen": "geschritten",
    "geschrittener": "geschritten",
    "geschrittenes": "geschritten",
    "geschrocken": "schrecken",
    "geschrockene": "geschrocken",
    "geschrockenem": "geschrocken",
    "geschrockenen": "geschrocken",
    "geschrockener": "geschrocken",
    "geschrockenes": "geschrocken",
    "geschrubbt": "schrubben",
    "geschrubbte": "geschrubbt",
    "geschrubbtem": "geschrubbt",
    "geschrubbten": "geschrubbt",
    "geschrubbter": "geschrubbt",
    "geschrubbtes": "geschrubbt",
    "geschrumpelt": "schrumpeln",
    "geschrumpelte": "geschrumpelt",
    "geschrumpeltem": "geschrumpelt",
    "geschrumpelten": "geschrumpelt",
    "geschrumpelter": "geschrumpelt",
    "geschrumpeltere": "geschrumpelt",
    "geschrumpelterem": "geschrumpelt",
    "geschrumpelteren": "geschrumpelt",
    "geschrumpelterer": "geschrumpelt",
    "geschrumpelteres": "geschrumpelt",
    "geschrumpeltes": "geschrumpelt",
    "geschrumpelteste": "geschrumpelt",
    "geschrumpeltestem": "geschrumpelt",
    "geschrumpeltesten": "geschrumpelt",
    "geschrumpeltester": "geschrumpelt",
    "geschrumpeltestes": "geschrumpelt",
    "geschrumpft": "schrumpfen",
    "geschrumpfte": "geschrumpft",
    "geschrumpftem": "geschrumpft",
    "geschrumpften": "geschrumpft",
    "geschrumpfter": "geschrumpft",
    "geschrumpftes": "geschrumpft",
    "geschrägt": "schrägen",
    "geschrägte": "geschrägt",
    "geschrägtem": "geschrägt",
    "geschrägten": "geschrägt",
    "geschrägter": "geschrägt",
    "geschrägtes": "geschrägt",
    "geschränkt": "schränken",
    "geschränkte": "geschränkt",
    "geschränktem": "geschränkt",
    "geschränkten": "geschränkt",
    "geschränkter": "geschränkt",
    "geschränktes": "geschränkt",
    "geschröpft": "schröpfen",
    "geschröpfte": "geschröpft",
    "geschröpftem": "geschröpft",
    "geschröpften": "geschröpft",
    "geschröpfter": "geschröpft",
    "geschröpftere": "geschröpft",
    "geschröpfterem": "geschröpft",
    "geschröpfteren": "geschröpft",
    "geschröpfterer": "geschröpft",
    "geschröpfteres": "geschröpft",
    "geschröpftes": "geschröpft",
    "geschröpfteste": "geschröpft",
    "geschröpftestem": "geschröpft",
    "geschröpftesten": "geschröpft",
    "geschröpftester": "geschröpft",
    "geschröpftestes": "geschröpft",
    "geschubst": "schubsen",
    "geschubste": "geschubst",
    "geschubstem": "geschubst",
    "geschubsten": "geschubst",
    "geschubster": "geschubst",
    "geschubstes": "geschubst",
    "geschuckelt": "schuckeln",
    "geschuckelte": "geschuckelt",
    "geschuckeltem": "geschuckelt",
    "geschuckelten": "geschuckelt",
    "geschuckelter": "geschuckelt",
    "geschuckeltes": "geschuckelt",
    "geschuftet": "schuften",
    "geschuftete": "geschuftet",
    "geschuftetem": "geschuftet",
    "geschufteten": "geschuftet",
    "geschufteter": "geschuftet",
    "geschuftetes": "geschuftet",
    "geschuldet": "schulden",
    "geschuldete": "geschuldet",
    "geschuldetem": "geschuldet",
    "geschuldeten": "geschuldet",
    "geschuldeter": "geschuldet",
    "geschuldetes": "geschuldet",
    "geschult": "schulen",
    "geschulte": "geschult",
    "geschultem": "geschult",
    "geschulten": "geschult",
    "geschulter": "geschult",
    "geschultere": "geschult",
    "geschulterem": "geschult",
    "geschulteren": "geschult",
    "geschulterer": "geschult",
    "geschulteres": "geschult",
    "geschultert": "schultern",
    "geschulterte": "geschultert",
    "geschultertem": "geschultert",
    "geschulterten": "geschultert",
    "geschulterter": "geschultert",
    "geschultertes": "geschultert",
    "geschultes": "geschult",
    "geschulteste": "geschult",
    "geschultestem": "geschult",
    "geschultesten": "geschult",
    "geschultester": "geschult",
    "geschultestes": "geschult",
    "geschummelt": "schummeln",
    "geschummelte": "geschummelt",
    "geschummeltem": "geschummelt",
    "geschummelten": "geschummelt",
    "geschummelter": "geschummelt",
    "geschummeltes": "geschummelt",
    "geschunden": "schinden",
    "geschundene": "geschunden",
    "geschundenem": "geschunden",
    "geschundenen": "geschunden",
    "geschundener": "geschunden",
    "geschundenere": "geschunden",
    "geschundenerem": "geschunden",
    "geschundeneren": "geschunden",
    "geschundenerer": "geschunden",
    "geschundeneres": "geschunden",
    "geschundenes": "geschunden",
    "geschundenste": "geschunden",
    "geschundenstem": "geschunden",
    "geschundensten": "geschunden",
    "geschundenster": "geschunden",
    "geschundenstes": "geschunden",
    "geschunkelt": "schunkeln",
    "geschunkelte": "geschunkelt",
    "geschunkeltem": "geschunkelt",
    "geschunkelten": "geschunkelt",
    "geschunkelter": "geschunkelt",
    "geschunkeltes": "geschunkelt",
    "geschustert": "schustern",
    "geschusterte": "geschustert",
    "geschustertem": "geschustert",
    "geschusterten": "geschustert",
    "geschusterter": "geschustert",
    "geschustertes": "geschustert",
    "geschwabbelt": "schwabbeln",
    "geschwabbelte": "geschwabbelt",
    "geschwabbeltem": "geschwabbelt",
    "geschwabbelten": "geschwabbelt",
    "geschwabbelter": "geschwabbelt",
    "geschwabbeltes": "geschwabbelt",
    "geschwafelt": "schwafeln",
    "geschwafelte": "geschwafelt",
    "geschwafeltem": "geschwafelt",
    "geschwafelten": "geschwafelt",
    "geschwafelter": "geschwafelt",
    "geschwafeltes": "geschwafelt",
    "geschwankt": "schwanken",
    "geschwankte": "geschwankt",
    "geschwanktem": "geschwankt",
    "geschwankten": "geschwankt",
    "geschwankter": "geschwankt",
    "geschwanktes": "geschwankt",
    "geschwant": "schwanen",
    "geschwante": "geschwant",
    "geschwantem": "geschwant",
    "geschwanten": "geschwant",
    "geschwanter": "geschwant",
    "geschwantes": "geschwant",
    "geschwappt": "schwappen",
    "geschwappte": "geschwappt",
    "geschwapptem": "geschwappt",
    "geschwappten": "geschwappt",
    "geschwappter": "geschwappt",
    "geschwapptes": "geschwappt",
    "geschwatzt": "schwatzen",
    "geschwatzte": "geschwatzt",
    "geschwatztem": "geschwatzt",
    "geschwatzten": "geschwatzt",
    "geschwatzter": "geschwatzt",
    "geschwatztes": "geschwatzt",
    "geschwebt": "schweben",
    "geschwebte": "geschwebt",
    "geschwebtem": "geschwebt",
    "geschwebten": "geschwebt",
    "geschwebter": "geschwebt",
    "geschwebtes": "geschwebt",
    "geschwefelt": "schwefeln",
    "geschwefelte": "geschwefelt",
    "geschwefeltem": "geschwefelt",
    "geschwefelten": "geschwefelt",
    "geschwefelter": "geschwefelt",
    "geschwefeltes": "geschwefelt",
    "geschweift": "schweifen",
    "geschweifte": "geschweift",
    "geschweiftem": "geschweift",
    "geschweiften": "geschweift",
    "geschweifter": "geschweift",
    "geschweiftes": "geschweift",
    "geschweißt": "schweißen",
    "geschweißte": "geschweißt",
    "geschweißtem": "geschweißt",
    "geschweißten": "geschweißt",
    "geschweißter": "geschweißt",
    "geschweißtes": "geschweißt",
    "geschwelgt": "schwelgen",
    "geschwelgte": "geschwelgt",
    "geschwelgtem": "geschwelgt",
    "geschwelgten": "geschwelgt",
    "geschwelgter": "geschwelgt",
    "geschwelgtes": "geschwelgt",
    "geschwellt": "schwellen",
    "geschwellte": "geschwellt",
    "geschwelltem": "geschwellt",
    "geschwellten": "geschwellt",
    "geschwellter": "geschwellt",
    "geschwelltes": "geschwellt",
    "geschwelt": "schwelen",
    "geschwelte": "geschwelt",
    "geschweltem": "geschwelt",
    "geschwelten": "geschwelt",
    "geschwelter": "geschwelt",
    "geschweltes": "geschwelt",
    "geschwemmt": "schwemmen",
    "geschwemmte": "geschwemmt",
    "geschwemmtem": "geschwemmt",
    "geschwemmten": "geschwemmt",
    "geschwemmter": "geschwemmt",
    "geschwemmtes": "geschwemmt",
    "geschwenkt": "schwenken",
    "geschwenkte": "geschwenkt",
    "geschwenktem": "geschwenkt",
    "geschwenkten": "geschwenkt",
    "geschwenkter": "geschwenkt",
    "geschwenktes": "geschwenkt",
    "geschwiegen": "schweigen",
    "geschwiegene": "geschwiegen",
    "geschwiegenem": "geschwiegen",
    "geschwiegenen": "geschwiegen",
    "geschwiegener": "geschwiegen",
    "geschwiegenes": "geschwiegen",
    "geschwinde": "geschwind",
    "geschwindelt": "schwindeln",
    "geschwindelte": "geschwindelt",
    "geschwindeltem": "geschwindelt",
    "geschwindelten": "geschwindelt",
    "geschwindelter": "geschwindelt",
    "geschwindeltes": "geschwindelt",
    "geschwindem": "geschwind",
    "geschwinden": "geschwind",
    "geschwinder": "geschwind",
    "geschwindes": "geschwind",
    "geschwirrt": "schwirren",
    "geschwirrte": "geschwirrt",
    "geschwirrtem": "geschwirrt",
    "geschwirrten": "geschwirrt",
    "geschwirrter": "geschwirrt",
    "geschwirrtes": "geschwirrt",
    "geschwisterlichem": "geschwisterlich",
    "geschwisterlichen": "geschwisterlich",
    "geschwisterlicher": "geschwisterlich",
    "geschwisterliches": "geschwisterlich",
    "geschwitzt": "schwitzen",
    "geschwitzte": "geschwitzt",
    "geschwitztem": "geschwitzt",
    "geschwitzten": "geschwitzt",
    "geschwitzter": "geschwitzt",
    "geschwitztes": "geschwitzt",
    "geschwollen": "schwellen",
    "geschwollene": "geschwollen",
    "geschwollenem": "geschwollen",
    "geschwollenen": "geschwollen",
    "geschwollener": "geschwollen",
    "geschwollenere": "geschwollen",
    "geschwollenerem": "geschwollen",
    "geschwolleneren": "geschwollen",
    "geschwollenerer": "geschwollen",
    "geschwolleneres": "geschwollen",
    "geschwollenes": "geschwollen",
    "geschwollenste": "geschwollen",
    "geschwollenstem": "geschwollen",
    "geschwollensten": "geschwollen",
    "geschwollenster": "geschwollen",
    "geschwollenstes": "geschwollen",
    "geschwommen": "schwimmen",
    "geschwommene": "geschwommen",
    "geschwommenem": "geschwommen",
    "geschwommenen": "geschwommen",
    "geschwommener": "geschwommen",
    "geschwommenes": "geschwommen",
    "geschworen": "schwören",
    "geschworene": "geschworen",
    "geschworenem": "geschworen",
    "geschworenen": "geschworen",
    "geschworener": "geschworen",
    "geschworenes": "geschworen",
    "geschwunden": "schwinden",
    "geschwundene": "geschwunden",
    "geschwundenem": "geschwunden",
    "geschwundenen": "geschwunden",
    "geschwundener": "geschwunden",
    "geschwundenere": "geschwunden",
    "geschwundenerem": "geschwunden",
    "geschwundeneren": "geschwunden",
    "geschwundenerer": "geschwunden",
    "geschwundeneres": "geschwunden",
    "geschwundenes": "geschwunden",
    "geschwundenste": "geschwunden",
    "geschwundenstem": "geschwunden",
    "geschwundensten": "geschwunden",
    "geschwundenster": "geschwunden",
    "geschwundenstes": "geschwunden",
    "geschwungen": "schwingen",
    "geschwungene": "geschwungen",
    "geschwungenem": "geschwungen",
    "geschwungenen": "geschwungen",
    "geschwungener": "geschwungen",
    "geschwungenes": "geschwungen",
    "geschwäbelt": "schwäbeln",
    "geschwäbelte": "geschwäbelt",
    "geschwäbeltem": "geschwäbelt",
    "geschwäbelten": "geschwäbelt",
    "geschwäbelter": "geschwäbelt",
    "geschwäbeltes": "geschwäbelt",
    "geschwächt": "schwächen",
    "geschwächte": "geschwächt",
    "geschwächtem": "geschwächt",
    "geschwächten": "geschwächt",
    "geschwächter": "geschwächt",
    "geschwächtere": "geschwächt",
    "geschwächterem": "geschwächt",
    "geschwächteren": "geschwächt",
    "geschwächterer": "geschwächt",
    "geschwächteres": "geschwächt",
    "geschwächtes": "geschwächt",
    "geschwächteste": "geschwächt",
    "geschwächtestem": "geschwächt",
    "geschwächtesten": "geschwächt",
    "geschwächtester": "geschwächt",
    "geschwächtestes": "geschwächt",
    "geschwängert": "schwängern",
    "geschwängerte": "geschwängert",
    "geschwängertem": "geschwängert",
    "geschwängerten": "geschwängert",
    "geschwängerter": "geschwängert",
    "geschwängertes": "geschwängert",
    "geschwänzt": "schwänzen",
    "geschwänzte": "geschwänzt",
    "geschwänztem": "geschwänzt",
    "geschwänzten": "geschwänzt",
    "geschwänzter": "geschwänzt",
    "geschwänztes": "geschwänzt",
    "geschwärmt": "schwärmen",
    "geschwärmte": "geschwärmt",
    "geschwärmtem": "geschwärmt",
    "geschwärmten": "geschwärmt",
    "geschwärmter": "geschwärmt",
    "geschwärmtes": "geschwärmt",
    "geschwärzt": "schwärzen",
    "geschwärzte": "geschwärzt",
    "geschwärztem": "geschwärzt",
    "geschwärzten": "geschwärzt",
    "geschwärzter": "geschwärzt",
    "geschwärztere": "geschwärzt",
    "geschwärzterem": "geschwärzt",
    "geschwärzteren": "geschwärzt",
    "geschwärzterer": "geschwärzt",
    "geschwärzteres": "geschwärzt",
    "geschwärztes": "geschwärzt",
    "geschwärzteste": "geschwärzt",
    "geschwärztestem": "geschwärzt",
    "geschwärztesten": "geschwärzt",
    "geschwärztester": "geschwärzt",
    "geschwärztestes": "geschwärzt",
    "geschwätzigem": "geschwätzig",
    "geschwätzigen": "geschwätzig",
    "geschwätziger": "geschwätzig",
    "geschwätzigere": "geschwätzig",
    "geschwätzigerem": "geschwätzig",
    "geschwätzigeren": "geschwätzig",
    "geschwätzigerer": "geschwätzig",
    "geschwätzigeres": "geschwätzig",
    "geschwätziges": "geschwätzig",
    "geschwätzigste": "geschwätzig",
    "geschwätzigstem": "geschwätzig",
    "geschwätzigsten": "geschwätzig",
    "geschwätzigster": "geschwätzig",
    "geschwätzigstes": "geschwätzig",
    "geschädigt": "schädigen",
    "geschädigte": "geschädigt",
    "geschädigtem": "geschädigt",
    "geschädigten": "geschädigt",
    "geschädigter": "geschädigt",
    "geschädigtes": "geschädigt",
    "geschäftigem": "geschäftig",
    "geschäftigen": "geschäftig",
    "geschäftiger": "geschäftig",
    "geschäftigere": "geschäftig",
    "geschäftigerem": "geschäftig",
    "geschäftigeren": "geschäftig",
    "geschäftigerer": "geschäftig",
    "geschäftigeres": "geschäftig",
    "geschäftiges": "geschäftig",
    "geschäftigste": "geschäftig",
    "geschäftigstem": "geschäftig",
    "geschäftigsten": "geschäftig",
    "geschäftigster": "geschäftig",
    "geschäftigstes": "geschäftig",
    "geschäftliche": "geschäftlich",
    "geschäftlichem": "geschäftlich",
    "geschäftlichen": "geschäftlich",
    "geschäftlicher": "geschäftlich",
    "geschäftliches": "geschäftlich",
    "geschäftsfähigem": "geschäftsfähig",
    "geschäftsfähigen": "geschäftsfähig",
    "geschäftsfähiger": "geschäftsfähig",
    "geschäftsfähiges": "geschäftsfähig",
    "geschäftsführende": "geschäftsführend",
    "geschäftsführendem": "geschäftsführend",
    "geschäftsführenden": "geschäftsführend",
    "geschäftsführender": "geschäftsführend",
    "geschäftsführendes": "geschäftsführend",
    "geschäftsmäßige": "geschäftsmäßig",
    "geschäftsmäßigem": "geschäftsmäßig",
    "geschäftsmäßigen": "geschäftsmäßig",
    "geschäftsmäßiger": "geschäftsmäßig",
    "geschäftsmäßiges": "geschäftsmäßig",
    "geschäftsschädigende": "geschäftsschädigend",
    "geschäftsschädigendem": "geschäftsschädigend",
    "geschäftsschädigenden": "geschäftsschädigend",
    "geschäftsschädigender": "geschäftsschädigend",
    "geschäftsschädigendere": "geschäftsschädigend",
    "geschäftsschädigenderem": "geschäftsschädigend",
    "geschäftsschädigenderen": "geschäftsschädigend",
    "geschäftsschädigenderer": "geschäftsschädigend",
    "geschäftsschädigenderes": "geschäftsschädigend",
    "geschäftsschädigendes": "geschäftsschädigend",
    "geschäftsschädigendste": "geschäftsschädigend",
    "geschäftsschädigendstem": "geschäftsschädigend",
    "geschäftsschädigendsten": "geschäftsschädigend",
    "geschäftsschädigendster": "geschäftsschädigend",
    "geschäftsschädigendstes": "geschäftsschädigend",
    "geschäftstüchtige": "geschäftstüchtig",
    "geschäftstüchtigem": "geschäftstüchtig",
    "geschäftstüchtigen": "geschäftstüchtig",
    "geschäftstüchtiger": "geschäftstüchtig",
    "geschäftstüchtigere": "geschäftstüchtig",
    "geschäftstüchtigerem": "geschäftstüchtig",
    "geschäftstüchtigeren": "geschäftstüchtig",
    "geschäftstüchtigerer": "geschäftstüchtig",
    "geschäftstüchtigeres": "geschäftstüchtig",
    "geschäftstüchtiges": "geschäftstüchtig",
    "geschäftstüchtigste": "geschäftstüchtig",
    "geschäftstüchtigstem": "geschäftstüchtig",
    "geschäftstüchtigsten": "geschäftstüchtig",
    "geschäftstüchtigster": "geschäftstüchtig",
    "geschäftstüchtigstes": "geschäftstüchtig",
    "geschäftsunfähige": "geschäftsunfähig",
    "geschäftsunfähigem": "geschäftsunfähig",
    "geschäftsunfähigen": "geschäftsunfähig",
    "geschäftsunfähiger": "geschäftsunfähig",
    "geschäftsunfähigere": "geschäftsunfähig",
    "geschäftsunfähigerem": "geschäftsunfähig",
    "geschäftsunfähigeren": "geschäftsunfähig",
    "geschäftsunfähigerer": "geschäftsunfähig",
    "geschäftsunfähigeres": "geschäftsunfähig",
    "geschäftsunfähiges": "geschäftsunfähig",
    "geschäftsunfähigste": "geschäftsunfähig",
    "geschäftsunfähigstem": "geschäftsunfähig",
    "geschäftsunfähigsten": "geschäftsunfähig",
    "geschäftsunfähigster": "geschäftsunfähig",
    "geschäftsunfähigstes": "geschäftsunfähig",
    "geschähe": "geschehen",
    "geschähen": "geschehen",
    "geschähest": "geschehen",
    "geschähet": "geschehen",
    "geschält": "schälen",
    "geschältem": "geschält",
    "geschälter": "geschält",
    "geschältes": "geschält",
    "geschämt": "schämen",
    "geschämte": "geschämt",
    "geschämtem": "geschämt",
    "geschämten": "geschämt",
    "geschämter": "geschämt",
    "geschämtes": "geschämt",
    "geschändet": "schänden",
    "geschändete": "geschändet",
    "geschändetem": "geschändet",
    "geschändeten": "geschändet",
    "geschändeter": "geschändet",
    "geschändetere": "geschändet",
    "geschändeterem": "geschändet",
    "geschändeteren": "geschändet",
    "geschändeterer": "geschändet",
    "geschändeteres": "geschändet",
    "geschändetes": "geschändet",
    "geschändeteste": "geschändet",
    "geschändetestem": "geschändet",
    "geschändetesten": "geschändet",
    "geschändetester": "geschändet",
    "geschändetestes": "geschändet",
    "geschärft": "schärfen",
    "geschärfte": "geschärft",
    "geschärftem": "geschärft",
    "geschärften": "geschärft",
    "geschärfter": "geschärft",
    "geschärftere": "geschärft",
    "geschärfterem": "geschärft",
    "geschärfteren": "geschärft",
    "geschärfterer": "geschärft",
    "geschärfteres": "geschärft",
    "geschärftes": "geschärft",
    "geschärfteste": "geschärft",
    "geschärftestem": "geschärft",
    "geschärftesten": "geschärft",
    "geschärftester": "geschärft",
    "geschärftestes": "geschärft",
    "geschätzt": "schätzen",
    "geschätzte": "geschätzt",
    "geschätztem": "geschätzt",
    "geschätzten": "geschätzt",
    "geschätzter": "geschätzt",
    "geschätztere": "geschätzt",
    "geschätzterem": "geschätzt",
    "geschätzteren": "geschätzt",
    "geschätzterer": "geschätzt",
    "geschätzteres": "geschätzt",
    "geschätztes": "geschätzt",
    "geschätzteste": "geschätzt",
    "geschätztestem": "geschätzt",
    "geschätztesten": "geschätzt",
    "geschätztester": "geschätzt",
    "geschätztestes": "geschätzt",
    "geschäumt": "schäumen",
    "geschäumte": "geschäumt",
    "geschäumtem": "geschäumt",
    "geschäumten": "geschäumt",
    "geschäumter": "geschäumt",
    "geschäumtere": "geschäumt",
    "geschäumterem": "geschäumt",
    "geschäumteren": "geschäumt",
    "geschäumterer": "geschäumt",
    "geschäumteres": "geschäumt",
    "geschäumtes": "geschäumt",
    "geschäumteste": "geschäumt",
    "geschäumtestem": "geschäumt",
    "geschäumtesten": "geschäumt",
    "geschäumtester": "geschäumt",
    "geschäumtestes": "geschäumt",
    "geschöpft": "schöpfen",
    "geschöpfte": "geschöpft",
    "geschöpftem": "geschöpft",
    "geschöpften": "geschöpft",
    "geschöpfter": "geschöpft",
    "geschöpftes": "geschöpft",
    "geschürft": "schürfen",
    "geschürfte": "geschürft",
    "geschürftem": "geschürft",
    "geschürften": "geschürft",
    "geschürfter": "geschürft",
    "geschürftes": "geschürft",
    "geschürt": "schüren",
    "geschürte": "geschürt",
    "geschürtem": "geschürt",
    "geschürten": "geschürt",
    "geschürter": "geschürt",
    "geschürtes": "geschürt",
    "geschüttelt": "schütteln",
    "geschüttelte": "geschüttelt",
    "geschütteltem": "geschüttelt",
    "geschüttelten": "geschüttelt",
    "geschüttelter": "geschüttelt",
    "geschütteltere": "geschüttelt",
    "geschüttelterem": "geschüttelt",
    "geschüttelteren": "geschüttelt",
    "geschüttelterer": "geschüttelt",
    "geschüttelteres": "geschüttelt",
    "geschütteltes": "geschüttelt",
    "geschüttelteste": "geschüttelt",
    "geschütteltestem": "geschüttelt",
    "geschütteltesten": "geschüttelt",
    "geschütteltester": "geschüttelt",
    "geschütteltestes": "geschüttelt",
    "geschüttert": "schüttern",
    "geschütterte": "geschüttert",
    "geschüttertem": "geschüttert",
    "geschütterten": "geschüttert",
    "geschütterter": "geschüttert",
    "geschüttertes": "geschüttert",
    "geschüttet": "schütten",
    "geschüttete": "geschüttet",
    "geschüttetem": "geschüttet",
    "geschütteten": "geschüttet",
    "geschütteter": "geschüttet",
    "geschüttetes": "geschüttet",
    "geschützt": "schützen",
    "geschützte": "geschützt",
    "geschütztem": "geschützt",
    "geschützten": "geschützt",
    "geschützter": "geschützt",
    "geschütztere": "geschützt",
    "geschützterem": "geschützt",
    "geschützteren": "geschützt",
    "geschützterer": "geschützt",
    "geschützteres": "geschützt",
    "geschütztes": "geschützt",
    "geschützteste": "geschützt",
    "geschütztestem": "geschützt",
    "geschütztesten": "geschützt",
    "geschütztester": "geschützt",
    "geschütztestes": "geschützt",
    "gesegelt": "segeln",
    "gesegelte": "gesegelt",
    "gesegeltem": "gesegelt",
    "gesegelten": "gesegelt",
    "gesegelter": "gesegelt",
    "gesegeltes": "gesegelt",
    "gesegnet": "segnen",
    "gesegnete": "gesegnet",
    "gesegnetem": "gesegnet",
    "gesegneten": "gesegnet",
    "gesegneter": "gesegnet",
    "gesegnetes": "gesegnet",
    "gesehen": "sehen",
    "gesehene": "gesehen",
    "gesehenem": "gesehen",
    "gesehenen": "gesehen",
    "gesehener": "gesehen",
    "gesehenes": "gesehen",
    "gesehnt": "sehnen",
    "gesehnte": "gesehnt",
    "gesehntem": "gesehnt",
    "gesehnten": "gesehnt",
    "gesehnter": "gesehnt",
    "gesehntes": "gesehnt",
    "geseift": "seifen",
    "geseifte": "geseift",
    "geseiftem": "geseift",
    "geseiften": "geseift",
    "geseifter": "geseift",
    "geseiftes": "geseift",
    "geseilt": "seilen",
    "geseilte": "geseilt",
    "geseiltem": "geseilt",
    "geseilten": "geseilt",
    "geseilter": "geseilt",
    "geseiltes": "geseilt",
    "geselle": "gesellen",
    "gesellend": "gesellen",
    "gesellende": "gesellend",
    "gesellendem": "gesellend",
    "gesellenden": "gesellend",
    "gesellender": "gesellend",
    "gesellendes": "gesellend",
    "gesellest": "gesellen",
    "gesellet": "gesellen",
    "gesellige": "gesellig",
    "geselligem": "gesellig",
    "geselligen": "gesellig",
    "geselliger": "gesellig",
    "geselligere": "gesellig",
    "geselligerem": "gesellig",
    "geselligeren": "gesellig",
    "geselligerer": "gesellig",
    "geselligeres": "gesellig",
    "geselliges": "gesellig",
    "geselligstem": "gesellig",
    "geselligsten": "gesellig",
    "geselligster": "gesellig",
    "geselligstes": "gesellig",
    "gesellschaftlichem": "gesellschaftlich",
    "gesellschaftlichen": "gesellschaftlich",
    "gesellschaftlicher": "gesellschaftlich",
    "gesellschaftlichere": "gesellschaftlich",
    "gesellschaftlicherem": "gesellschaftlich",
    "gesellschaftlicheren": "gesellschaftlich",
    "gesellschaftlicherer": "gesellschaftlich",
    "gesellschaftlicheres": "gesellschaftlich",
    "gesellschaftliches": "gesellschaftlich",
    "gesellschaftlichste": "gesellschaftlich",
    "gesellschaftlichstem": "gesellschaftlich",
    "gesellschaftlichsten": "gesellschaftlich",
    "gesellschaftlichster": "gesellschaftlich",
    "gesellschaftlichstes": "gesellschaftlich",
    "gesellschaftsfähige": "gesellschaftsfähig",
    "gesellschaftsfähigem": "gesellschaftsfähig",
    "gesellschaftsfähigen": "gesellschaftsfähig",
    "gesellschaftsfähiger": "gesellschaftsfähig",
    "gesellschaftsfähigere": "gesellschaftsfähig",
    "gesellschaftsfähigerem": "gesellschaftsfähig",
    "gesellschaftsfähigeren": "gesellschaftsfähig",
    "gesellschaftsfähigerer": "gesellschaftsfähig",
    "gesellschaftsfähigeres": "gesellschaftsfähig",
    "gesellschaftsfähiges": "gesellschaftsfähig",
    "gesellschaftsfähigste": "gesellschaftsfähig",
    "gesellschaftsfähigstem": "gesellschaftsfähig",
    "gesellschaftsfähigsten": "gesellschaftsfähig",
    "gesellschaftsfähigster": "gesellschaftsfähig",
    "gesellschaftsfähigstes": "gesellschaftsfähig",
    "gesellst": "gesellen",
    "gesellt": "gesellen",
    "gesellte": "gesellen",
    "geselltem": "gesellt",
    "gesellten": "gesellen",
    "gesellter": "gesellt",
    "geselltes": "gesellt",
    "geselltest": "gesellen",
    "geselltet": "gesellen",
    "gesendet": "senden",
    "gesendete": "gesendet",
    "gesendetem": "gesendet",
    "gesendeten": "gesendet",
    "gesendeter": "gesendet",
    "gesendetes": "gesendet",
    "gesengt": "sengen",
    "gesengte": "gesengt",
    "gesengtem": "gesengt",
    "gesengten": "gesengt",
    "gesengter": "gesengt",
    "gesengtes": "gesengt",
    "gesenkt": "senken",
    "gesenkte": "gesenkt",
    "gesenktem": "gesenkt",
    "gesenkten": "gesenkt",
    "gesenkter": "gesenkt",
    "gesenktere": "gesenkt",
    "gesenkterem": "gesenkt",
    "gesenkteren": "gesenkt",
    "gesenkterer": "gesenkt",
    "gesenkteres": "gesenkt",
    "gesenktes": "gesenkt",
    "gesenkteste": "gesenkt",
    "gesenktestem": "gesenkt",
    "gesenktesten": "gesenkt",
    "gesenktester": "gesenkt",
    "gesenktestes": "gesenkt",
    "gesessen": "sitzen",
    "gesessene": "gesessen",
    "gesessenem": "gesessen",
    "gesessenen": "gesessen",
    "gesessener": "gesessen",
    "gesessenes": "gesessen",
    "gesetzlichem": "gesetzlich",
    "gesetzlichen": "gesetzlich",
    "gesetzlicher": "gesetzlich",
    "gesetzliches": "gesetzlich",
    "gesetzlose": "gesetzlos",
    "gesetzlosem": "gesetzlos",
    "gesetzlosen": "gesetzlos",
    "gesetzloser": "gesetzlos",
    "gesetzlosere": "gesetzlos",
    "gesetzloserem": "gesetzlos",
    "gesetzloseren": "gesetzlos",
    "gesetzloserer": "gesetzlos",
    "gesetzloseres": "gesetzlos",
    "gesetzloses": "gesetzlos",
    "gesetzloseste": "gesetzlos",
    "gesetzlosestem": "gesetzlos",
    "gesetzlosesten": "gesetzlos",
    "gesetzlosester": "gesetzlos",
    "gesetzlosestes": "gesetzlos",
    "gesetzmäßige": "gesetzmäßig",
    "gesetzmäßigem": "gesetzmäßig",
    "gesetzmäßigen": "gesetzmäßig",
    "gesetzmäßiger": "gesetzmäßig",
    "gesetzmäßigere": "gesetzmäßig",
    "gesetzmäßigerem": "gesetzmäßig",
    "gesetzmäßigeren": "gesetzmäßig",
    "gesetzmäßigerer": "gesetzmäßig",
    "gesetzmäßigeres": "gesetzmäßig",
    "gesetzmäßiges": "gesetzmäßig",
    "gesetzmäßigste": "gesetzmäßig",
    "gesetzmäßigstem": "gesetzmäßig",
    "gesetzmäßigsten": "gesetzmäßig",
    "gesetzmäßigster": "gesetzmäßig",
    "gesetzmäßigstes": "gesetzmäßig",
    "gesetzt": "setzen",
    "gesetzte": "gesetzt",
    "gesetztem": "gesetzt",
    "gesetzten": "gesetzt",
    "gesetzter": "gesetzt",
    "gesetztere": "gesetzt",
    "gesetzterem": "gesetzt",
    "gesetzteren": "gesetzt",
    "gesetzterer": "gesetzt",
    "gesetzteres": "gesetzt",
    "gesetztes": "gesetzt",
    "gesetzteste": "gesetzt",
    "gesetztestem": "gesetzt",
    "gesetztesten": "gesetzt",
    "gesetztester": "gesetzt",
    "gesetztestes": "gesetzt",
    "gesetzwidrige": "gesetzwidrig",
    "gesetzwidrigem": "gesetzwidrig",
    "gesetzwidrigen": "gesetzwidrig",
    "gesetzwidriger": "gesetzwidrig",
    "gesetzwidrigere": "gesetzwidrig",
    "gesetzwidrigerem": "gesetzwidrig",
    "gesetzwidrigeren": "gesetzwidrig",
    "gesetzwidrigerer": "gesetzwidrig",
    "gesetzwidrigeres": "gesetzwidrig",
    "gesetzwidriges": "gesetzwidrig",
    "gesetzwidrigste": "gesetzwidrig",
    "gesetzwidrigstem": "gesetzwidrig",
    "gesetzwidrigsten": "gesetzwidrig",
    "gesetzwidrigster": "gesetzwidrig",
    "gesetzwidrigstes": "gesetzwidrig",
    "geseufzt": "seufzen",
    "geseufzte": "geseufzt",
    "geseufztem": "geseufzt",
    "geseufzten": "geseufzt",
    "geseufzter": "geseufzt",
    "geseufztes": "geseufzt",
    "gesichert": "sichern",
    "gesicherte": "gesichert",
    "gesichertem": "gesichert",
    "gesicherten": "gesichert",
    "gesicherter": "gesichert",
    "gesichertere": "gesichert",
    "gesicherterem": "gesichert",
    "gesicherteren": "gesichert",
    "gesicherterer": "gesichert",
    "gesicherteres": "gesichert",
    "gesichertes": "gesichert",
    "gesicherteste": "gesichert",
    "gesichertestem": "gesichert",
    "gesichertesten": "gesichert",
    "gesichertester": "gesichert",
    "gesichertestes": "gesichert",
    "gesichtet": "sichten",
    "gesichtete": "gesichtet",
    "gesichtetem": "gesichtet",
    "gesichteten": "gesichtet",
    "gesichteter": "gesichtet",
    "gesichtetes": "gesichtet",
    "gesiebt": "sieben",
    "gesiebte": "gesiebt",
    "gesiebtem": "gesiebt",
    "gesiebten": "gesiebt",
    "gesiebter": "gesiebt",
    "gesiebtes": "gesiebt",
    "gesiecht": "siechen",
    "gesiechte": "gesiecht",
    "gesiechtem": "gesiecht",
    "gesiechten": "gesiecht",
    "gesiechter": "gesiecht",
    "gesiechtes": "gesiecht",
    "gesiedelt": "siedeln",
    "gesiedelte": "gesiedelt",
    "gesiedeltem": "gesiedelt",
    "gesiedelten": "gesiedelt",
    "gesiedelter": "gesiedelt",
    "gesiedeltes": "gesiedelt",
    "gesiedet": "sieden",
    "gesiedete": "gesiedet",
    "gesiedetem": "gesiedet",
    "gesiedeten": "gesiedet",
    "gesiedeter": "gesiedet",
    "gesiedetes": "gesiedet",
    "gesiegelt": "siegeln",
    "gesiegelte": "gesiegelt",
    "gesiegeltem": "gesiegelt",
    "gesiegelten": "gesiegelt",
    "gesiegelter": "gesiegelt",
    "gesiegeltes": "gesiegelt",
    "gesiegt": "siegen",
    "gesiegte": "gesiegt",
    "gesiegtem": "gesiegt",
    "gesiegten": "gesiegt",
    "gesiegter": "gesiegt",
    "gesiegtes": "gesiegt",
    "gesiezt": "siezen",
    "gesiezte": "gesiezt",
    "gesieztem": "gesiezt",
    "gesiezten": "gesiezt",
    "gesiezter": "gesiezt",
    "gesieztes": "gesiezt",
    "gesinnungslosem": "gesinnungslos",
    "gesinnungslosen": "gesinnungslos",
    "gesinnungsloser": "gesinnungslos",
    "gesinnungsloses": "gesinnungslos",
    "gesinnungstreue": "gesinnungstreu",
    "gesinnungstreuem": "gesinnungstreu",
    "gesinnungstreuen": "gesinnungstreu",
    "gesinnungstreuer": "gesinnungstreu",
    "gesinnungstreuere": "gesinnungstreu",
    "gesinnungstreuerem": "gesinnungstreu",
    "gesinnungstreueren": "gesinnungstreu",
    "gesinnungstreuerer": "gesinnungstreu",
    "gesinnungstreueres": "gesinnungstreu",
    "gesinnungstreues": "gesinnungstreu",
    "gesinnungstreuste": "gesinnungstreu",
    "gesinnungstreustem": "gesinnungstreu",
    "gesinnungstreusten": "gesinnungstreu",
    "gesinnungstreuster": "gesinnungstreu",
    "gesinnungstreustes": "gesinnungstreu",
    "gesittete": "gesittet",
    "gesittetem": "gesittet",
    "gesitteten": "gesittet",
    "gesitteter": "gesittet",
    "gesittetere": "gesittet",
    "gesitteterem": "gesittet",
    "gesitteteren": "gesittet",
    "gesitteterer": "gesittet",
    "gesitteteres": "gesittet",
    "gesittetes": "gesittet",
    "gesitteteste": "gesittet",
    "gesittetestem": "gesittet",
    "gesittetesten": "gesittet",
    "gesittetester": "gesittet",
    "gesittetestes": "gesittet",
    "gesoffen": "saufen",
    "gesoffene": "gesoffen",
    "gesoffenem": "gesoffen",
    "gesoffenen": "gesoffen",
    "gesoffener": "gesoffen",
    "gesoffenere": "gesoffen",
    "gesoffenerem": "gesoffen",
    "gesoffeneren": "gesoffen",
    "gesoffenerer": "gesoffen",
    "gesoffeneres": "gesoffen",
    "gesoffenes": "gesoffen",
    "gesoffenste": "gesoffen",
    "gesoffenstem": "gesoffen",
    "gesoffensten": "gesoffen",
    "gesoffenster": "gesoffen",
    "gesoffenstes": "gesoffen",
    "gesogen": "saugen",
    "gesogene": "gesogen",
    "gesogenem": "gesogen",
    "gesogenen": "gesogen",
    "gesogener": "gesogen",
    "gesogenes": "gesogen",
    "gesohlt": "sohlen",
    "gesohlte": "gesohlt",
    "gesohltem": "gesohlt",
    "gesohlten": "gesohlt",
    "gesohlter": "gesohlt",
    "gesohltes": "gesohlt",
    "gesollt": "sollen",
    "gesondert": "sondern",
    "gesonderte": "gesondert",
    "gesondertem": "gesondert",
    "gesonderten": "gesondert",
    "gesonderter": "gesondert",
    "gesondertes": "gesondert",
    "gesonnen": "sinnen",
    "gesonnene": "gesonnen",
    "gesonnenem": "gesonnen",
    "gesonnenen": "gesonnen",
    "gesonnener": "gesonnen",
    "gesonnenes": "gesonnen",
    "gesonnt": "sonnen",
    "gesonnte": "gesonnt",
    "gesonntem": "gesonnt",
    "gesonnten": "gesonnt",
    "gesonnter": "gesonnt",
    "gesonntes": "gesonnt",
    "gesorgt": "sorgen",
    "gesorgte": "gesorgt",
    "gesorgtem": "gesorgt",
    "gesorgten": "gesorgt",
    "gesorgter": "gesorgt",
    "gesorgtes": "gesorgt",
    "gesotten": "sieden",
    "gesottene": "gesotten",
    "gesottenem": "gesotten",
    "gesottenen": "gesotten",
    "gesottener": "gesotten",
    "gesottenes": "gesotten",
    "gespachtelt": "spachteln",
    "gespachtelte": "gespachtelt",
    "gespachteltem": "gespachtelt",
    "gespachtelten": "gespachtelt",
    "gespachtelter": "gespachtelt",
    "gespachteltes": "gespachtelt",
    "gespalten": "spalten",
    "gespaltene": "gespalten",
    "gespaltenem": "gespalten",
    "gespaltenen": "gespalten",
    "gespaltener": "gespalten",
    "gespaltenere": "gespalten",
    "gespaltenerem": "gespalten",
    "gespalteneren": "gespalten",
    "gespaltenerer": "gespalten",
    "gespalteneres": "gespalten",
    "gespaltenes": "gespalten",
    "gespaltenste": "gespalten",
    "gespaltenstem": "gespalten",
    "gespaltensten": "gespalten",
    "gespaltenster": "gespalten",
    "gespaltenstes": "gespalten",
    "gespannt": "spannen",
    "gespannte": "gespannt",
    "gespanntem": "gespannt",
    "gespannten": "gespannt",
    "gespannter": "gespannt",
    "gespanntere": "gespannt",
    "gespannterem": "gespannt",
    "gespannteren": "gespannt",
    "gespannterer": "gespannt",
    "gespannteres": "gespannt",
    "gespanntes": "gespannt",
    "gespannteste": "gespannt",
    "gespanntestem": "gespannt",
    "gespanntesten": "gespannt",
    "gespanntester": "gespannt",
    "gespanntestes": "gespannt",
    "gespart": "sparen",
    "gesparte": "gespart",
    "gespartem": "gespart",
    "gesparten": "gespart",
    "gesparter": "gespart",
    "gespartes": "gespart",
    "gespaßt": "spaßen",
    "gespaßte": "gespaßt",
    "gespaßtem": "gespaßt",
    "gespaßten": "gespaßt",
    "gespaßter": "gespaßt",
    "gespaßtes": "gespaßt",
    "gespeichert": "speichern",
    "gespeicherte": "gespeichert",
    "gespeichertem": "gespeichert",
    "gespeicherten": "gespeichert",
    "gespeicherter": "gespeichert",
    "gespeichertes": "gespeichert",
    "gespeist": "speisen",
    "gespeiste": "gespeist",
    "gespeistem": "gespeist",
    "gespeisten": "gespeist",
    "gespeister": "gespeist",
    "gespeistes": "gespeist",
    "gespendet": "spenden",
    "gespendete": "gespendet",
    "gespendetem": "gespendet",
    "gespendeten": "gespendet",
    "gespendeter": "gespendet",
    "gespendetes": "gespendet",
    "gespenstigem": "gespenstig",
    "gespenstigen": "gespenstig",
    "gespenstiger": "gespenstig",
    "gespenstigere": "gespenstig",
    "gespenstigerem": "gespenstig",
    "gespenstigeren": "gespenstig",
    "gespenstigerer": "gespenstig",
    "gespenstigeres": "gespenstig",
    "gespenstiges": "gespenstig",
    "gespenstigste": "gespenstig",
    "gespenstigstem": "gespenstig",
    "gespenstigsten": "gespenstig",
    "gespenstigster": "gespenstig",
    "gespenstigstes": "gespenstig",
    "gespenstische": "gespenstisch",
    "gespenstischem": "gespenstisch",
    "gespenstischen": "gespenstisch",
    "gespenstischer": "gespenstisch",
    "gespenstischere": "gespenstisch",
    "gespenstischerem": "gespenstisch",
    "gespenstischeren": "gespenstisch",
    "gespenstischerer": "gespenstisch",
    "gespenstischeres": "gespenstisch",
    "gespenstisches": "gespenstisch",
    "gespenstischste": "gespenstisch",
    "gespenstischstem": "gespenstisch",
    "gespenstischsten": "gespenstisch",
    "gespenstischster": "gespenstisch",
    "gespenstischstes": "gespenstisch",
    "gesperrt": "sperren",
    "gesperrte": "gesperrt",
    "gesperrtem": "gesperrt",
    "gesperrten": "gesperrt",
    "gesperrter": "gesperrt",
    "gesperrtes": "gesperrt",
    "gespickt": "spicken",
    "gespickte": "gespickt",
    "gespicktem": "gespickt",
    "gespickten": "gespickt",
    "gespickter": "gespickt",
    "gespicktes": "gespickt",
    "gespiegelt": "spiegeln",
    "gespiegelte": "gespiegelt",
    "gespiegeltem": "gespiegelt",
    "gespiegelten": "gespiegelt",
    "gespiegelter": "gespiegelt",
    "gespiegeltere": "gespiegelt",
    "gespiegelterem": "gespiegelt",
    "gespiegelteren": "gespiegelt",
    "gespiegelterer": "gespiegelt",
    "gespiegelteres": "gespiegelt",
    "gespiegeltes": "gespiegelt",
    "gespiegelteste": "gespiegelt",
    "gespiegeltestem": "gespiegelt",
    "gespiegeltesten": "gespiegelt",
    "gespiegeltester": "gespiegelt",
    "gespiegeltestes": "gespiegelt",
    "gespielt": "spielen",
    "gespielte": "gespielt",
    "gespieltem": "gespielt",
    "gespielten": "gespielt",
    "gespielter": "gespielt",
    "gespieltes": "gespielt",
    "gespien": "speien",
    "gespiene": "gespien",
    "gespienem": "gespien",
    "gespienen": "gespien",
    "gespiener": "gespien",
    "gespienes": "gespien",
    "gespießt": "spießen",
    "gespießte": "gespießt",
    "gespießtem": "gespießt",
    "gespießten": "gespießt",
    "gespießter": "gespießt",
    "gespießtes": "gespießt",
    "gespitzelt": "spitzeln",
    "gespitzelte": "gespitzelt",
    "gespitzeltem": "gespitzelt",
    "gespitzelten": "gespitzelt",
    "gespitzelter": "gespitzelt",
    "gespitzeltes": "gespitzelt",
    "gespitzt": "spitzen",
    "gespitzte": "gespitzt",
    "gespitztem": "gespitzt",
    "gespitzten": "gespitzt",
    "gespitzter": "gespitzt",
    "gespitztere": "gespitzt",
    "gespitzterem": "gespitzt",
    "gespitzteren": "gespitzt",
    "gespitzterer": "gespitzt",
    "gespitzteres": "gespitzt",
    "gespitztes": "gespitzt",
    "gespitzteste": "gespitzt",
    "gespitztestem": "gespitzt",
    "gespitztesten": "gespitzt",
    "gespitztester": "gespitzt",
    "gespitztestes": "gespitzt",
    "gesplissen": "spleißen",
    "gesplissene": "gesplissen",
    "gesplissenem": "gesplissen",
    "gesplissenen": "gesplissen",
    "gesplissener": "gesplissen",
    "gesplissenes": "gesplissen",
    "gesplittert": "splittern",
    "gesplitterte": "gesplittert",
    "gesplittertem": "gesplittert",
    "gesplitterten": "gesplittert",
    "gesplitterter": "gesplittert",
    "gesplittertes": "gesplittert",
    "gesponnen": "spinnen",
    "gesponnene": "gesponnen",
    "gesponnenem": "gesponnen",
    "gesponnenen": "gesponnen",
    "gesponnener": "gesponnen",
    "gesponnenere": "gesponnen",
    "gesponnenerem": "gesponnen",
    "gesponneneren": "gesponnen",
    "gesponnenerer": "gesponnen",
    "gesponneneres": "gesponnen",
    "gesponnenes": "gesponnen",
    "gesponnenste": "gesponnen",
    "gesponnenstem": "gesponnen",
    "gesponnensten": "gesponnen",
    "gesponnenster": "gesponnen",
    "gesponnenstes": "gesponnen",
    "gesponsert": "sponsern",
    "gesponserte": "gesponsert",
    "gesponsertem": "gesponsert",
    "gesponserten": "gesponsert",
    "gesponserter": "gesponsert",
    "gesponsertere": "gesponsert",
    "gesponserterem": "gesponsert",
    "gesponserteren": "gesponsert",
    "gesponserterer": "gesponsert",
    "gesponserteres": "gesponsert",
    "gesponsertes": "gesponsert",
    "gesponserteste": "gesponsert",
    "gesponsertestem": "gesponsert",
    "gesponsertesten": "gesponsert",
    "gesponsertester": "gesponsert",
    "gesponsertestes": "gesponsert",
    "gespornt": "spornen",
    "gespornte": "gespornt",
    "gesporntem": "gespornt",
    "gespornten": "gespornt",
    "gespornter": "gespornt",
    "gesporntes": "gespornt",
    "gespottet": "spotten",
    "gespottete": "gespottet",
    "gespottetem": "gespottet",
    "gespotteten": "gespottet",
    "gespotteter": "gespottet",
    "gespottetes": "gespottet",
    "gespreizt": "spreizen",
    "gespreizte": "gespreizt",
    "gespreiztem": "gespreizt",
    "gespreizten": "gespreizt",
    "gespreizter": "gespreizt",
    "gespreiztes": "gespreizt",
    "gesprengt": "sprengen",
    "gesprengte": "gesprengt",
    "gesprengtem": "gesprengt",
    "gesprengten": "gesprengt",
    "gesprengter": "gesprengt",
    "gesprengtes": "gesprengt",
    "gesprenkelt": "sprenkeln",
    "gesprenkelte": "gesprenkelt",
    "gesprenkeltem": "gesprenkelt",
    "gesprenkelten": "gesprenkelt",
    "gesprenkelter": "gesprenkelt",
    "gesprenkeltere": "gesprenkelt",
    "gesprenkelterem": "gesprenkelt",
    "gesprenkelteren": "gesprenkelt",
    "gesprenkelterer": "gesprenkelt",
    "gesprenkelteres": "gesprenkelt",
    "gesprenkeltes": "gesprenkelt",
    "gesprenkelteste": "gesprenkelt",
    "gesprenkeltestem": "gesprenkelt",
    "gesprenkeltesten": "gesprenkelt",
    "gesprenkeltester": "gesprenkelt",
    "gesprenkeltestes": "gesprenkelt",
    "gesprintet": "sprinten",
    "gesprintete": "gesprintet",
    "gesprintetem": "gesprintet",
    "gesprinteten": "gesprintet",
    "gesprinteter": "gesprintet",
    "gesprintetes": "gesprintet",
    "gespritzt": "spritzen",
    "gespritzte": "gespritzt",
    "gespritztem": "gespritzt",
    "gespritzten": "gespritzt",
    "gespritzter": "gespritzt",
    "gespritztere": "gespritzt",
    "gespritzterem": "gespritzt",
    "gespritzteren": "gespritzt",
    "gespritzterer": "gespritzt",
    "gespritzteres": "gespritzt",
    "gespritztes": "gespritzt",
    "gespritzteste": "gespritzt",
    "gespritztestem": "gespritzt",
    "gespritztesten": "gespritzt",
    "gespritztester": "gespritzt",
    "gespritztestes": "gespritzt",
    "gesprochen": "sprechen",
    "gesprochene": "gesprochen",
    "gesprochenem": "gesprochen",
    "gesprochenen": "gesprochen",
    "gesprochener": "gesprochen",
    "gesprochenere": "gesprochen",
    "gesprochenerem": "gesprochen",
    "gesprocheneren": "gesprochen",
    "gesprochenerer": "gesprochen",
    "gesprocheneres": "gesprochen",
    "gesprochenes": "gesprochen",
    "gesprochenste": "gesprochen",
    "gesprochenstem": "gesprochen",
    "gesprochensten": "gesprochen",
    "gesprochenster": "gesprochen",
    "gesprochenstes": "gesprochen",
    "gesprossen": "sprießen",
    "gesprossene": "gesprossen",
    "gesprossenem": "gesprossen",
    "gesprossenen": "gesprossen",
    "gesprossener": "gesprossen",
    "gesprossenere": "gesprossen",
    "gesprossenerem": "gesprossen",
    "gesprosseneren": "gesprossen",
    "gesprossenerer": "gesprossen",
    "gesprosseneres": "gesprossen",
    "gesprossenes": "gesprossen",
    "gesprossenste": "gesprossen",
    "gesprossenstem": "gesprossen",
    "gesprossensten": "gesprossen",
    "gesprossenster": "gesprossen",
    "gesprossenstes": "gesprossen",
    "gesprudelt": "sprudeln",
    "gesprudelte": "gesprudelt",
    "gesprudeltem": "gesprudelt",
    "gesprudelten": "gesprudelt",
    "gesprudelter": "gesprudelt",
    "gesprudeltes": "gesprudelt",
    "gesprungen": "springen",
    "gesprungene": "gesprungen",
    "gesprungenem": "gesprungen",
    "gesprungenen": "gesprungen",
    "gesprungener": "gesprungen",
    "gesprungenes": "gesprungen",
    "gesprächigem": "gesprächig",
    "gesprächigen": "gesprächig",
    "gesprächiger": "gesprächig",
    "gesprächigere": "gesprächig",
    "gesprächigerem": "gesprächig",
    "gesprächigeren": "gesprächig",
    "gesprächigerer": "gesprächig",
    "gesprächigeres": "gesprächig",
    "gesprächiges": "gesprächig",
    "gesprächigste": "gesprächig",
    "gesprächigstem": "gesprächig",
    "gesprächigsten": "gesprächig",
    "gesprächigster": "gesprächig",
    "gesprächigstes": "gesprächig",
    "gesprüht": "sprühen",
    "gesprühte": "gesprüht",
    "gesprühtem": "gesprüht",
    "gesprühten": "gesprüht",
    "gesprühter": "gesprüht",
    "gesprühtes": "gesprüht",
    "gespuckt": "spucken",
    "gespuckte": "gespuckt",
    "gespucktem": "gespuckt",
    "gespuckten": "gespuckt",
    "gespuckter": "gespuckt",
    "gespucktes": "gespuckt",
    "gespukt": "spuken",
    "gespukte": "gespukt",
    "gespuktem": "gespukt",
    "gespukten": "gespukt",
    "gespukter": "gespukt",
    "gespuktes": "gespukt",
    "gespult": "spulen",
    "gespulte": "gespult",
    "gespultem": "gespult",
    "gespulten": "gespult",
    "gespulter": "gespult",
    "gespultes": "gespult",
    "gespurt": "spuren",
    "gespurte": "gespurt",
    "gespurtem": "gespurt",
    "gespurten": "gespurt",
    "gespurter": "gespurt",
    "gespurtes": "gespurt",
    "gespurtet": "spurten",
    "gespurtete": "gespurtet",
    "gespurtetem": "gespurtet",
    "gespurteten": "gespurtet",
    "gespurteter": "gespurtet",
    "gespurtetere": "gespurtet",
    "gespurteterem": "gespurtet",
    "gespurteteren": "gespurtet",
    "gespurteterer": "gespurtet",
    "gespurteteres": "gespurtet",
    "gespurtetes": "gespurtet",
    "gespurteteste": "gespurtet",
    "gespurtetestem": "gespurtet",
    "gespurtetesten": "gespurtet",
    "gespurtetester": "gespurtet",
    "gespurtetestes": "gespurtet",
    "gesputet": "sputen",
    "gesputete": "gesputet",
    "gesputetem": "gesputet",
    "gesputeten": "gesputet",
    "gesputeter": "gesputet",
    "gesputetes": "gesputet",
    "gespäht": "spähen",
    "gespähte": "gespäht",
    "gespähtem": "gespäht",
    "gespähten": "gespäht",
    "gespähter": "gespäht",
    "gespähtes": "gespäht",
    "gespült": "spülen",
    "gespültem": "gespült",
    "gespülter": "gespült",
    "gespültes": "gespült",
    "gespürt": "spüren",
    "gespürtem": "gespürt",
    "gespürter": "gespürt",
    "gespürtes": "gespürt",
    "gestachelt": "stacheln",
    "gestachelte": "gestachelt",
    "gestacheltem": "gestachelt",
    "gestachelten": "gestachelt",
    "gestachelter": "gestachelt",
    "gestacheltes": "gestachelt",
    "gestaffelt": "staffeln",
    "gestaffelte": "gestaffelt",
    "gestaffeltem": "gestaffelt",
    "gestaffelten": "gestaffelt",
    "gestaffelter": "gestaffelt",
    "gestaffeltes": "gestaffelt",
    "gestalte": "gestalten",
    "gestaltend": "gestalten",
    "gestaltende": "gestaltend",
    "gestaltendem": "gestaltend",
    "gestaltenden": "gestaltend",
    "gestaltender": "gestaltend",
    "gestaltendes": "gestaltend",
    "gestalterischem": "gestalterisch",
    "gestalterischen": "gestalterisch",
    "gestalterischer": "gestalterisch",
    "gestalterisches": "gestalterisch",
    "gestaltest": "gestalten",
    "gestaltet": "gestalten",
    "gestaltete": "gestalten",
    "gestaltetem": "gestaltet",
    "gestalteten": "gestalten",
    "gestalteter": "gestaltet",
    "gestaltetes": "gestaltet",
    "gestaltetest": "gestalten",
    "gestaltetet": "gestalten",
    "gestaltlosem": "gestaltlos",
    "gestaltlosen": "gestaltlos",
    "gestaltloser": "gestaltlos",
    "gestaltloses": "gestaltlos",
    "gestaltmäßige": "gestaltmäßig",
    "gestaltmäßigem": "gestaltmäßig",
    "gestaltmäßigen": "gestaltmäßig",
    "gestaltmäßiger": "gestaltmäßig",
    "gestaltmäßiges": "gestaltmäßig",
    "gestammelt": "stammeln",
    "gestammelte": "gestammelt",
    "gestammeltem": "gestammelt",
    "gestammelten": "gestammelt",
    "gestammelter": "gestammelt",
    "gestammeltere": "gestammelt",
    "gestammelterem": "gestammelt",
    "gestammelteren": "gestammelt",
    "gestammelterer": "gestammelt",
    "gestammelteres": "gestammelt",
    "gestammeltes": "gestammelt",
    "gestammelteste": "gestammelt",
    "gestammeltestem": "gestammelt",
    "gestammeltesten": "gestammelt",
    "gestammeltester": "gestammelt",
    "gestammeltestes": "gestammelt",
    "gestammt": "stammen",
    "gestammte": "gestammt",
    "gestammtem": "gestammt",
    "gestammten": "gestammt",
    "gestammter": "gestammt",
    "gestammtes": "gestammt",
    "gestampft": "stampfen",
    "gestampfte": "gestampft",
    "gestampftem": "gestampft",
    "gestampften": "gestampft",
    "gestampfter": "gestampft",
    "gestampftere": "gestampft",
    "gestampfterem": "gestampft",
    "gestampfteren": "gestampft",
    "gestampfterer": "gestampft",
    "gestampfteres": "gestampft",
    "gestampftes": "gestampft",
    "gestampfteste": "gestampft",
    "gestampftestem": "gestampft",
    "gestampftesten": "gestampft",
    "gestampftester": "gestampft",
    "gestampftestes": "gestampft",
    "gestand": "gestehen",
    "gestanden": "stehen",
    "gestandene": "gestanden",
    "gestandenem": "gestanden",
    "gestandenen": "gestanden",
    "gestandener": "gestanden",
    "gestandenes": "gestanden",
    "gestandest": "gestehen",
    "gestandet": "gestehen",
    "gestanzt": "stanzen",
    "gestanzte": "gestanzt",
    "gestanztem": "gestanzt",
    "gestanzten": "gestanzt",
    "gestanzter": "gestanzt",
    "gestanztes": "gestanzt",
    "gestapelt": "stapeln",
    "gestapelte": "gestapelt",
    "gestapeltem": "gestapelt",
    "gestapelten": "gestapelt",
    "gestapelter": "gestapelt",
    "gestapeltere": "gestapelt",
    "gestapelterem": "gestapelt",
    "gestapelteren": "gestapelt",
    "gestapelterer": "gestapelt",
    "gestapelteres": "gestapelt",
    "gestapeltes": "gestapelt",
    "gestapelteste": "gestapelt",
    "gestapeltestem": "gestapelt",
    "gestapeltesten": "gestapelt",
    "gestapeltester": "gestapelt",
    "gestapeltestes": "gestapelt",
    "gestapft": "stapfen",
    "gestapfte": "gestapft",
    "gestapftem": "gestapft",
    "gestapften": "gestapft",
    "gestapfter": "gestapft",
    "gestapftes": "gestapft",
    "gestarrt": "starren",
    "gestarrte": "gestarrt",
    "gestarrtem": "gestarrt",
    "gestarrten": "gestarrt",
    "gestarrter": "gestarrt",
    "gestarrtes": "gestarrt",
    "gestartet": "starten",
    "gestartete": "gestartet",
    "gestartetem": "gestartet",
    "gestarteten": "gestartet",
    "gestarteter": "gestartet",
    "gestartetes": "gestartet",
    "gestatte": "gestatten",
    "gestattend": "gestatten",
    "gestattende": "gestattend",
    "gestattendem": "gestattend",
    "gestattenden": "gestattend",
    "gestattender": "gestattend",
    "gestattendes": "gestattend",
    "gestattest": "gestatten",
    "gestattet": "statten",
    "gestattete": "gestatten",
    "gestattetem": "gestattet",
    "gestatteten": "gestatten",
    "gestatteter": "gestattet",
    "gestattetes": "gestattet",
    "gestattetest": "gestatten",
    "gestattetet": "gestatten",
    "gestaubt": "stauben",
    "gestaubte": "gestaubt",
    "gestaubtem": "gestaubt",
    "gestaubten": "gestaubt",
    "gestaubter": "gestaubt",
    "gestaubtere": "gestaubt",
    "gestaubterem": "gestaubt",
    "gestaubteren": "gestaubt",
    "gestaubterer": "gestaubt",
    "gestaubteres": "gestaubt",
    "gestaubtes": "gestaubt",
    "gestaubteste": "gestaubt",
    "gestaubtestem": "gestaubt",
    "gestaubtesten": "gestaubt",
    "gestaubtester": "gestaubt",
    "gestaubtestes": "gestaubt",
    "gestaucht": "stauchen",
    "gestauchte": "gestaucht",
    "gestauchtem": "gestaucht",
    "gestauchten": "gestaucht",
    "gestauchter": "gestaucht",
    "gestauchtere": "gestaucht",
    "gestauchterem": "gestaucht",
    "gestauchteren": "gestaucht",
    "gestauchterer": "gestaucht",
    "gestauchteres": "gestaucht",
    "gestauchtes": "gestaucht",
    "gestauchteste": "gestaucht",
    "gestauchtestem": "gestaucht",
    "gestauchtesten": "gestaucht",
    "gestauchtester": "gestaucht",
    "gestauchtestes": "gestaucht",
    "gestaunt": "staunen",
    "gestaunte": "gestaunt",
    "gestauntem": "gestaunt",
    "gestaunten": "gestaunt",
    "gestaunter": "gestaunt",
    "gestauntes": "gestaunt",
    "gestaut": "stauen",
    "gestaute": "gestaut",
    "gestautem": "gestaut",
    "gestauten": "gestaut",
    "gestauter": "gestaut",
    "gestautere": "gestaut",
    "gestauterem": "gestaut",
    "gestauteren": "gestaut",
    "gestauterer": "gestaut",
    "gestauteres": "gestaut",
    "gestautes": "gestaut",
    "gestauteste": "gestaut",
    "gestautestem": "gestaut",
    "gestautesten": "gestaut",
    "gestautester": "gestaut",
    "gestautestes": "gestaut",
    "gesteckt": "stecken",
    "gesteckte": "gesteckt",
    "gestecktem": "gesteckt",
    "gesteckten": "gesteckt",
    "gesteckter": "gesteckt",
    "gestecktes": "gesteckt",
    "gestehe": "gestehen",
    "gestehend": "gestehen",
    "gestehende": "gestehend",
    "gestehendem": "gestehend",
    "gestehenden": "gestehend",
    "gestehender": "gestehend",
    "gestehendes": "gestehend",
    "gestehest": "gestehen",
    "gestehet": "gestehen",
    "gestehst": "gestehen",
    "gesteht": "gestehen",
    "gesteift": "steifen",
    "gesteifte": "gesteift",
    "gesteiftem": "gesteift",
    "gesteiften": "gesteift",
    "gesteifter": "gesteift",
    "gesteiftere": "gesteift",
    "gesteifterem": "gesteift",
    "gesteifteren": "gesteift",
    "gesteifterer": "gesteift",
    "gesteifteres": "gesteift",
    "gesteiftes": "gesteift",
    "gesteifteste": "gesteift",
    "gesteiftestem": "gesteift",
    "gesteiftesten": "gesteift",
    "gesteiftester": "gesteift",
    "gesteiftestes": "gesteift",
    "gesteigert": "steigern",
    "gesteigerte": "gesteigert",
    "gesteigertem": "gesteigert",
    "gesteigerten": "gesteigert",
    "gesteigerter": "gesteigert",
    "gesteigertes": "gesteigert",
    "gesteinigt": "steinigen",
    "gesteinigte": "gesteinigt",
    "gesteinigtem": "gesteinigt",
    "gesteinigten": "gesteinigt",
    "gesteinigter": "gesteinigt",
    "gesteinigtes": "gesteinigt",
    "gestellt": "stellen",
    "gestellte": "gestellt",
    "gestelltem": "gestellt",
    "gestellten": "gestellt",
    "gestellter": "gestellt",
    "gestelltere": "gestellt",
    "gestellterem": "gestellt",
    "gestellteren": "gestellt",
    "gestellterer": "gestellt",
    "gestellteres": "gestellt",
    "gestelltes": "gestellt",
    "gestellteste": "gestellt",
    "gestelltestem": "gestellt",
    "gestelltesten": "gestellt",
    "gestelltester": "gestellt",
    "gestelltestes": "gestellt",
    "gestemmt": "stemmen",
    "gestemmte": "gestemmt",
    "gestemmtem": "gestemmt",
    "gestemmten": "gestemmt",
    "gestemmter": "gestemmt",
    "gestemmtes": "gestemmt",
    "gestempelt": "stempeln",
    "gestempelte": "gestempelt",
    "gestempeltem": "gestempelt",
    "gestempelten": "gestempelt",
    "gestempelter": "gestempelt",
    "gestempeltes": "gestempelt",
    "gestenreichem": "gestenreich",
    "gestenreichen": "gestenreich",
    "gestenreicher": "gestenreich",
    "gestenreichere": "gestenreich",
    "gestenreicherem": "gestenreich",
    "gestenreicheren": "gestenreich",
    "gestenreicherer": "gestenreich",
    "gestenreicheres": "gestenreich",
    "gestenreiches": "gestenreich",
    "gestenreichste": "gestenreich",
    "gestenreichstem": "gestenreich",
    "gestenreichsten": "gestenreich",
    "gestenreichster": "gestenreich",
    "gestenreichstes": "gestenreich",
    "gesteppt": "steppen",
    "gesteppte": "gesteppt",
    "gestepptem": "gesteppt",
    "gesteppten": "gesteppt",
    "gesteppter": "gesteppt",
    "gestepptes": "gesteppt",
    "gesteuert": "steuern",
    "gesteuerte": "gesteuert",
    "gesteuertem": "gesteuert",
    "gesteuerten": "gesteuert",
    "gesteuerter": "gesteuert",
    "gesteuertes": "gesteuert",
    "gestichelt": "sticheln",
    "gestichelte": "gestichelt",
    "gesticheltem": "gestichelt",
    "gestichelten": "gestichelt",
    "gestichelter": "gestichelt",
    "gesticheltes": "gestichelt",
    "gestiefelt": "stiefeln",
    "gestiefelte": "gestiefelt",
    "gestiefeltem": "gestiefelt",
    "gestiefelten": "gestiefelt",
    "gestiefelter": "gestiefelt",
    "gestiefeltes": "gestiefelt",
    "gestiegen": "steigen",
    "gestiegene": "gestiegen",
    "gestiegenem": "gestiegen",
    "gestiegenen": "gestiegen",
    "gestiegener": "gestiegen",
    "gestiegenes": "gestiegen",
    "gestielt": "stielen",
    "gestielte": "gestielt",
    "gestieltem": "gestielt",
    "gestielten": "gestielt",
    "gestielter": "gestielt",
    "gestieltes": "gestielt",
    "gestiert": "stieren",
    "gestierte": "gestiert",
    "gestiertem": "gestiert",
    "gestierten": "gestiert",
    "gestierter": "gestiert",
    "gestiertes": "gestiert",
    "gestiftet": "stiften",
    "gestiftete": "gestiftet",
    "gestiftetem": "gestiftet",
    "gestifteten": "gestiftet",
    "gestifteter": "gestiftet",
    "gestiftetes": "gestiftet",
    "gestikuliere": "gestikulieren",
    "gestikulierend": "gestikulieren",
    "gestikulierende": "gestikulierend",
    "gestikulierendem": "gestikulierend",
    "gestikulierenden": "gestikulierend",
    "gestikulierender": "gestikulierend",
    "gestikulierendere": "gestikulierend",
    "gestikulierenderem": "gestikulierend",
    "gestikulierenderen": "gestikulierend",
    "gestikulierenderer": "gestikulierend",
    "gestikulierenderes": "gestikulierend",
    "gestikulierendes": "gestikulierend",
    "gestikulierendste": "gestikulierend",
    "gestikulierendstem": "gestikulierend",
    "gestikulierendsten": "gestikulierend",
    "gestikulierendster": "gestikulierend",
    "gestikulierendstes": "gestikulierend",
    "gestikulierest": "gestikulieren",
    "gestikulieret": "gestikulieren",
    "gestikulierst": "gestikulieren",
    "gestikuliert": "gestikulieren",
    "gestikulierte": "gestikulieren",
    "gestikuliertem": "gestikuliert",
    "gestikulierten": "gestikulieren",
    "gestikulierter": "gestikuliert",
    "gestikuliertes": "gestikuliert",
    "gestikuliertest": "gestikulieren",
    "gestikuliertet": "gestikulieren",
    "gestillt": "stillen",
    "gestillte": "gestillt",
    "gestilltem": "gestillt",
    "gestillten": "gestillt",
    "gestillter": "gestillt",
    "gestilltes": "gestillt",
    "gestimmt": "stimmen",
    "gestimmte": "gestimmt",
    "gestimmtem": "gestimmt",
    "gestimmten": "gestimmt",
    "gestimmter": "gestimmt",
    "gestimmtere": "gestimmt",
    "gestimmterem": "gestimmt",
    "gestimmteren": "gestimmt",
    "gestimmterer": "gestimmt",
    "gestimmteres": "gestimmt",
    "gestimmtes": "gestimmt",
    "gestimmteste": "gestimmt",
    "gestimmtestem": "gestimmt",
    "gestimmtesten": "gestimmt",
    "gestimmtester": "gestimmt",
    "gestimmtestes": "gestimmt",
    "gestippt": "stippen",
    "gestippte": "gestippt",
    "gestipptem": "gestippt",
    "gestippten": "gestippt",
    "gestippter": "gestippt",
    "gestipptes": "gestippt",
    "gestoben": "stieben",
    "gestobene": "gestoben",
    "gestobenem": "gestoben",
    "gestobenen": "gestoben",
    "gestobener": "gestoben",
    "gestobenere": "gestoben",
    "gestobenerem": "gestoben",
    "gestobeneren": "gestoben",
    "gestobenerer": "gestoben",
    "gestobeneres": "gestoben",
    "gestobenes": "gestoben",
    "gestobenste": "gestoben",
    "gestobenstem": "gestoben",
    "gestobensten": "gestoben",
    "gestobenster": "gestoben",
    "gestobenstes": "gestoben",
    "gestochen": "stechen",
    "gestochene": "gestochen",
    "gestochenem": "gestochen",
    "gestochenen": "gestochen",
    "gestochener": "gestochen",
    "gestochenere": "gestochen",
    "gestochenerem": "gestochen",
    "gestocheneren": "gestochen",
    "gestochenerer": "gestochen",
    "gestocheneres": "gestochen",
    "gestochenes": "gestochen",
    "gestochenste": "gestochen",
    "gestochenstem": "gestochen",
    "gestochensten": "gestochen",
    "gestochenster": "gestochen",
    "gestochenstes": "gestochen",
    "gestochert": "stochern",
    "gestocherte": "gestochert",
    "gestochertem": "gestochert",
    "gestocherten": "gestochert",
    "gestocherter": "gestochert",
    "gestochertes": "gestochert",
    "gestockt": "stocken",
    "gestockte": "gestockt",
    "gestocktem": "gestockt",
    "gestockten": "gestockt",
    "gestockter": "gestockt",
    "gestocktes": "gestockt",
    "gestohlen": "stehlen",
    "gestohlene": "gestohlen",
    "gestohlenem": "gestohlen",
    "gestohlenen": "gestohlen",
    "gestohlener": "gestohlen",
    "gestohlenes": "gestohlen",
    "gestolpert": "stolpern",
    "gestolperte": "gestolpert",
    "gestolpertem": "gestolpert",
    "gestolperten": "gestolpert",
    "gestolperter": "gestolpert",
    "gestolpertes": "gestolpert",
    "gestopft": "stopfen",
    "gestopfte": "gestopft",
    "gestopftem": "gestopft",
    "gestopften": "gestopft",
    "gestopfter": "gestopft",
    "gestopftere": "gestopft",
    "gestopfterem": "gestopft",
    "gestopfteren": "gestopft",
    "gestopfterer": "gestopft",
    "gestopfteres": "gestopft",
    "gestopftes": "gestopft",
    "gestopfteste": "gestopft",
    "gestopftestem": "gestopft",
    "gestopftesten": "gestopft",
    "gestopftester": "gestopft",
    "gestopftestes": "gestopft",
    "gestoppelt": "stoppeln",
    "gestoppelte": "gestoppelt",
    "gestoppeltem": "gestoppelt",
    "gestoppelten": "gestoppelt",
    "gestoppelter": "gestoppelt",
    "gestoppeltes": "gestoppelt",
    "gestoppt": "stoppen",
    "gestoppte": "gestoppt",
    "gestopptem": "gestoppt",
    "gestoppten": "gestoppt",
    "gestoppter": "gestoppt",
    "gestopptes": "gestoppt",
    "gestorben": "sterben",
    "gestorbene": "gestorben",
    "gestorbenem": "gestorben",
    "gestorbenen": "gestorben",
    "gestorbener": "gestorben",
    "gestorbenes": "gestorben",
    "gestottert": "stottern",
    "gestotterte": "gestottert",
    "gestottertem": "gestottert",
    "gestotterten": "gestottert",
    "gestotterter": "gestottert",
    "gestottertes": "gestottert",
    "gestoßen": "stoßen",
    "gestoßene": "gestoßen",
    "gestoßenem": "gestoßen",
    "gestoßenen": "gestoßen",
    "gestoßener": "gestoßen",
    "gestoßenes": "gestoßen",
    "gestraft": "strafen",
    "gestrafte": "gestraft",
    "gestraftem": "gestraft",
    "gestraften": "gestraft",
    "gestrafter": "gestraft",
    "gestraftere": "gestraft",
    "gestrafterem": "gestraft",
    "gestrafteren": "gestraft",
    "gestrafterer": "gestraft",
    "gestrafteres": "gestraft",
    "gestraftes": "gestraft",
    "gestrafteste": "gestraft",
    "gestraftestem": "gestraft",
    "gestraftesten": "gestraft",
    "gestraftester": "gestraft",
    "gestraftestes": "gestraft",
    "gestrahlt": "strahlen",
    "gestrahlte": "gestrahlt",
    "gestrahltem": "gestrahlt",
    "gestrahlten": "gestrahlt",
    "gestrahlter": "gestrahlt",
    "gestrahltes": "gestrahlt",
    "gestrampelt": "strampeln",
    "gestrampelte": "gestrampelt",
    "gestrampeltem": "gestrampelt",
    "gestrampelten": "gestrampelt",
    "gestrampelter": "gestrampelt",
    "gestrampeltes": "gestrampelt",
    "gestrandet": "stranden",
    "gestrandete": "gestrandet",
    "gestrandetem": "gestrandet",
    "gestrandeten": "gestrandet",
    "gestrandeter": "gestrandet",
    "gestrandetes": "gestrandet",
    "gestrauchelt": "straucheln",
    "gestrauchelte": "gestrauchelt",
    "gestraucheltem": "gestrauchelt",
    "gestrauchelten": "gestrauchelt",
    "gestrauchelter": "gestrauchelt",
    "gestraucheltere": "gestrauchelt",
    "gestrauchelterem": "gestrauchelt",
    "gestrauchelteren": "gestrauchelt",
    "gestrauchelterer": "gestrauchelt",
    "gestrauchelteres": "gestrauchelt",
    "gestraucheltes": "gestrauchelt",
    "gestrauchelteste": "gestrauchelt",
    "gestraucheltestem": "gestrauchelt",
    "gestraucheltesten": "gestrauchelt",
    "gestraucheltester": "gestrauchelt",
    "gestraucheltestes": "gestrauchelt",
    "gestrebt": "streben",
    "gestrebte": "gestrebt",
    "gestrebtem": "gestrebt",
    "gestrebten": "gestrebt",
    "gestrebter": "gestrebt",
    "gestrebtes": "gestrebt",
    "gestreckt": "strecken",
    "gestreckte": "gestreckt",
    "gestrecktem": "gestreckt",
    "gestreckten": "gestreckt",
    "gestreckter": "gestreckt",
    "gestrecktere": "gestreckt",
    "gestreckterem": "gestreckt",
    "gestreckteren": "gestreckt",
    "gestreckterer": "gestreckt",
    "gestreckteres": "gestreckt",
    "gestrecktes": "gestreckt",
    "gestreckteste": "gestreckt",
    "gestrecktestem": "gestreckt",
    "gestrecktesten": "gestreckt",
    "gestrecktester": "gestreckt",
    "gestrecktestes": "gestreckt",
    "gestreichelt": "streicheln",
    "gestreichelte": "gestreichelt",
    "gestreicheltem": "gestreichelt",
    "gestreichelten": "gestreichelt",
    "gestreichelter": "gestreichelt",
    "gestreicheltes": "gestreichelt",
    "gestreift": "streifen",
    "gestreifte": "gestreift",
    "gestreiftem": "gestreift",
    "gestreiften": "gestreift",
    "gestreifter": "gestreift",
    "gestreiftes": "gestreift",
    "gestreikt": "streiken",
    "gestreikte": "gestreikt",
    "gestreiktem": "gestreikt",
    "gestreikten": "gestreikt",
    "gestreikter": "gestreikt",
    "gestreiktes": "gestreikt",
    "gestrengt": "strengen",
    "gestreunt": "streunen",
    "gestreunte": "gestreunt",
    "gestreuntem": "gestreunt",
    "gestreunten": "gestreunt",
    "gestreunter": "gestreunt",
    "gestreuntes": "gestreunt",
    "gestreuselt": "streuseln",
    "gestreuselte": "gestreuselt",
    "gestreuseltem": "gestreuselt",
    "gestreuselten": "gestreuselt",
    "gestreuselter": "gestreuselt",
    "gestreuseltes": "gestreuselt",
    "gestreut": "streuen",
    "gestreute": "gestreut",
    "gestreutem": "gestreut",
    "gestreuten": "gestreut",
    "gestreuter": "gestreut",
    "gestreutes": "gestreut",
    "gestreßt": "stressen",
    "gestreßte": "gestreßt",
    "gestreßtem": "gestreßt",
    "gestreßten": "gestreßt",
    "gestreßter": "gestreßt",
    "gestreßtere": "gestreßt",
    "gestreßterem": "gestreßt",
    "gestreßteren": "gestreßt",
    "gestreßterer": "gestreßt",
    "gestreßteres": "gestreßt",
    "gestreßtes": "gestreßt",
    "gestreßteste": "gestreßt",
    "gestreßtestem": "gestreßt",
    "gestreßtesten": "gestreßt",
    "gestreßtester": "gestreßt",
    "gestreßtestes": "gestreßt",
    "gestrichen": "streichen",
    "gestrichene": "gestrichen",
    "gestrichenem": "gestrichen",
    "gestrichenen": "gestrichen",
    "gestrichener": "gestrichen",
    "gestrichenes": "gestrichen",
    "gestriegelt": "striegeln",
    "gestriegelte": "gestriegelt",
    "gestriegeltem": "gestriegelt",
    "gestriegelten": "gestriegelt",
    "gestriegelter": "gestriegelt",
    "gestriegeltere": "gestriegelt",
    "gestriegelterem": "gestriegelt",
    "gestriegelteren": "gestriegelt",
    "gestriegelterer": "gestriegelt",
    "gestriegelteres": "gestriegelt",
    "gestriegeltes": "gestriegelt",
    "gestriegelteste": "gestriegelt",
    "gestriegeltestem": "gestriegelt",
    "gestriegeltesten": "gestriegelt",
    "gestriegeltester": "gestriegelt",
    "gestriegeltestes": "gestriegelt",
    "gestrige": "gestrig",
    "gestrigem": "gestrig",
    "gestrigen": "gestrig",
    "gestriger": "gestrig",
    "gestriges": "gestrig",
    "gestrippt": "strippen",
    "gestrippte": "gestrippt",
    "gestripptem": "gestrippt",
    "gestrippten": "gestrippt",
    "gestrippter": "gestrippt",
    "gestripptes": "gestrippt",
    "gestritten": "streiten",
    "gestrittene": "gestritten",
    "gestrittenem": "gestritten",
    "gestrittenen": "gestritten",
    "gestrittener": "gestritten",
    "gestrittenes": "gestritten",
    "gestrolcht": "strolchen",
    "gestrolchte": "gestrolcht",
    "gestrolchtem": "gestrolcht",
    "gestrolchten": "gestrolcht",
    "gestrolchter": "gestrolcht",
    "gestrolchtes": "gestrolcht",
    "gestromert": "stromern",
    "gestromerte": "gestromert",
    "gestromertem": "gestromert",
    "gestromerten": "gestromert",
    "gestromerter": "gestromert",
    "gestromertes": "gestromert",
    "gestrotzt": "strotzen",
    "gestrotzte": "gestrotzt",
    "gestrotztem": "gestrotzt",
    "gestrotzten": "gestrotzt",
    "gestrotzter": "gestrotzt",
    "gestrotztes": "gestrotzt",
    "gestrudelt": "strudeln",
    "gestrudelte": "gestrudelt",
    "gestrudeltem": "gestrudelt",
    "gestrudelten": "gestrudelt",
    "gestrudelter": "gestrudelt",
    "gestrudeltes": "gestrudelt",
    "gestrullt": "strullen",
    "gestrullte": "gestrullt",
    "gestrulltem": "gestrullt",
    "gestrullten": "gestrullt",
    "gestrullter": "gestrullt",
    "gestrulltes": "gestrullt",
    "gesträubt": "sträuben",
    "gesträubte": "gesträubt",
    "gesträubtem": "gesträubt",
    "gesträubten": "gesträubt",
    "gesträubter": "gesträubt",
    "gesträubtes": "gesträubt",
    "geströmt": "strömen",
    "geströmte": "geströmt",
    "geströmtem": "geströmt",
    "geströmten": "geströmt",
    "geströmter": "geströmt",
    "geströmtes": "geströmt",
    "gestuft": "stufen",
    "gestufte": "gestuft",
    "gestuftem": "gestuft",
    "gestuften": "gestuft",
    "gestufter": "gestuft",
    "gestuftes": "gestuft",
    "gestumpft": "stumpfen",
    "gestumpfte": "gestumpft",
    "gestumpftem": "gestumpft",
    "gestumpften": "gestumpft",
    "gestumpfter": "gestumpft",
    "gestumpftes": "gestumpft",
    "gestundet": "stunden",
    "gestundete": "gestundet",
    "gestundetem": "gestundet",
    "gestundeten": "gestundet",
    "gestundeter": "gestundet",
    "gestundetes": "gestundet",
    "gestunken": "stinken",
    "gestunkene": "gestunken",
    "gestunkenem": "gestunken",
    "gestunkenen": "gestunken",
    "gestunkener": "gestunken",
    "gestunkenes": "gestunken",
    "gestutzt": "stutzen",
    "gestutzte": "gestutzt",
    "gestutztem": "gestutzt",
    "gestutzten": "gestutzt",
    "gestutzter": "gestutzt",
    "gestutztere": "gestutzt",
    "gestutzterem": "gestutzt",
    "gestutzteren": "gestutzt",
    "gestutzterer": "gestutzt",
    "gestutzteres": "gestutzt",
    "gestutztes": "gestutzt",
    "gestutzteste": "gestutzt",
    "gestutztestem": "gestutzt",
    "gestutztesten": "gestutzt",
    "gestutztester": "gestutzt",
    "gestutztestes": "gestutzt",
    "gestände": "gestehen",
    "geständen": "gestehen",
    "geständest": "gestehen",
    "geständet": "gestehen",
    "geständige": "geständig",
    "geständigem": "geständig",
    "geständigen": "geständig",
    "geständiger": "geständig",
    "geständiges": "geständig",
    "gestänkert": "stänkern",
    "gestänkerte": "gestänkert",
    "gestänkertem": "gestänkert",
    "gestänkerten": "gestänkert",
    "gestänkerter": "gestänkert",
    "gestänkertes": "gestänkert",
    "gestärkt": "stärken",
    "gestärkte": "gestärkt",
    "gestärktem": "gestärkt",
    "gestärkten": "gestärkt",
    "gestärkter": "gestärkt",
    "gestärktere": "gestärkt",
    "gestärkterem": "gestärkt",
    "gestärkteren": "gestärkt",
    "gestärkterer": "gestärkt",
    "gestärkteres": "gestärkt",
    "gestärktes": "gestärkt",
    "gestärkteste": "gestärkt",
    "gestärktestem": "gestärkt",
    "gestärktesten": "gestärkt",
    "gestärktester": "gestärkt",
    "gestärktestes": "gestärkt",
    "gestöbert": "stöbern",
    "gestöberte": "gestöbert",
    "gestöbertem": "gestöbert",
    "gestöberten": "gestöbert",
    "gestöberter": "gestöbert",
    "gestöbertes": "gestöbert",
    "gestöhnt": "stöhnen",
    "gestöhnte": "gestöhnt",
    "gestöhntem": "gestöhnt",
    "gestöhnten": "gestöhnt",
    "gestöhnter": "gestöhnt",
    "gestöhntes": "gestöhnt",
    "gestöpselt": "stöpseln",
    "gestöpselte": "gestöpselt",
    "gestöpseltem": "gestöpselt",
    "gestöpselten": "gestöpselt",
    "gestöpselter": "gestöpselt",
    "gestöpseltes": "gestöpselt",
    "gestört": "stören",
    "gestörte": "gestört",
    "gestörtem": "gestört",
    "gestörten": "gestört",
    "gestörter": "gestört",
    "gestörtere": "gestört",
    "gestörterem": "gestört",
    "gestörteren": "gestört",
    "gestörterer": "gestört",
    "gestörteres": "gestört",
    "gestörtes": "gestört",
    "gestörteste": "gestört",
    "gestörtestem": "gestört",
    "gestörtesten": "gestört",
    "gestörtester": "gestört",
    "gestörtestes": "gestört",
    "gestückelt": "stückeln",
    "gestückelte": "gestückelt",
    "gestückeltem": "gestückelt",
    "gestückelten": "gestückelt",
    "gestückelter": "gestückelt",
    "gestückeltere": "gestückelt",
    "gestückelterem": "gestückelt",
    "gestückelteren": "gestückelt",
    "gestückelterer": "gestückelt",
    "gestückelteres": "gestückelt",
    "gestückeltes": "gestückelt",
    "gestückelteste": "gestückelt",
    "gestückeltestem": "gestückelt",
    "gestückeltesten": "gestückelt",
    "gestückeltester": "gestückelt",
    "gestückeltestes": "gestückelt",
    "gestülpt": "stülpen",
    "gestülpte": "gestülpt",
    "gestülptem": "gestülpt",
    "gestülpten": "gestülpt",
    "gestülpter": "gestülpt",
    "gestülptes": "gestülpt",
    "gestümmelt": "stümmeln",
    "gestümmelte": "gestümmelt",
    "gestümmeltem": "gestümmelt",
    "gestümmelten": "gestümmelt",
    "gestümmelter": "gestümmelt",
    "gestümmeltes": "gestümmelt",
    "gestümpert": "stümpern",
    "gestümperte": "gestümpert",
    "gestümpertem": "gestümpert",
    "gestümperten": "gestümpert",
    "gestümperter": "gestümpert",
    "gestümpertere": "gestümpert",
    "gestümperterem": "gestümpert",
    "gestümperteren": "gestümpert",
    "gestümperterer": "gestümpert",
    "gestümperteres": "gestümpert",
    "gestümpertes": "gestümpert",
    "gestümperteste": "gestümpert",
    "gestümpertestem": "gestümpert",
    "gestümpertesten": "gestümpert",
    "gestümpertester": "gestümpert",
    "gestümpertestes": "gestümpert",
    "gestürmt": "stürmen",
    "gestürmte": "gestürmt",
    "gestürmtem": "gestürmt",
    "gestürmten": "gestürmt",
    "gestürmter": "gestürmt",
    "gestürmtes": "gestürmt",
    "gestürzt": "stürzen",
    "gestürzte": "gestürzt",
    "gestürztem": "gestürzt",
    "gestürzten": "gestürzt",
    "gestürzter": "gestürzt",
    "gestürztes": "gestürzt",
    "gestützt": "stützen",
    "gestütztem": "gestützt",
    "gestützter": "gestützt",
    "gestütztes": "gestützt",
    "gesucht": "suchen",
    "gesuchte": "gesucht",
    "gesuchtem": "gesucht",
    "gesuchten": "gesucht",
    "gesuchter": "gesucht",
    "gesuchtere": "gesucht",
    "gesuchterem": "gesucht",
    "gesuchteren": "gesucht",
    "gesuchterer": "gesucht",
    "gesuchteres": "gesucht",
    "gesuchtes": "gesucht",
    "gesuchteste": "gesucht",
    "gesuchtestem": "gesucht",
    "gesuchtesten": "gesucht",
    "gesuchtester": "gesucht",
    "gesuchtestes": "gesucht",
    "gesudelt": "sudeln",
    "gesudelte": "gesudelt",
    "gesudeltem": "gesudelt",
    "gesudelten": "gesudelt",
    "gesudelter": "gesudelt",
    "gesudeltere": "gesudelt",
    "gesudelterem": "gesudelt",
    "gesudelteren": "gesudelt",
    "gesudelterer": "gesudelt",
    "gesudelteres": "gesudelt",
    "gesudeltes": "gesudelt",
    "gesudelteste": "gesudelt",
    "gesudeltestem": "gesudelt",
    "gesudeltesten": "gesudelt",
    "gesudeltester": "gesudelt",
    "gesudeltestes": "gesudelt",
    "gesuhlt": "suhlen",
    "gesuhlte": "gesuhlt",
    "gesuhltem": "gesuhlt",
    "gesuhlten": "gesuhlt",
    "gesuhlter": "gesuhlt",
    "gesuhltes": "gesuhlt",
    "gesumpft": "sumpfen",
    "gesumpfte": "gesumpft",
    "gesumpftem": "gesumpft",
    "gesumpften": "gesumpft",
    "gesumpfter": "gesumpft",
    "gesumpftes": "gesumpft",
    "gesundbete": "gesundbeten",
    "gesundbetend": "gesundbeten",
    "gesundbetende": "gesundbetend",
    "gesundbetendem": "gesundbetend",
    "gesundbetenden": "gesundbetend",
    "gesundbetender": "gesundbetend",
    "gesundbetendes": "gesundbetend",
    "gesundbetest": "gesundbeten",
    "gesundbetet": "gesundbeten",
    "gesundbetete": "gesundbeten",
    "gesundbeteten": "gesundbeten",
    "gesundbetetest": "gesundbeten",
    "gesundbetetet": "gesundbeten",
    "gesunde": "gesunden",
    "gesundem": "gesund",
    "gesunden": "gesund",
    "gesundend": "gesunden",
    "gesundende": "gesundend",
    "gesundendem": "gesundend",
    "gesundenden": "gesundend",
    "gesundender": "gesundend",
    "gesundendere": "gesundend",
    "gesundenderem": "gesundend",
    "gesundenderen": "gesundend",
    "gesundenderer": "gesundend",
    "gesundenderes": "gesundend",
    "gesundendes": "gesundend",
    "gesundendste": "gesundend",
    "gesundendstem": "gesundend",
    "gesundendsten": "gesundend",
    "gesundendster": "gesundend",
    "gesundendstes": "gesundend",
    "gesunder": "gesund",
    "gesundere": "gesund",
    "gesunderem": "gesund",
    "gesunderen": "gesund",
    "gesunderer": "gesund",
    "gesunderes": "gesund",
    "gesundes": "gesund",
    "gesundest": "gesunden",
    "gesundeste": "gesund",
    "gesundestem": "gesund",
    "gesundesten": "gesund",
    "gesundester": "gesund",
    "gesundestes": "gesund",
    "gesundet": "gesunden",
    "gesundete": "gesunden",
    "gesundetem": "gesundet",
    "gesundeten": "gesunden",
    "gesundeter": "gesundet",
    "gesundetes": "gesundet",
    "gesundetest": "gesunden",
    "gesundetet": "gesunden",
    "gesundgebetet": "gesundbeten",
    "gesundgebetete": "gesundgebetet",
    "gesundgebetetem": "gesundgebetet",
    "gesundgebeteten": "gesundgebetet",
    "gesundgebeteter": "gesundgebetet",
    "gesundgebetetes": "gesundgebetet",
    "gesundgepflegt": "gesundpflegen",
    "gesundgepflegte": "gesundgepflegt",
    "gesundgepflegtem": "gesundgepflegt",
    "gesundgepflegten": "gesundgepflegt",
    "gesundgepflegter": "gesundgepflegt",
    "gesundgepflegtere": "gesundgepflegt",
    "gesundgepflegterem": "gesundgepflegt",
    "gesundgepflegteren": "gesundgepflegt",
    "gesundgepflegterer": "gesundgepflegt",
    "gesundgepflegteres": "gesundgepflegt",
    "gesundgepflegtes": "gesundgepflegt",
    "gesundgepflegteste": "gesundgepflegt",
    "gesundgepflegtestem": "gesundgepflegt",
    "gesundgepflegtesten": "gesundgepflegt",
    "gesundgepflegtester": "gesundgepflegt",
    "gesundgepflegtestes": "gesundgepflegt",
    "gesundgeschrieben": "gesundschreiben",
    "gesundgeschriebene": "gesundgeschrieben",
    "gesundgeschriebenem": "gesundgeschrieben",
    "gesundgeschriebenen": "gesundgeschrieben",
    "gesundgeschriebener": "gesundgeschrieben",
    "gesundgeschriebenes": "gesundgeschrieben",
    "gesundgeschrumpft": "gesundschrumpfen",
    "gesundgeschrumpfte": "gesundgeschrumpft",
    "gesundgeschrumpftem": "gesundgeschrumpft",
    "gesundgeschrumpften": "gesundgeschrumpft",
    "gesundgeschrumpfter": "gesundgeschrumpft",
    "gesundgeschrumpftere": "gesundgeschrumpft",
    "gesundgeschrumpfterem": "gesundgeschrumpft",
    "gesundgeschrumpfteren": "gesundgeschrumpft",
    "gesundgeschrumpfterer": "gesundgeschrumpft",
    "gesundgeschrumpfteres": "gesundgeschrumpft",
    "gesundgeschrumpftes": "gesundgeschrumpft",
    "gesundgeschrumpfteste": "gesundgeschrumpft",
    "gesundgeschrumpftestem": "gesundgeschrumpft",
    "gesundgeschrumpftesten": "gesundgeschrumpft",
    "gesundgeschrumpftester": "gesundgeschrumpft",
    "gesundgeschrumpftestes": "gesundgeschrumpft",
    "gesundgestoßen": "gesundstoßen",
    "gesundgestoßene": "gesundgestoßen",
    "gesundgestoßenem": "gesundgestoßen",
    "gesundgestoßenen": "gesundgestoßen",
    "gesundgestoßener": "gesundgestoßen",
    "gesundgestoßenere": "gesundgestoßen",
    "gesundgestoßenerem": "gesundgestoßen",
    "gesundgestoßeneren": "gesundgestoßen",
    "gesundgestoßenerer": "gesundgestoßen",
    "gesundgestoßeneres": "gesundgestoßen",
    "gesundgestoßenes": "gesundgestoßen",
    "gesundgestoßenste": "gesundgestoßen",
    "gesundgestoßenstem": "gesundgestoßen",
    "gesundgestoßensten": "gesundgestoßen",
    "gesundgestoßenster": "gesundgestoßen",
    "gesundgestoßenstes": "gesundgestoßen",
    "gesundheitlichem": "gesundheitlich",
    "gesundheitlichen": "gesundheitlich",
    "gesundheitlicher": "gesundheitlich",
    "gesundheitliches": "gesundheitlich",
    "gesundheitsschädliche": "gesundheitsschädlich",
    "gesundheitsschädlichem": "gesundheitsschädlich",
    "gesundheitsschädlichen": "gesundheitsschädlich",
    "gesundheitsschädlicher": "gesundheitsschädlich",
    "gesundheitsschädlichere": "gesundheitsschädlich",
    "gesundheitsschädlicherem": "gesundheitsschädlich",
    "gesundheitsschädlicheren": "gesundheitsschädlich",
    "gesundheitsschädlicherer": "gesundheitsschädlich",
    "gesundheitsschädlicheres": "gesundheitsschädlich",
    "gesundheitsschädliches": "gesundheitsschädlich",
    "gesundheitsschädlichste": "gesundheitsschädlich",
    "gesundheitsschädlichstem": "gesundheitsschädlich",
    "gesundheitsschädlichsten": "gesundheitsschädlich",
    "gesundheitsschädlichster": "gesundheitsschädlich",
    "gesundheitsschädlichstes": "gesundheitsschädlich",
    "gesundpflege": "gesundpflegen",
    "gesundpflegend": "gesundpflegen",
    "gesundpflegende": "gesundpflegend",
    "gesundpflegendem": "gesundpflegend",
    "gesundpflegenden": "gesundpflegend",
    "gesundpflegender": "gesundpflegend",
    "gesundpflegendere": "gesundpflegend",
    "gesundpflegenderem": "gesundpflegend",
    "gesundpflegenderen": "gesundpflegend",
    "gesundpflegenderer": "gesundpflegend",
    "gesundpflegenderes": "gesundpflegend",
    "gesundpflegendes": "gesundpflegend",
    "gesundpflegendste": "gesundpflegend",
    "gesundpflegendstem": "gesundpflegend",
    "gesundpflegendsten": "gesundpflegend",
    "gesundpflegendster": "gesundpflegend",
    "gesundpflegendstes": "gesundpflegend",
    "gesundpflegest": "gesundpflegen",
    "gesundpfleget": "gesundpflegen",
    "gesundpflegst": "gesundpflegen",
    "gesundpflegt": "gesundpflegen",
    "gesundpflegte": "gesundpflegen",
    "gesundpflegten": "gesundpflegen",
    "gesundpflegtest": "gesundpflegen",
    "gesundpflegtet": "gesundpflegen",
    "gesundschreibe": "gesundschreiben",
    "gesundschreibend": "gesundschreiben",
    "gesundschreibende": "gesundschreibend",
    "gesundschreibendem": "gesundschreibend",
    "gesundschreibenden": "gesundschreibend",
    "gesundschreibender": "gesundschreibend",
    "gesundschreibendes": "gesundschreibend",
    "gesundschreibest": "gesundschreiben",
    "gesundschreibet": "gesundschreiben",
    "gesundschreibst": "gesundschreiben",
    "gesundschreibt": "gesundschreiben",
    "gesundschrieb": "gesundschreiben",
    "gesundschriebe": "gesundschreiben",
    "gesundschrieben": "gesundschreiben",
    "gesundschriebest": "gesundschreiben",
    "gesundschriebet": "gesundschreiben",
    "gesundschriebst": "gesundschreiben",
    "gesundschriebt": "gesundschreiben",
    "gesundschrumpfe": "gesundschrumpfen",
    "gesundschrumpfend": "gesundschrumpfen",
    "gesundschrumpfende": "gesundschrumpfend",
    "gesundschrumpfendem": "gesundschrumpfend",
    "gesundschrumpfenden": "gesundschrumpfend",
    "gesundschrumpfender": "gesundschrumpfend",
    "gesundschrumpfendere": "gesundschrumpfend",
    "gesundschrumpfenderem": "gesundschrumpfend",
    "gesundschrumpfenderen": "gesundschrumpfend",
    "gesundschrumpfenderer": "gesundschrumpfend",
    "gesundschrumpfenderes": "gesundschrumpfend",
    "gesundschrumpfendes": "gesundschrumpfend",
    "gesundschrumpfendste": "gesundschrumpfend",
    "gesundschrumpfendstem": "gesundschrumpfend",
    "gesundschrumpfendsten": "gesundschrumpfend",
    "gesundschrumpfendster": "gesundschrumpfend",
    "gesundschrumpfendstes": "gesundschrumpfend",
    "gesundschrumpfest": "gesundschrumpfen",
    "gesundschrumpfet": "gesundschrumpfen",
    "gesundschrumpfst": "gesundschrumpfen",
    "gesundschrumpft": "gesundschrumpfen",
    "gesundschrumpfte": "gesundschrumpfen",
    "gesundschrumpften": "gesundschrumpfen",
    "gesundschrumpftest": "gesundschrumpfen",
    "gesundschrumpftet": "gesundschrumpfen",
    "gesundstieß": "gesundstoßen",
    "gesundstieße": "gesundstoßen",
    "gesundstießen": "gesundstoßen",
    "gesundstießest": "gesundstoßen",
    "gesundstießet": "gesundstoßen",
    "gesundstießt": "gesundstoßen",
    "gesundstoße": "gesundstoßen",
    "gesundstoßend": "gesundstoßen",
    "gesundstoßende": "gesundstoßend",
    "gesundstoßendem": "gesundstoßend",
    "gesundstoßenden": "gesundstoßend",
    "gesundstoßender": "gesundstoßend",
    "gesundstoßendere": "gesundstoßend",
    "gesundstoßenderem": "gesundstoßend",
    "gesundstoßenderen": "gesundstoßend",
    "gesundstoßenderer": "gesundstoßend",
    "gesundstoßenderes": "gesundstoßend",
    "gesundstoßendes": "gesundstoßend",
    "gesundstoßendste": "gesundstoßend",
    "gesundstoßendstem": "gesundstoßend",
    "gesundstoßendsten": "gesundstoßend",
    "gesundstoßendster": "gesundstoßend",
    "gesundstoßendstes": "gesundstoßend",
    "gesundstoßest": "gesundstoßen",
    "gesundstoßet": "gesundstoßen",
    "gesundstoßt": "gesundstoßen",
    "gesundstößt": "gesundstoßen",
    "gesundzubeten": "gesundbeten",
    "gesundzupflegen": "gesundpflegen",
    "gesundzuschreiben": "gesundschreiben",
    "gesundzuschrumpfen": "gesundschrumpfen",
    "gesundzustoßen": "gesundstoßen",
    "gesungen": "singen",
    "gesungene": "gesungen",
    "gesungenem": "gesungen",
    "gesungenen": "gesungen",
    "gesungener": "gesungen",
    "gesungenere": "gesungen",
    "gesungenerem": "gesungen",
    "gesungeneren": "gesungen",
    "gesungenerer": "gesungen",
    "gesungeneres": "gesungen",
    "gesungenes": "gesungen",
    "gesungenste": "gesungen",
    "gesungenstem": "gesungen",
    "gesungensten": "gesungen",
    "gesungenster": "gesungen",
    "gesungenstes": "gesungen",
    "gesunken": "sinken",
    "gesunkene": "gesunken",
    "gesunkenem": "gesunken",
    "gesunkenen": "gesunken",
    "gesunkener": "gesunken",
    "gesunkenere": "gesunken",
    "gesunkenerem": "gesunken",
    "gesunkeneren": "gesunken",
    "gesunkenerer": "gesunken",
    "gesunkeneres": "gesunken",
    "gesunkenes": "gesunken",
    "gesunkenste": "gesunken",
    "gesunkenstem": "gesunken",
    "gesunkensten": "gesunken",
    "gesunkenster": "gesunken",
    "gesunkenstes": "gesunken",
    "gesurrt": "surren",
    "gesurrte": "gesurrt",
    "gesurrtem": "gesurrt",
    "gesurrten": "gesurrt",
    "gesurrter": "gesurrt",
    "gesurrtes": "gesurrt",
    "geswingt": "swingen",
    "geswingte": "geswingt",
    "geswingtem": "geswingt",
    "geswingten": "geswingt",
    "geswingter": "geswingt",
    "geswingtere": "geswingt",
    "geswingterem": "geswingt",
    "geswingteren": "geswingt",
    "geswingterer": "geswingt",
    "geswingteres": "geswingt",
    "geswingtes": "geswingt",
    "geswingteste": "geswingt",
    "geswingtestem": "geswingt",
    "geswingtesten": "geswingt",
    "geswingtester": "geswingt",
    "geswingtestes": "geswingt",
    "gesäbelt": "säbeln",
    "gesäbelte": "gesäbelt",
    "gesäbeltem": "gesäbelt",
    "gesäbelten": "gesäbelt",
    "gesäbelter": "gesäbelt",
    "gesäbeltes": "gesäbelt",
    "gesägt": "sägen",
    "gesägtem": "gesägt",
    "gesägter": "gesägt",
    "gesägtes": "gesägt",
    "gesäht": "sähen",
    "gesähte": "gesäht",
    "gesähtem": "gesäht",
    "gesähten": "gesäht",
    "gesähter": "gesäht",
    "gesähtes": "gesäht",
    "gesänftigt": "sänftigen",
    "gesänftigte": "gesänftigt",
    "gesänftigtem": "gesänftigt",
    "gesänftigten": "gesänftigt",
    "gesänftigter": "gesänftigt",
    "gesänftigtere": "gesänftigt",
    "gesänftigterem": "gesänftigt",
    "gesänftigteren": "gesänftigt",
    "gesänftigterer": "gesänftigt",
    "gesänftigteres": "gesänftigt",
    "gesänftigtes": "gesänftigt",
    "gesänftigteste": "gesänftigt",
    "gesänftigtestem": "gesänftigt",
    "gesänftigtesten": "gesänftigt",
    "gesänftigtester": "gesänftigt",
    "gesänftigtestes": "gesänftigt",
    "gesät": "säen",
    "gesäte": "gesät",
    "gesätem": "gesät",
    "gesäten": "gesät",
    "gesäter": "gesät",
    "gesätes": "gesät",
    "gesättigt": "sättigen",
    "gesättigte": "gesättigt",
    "gesättigtem": "gesättigt",
    "gesättigten": "gesättigt",
    "gesättigter": "gesättigt",
    "gesättigtere": "gesättigt",
    "gesättigterem": "gesättigt",
    "gesättigteren": "gesättigt",
    "gesättigterer": "gesättigt",
    "gesättigteres": "gesättigt",
    "gesättigtes": "gesättigt",
    "gesättigteste": "gesättigt",
    "gesättigtestem": "gesättigt",
    "gesättigtesten": "gesättigt",
    "gesättigtester": "gesättigt",
    "gesättigtestes": "gesättigt",
    "gesäubert": "säubern",
    "gesäuberte": "gesäubert",
    "gesäubertem": "gesäubert",
    "gesäuberten": "gesäubert",
    "gesäuberter": "gesäubert",
    "gesäubertere": "gesäubert",
    "gesäuberterem": "gesäubert",
    "gesäuberteren": "gesäubert",
    "gesäuberterer": "gesäubert",
    "gesäuberteres": "gesäubert",
    "gesäubertes": "gesäubert",
    "gesäuberteste": "gesäubert",
    "gesäubertestem": "gesäubert",
    "gesäubertesten": "gesäubert",
    "gesäubertester": "gesäubert",
    "gesäubertestes": "gesäubert",
    "gesäuert": "säuern",
    "gesäuertem": "gesäuert",
    "gesäuerter": "gesäuert",
    "gesäuerterem": "gesäuert",
    "gesäuerterer": "gesäuert",
    "gesäuerteres": "gesäuert",
    "gesäuertes": "gesäuert",
    "gesäuertestem": "gesäuert",
    "gesäuertester": "gesäuert",
    "gesäuertestes": "gesäuert",
    "gesäumt": "säumen",
    "gesäumte": "gesäumt",
    "gesäumtem": "gesäumt",
    "gesäumten": "gesäumt",
    "gesäumter": "gesäumt",
    "gesäumtes": "gesäumt",
    "gesäuselt": "säuseln",
    "gesäuselte": "gesäuselt",
    "gesäuseltem": "gesäuselt",
    "gesäuselten": "gesäuselt",
    "gesäuselter": "gesäuselt",
    "gesäuseltes": "gesäuselt",
    "gesöhnt": "söhnen",
    "gesöhnte": "gesöhnt",
    "gesöhntem": "gesöhnt",
    "gesöhnten": "gesöhnt",
    "gesöhnter": "gesöhnt",
    "gesöhntes": "gesöhnt",
    "gesüffelt": "süffeln",
    "gesüffelte": "gesüffelt",
    "gesüffeltem": "gesüffelt",
    "gesüffelten": "gesüffelt",
    "gesüffelter": "gesüffelt",
    "gesüffeltes": "gesüffelt",
    "gesühnt": "sühnen",
    "gesühnte": "gesühnt",
    "gesühntem": "gesühnt",
    "gesühnten": "gesühnt",
    "gesühnter": "gesühnt",
    "gesühntes": "gesühnt",
    "gesülzt": "sülzen",
    "gesülzte": "gesülzt",
    "gesülztem": "gesülzt",
    "gesülzten": "gesülzt",
    "gesülzter": "gesülzt",
    "gesülztes": "gesülzt",
    "gesündigt": "sündigen",
    "gesündigte": "gesündigt",
    "gesündigtem": "gesündigt",
    "gesündigten": "gesündigt",
    "gesündigter": "gesündigt",
    "gesündigtere": "gesündigt",
    "gesündigterem": "gesündigt",
    "gesündigteren": "gesündigt",
    "gesündigterer": "gesündigt",
    "gesündigteres": "gesündigt",
    "gesündigtes": "gesündigt",
    "gesündigteste": "gesündigt",
    "gesündigtestem": "gesündigt",
    "gesündigtesten": "gesündigt",
    "gesündigtester": "gesündigt",
    "gesündigtestes": "gesündigt",
    "gesüßt": "süßen",
    "gesüßte": "gesüßt",
    "gesüßtem": "gesüßt",
    "gesüßten": "gesüßt",
    "gesüßter": "gesüßt",
    "gesüßtere": "gesüßt",
    "gesüßterem": "gesüßt",
    "gesüßteren": "gesüßt",
    "gesüßterer": "gesüßt",
    "gesüßteres": "gesüßt",
    "gesüßtes": "gesüßt",
    "gesüßteste": "gesüßt",
    "gesüßtestem": "gesüßt",
    "gesüßtesten": "gesüßt",
    "gesüßtester": "gesüßt",
    "gesüßtestes": "gesüßt",
    "getadelt": "tadeln",
    "getadelte": "getadelt",
    "getadeltem": "getadelt",
    "getadelten": "getadelt",
    "getadelter": "getadelt",
    "getadeltere": "getadelt",
    "getadelterem": "getadelt",
    "getadelteren": "getadelt",
    "getadelterer": "getadelt",
    "getadelteres": "getadelt",
    "getadeltes": "getadelt",
    "getadelteste": "getadelt",
    "getadeltestem": "getadelt",
    "getadeltesten": "getadelt",
    "getadeltester": "getadelt",
    "getadeltestes": "getadelt",
    "getagt": "tagen",
    "getagte": "getagt",
    "getagtem": "getagt",
    "getagten": "getagt",
    "getagter": "getagt",
    "getagtes": "getagt",
    "getakelt": "takeln",
    "getakelte": "getakelt",
    "getakeltem": "getakelt",
    "getakelten": "getakelt",
    "getakelter": "getakelt",
    "getakeltes": "getakelt",
    "getan": "tun",
    "getane": "getan",
    "getanem": "getan",
    "getanen": "getan",
    "getaner": "getan",
    "getanes": "getan",
    "getankt": "tanken",
    "getankte": "getankt",
    "getanktem": "getankt",
    "getankten": "getankt",
    "getankter": "getankt",
    "getanktes": "getankt",
    "getanzt": "tanzen",
    "getanzte": "getanzt",
    "getanztem": "getanzt",
    "getanzten": "getanzt",
    "getanzter": "getanzt",
    "getanztes": "getanzt",
    "getapert": "tapern",
    "getaperte": "getapert",
    "getapertem": "getapert",
    "getaperten": "getapert",
    "getaperter": "getapert",
    "getapertes": "getapert",
    "getappt": "tappen",
    "getappte": "getappt",
    "getapptem": "getappt",
    "getappten": "getappt",
    "getappter": "getappt",
    "getapptes": "getappt",
    "getapst": "tapsen",
    "getapste": "getapst",
    "getapstem": "getapst",
    "getapsten": "getapst",
    "getapster": "getapst",
    "getapstes": "getapst",
    "getarnt": "tarnen",
    "getarnte": "getarnt",
    "getarntem": "getarnt",
    "getarnten": "getarnt",
    "getarnter": "getarnt",
    "getarntere": "getarnt",
    "getarnterem": "getarnt",
    "getarnteren": "getarnt",
    "getarnterer": "getarnt",
    "getarnteres": "getarnt",
    "getarntes": "getarnt",
    "getarnteste": "getarnt",
    "getarntestem": "getarnt",
    "getarntesten": "getarnt",
    "getarntester": "getarnt",
    "getarntestes": "getarnt",
    "getastet": "tasten",
    "getastete": "getastet",
    "getastetem": "getastet",
    "getasteten": "getastet",
    "getasteter": "getastet",
    "getastetes": "getastet",
    "getatscht": "tatschen",
    "getatschte": "getatscht",
    "getatschtem": "getatscht",
    "getatschten": "getatscht",
    "getatschter": "getatscht",
    "getatschtes": "getatscht",
    "getaucht": "tauchen",
    "getauchte": "getaucht",
    "getauchtem": "getaucht",
    "getauchten": "getaucht",
    "getauchter": "getaucht",
    "getauchtes": "getaucht",
    "getauft": "taufen",
    "getaufte": "getauft",
    "getauftem": "getauft",
    "getauften": "getauft",
    "getaufter": "getauft",
    "getauftes": "getauft",
    "getaugt": "taugen",
    "getaugte": "getaugt",
    "getaugtem": "getaugt",
    "getaugten": "getaugt",
    "getaugter": "getaugt",
    "getaugtes": "getaugt",
    "getaumelt": "taumeln",
    "getaumelte": "getaumelt",
    "getaumeltem": "getaumelt",
    "getaumelten": "getaumelt",
    "getaumelter": "getaumelt",
    "getaumeltes": "getaumelt",
    "getauscht": "tauschen",
    "getauschte": "getauscht",
    "getauschtem": "getauscht",
    "getauschten": "getauscht",
    "getauschter": "getauscht",
    "getauschtes": "getauscht",
    "getaut": "tauen",
    "getaute": "getaut",
    "getautem": "getaut",
    "getauten": "getaut",
    "getauter": "getaut",
    "getautes": "getaut",
    "geteert": "teeren",
    "geteerte": "geteert",
    "geteertem": "geteert",
    "geteerten": "geteert",
    "geteerter": "geteert",
    "geteertere": "geteert",
    "geteerterem": "geteert",
    "geteerteren": "geteert",
    "geteerterer": "geteert",
    "geteerteres": "geteert",
    "geteertes": "geteert",
    "geteerteste": "geteert",
    "geteertestem": "geteert",
    "geteertesten": "geteert",
    "geteertester": "geteert",
    "geteertestes": "geteert",
    "geteilt": "teilen",
    "geteilte": "geteilt",
    "geteiltem": "geteilt",
    "geteilten": "geteilt",
    "geteilter": "geteilt",
    "geteiltes": "geteilt",
    "getestet": "testen",
    "getestete": "getestet",
    "getestetem": "getestet",
    "getesteten": "getestet",
    "getesteter": "getestet",
    "getestetere": "getestet",
    "getesteterem": "getestet",
    "getesteteren": "getestet",
    "getesteterer": "getestet",
    "getesteteres": "getestet",
    "getestetes": "getestet",
    "getesteteste": "getestet",
    "getestetestem": "getestet",
    "getestetesten": "getestet",
    "getestetester": "getestet",
    "getestetestes": "getestet",
    "getextet": "texten",
    "getextete": "getextet",
    "getextetem": "getextet",
    "getexteten": "getextet",
    "getexteter": "getextet",
    "getextetes": "getextet",
    "gethront": "thronen",
    "gethronte": "gethront",
    "gethrontem": "gethront",
    "gethronten": "gethront",
    "gethronter": "gethront",
    "gethrontes": "gethront",
    "getigert": "tigern",
    "getigerte": "getigert",
    "getigertem": "getigert",
    "getigerten": "getigert",
    "getigerter": "getigert",
    "getigertes": "getigert",
    "getilgt": "tilgen",
    "getilgte": "getilgt",
    "getilgtem": "getilgt",
    "getilgten": "getilgt",
    "getilgter": "getilgt",
    "getilgtes": "getilgt",
    "getingelt": "tingeln",
    "getingelte": "getingelt",
    "getingeltem": "getingelt",
    "getingelten": "getingelt",
    "getingelter": "getingelt",
    "getingeltes": "getingelt",
    "getippelt": "tippeln",
    "getippelte": "getippelt",
    "getippeltem": "getippelt",
    "getippelten": "getippelt",
    "getippelter": "getippelt",
    "getippeltes": "getippelt",
    "getippt": "tippen",
    "getippte": "getippt",
    "getipptem": "getippt",
    "getippten": "getippt",
    "getippter": "getippt",
    "getipptes": "getippt",
    "getischlert": "tischlern",
    "getischlerte": "getischlert",
    "getischlertem": "getischlert",
    "getischlerten": "getischlert",
    "getischlerter": "getischlert",
    "getischlertes": "getischlert",
    "getischt": "tischen",
    "getischte": "getischt",
    "getischtem": "getischt",
    "getischten": "getischt",
    "getischter": "getischt",
    "getischtes": "getischt",
    "getitscht": "titschen",
    "getitschte": "getitscht",
    "getitschtem": "getitscht",
    "getitschten": "getitscht",
    "getitschter": "getitscht",
    "getitschtes": "getitscht",
    "getoastet": "toasten",
    "getoastete": "getoastet",
    "getoastetem": "getoastet",
    "getoasteten": "getoastet",
    "getoasteter": "getoastet",
    "getoastetes": "getoastet",
    "getobt": "toben",
    "getobte": "getobt",
    "getobtem": "getobt",
    "getobten": "getobt",
    "getobter": "getobt",
    "getobtes": "getobt",
    "getollt": "tollen",
    "getollte": "getollt",
    "getolltem": "getollt",
    "getollten": "getollt",
    "getollter": "getollt",
    "getolltes": "getollt",
    "getopft": "topfen",
    "getopfte": "getopft",
    "getopftem": "getopft",
    "getopften": "getopft",
    "getopfter": "getopft",
    "getopftes": "getopft",
    "getoppt": "toppen",
    "getoppte": "getoppt",
    "getopptem": "getoppt",
    "getoppten": "getoppt",
    "getoppter": "getoppt",
    "getopptere": "getoppt",
    "getoppterem": "getoppt",
    "getoppteren": "getoppt",
    "getoppterer": "getoppt",
    "getoppteres": "getoppt",
    "getopptes": "getoppt",
    "getoppteste": "getoppt",
    "getopptestem": "getoppt",
    "getopptesten": "getoppt",
    "getopptester": "getoppt",
    "getopptestes": "getoppt",
    "getorkelt": "torkeln",
    "getorkelte": "getorkelt",
    "getorkeltem": "getorkelt",
    "getorkelten": "getorkelt",
    "getorkelter": "getorkelt",
    "getorkeltes": "getorkelt",
    "getost": "tosen",
    "getoste": "getost",
    "getostem": "getost",
    "getosten": "getost",
    "getoster": "getost",
    "getostes": "getost",
    "getrabt": "traben",
    "getrabte": "getrabt",
    "getrabtem": "getrabt",
    "getrabten": "getrabt",
    "getrabter": "getrabt",
    "getrabtes": "getrabt",
    "getrachtet": "trachten",
    "getrachtete": "getrachtet",
    "getrachtetem": "getrachtet",
    "getrachteten": "getrachtet",
    "getrachteter": "getrachtet",
    "getrachtetes": "getrachtet",
    "getragen": "tragen",
    "getragene": "getragen",
    "getragenem": "getragen",
    "getragenen": "getragen",
    "getragener": "getragen",
    "getragenes": "getragen",
    "getrampelt": "trampeln",
    "getrampelte": "getrampelt",
    "getrampeltem": "getrampelt",
    "getrampelten": "getrampelt",
    "getrampelter": "getrampelt",
    "getrampeltes": "getrampelt",
    "getrappt": "trappen",
    "getrappte": "getrappt",
    "getrapptem": "getrappt",
    "getrappten": "getrappt",
    "getrappter": "getrappt",
    "getrapptes": "getrappt",
    "getrapst": "trapsen",
    "getrapste": "getrapst",
    "getrapstem": "getrapst",
    "getrapsten": "getrapst",
    "getrapster": "getrapst",
    "getrapstes": "getrapst",
    "getrauert": "trauern",
    "getrauerte": "getrauert",
    "getrauertem": "getrauert",
    "getrauerten": "getrauert",
    "getrauerter": "getrauert",
    "getrauertes": "getrauert",
    "getraumwandelt": "traumwandeln",
    "getraumwandelte": "getraumwandelt",
    "getraumwandeltem": "getraumwandelt",
    "getraumwandelten": "getraumwandelt",
    "getraumwandelter": "getraumwandelt",
    "getraumwandeltes": "getraumwandelt",
    "getraut": "trauen",
    "getraute": "getraut",
    "getrautem": "getraut",
    "getrauten": "getraut",
    "getrauter": "getraut",
    "getrautes": "getraut",
    "getrennt": "trennen",
    "getrennte": "getrennt",
    "getrenntem": "getrennt",
    "getrennten": "getrennt",
    "getrennter": "getrennt",
    "getrenntes": "getrennt",
    "getreten": "treten",
    "getretene": "getreten",
    "getretenem": "getreten",
    "getretenen": "getreten",
    "getretener": "getreten",
    "getretenere": "getreten",
    "getretenerem": "getreten",
    "getreteneren": "getreten",
    "getretenerer": "getreten",
    "getreteneres": "getreten",
    "getretenes": "getreten",
    "getretenste": "getreten",
    "getretenstem": "getreten",
    "getretensten": "getreten",
    "getretenster": "getreten",
    "getretenstes": "getreten",
    "getrichtert": "trichtern",
    "getrichterte": "getrichtert",
    "getrichtertem": "getrichtert",
    "getrichterten": "getrichtert",
    "getrichterter": "getrichtert",
    "getrichtertes": "getrichtert",
    "getrickst": "tricksen",
    "getrickste": "getrickst",
    "getrickstem": "getrickst",
    "getricksten": "getrickst",
    "getrickster": "getrickst",
    "getrickstere": "getrickst",
    "getricksterem": "getrickst",
    "getricksteren": "getrickst",
    "getricksterer": "getrickst",
    "getricksteres": "getrickst",
    "getrickstes": "getrickst",
    "getricksteste": "getrickst",
    "getrickstestem": "getrickst",
    "getrickstesten": "getrickst",
    "getrickstester": "getrickst",
    "getrickstestes": "getrickst",
    "getriebene": "getrieben",
    "getriebenem": "getrieben",
    "getriebenen": "getrieben",
    "getriebener": "getrieben",
    "getriebenes": "getrieben",
    "getrieft": "triefen",
    "getriefte": "getrieft",
    "getrieftem": "getrieft",
    "getrieften": "getrieft",
    "getriefter": "getrieft",
    "getrieftes": "getrieft",
    "getriezt": "triezen",
    "getriezte": "getriezt",
    "getrieztem": "getriezt",
    "getriezten": "getriezt",
    "getriezter": "getriezt",
    "getrieztere": "getriezt",
    "getriezterem": "getriezt",
    "getriezteren": "getriezt",
    "getriezterer": "getriezt",
    "getriezteres": "getriezt",
    "getrieztes": "getriezt",
    "getriezteste": "getriezt",
    "getrieztestem": "getriezt",
    "getrieztesten": "getriezt",
    "getrieztester": "getriezt",
    "getrieztestes": "getriezt",
    "getrillert": "trillern",
    "getrillerte": "getrillert",
    "getrillertem": "getrillert",
    "getrillerten": "getrillert",
    "getrillerter": "getrillert",
    "getrillertes": "getrillert",
    "getrimmt": "trimmen",
    "getrimmte": "getrimmt",
    "getrimmtem": "getrimmt",
    "getrimmten": "getrimmt",
    "getrimmter": "getrimmt",
    "getrimmtere": "getrimmt",
    "getrimmterem": "getrimmt",
    "getrimmteren": "getrimmt",
    "getrimmterer": "getrimmt",
    "getrimmteres": "getrimmt",
    "getrimmtes": "getrimmt",
    "getrimmteste": "getrimmt",
    "getrimmtestem": "getrimmt",
    "getrimmtesten": "getrimmt",
    "getrimmtester": "getrimmt",
    "getrimmtestes": "getrimmt",
    "getrippelt": "trippeln",
    "getrippelte": "getrippelt",
    "getrippeltem": "getrippelt",
    "getrippelten": "getrippelt",
    "getrippelter": "getrippelt",
    "getrippeltes": "getrippelt",
    "getrocknet": "trocknen",
    "getrocknete": "getrocknet",
    "getrocknetem": "getrocknet",
    "getrockneten": "getrocknet",
    "getrockneter": "getrocknet",
    "getrocknetere": "getrocknet",
    "getrockneterem": "getrocknet",
    "getrockneteren": "getrocknet",
    "getrockneterer": "getrocknet",
    "getrockneteres": "getrocknet",
    "getrocknetes": "getrocknet",
    "getrockneteste": "getrocknet",
    "getrocknetestem": "getrocknet",
    "getrocknetesten": "getrocknet",
    "getrocknetester": "getrocknet",
    "getrocknetestes": "getrocknet",
    "getroffen": "triefen",
    "getroffene": "getroffen",
    "getroffenem": "getroffen",
    "getroffenen": "getroffen",
    "getroffener": "getroffen",
    "getroffenere": "getroffen",
    "getroffenerem": "getroffen",
    "getroffeneren": "getroffen",
    "getroffenerer": "getroffen",
    "getroffeneres": "getroffen",
    "getroffenes": "getroffen",
    "getroffenste": "getroffen",
    "getroffenstem": "getroffen",
    "getroffensten": "getroffen",
    "getroffenster": "getroffen",
    "getroffenstes": "getroffen",
    "getrogen": "trügen",
    "getrogene": "getrogen",
    "getrogenem": "getrogen",
    "getrogenen": "getrogen",
    "getrogener": "getrogen",
    "getrogenes": "getrogen",
    "getrommelt": "trommeln",
    "getrommelte": "getrommelt",
    "getrommeltem": "getrommelt",
    "getrommelten": "getrommelt",
    "getrommelter": "getrommelt",
    "getrommeltes": "getrommelt",
    "getropft": "tropfen",
    "getropfte": "getropft",
    "getropftem": "getropft",
    "getropften": "getropft",
    "getropfter": "getropft",
    "getropftes": "getropft",
    "getrottet": "trotten",
    "getrottete": "getrottet",
    "getrottetem": "getrottet",
    "getrotteten": "getrottet",
    "getrotteter": "getrottet",
    "getrottetes": "getrottet",
    "getrotzt": "trotzen",
    "getrotzte": "getrotzt",
    "getrotztem": "getrotzt",
    "getrotzten": "getrotzt",
    "getrotzter": "getrotzt",
    "getrotztes": "getrotzt",
    "getrudelt": "trudeln",
    "getrudelte": "getrudelt",
    "getrudeltem": "getrudelt",
    "getrudelten": "getrudelt",
    "getrudelter": "getrudelt",
    "getrudeltes": "getrudelt",
    "getrumpft": "trumpfen",
    "getrumpfte": "getrumpft",
    "getrumpftem": "getrumpft",
    "getrumpften": "getrumpft",
    "getrumpfter": "getrumpft",
    "getrumpftes": "getrumpft",
    "getrunken": "trinken",
    "getrunkene": "getrunken",
    "getrunkenem": "getrunken",
    "getrunkenen": "getrunken",
    "getrunkener": "getrunken",
    "getrunkenes": "getrunken",
    "geträllert": "trällern",
    "geträllerte": "geträllert",
    "geträllertem": "geträllert",
    "geträllerten": "geträllert",
    "geträllerter": "geträllert",
    "geträllertes": "geträllert",
    "getränt": "tränen",
    "getränte": "getränt",
    "geträntem": "getränt",
    "getränten": "getränt",
    "getränter": "getränt",
    "geträntes": "getränt",
    "geträufelt": "träufeln",
    "geträufelte": "geträufelt",
    "geträufeltem": "geträufelt",
    "geträufelten": "geträufelt",
    "geträufelter": "geträufelt",
    "geträufeltere": "geträufelt",
    "geträufelterem": "geträufelt",
    "geträufelteren": "geträufelt",
    "geträufelterer": "geträufelt",
    "geträufelteres": "geträufelt",
    "geträufeltes": "geträufelt",
    "geträufelteste": "geträufelt",
    "geträufeltestem": "geträufelt",
    "geträufeltesten": "geträufelt",
    "geträufeltester": "geträufelt",
    "geträufeltestes": "geträufelt",
    "geträuft": "träufen",
    "geträufte": "geträuft",
    "geträuftem": "geträuft",
    "geträuften": "geträuft",
    "geträufter": "geträuft",
    "geträuftere": "geträuft",
    "geträufterem": "geträuft",
    "geträufteren": "geträuft",
    "geträufterer": "geträuft",
    "geträufteres": "geträuft",
    "geträuftes": "geträuft",
    "geträufteste": "geträuft",
    "geträuftestem": "geträuft",
    "geträuftesten": "geträuft",
    "geträuftester": "geträuft",
    "geträuftestes": "geträuft",
    "geträumt": "träumen",
    "geträumte": "geträumt",
    "geträumtem": "geträumt",
    "geträumten": "geträumt",
    "geträumter": "geträumt",
    "geträumtes": "geträumt",
    "getrödelt": "trödeln",
    "getrödelte": "getrödelt",
    "getrödeltem": "getrödelt",
    "getrödelten": "getrödelt",
    "getrödelter": "getrödelt",
    "getrödeltes": "getrödelt",
    "getröpfelt": "tröpfeln",
    "getröpfelte": "getröpfelt",
    "getröpfeltem": "getröpfelt",
    "getröpfelten": "getröpfelt",
    "getröpfelter": "getröpfelt",
    "getröpfeltes": "getröpfelt",
    "getröstet": "trösten",
    "getröstete": "getröstet",
    "getröstetem": "getröstet",
    "getrösteten": "getröstet",
    "getrösteter": "getröstet",
    "getröstetere": "getröstet",
    "getrösteterem": "getröstet",
    "getrösteteren": "getröstet",
    "getrösteterer": "getröstet",
    "getrösteteres": "getröstet",
    "getröstetes": "getröstet",
    "getrösteteste": "getröstet",
    "getröstetestem": "getröstet",
    "getröstetesten": "getröstet",
    "getröstetester": "getröstet",
    "getröstetestes": "getröstet",
    "getrübt": "trüben",
    "getrübte": "getrübt",
    "getrübtem": "getrübt",
    "getrübten": "getrübt",
    "getrübter": "getrübt",
    "getrübtere": "getrübt",
    "getrübterem": "getrübt",
    "getrübteren": "getrübt",
    "getrübterer": "getrübt",
    "getrübteres": "getrübt",
    "getrübtes": "getrübt",
    "getrübteste": "getrübt",
    "getrübtestem": "getrübt",
    "getrübtesten": "getrübt",
    "getrübtester": "getrübt",
    "getrübtestes": "getrübt",
    "getummelt": "tummeln",
    "getummelte": "getummelt",
    "getummeltem": "getummelt",
    "getummelten": "getummelt",
    "getummelter": "getummelt",
    "getummeltes": "getummelt",
    "getunkt": "tunken",
    "getunkte": "getunkt",
    "getunktem": "getunkt",
    "getunkten": "getunkt",
    "getunkter": "getunkt",
    "getunktes": "getunkt",
    "getupft": "tupfen",
    "getupfte": "getupft",
    "getupftem": "getupft",
    "getupften": "getupft",
    "getupfter": "getupft",
    "getupftes": "getupft",
    "geturnt": "turnen",
    "geturnte": "geturnt",
    "geturntem": "geturnt",
    "geturnten": "geturnt",
    "geturnter": "geturnt",
    "geturntes": "geturnt",
    "geturtelt": "turteln",
    "geturtelte": "geturtelt",
    "geturteltem": "geturtelt",
    "geturtelten": "geturtelt",
    "geturtelter": "geturtelt",
    "geturteltes": "geturtelt",
    "getuschelt": "tuscheln",
    "getuschelte": "getuschelt",
    "getuscheltem": "getuschelt",
    "getuschelten": "getuschelt",
    "getuschelter": "getuschelt",
    "getuscheltes": "getuschelt",
    "getutet": "tuten",
    "getutete": "getutet",
    "getutetem": "getutet",
    "getuteten": "getutet",
    "getuteter": "getutet",
    "getutetes": "getutet",
    "getäfelt": "täfeln",
    "getäfelte": "getäfelt",
    "getäfeltem": "getäfelt",
    "getäfelten": "getäfelt",
    "getäfelter": "getäfelt",
    "getäfeltes": "getäfelt",
    "getändelt": "tändeln",
    "getändelte": "getändelt",
    "getändeltem": "getändelt",
    "getändelten": "getändelt",
    "getändelter": "getändelt",
    "getändeltes": "getändelt",
    "getänzelt": "tänzeln",
    "getänzelte": "getänzelt",
    "getänzeltem": "getänzelt",
    "getänzelten": "getänzelt",
    "getänzelter": "getänzelt",
    "getänzeltes": "getänzelt",
    "getätigt": "tätigen",
    "getätigte": "getätigt",
    "getätigtem": "getätigt",
    "getätigten": "getätigt",
    "getätigter": "getätigt",
    "getätigtes": "getätigt",
    "getätschelt": "tätscheln",
    "getätschelte": "getätschelt",
    "getätscheltem": "getätschelt",
    "getätschelten": "getätschelt",
    "getätschelter": "getätschelt",
    "getätscheltes": "getätschelt",
    "getäuscht": "täuschen",
    "getäuschtem": "getäuscht",
    "getäuschter": "getäuscht",
    "getäuschtere": "getäuscht",
    "getäuschterem": "getäuscht",
    "getäuschteren": "getäuscht",
    "getäuschterer": "getäuscht",
    "getäuschteres": "getäuscht",
    "getäuschtes": "getäuscht",
    "getäuschteste": "getäuscht",
    "getäuschtestem": "getäuscht",
    "getäuschtesten": "getäuscht",
    "getäuschtester": "getäuscht",
    "getäuschtestes": "getäuscht",
    "getönt": "tönen",
    "getönte": "getönt",
    "getöntem": "getönt",
    "getönten": "getönt",
    "getönter": "getönt",
    "getöntere": "getönt",
    "getönterem": "getönt",
    "getönteren": "getönt",
    "getönterer": "getönt",
    "getönteres": "getönt",
    "getöntes": "getönt",
    "getönteste": "getönt",
    "getöntestem": "getönt",
    "getöntesten": "getönt",
    "getöntester": "getönt",
    "getöntestes": "getönt",
    "getöpfert": "töpfern",
    "getöpferte": "getöpfert",
    "getöpfertem": "getöpfert",
    "getöpferten": "getöpfert",
    "getöpferter": "getöpfert",
    "getöpfertes": "getöpfert",
    "getörnt": "törnen",
    "getörnte": "getörnt",
    "getörntem": "getörnt",
    "getörnten": "getörnt",
    "getörnter": "getörnt",
    "getörntes": "getörnt",
    "getötet": "töten",
    "getötete": "getötet",
    "getötetem": "getötet",
    "getöteten": "getötet",
    "getöteter": "getötet",
    "getötetes": "getötet",
    "getüftelt": "tüfteln",
    "getüftelte": "getüftelt",
    "getüfteltem": "getüftelt",
    "getüftelten": "getüftelt",
    "getüftelter": "getüftelt",
    "getüfteltes": "getüftelt",
    "getüncht": "tünchen",
    "getünchte": "getüncht",
    "getünchtem": "getüncht",
    "getünchten": "getüncht",
    "getünchter": "getüncht",
    "getünchtes": "getüncht",
    "getürkt": "türken",
    "getürkte": "getürkt",
    "getürktem": "getürkt",
    "getürkten": "getürkt",
    "getürkter": "getürkt",
    "getürktere": "getürkt",
    "getürkterem": "getürkt",
    "getürkteren": "getürkt",
    "getürkterer": "getürkt",
    "getürkteres": "getürkt",
    "getürktes": "getürkt",
    "getürkteste": "getürkt",
    "getürktestem": "getürkt",
    "getürktesten": "getürkt",
    "getürktester": "getürkt",
    "getürktestes": "getürkt",
    "getürmt": "türmen",
    "getürmte": "getürmt",
    "getürmtem": "getürmt",
    "getürmten": "getürmt",
    "getürmter": "getürmt",
    "getürmtes": "getürmt",
    "getütet": "tüten",
    "getütetem": "getütet",
    "getüteter": "getütet",
    "getütetes": "getütet",
    "geufert": "ufern",
    "geuferte": "geufert",
    "geufertem": "geufert",
    "geuferten": "geufert",
    "geuferter": "geufert",
    "geufertes": "geufert",
    "geulkt": "ulken",
    "geulkte": "geulkt",
    "geulktem": "geulkt",
    "geulkten": "geulkt",
    "geulkter": "geulkt",
    "geulktes": "geulkt",
    "geunkt": "unken",
    "geunkte": "geunkt",
    "geunktem": "geunkt",
    "geunkten": "geunkt",
    "geunkter": "geunkt",
    "geunktes": "geunkt",
    "geurteilt": "urteilen",
    "geurteilte": "geurteilt",
    "geurteiltem": "geurteilt",
    "geurteilten": "geurteilt",
    "geurteilter": "geurteilt",
    "geurteiltes": "geurteilt",
    "gevierteilt": "vierteilen",
    "gevierteilte": "gevierteilt",
    "gevierteiltem": "gevierteilt",
    "gevierteilten": "gevierteilt",
    "gevierteilter": "gevierteilt",
    "gevierteiltes": "gevierteilt",
    "geviertelt": "vierteln",
    "geviertelte": "geviertelt",
    "gevierteltem": "geviertelt",
    "geviertelten": "geviertelt",
    "geviertelter": "geviertelt",
    "gevierteltes": "geviertelt",
    "gevögelt": "vögeln",
    "gevögelte": "gevögelt",
    "gevögeltem": "gevögelt",
    "gevögelten": "gevögelt",
    "gevögelter": "gevögelt",
    "gevögeltes": "gevögelt",
    "gewabbelt": "wabbeln",
    "gewabbelte": "gewabbelt",
    "gewabbeltem": "gewabbelt",
    "gewabbelten": "gewabbelt",
    "gewabbelter": "gewabbelt",
    "gewabbeltes": "gewabbelt",
    "gewachsen": "wachsen",
    "gewachsenem": "gewachsen",
    "gewachsenen": "gewachsen",
    "gewachsener": "gewachsen",
    "gewachsenere": "gewachsen",
    "gewachsenerem": "gewachsen",
    "gewachseneren": "gewachsen",
    "gewachsenerer": "gewachsen",
    "gewachseneres": "gewachsen",
    "gewachsenes": "gewachsen",
    "gewachsenste": "gewachsen",
    "gewachsenstem": "gewachsen",
    "gewachsensten": "gewachsen",
    "gewachsenster": "gewachsen",
    "gewachsenstes": "gewachsen",
    "gewachst": "wachsen",
    "gewachste": "gewachst",
    "gewachstem": "gewachst",
    "gewachsten": "gewachst",
    "gewachster": "gewachst",
    "gewachstere": "gewachst",
    "gewachsterem": "gewachst",
    "gewachsteren": "gewachst",
    "gewachsterer": "gewachst",
    "gewachsteres": "gewachst",
    "gewachstes": "gewachst",
    "gewachsteste": "gewachst",
    "gewachstestem": "gewachst",
    "gewachstesten": "gewachst",
    "gewachstester": "gewachst",
    "gewachstestes": "gewachst",
    "gewacht": "wachen",
    "gewachte": "gewacht",
    "gewachtem": "gewacht",
    "gewachten": "gewacht",
    "gewachter": "gewacht",
    "gewachtes": "gewacht",
    "gewaffnet": "waffnen",
    "gewaffnete": "gewaffnet",
    "gewaffnetem": "gewaffnet",
    "gewaffneten": "gewaffnet",
    "gewaffneter": "gewaffnet",
    "gewaffnetes": "gewaffnet",
    "gewagt": "wagen",
    "gewagte": "gewagt",
    "gewagtem": "gewagt",
    "gewagten": "gewagt",
    "gewagter": "gewagt",
    "gewagtere": "gewagt",
    "gewagterem": "gewagt",
    "gewagteren": "gewagt",
    "gewagterer": "gewagt",
    "gewagteres": "gewagt",
    "gewagtes": "gewagt",
    "gewagteste": "gewagt",
    "gewagtestem": "gewagt",
    "gewagtesten": "gewagt",
    "gewagtester": "gewagt",
    "gewagtestes": "gewagt",
    "gewahrt": "wahren",
    "gewahrte": "gewahrt",
    "gewahrtem": "gewahrt",
    "gewahrten": "gewahrt",
    "gewahrter": "gewahrt",
    "gewahrtes": "gewahrt",
    "gewallt": "wallen",
    "gewallte": "gewallt",
    "gewalltem": "gewallt",
    "gewallten": "gewallt",
    "gewallter": "gewallt",
    "gewalltes": "gewallt",
    "gewaltet": "walten",
    "gewaltete": "gewaltet",
    "gewaltetem": "gewaltet",
    "gewalteten": "gewaltet",
    "gewalteter": "gewaltet",
    "gewaltetes": "gewaltet",
    "gewaltige": "gewaltig",
    "gewaltigem": "gewaltig",
    "gewaltigen": "gewaltig",
    "gewaltiger": "gewaltig",
    "gewaltigere": "gewaltig",
    "gewaltigerem": "gewaltig",
    "gewaltigeren": "gewaltig",
    "gewaltigerer": "gewaltig",
    "gewaltigeres": "gewaltig",
    "gewaltiges": "gewaltig",
    "gewaltigste": "gewaltig",
    "gewaltigstem": "gewaltig",
    "gewaltigsten": "gewaltig",
    "gewaltigster": "gewaltig",
    "gewaltigstes": "gewaltig",
    "gewaltlose": "gewaltlos",
    "gewaltlosem": "gewaltlos",
    "gewaltlosen": "gewaltlos",
    "gewaltloser": "gewaltlos",
    "gewaltlosere": "gewaltlos",
    "gewaltloserem": "gewaltlos",
    "gewaltloseren": "gewaltlos",
    "gewaltloserer": "gewaltlos",
    "gewaltloseres": "gewaltlos",
    "gewaltloses": "gewaltlos",
    "gewaltloseste": "gewaltlos",
    "gewaltlosestem": "gewaltlos",
    "gewaltlosesten": "gewaltlos",
    "gewaltlosester": "gewaltlos",
    "gewaltlosestes": "gewaltlos",
    "gewaltsame": "gewaltsam",
    "gewaltsamem": "gewaltsam",
    "gewaltsamen": "gewaltsam",
    "gewaltsamer": "gewaltsam",
    "gewaltsames": "gewaltsam",
    "gewalttätige": "gewalttätig",
    "gewalttätigem": "gewalttätig",
    "gewalttätigen": "gewalttätig",
    "gewalttätiger": "gewalttätig",
    "gewalttätigere": "gewalttätig",
    "gewalttätigerem": "gewalttätig",
    "gewalttätigeren": "gewalttätig",
    "gewalttätigerer": "gewalttätig",
    "gewalttätigeres": "gewalttätig",
    "gewalttätiges": "gewalttätig",
    "gewalttätigste": "gewalttätig",
    "gewalttätigstem": "gewalttätig",
    "gewalttätigsten": "gewalttätig",
    "gewalttätigster": "gewalttätig",
    "gewalttätigstes": "gewalttätig",
    "gewalzt": "walzen",
    "gewalzte": "gewalzt",
    "gewalztem": "gewalzt",
    "gewalzten": "gewalzt",
    "gewalzter": "gewalzt",
    "gewalztere": "gewalzt",
    "gewalzterem": "gewalzt",
    "gewalzteren": "gewalzt",
    "gewalzterer": "gewalzt",
    "gewalzteres": "gewalzt",
    "gewalztes": "gewalzt",
    "gewalzteste": "gewalzt",
    "gewalztestem": "gewalzt",
    "gewalztesten": "gewalzt",
    "gewalztester": "gewalzt",
    "gewalztestes": "gewalzt",
    "gewandelt": "wandeln",
    "gewandelte": "gewandelt",
    "gewandeltem": "gewandelt",
    "gewandelten": "gewandelt",
    "gewandelter": "gewandelt",
    "gewandeltere": "gewandelt",
    "gewandelterem": "gewandelt",
    "gewandelteren": "gewandelt",
    "gewandelterer": "gewandelt",
    "gewandelteres": "gewandelt",
    "gewandeltes": "gewandelt",
    "gewandelteste": "gewandelt",
    "gewandeltestem": "gewandelt",
    "gewandeltesten": "gewandelt",
    "gewandeltester": "gewandelt",
    "gewandeltestes": "gewandelt",
    "gewandert": "wandern",
    "gewanderte": "gewandert",
    "gewandertem": "gewandert",
    "gewanderten": "gewandert",
    "gewanderter": "gewandert",
    "gewandertes": "gewandert",
    "gewandt": "wenden",
    "gewandte": "gewandt",
    "gewandtem": "gewandt",
    "gewandten": "gewandt",
    "gewandter": "gewandt",
    "gewandtere": "gewandt",
    "gewandterem": "gewandt",
    "gewandteren": "gewandt",
    "gewandterer": "gewandt",
    "gewandteres": "gewandt",
    "gewandtes": "gewandt",
    "gewandteste": "gewandt",
    "gewandtestem": "gewandt",
    "gewandtesten": "gewandt",
    "gewandtester": "gewandt",
    "gewandtestes": "gewandt",
    "gewankt": "wanken",
    "gewankte": "gewankt",
    "gewanktem": "gewankt",
    "gewankten": "gewankt",
    "gewankter": "gewankt",
    "gewanktes": "gewankt",
    "gewann": "gewinnen",
    "gewannen": "gewinnen",
    "gewannst": "gewinnen",
    "gewannt": "gewinnen",
    "gewappnet": "wappnen",
    "gewappnete": "gewappnet",
    "gewappnetem": "gewappnet",
    "gewappneten": "gewappnet",
    "gewappneter": "gewappnet",
    "gewappnetes": "gewappnet",
    "gewarnt": "warnen",
    "gewarnte": "gewarnt",
    "gewarntem": "gewarnt",
    "gewarnten": "gewarnt",
    "gewarnter": "gewarnt",
    "gewarntes": "gewarnt",
    "gewartet": "warten",
    "gewartete": "gewartet",
    "gewartetem": "gewartet",
    "gewarteten": "gewartet",
    "gewarteter": "gewartet",
    "gewartetere": "gewartet",
    "gewarteterem": "gewartet",
    "gewarteteren": "gewartet",
    "gewarteterer": "gewartet",
    "gewarteteres": "gewartet",
    "gewartetes": "gewartet",
    "gewarteteste": "gewartet",
    "gewartetestem": "gewartet",
    "gewartetesten": "gewartet",
    "gewartetester": "gewartet",
    "gewartetestes": "gewartet",
    "gewaschen": "waschen",
    "gewaschene": "gewaschen",
    "gewaschenem": "gewaschen",
    "gewaschenen": "gewaschen",
    "gewaschener": "gewaschen",
    "gewaschenere": "gewaschen",
    "gewaschenerem": "gewaschen",
    "gewascheneren": "gewaschen",
    "gewaschenerer": "gewaschen",
    "gewascheneres": "gewaschen",
    "gewaschenes": "gewaschen",
    "gewaschenste": "gewaschen",
    "gewaschenstem": "gewaschen",
    "gewaschensten": "gewaschen",
    "gewaschenster": "gewaschen",
    "gewaschenstes": "gewaschen",
    "gewatet": "waten",
    "gewatete": "gewatet",
    "gewatetem": "gewatet",
    "gewateten": "gewatet",
    "gewateter": "gewatet",
    "gewatetes": "gewatet",
    "gewatschelt": "watscheln",
    "gewatschelte": "gewatschelt",
    "gewatscheltem": "gewatschelt",
    "gewatschelten": "gewatschelt",
    "gewatschelter": "gewatschelt",
    "gewatscheltes": "gewatschelt",
    "gewebt": "weben",
    "gewebte": "gewebt",
    "gewebtem": "gewebt",
    "gewebten": "gewebt",
    "gewebter": "gewebt",
    "gewebtes": "gewebt",
    "gewechselt": "wechseln",
    "gewechselte": "gewechselt",
    "gewechseltem": "gewechselt",
    "gewechselten": "gewechselt",
    "gewechselter": "gewechselt",
    "gewechseltes": "gewechselt",
    "geweckt": "wecken",
    "geweckte": "geweckt",
    "gewecktem": "geweckt",
    "geweckten": "geweckt",
    "geweckter": "geweckt",
    "gewecktes": "geweckt",
    "gewedelt": "wedeln",
    "gewedelte": "gewedelt",
    "gewedeltem": "gewedelt",
    "gewedelten": "gewedelt",
    "gewedelter": "gewedelt",
    "gewedeltes": "gewedelt",
    "gewehrt": "wehren",
    "gewehrte": "gewehrt",
    "gewehrtem": "gewehrt",
    "gewehrten": "gewehrt",
    "gewehrter": "gewehrt",
    "gewehrtes": "gewehrt",
    "geweht": "wehen",
    "gewehte": "geweht",
    "gewehtem": "geweht",
    "gewehten": "geweht",
    "gewehter": "geweht",
    "gewehtes": "geweht",
    "geweicht": "weichen",
    "geweichte": "geweicht",
    "geweichtem": "geweicht",
    "geweichten": "geweicht",
    "geweichter": "geweicht",
    "geweichtes": "geweicht",
    "geweidet": "weiden",
    "geweidete": "geweidet",
    "geweidetem": "geweidet",
    "geweideten": "geweidet",
    "geweideter": "geweidet",
    "geweidetes": "geweidet",
    "geweigert": "weigern",
    "geweigerte": "geweigert",
    "geweigertem": "geweigert",
    "geweigerten": "geweigert",
    "geweigerter": "geweigert",
    "geweigertes": "geweigert",
    "geweihnachtet": "weihnachten",
    "geweihnachtete": "geweihnachtet",
    "geweihnachtetem": "geweihnachtet",
    "geweihnachteten": "geweihnachtet",
    "geweihnachteter": "geweihnachtet",
    "geweihnachtetes": "geweihnachtet",
    "geweiht": "weihen",
    "geweihte": "geweiht",
    "geweihtem": "geweiht",
    "geweihten": "geweiht",
    "geweihter": "geweiht",
    "geweihtere": "geweiht",
    "geweihterem": "geweiht",
    "geweihteren": "geweiht",
    "geweihterer": "geweiht",
    "geweihteres": "geweiht",
    "geweihtes": "geweiht",
    "geweihteste": "geweiht",
    "geweihtestem": "geweiht",
    "geweihtesten": "geweiht",
    "geweihtester": "geweiht",
    "geweihtestes": "geweiht",
    "geweilt": "weilen",
    "geweilte": "geweilt",
    "geweiltem": "geweilt",
    "geweilten": "geweilt",
    "geweilter": "geweilt",
    "geweiltes": "geweilt",
    "geweint": "weinen",
    "geweinte": "geweint",
    "geweintem": "geweint",
    "geweinten": "geweint",
    "geweinter": "geweint",
    "geweintes": "geweint",
    "geweitet": "weiten",
    "geweitete": "geweitet",
    "geweitetem": "geweitet",
    "geweiteten": "geweitet",
    "geweiteter": "geweitet",
    "geweitetere": "geweitet",
    "geweiteterem": "geweitet",
    "geweiteteren": "geweitet",
    "geweiteterer": "geweitet",
    "geweiteteres": "geweitet",
    "geweitetes": "geweitet",
    "geweiteteste": "geweitet",
    "geweitetestem": "geweitet",
    "geweitetesten": "geweitet",
    "geweitetester": "geweitet",
    "geweitetestes": "geweitet",
    "gewelkt": "welken",
    "gewelkte": "gewelkt",
    "gewelktem": "gewelkt",
    "gewelkten": "gewelkt",
    "gewelkter": "gewelkt",
    "gewelktes": "gewelkt",
    "gewellt": "wellen",
    "gewellte": "gewellt",
    "gewelltem": "gewellt",
    "gewellten": "gewellt",
    "gewellter": "gewellt",
    "gewelltes": "gewellt",
    "gewendet": "wenden",
    "gewendete": "gewendet",
    "gewendetem": "gewendet",
    "gewendeten": "gewendet",
    "gewendeter": "gewendet",
    "gewendetes": "gewendet",
    "gewerbetreibendem": "gewerbetreibend",
    "gewerbetreibenden": "gewerbetreibend",
    "gewerbetreibender": "gewerbetreibend",
    "gewerbetreibendes": "gewerbetreibend",
    "gewerbliche": "gewerblich",
    "gewerblichem": "gewerblich",
    "gewerblichen": "gewerblich",
    "gewerblicher": "gewerblich",
    "gewerbliches": "gewerblich",
    "gewerkelt": "werkeln",
    "gewerkelte": "gewerkelt",
    "gewerkeltem": "gewerkelt",
    "gewerkelten": "gewerkelt",
    "gewerkelter": "gewerkelt",
    "gewerkeltes": "gewerkelt",
    "gewerkschaftlichem": "gewerkschaftlich",
    "gewerkschaftlichen": "gewerkschaftlich",
    "gewerkschaftlicher": "gewerkschaftlich",
    "gewerkschaftliches": "gewerkschaftlich",
    "gewerkt": "werken",
    "gewerkte": "gewerkt",
    "gewerktem": "gewerkt",
    "gewerkten": "gewerkt",
    "gewerkter": "gewerkt",
    "gewerktes": "gewerkt",
    "gewertet": "werten",
    "gewertete": "gewertet",
    "gewertetem": "gewertet",
    "gewerteten": "gewertet",
    "gewerteter": "gewertet",
    "gewertetes": "gewertet",
    "gewesen": "sein",
    "gewettert": "wettern",
    "gewetterte": "gewettert",
    "gewettertem": "gewettert",
    "gewetterten": "gewettert",
    "gewetterter": "gewettert",
    "gewettertes": "gewettert",
    "gewettet": "wetten",
    "gewettete": "gewettet",
    "gewettetem": "gewettet",
    "gewetteten": "gewettet",
    "gewetteter": "gewettet",
    "gewettetes": "gewettet",
    "gewetzt": "wetzen",
    "gewetzte": "gewetzt",
    "gewetztem": "gewetzt",
    "gewetzten": "gewetzt",
    "gewetzter": "gewetzt",
    "gewetztes": "gewetzt",
    "gewichen": "weichen",
    "gewichene": "gewichen",
    "gewichenem": "gewichen",
    "gewichenen": "gewichen",
    "gewichener": "gewichen",
    "gewichenes": "gewichen",
    "gewichtelt": "wichteln",
    "gewichtelte": "gewichtelt",
    "gewichteltem": "gewichtelt",
    "gewichtelten": "gewichtelt",
    "gewichtelter": "gewichtelt",
    "gewichteltes": "gewichtelt",
    "gewichtend": "gewichten",
    "gewichtende": "gewichtend",
    "gewichtendem": "gewichtend",
    "gewichtenden": "gewichtend",
    "gewichtender": "gewichtend",
    "gewichtendes": "gewichtend",
    "gewichtest": "gewichten",
    "gewichtet": "gewichten",
    "gewichtete": "gewichten",
    "gewichtetem": "gewichtet",
    "gewichteten": "gewichten",
    "gewichteter": "gewichtet",
    "gewichtetes": "gewichtet",
    "gewichtetest": "gewichten",
    "gewichtetet": "gewichten",
    "gewichtige": "gewichtig",
    "gewichtigem": "gewichtig",
    "gewichtigen": "gewichtig",
    "gewichtiger": "gewichtig",
    "gewichtigere": "gewichtig",
    "gewichtigerem": "gewichtig",
    "gewichtigeren": "gewichtig",
    "gewichtigerer": "gewichtig",
    "gewichtigeres": "gewichtig",
    "gewichtiges": "gewichtig",
    "gewichtigste": "gewichtig",
    "gewichtigstem": "gewichtig",
    "gewichtigsten": "gewichtig",
    "gewichtigster": "gewichtig",
    "gewichtigstes": "gewichtig",
    "gewickelt": "wickeln",
    "gewickelte": "gewickelt",
    "gewickeltem": "gewickelt",
    "gewickelten": "gewickelt",
    "gewickelter": "gewickelt",
    "gewickeltes": "gewickelt",
    "gewidert": "widern",
    "gewiderte": "gewidert",
    "gewidertem": "gewidert",
    "gewiderten": "gewidert",
    "gewiderter": "gewidert",
    "gewidertes": "gewidert",
    "gewidmet": "widmen",
    "gewidmete": "gewidmet",
    "gewidmetem": "gewidmet",
    "gewidmeten": "gewidmet",
    "gewidmeter": "gewidmet",
    "gewidmetes": "gewidmet",
    "gewiefte": "gewieft",
    "gewieftem": "gewieft",
    "gewieften": "gewieft",
    "gewiefter": "gewieft",
    "gewieftere": "gewieft",
    "gewiefterem": "gewieft",
    "gewiefteren": "gewieft",
    "gewiefterer": "gewieft",
    "gewiefteres": "gewieft",
    "gewieftes": "gewieft",
    "gewiefteste": "gewieft",
    "gewieftestem": "gewieft",
    "gewieftesten": "gewieft",
    "gewieftester": "gewieft",
    "gewieftestes": "gewieft",
    "gewiegelt": "wiegeln",
    "gewiegelte": "gewiegelt",
    "gewiegeltem": "gewiegelt",
    "gewiegelten": "gewiegelt",
    "gewiegelter": "gewiegelt",
    "gewiegeltes": "gewiegelt",
    "gewiehert": "wiehern",
    "gewieherte": "gewiehert",
    "gewiehertem": "gewiehert",
    "gewieherten": "gewiehert",
    "gewieherter": "gewiehert",
    "gewiehertes": "gewiehert",
    "gewienert": "wienern",
    "gewienerte": "gewienert",
    "gewienertem": "gewienert",
    "gewienerten": "gewienert",
    "gewienerter": "gewienert",
    "gewienertes": "gewienert",
    "gewiesen": "weisen",
    "gewiesene": "gewiesen",
    "gewiesenem": "gewiesen",
    "gewiesenen": "gewiesen",
    "gewiesener": "gewiesen",
    "gewiesenes": "gewiesen",
    "gewildert": "wildern",
    "gewilderte": "gewildert",
    "gewildertem": "gewildert",
    "gewilderten": "gewildert",
    "gewilderter": "gewildert",
    "gewildertes": "gewildert",
    "gewilligt": "willigen",
    "gewilligte": "gewilligt",
    "gewilligtem": "gewilligt",
    "gewilligten": "gewilligt",
    "gewilligter": "gewilligt",
    "gewilligtes": "gewilligt",
    "gewillte": "gewillt",
    "gewilltem": "gewillt",
    "gewillten": "gewillt",
    "gewillter": "gewillt",
    "gewilltere": "gewillt",
    "gewillterem": "gewillt",
    "gewillteren": "gewillt",
    "gewillterer": "gewillt",
    "gewillteres": "gewillt",
    "gewilltes": "gewillt",
    "gewillteste": "gewillt",
    "gewilltestem": "gewillt",
    "gewilltesten": "gewillt",
    "gewilltester": "gewillt",
    "gewilltestes": "gewillt",
    "gewimmelt": "wimmeln",
    "gewimmelte": "gewimmelt",
    "gewimmeltem": "gewimmelt",
    "gewimmelten": "gewimmelt",
    "gewimmelter": "gewimmelt",
    "gewimmeltes": "gewimmelt",
    "gewimmert": "wimmern",
    "gewimmerte": "gewimmert",
    "gewimmertem": "gewimmert",
    "gewimmerten": "gewimmert",
    "gewimmerter": "gewimmert",
    "gewimmertes": "gewimmert",
    "gewinkelt": "winkeln",
    "gewinkelte": "gewinkelt",
    "gewinkeltem": "gewinkelt",
    "gewinkelten": "gewinkelt",
    "gewinkelter": "gewinkelt",
    "gewinkeltes": "gewinkelt",
    "gewinkt": "winken",
    "gewinkte": "gewinkt",
    "gewinktem": "gewinkt",
    "gewinkten": "gewinkt",
    "gewinkter": "gewinkt",
    "gewinktes": "gewinkt",
    "gewinnend": "gewinnen",
    "gewinnende": "gewinnend",
    "gewinnendem": "gewinnend",
    "gewinnenden": "gewinnend",
    "gewinnender": "gewinnend",
    "gewinnendes": "gewinnend",
    "gewinnest": "gewinnen",
    "gewinnet": "gewinnen",
    "gewinnst": "gewinnen",
    "gewinnsüchtige": "gewinnsüchtig",
    "gewinnsüchtigem": "gewinnsüchtig",
    "gewinnsüchtigen": "gewinnsüchtig",
    "gewinnsüchtiger": "gewinnsüchtig",
    "gewinnsüchtigere": "gewinnsüchtig",
    "gewinnsüchtigerem": "gewinnsüchtig",
    "gewinnsüchtigeren": "gewinnsüchtig",
    "gewinnsüchtigerer": "gewinnsüchtig",
    "gewinnsüchtigeres": "gewinnsüchtig",
    "gewinnsüchtiges": "gewinnsüchtig",
    "gewinnsüchtigste": "gewinnsüchtig",
    "gewinnsüchtigstem": "gewinnsüchtig",
    "gewinnsüchtigsten": "gewinnsüchtig",
    "gewinnsüchtigster": "gewinnsüchtig",
    "gewinnsüchtigstes": "gewinnsüchtig",
    "gewinnt": "gewinnen",
    "gewinselt": "winseln",
    "gewinselte": "gewinselt",
    "gewinseltem": "gewinselt",
    "gewinselten": "gewinselt",
    "gewinselter": "gewinselt",
    "gewinseltes": "gewinselt",
    "gewippt": "wippen",
    "gewippte": "gewippt",
    "gewipptem": "gewippt",
    "gewippten": "gewippt",
    "gewippter": "gewippt",
    "gewipptes": "gewippt",
    "gewirbelt": "wirbeln",
    "gewirbelte": "gewirbelt",
    "gewirbeltem": "gewirbelt",
    "gewirbelten": "gewirbelt",
    "gewirbelter": "gewirbelt",
    "gewirbeltes": "gewirbelt",
    "gewirkt": "wirken",
    "gewirkte": "gewirkt",
    "gewirktem": "gewirkt",
    "gewirkten": "gewirkt",
    "gewirkter": "gewirkt",
    "gewirktes": "gewirkt",
    "gewirtet": "wirten",
    "gewirtete": "gewirtet",
    "gewirtetem": "gewirtet",
    "gewirteten": "gewirtet",
    "gewirteter": "gewirtet",
    "gewirtetes": "gewirtet",
    "gewirtschaftet": "wirtschaften",
    "gewirtschaftete": "gewirtschaftet",
    "gewirtschaftetem": "gewirtschaftet",
    "gewirtschafteten": "gewirtschaftet",
    "gewirtschafteter": "gewirtschaftet",
    "gewirtschaftetes": "gewirtschaftet",
    "gewischt": "wischen",
    "gewischte": "gewischt",
    "gewischtem": "gewischt",
    "gewischten": "gewischt",
    "gewischter": "gewischt",
    "gewischtes": "gewischt",
    "gewispert": "wispern",
    "gewisperte": "gewispert",
    "gewispertem": "gewispert",
    "gewisperten": "gewispert",
    "gewisperter": "gewispert",
    "gewispertes": "gewispert",
    "gewisse": "gewiß",
    "gewissem": "gewiß",
    "gewissen": "gewiß",
    "gewissenhaftem": "gewissenhaft",
    "gewissenhaften": "gewissenhaft",
    "gewissenhafter": "gewissenhaft",
    "gewissenhaftere": "gewissenhaft",
    "gewissenhafterem": "gewissenhaft",
    "gewissenhafteren": "gewissenhaft",
    "gewissenhafterer": "gewissenhaft",
    "gewissenhafteres": "gewissenhaft",
    "gewissenhaftes": "gewissenhaft",
    "gewissenhafteste": "gewissenhaft",
    "gewissenhaftestem": "gewissenhaft",
    "gewissenhaftesten": "gewissenhaft",
    "gewissenhaftester": "gewissenhaft",
    "gewissenhaftestes": "gewissenhaft",
    "gewissenlose": "gewissenlos",
    "gewissenlosem": "gewissenlos",
    "gewissenlosen": "gewissenlos",
    "gewissenloser": "gewissenlos",
    "gewissenlosere": "gewissenlos",
    "gewissenloserem": "gewissenlos",
    "gewissenloseren": "gewissenlos",
    "gewissenloserer": "gewissenlos",
    "gewissenloseres": "gewissenlos",
    "gewissenloses": "gewissenlos",
    "gewissenloseste": "gewissenlos",
    "gewissenlosestem": "gewissenlos",
    "gewissenlosesten": "gewissenlos",
    "gewissenlosester": "gewissenlos",
    "gewissenlosestes": "gewissenlos",
    "gewisser": "gewiß",
    "gewisses": "gewiß",
    "gewittere": "gewittern",
    "gewitterigem": "gewitterig",
    "gewitterigen": "gewitterig",
    "gewitteriger": "gewitterig",
    "gewitteriges": "gewitterig",
    "gewitternd": "gewittern",
    "gewitternde": "gewitternd",
    "gewitterndem": "gewitternd",
    "gewitternden": "gewitternd",
    "gewitternder": "gewitternd",
    "gewitterndere": "gewitternd",
    "gewitternderem": "gewitternd",
    "gewitternderen": "gewitternd",
    "gewitternderer": "gewitternd",
    "gewitternderes": "gewitternd",
    "gewitterndes": "gewitternd",
    "gewitterndste": "gewitternd",
    "gewitterndstem": "gewitternd",
    "gewitterndsten": "gewitternd",
    "gewitterndster": "gewitternd",
    "gewitterndstes": "gewitternd",
    "gewitterst": "gewittern",
    "gewittert": "wittern",
    "gewitterte": "gewittern",
    "gewittertem": "gewittert",
    "gewitterten": "gewittern",
    "gewitterter": "gewittert",
    "gewittertes": "gewittert",
    "gewittertest": "gewittern",
    "gewittertet": "gewittern",
    "gewittrige": "gewittrig",
    "gewittrigem": "gewittrig",
    "gewittrigen": "gewittrig",
    "gewittriger": "gewittrig",
    "gewittrigere": "gewittrig",
    "gewittrigerem": "gewittrig",
    "gewittrigeren": "gewittrig",
    "gewittrigerer": "gewittrig",
    "gewittrigeres": "gewittrig",
    "gewittriges": "gewittrig",
    "gewittrigste": "gewittrig",
    "gewittrigstem": "gewittrig",
    "gewittrigsten": "gewittrig",
    "gewittrigster": "gewittrig",
    "gewittrigstes": "gewittrig",
    "gewitzelt": "witzeln",
    "gewitzelte": "gewitzelt",
    "gewitzeltem": "gewitzelt",
    "gewitzelten": "gewitzelt",
    "gewitzelter": "gewitzelt",
    "gewitzeltes": "gewitzelt",
    "gewitzte": "gewitzt",
    "gewitztem": "gewitzt",
    "gewitzten": "gewitzt",
    "gewitzter": "gewitzt",
    "gewitztere": "gewitzt",
    "gewitzterem": "gewitzt",
    "gewitzteren": "gewitzt",
    "gewitzterer": "gewitzt",
    "gewitzteres": "gewitzt",
    "gewitztes": "gewitzt",
    "gewitzteste": "gewitzt",
    "gewitztestem": "gewitzt",
    "gewitztesten": "gewitzt",
    "gewitztester": "gewitzt",
    "gewitztestes": "gewitzt",
    "gewoben": "weben",
    "gewobene": "gewoben",
    "gewobenem": "gewoben",
    "gewobenen": "gewoben",
    "gewobener": "gewoben",
    "gewobenes": "gewoben",
    "gewogen": "wiegen",
    "gewogene": "gewogen",
    "gewogenem": "gewogen",
    "gewogenen": "gewogen",
    "gewogener": "gewogen",
    "gewogenes": "gewogen",
    "gewohnheitsgemäßem": "gewohnheitsgemäß",
    "gewohnheitsgemäßen": "gewohnheitsgemäß",
    "gewohnheitsgemäßer": "gewohnheitsgemäß",
    "gewohnheitsgemäßes": "gewohnheitsgemäß",
    "gewohnheitsmäßige": "gewohnheitsmäßig",
    "gewohnheitsmäßigem": "gewohnheitsmäßig",
    "gewohnheitsmäßigen": "gewohnheitsmäßig",
    "gewohnheitsmäßiger": "gewohnheitsmäßig",
    "gewohnheitsmäßiges": "gewohnheitsmäßig",
    "gewohnt": "wohnen",
    "gewohnte": "gewohnt",
    "gewohntem": "gewohnt",
    "gewohnten": "gewohnt",
    "gewohnter": "gewohnt",
    "gewohntes": "gewohnt",
    "gewollt": "wollen",
    "gewonnen": "gewinnen",
    "gewonnene": "gewonnen",
    "gewonnenem": "gewonnen",
    "gewonnenen": "gewonnen",
    "gewonnener": "gewonnen",
    "gewonnenes": "gewonnen",
    "geworben": "werben",
    "geworbene": "geworben",
    "geworbenem": "geworben",
    "geworbenen": "geworben",
    "geworbener": "geworben",
    "geworbenes": "geworben",
    "geworden": "werden",
    "gewordene": "geworden",
    "gewordenem": "geworden",
    "gewordenen": "geworden",
    "gewordener": "geworden",
    "gewordenes": "geworden",
    "geworfen": "werfen",
    "geworfene": "geworfen",
    "geworfenem": "geworfen",
    "geworfenen": "geworfen",
    "geworfener": "geworfen",
    "geworfenes": "geworfen",
    "gewrungen": "wringen",
    "gewrungene": "gewrungen",
    "gewrungenem": "gewrungen",
    "gewrungenen": "gewrungen",
    "gewrungener": "gewrungen",
    "gewrungenes": "gewrungen",
    "gewuchert": "wuchern",
    "gewucherte": "gewuchert",
    "gewuchertem": "gewuchert",
    "gewucherten": "gewuchert",
    "gewucherter": "gewuchert",
    "gewuchertes": "gewuchert",
    "gewuchtet": "wuchten",
    "gewuchtete": "gewuchtet",
    "gewuchtetem": "gewuchtet",
    "gewuchteten": "gewuchtet",
    "gewuchteter": "gewuchtet",
    "gewuchtetere": "gewuchtet",
    "gewuchteterem": "gewuchtet",
    "gewuchteteren": "gewuchtet",
    "gewuchteterer": "gewuchtet",
    "gewuchteteres": "gewuchtet",
    "gewuchtetes": "gewuchtet",
    "gewuchteteste": "gewuchtet",
    "gewuchtetestem": "gewuchtet",
    "gewuchtetesten": "gewuchtet",
    "gewuchtetester": "gewuchtet",
    "gewuchtetestes": "gewuchtet",
    "gewunden": "winden",
    "gewundene": "gewunden",
    "gewundenem": "gewunden",
    "gewundenen": "gewunden",
    "gewundener": "gewunden",
    "gewundenes": "gewunden",
    "gewundert": "wundern",
    "gewunderte": "gewundert",
    "gewundertem": "gewundert",
    "gewunderten": "gewundert",
    "gewunderter": "gewundert",
    "gewundertes": "gewundert",
    "gewurmt": "wurmen",
    "gewurmte": "gewurmt",
    "gewurmtem": "gewurmt",
    "gewurmten": "gewurmt",
    "gewurmter": "gewurmt",
    "gewurmtes": "gewurmt",
    "gewurstelt": "wursteln",
    "gewurstelte": "gewurstelt",
    "gewursteltem": "gewurstelt",
    "gewurstelten": "gewurstelt",
    "gewurstelter": "gewurstelt",
    "gewursteltes": "gewurstelt",
    "gewurstet": "wursten",
    "gewurstete": "gewurstet",
    "gewurstetem": "gewurstet",
    "gewursteten": "gewurstet",
    "gewursteter": "gewurstet",
    "gewurstetes": "gewurstet",
    "gewurzelt": "wurzeln",
    "gewurzelte": "gewurzelt",
    "gewurzeltem": "gewurzelt",
    "gewurzelten": "gewurzelt",
    "gewurzelter": "gewurzelt",
    "gewurzeltes": "gewurzelt",
    "gewuselt": "wuseln",
    "gewuselte": "gewuselt",
    "gewuseltem": "gewuselt",
    "gewuselten": "gewuselt",
    "gewuselter": "gewuselt",
    "gewuseltes": "gewuselt",
    "gewußt": "wissen",
    "gewußte": "gewußt",
    "gewußtem": "gewußt",
    "gewußten": "gewußt",
    "gewußter": "gewußt",
    "gewußtes": "gewußt",
    "gewählt": "wählen",
    "gewählte": "gewählt",
    "gewähltem": "gewählt",
    "gewählten": "gewählt",
    "gewählter": "gewählt",
    "gewähltere": "gewählt",
    "gewählterem": "gewählt",
    "gewählteren": "gewählt",
    "gewählterer": "gewählt",
    "gewählteres": "gewählt",
    "gewähltes": "gewählt",
    "gewählteste": "gewählt",
    "gewähltestem": "gewählt",
    "gewähltesten": "gewählt",
    "gewähltester": "gewählt",
    "gewähltestes": "gewählt",
    "gewähnt": "wähnen",
    "gewähnte": "gewähnt",
    "gewähntem": "gewähnt",
    "gewähnten": "gewähnt",
    "gewähnter": "gewähnt",
    "gewähntes": "gewähnt",
    "gewähre": "gewähren",
    "gewährend": "gewähren",
    "gewährende": "gewährend",
    "gewährendem": "gewährend",
    "gewährenden": "gewährend",
    "gewährender": "gewährend",
    "gewährendes": "gewährend",
    "gewährest": "gewähren",
    "gewähret": "gewähren",
    "gewährleiste": "gewährleisten",
    "gewährleistend": "gewährleisten",
    "gewährleistende": "gewährleistend",
    "gewährleistendem": "gewährleistend",
    "gewährleistenden": "gewährleistend",
    "gewährleistender": "gewährleistend",
    "gewährleistendes": "gewährleistend",
    "gewährleistest": "gewährleisten",
    "gewährleistet": "gewährleisten",
    "gewährleistete": "gewährleisten",
    "gewährleistetem": "gewährleistet",
    "gewährleisteten": "gewährleisten",
    "gewährleisteter": "gewährleistet",
    "gewährleistetes": "gewährleistet",
    "gewährleistetest": "gewährleisten",
    "gewährleistetet": "gewährleisten",
    "gewährst": "gewähren",
    "gewährt": "währen",
    "gewährte": "gewährt",
    "gewährtem": "gewährt",
    "gewährten": "gewährt",
    "gewährter": "gewährt",
    "gewährtes": "gewährt",
    "gewährtest": "gewähren",
    "gewährtet": "gewähren",
    "gewälzt": "wälzen",
    "gewälztem": "gewälzt",
    "gewälzter": "gewälzt",
    "gewälzterem": "gewälzt",
    "gewälzterer": "gewälzt",
    "gewälzteres": "gewälzt",
    "gewälztes": "gewälzt",
    "gewälztestem": "gewälzt",
    "gewälztester": "gewälzt",
    "gewälztestes": "gewälzt",
    "gewänne": "gewinnen",
    "gewännen": "gewinnen",
    "gewännest": "gewinnen",
    "gewännet": "gewinnen",
    "gewärmt": "wärmen",
    "gewärmte": "gewärmt",
    "gewärmtem": "gewärmt",
    "gewärmten": "gewärmt",
    "gewärmter": "gewärmt",
    "gewärmtes": "gewärmt",
    "gewässert": "wässern",
    "gewässerte": "gewässert",
    "gewässertem": "gewässert",
    "gewässerten": "gewässert",
    "gewässerter": "gewässert",
    "gewässertere": "gewässert",
    "gewässerterem": "gewässert",
    "gewässerteren": "gewässert",
    "gewässerterer": "gewässert",
    "gewässerteres": "gewässert",
    "gewässertes": "gewässert",
    "gewässerteste": "gewässert",
    "gewässertestem": "gewässert",
    "gewässertesten": "gewässert",
    "gewässertester": "gewässert",
    "gewässertestes": "gewässert",
    "gewöhne": "gewöhnen",
    "gewöhnend": "gewöhnen",
    "gewöhnende": "gewöhnend",
    "gewöhnendem": "gewöhnend",
    "gewöhnenden": "gewöhnend",
    "gewöhnender": "gewöhnend",
    "gewöhnendes": "gewöhnend",
    "gewöhnest": "gewöhnen",
    "gewöhnet": "gewöhnen",
    "gewöhnliche": "gewöhnlich",
    "gewöhnlichem": "gewöhnlich",
    "gewöhnlichen": "gewöhnlich",
    "gewöhnlicher": "gewöhnlich",
    "gewöhnlichere": "gewöhnlich",
    "gewöhnlicherem": "gewöhnlich",
    "gewöhnlicheren": "gewöhnlich",
    "gewöhnlicherer": "gewöhnlich",
    "gewöhnlicheres": "gewöhnlich",
    "gewöhnliches": "gewöhnlich",
    "gewöhnlichste": "gewöhnlich",
    "gewöhnlichstem": "gewöhnlich",
    "gewöhnlichsten": "gewöhnlich",
    "gewöhnlichster": "gewöhnlich",
    "gewöhnlichstes": "gewöhnlich",
    "gewöhnst": "gewöhnen",
    "gewöhnt": "gewöhnen",
    "gewöhnte": "gewöhnt",
    "gewöhntem": "gewöhnt",
    "gewöhnten": "gewöhnt",
    "gewöhnter": "gewöhnt",
    "gewöhntes": "gewöhnt",
    "gewöhntest": "gewöhnen",
    "gewöhntet": "gewöhnen",
    "gewölbt": "wölben",
    "gewölbte": "gewölbt",
    "gewölbtem": "gewölbt",
    "gewölbten": "gewölbt",
    "gewölbter": "gewölbt",
    "gewölbtes": "gewölbt",
    "gewühlt": "wühlen",
    "gewühlte": "gewühlt",
    "gewühltem": "gewühlt",
    "gewühlten": "gewühlt",
    "gewühlter": "gewühlt",
    "gewühltes": "gewühlt",
    "gewünscht": "wünschen",
    "gewünschte": "gewünscht",
    "gewünschtem": "gewünscht",
    "gewünschten": "gewünscht",
    "gewünschter": "gewünscht",
    "gewünschtes": "gewünscht",
    "gewürdigt": "würdigen",
    "gewürdigte": "gewürdigt",
    "gewürdigtem": "gewürdigt",
    "gewürdigten": "gewürdigt",
    "gewürdigter": "gewürdigt",
    "gewürdigtere": "gewürdigt",
    "gewürdigterem": "gewürdigt",
    "gewürdigteren": "gewürdigt",
    "gewürdigterer": "gewürdigt",
    "gewürdigteres": "gewürdigt",
    "gewürdigtes": "gewürdigt",
    "gewürdigteste": "gewürdigt",
    "gewürdigtestem": "gewürdigt",
    "gewürdigtesten": "gewürdigt",
    "gewürdigtester": "gewürdigt",
    "gewürdigtestes": "gewürdigt",
    "gewürfelt": "würfeln",
    "gewürfelte": "gewürfelt",
    "gewürfeltem": "gewürfelt",
    "gewürfelten": "gewürfelt",
    "gewürfelter": "gewürfelt",
    "gewürfeltes": "gewürfelt",
    "gewürgt": "würgen",
    "gewürgte": "gewürgt",
    "gewürgtem": "gewürgt",
    "gewürgten": "gewürgt",
    "gewürgter": "gewürgt",
    "gewürgtere": "gewürgt",
    "gewürgterem": "gewürgt",
    "gewürgteren": "gewürgt",
    "gewürgterer": "gewürgt",
    "gewürgteres": "gewürgt",
    "gewürgtes": "gewürgt",
    "gewürgteste": "gewürgt",
    "gewürgtestem": "gewürgt",
    "gewürgtesten": "gewürgt",
    "gewürgtester": "gewürgt",
    "gewürgtestes": "gewürgt",
    "gewürzt": "würzen",
    "gewürzte": "gewürzt",
    "gewürztem": "gewürzt",
    "gewürzten": "gewürzt",
    "gewürzter": "gewürzt",
    "gewürztere": "gewürzt",
    "gewürzterem": "gewürzt",
    "gewürzteren": "gewürzt",
    "gewürzterer": "gewürzt",
    "gewürzteres": "gewürzt",
    "gewürztes": "gewürzt",
    "gewürzteste": "gewürzt",
    "gewürztestem": "gewürzt",
    "gewürztesten": "gewürzt",
    "gewürztester": "gewürzt",
    "gewürztestes": "gewürzt",
    "gewütet": "wüten",
    "gewütete": "gewütet",
    "gewütetem": "gewütet",
    "gewüteten": "gewütet",
    "gewüteter": "gewütet",
    "gewütetere": "gewütet",
    "gewüteterem": "gewütet",
    "gewüteteren": "gewütet",
    "gewüteterer": "gewütet",
    "gewüteteres": "gewütet",
    "gewütetes": "gewütet",
    "gewüteteste": "gewütet",
    "gewütetestem": "gewütet",
    "gewütetesten": "gewütet",
    "gewütetester": "gewütet",
    "gewütetestes": "gewütet",
    "gezagt": "zagen",
    "gezagte": "gezagt",
    "gezagtem": "gezagt",
    "gezagten": "gezagt",
    "gezagter": "gezagt",
    "gezagtes": "gezagt",
    "gezahlt": "zahlen",
    "gezahlte": "gezahlt",
    "gezahltem": "gezahlt",
    "gezahlten": "gezahlt",
    "gezahlter": "gezahlt",
    "gezahltes": "gezahlt",
    "gezahnt": "zahnen",
    "gezahnte": "gezahnt",
    "gezahntem": "gezahnt",
    "gezahnten": "gezahnt",
    "gezahnter": "gezahnt",
    "gezahntes": "gezahnt",
    "gezankt": "zanken",
    "gezankte": "gezankt",
    "gezanktem": "gezankt",
    "gezankten": "gezankt",
    "gezankter": "gezankt",
    "gezanktes": "gezankt",
    "gezapft": "zapfen",
    "gezapfte": "gezapft",
    "gezapftem": "gezapft",
    "gezapften": "gezapft",
    "gezapfter": "gezapft",
    "gezapftes": "gezapft",
    "gezappelt": "zappeln",
    "gezappelte": "gezappelt",
    "gezappeltem": "gezappelt",
    "gezappelten": "gezappelt",
    "gezappelter": "gezappelt",
    "gezappeltes": "gezappelt",
    "gezaubert": "zaubern",
    "gezauberte": "gezaubert",
    "gezaubertem": "gezaubert",
    "gezauberten": "gezaubert",
    "gezauberter": "gezaubert",
    "gezaubertes": "gezaubert",
    "gezaudert": "zaudern",
    "gezauderte": "gezaudert",
    "gezaudertem": "gezaudert",
    "gezauderten": "gezaudert",
    "gezauderter": "gezaudert",
    "gezaudertes": "gezaudert",
    "gezaust": "zausen",
    "gezauste": "gezaust",
    "gezaustem": "gezaust",
    "gezausten": "gezaust",
    "gezauster": "gezaust",
    "gezaustes": "gezaust",
    "gezecht": "zechen",
    "gezechte": "gezecht",
    "gezechtem": "gezecht",
    "gezechten": "gezecht",
    "gezechter": "gezecht",
    "gezechtes": "gezecht",
    "gezehrt": "zehren",
    "gezehrte": "gezehrt",
    "gezehrtem": "gezehrt",
    "gezehrten": "gezehrt",
    "gezehrter": "gezehrt",
    "gezehrtere": "gezehrt",
    "gezehrterem": "gezehrt",
    "gezehrteren": "gezehrt",
    "gezehrterer": "gezehrt",
    "gezehrteres": "gezehrt",
    "gezehrtes": "gezehrt",
    "gezehrteste": "gezehrt",
    "gezehrtestem": "gezehrt",
    "gezehrtesten": "gezehrt",
    "gezehrtester": "gezehrt",
    "gezehrtestes": "gezehrt",
    "gezeichnet": "zeichnen",
    "gezeichnete": "gezeichnet",
    "gezeichnetem": "gezeichnet",
    "gezeichneten": "gezeichnet",
    "gezeichneter": "gezeichnet",
    "gezeichnetes": "gezeichnet",
    "gezeigt": "zeigen",
    "gezeigte": "gezeigt",
    "gezeigtem": "gezeigt",
    "gezeigten": "gezeigt",
    "gezeigter": "gezeigt",
    "gezeigtere": "gezeigt",
    "gezeigterem": "gezeigt",
    "gezeigteren": "gezeigt",
    "gezeigterer": "gezeigt",
    "gezeigteres": "gezeigt",
    "gezeigtes": "gezeigt",
    "gezeigteste": "gezeigt",
    "gezeigtestem": "gezeigt",
    "gezeigtesten": "gezeigt",
    "gezeigtester": "gezeigt",
    "gezeigtestes": "gezeigt",
    "gezeltet": "zelten",
    "gezeltete": "gezeltet",
    "gezeltetem": "gezeltet",
    "gezelteten": "gezeltet",
    "gezelteter": "gezeltet",
    "gezeltetes": "gezeltet",
    "gezerrt": "zerren",
    "gezerrte": "gezerrt",
    "gezerrtem": "gezerrt",
    "gezerrten": "gezerrt",
    "gezerrter": "gezerrt",
    "gezerrtes": "gezerrt",
    "gezettelt": "zetteln",
    "gezettelte": "gezettelt",
    "gezetteltem": "gezettelt",
    "gezettelten": "gezettelt",
    "gezettelter": "gezettelt",
    "gezetteltes": "gezettelt",
    "gezeugt": "zeugen",
    "gezeugte": "gezeugt",
    "gezeugtem": "gezeugt",
    "gezeugten": "gezeugt",
    "gezeugter": "gezeugt",
    "gezeugtes": "gezeugt",
    "gezielt": "zielen",
    "gezielte": "gezielt",
    "gezieltem": "gezielt",
    "gezielten": "gezielt",
    "gezielter": "gezielt",
    "gezieltere": "gezielt",
    "gezielterem": "gezielt",
    "gezielteren": "gezielt",
    "gezielterer": "gezielt",
    "gezielteres": "gezielt",
    "gezieltes": "gezielt",
    "gezielteste": "gezielt",
    "gezieltestem": "gezielt",
    "gezieltesten": "gezielt",
    "gezieltester": "gezielt",
    "gezieltestes": "gezielt",
    "gezieme": "geziemen",
    "geziemend": "geziemen",
    "geziemende": "geziemend",
    "geziemendem": "geziemend",
    "geziemenden": "geziemend",
    "geziemender": "geziemend",
    "geziemendes": "geziemend",
    "geziemest": "geziemen",
    "geziemet": "geziemen",
    "geziemst": "geziemen",
    "geziemt": "ziemen",
    "geziemte": "geziemen",
    "geziemtem": "geziemt",
    "geziemten": "geziemen",
    "geziemter": "geziemt",
    "geziemtes": "geziemt",
    "geziemtest": "geziemen",
    "geziemtet": "geziemen",
    "geziert": "zieren",
    "gezierte": "geziert",
    "geziertem": "geziert",
    "gezierten": "geziert",
    "gezierter": "geziert",
    "geziertes": "geziert",
    "gezimmert": "zimmern",
    "gezimmerte": "gezimmert",
    "gezimmertem": "gezimmert",
    "gezimmerten": "gezimmert",
    "gezimmerter": "gezimmert",
    "gezimmertes": "gezimmert",
    "gezinkt": "zinken",
    "gezinkte": "gezinkt",
    "gezinktem": "gezinkt",
    "gezinkten": "gezinkt",
    "gezinkter": "gezinkt",
    "gezinktere": "gezinkt",
    "gezinkterem": "gezinkt",
    "gezinkteren": "gezinkt",
    "gezinkterer": "gezinkt",
    "gezinkteres": "gezinkt",
    "gezinktes": "gezinkt",
    "gezinkteste": "gezinkt",
    "gezinktestem": "gezinkt",
    "gezinktesten": "gezinkt",
    "gezinktester": "gezinkt",
    "gezinktestes": "gezinkt",
    "gezirkelt": "zirkeln",
    "gezirkelte": "gezirkelt",
    "gezirkeltem": "gezirkelt",
    "gezirkelten": "gezirkelt",
    "gezirkelter": "gezirkelt",
    "gezirkeltes": "gezirkelt",
    "gezischt": "zischen",
    "gezischte": "gezischt",
    "gezischtem": "gezischt",
    "gezischten": "gezischt",
    "gezischter": "gezischt",
    "gezischtes": "gezischt",
    "gezittert": "zittern",
    "gezitterte": "gezittert",
    "gezittertem": "gezittert",
    "gezitterten": "gezittert",
    "gezitterter": "gezittert",
    "gezittertes": "gezittert",
    "gezogen": "ziehen",
    "gezogene": "gezogen",
    "gezogenem": "gezogen",
    "gezogenen": "gezogen",
    "gezogener": "gezogen",
    "gezogenes": "gezogen",
    "gezollt": "zollen",
    "gezollte": "gezollt",
    "gezolltem": "gezollt",
    "gezollten": "gezollt",
    "gezollter": "gezollt",
    "gezolltes": "gezollt",
    "gezuckt": "zucken",
    "gezuckte": "gezuckt",
    "gezucktem": "gezuckt",
    "gezuckten": "gezuckt",
    "gezuckter": "gezuckt",
    "gezucktes": "gezuckt",
    "gezupft": "zupfen",
    "gezupfte": "gezupft",
    "gezupftem": "gezupft",
    "gezupften": "gezupft",
    "gezupfter": "gezupft",
    "gezupftes": "gezupft",
    "gezurrt": "zurren",
    "gezurrte": "gezurrt",
    "gezurrtem": "gezurrt",
    "gezurrten": "gezurrt",
    "gezurrter": "gezurrt",
    "gezurrtes": "gezurrt",
    "gezweifelt": "zweifeln",
    "gezweifelte": "gezweifelt",
    "gezweifeltem": "gezweifelt",
    "gezweifelten": "gezweifelt",
    "gezweifelter": "gezweifelt",
    "gezweifeltes": "gezweifelt",
    "gezweigt": "zweigen",
    "gezweigte": "gezweigt",
    "gezweigtem": "gezweigt",
    "gezweigten": "gezweigt",
    "gezweigter": "gezweigt",
    "gezweigtes": "gezweigt",
    "gezwiebelt": "zwiebeln",
    "gezwiebelte": "gezwiebelt",
    "gezwiebeltem": "gezwiebelt",
    "gezwiebelten": "gezwiebelt",
    "gezwiebelter": "gezwiebelt",
    "gezwiebeltes": "gezwiebelt",
    "gezwinkert": "zwinkern",
    "gezwinkerte": "gezwinkert",
    "gezwinkertem": "gezwinkert",
    "gezwinkerten": "gezwinkert",
    "gezwinkerter": "gezwinkert",
    "gezwinkertes": "gezwinkert",
    "gezwirbelt": "zwirbeln",
    "gezwirbelte": "gezwirbelt",
    "gezwirbeltem": "gezwirbelt",
    "gezwirbelten": "gezwirbelt",
    "gezwirbelter": "gezwirbelt",
    "gezwirbeltes": "gezwirbelt",
    "gezwitschert": "zwitschern",
    "gezwitscherte": "gezwitschert",
    "gezwitschertem": "gezwitschert",
    "gezwitscherten": "gezwitschert",
    "gezwitscherter": "gezwitschert",
    "gezwitschertes": "gezwitschert",
    "gezwungen": "zwingen",
    "gezwungene": "gezwungen",
    "gezwungenem": "gezwungen",
    "gezwungenen": "gezwungen",
    "gezwungener": "gezwungen",
    "gezwungenere": "gezwungen",
    "gezwungenerem": "gezwungen",
    "gezwungeneren": "gezwungen",
    "gezwungenerer": "gezwungen",
    "gezwungeneres": "gezwungen",
    "gezwungenes": "gezwungen",
    "gezwungenste": "gezwungen",
    "gezwungenstem": "gezwungen",
    "gezwungensten": "gezwungen",
    "gezwungenster": "gezwungen",
    "gezwungenstes": "gezwungen",
    "gezwängt": "zwängen",
    "gezwängte": "gezwängt",
    "gezwängtem": "gezwängt",
    "gezwängten": "gezwängt",
    "gezwängter": "gezwängt",
    "gezwängtes": "gezwängt",
    "gezählt": "zählen",
    "gezähltem": "gezählt",
    "gezählter": "gezählt",
    "gezähltes": "gezählt",
    "gezähmt": "zähmen",
    "gezähmte": "gezähmt",
    "gezähmtem": "gezähmt",
    "gezähmten": "gezähmt",
    "gezähmter": "gezähmt",
    "gezähmtere": "gezähmt",
    "gezähmterem": "gezähmt",
    "gezähmteren": "gezähmt",
    "gezähmterer": "gezähmt",
    "gezähmteres": "gezähmt",
    "gezähmtes": "gezähmt",
    "gezähmteste": "gezähmt",
    "gezähmtestem": "gezähmt",
    "gezähmtesten": "gezähmt",
    "gezähmtester": "gezähmt",
    "gezähmtestes": "gezähmt",
    "gezäumt": "zäumen",
    "gezäumte": "gezäumt",
    "gezäumtem": "gezäumt",
    "gezäumten": "gezäumt",
    "gezäumter": "gezäumt",
    "gezäumtes": "gezäumt",
    "gezäunt": "zäunen",
    "gezäunte": "gezäunt",
    "gezäuntem": "gezäunt",
    "gezäunten": "gezäunt",
    "gezäunter": "gezäunt",
    "gezäuntes": "gezäunt",
    "gezögert": "zögern",
    "gezögerte": "gezögert",
    "gezögertem": "gezögert",
    "gezögerten": "gezögert",
    "gezögerter": "gezögert",
    "gezögertes": "gezögert",
    "gezüchtet": "züchten",
    "gezüchtete": "gezüchtet",
    "gezüchtetem": "gezüchtet",
    "gezüchteten": "gezüchtet",
    "gezüchteter": "gezüchtet",
    "gezüchtetes": "gezüchtet",
    "gezüchtigt": "züchtigen",
    "gezüchtigte": "gezüchtigt",
    "gezüchtigtem": "gezüchtigt",
    "gezüchtigten": "gezüchtigt",
    "gezüchtigter": "gezüchtigt",
    "gezüchtigtes": "gezüchtigt",
    "gezügelt": "zügeln",
    "gezügelte": "gezügelt",
    "gezügeltem": "gezügelt",
    "gezügelten": "gezügelt",
    "gezügelter": "gezügelt",
    "gezügeltere": "gezügelt",
    "gezügelterem": "gezügelt",
    "gezügelteren": "gezügelt",
    "gezügelterer": "gezügelt",
    "gezügelteres": "gezügelt",
    "gezügeltes": "gezügelt",
    "gezügelteste": "gezügelt",
    "gezügeltestem": "gezügelt",
    "gezügeltesten": "gezügelt",
    "gezügeltester": "gezügelt",
    "gezügeltestes": "gezügelt",
    "gezündelt": "zündeln",
    "gezündelte": "gezündelt",
    "gezündeltem": "gezündelt",
    "gezündelten": "gezündelt",
    "gezündelter": "gezündelt",
    "gezündeltes": "gezündelt",
    "gezündet": "zünden",
    "gezündete": "gezündet",
    "gezündetem": "gezündet",
    "gezündeten": "gezündet",
    "gezündeter": "gezündet",
    "gezündetes": "gezündet",
    "gezüngelt": "züngeln",
    "gezüngelte": "gezüngelt",
    "gezüngeltem": "gezüngelt",
    "gezüngelten": "gezüngelt",
    "gezüngelter": "gezüngelt",
    "gezüngeltes": "gezüngelt",
    "gezürnt": "zürnen",
    "gezürnte": "gezürnt",
    "gezürntem": "gezürnt",
    "gezürnten": "gezürnt",
    "gezürnter": "gezürnt",
    "gezürntere": "gezürnt",
    "gezürnterem": "gezürnt",
    "gezürnteren": "gezürnt",
    "gezürnterer": "gezürnt",
    "gezürnteres": "gezürnt",
    "gezürntes": "gezürnt",
    "gezürnteste": "gezürnt",
    "gezürntestem": "gezürnt",
    "gezürntesten": "gezürnt",
    "gezürntester": "gezürnt",
    "gezürntestes": "gezürnt",
    "geächtet": "ächten",
    "geächtetem": "geächtet",
    "geächteter": "geächtet",
    "geächteterem": "geächtet",
    "geächteterer": "geächtet",
    "geächteteres": "geächtet",
    "geächtetes": "geächtet",
    "geächtetestem": "geächtet",
    "geächtetester": "geächtet",
    "geächtetestes": "geächtet",
    "geächzt": "ächzen",
    "geächzte": "geächzt",
    "geächztem": "geächzt",
    "geächzten": "geächzt",
    "geächzter": "geächzt",
    "geächztes": "geächzt",
    "geäfft": "äffen",
    "geäffte": "geäfft",
    "geäfftem": "geäfft",
    "geäfften": "geäfft",
    "geäffter": "geäfft",
    "geäfftere": "geäfft",
    "geäffterem": "geäfft",
    "geäffteren": "geäfft",
    "geäffterer": "geäfft",
    "geäffteres": "geäfft",
    "geäfftes": "geäfft",
    "geäffteste": "geäfft",
    "geäfftestem": "geäfft",
    "geäfftesten": "geäfft",
    "geäfftester": "geäfft",
    "geäfftestes": "geäfft",
    "geähnelt": "ähneln",
    "geähnelte": "geähnelt",
    "geähneltem": "geähnelt",
    "geähnelten": "geähnelt",
    "geähnelter": "geähnelt",
    "geähneltes": "geähnelt",
    "geändert": "ändern",
    "geänderte": "geändert",
    "geändertem": "geändert",
    "geänderten": "geändert",
    "geänderter": "geändert",
    "geändertere": "geändert",
    "geänderterem": "geändert",
    "geänderteren": "geändert",
    "geänderterer": "geändert",
    "geänderteres": "geändert",
    "geändertes": "geändert",
    "geänderteste": "geändert",
    "geändertestem": "geändert",
    "geändertesten": "geändert",
    "geändertester": "geändert",
    "geändertestes": "geändert",
    "geängstigt": "ängstigen",
    "geängstigte": "geängstigt",
    "geängstigtem": "geängstigt",
    "geängstigten": "geängstigt",
    "geängstigter": "geängstigt",
    "geängstigtere": "geängstigt",
    "geängstigterem": "geängstigt",
    "geängstigteren": "geängstigt",
    "geängstigterer": "geängstigt",
    "geängstigteres": "geängstigt",
    "geängstigtes": "geängstigt",
    "geängstigteste": "geängstigt",
    "geängstigtestem": "geängstigt",
    "geängstigtesten": "geängstigt",
    "geängstigtester": "geängstigt",
    "geängstigtestes": "geängstigt",
    "geärgert": "ärgern",
    "geärgerte": "geärgert",
    "geärgertem": "geärgert",
    "geärgerten": "geärgert",
    "geärgerter": "geärgert",
    "geärgertes": "geärgert",
    "geäschert": "äschern",
    "geäscherte": "geäschert",
    "geäschertem": "geäschert",
    "geäscherten": "geäschert",
    "geäscherter": "geäschert",
    "geäschertes": "geäschert",
    "geästet": "ästen",
    "geästete": "geästet",
    "geästetem": "geästet",
    "geästeten": "geästet",
    "geästeter": "geästet",
    "geästetes": "geästet",
    "geätzt": "ätzen",
    "geätzte": "geätzt",
    "geätztem": "geätzt",
    "geätzten": "geätzt",
    "geätzter": "geätzt",
    "geätztes": "geätzt",
    "geäußert": "äußern",
    "geäußerte": "geäußert",
    "geäußertem": "geäußert",
    "geäußerten": "geäußert",
    "geäußerter": "geäußert",
    "geäußertes": "geäußert",
    "geödet": "öden",
    "geödete": "geödet",
    "geödetem": "geödet",
    "geödeten": "geödet",
    "geödeter": "geödet",
    "geödetes": "geödet",
    "geöffnet": "öffnen",
    "geöffnete": "geöffnet",
    "geöffnetem": "geöffnet",
    "geöffneten": "geöffnet",
    "geöffneter": "geöffnet",
    "geöffnetere": "geöffnet",
    "geöffneterem": "geöffnet",
    "geöffneteren": "geöffnet",
    "geöffneterer": "geöffnet",
    "geöffneteres": "geöffnet",
    "geöffnetes": "geöffnet",
    "geöffneteste": "geöffnet",
    "geöffnetestem": "geöffnet",
    "geöffnetesten": "geöffnet",
    "geöffnetester": "geöffnet",
    "geöffnetestes": "geöffnet",
    "geölt": "ölen",
    "geölte": "geölt",
    "geöltem": "geölt",
    "geölten": "geölt",
    "geölter": "geölt",
    "geöltes": "geölt",
    "geübt": "üben",
    "geübte": "geübt",
    "geübtem": "geübt",
    "geübten": "geübt",
    "geübter": "geübt",
    "geübtere": "geübt",
    "geübterem": "geübt",
    "geübteren": "geübt",
    "geübterer": "geübt",
    "geübteres": "geübt",
    "geübtes": "geübt",
    "geübteste": "geübt",
    "geübtestem": "geübt",
    "geübtesten": "geübt",
    "geübtester": "geübt",
    "geübtestes": "geübt",
    "gib": "geben",
    "gibst": "geben",
    "gibt": "geben",
    "giere": "gieren",
    "gierend": "gieren",
    "gierende": "gierend",
    "gierendem": "gierend",
    "gierenden": "gierend",
    "gierender": "gierend",
    "gierendere": "gierend",
    "gierenderem": "gierend",
    "gierenderen": "gierend",
    "gierenderer": "gierend",
    "gierenderes": "gierend",
    "gierendes": "gierend",
    "gierendste": "gierend",
    "gierendstem": "gierend",
    "gierendsten": "gierend",
    "gierendster": "gierend",
    "gierendstes": "gierend",
    "gierest": "gieren",
    "gieret": "gieren",
    "gierige": "gierig",
    "gierigem": "gierig",
    "gierigen": "gierig",
    "gieriger": "gierig",
    "gierigere": "gierig",
    "gierigerem": "gierig",
    "gierigeren": "gierig",
    "gierigerer": "gierig",
    "gierigeres": "gierig",
    "gieriges": "gierig",
    "gierigste": "gierig",
    "gierigstem": "gierig",
    "gierigsten": "gierig",
    "gierigster": "gierig",
    "gierigstes": "gierig",
    "gierst": "gieren",
    "giert": "gieren",
    "gierte": "gieren",
    "gierten": "gieren",
    "giertest": "gieren",
    "giertet": "gieren",
    "gieße": "gießen",
    "gießend": "gießen",
    "gießende": "gießend",
    "gießendem": "gießend",
    "gießenden": "gießend",
    "gießender": "gießend",
    "gießendes": "gießend",
    "gießest": "gießen",
    "gießet": "gießen",
    "gießt": "gießen",
    "giftend": "giften",
    "giftende": "giftend",
    "giftendem": "giftend",
    "giftenden": "giftend",
    "giftender": "giftend",
    "giftendes": "giftend",
    "giftest": "giften",
    "giftet": "giften",
    "giftete": "giften",
    "gifteten": "giften",
    "giftetest": "giften",
    "giftetet": "giften",
    "giftige": "giftig",
    "giftigem": "giftig",
    "giftigen": "giftig",
    "giftiger": "giftig",
    "giftigere": "giftig",
    "giftigerem": "giftig",
    "giftigeren": "giftig",
    "giftigerer": "giftig",
    "giftigeres": "giftig",
    "giftiges": "giftig",
    "giftigste": "giftig",
    "giftigstem": "giftig",
    "giftigsten": "giftig",
    "giftigster": "giftig",
    "giftigstes": "giftig",
    "gigantischem": "gigantisch",
    "gigantischen": "gigantisch",
    "gigantischer": "gigantisch",
    "gigantischere": "gigantisch",
    "gigantischerem": "gigantisch",
    "gigantischeren": "gigantisch",
    "gigantischerer": "gigantisch",
    "gigantischeres": "gigantisch",
    "gigantisches": "gigantisch",
    "gigantischste": "gigantisch",
    "gigantischstem": "gigantisch",
    "gigantischsten": "gigantisch",
    "gigantischster": "gigantisch",
    "gigantischstes": "gigantisch",
    "gilt": "gelten",
    "giltst": "gelten",
    "ging": "gehen",
    "ginge": "gehen",
    "gingen": "gehen",
    "gingest": "gehen",
    "ginget": "gehen",
    "gingst": "gehen",
    "gingt": "gehen",
    "gipfele": "gipfeln",
    "gipfelnd": "gipfeln",
    "gipfelnde": "gipfelnd",
    "gipfelndem": "gipfelnd",
    "gipfelnden": "gipfelnd",
    "gipfelnder": "gipfelnd",
    "gipfelndere": "gipfelnd",
    "gipfelnderem": "gipfelnd",
    "gipfelnderen": "gipfelnd",
    "gipfelnderer": "gipfelnd",
    "gipfelnderes": "gipfelnd",
    "gipfelndes": "gipfelnd",
    "gipfelndste": "gipfelnd",
    "gipfelndstem": "gipfelnd",
    "gipfelndsten": "gipfelnd",
    "gipfelndster": "gipfelnd",
    "gipfelndstes": "gipfelnd",
    "gipfelst": "gipfeln",
    "gipfelt": "gipfeln",
    "gipfelte": "gipfeln",
    "gipfelten": "gipfeln",
    "gipfeltest": "gipfeln",
    "gipfeltet": "gipfeln",
    "gipfle": "gipfeln",
    "gipsend": "gipsen",
    "gipsende": "gipsend",
    "gipsendem": "gipsend",
    "gipsenden": "gipsend",
    "gipsender": "gipsend",
    "gipsendes": "gipsend",
    "gipsest": "gipsen",
    "gipset": "gipsen",
    "gipst": "gipsen",
    "gipste": "gipsen",
    "gipsten": "gipsen",
    "gipstest": "gipsen",
    "gipstet": "gipsen",
    "gittere": "gittern",
    "gitternd": "gittern",
    "gitternde": "gitternd",
    "gitterndem": "gitternd",
    "gitternden": "gitternd",
    "gitternder": "gitternd",
    "gitterndes": "gitternd",
    "gitterst": "gittern",
    "gittert": "gittern",
    "gitterte": "gittern",
    "gitterten": "gittern",
    "gittertest": "gittern",
    "gittertet": "gittern",
    "glanzlosem": "glanzlos",
    "glanzlosen": "glanzlos",
    "glanzloser": "glanzlos",
    "glanzlosere": "glanzlos",
    "glanzloserem": "glanzlos",
    "glanzloseren": "glanzlos",
    "glanzloserer": "glanzlos",
    "glanzloseres": "glanzlos",
    "glanzloses": "glanzlos",
    "glanzloseste": "glanzlos",
    "glanzlosestem": "glanzlos",
    "glanzlosesten": "glanzlos",
    "glanzlosester": "glanzlos",
    "glanzlosestes": "glanzlos",
    "glanzvolle": "glanzvoll",
    "glanzvollem": "glanzvoll",
    "glanzvollen": "glanzvoll",
    "glanzvoller": "glanzvoll",
    "glanzvollere": "glanzvoll",
    "glanzvollerem": "glanzvoll",
    "glanzvolleren": "glanzvoll",
    "glanzvollerer": "glanzvoll",
    "glanzvolleres": "glanzvoll",
    "glanzvolles": "glanzvoll",
    "glanzvollste": "glanzvoll",
    "glanzvollstem": "glanzvoll",
    "glanzvollsten": "glanzvoll",
    "glanzvollster": "glanzvoll",
    "glanzvollstes": "glanzvoll",
    "glasend": "glasen",
    "glasende": "glasend",
    "glasendem": "glasend",
    "glasenden": "glasend",
    "glasender": "glasend",
    "glasendes": "glasend",
    "glasest": "glasen",
    "glaset": "glasen",
    "glasiere": "glasieren",
    "glasierend": "glasieren",
    "glasierende": "glasierend",
    "glasierendem": "glasierend",
    "glasierenden": "glasierend",
    "glasierender": "glasierend",
    "glasierendere": "glasierend",
    "glasierenderem": "glasierend",
    "glasierenderen": "glasierend",
    "glasierenderer": "glasierend",
    "glasierenderes": "glasierend",
    "glasierendes": "glasierend",
    "glasierendste": "glasierend",
    "glasierendstem": "glasierend",
    "glasierendsten": "glasierend",
    "glasierendster": "glasierend",
    "glasierendstes": "glasierend",
    "glasierest": "glasieren",
    "glasieret": "glasieren",
    "glasierst": "glasieren",
    "glasiert": "glasieren",
    "glasierte": "glasieren",
    "glasiertem": "glasiert",
    "glasierten": "glasieren",
    "glasierter": "glasiert",
    "glasiertere": "glasiert",
    "glasierterem": "glasiert",
    "glasierteren": "glasiert",
    "glasierterer": "glasiert",
    "glasierteres": "glasiert",
    "glasiertes": "glasiert",
    "glasiertest": "glasieren",
    "glasierteste": "glasiert",
    "glasiertestem": "glasiert",
    "glasiertesten": "glasiert",
    "glasiertester": "glasiert",
    "glasiertestes": "glasiert",
    "glasiertet": "glasieren",
    "glasige": "glasig",
    "glasigem": "glasig",
    "glasigen": "glasig",
    "glasiger": "glasig",
    "glasigere": "glasig",
    "glasigerem": "glasig",
    "glasigeren": "glasig",
    "glasigerer": "glasig",
    "glasigeres": "glasig",
    "glasiges": "glasig",
    "glasigste": "glasig",
    "glasigstem": "glasig",
    "glasigsten": "glasig",
    "glasigster": "glasig",
    "glasigstes": "glasig",
    "glast": "glasen",
    "glaste": "glasen",
    "glasten": "glasen",
    "glastest": "glasen",
    "glastet": "glasen",
    "glatte": "glatt",
    "glattem": "glatt",
    "glatten": "glatt",
    "glatter": "glatt",
    "glattere": "glatt",
    "glatterem": "glatt",
    "glatteren": "glatt",
    "glatterer": "glatt",
    "glatteres": "glatt",
    "glattes": "glatt",
    "glatteste": "glatt",
    "glattestem": "glatt",
    "glattesten": "glatt",
    "glattester": "glatt",
    "glattestes": "glatt",
    "glattgegangen": "glattgehen",
    "glattgegangene": "glattgegangen",
    "glattgegangenem": "glattgegangen",
    "glattgegangenen": "glattgegangen",
    "glattgegangener": "glattgegangen",
    "glattgegangenes": "glattgegangen",
    "glattgehe": "glattgehen",
    "glattgehend": "glattgehen",
    "glattgehende": "glattgehend",
    "glattgehendem": "glattgehend",
    "glattgehenden": "glattgehend",
    "glattgehender": "glattgehend",
    "glattgehendes": "glattgehend",
    "glattgehest": "glattgehen",
    "glattgehet": "glattgehen",
    "glattgehobelt": "glatthobeln",
    "glattgehobelte": "glattgehobelt",
    "glattgehobeltem": "glattgehobelt",
    "glattgehobelten": "glattgehobelt",
    "glattgehobelter": "glattgehobelt",
    "glattgehobeltere": "glattgehobelt",
    "glattgehobelterem": "glattgehobelt",
    "glattgehobelteren": "glattgehobelt",
    "glattgehobelterer": "glattgehobelt",
    "glattgehobelteres": "glattgehobelt",
    "glattgehobeltes": "glattgehobelt",
    "glattgehobelteste": "glattgehobelt",
    "glattgehobeltestem": "glattgehobelt",
    "glattgehobeltesten": "glattgehobelt",
    "glattgehobeltester": "glattgehobelt",
    "glattgehobeltestes": "glattgehobelt",
    "glattgehst": "glattgehen",
    "glattgeht": "glattgehen",
    "glattgestrichen": "glattstreichen",
    "glattgestrichene": "glattgestrichen",
    "glattgestrichenem": "glattgestrichen",
    "glattgestrichenen": "glattgestrichen",
    "glattgestrichener": "glattgestrichen",
    "glattgestrichenes": "glattgestrichen",
    "glattgezogen": "glattziehen",
    "glattgezogene": "glattgezogen",
    "glattgezogenem": "glattgezogen",
    "glattgezogenen": "glattgezogen",
    "glattgezogener": "glattgezogen",
    "glattgezogenere": "glattgezogen",
    "glattgezogenerem": "glattgezogen",
    "glattgezogeneren": "glattgezogen",
    "glattgezogenerer": "glattgezogen",
    "glattgezogeneres": "glattgezogen",
    "glattgezogenes": "glattgezogen",
    "glattgezogenste": "glattgezogen",
    "glattgezogenstem": "glattgezogen",
    "glattgezogensten": "glattgezogen",
    "glattgezogenster": "glattgezogen",
    "glattgezogenstes": "glattgezogen",
    "glattging": "glattgehen",
    "glattginge": "glattgehen",
    "glattgingen": "glattgehen",
    "glattgingest": "glattgehen",
    "glattginget": "glattgehen",
    "glattgingst": "glattgehen",
    "glattgingt": "glattgehen",
    "glatthobele": "glatthobeln",
    "glatthobelnd": "glatthobeln",
    "glatthobelnde": "glatthobelnd",
    "glatthobelndem": "glatthobelnd",
    "glatthobelnden": "glatthobelnd",
    "glatthobelnder": "glatthobelnd",
    "glatthobelndere": "glatthobelnd",
    "glatthobelnderem": "glatthobelnd",
    "glatthobelnderen": "glatthobelnd",
    "glatthobelnderer": "glatthobelnd",
    "glatthobelnderes": "glatthobelnd",
    "glatthobelndes": "glatthobelnd",
    "glatthobelndste": "glatthobelnd",
    "glatthobelndstem": "glatthobelnd",
    "glatthobelndsten": "glatthobelnd",
    "glatthobelndster": "glatthobelnd",
    "glatthobelndstes": "glatthobelnd",
    "glatthobelst": "glatthobeln",
    "glatthobelt": "glatthobeln",
    "glatthobelte": "glatthobeln",
    "glatthobelten": "glatthobeln",
    "glatthobeltest": "glatthobeln",
    "glatthobeltet": "glatthobeln",
    "glatthoble": "glatthobeln",
    "glattstreiche": "glattstreichen",
    "glattstreichend": "glattstreichen",
    "glattstreichende": "glattstreichend",
    "glattstreichendem": "glattstreichend",
    "glattstreichenden": "glattstreichend",
    "glattstreichender": "glattstreichend",
    "glattstreichendes": "glattstreichend",
    "glattstreichest": "glattstreichen",
    "glattstreichet": "glattstreichen",
    "glattstreichst": "glattstreichen",
    "glattstreicht": "glattstreichen",
    "glattstrich": "glattstreichen",
    "glattstriche": "glattstreichen",
    "glattstrichen": "glattstreichen",
    "glattstrichest": "glattstreichen",
    "glattstrichet": "glattstreichen",
    "glattstrichst": "glattstreichen",
    "glattstricht": "glattstreichen",
    "glattziehe": "glattziehen",
    "glattziehend": "glattziehen",
    "glattziehende": "glattziehend",
    "glattziehendem": "glattziehend",
    "glattziehenden": "glattziehend",
    "glattziehender": "glattziehend",
    "glattziehendere": "glattziehend",
    "glattziehenderem": "glattziehend",
    "glattziehenderen": "glattziehend",
    "glattziehenderer": "glattziehend",
    "glattziehenderes": "glattziehend",
    "glattziehendes": "glattziehend",
    "glattziehendste": "glattziehend",
    "glattziehendstem": "glattziehend",
    "glattziehendsten": "glattziehend",
    "glattziehendster": "glattziehend",
    "glattziehendstes": "glattziehend",
    "glattziehest": "glattziehen",
    "glattziehet": "glattziehen",
    "glattziehst": "glattziehen",
    "glattzieht": "glattziehen",
    "glattzog": "glattziehen",
    "glattzogen": "glattziehen",
    "glattzogst": "glattziehen",
    "glattzogt": "glattziehen",
    "glattzugehen": "glattgehen",
    "glattzuhobeln": "glatthobeln",
    "glattzustreichen": "glattstreichen",
    "glattzuziehen": "glattziehen",
    "glattzöge": "glattziehen",
    "glattzögen": "glattziehen",
    "glattzögest": "glattziehen",
    "glattzöget": "glattziehen",
    "glattzüngige": "glattzüngig",
    "glattzüngigem": "glattzüngig",
    "glattzüngigen": "glattzüngig",
    "glattzüngiger": "glattzüngig",
    "glattzüngiges": "glattzüngig",
    "glatzköpfigem": "glatzköpfig",
    "glatzköpfigen": "glatzköpfig",
    "glatzköpfiger": "glatzköpfig",
    "glatzköpfiges": "glatzköpfig",
    "glaube": "glauben",
    "glaubend": "glauben",
    "glaubende": "glaubend",
    "glaubendem": "glaubend",
    "glaubenden": "glaubend",
    "glaubender": "glaubend",
    "glaubendes": "glaubend",
    "glaubest": "glauben",
    "glaubet": "glauben",
    "glaubhafte": "glaubhaft",
    "glaubhaftem": "glaubhaft",
    "glaubhaften": "glaubhaft",
    "glaubhafter": "glaubhaft",
    "glaubhaftere": "glaubhaft",
    "glaubhafterem": "glaubhaft",
    "glaubhafteren": "glaubhaft",
    "glaubhafterer": "glaubhaft",
    "glaubhafteres": "glaubhaft",
    "glaubhaftes": "glaubhaft",
    "glaubhafteste": "glaubhaft",
    "glaubhaftestem": "glaubhaft",
    "glaubhaftesten": "glaubhaft",
    "glaubhaftester": "glaubhaft",
    "glaubhaftestes": "glaubhaft",
    "glaubst": "glauben",
    "glaubt": "glauben",
    "glaubte": "glauben",
    "glaubten": "glauben",
    "glaubtest": "glauben",
    "glaubtet": "glauben",
    "glaubwürdige": "glaubwürdig",
    "glaubwürdigem": "glaubwürdig",
    "glaubwürdigen": "glaubwürdig",
    "glaubwürdiger": "glaubwürdig",
    "glaubwürdigere": "glaubwürdig",
    "glaubwürdigerem": "glaubwürdig",
    "glaubwürdigeren": "glaubwürdig",
    "glaubwürdigerer": "glaubwürdig",
    "glaubwürdigeres": "glaubwürdig",
    "glaubwürdiges": "glaubwürdig",
    "glaubwürdigste": "glaubwürdig",
    "glaubwürdigstem": "glaubwürdig",
    "glaubwürdigsten": "glaubwürdig",
    "glaubwürdigster": "glaubwürdig",
    "glaubwürdigstes": "glaubwürdig",
    "glaziale": "glazial",
    "glazialem": "glazial",
    "glazialen": "glazial",
    "glazialer": "glazial",
    "glaziales": "glazial",
    "gleich": "gleichen",
    "gleichaltrige": "gleichaltrig",
    "gleichaltrigem": "gleichaltrig",
    "gleichaltrigen": "gleichaltrig",
    "gleichaltriger": "gleichaltrig",
    "gleichaltriges": "gleichaltrig",
    "gleichartige": "gleichartig",
    "gleichartigem": "gleichartig",
    "gleichartigen": "gleichartig",
    "gleichartiger": "gleichartig",
    "gleichartiges": "gleichartig",
    "gleichbedeutende": "gleichbedeutend",
    "gleichbedeutendem": "gleichbedeutend",
    "gleichbedeutenden": "gleichbedeutend",
    "gleichbedeutender": "gleichbedeutend",
    "gleichbedeutendes": "gleichbedeutend",
    "gleichberechtigte": "gleichberechtigt",
    "gleichberechtigtem": "gleichberechtigt",
    "gleichberechtigten": "gleichberechtigt",
    "gleichberechtigter": "gleichberechtigt",
    "gleichberechtigtes": "gleichberechtigt",
    "gleiche": "gleich",
    "gleichem": "gleich",
    "gleichen": "gleich",
    "gleichend": "gleichen",
    "gleichende": "gleichend",
    "gleichendem": "gleichend",
    "gleichenden": "gleichend",
    "gleichender": "gleichend",
    "gleichendere": "gleichend",
    "gleichenderem": "gleichend",
    "gleichenderen": "gleichend",
    "gleichenderer": "gleichend",
    "gleichenderes": "gleichend",
    "gleichendes": "gleichend",
    "gleichendste": "gleichend",
    "gleichendstem": "gleichend",
    "gleichendsten": "gleichend",
    "gleichendster": "gleichend",
    "gleichendstes": "gleichend",
    "gleicher": "gleich",
    "gleiches": "gleich",
    "gleichest": "gleichen",
    "gleichet": "gleichen",
    "gleichförmige": "gleichförmig",
    "gleichförmigem": "gleichförmig",
    "gleichförmigen": "gleichförmig",
    "gleichförmiger": "gleichförmig",
    "gleichförmigere": "gleichförmig",
    "gleichförmigerem": "gleichförmig",
    "gleichförmigeren": "gleichförmig",
    "gleichförmigerer": "gleichförmig",
    "gleichförmigeres": "gleichförmig",
    "gleichförmiges": "gleichförmig",
    "gleichförmigste": "gleichförmig",
    "gleichförmigstem": "gleichförmig",
    "gleichförmigsten": "gleichförmig",
    "gleichförmigster": "gleichförmig",
    "gleichförmigstes": "gleichförmig",
    "gleichgelaufen": "gleichlaufen",
    "gleichgelaufene": "gleichgelaufen",
    "gleichgelaufenem": "gleichgelaufen",
    "gleichgelaufenen": "gleichgelaufen",
    "gleichgelaufener": "gleichgelaufen",
    "gleichgelaufenere": "gleichgelaufen",
    "gleichgelaufenerem": "gleichgelaufen",
    "gleichgelaufeneren": "gleichgelaufen",
    "gleichgelaufenerer": "gleichgelaufen",
    "gleichgelaufeneres": "gleichgelaufen",
    "gleichgelaufenes": "gleichgelaufen",
    "gleichgelaufenste": "gleichgelaufen",
    "gleichgelaufenstem": "gleichgelaufen",
    "gleichgelaufensten": "gleichgelaufen",
    "gleichgelaufenster": "gleichgelaufen",
    "gleichgelaufenstes": "gleichgelaufen",
    "gleichgeschaltet": "gleichschalten",
    "gleichgeschaltete": "gleichgeschaltet",
    "gleichgeschaltetem": "gleichgeschaltet",
    "gleichgeschalteten": "gleichgeschaltet",
    "gleichgeschalteter": "gleichgeschaltet",
    "gleichgeschaltetere": "gleichgeschaltet",
    "gleichgeschalteterem": "gleichgeschaltet",
    "gleichgeschalteteren": "gleichgeschaltet",
    "gleichgeschalteterer": "gleichgeschaltet",
    "gleichgeschalteteres": "gleichgeschaltet",
    "gleichgeschaltetes": "gleichgeschaltet",
    "gleichgeschalteteste": "gleichgeschaltet",
    "gleichgeschaltetestem": "gleichgeschaltet",
    "gleichgeschaltetesten": "gleichgeschaltet",
    "gleichgeschaltetester": "gleichgeschaltet",
    "gleichgeschaltetestes": "gleichgeschaltet",
    "gleichgeschlechtliche": "gleichgeschlechtlich",
    "gleichgeschlechtlichem": "gleichgeschlechtlich",
    "gleichgeschlechtlichen": "gleichgeschlechtlich",
    "gleichgeschlechtlicher": "gleichgeschlechtlich",
    "gleichgeschlechtliches": "gleichgeschlechtlich",
    "gleichgesetzt": "gleichsetzen",
    "gleichgesetzte": "gleichgesetzt",
    "gleichgesetztem": "gleichgesetzt",
    "gleichgesetzten": "gleichgesetzt",
    "gleichgesetzter": "gleichgesetzt",
    "gleichgesetztes": "gleichgesetzt",
    "gleichgestanden": "gleichstehen",
    "gleichgestandene": "gleichgestanden",
    "gleichgestandenem": "gleichgestanden",
    "gleichgestandenen": "gleichgestanden",
    "gleichgestandener": "gleichgestanden",
    "gleichgestandenes": "gleichgestanden",
    "gleichgestellt": "gleichstellen",
    "gleichgestellte": "gleichgestellt",
    "gleichgestelltem": "gleichgestellt",
    "gleichgestellten": "gleichgestellt",
    "gleichgestellter": "gleichgestellt",
    "gleichgestelltere": "gleichgestellt",
    "gleichgestellterem": "gleichgestellt",
    "gleichgestellteren": "gleichgestellt",
    "gleichgestellterer": "gleichgestellt",
    "gleichgestellteres": "gleichgestellt",
    "gleichgestelltes": "gleichgestellt",
    "gleichgestellteste": "gleichgestellt",
    "gleichgestelltestem": "gleichgestellt",
    "gleichgestelltesten": "gleichgestellt",
    "gleichgestelltester": "gleichgestellt",
    "gleichgestelltestes": "gleichgestellt",
    "gleichgestimmt": "gleichstimmen",
    "gleichgestimmte": "gleichgestimmt",
    "gleichgestimmtem": "gleichgestimmt",
    "gleichgestimmten": "gleichgestimmt",
    "gleichgestimmter": "gleichgestimmt",
    "gleichgestimmtes": "gleichgestimmt",
    "gleichgezogen": "gleichziehen",
    "gleichgezogene": "gleichgezogen",
    "gleichgezogenem": "gleichgezogen",
    "gleichgezogenen": "gleichgezogen",
    "gleichgezogener": "gleichgezogen",
    "gleichgezogenes": "gleichgezogen",
    "gleichgültige": "gleichgültig",
    "gleichgültigem": "gleichgültig",
    "gleichgültigen": "gleichgültig",
    "gleichgültiger": "gleichgültig",
    "gleichgültigere": "gleichgültig",
    "gleichgültigerem": "gleichgültig",
    "gleichgültigeren": "gleichgültig",
    "gleichgültigerer": "gleichgültig",
    "gleichgültigeres": "gleichgültig",
    "gleichgültiges": "gleichgültig",
    "gleichgültigste": "gleichgültig",
    "gleichgültigstem": "gleichgültig",
    "gleichgültigsten": "gleichgültig",
    "gleichgültigster": "gleichgültig",
    "gleichgültigstes": "gleichgültig",
    "gleichlaufe": "gleichlaufen",
    "gleichlaufend": "gleichlaufen",
    "gleichlaufende": "gleichlaufend",
    "gleichlaufendem": "gleichlaufend",
    "gleichlaufenden": "gleichlaufend",
    "gleichlaufender": "gleichlaufend",
    "gleichlaufendere": "gleichlaufend",
    "gleichlaufenderem": "gleichlaufend",
    "gleichlaufenderen": "gleichlaufend",
    "gleichlaufenderer": "gleichlaufend",
    "gleichlaufenderes": "gleichlaufend",
    "gleichlaufendes": "gleichlaufend",
    "gleichlaufendste": "gleichlaufend",
    "gleichlaufendstem": "gleichlaufend",
    "gleichlaufendsten": "gleichlaufend",
    "gleichlaufendster": "gleichlaufend",
    "gleichlaufendstes": "gleichlaufend",
    "gleichlaufest": "gleichlaufen",
    "gleichlaufet": "gleichlaufen",
    "gleichlauft": "gleichlaufen",
    "gleichlautende": "gleichlautend",
    "gleichlautendem": "gleichlautend",
    "gleichlautenden": "gleichlautend",
    "gleichlautender": "gleichlautend",
    "gleichlautendes": "gleichlautend",
    "gleichlief": "gleichlaufen",
    "gleichliefe": "gleichlaufen",
    "gleichliefen": "gleichlaufen",
    "gleichliefest": "gleichlaufen",
    "gleichliefet": "gleichlaufen",
    "gleichliefst": "gleichlaufen",
    "gleichlieft": "gleichlaufen",
    "gleichläufst": "gleichlaufen",
    "gleichläuft": "gleichlaufen",
    "gleichmäßige": "gleichmäßig",
    "gleichmäßigem": "gleichmäßig",
    "gleichmäßigen": "gleichmäßig",
    "gleichmäßiger": "gleichmäßig",
    "gleichmäßigere": "gleichmäßig",
    "gleichmäßigerem": "gleichmäßig",
    "gleichmäßigeren": "gleichmäßig",
    "gleichmäßigerer": "gleichmäßig",
    "gleichmäßigeres": "gleichmäßig",
    "gleichmäßiges": "gleichmäßig",
    "gleichmäßigstem": "gleichmäßig",
    "gleichmäßigsten": "gleichmäßig",
    "gleichmäßigster": "gleichmäßig",
    "gleichmäßigstes": "gleichmäßig",
    "gleichmütige": "gleichmütig",
    "gleichmütigem": "gleichmütig",
    "gleichmütigen": "gleichmütig",
    "gleichmütiger": "gleichmütig",
    "gleichmütiges": "gleichmütig",
    "gleichnamige": "gleichnamig",
    "gleichnamigem": "gleichnamig",
    "gleichnamigen": "gleichnamig",
    "gleichnamiger": "gleichnamig",
    "gleichnamiges": "gleichnamig",
    "gleichrangigem": "gleichrangig",
    "gleichrangigen": "gleichrangig",
    "gleichrangiger": "gleichrangig",
    "gleichrangiges": "gleichrangig",
    "gleichschalte": "gleichschalten",
    "gleichschaltend": "gleichschalten",
    "gleichschaltende": "gleichschaltend",
    "gleichschaltendem": "gleichschaltend",
    "gleichschaltenden": "gleichschaltend",
    "gleichschaltender": "gleichschaltend",
    "gleichschaltendere": "gleichschaltend",
    "gleichschaltenderem": "gleichschaltend",
    "gleichschaltenderen": "gleichschaltend",
    "gleichschaltenderer": "gleichschaltend",
    "gleichschaltenderes": "gleichschaltend",
    "gleichschaltendes": "gleichschaltend",
    "gleichschaltendste": "gleichschaltend",
    "gleichschaltendstem": "gleichschaltend",
    "gleichschaltendsten": "gleichschaltend",
    "gleichschaltendster": "gleichschaltend",
    "gleichschaltendstes": "gleichschaltend",
    "gleichschaltest": "gleichschalten",
    "gleichschaltet": "gleichschalten",
    "gleichschaltete": "gleichschalten",
    "gleichschalteten": "gleichschalten",
    "gleichschaltetest": "gleichschalten",
    "gleichschaltetet": "gleichschalten",
    "gleichseitige": "gleichseitig",
    "gleichseitigem": "gleichseitig",
    "gleichseitigen": "gleichseitig",
    "gleichseitiger": "gleichseitig",
    "gleichseitiges": "gleichseitig",
    "gleichsetze": "gleichsetzen",
    "gleichsetzend": "gleichsetzen",
    "gleichsetzende": "gleichsetzend",
    "gleichsetzendem": "gleichsetzend",
    "gleichsetzenden": "gleichsetzend",
    "gleichsetzender": "gleichsetzend",
    "gleichsetzendes": "gleichsetzend",
    "gleichsetzest": "gleichsetzen",
    "gleichsetzet": "gleichsetzen",
    "gleichsetzt": "gleichsetzen",
    "gleichsetzte": "gleichsetzen",
    "gleichsetzten": "gleichsetzen",
    "gleichsetztest": "gleichsetzen",
    "gleichsetztet": "gleichsetzen",
    "gleichst": "gleichen",
    "gleichstand": "gleichstehen",
    "gleichstanden": "gleichstehen",
    "gleichstandest": "gleichstehen",
    "gleichstandet": "gleichstehen",
    "gleichstehe": "gleichstehen",
    "gleichstehend": "gleichstehen",
    "gleichstehende": "gleichstehend",
    "gleichstehendem": "gleichstehend",
    "gleichstehenden": "gleichstehend",
    "gleichstehender": "gleichstehend",
    "gleichstehendes": "gleichstehend",
    "gleichstehest": "gleichstehen",
    "gleichstehet": "gleichstehen",
    "gleichstehst": "gleichstehen",
    "gleichsteht": "gleichstehen",
    "gleichstelle": "gleichstellen",
    "gleichstellend": "gleichstellen",
    "gleichstellende": "gleichstellend",
    "gleichstellendem": "gleichstellend",
    "gleichstellenden": "gleichstellend",
    "gleichstellender": "gleichstellend",
    "gleichstellendere": "gleichstellend",
    "gleichstellenderem": "gleichstellend",
    "gleichstellenderen": "gleichstellend",
    "gleichstellenderer": "gleichstellend",
    "gleichstellenderes": "gleichstellend",
    "gleichstellendes": "gleichstellend",
    "gleichstellendste": "gleichstellend",
    "gleichstellendstem": "gleichstellend",
    "gleichstellendsten": "gleichstellend",
    "gleichstellendster": "gleichstellend",
    "gleichstellendstes": "gleichstellend",
    "gleichstellest": "gleichstellen",
    "gleichstellet": "gleichstellen",
    "gleichstellst": "gleichstellen",
    "gleichstellt": "gleichstellen",
    "gleichstellte": "gleichstellen",
    "gleichstellten": "gleichstellen",
    "gleichstelltest": "gleichstellen",
    "gleichstelltet": "gleichstellen",
    "gleichstimme": "gleichstimmen",
    "gleichstimmend": "gleichstimmen",
    "gleichstimmende": "gleichstimmend",
    "gleichstimmendem": "gleichstimmend",
    "gleichstimmenden": "gleichstimmend",
    "gleichstimmender": "gleichstimmend",
    "gleichstimmendes": "gleichstimmend",
    "gleichstimmest": "gleichstimmen",
    "gleichstimmet": "gleichstimmen",
    "gleichstimmst": "gleichstimmen",
    "gleichstimmt": "gleichstimmen",
    "gleichstimmte": "gleichstimmen",
    "gleichstimmten": "gleichstimmen",
    "gleichstimmtest": "gleichstimmen",
    "gleichstimmtet": "gleichstimmen",
    "gleichstünde": "gleichstehen",
    "gleichstünden": "gleichstehen",
    "gleichstündest": "gleichstehen",
    "gleichstündet": "gleichstehen",
    "gleicht": "gleichen",
    "gleichwertigem": "gleichwertig",
    "gleichwertigen": "gleichwertig",
    "gleichwertiger": "gleichwertig",
    "gleichwertiges": "gleichwertig",
    "gleichzeitigem": "gleichzeitig",
    "gleichzeitigen": "gleichzeitig",
    "gleichzeitiger": "gleichzeitig",
    "gleichzeitiges": "gleichzeitig",
    "gleichziehe": "gleichziehen",
    "gleichziehend": "gleichziehen",
    "gleichziehende": "gleichziehend",
    "gleichziehendem": "gleichziehend",
    "gleichziehenden": "gleichziehend",
    "gleichziehender": "gleichziehend",
    "gleichziehendes": "gleichziehend",
    "gleichziehest": "gleichziehen",
    "gleichziehet": "gleichziehen",
    "gleichziehst": "gleichziehen",
    "gleichzieht": "gleichziehen",
    "gleichzog": "gleichziehen",
    "gleichzogen": "gleichziehen",
    "gleichzogst": "gleichziehen",
    "gleichzogt": "gleichziehen",
    "gleichzulaufen": "gleichlaufen",
    "gleichzuschalten": "gleichschalten",
    "gleichzusetzen": "gleichsetzen",
    "gleichzustehen": "gleichstehen",
    "gleichzustellen": "gleichstellen",
    "gleichzustimmen": "gleichstimmen",
    "gleichzuziehen": "gleichziehen",
    "gleichzöge": "gleichziehen",
    "gleichzögen": "gleichziehen",
    "gleichzögest": "gleichziehen",
    "gleichzöget": "gleichziehen",
    "gleisend": "gleisen",
    "gleisende": "gleisend",
    "gleisendem": "gleisend",
    "gleisenden": "gleisend",
    "gleisender": "gleisend",
    "gleisendes": "gleisend",
    "gleisest": "gleisen",
    "gleiset": "gleisen",
    "gleist": "gleisen",
    "gleiste": "gleisen",
    "gleisten": "gleisen",
    "gleistest": "gleisen",
    "gleistet": "gleisen",
    "gleite": "gleiten",
    "gleitend": "gleiten",
    "gleitende": "gleitend",
    "gleitendem": "gleitend",
    "gleitenden": "gleitend",
    "gleitender": "gleitend",
    "gleitendere": "gleitend",
    "gleitenderem": "gleitend",
    "gleitenderen": "gleitend",
    "gleitenderer": "gleitend",
    "gleitenderes": "gleitend",
    "gleitendes": "gleitend",
    "gleitendste": "gleitend",
    "gleitendstem": "gleitend",
    "gleitendsten": "gleitend",
    "gleitendster": "gleitend",
    "gleitendstes": "gleitend",
    "gleitest": "gleiten",
    "gleitet": "gleiten",
    "glibbere": "glibbern",
    "glibberige": "glibberig",
    "glibberigem": "glibberig",
    "glibberigen": "glibberig",
    "glibberiger": "glibberig",
    "glibberigere": "glibberig",
    "glibberigerem": "glibberig",
    "glibberigeren": "glibberig",
    "glibberigerer": "glibberig",
    "glibberigeres": "glibberig",
    "glibberiges": "glibberig",
    "glibberigste": "glibberig",
    "glibberigstem": "glibberig",
    "glibberigsten": "glibberig",
    "glibberigster": "glibberig",
    "glibberigstes": "glibberig",
    "glibbernd": "glibbern",
    "glibbernde": "glibbernd",
    "glibberndem": "glibbernd",
    "glibbernden": "glibbernd",
    "glibbernder": "glibbernd",
    "glibberndere": "glibbernd",
    "glibbernderem": "glibbernd",
    "glibbernderen": "glibbernd",
    "glibbernderer": "glibbernd",
    "glibbernderes": "glibbernd",
    "glibberndes": "glibbernd",
    "glibberndste": "glibbernd",
    "glibberndstem": "glibbernd",
    "glibberndsten": "glibbernd",
    "glibberndster": "glibbernd",
    "glibberndstes": "glibbernd",
    "glibberst": "glibbern",
    "glibbert": "glibbern",
    "glibberte": "glibbern",
    "glibberten": "glibbern",
    "glibbertest": "glibbern",
    "glibbertet": "glibbern",
    "glich": "gleichen",
    "gliche": "gleichen",
    "glichen": "gleichen",
    "glichest": "gleichen",
    "glichet": "gleichen",
    "glichst": "gleichen",
    "glicht": "gleichen",
    "gliedere": "gliedern",
    "gliedernd": "gliedern",
    "gliedernde": "gliedernd",
    "gliederndem": "gliedernd",
    "gliedernden": "gliedernd",
    "gliedernder": "gliedernd",
    "gliederndes": "gliedernd",
    "gliederst": "gliedern",
    "gliedert": "gliedern",
    "gliederte": "gliedern",
    "gliederten": "gliedern",
    "gliedertest": "gliedern",
    "gliedertet": "gliedern",
    "glimme": "glimmen",
    "glimmend": "glimmen",
    "glimmende": "glimmend",
    "glimmendem": "glimmend",
    "glimmenden": "glimmend",
    "glimmender": "glimmend",
    "glimmendere": "glimmend",
    "glimmenderem": "glimmend",
    "glimmenderen": "glimmend",
    "glimmenderer": "glimmend",
    "glimmenderes": "glimmend",
    "glimmendes": "glimmend",
    "glimmendste": "glimmend",
    "glimmendstem": "glimmend",
    "glimmendsten": "glimmend",
    "glimmendster": "glimmend",
    "glimmendstes": "glimmend",
    "glimmere": "glimmern",
    "glimmerige": "glimmerig",
    "glimmerigem": "glimmerig",
    "glimmerigen": "glimmerig",
    "glimmeriger": "glimmerig",
    "glimmerigere": "glimmerig",
    "glimmerigerem": "glimmerig",
    "glimmerigeren": "glimmerig",
    "glimmerigerer": "glimmerig",
    "glimmerigeres": "glimmerig",
    "glimmeriges": "glimmerig",
    "glimmerigste": "glimmerig",
    "glimmerigstem": "glimmerig",
    "glimmerigsten": "glimmerig",
    "glimmerigster": "glimmerig",
    "glimmerigstes": "glimmerig",
    "glimmernd": "glimmern",
    "glimmernde": "glimmernd",
    "glimmerndem": "glimmernd",
    "glimmernden": "glimmernd",
    "glimmernder": "glimmernd",
    "glimmerndere": "glimmernd",
    "glimmernderem": "glimmernd",
    "glimmernderen": "glimmernd",
    "glimmernderer": "glimmernd",
    "glimmernderes": "glimmernd",
    "glimmerndes": "glimmernd",
    "glimmerndste": "glimmernd",
    "glimmerndstem": "glimmernd",
    "glimmerndsten": "glimmernd",
    "glimmerndster": "glimmernd",
    "glimmerndstes": "glimmernd",
    "glimmerst": "glimmern",
    "glimmert": "glimmern",
    "glimmerte": "glimmern",
    "glimmerten": "glimmern",
    "glimmertest": "glimmern",
    "glimmertet": "glimmern",
    "glimmest": "glimmen",
    "glimmet": "glimmen",
    "glimmst": "glimmen",
    "glimmt": "glimmen",
    "glimpfliche": "glimpflich",
    "glimpflichem": "glimpflich",
    "glimpflichen": "glimpflich",
    "glimpflicher": "glimpflich",
    "glimpflichere": "glimpflich",
    "glimpflicherem": "glimpflich",
    "glimpflicheren": "glimpflich",
    "glimpflicherer": "glimpflich",
    "glimpflicheres": "glimpflich",
    "glimpfliches": "glimpflich",
    "glimpflichste": "glimpflich",
    "glimpflichstem": "glimpflich",
    "glimpflichsten": "glimpflich",
    "glimpflichster": "glimpflich",
    "glimpflichstes": "glimpflich",
    "glitsche": "glitschen",
    "glitschend": "glitschen",
    "glitschende": "glitschend",
    "glitschendem": "glitschend",
    "glitschenden": "glitschend",
    "glitschender": "glitschend",
    "glitschendere": "glitschend",
    "glitschenderem": "glitschend",
    "glitschenderen": "glitschend",
    "glitschenderer": "glitschend",
    "glitschenderes": "glitschend",
    "glitschendes": "glitschend",
    "glitschendste": "glitschend",
    "glitschendstem": "glitschend",
    "glitschendsten": "glitschend",
    "glitschendster": "glitschend",
    "glitschendstes": "glitschend",
    "glitschest": "glitschen",
    "glitschet": "glitschen",
    "glitschige": "glitschig",
    "glitschigem": "glitschig",
    "glitschigen": "glitschig",
    "glitschiger": "glitschig",
    "glitschigere": "glitschig",
    "glitschigerem": "glitschig",
    "glitschigeren": "glitschig",
    "glitschigerer": "glitschig",
    "glitschigeres": "glitschig",
    "glitschiges": "glitschig",
    "glitschigste": "glitschig",
    "glitschigstem": "glitschig",
    "glitschigsten": "glitschig",
    "glitschigster": "glitschig",
    "glitschigstes": "glitschig",
    "glitschst": "glitschen",
    "glitscht": "glitschen",
    "glitschte": "glitschen",
    "glitschten": "glitschen",
    "glitschtest": "glitschen",
    "glitschtet": "glitschen",
    "glitt": "gleiten",
    "glitte": "gleiten",
    "glitten": "gleiten",
    "glittest": "gleiten",
    "glittet": "gleiten",
    "globale": "global",
    "globalem": "global",
    "globalen": "global",
    "globaler": "global",
    "globalere": "global",
    "globalerem": "global",
    "globaleren": "global",
    "globalerer": "global",
    "globaleres": "global",
    "globales": "global",
    "globalste": "global",
    "globalstem": "global",
    "globalsten": "global",
    "globalster": "global",
    "globalstes": "global",
    "glomm": "glimmen",
    "glommen": "glimmen",
    "glommst": "glimmen",
    "glommt": "glimmen",
    "glorifizierend": "glorifizieren",
    "glorifizierende": "glorifizierend",
    "glorifizierendem": "glorifizierend",
    "glorifizierenden": "glorifizierend",
    "glorifizierender": "glorifizierend",
    "glorifizierendere": "glorifizierend",
    "glorifizierenderem": "glorifizierend",
    "glorifizierenderen": "glorifizierend",
    "glorifizierenderer": "glorifizierend",
    "glorifizierenderes": "glorifizierend",
    "glorifizierendes": "glorifizierend",
    "glorifizierendste": "glorifizierend",
    "glorifizierendstem": "glorifizierend",
    "glorifizierendsten": "glorifizierend",
    "glorifizierendster": "glorifizierend",
    "glorifizierendstes": "glorifizierend",
    "glorifizierest": "glorifizieren",
    "glorifizieret": "glorifizieren",
    "glorifizierst": "glorifizieren",
    "glorifiziert": "glorifizieren",
    "glorifizierte": "glorifizieren",
    "glorifiziertem": "glorifiziert",
    "glorifizierten": "glorifizieren",
    "glorifizierter": "glorifiziert",
    "glorifiziertere": "glorifiziert",
    "glorifizierterem": "glorifiziert",
    "glorifizierteren": "glorifiziert",
    "glorifizierterer": "glorifiziert",
    "glorifizierteres": "glorifiziert",
    "glorifiziertes": "glorifiziert",
    "glorifiziertest": "glorifizieren",
    "glorifizierteste": "glorifiziert",
    "glorifiziertestem": "glorifiziert",
    "glorifiziertesten": "glorifiziert",
    "glorifiziertester": "glorifiziert",
    "glorifiziertestes": "glorifiziert",
    "glorifiziertet": "glorifizieren",
    "glotzend": "glotzen",
    "glotzende": "glotzend",
    "glotzendem": "glotzend",
    "glotzenden": "glotzend",
    "glotzender": "glotzend",
    "glotzendere": "glotzend",
    "glotzenderem": "glotzend",
    "glotzenderen": "glotzend",
    "glotzenderer": "glotzend",
    "glotzenderes": "glotzend",
    "glotzendes": "glotzend",
    "glotzendste": "glotzend",
    "glotzendstem": "glotzend",
    "glotzendsten": "glotzend",
    "glotzendster": "glotzend",
    "glotzendstes": "glotzend",
    "glotzest": "glotzen",
    "glotzet": "glotzen",
    "glotzt": "glotzen",
    "glotzte": "glotzen",
    "glotzten": "glotzen",
    "glotztest": "glotzen",
    "glotztet": "glotzen",
    "gluckse": "glucksen",
    "glucksend": "glucksen",
    "glucksende": "glucksend",
    "glucksendem": "glucksend",
    "glucksenden": "glucksend",
    "glucksender": "glucksend",
    "glucksendere": "glucksend",
    "glucksenderem": "glucksend",
    "glucksenderen": "glucksend",
    "glucksenderer": "glucksend",
    "glucksenderes": "glucksend",
    "glucksendes": "glucksend",
    "glucksendste": "glucksend",
    "glucksendstem": "glucksend",
    "glucksendsten": "glucksend",
    "glucksendster": "glucksend",
    "glucksendstes": "glucksend",
    "glucksest": "glucksen",
    "gluckset": "glucksen",
    "gluckst": "glucksen",
    "gluckste": "glucksen",
    "glucksten": "glucksen",
    "gluckstest": "glucksen",
    "gluckstet": "glucksen",
    "glupsche": "glupschen",
    "glupschend": "glupschen",
    "glupschende": "glupschend",
    "glupschendem": "glupschend",
    "glupschenden": "glupschend",
    "glupschender": "glupschend",
    "glupschendere": "glupschend",
    "glupschenderem": "glupschend",
    "glupschenderen": "glupschend",
    "glupschenderer": "glupschend",
    "glupschenderes": "glupschend",
    "glupschendes": "glupschend",
    "glupschendste": "glupschend",
    "glupschendstem": "glupschend",
    "glupschendsten": "glupschend",
    "glupschendster": "glupschend",
    "glupschendstes": "glupschend",
    "glupschest": "glupschen",
    "glupschet": "glupschen",
    "glupschst": "glupschen",
    "glupscht": "glupschen",
    "glupschte": "glupschen",
    "glupschten": "glupschen",
    "glupschtest": "glupschen",
    "glupschtet": "glupschen",
    "glänze": "glänzen",
    "glänzend": "glänzen",
    "glänzende": "glänzend",
    "glänzendem": "glänzend",
    "glänzenden": "glänzend",
    "glänzender": "glänzend",
    "glänzendere": "glänzend",
    "glänzenderem": "glänzend",
    "glänzenderen": "glänzend",
    "glänzenderer": "glänzend",
    "glänzenderes": "glänzend",
    "glänzendes": "glänzend",
    "glänzendste": "glänzend",
    "glänzendstem": "glänzend",
    "glänzendsten": "glänzend",
    "glänzendster": "glänzend",
    "glänzendstes": "glänzend",
    "glänzest": "glänzen",
    "glänzet": "glänzen",
    "glänzt": "glänzen",
    "glänzte": "glänzen",
    "glänzten": "glänzen",
    "glänztest": "glänzen",
    "glänztet": "glänzen",
    "gläsernem": "gläsern",
    "gläsernen": "gläsern",
    "gläserner": "gläsern",
    "gläsernes": "gläsern",
    "glättend": "glätten",
    "glättende": "glättend",
    "glättendem": "glättend",
    "glättenden": "glättend",
    "glättender": "glättend",
    "glättendere": "glättend",
    "glättenderem": "glättend",
    "glättenderen": "glättend",
    "glättenderer": "glättend",
    "glättenderes": "glättend",
    "glättendes": "glättend",
    "glättendste": "glättend",
    "glättendstem": "glättend",
    "glättendsten": "glättend",
    "glättendster": "glättend",
    "glättendstes": "glättend",
    "glättest": "glätten",
    "glättet": "glätten",
    "glättete": "glätten",
    "glätteten": "glätten",
    "glättetest": "glätten",
    "glättetet": "glätten",
    "gläubige": "gläubig",
    "gläubigem": "gläubig",
    "gläubigen": "gläubig",
    "gläubiger": "gläubig",
    "gläubigere": "gläubig",
    "gläubigerem": "gläubig",
    "gläubigeren": "gläubig",
    "gläubigerer": "gläubig",
    "gläubigeres": "gläubig",
    "gläubiges": "gläubig",
    "gläubigstem": "gläubig",
    "gläubigsten": "gläubig",
    "gläubigster": "gläubig",
    "gläubigstes": "gläubig",
    "glömme": "glimmen",
    "glömmen": "glimmen",
    "glömmest": "glimmen",
    "glömmet": "glimmen",
    "glückend": "glücken",
    "glückende": "glückend",
    "glückendem": "glückend",
    "glückenden": "glückend",
    "glückender": "glückend",
    "glückendes": "glückend",
    "glückest": "glücken",
    "glücket": "glücken",
    "glücklichem": "glücklich",
    "glücklichen": "glücklich",
    "glücklicher": "glücklich",
    "glücklichere": "glücklich",
    "glücklicherem": "glücklich",
    "glücklicheren": "glücklich",
    "glücklicherer": "glücklich",
    "glücklicheres": "glücklich",
    "glückliches": "glücklich",
    "glücklichste": "glücklich",
    "glücklichstem": "glücklich",
    "glücklichsten": "glücklich",
    "glücklichster": "glücklich",
    "glücklichstes": "glücklich",
    "glücklose": "glücklos",
    "glücklosem": "glücklos",
    "glücklosen": "glücklos",
    "glückloser": "glücklos",
    "glücklosere": "glücklos",
    "glückloserem": "glücklos",
    "glückloseren": "glücklos",
    "glückloserer": "glücklos",
    "glückloseres": "glücklos",
    "glückloses": "glücklos",
    "glückloseste": "glücklos",
    "glücklosestem": "glücklos",
    "glücklosesten": "glücklos",
    "glücklosester": "glücklos",
    "glücklosestes": "glücklos",
    "glückselige": "glückselig",
    "glückseligem": "glückselig",
    "glückseligen": "glückselig",
    "glückseliger": "glückselig",
    "glückseliges": "glückselig",
    "glückst": "glücken",
    "glückstrahlende": "glückstrahlend",
    "glückstrahlendem": "glückstrahlend",
    "glückstrahlenden": "glückstrahlend",
    "glückstrahlender": "glückstrahlend",
    "glückstrahlendes": "glückstrahlend",
    "glückt": "glücken",
    "glückte": "glücken",
    "glückten": "glücken",
    "glücktest": "glücken",
    "glücktet": "glücken",
    "glühe": "glühen",
    "glühend": "glühen",
    "glühende": "glühend",
    "glühendem": "glühend",
    "glühenden": "glühend",
    "glühender": "glühend",
    "glühendere": "glühend",
    "glühenderem": "glühend",
    "glühenderen": "glühend",
    "glühenderer": "glühend",
    "glühenderes": "glühend",
    "glühendes": "glühend",
    "glühendste": "glühend",
    "glühendstem": "glühend",
    "glühendsten": "glühend",
    "glühendster": "glühend",
    "glühendstes": "glühend",
    "glühest": "glühen",
    "glühet": "glühen",
    "glühst": "glühen",
    "glüht": "glühen",
    "glühte": "glühen",
    "glühten": "glühen",
    "glühtest": "glühen",
    "glühtet": "glühen",
    "gnadenlosem": "gnadenlos",
    "gnadenlosen": "gnadenlos",
    "gnadenloser": "gnadenlos",
    "gnadenlosere": "gnadenlos",
    "gnadenloserem": "gnadenlos",
    "gnadenloseren": "gnadenlos",
    "gnadenloserer": "gnadenlos",
    "gnadenloseres": "gnadenlos",
    "gnadenloses": "gnadenlos",
    "gnadenloseste": "gnadenlos",
    "gnadenlosestem": "gnadenlos",
    "gnadenlosesten": "gnadenlos",
    "gnadenlosester": "gnadenlos",
    "gnadenlosestes": "gnadenlos",
    "gnadenreiche": "gnadenreich",
    "gnadenreichem": "gnadenreich",
    "gnadenreichen": "gnadenreich",
    "gnadenreicher": "gnadenreich",
    "gnadenreiches": "gnadenreich",
    "gnädige": "gnädig",
    "gnädigem": "gnädig",
    "gnädigen": "gnädig",
    "gnädiger": "gnädig",
    "gnädigere": "gnädig",
    "gnädigerem": "gnädig",
    "gnädigeren": "gnädig",
    "gnädigerer": "gnädig",
    "gnädigeres": "gnädig",
    "gnädiges": "gnädig",
    "gnädigste": "gnädig",
    "gnädigstem": "gnädig",
    "gnädigsten": "gnädig",
    "gnädigster": "gnädig",
    "gnädigstes": "gnädig",
    "goldemailliertem": "goldemailliert",
    "goldemaillierten": "goldemailliert",
    "goldemaillierter": "goldemailliert",
    "goldemailliertere": "goldemailliert",
    "goldemaillierterem": "goldemailliert",
    "goldemaillierteren": "goldemailliert",
    "goldemaillierterer": "goldemailliert",
    "goldemaillierteres": "goldemailliert",
    "goldemailliertes": "goldemailliert",
    "goldemaillierteste": "goldemailliert",
    "goldemailliertestem": "goldemailliert",
    "goldemailliertesten": "goldemailliert",
    "goldemailliertester": "goldemailliert",
    "goldemailliertestes": "goldemailliert",
    "goldene": "golden",
    "goldenem": "golden",
    "goldenen": "golden",
    "goldener": "golden",
    "goldenere": "golden",
    "goldenerem": "golden",
    "goldeneren": "golden",
    "goldenerer": "golden",
    "goldeneres": "golden",
    "goldenes": "golden",
    "goldenste": "golden",
    "goldenstem": "golden",
    "goldensten": "golden",
    "goldenster": "golden",
    "goldenstes": "golden",
    "goldigem": "goldig",
    "goldigen": "goldig",
    "goldiger": "goldig",
    "goldigere": "goldig",
    "goldigerem": "goldig",
    "goldigeren": "goldig",
    "goldigerer": "goldig",
    "goldigeres": "goldig",
    "goldiges": "goldig",
    "goldigste": "goldig",
    "goldigstem": "goldig",
    "goldigsten": "goldig",
    "goldigster": "goldig",
    "goldigstes": "goldig",
    "goldrichtigem": "goldrichtig",
    "goldrichtigen": "goldrichtig",
    "goldrichtiger": "goldrichtig",
    "goldrichtiges": "goldrichtig",
    "golfe": "golfen",
    "golfend": "golfen",
    "golfende": "golfend",
    "golfendem": "golfend",
    "golfenden": "golfend",
    "golfender": "golfend",
    "golfendes": "golfend",
    "golfest": "golfen",
    "golfet": "golfen",
    "golfst": "golfen",
    "golft": "golfen",
    "golfte": "golfen",
    "golften": "golfen",
    "golftest": "golfen",
    "golftet": "golfen",
    "gondele": "gondeln",
    "gondelnd": "gondeln",
    "gondelnde": "gondelnd",
    "gondelndem": "gondelnd",
    "gondelnden": "gondelnd",
    "gondelnder": "gondelnd",
    "gondelndere": "gondelnd",
    "gondelnderem": "gondelnd",
    "gondelnderen": "gondelnd",
    "gondelnderer": "gondelnd",
    "gondelnderes": "gondelnd",
    "gondelndes": "gondelnd",
    "gondelndste": "gondelnd",
    "gondelndstem": "gondelnd",
    "gondelndsten": "gondelnd",
    "gondelndster": "gondelnd",
    "gondelndstes": "gondelnd",
    "gondelst": "gondeln",
    "gondelt": "gondeln",
    "gondelte": "gondeln",
    "gondelten": "gondeln",
    "gondeltest": "gondeln",
    "gondeltet": "gondeln",
    "gondle": "gondeln",
    "gongend": "gongen",
    "gongende": "gongend",
    "gongendem": "gongend",
    "gongenden": "gongend",
    "gongender": "gongend",
    "gongendes": "gongend",
    "gongest": "gongen",
    "gonget": "gongen",
    "gongst": "gongen",
    "gongt": "gongen",
    "gongte": "gongen",
    "gongten": "gongen",
    "gongtest": "gongen",
    "gongtet": "gongen",
    "gor": "gären",
    "gordischem": "gordisch",
    "gordischen": "gordisch",
    "gordischer": "gordisch",
    "gordisches": "gordisch",
    "goren": "gären",
    "gorst": "gären",
    "gort": "gären",
    "gossen": "gießen",
    "gotischem": "gotisch",
    "gotischen": "gotisch",
    "gotischer": "gotisch",
    "gotisches": "gotisch",
    "gottesfürchtigem": "gottesfürchtig",
    "gottesfürchtigen": "gottesfürchtig",
    "gottesfürchtiger": "gottesfürchtig",
    "gottesfürchtigere": "gottesfürchtig",
    "gottesfürchtigerem": "gottesfürchtig",
    "gottesfürchtigeren": "gottesfürchtig",
    "gottesfürchtigerer": "gottesfürchtig",
    "gottesfürchtigeres": "gottesfürchtig",
    "gottesfürchtiges": "gottesfürchtig",
    "gottesfürchtigste": "gottesfürchtig",
    "gottesfürchtigstem": "gottesfürchtig",
    "gottesfürchtigsten": "gottesfürchtig",
    "gottesfürchtigster": "gottesfürchtig",
    "gottesfürchtigstes": "gottesfürchtig",
    "gotteslästerliche": "gotteslästerlich",
    "gotteslästerlichem": "gotteslästerlich",
    "gotteslästerlichen": "gotteslästerlich",
    "gotteslästerlicher": "gotteslästerlich",
    "gotteslästerliches": "gotteslästerlich",
    "gottgläubigem": "gottgläubig",
    "gottgläubigen": "gottgläubig",
    "gottgläubiger": "gottgläubig",
    "gottgläubigere": "gottgläubig",
    "gottgläubigerem": "gottgläubig",
    "gottgläubigeren": "gottgläubig",
    "gottgläubigerer": "gottgläubig",
    "gottgläubigeres": "gottgläubig",
    "gottgläubiges": "gottgläubig",
    "gottgläubigste": "gottgläubig",
    "gottgläubigstem": "gottgläubig",
    "gottgläubigsten": "gottgläubig",
    "gottgläubigster": "gottgläubig",
    "gottgläubigstes": "gottgläubig",
    "gottjämmerlichem": "gottjämmerlich",
    "gottjämmerlichen": "gottjämmerlich",
    "gottjämmerlicher": "gottjämmerlich",
    "gottjämmerliches": "gottjämmerlich",
    "gottlose": "gottlos",
    "gottlosem": "gottlos",
    "gottlosen": "gottlos",
    "gottloser": "gottlos",
    "gottlosere": "gottlos",
    "gottloserem": "gottlos",
    "gottloseren": "gottlos",
    "gottloserer": "gottlos",
    "gottloseres": "gottlos",
    "gottloses": "gottlos",
    "gottloseste": "gottlos",
    "gottlosestem": "gottlos",
    "gottlosesten": "gottlos",
    "gottlosester": "gottlos",
    "gottlosestes": "gottlos",
    "goß": "gießen",
    "goßt": "gießen",
    "grabend": "graben",
    "grabende": "grabend",
    "grabendem": "grabend",
    "grabenden": "grabend",
    "grabender": "grabend",
    "grabendere": "grabend",
    "grabenderem": "grabend",
    "grabenderen": "grabend",
    "grabenderer": "grabend",
    "grabenderes": "grabend",
    "grabendes": "grabend",
    "grabendste": "grabend",
    "grabendstem": "grabend",
    "grabendsten": "grabend",
    "grabendster": "grabend",
    "grabendstes": "grabend",
    "grabest": "graben",
    "grabet": "graben",
    "grabsche": "grabschen",
    "grabschend": "grabschen",
    "grabschende": "grabschend",
    "grabschendem": "grabschend",
    "grabschenden": "grabschend",
    "grabschender": "grabschend",
    "grabschendere": "grabschend",
    "grabschenderem": "grabschend",
    "grabschenderen": "grabschend",
    "grabschenderer": "grabschend",
    "grabschenderes": "grabschend",
    "grabschendes": "grabschend",
    "grabschendste": "grabschend",
    "grabschendstem": "grabschend",
    "grabschendsten": "grabschend",
    "grabschendster": "grabschend",
    "grabschendstes": "grabschend",
    "grabschest": "grabschen",
    "grabschet": "grabschen",
    "grabschst": "grabschen",
    "grabscht": "grabschen",
    "grabschte": "grabschen",
    "grabschten": "grabschen",
    "grabschtest": "grabschen",
    "grabschtet": "grabschen",
    "grabt": "graben",
    "gradiere": "gradieren",
    "gradierend": "gradieren",
    "gradierende": "gradierend",
    "gradierendem": "gradierend",
    "gradierenden": "gradierend",
    "gradierender": "gradierend",
    "gradierendes": "gradierend",
    "gradierest": "gradieren",
    "gradieret": "gradieren",
    "gradierst": "gradieren",
    "gradiert": "gradieren",
    "gradierte": "gradieren",
    "gradiertem": "gradiert",
    "gradierten": "gradieren",
    "gradierter": "gradiert",
    "gradiertes": "gradiert",
    "gradiertest": "gradieren",
    "gradiertet": "gradieren",
    "graduellem": "graduell",
    "graduellen": "graduell",
    "gradueller": "graduell",
    "graduelles": "graduell",
    "graduiere": "graduieren",
    "graduierend": "graduieren",
    "graduierende": "graduierend",
    "graduierendem": "graduierend",
    "graduierenden": "graduierend",
    "graduierender": "graduierend",
    "graduierendes": "graduierend",
    "graduierest": "graduieren",
    "graduieret": "graduieren",
    "graduierst": "graduieren",
    "graduiert": "graduieren",
    "graduierte": "graduieren",
    "graduiertem": "graduiert",
    "graduierten": "graduieren",
    "graduierter": "graduiert",
    "graduiertes": "graduiert",
    "graduiertest": "graduieren",
    "graduiertet": "graduieren",
    "gramerfülltem": "gramerfüllt",
    "gramerfüllten": "gramerfüllt",
    "gramerfüllter": "gramerfüllt",
    "gramerfülltere": "gramerfüllt",
    "gramerfüllterem": "gramerfüllt",
    "gramerfüllteren": "gramerfüllt",
    "gramerfüllterer": "gramerfüllt",
    "gramerfüllteres": "gramerfüllt",
    "gramerfülltes": "gramerfüllt",
    "gramerfüllteste": "gramerfüllt",
    "gramerfülltestem": "gramerfüllt",
    "gramerfülltesten": "gramerfüllt",
    "gramerfülltester": "gramerfüllt",
    "gramerfülltestes": "gramerfüllt",
    "grammatikalische": "grammatikalisch",
    "grammatikalischem": "grammatikalisch",
    "grammatikalischen": "grammatikalisch",
    "grammatikalischer": "grammatikalisch",
    "grammatikalisches": "grammatikalisch",
    "grammatischem": "grammatisch",
    "grammatischen": "grammatisch",
    "grammatischer": "grammatisch",
    "grammatisches": "grammatisch",
    "gramvolle": "gramvoll",
    "gramvollem": "gramvoll",
    "gramvollen": "gramvoll",
    "gramvoller": "gramvoll",
    "gramvollere": "gramvoll",
    "gramvollerem": "gramvoll",
    "gramvolleren": "gramvoll",
    "gramvollerer": "gramvoll",
    "gramvolleres": "gramvoll",
    "gramvolles": "gramvoll",
    "gramvollste": "gramvoll",
    "gramvollstem": "gramvoll",
    "gramvollsten": "gramvoll",
    "gramvollster": "gramvoll",
    "gramvollstes": "gramvoll",
    "grandiosem": "grandios",
    "grandiosen": "grandios",
    "grandioser": "grandios",
    "grandiosere": "grandios",
    "grandioserem": "grandios",
    "grandioseren": "grandios",
    "grandioserer": "grandios",
    "grandioseres": "grandios",
    "grandioses": "grandios",
    "grandioseste": "grandios",
    "grandiosestem": "grandios",
    "grandiosesten": "grandios",
    "grandiosester": "grandios",
    "grandiosestes": "grandios",
    "grantigem": "grantig",
    "grantigen": "grantig",
    "grantiger": "grantig",
    "grantigere": "grantig",
    "grantigerem": "grantig",
    "grantigeren": "grantig",
    "grantigerer": "grantig",
    "grantigeres": "grantig",
    "grantiges": "grantig",
    "grantigste": "grantig",
    "grantigstem": "grantig",
    "grantigsten": "grantig",
    "grantigster": "grantig",
    "grantigstes": "grantig",
    "graphischem": "graphisch",
    "graphischen": "graphisch",
    "graphischer": "graphisch",
    "graphisches": "graphisch",
    "graphologischem": "graphologisch",
    "graphologischen": "graphologisch",
    "graphologischer": "graphologisch",
    "graphologisches": "graphologisch",
    "grasend": "grasen",
    "grasende": "grasend",
    "grasendem": "grasend",
    "grasenden": "grasend",
    "grasender": "grasend",
    "grasendes": "grasend",
    "grasest": "grasen",
    "graset": "grasen",
    "grassiere": "grassieren",
    "grassierend": "grassieren",
    "grassierende": "grassierend",
    "grassierendem": "grassierend",
    "grassierenden": "grassierend",
    "grassierender": "grassierend",
    "grassierendere": "grassierend",
    "grassierenderem": "grassierend",
    "grassierenderen": "grassierend",
    "grassierenderer": "grassierend",
    "grassierenderes": "grassierend",
    "grassierendes": "grassierend",
    "grassierendste": "grassierend",
    "grassierendstem": "grassierend",
    "grassierendsten": "grassierend",
    "grassierendster": "grassierend",
    "grassierendstes": "grassierend",
    "grassierest": "grassieren",
    "grassieret": "grassieren",
    "grassierst": "grassieren",
    "grassiert": "grassieren",
    "grassierte": "grassieren",
    "grassiertem": "grassiert",
    "grassierten": "grassieren",
    "grassierter": "grassiert",
    "grassiertere": "grassiert",
    "grassierterem": "grassiert",
    "grassierteren": "grassiert",
    "grassierterer": "grassiert",
    "grassierteres": "grassiert",
    "grassiertes": "grassiert",
    "grassiertest": "grassieren",
    "grassierteste": "grassiert",
    "grassiertestem": "grassiert",
    "grassiertesten": "grassiert",
    "grassiertester": "grassiert",
    "grassiertestes": "grassiert",
    "grassiertet": "grassieren",
    "grast": "grasen",
    "graste": "grasen",
    "grasten": "grasen",
    "grastest": "grasen",
    "grastet": "grasen",
    "gratifiziere": "gratifizieren",
    "gratifizierend": "gratifizieren",
    "gratifizierende": "gratifizierend",
    "gratifizierendem": "gratifizierend",
    "gratifizierenden": "gratifizierend",
    "gratifizierender": "gratifizierend",
    "gratifizierendes": "gratifizierend",
    "gratifizierest": "gratifizieren",
    "gratifizieret": "gratifizieren",
    "gratifizierst": "gratifizieren",
    "gratifiziert": "gratifizieren",
    "gratifizierte": "gratifizieren",
    "gratifiziertem": "gratifiziert",
    "gratifizierten": "gratifizieren",
    "gratifizierter": "gratifiziert",
    "gratifiziertes": "gratifiziert",
    "gratifiziertest": "gratifizieren",
    "gratifiziertet": "gratifizieren",
    "gratiniere": "gratinieren",
    "gratinierend": "gratinieren",
    "gratinierende": "gratinierend",
    "gratinierendem": "gratinierend",
    "gratinierenden": "gratinierend",
    "gratinierender": "gratinierend",
    "gratinierendere": "gratinierend",
    "gratinierenderem": "gratinierend",
    "gratinierenderen": "gratinierend",
    "gratinierenderer": "gratinierend",
    "gratinierenderes": "gratinierend",
    "gratinierendes": "gratinierend",
    "gratinierendste": "gratinierend",
    "gratinierendstem": "gratinierend",
    "gratinierendsten": "gratinierend",
    "gratinierendster": "gratinierend",
    "gratinierendstes": "gratinierend",
    "gratinierest": "gratinieren",
    "gratinieret": "gratinieren",
    "gratinierst": "gratinieren",
    "gratiniert": "gratinieren",
    "gratinierte": "gratinieren",
    "gratiniertem": "gratiniert",
    "gratinierten": "gratinieren",
    "gratinierter": "gratiniert",
    "gratiniertes": "gratiniert",
    "gratiniertest": "gratinieren",
    "gratiniertet": "gratinieren",
    "gratuliere": "gratulieren",
    "gratulierend": "gratulieren",
    "gratulierende": "gratulierend",
    "gratulierendem": "gratulierend",
    "gratulierenden": "gratulierend",
    "gratulierender": "gratulierend",
    "gratulierendes": "gratulierend",
    "gratulierest": "gratulieren",
    "gratulieret": "gratulieren",
    "gratulierst": "gratulieren",
    "gratuliert": "gratulieren",
    "gratulierte": "gratulieren",
    "gratuliertem": "gratuliert",
    "gratulierten": "gratulieren",
    "gratulierter": "gratuliert",
    "gratuliertes": "gratuliert",
    "gratuliertest": "gratulieren",
    "gratuliertet": "gratulieren",
    "graue": "grau",
    "grauem": "grau",
    "grauen": "grau",
    "grauenerregendem": "grauenerregend",
    "grauenerregenden": "grauenerregend",
    "grauenerregender": "grauenerregend",
    "grauenerregendere": "grauenerregend",
    "grauenerregenderem": "grauenerregend",
    "grauenerregenderen": "grauenerregend",
    "grauenerregenderer": "grauenerregend",
    "grauenerregenderes": "grauenerregend",
    "grauenerregendes": "grauenerregend",
    "grauenerregendste": "grauenerregend",
    "grauenerregendstem": "grauenerregend",
    "grauenerregendsten": "grauenerregend",
    "grauenerregendster": "grauenerregend",
    "grauenerregendstes": "grauenerregend",
    "grauenhafte": "grauenhaft",
    "grauenhaftem": "grauenhaft",
    "grauenhaften": "grauenhaft",
    "grauenhafter": "grauenhaft",
    "grauenhaftere": "grauenhaft",
    "grauenhafterem": "grauenhaft",
    "grauenhafteren": "grauenhaft",
    "grauenhafterer": "grauenhaft",
    "grauenhafteres": "grauenhaft",
    "grauenhaftes": "grauenhaft",
    "grauenhafteste": "grauenhaft",
    "grauenhaftestem": "grauenhaft",
    "grauenhaftesten": "grauenhaft",
    "grauenhaftester": "grauenhaft",
    "grauenhaftestes": "grauenhaft",
    "grauer": "grau",
    "grauere": "grau",
    "grauerem": "grau",
    "graueren": "grau",
    "grauerer": "grau",
    "graueres": "grau",
    "graues": "grau",
    "graueste": "grau",
    "grauestem": "grau",
    "grauesten": "grau",
    "grauester": "grau",
    "grauestes": "grau",
    "grauhaarige": "grauhaarig",
    "grauhaarigem": "grauhaarig",
    "grauhaarigen": "grauhaarig",
    "grauhaariger": "grauhaarig",
    "grauhaariges": "grauhaarig",
    "graule": "graulen",
    "graulend": "graulen",
    "graulende": "graulend",
    "graulendem": "graulend",
    "graulenden": "graulend",
    "graulender": "graulend",
    "graulendes": "graulend",
    "graulest": "graulen",
    "graulet": "graulen",
    "grauliche": "graulich",
    "graulichem": "graulich",
    "graulichen": "graulich",
    "graulicher": "graulich",
    "graulichere": "graulich",
    "graulicherem": "graulich",
    "graulicheren": "graulich",
    "graulicherer": "graulich",
    "graulicheres": "graulich",
    "grauliches": "graulich",
    "graulichste": "graulich",
    "graulichstem": "graulich",
    "graulichsten": "graulich",
    "graulichster": "graulich",
    "graulichstes": "graulich",
    "graulst": "graulen",
    "grault": "graulen",
    "graulte": "graulen",
    "graulten": "graulen",
    "graultest": "graulen",
    "graultet": "graulen",
    "graumelierte": "graumeliert",
    "graumeliertem": "graumeliert",
    "graumelierten": "graumeliert",
    "graumelierter": "graumeliert",
    "graumeliertes": "graumeliert",
    "graupele": "graupeln",
    "graupelnd": "graupeln",
    "graupelnde": "graupelnd",
    "graupelndem": "graupelnd",
    "graupelnden": "graupelnd",
    "graupelnder": "graupelnd",
    "graupelndere": "graupelnd",
    "graupelnderem": "graupelnd",
    "graupelnderen": "graupelnd",
    "graupelnderer": "graupelnd",
    "graupelnderes": "graupelnd",
    "graupelndes": "graupelnd",
    "graupelndste": "graupelnd",
    "graupelndstem": "graupelnd",
    "graupelndsten": "graupelnd",
    "graupelndster": "graupelnd",
    "graupelndstes": "graupelnd",
    "graupelst": "graupeln",
    "graupelt": "graupeln",
    "graupelte": "graupeln",
    "graupelten": "graupeln",
    "graupeltest": "graupeln",
    "graupeltet": "graupeln",
    "grauple": "graupeln",
    "grausamem": "grausam",
    "grausamen": "grausam",
    "grausamer": "grausam",
    "grausamere": "grausam",
    "grausamerem": "grausam",
    "grausameren": "grausam",
    "grausamerer": "grausam",
    "grausameres": "grausam",
    "grausames": "grausam",
    "grausamste": "grausam",
    "grausamstem": "grausam",
    "grausamsten": "grausam",
    "grausamster": "grausam",
    "grausamstes": "grausam",
    "grause": "grausen",
    "grausend": "grausen",
    "grausende": "grausend",
    "grausendem": "grausend",
    "grausenden": "grausend",
    "grausender": "grausend",
    "grausendes": "grausend",
    "grausest": "grausen",
    "grauset": "grausen",
    "grausige": "grausig",
    "grausigem": "grausig",
    "grausigen": "grausig",
    "grausiger": "grausig",
    "grausigere": "grausig",
    "grausigerem": "grausig",
    "grausigeren": "grausig",
    "grausigerer": "grausig",
    "grausigeres": "grausig",
    "grausiges": "grausig",
    "grausigste": "grausig",
    "grausigstem": "grausig",
    "grausigsten": "grausig",
    "grausigster": "grausig",
    "grausigstes": "grausig",
    "graust": "grausen",
    "grauste": "grausen",
    "grausten": "grausen",
    "graustest": "grausen",
    "graustet": "grausen",
    "gravierendem": "gravierend",
    "gravierenden": "gravierend",
    "gravierender": "gravierend",
    "gravierendere": "gravierend",
    "gravierenderem": "gravierend",
    "gravierenderen": "gravierend",
    "gravierenderer": "gravierend",
    "gravierenderes": "gravierend",
    "gravierendes": "gravierend",
    "gravierendste": "gravierend",
    "gravierendstem": "gravierend",
    "gravierendsten": "gravierend",
    "gravierendster": "gravierend",
    "gravierendstes": "gravierend",
    "grazile": "grazil",
    "grazilem": "grazil",
    "grazilen": "grazil",
    "graziler": "grazil",
    "grazilere": "grazil",
    "grazilerem": "grazil",
    "grazileren": "grazil",
    "grazilerer": "grazil",
    "grazileres": "grazil",
    "graziles": "grazil",
    "grazilste": "grazil",
    "grazilstem": "grazil",
    "grazilsten": "grazil",
    "grazilster": "grazil",
    "grazilstes": "grazil",
    "graziöse": "graziös",
    "graziösem": "graziös",
    "graziösen": "graziös",
    "graziöser": "graziös",
    "graziösere": "graziös",
    "graziöserem": "graziös",
    "graziöseren": "graziös",
    "graziöserer": "graziös",
    "graziöseres": "graziös",
    "graziöses": "graziös",
    "graziöseste": "graziös",
    "graziösestem": "graziös",
    "graziösesten": "graziös",
    "graziösester": "graziös",
    "graziösestes": "graziös",
    "greifbarem": "greifbar",
    "greifbaren": "greifbar",
    "greifbarer": "greifbar",
    "greifbarere": "greifbar",
    "greifbarerem": "greifbar",
    "greifbareren": "greifbar",
    "greifbarerer": "greifbar",
    "greifbareres": "greifbar",
    "greifbares": "greifbar",
    "greifbarste": "greifbar",
    "greifbarstem": "greifbar",
    "greifbarsten": "greifbar",
    "greifbarster": "greifbar",
    "greifbarstes": "greifbar",
    "greife": "greifen",
    "greifend": "greifen",
    "greifende": "greifend",
    "greifendem": "greifend",
    "greifenden": "greifend",
    "greifender": "greifend",
    "greifendes": "greifend",
    "greifest": "greifen",
    "greifet": "greifen",
    "greifst": "greifen",
    "greift": "greifen",
    "greise": "greis",
    "greisem": "greis",
    "greisen": "greis",
    "greisenhaftem": "greisenhaft",
    "greisenhaften": "greisenhaft",
    "greisenhafter": "greisenhaft",
    "greisenhaftere": "greisenhaft",
    "greisenhafterem": "greisenhaft",
    "greisenhafteren": "greisenhaft",
    "greisenhafterer": "greisenhaft",
    "greisenhafteres": "greisenhaft",
    "greisenhaftes": "greisenhaft",
    "greisenhafteste": "greisenhaft",
    "greisenhaftestem": "greisenhaft",
    "greisenhaftesten": "greisenhaft",
    "greisenhaftester": "greisenhaft",
    "greisenhaftestes": "greisenhaft",
    "greiser": "greis",
    "greisere": "greis",
    "greiserem": "greis",
    "greiseren": "greis",
    "greiserer": "greis",
    "greiseres": "greis",
    "greises": "greis",
    "greiseste": "greis",
    "greisestem": "greis",
    "greisesten": "greis",
    "greisester": "greis",
    "greisestes": "greis",
    "grellem": "grell",
    "grellen": "grell",
    "greller": "grell",
    "grellere": "grell",
    "grellerem": "grell",
    "grelleren": "grell",
    "grellerer": "grell",
    "grelleres": "grell",
    "grelles": "grell",
    "grellste": "grell",
    "grellstem": "grell",
    "grellsten": "grell",
    "grellster": "grell",
    "grellstes": "grell",
    "grenzend": "grenzen",
    "grenzende": "grenzend",
    "grenzendem": "grenzend",
    "grenzenden": "grenzend",
    "grenzender": "grenzend",
    "grenzendes": "grenzend",
    "grenzenlose": "grenzenlos",
    "grenzenlosem": "grenzenlos",
    "grenzenlosen": "grenzenlos",
    "grenzenloser": "grenzenlos",
    "grenzenlosere": "grenzenlos",
    "grenzenloserem": "grenzenlos",
    "grenzenloseren": "grenzenlos",
    "grenzenloserer": "grenzenlos",
    "grenzenloseres": "grenzenlos",
    "grenzenloses": "grenzenlos",
    "grenzenloseste": "grenzenlos",
    "grenzenlosestem": "grenzenlos",
    "grenzenlosesten": "grenzenlos",
    "grenzenlosester": "grenzenlos",
    "grenzenlosestes": "grenzenlos",
    "grenzest": "grenzen",
    "grenzet": "grenzen",
    "grenzt": "grenzen",
    "grenzte": "grenzen",
    "grenzten": "grenzen",
    "grenztest": "grenzen",
    "grenztet": "grenzen",
    "grenzüberschreitendem": "grenzüberschreitend",
    "grenzüberschreitenden": "grenzüberschreitend",
    "grenzüberschreitender": "grenzüberschreitend",
    "grenzüberschreitendes": "grenzüberschreitend",
    "griechischem": "griechisch",
    "griechischen": "griechisch",
    "griechischer": "griechisch",
    "griechisches": "griechisch",
    "griffbereite": "griffbereit",
    "griffbereitem": "griffbereit",
    "griffbereiten": "griffbereit",
    "griffbereiter": "griffbereit",
    "griffbereites": "griffbereit",
    "griffe": "greifen",
    "griffest": "greifen",
    "griffet": "greifen",
    "griffige": "griffig",
    "griffigem": "griffig",
    "griffigen": "griffig",
    "griffiger": "griffig",
    "griffigere": "griffig",
    "griffigerem": "griffig",
    "griffigeren": "griffig",
    "griffigerer": "griffig",
    "griffigeres": "griffig",
    "griffiges": "griffig",
    "griffigste": "griffig",
    "griffigstem": "griffig",
    "griffigsten": "griffig",
    "griffigster": "griffig",
    "griffigstes": "griffig",
    "griffst": "greifen",
    "grifft": "greifen",
    "grillend": "grillen",
    "grillende": "grillend",
    "grillendem": "grillend",
    "grillenden": "grillend",
    "grillender": "grillend",
    "grillendes": "grillend",
    "grillest": "grillen",
    "grillet": "grillen",
    "grillst": "grillen",
    "grillt": "grillen",
    "grillte": "grillen",
    "grillten": "grillen",
    "grilltest": "grillen",
    "grilltet": "grillen",
    "grimmigem": "grimmig",
    "grimmigen": "grimmig",
    "grimmiger": "grimmig",
    "grimmigere": "grimmig",
    "grimmigerem": "grimmig",
    "grimmigeren": "grimmig",
    "grimmigerer": "grimmig",
    "grimmigeres": "grimmig",
    "grimmiges": "grimmig",
    "grimmigste": "grimmig",
    "grimmigstem": "grimmig",
    "grimmigsten": "grimmig",
    "grimmigster": "grimmig",
    "grimmigstes": "grimmig",
    "grinse": "grinsen",
    "grinsend": "grinsen",
    "grinsende": "grinsend",
    "grinsendem": "grinsend",
    "grinsenden": "grinsend",
    "grinsender": "grinsend",
    "grinsendere": "grinsend",
    "grinsenderem": "grinsend",
    "grinsenderen": "grinsend",
    "grinsenderer": "grinsend",
    "grinsenderes": "grinsend",
    "grinsendes": "grinsend",
    "grinsendste": "grinsend",
    "grinsendstem": "grinsend",
    "grinsendsten": "grinsend",
    "grinsendster": "grinsend",
    "grinsendstes": "grinsend",
    "grinsest": "grinsen",
    "grinset": "grinsen",
    "grinst": "grinsen",
    "grinste": "grinsen",
    "grinsten": "grinsen",
    "grinstest": "grinsen",
    "grinstet": "grinsen",
    "grippale": "grippal",
    "grippalem": "grippal",
    "grippalen": "grippal",
    "grippaler": "grippal",
    "grippales": "grippal",
    "grobem": "grob",
    "groben": "grob",
    "grober": "grob",
    "grobes": "grob",
    "grobkörnigem": "grobkörnig",
    "grobkörnigen": "grobkörnig",
    "grobkörniger": "grobkörnig",
    "grobkörnigere": "grobkörnig",
    "grobkörnigerem": "grobkörnig",
    "grobkörnigeren": "grobkörnig",
    "grobkörnigerer": "grobkörnig",
    "grobkörnigeres": "grobkörnig",
    "grobkörniges": "grobkörnig",
    "grobkörnigste": "grobkörnig",
    "grobkörnigstem": "grobkörnig",
    "grobkörnigsten": "grobkörnig",
    "grobkörnigster": "grobkörnig",
    "grobkörnigstes": "grobkörnig",
    "grobschlächtige": "grobschlächtig",
    "grobschlächtigem": "grobschlächtig",
    "grobschlächtigen": "grobschlächtig",
    "grobschlächtiger": "grobschlächtig",
    "grobschlächtigere": "grobschlächtig",
    "grobschlächtigerem": "grobschlächtig",
    "grobschlächtigeren": "grobschlächtig",
    "grobschlächtigerer": "grobschlächtig",
    "grobschlächtigeres": "grobschlächtig",
    "grobschlächtiges": "grobschlächtig",
    "grobschlächtigste": "grobschlächtig",
    "grobschlächtigstem": "grobschlächtig",
    "grobschlächtigsten": "grobschlächtig",
    "grobschlächtigster": "grobschlächtig",
    "grobschlächtigstes": "grobschlächtig",
    "groteske": "grotesk",
    "groteskem": "grotesk",
    "grotesken": "grotesk",
    "grotesker": "grotesk",
    "groteskere": "grotesk",
    "groteskerem": "grotesk",
    "groteskeren": "grotesk",
    "groteskerer": "grotesk",
    "groteskeres": "grotesk",
    "groteskes": "grotesk",
    "groteskeste": "grotesk",
    "groteskestem": "grotesk",
    "groteskesten": "grotesk",
    "groteskester": "grotesk",
    "groteskestes": "grotesk",
    "großartigem": "großartig",
    "großartigen": "großartig",
    "großartiger": "großartig",
    "großartigere": "großartig",
    "großartigerem": "großartig",
    "großartigeren": "großartig",
    "großartigerer": "großartig",
    "großartigeres": "großartig",
    "großartiges": "großartig",
    "großartigste": "großartig",
    "großartigstem": "großartig",
    "großartigsten": "großartig",
    "großartigster": "großartig",
    "großartigstes": "großartig",
    "großdeutschem": "großdeutsch",
    "großdeutschen": "großdeutsch",
    "großdeutscher": "großdeutsch",
    "großdeutsches": "großdeutsch",
    "große": "groß",
    "großem": "groß",
    "großen": "groß",
    "großer": "groß",
    "großes": "groß",
    "großflächigem": "großflächig",
    "großflächigen": "großflächig",
    "großflächiger": "großflächig",
    "großflächiges": "großflächig",
    "großherzigem": "großherzig",
    "großherzigen": "großherzig",
    "großherziger": "großherzig",
    "großherzigere": "großherzig",
    "großherzigerem": "großherzig",
    "großherzigeren": "großherzig",
    "großherzigerer": "großherzig",
    "großherzigeres": "großherzig",
    "großherziges": "großherzig",
    "großherzigste": "großherzig",
    "großherzigstem": "großherzig",
    "großherzigsten": "großherzig",
    "großherzigster": "großherzig",
    "großherzigstes": "großherzig",
    "großkalibrigem": "großkalibrig",
    "großkalibrigen": "großkalibrig",
    "großkalibriger": "großkalibrig",
    "großkalibriges": "großkalibrig",
    "großkotzigem": "großkotzig",
    "großkotzigen": "großkotzig",
    "großkotziger": "großkotzig",
    "großkotzigere": "großkotzig",
    "großkotzigerem": "großkotzig",
    "großkotzigeren": "großkotzig",
    "großkotzigerer": "großkotzig",
    "großkotzigeres": "großkotzig",
    "großkotziges": "großkotzig",
    "großkotzigste": "großkotzig",
    "großkotzigstem": "großkotzig",
    "großkotzigsten": "großkotzig",
    "großkotzigster": "großkotzig",
    "großkotzigstes": "großkotzig",
    "großmächtigem": "großmächtig",
    "großmächtigen": "großmächtig",
    "großmächtiger": "großmächtig",
    "großmächtiges": "großmächtig",
    "großmäuligem": "großmäulig",
    "großmäuligen": "großmäulig",
    "großmäuliger": "großmäulig",
    "großmäuligere": "großmäulig",
    "großmäuligerem": "großmäulig",
    "großmäuligeren": "großmäulig",
    "großmäuligerer": "großmäulig",
    "großmäuligeres": "großmäulig",
    "großmäuliges": "großmäulig",
    "großmäuligste": "großmäulig",
    "großmäuligstem": "großmäulig",
    "großmäuligsten": "großmäulig",
    "großmäuligster": "großmäulig",
    "großmäuligstes": "großmäulig",
    "großmütigem": "großmütig",
    "großmütigen": "großmütig",
    "großmütiger": "großmütig",
    "großmütigere": "großmütig",
    "großmütigerem": "großmütig",
    "großmütigeren": "großmütig",
    "großmütigerer": "großmütig",
    "großmütigeres": "großmütig",
    "großmütiges": "großmütig",
    "großmütigste": "großmütig",
    "großmütigstem": "großmütig",
    "großmütigsten": "großmütig",
    "großmütigster": "großmütig",
    "großmütigstes": "großmütig",
    "großmütterlichem": "großmütterlich",
    "großmütterlichen": "großmütterlich",
    "großmütterlicher": "großmütterlich",
    "großmütterliches": "großmütterlich",
    "großschnauzigem": "großschnauzig",
    "großschnauzigen": "großschnauzig",
    "großschnauziger": "großschnauzig",
    "großschnauzigere": "großschnauzig",
    "großschnauzigerem": "großschnauzig",
    "großschnauzigeren": "großschnauzig",
    "großschnauzigerer": "großschnauzig",
    "großschnauzigeres": "großschnauzig",
    "großschnauziges": "großschnauzig",
    "großschnauzigste": "großschnauzig",
    "großschnauzigstem": "großschnauzig",
    "großschnauzigsten": "großschnauzig",
    "großschnauzigster": "großschnauzig",
    "großschnauzigstes": "großschnauzig",
    "großspurigem": "großspurig",
    "großspurigen": "großspurig",
    "großspuriger": "großspurig",
    "großspurigere": "großspurig",
    "großspurigerem": "großspurig",
    "großspurigeren": "großspurig",
    "großspurigerer": "großspurig",
    "großspurigeres": "großspurig",
    "großspuriges": "großspurig",
    "großspurigste": "großspurig",
    "großspurigstem": "großspurig",
    "großspurigsten": "großspurig",
    "großspurigster": "großspurig",
    "großspurigstes": "großspurig",
    "großväterlichem": "großväterlich",
    "großväterlichen": "großväterlich",
    "großväterlicher": "großväterlich",
    "großväterliches": "großväterlich",
    "großzügigem": "großzügig",
    "großzügigen": "großzügig",
    "großzügiger": "großzügig",
    "großzügigere": "großzügig",
    "großzügigerem": "großzügig",
    "großzügigeren": "großzügig",
    "großzügigerer": "großzügig",
    "großzügigeres": "großzügig",
    "großzügiges": "großzügig",
    "großzügigstem": "großzügig",
    "großzügigsten": "großzügig",
    "großzügigster": "großzügig",
    "großzügigstes": "großzügig",
    "grub": "graben",
    "gruben": "graben",
    "grubst": "graben",
    "grubt": "graben",
    "grummele": "grummeln",
    "grummelnd": "grummeln",
    "grummelnde": "grummelnd",
    "grummelndem": "grummelnd",
    "grummelnden": "grummelnd",
    "grummelnder": "grummelnd",
    "grummelndere": "grummelnd",
    "grummelnderem": "grummelnd",
    "grummelnderen": "grummelnd",
    "grummelnderer": "grummelnd",
    "grummelnderes": "grummelnd",
    "grummelndes": "grummelnd",
    "grummelndste": "grummelnd",
    "grummelndstem": "grummelnd",
    "grummelndsten": "grummelnd",
    "grummelndster": "grummelnd",
    "grummelndstes": "grummelnd",
    "grummelst": "grummeln",
    "grummelt": "grummeln",
    "grummelte": "grummeln",
    "grummelten": "grummeln",
    "grummeltest": "grummeln",
    "grummeltet": "grummeln",
    "grummle": "grummeln",
    "grundanständigem": "grundanständig",
    "grundanständigen": "grundanständig",
    "grundanständiger": "grundanständig",
    "grundanständigere": "grundanständig",
    "grundanständigerem": "grundanständig",
    "grundanständigeren": "grundanständig",
    "grundanständigerer": "grundanständig",
    "grundanständigeres": "grundanständig",
    "grundanständiges": "grundanständig",
    "grundanständigste": "grundanständig",
    "grundanständigstem": "grundanständig",
    "grundanständigsten": "grundanständig",
    "grundanständigster": "grundanständig",
    "grundanständigstes": "grundanständig",
    "grundehrliche": "grundehrlich",
    "grundehrlichem": "grundehrlich",
    "grundehrlichen": "grundehrlich",
    "grundehrlicher": "grundehrlich",
    "grundehrlichere": "grundehrlich",
    "grundehrlicherem": "grundehrlich",
    "grundehrlicheren": "grundehrlich",
    "grundehrlicherer": "grundehrlich",
    "grundehrlicheres": "grundehrlich",
    "grundehrliches": "grundehrlich",
    "grundehrlichste": "grundehrlich",
    "grundehrlichstem": "grundehrlich",
    "grundehrlichsten": "grundehrlich",
    "grundehrlichster": "grundehrlich",
    "grundehrlichstes": "grundehrlich",
    "grundfalsche": "grundfalsch",
    "grundfalschem": "grundfalsch",
    "grundfalschen": "grundfalsch",
    "grundfalscher": "grundfalsch",
    "grundfalsches": "grundfalsch",
    "grundgütigem": "grundgütig",
    "grundgütigen": "grundgütig",
    "grundgütiger": "grundgütig",
    "grundgütiges": "grundgütig",
    "grundhäßliche": "grundhäßlich",
    "grundhäßlichem": "grundhäßlich",
    "grundhäßlichen": "grundhäßlich",
    "grundhäßlicher": "grundhäßlich",
    "grundhäßliches": "grundhäßlich",
    "grundlegendem": "grundlegend",
    "grundlegenden": "grundlegend",
    "grundlegender": "grundlegend",
    "grundlegendere": "grundlegend",
    "grundlegenderem": "grundlegend",
    "grundlegenderen": "grundlegend",
    "grundlegenderer": "grundlegend",
    "grundlegenderes": "grundlegend",
    "grundlegendes": "grundlegend",
    "grundlegendste": "grundlegend",
    "grundlegendstem": "grundlegend",
    "grundlegendsten": "grundlegend",
    "grundlegendster": "grundlegend",
    "grundlegendstes": "grundlegend",
    "grundlose": "grundlos",
    "grundlosem": "grundlos",
    "grundlosen": "grundlos",
    "grundloser": "grundlos",
    "grundloses": "grundlos",
    "grundschlechte": "grundschlecht",
    "grundschlechtem": "grundschlecht",
    "grundschlechten": "grundschlecht",
    "grundschlechter": "grundschlecht",
    "grundschlechtes": "grundschlecht",
    "grundsätzlichem": "grundsätzlich",
    "grundsätzlichen": "grundsätzlich",
    "grundsätzlicher": "grundsätzlich",
    "grundsätzliches": "grundsätzlich",
    "grundverkehrtem": "grundverkehrt",
    "grundverkehrten": "grundverkehrt",
    "grundverkehrter": "grundverkehrt",
    "grundverkehrtes": "grundverkehrt",
    "grundverschiedene": "grundverschieden",
    "grundverschiedenem": "grundverschieden",
    "grundverschiedenen": "grundverschieden",
    "grundverschiedener": "grundverschieden",
    "grundverschiedenes": "grundverschieden",
    "grunze": "grunzen",
    "grunzend": "grunzen",
    "grunzende": "grunzend",
    "grunzendem": "grunzend",
    "grunzenden": "grunzend",
    "grunzender": "grunzend",
    "grunzendere": "grunzend",
    "grunzenderem": "grunzend",
    "grunzenderen": "grunzend",
    "grunzenderer": "grunzend",
    "grunzenderes": "grunzend",
    "grunzendes": "grunzend",
    "grunzendste": "grunzend",
    "grunzendstem": "grunzend",
    "grunzendsten": "grunzend",
    "grunzendster": "grunzend",
    "grunzendstes": "grunzend",
    "grunzest": "grunzen",
    "grunzet": "grunzen",
    "grunzt": "grunzen",
    "grunzte": "grunzen",
    "grunzten": "grunzen",
    "grunztest": "grunzen",
    "grunztet": "grunzen",
    "gruppendynamischem": "gruppendynamisch",
    "gruppendynamischen": "gruppendynamisch",
    "gruppendynamischer": "gruppendynamisch",
    "gruppendynamisches": "gruppendynamisch",
    "gruppenspezifische": "gruppenspezifisch",
    "gruppenspezifischem": "gruppenspezifisch",
    "gruppenspezifischen": "gruppenspezifisch",
    "gruppenspezifischer": "gruppenspezifisch",
    "gruppenspezifisches": "gruppenspezifisch",
    "gruppiere": "gruppieren",
    "gruppierend": "gruppieren",
    "gruppierende": "gruppierend",
    "gruppierendem": "gruppierend",
    "gruppierenden": "gruppierend",
    "gruppierender": "gruppierend",
    "gruppierendes": "gruppierend",
    "gruppierest": "gruppieren",
    "gruppieret": "gruppieren",
    "gruppierst": "gruppieren",
    "gruppiert": "gruppieren",
    "gruppierte": "gruppieren",
    "gruppiertem": "gruppiert",
    "gruppierten": "gruppieren",
    "gruppierter": "gruppiert",
    "gruppiertes": "gruppiert",
    "gruppiertest": "gruppieren",
    "gruppiertet": "gruppieren",
    "grusele": "gruseln",
    "gruselige": "gruselig",
    "gruseligem": "gruselig",
    "gruseligen": "gruselig",
    "gruseliger": "gruselig",
    "gruseligere": "gruselig",
    "gruseligerem": "gruselig",
    "gruseligeren": "gruselig",
    "gruseligerer": "gruselig",
    "gruseligeres": "gruselig",
    "gruseliges": "gruselig",
    "gruseligste": "gruselig",
    "gruseligstem": "gruselig",
    "gruseligsten": "gruselig",
    "gruseligster": "gruselig",
    "gruseligstes": "gruselig",
    "gruselnd": "gruseln",
    "gruselnde": "gruselnd",
    "gruselndem": "gruselnd",
    "gruselnden": "gruselnd",
    "gruselnder": "gruselnd",
    "gruselndere": "gruselnd",
    "gruselnderem": "gruselnd",
    "gruselnderen": "gruselnd",
    "gruselnderer": "gruselnd",
    "gruselnderes": "gruselnd",
    "gruselndes": "gruselnd",
    "gruselndste": "gruselnd",
    "gruselndstem": "gruselnd",
    "gruselndsten": "gruselnd",
    "gruselndster": "gruselnd",
    "gruselndstes": "gruselnd",
    "gruselst": "gruseln",
    "gruselt": "gruseln",
    "gruselte": "gruseln",
    "gruselten": "gruseln",
    "gruseltest": "gruseln",
    "gruseltet": "gruseln",
    "grusle": "gruseln",
    "gräbst": "graben",
    "gräbt": "graben",
    "gräme": "grämen",
    "grämend": "grämen",
    "grämende": "grämend",
    "grämendem": "grämend",
    "grämenden": "grämend",
    "grämender": "grämend",
    "grämendere": "grämend",
    "grämenderem": "grämend",
    "grämenderen": "grämend",
    "grämenderer": "grämend",
    "grämenderes": "grämend",
    "grämendes": "grämend",
    "grämendste": "grämend",
    "grämendstem": "grämend",
    "grämendsten": "grämend",
    "grämendster": "grämend",
    "grämendstes": "grämend",
    "grämest": "grämen",
    "grämet": "grämen",
    "grämliche": "grämlich",
    "grämlichem": "grämlich",
    "grämlichen": "grämlich",
    "grämlicher": "grämlich",
    "grämliches": "grämlich",
    "grämst": "grämen",
    "grämt": "grämen",
    "grämte": "grämen",
    "grämten": "grämen",
    "grämtest": "grämen",
    "grämtet": "grämen",
    "grätsche": "grätschen",
    "grätschend": "grätschen",
    "grätschende": "grätschend",
    "grätschendem": "grätschend",
    "grätschenden": "grätschend",
    "grätschender": "grätschend",
    "grätschendere": "grätschend",
    "grätschenderem": "grätschend",
    "grätschenderen": "grätschend",
    "grätschenderer": "grätschend",
    "grätschenderes": "grätschend",
    "grätschendes": "grätschend",
    "grätschendste": "grätschend",
    "grätschendstem": "grätschend",
    "grätschendsten": "grätschend",
    "grätschendster": "grätschend",
    "grätschendstes": "grätschend",
    "grätschest": "grätschen",
    "grätschet": "grätschen",
    "grätschst": "grätschen",
    "grätscht": "grätschen",
    "grätschte": "grätschen",
    "grätschten": "grätschen",
    "grätschtest": "grätschen",
    "grätschtet": "grätschen",
    "gräulichem": "gräulich",
    "gräulicher": "gräulich",
    "gräulicherem": "gräulich",
    "gräulicherer": "gräulich",
    "gräulicheres": "gräulich",
    "gräuliches": "gräulich",
    "gräulichstem": "gräulich",
    "gräulichster": "gräulich",
    "gräulichstes": "gräulich",
    "gräßliche": "gräßlich",
    "gräßlichem": "gräßlich",
    "gräßlichen": "gräßlich",
    "gräßlicher": "gräßlich",
    "gräßlichere": "gräßlich",
    "gräßlicherem": "gräßlich",
    "gräßlicheren": "gräßlich",
    "gräßlicherer": "gräßlich",
    "gräßlicheres": "gräßlich",
    "gräßliches": "gräßlich",
    "gräßlichste": "gräßlich",
    "gräßlichstem": "gräßlich",
    "gräßlichsten": "gräßlich",
    "gräßlichster": "gräßlich",
    "gräßlichstes": "gräßlich",
    "gröber": "grob",
    "gröbere": "grob",
    "gröberem": "grob",
    "gröberen": "grob",
    "gröberer": "grob",
    "gröberes": "grob",
    "gröbste": "grob",
    "gröbstem": "grob",
    "gröbsten": "grob",
    "gröbster": "grob",
    "gröbstes": "grob",
    "gröle": "grölen",
    "grölend": "grölen",
    "grölende": "grölend",
    "grölendem": "grölend",
    "grölenden": "grölend",
    "grölender": "grölend",
    "grölendere": "grölend",
    "grölenderem": "grölend",
    "grölenderen": "grölend",
    "grölenderer": "grölend",
    "grölenderes": "grölend",
    "grölendes": "grölend",
    "grölendste": "grölend",
    "grölendstem": "grölend",
    "grölendsten": "grölend",
    "grölendster": "grölend",
    "grölendstes": "grölend",
    "grölest": "grölen",
    "grölet": "grölen",
    "grölst": "grölen",
    "grölt": "grölen",
    "grölte": "grölen",
    "grölten": "grölen",
    "gröltest": "grölen",
    "gröltet": "grölen",
    "größenwahnsinnigem": "größenwahnsinnig",
    "größenwahnsinnigen": "größenwahnsinnig",
    "größenwahnsinniger": "größenwahnsinnig",
    "größenwahnsinnigere": "größenwahnsinnig",
    "größenwahnsinnigerem": "größenwahnsinnig",
    "größenwahnsinnigeren": "größenwahnsinnig",
    "größenwahnsinnigerer": "größenwahnsinnig",
    "größenwahnsinnigeres": "größenwahnsinnig",
    "größenwahnsinniges": "größenwahnsinnig",
    "größenwahnsinnigste": "größenwahnsinnig",
    "größenwahnsinnigstem": "größenwahnsinnig",
    "größenwahnsinnigsten": "größenwahnsinnig",
    "größenwahnsinnigster": "größenwahnsinnig",
    "größenwahnsinnigstes": "größenwahnsinnig",
    "größer": "groß",
    "größere": "groß",
    "größerem": "groß",
    "größeren": "groß",
    "größerer": "groß",
    "größeres": "groß",
    "größte": "groß",
    "größtem": "groß",
    "größten": "groß",
    "größter": "groß",
    "größtes": "groß",
    "größtmögliche": "größtmöglich",
    "größtmöglichem": "größtmöglich",
    "größtmöglichen": "größtmöglich",
    "größtmöglicher": "größtmöglich",
    "größtmöglichere": "größtmöglich",
    "größtmöglicherem": "größtmöglich",
    "größtmöglicheren": "größtmöglich",
    "größtmöglicherer": "größtmöglich",
    "größtmöglicheres": "größtmöglich",
    "größtmögliches": "größtmöglich",
    "größtmöglichste": "größtmöglich",
    "größtmöglichstem": "größtmöglich",
    "größtmöglichsten": "größtmöglich",
    "größtmöglichster": "größtmöglich",
    "größtmöglichstes": "größtmöglich",
    "grübe": "graben",
    "grübele": "grübeln",
    "grübelnd": "grübeln",
    "grübelnde": "grübelnd",
    "grübelndem": "grübelnd",
    "grübelnden": "grübelnd",
    "grübelnder": "grübelnd",
    "grübelndere": "grübelnd",
    "grübelnderem": "grübelnd",
    "grübelnderen": "grübelnd",
    "grübelnderer": "grübelnd",
    "grübelnderes": "grübelnd",
    "grübelndes": "grübelnd",
    "grübelndste": "grübelnd",
    "grübelndstem": "grübelnd",
    "grübelndsten": "grübelnd",
    "grübelndster": "grübelnd",
    "grübelndstes": "grübelnd",
    "grübelst": "grübeln",
    "grübelt": "grübeln",
    "grübelte": "grübeln",
    "grübelten": "grübeln",
    "grübeltest": "grübeln",
    "grübeltet": "grübeln",
    "grüben": "graben",
    "grübest": "graben",
    "grübet": "graben",
    "grüble": "grübeln",
    "grüblerische": "grüblerisch",
    "grüblerischem": "grüblerisch",
    "grüblerischen": "grüblerisch",
    "grüblerischer": "grüblerisch",
    "grüblerischere": "grüblerisch",
    "grüblerischerem": "grüblerisch",
    "grüblerischeren": "grüblerisch",
    "grüblerischerer": "grüblerisch",
    "grüblerischeres": "grüblerisch",
    "grüblerisches": "grüblerisch",
    "grüblerischste": "grüblerisch",
    "grüblerischstem": "grüblerisch",
    "grüblerischsten": "grüblerisch",
    "grüblerischster": "grüblerisch",
    "grüblerischstes": "grüblerisch",
    "gründend": "gründen",
    "gründende": "gründend",
    "gründendem": "gründend",
    "gründenden": "gründend",
    "gründender": "gründend",
    "gründendes": "gründend",
    "gründest": "gründen",
    "gründet": "gründen",
    "gründete": "gründen",
    "gründeten": "gründen",
    "gründetest": "gründen",
    "gründetet": "gründen",
    "gründliche": "gründlich",
    "gründlichem": "gründlich",
    "gründlichen": "gründlich",
    "gründlicher": "gründlich",
    "gründlichere": "gründlich",
    "gründlicherem": "gründlich",
    "gründlicheren": "gründlich",
    "gründlicherer": "gründlich",
    "gründlicheres": "gründlich",
    "gründliches": "gründlich",
    "gründlichste": "gründlich",
    "gründlichstem": "gründlich",
    "gründlichsten": "gründlich",
    "gründlichster": "gründlich",
    "gründlichstes": "gründlich",
    "grünem": "grün",
    "grünen": "grün",
    "grüner": "grün",
    "grünere": "grün",
    "grünerem": "grün",
    "grüneren": "grün",
    "grünerer": "grün",
    "grüneres": "grün",
    "grünes": "grün",
    "grünlichem": "grünlich",
    "grünlichen": "grünlich",
    "grünlicher": "grünlich",
    "grünliches": "grünlich",
    "grünstem": "grün",
    "grünsten": "grün",
    "grünster": "grün",
    "grünstes": "grün",
    "grüßend": "grüßen",
    "grüßende": "grüßend",
    "grüßendem": "grüßend",
    "grüßenden": "grüßend",
    "grüßender": "grüßend",
    "grüßendes": "grüßend",
    "grüßest": "grüßen",
    "grüßet": "grüßen",
    "grüßt": "grüßen",
    "grüßte": "grüßen",
    "grüßten": "grüßen",
    "grüßtest": "grüßen",
    "grüßtet": "grüßen",
    "gucke": "gucken",
    "guckend": "gucken",
    "guckende": "guckend",
    "guckendem": "guckend",
    "guckenden": "guckend",
    "guckender": "guckend",
    "guckendes": "guckend",
    "guckest": "gucken",
    "gucket": "gucken",
    "guckst": "gucken",
    "guckt": "gucken",
    "guckte": "gucken",
    "guckten": "gucken",
    "gucktest": "gucken",
    "gucktet": "gucken",
    "gummiere": "gummieren",
    "gummierend": "gummieren",
    "gummierende": "gummierend",
    "gummierendem": "gummierend",
    "gummierenden": "gummierend",
    "gummierender": "gummierend",
    "gummierendes": "gummierend",
    "gummierest": "gummieren",
    "gummieret": "gummieren",
    "gummierst": "gummieren",
    "gummiert": "gummieren",
    "gummierte": "gummieren",
    "gummiertem": "gummiert",
    "gummierten": "gummieren",
    "gummierter": "gummiert",
    "gummiertere": "gummiert",
    "gummierterem": "gummiert",
    "gummierteren": "gummiert",
    "gummierterer": "gummiert",
    "gummierteres": "gummiert",
    "gummiertes": "gummiert",
    "gummiertest": "gummieren",
    "gummierteste": "gummiert",
    "gummiertestem": "gummiert",
    "gummiertesten": "gummiert",
    "gummiertester": "gummiert",
    "gummiertestes": "gummiert",
    "gummiertet": "gummieren",
    "gurgele": "gurgeln",
    "gurgelnd": "gurgeln",
    "gurgelnde": "gurgelnd",
    "gurgelndem": "gurgelnd",
    "gurgelnden": "gurgelnd",
    "gurgelnder": "gurgelnd",
    "gurgelndes": "gurgelnd",
    "gurgelst": "gurgeln",
    "gurgelt": "gurgeln",
    "gurgelte": "gurgeln",
    "gurgelten": "gurgeln",
    "gurgeltest": "gurgeln",
    "gurgeltet": "gurgeln",
    "gurgle": "gurgeln",
    "gurre": "gurren",
    "gurrend": "gurren",
    "gurrende": "gurrend",
    "gurrendem": "gurrend",
    "gurrenden": "gurrend",
    "gurrender": "gurrend",
    "gurrendes": "gurrend",
    "gurrest": "gurren",
    "gurret": "gurren",
    "gurrst": "gurren",
    "gurrt": "gurren",
    "gurrte": "gurren",
    "gurrten": "gurren",
    "gurrtest": "gurren",
    "gurrtet": "gurren",
    "gurtend": "gurten",
    "gurtende": "gurtend",
    "gurtendem": "gurtend",
    "gurtenden": "gurtend",
    "gurtender": "gurtend",
    "gurtendes": "gurtend",
    "gurtest": "gurten",
    "gurtet": "gurten",
    "gurtete": "gurten",
    "gurteten": "gurten",
    "gurtetest": "gurten",
    "gurtetet": "gurten",
    "gutartigem": "gutartig",
    "gutartigen": "gutartig",
    "gutartiger": "gutartig",
    "gutartiges": "gutartig",
    "gutbürgerliche": "gutbürgerlich",
    "gutbürgerlichem": "gutbürgerlich",
    "gutbürgerlichen": "gutbürgerlich",
    "gutbürgerlicher": "gutbürgerlich",
    "gutbürgerliches": "gutbürgerlich",
    "gute": "gut",
    "gutem": "gut",
    "guten": "gut",
    "guter": "gut",
    "gutgeheißen": "gutheißen",
    "gutgeheißene": "gutgeheißen",
    "gutgeheißenem": "gutgeheißen",
    "gutgeheißenen": "gutgeheißen",
    "gutgeheißener": "gutgeheißen",
    "gutgeheißenere": "gutgeheißen",
    "gutgeheißenerem": "gutgeheißen",
    "gutgeheißeneren": "gutgeheißen",
    "gutgeheißenerer": "gutgeheißen",
    "gutgeheißeneres": "gutgeheißen",
    "gutgeheißenes": "gutgeheißen",
    "gutgeheißenste": "gutgeheißen",
    "gutgeheißenstem": "gutgeheißen",
    "gutgeheißensten": "gutgeheißen",
    "gutgeheißenster": "gutgeheißen",
    "gutgeheißenstes": "gutgeheißen",
    "gutgelaunte": "gutgelaunt",
    "gutgelauntem": "gutgelaunt",
    "gutgelaunten": "gutgelaunt",
    "gutgelaunter": "gutgelaunt",
    "gutgelauntes": "gutgelaunt",
    "gutgemeinte": "gutgemeint",
    "gutgemeintem": "gutgemeint",
    "gutgemeinten": "gutgemeint",
    "gutgemeinter": "gutgemeint",
    "gutgemeintes": "gutgemeint",
    "gutgläubige": "gutgläubig",
    "gutgläubigem": "gutgläubig",
    "gutgläubigen": "gutgläubig",
    "gutgläubiger": "gutgläubig",
    "gutgläubigere": "gutgläubig",
    "gutgläubigerem": "gutgläubig",
    "gutgläubigeren": "gutgläubig",
    "gutgläubigerer": "gutgläubig",
    "gutgläubigeres": "gutgläubig",
    "gutgläubiges": "gutgläubig",
    "gutgläubigste": "gutgläubig",
    "gutgläubigstem": "gutgläubig",
    "gutgläubigsten": "gutgläubig",
    "gutgläubigster": "gutgläubig",
    "gutgläubigstes": "gutgläubig",
    "gutheiße": "gutheißen",
    "gutheißend": "gutheißen",
    "gutheißende": "gutheißend",
    "gutheißendem": "gutheißend",
    "gutheißenden": "gutheißend",
    "gutheißender": "gutheißend",
    "gutheißendere": "gutheißend",
    "gutheißenderem": "gutheißend",
    "gutheißenderen": "gutheißend",
    "gutheißenderer": "gutheißend",
    "gutheißenderes": "gutheißend",
    "gutheißendes": "gutheißend",
    "gutheißendste": "gutheißend",
    "gutheißendstem": "gutheißend",
    "gutheißendsten": "gutheißend",
    "gutheißendster": "gutheißend",
    "gutheißendstes": "gutheißend",
    "gutheißest": "gutheißen",
    "gutheißet": "gutheißen",
    "gutheißt": "gutheißen",
    "guthieß": "gutheißen",
    "guthieße": "gutheißen",
    "guthießen": "gutheißen",
    "guthießest": "gutheißen",
    "guthießet": "gutheißen",
    "guthießt": "gutheißen",
    "gutmütige": "gutmütig",
    "gutmütigem": "gutmütig",
    "gutmütigen": "gutmütig",
    "gutmütiger": "gutmütig",
    "gutmütigere": "gutmütig",
    "gutmütigerem": "gutmütig",
    "gutmütigeren": "gutmütig",
    "gutmütigerer": "gutmütig",
    "gutmütigeres": "gutmütig",
    "gutmütiges": "gutmütig",
    "gutmütigstem": "gutmütig",
    "gutmütigsten": "gutmütig",
    "gutmütigster": "gutmütig",
    "gutmütigstes": "gutmütig",
    "gutsituiertem": "gutsituiert",
    "gutsituierten": "gutsituiert",
    "gutsituierter": "gutsituiert",
    "gutsituiertere": "gutsituiert",
    "gutsituierterem": "gutsituiert",
    "gutsituierteren": "gutsituiert",
    "gutsituierterer": "gutsituiert",
    "gutsituierteres": "gutsituiert",
    "gutsituiertes": "gutsituiert",
    "gutsituierteste": "gutsituiert",
    "gutsituiertestem": "gutsituiert",
    "gutsituiertesten": "gutsituiert",
    "gutsituiertester": "gutsituiert",
    "gutsituiertestes": "gutsituiert",
    "gutwillige": "gutwillig",
    "gutwilligem": "gutwillig",
    "gutwilligen": "gutwillig",
    "gutwilliger": "gutwillig",
    "gutwilliges": "gutwillig",
    "gutzuheißen": "gutheißen",
    "gußeisernem": "gußeisern",
    "gußeisernen": "gußeisern",
    "gußeiserner": "gußeisern",
    "gußeisernes": "gußeisern",
    "gymnasiale": "gymnasial",
    "gymnasialem": "gymnasial",
    "gymnasialen": "gymnasial",
    "gymnasialer": "gymnasial",
    "gymnasiales": "gymnasial",
    "gynäkologischem": "gynäkologisch",
    "gynäkologischen": "gynäkologisch",
    "gynäkologischer": "gynäkologisch",
    "gynäkologisches": "gynäkologisch",
    "gäbe": "geben",
    "gäben": "geben",
    "gäbest": "geben",
    "gäbet": "geben",
    "gähne": "gähnen",
    "gähnend": "gähnen",
    "gähnende": "gähnend",
    "gähnendem": "gähnend",
    "gähnenden": "gähnend",
    "gähnender": "gähnend",
    "gähnendere": "gähnend",
    "gähnenderem": "gähnend",
    "gähnenderen": "gähnend",
    "gähnenderer": "gähnend",
    "gähnenderes": "gähnend",
    "gähnendes": "gähnend",
    "gähnendste": "gähnend",
    "gähnendstem": "gähnend",
    "gähnendsten": "gähnend",
    "gähnendster": "gähnend",
    "gähnendstes": "gähnend",
    "gähnest": "gähnen",
    "gähnet": "gähnen",
    "gähnst": "gähnen",
    "gähnt": "gähnen",
    "gähnte": "gähnen",
    "gähnten": "gähnen",
    "gähntest": "gähnen",
    "gähntet": "gähnen",
    "gälte": "gelten",
    "gälten": "gelten",
    "gältest": "gelten",
    "gältet": "gelten",
    "gängele": "gängeln",
    "gängelnd": "gängeln",
    "gängelnde": "gängelnd",
    "gängelndem": "gängelnd",
    "gängelnden": "gängelnd",
    "gängelnder": "gängelnd",
    "gängelndere": "gängelnd",
    "gängelnderem": "gängelnd",
    "gängelnderen": "gängelnd",
    "gängelnderer": "gängelnd",
    "gängelnderes": "gängelnd",
    "gängelndes": "gängelnd",
    "gängelndste": "gängelnd",
    "gängelndstem": "gängelnd",
    "gängelndsten": "gängelnd",
    "gängelndster": "gängelnd",
    "gängelndstes": "gängelnd",
    "gängelst": "gängeln",
    "gängelt": "gängeln",
    "gängelte": "gängeln",
    "gängelten": "gängeln",
    "gängeltest": "gängeln",
    "gängeltet": "gängeln",
    "gängigem": "gängig",
    "gängigen": "gängig",
    "gängiger": "gängig",
    "gängigere": "gängig",
    "gängigerem": "gängig",
    "gängigeren": "gängig",
    "gängigerer": "gängig",
    "gängigeres": "gängig",
    "gängiges": "gängig",
    "gängigste": "gängig",
    "gängigstem": "gängig",
    "gängigsten": "gängig",
    "gängigster": "gängig",
    "gängigstes": "gängig",
    "gängle": "gängeln",
    "gänzliche": "gänzlich",
    "gänzlichem": "gänzlich",
    "gänzlichen": "gänzlich",
    "gänzlicher": "gänzlich",
    "gänzliches": "gänzlich",
    "gäre": "gären",
    "gärend": "gären",
    "gärendem": "gärend",
    "gärender": "gärend",
    "gärenderem": "gärend",
    "gärenderer": "gärend",
    "gärenderes": "gärend",
    "gärendes": "gärend",
    "gärendstem": "gärend",
    "gärendster": "gärend",
    "gärendstes": "gärend",
    "gärest": "gären",
    "gäret": "gären",
    "gärst": "gären",
    "gärt": "gären",
    "gärtnere": "gärtnern",
    "gärtnernd": "gärtnern",
    "gärtnernde": "gärtnernd",
    "gärtnerndem": "gärtnernd",
    "gärtnernden": "gärtnernd",
    "gärtnernder": "gärtnernd",
    "gärtnerndes": "gärtnernd",
    "gärtnerst": "gärtnern",
    "gärtnert": "gärtnern",
    "gärtnerte": "gärtnern",
    "gärtnerten": "gärtnern",
    "gärtnertest": "gärtnern",
    "gärtnertet": "gärtnern",
    "gönne": "gönnen",
    "gönnend": "gönnen",
    "gönnende": "gönnend",
    "gönnendem": "gönnend",
    "gönnenden": "gönnend",
    "gönnender": "gönnend",
    "gönnendes": "gönnend",
    "gönnerhaftem": "gönnerhaft",
    "gönnerhaften": "gönnerhaft",
    "gönnerhafter": "gönnerhaft",
    "gönnerhaftere": "gönnerhaft",
    "gönnerhafterem": "gönnerhaft",
    "gönnerhafteren": "gönnerhaft",
    "gönnerhafterer": "gönnerhaft",
    "gönnerhafteres": "gönnerhaft",
    "gönnerhaftes": "gönnerhaft",
    "gönnerhafteste": "gönnerhaft",
    "gönnerhaftestem": "gönnerhaft",
    "gönnerhaftesten": "gönnerhaft",
    "gönnerhaftester": "gönnerhaft",
    "gönnerhaftestes": "gönnerhaft",
    "gönnest": "gönnen",
    "gönnet": "gönnen",
    "gönnst": "gönnen",
    "gönnt": "gönnen",
    "gönnte": "gönnen",
    "gönnten": "gönnen",
    "gönntest": "gönnen",
    "gönntet": "gönnen",
    "göre": "gären",
    "gören": "gären",
    "görest": "gären",
    "göret": "gären",
    "gösse": "gießen",
    "gössen": "gießen",
    "gössest": "gießen",
    "gösset": "gießen",
    "göttliche": "göttlich",
    "göttlichem": "göttlich",
    "göttlichen": "göttlich",
    "göttlicher": "göttlich",
    "göttlichere": "göttlich",
    "göttlicherem": "göttlich",
    "göttlicheren": "göttlich",
    "göttlicherer": "göttlich",
    "göttlicheres": "göttlich",
    "göttliches": "göttlich",
    "göttlichste": "göttlich",
    "göttlichstem": "göttlich",
    "göttlichsten": "göttlich",
    "göttlichster": "göttlich",
    "göttlichstes": "göttlich",
    "güldenem": "gülden",
    "güldenen": "gülden",
    "güldener": "gülden",
    "güldenes": "gülden",
    "gültigem": "gültig",
    "gültigen": "gültig",
    "gültiger": "gültig",
    "gültiges": "gültig",
    "günstigem": "günstig",
    "günstigen": "günstig",
    "günstiger": "günstig",
    "günstigere": "günstig",
    "günstigerem": "günstig",
    "günstigeren": "günstig",
    "günstigerer": "günstig",
    "günstigeres": "günstig",
    "günstiges": "günstig",
    "günstigste": "günstig",
    "günstigstem": "günstig",
    "günstigsten": "günstig",
    "günstigster": "günstig",
    "günstigstes": "günstig",
    "gütige": "gütig",
    "gütigem": "gütig",
    "gütigen": "gütig",
    "gütiger": "gütig",
    "gütigere": "gütig",
    "gütigerem": "gütig",
    "gütigeren": "gütig",
    "gütigerer": "gütig",
    "gütigeres": "gütig",
    "gütiges": "gütig",
    "gütigste": "gütig",
    "gütigstem": "gütig",
    "gütigsten": "gütig",
    "gütigster": "gütig",
    "gütigstes": "gütig",
    "gütliche": "gütlich",
    "gütlichem": "gütlich",
    "gütlichen": "gütlich",
    "gütlicher": "gütlich",
    "gütliches": "gütlich",
    "haarend": "haaren",
    "haarende": "haarend",
    "haarendem": "haarend",
    "haarenden": "haarend",
    "haarender": "haarend",
    "haarendere": "haarend",
    "haarenderem": "haarend",
    "haarenderen": "haarend",
    "haarenderer": "haarend",
    "haarenderes": "haarend",
    "haarendes": "haarend",
    "haarendste": "haarend",
    "haarendstem": "haarend",
    "haarendsten": "haarend",
    "haarendster": "haarend",
    "haarendstes": "haarend",
    "haarest": "haaren",
    "haaret": "haaren",
    "haargenauem": "haargenau",
    "haargenauen": "haargenau",
    "haargenauer": "haargenau",
    "haargenaues": "haargenau",
    "haarige": "haarig",
    "haarigem": "haarig",
    "haarigen": "haarig",
    "haariger": "haarig",
    "haarigere": "haarig",
    "haarigerem": "haarig",
    "haarigeren": "haarig",
    "haarigerer": "haarig",
    "haarigeres": "haarig",
    "haariges": "haarig",
    "haarigste": "haarig",
    "haarigstem": "haarig",
    "haarigsten": "haarig",
    "haarigster": "haarig",
    "haarigstes": "haarig",
    "haarlose": "haarlos",
    "haarlosem": "haarlos",
    "haarlosen": "haarlos",
    "haarloser": "haarlos",
    "haarlosere": "haarlos",
    "haarloserem": "haarlos",
    "haarloseren": "haarlos",
    "haarloserer": "haarlos",
    "haarloseres": "haarlos",
    "haarloses": "haarlos",
    "haarloseste": "haarlos",
    "haarlosestem": "haarlos",
    "haarlosesten": "haarlos",
    "haarlosester": "haarlos",
    "haarlosestes": "haarlos",
    "haarscharfem": "haarscharf",
    "haarscharfen": "haarscharf",
    "haarscharfer": "haarscharf",
    "haarscharfes": "haarscharf",
    "haarst": "haaren",
    "haarsträubende": "haarsträubend",
    "haarsträubendem": "haarsträubend",
    "haarsträubenden": "haarsträubend",
    "haarsträubender": "haarsträubend",
    "haarsträubendes": "haarsträubend",
    "haart": "haaren",
    "haarte": "haaren",
    "haarten": "haaren",
    "haartest": "haaren",
    "haartet": "haaren",
    "habend": "haben",
    "habende": "habend",
    "habendem": "habend",
    "habenden": "habend",
    "habender": "habend",
    "habendes": "habend",
    "habest": "haben",
    "habet": "haben",
    "habgierige": "habgierig",
    "habgierigem": "habgierig",
    "habgierigen": "habgierig",
    "habgieriger": "habgierig",
    "habgierigere": "habgierig",
    "habgierigerem": "habgierig",
    "habgierigeren": "habgierig",
    "habgierigerer": "habgierig",
    "habgierigeres": "habgierig",
    "habgieriges": "habgierig",
    "habgierigste": "habgierig",
    "habgierigstem": "habgierig",
    "habgierigsten": "habgierig",
    "habgierigster": "habgierig",
    "habgierigstes": "habgierig",
    "habilitiere": "habilitieren",
    "habilitierend": "habilitieren",
    "habilitierende": "habilitierend",
    "habilitierendem": "habilitierend",
    "habilitierenden": "habilitierend",
    "habilitierender": "habilitierend",
    "habilitierendes": "habilitierend",
    "habilitierest": "habilitieren",
    "habilitieret": "habilitieren",
    "habilitierst": "habilitieren",
    "habilitiert": "habilitieren",
    "habilitierte": "habilitieren",
    "habilitiertem": "habilitiert",
    "habilitierten": "habilitieren",
    "habilitierter": "habilitiert",
    "habilitiertes": "habilitiert",
    "habilitiertest": "habilitieren",
    "habilitiertet": "habilitieren",
    "habsüchtigem": "habsüchtig",
    "habsüchtigen": "habsüchtig",
    "habsüchtiger": "habsüchtig",
    "habsüchtigere": "habsüchtig",
    "habsüchtigerem": "habsüchtig",
    "habsüchtigeren": "habsüchtig",
    "habsüchtigerer": "habsüchtig",
    "habsüchtigeres": "habsüchtig",
    "habsüchtiges": "habsüchtig",
    "habsüchtigste": "habsüchtig",
    "habsüchtigstem": "habsüchtig",
    "habsüchtigsten": "habsüchtig",
    "habsüchtigster": "habsüchtig",
    "habsüchtigstes": "habsüchtig",
    "habt": "haben",
    "hacke": "hacken",
    "hackend": "hacken",
    "hackende": "hackend",
    "hackendem": "hackend",
    "hackenden": "hackend",
    "hackender": "hackend",
    "hackendes": "hackend",
    "hackest": "hacken",
    "hacket": "hacken",
    "hackst": "hacken",
    "hackt": "hacken",
    "hackte": "hacken",
    "hackten": "hacken",
    "hacktest": "hacken",
    "hacktet": "hacken",
    "hadere": "hadern",
    "hadernd": "hadern",
    "hadernde": "hadernd",
    "haderndem": "hadernd",
    "hadernden": "hadernd",
    "hadernder": "hadernd",
    "haderndere": "hadernd",
    "hadernderem": "hadernd",
    "hadernderen": "hadernd",
    "hadernderer": "hadernd",
    "hadernderes": "hadernd",
    "haderndes": "hadernd",
    "haderndste": "hadernd",
    "haderndstem": "hadernd",
    "haderndsten": "hadernd",
    "haderndster": "hadernd",
    "haderndstes": "hadernd",
    "haderst": "hadern",
    "hadert": "hadern",
    "haderte": "hadern",
    "haderten": "hadern",
    "hadertest": "hadern",
    "hadertet": "hadern",
    "haftbarem": "haftbar",
    "haftbaren": "haftbar",
    "haftbarer": "haftbar",
    "haftbares": "haftbar",
    "hafte": "haften",
    "haftenbleibe": "haftenbleiben",
    "haftenbleibend": "haftenbleiben",
    "haftenbleibende": "haftenbleibend",
    "haftenbleibendem": "haftenbleibend",
    "haftenbleibenden": "haftenbleibend",
    "haftenbleibender": "haftenbleibend",
    "haftenbleibendes": "haftenbleibend",
    "haftenbleibest": "haftenbleiben",
    "haftenbleibet": "haftenbleiben",
    "haftenbleibst": "haftenbleiben",
    "haftenbleibt": "haftenbleiben",
    "haftenblieb": "haftenbleiben",
    "haftenbliebe": "haftenbleiben",
    "haftenblieben": "haftenbleiben",
    "haftenbliebest": "haftenbleiben",
    "haftenbliebet": "haftenbleiben",
    "haftenbliebst": "haftenbleiben",
    "haftenbliebt": "haftenbleiben",
    "haftend": "haften",
    "haftende": "haftend",
    "haftendem": "haftend",
    "haftenden": "haftend",
    "haftender": "haftend",
    "haftendere": "haftend",
    "haftenderem": "haftend",
    "haftenderen": "haftend",
    "haftenderer": "haftend",
    "haftenderes": "haftend",
    "haftendes": "haftend",
    "haftendste": "haftend",
    "haftendstem": "haftend",
    "haftendsten": "haftend",
    "haftendster": "haftend",
    "haftendstes": "haftend",
    "haftengeblieben": "haftenbleiben",
    "haftengebliebene": "haftengeblieben",
    "haftengebliebenem": "haftengeblieben",
    "haftengebliebenen": "haftengeblieben",
    "haftengebliebener": "haftengeblieben",
    "haftengebliebenes": "haftengeblieben",
    "haftenzubleiben": "haftenbleiben",
    "haftest": "haften",
    "haftet": "haften",
    "haftete": "haften",
    "hafteten": "haften",
    "haftetest": "haften",
    "haftetet": "haften",
    "haftfähige": "haftfähig",
    "haftfähigem": "haftfähig",
    "haftfähigen": "haftfähig",
    "haftfähiger": "haftfähig",
    "haftfähigere": "haftfähig",
    "haftfähigerem": "haftfähig",
    "haftfähigeren": "haftfähig",
    "haftfähigerer": "haftfähig",
    "haftfähigeres": "haftfähig",
    "haftfähiges": "haftfähig",
    "haftfähigste": "haftfähig",
    "haftfähigstem": "haftfähig",
    "haftfähigsten": "haftfähig",
    "haftfähigster": "haftfähig",
    "haftfähigstes": "haftfähig",
    "haftpflichtigem": "haftpflichtig",
    "haftpflichtigen": "haftpflichtig",
    "haftpflichtiger": "haftpflichtig",
    "haftpflichtiges": "haftpflichtig",
    "haftunfähige": "haftunfähig",
    "haftunfähigem": "haftunfähig",
    "haftunfähigen": "haftunfähig",
    "haftunfähiger": "haftunfähig",
    "haftunfähigere": "haftunfähig",
    "haftunfähigerem": "haftunfähig",
    "haftunfähigeren": "haftunfähig",
    "haftunfähigerer": "haftunfähig",
    "haftunfähigeres": "haftunfähig",
    "haftunfähiges": "haftunfähig",
    "haftunfähigste": "haftunfähig",
    "haftunfähigstem": "haftunfähig",
    "haftunfähigsten": "haftunfähig",
    "haftunfähigster": "haftunfähig",
    "haftunfähigstes": "haftunfähig",
    "hagele": "hageln",
    "hagelnd": "hageln",
    "hagelnde": "hagelnd",
    "hagelndem": "hagelnd",
    "hagelnden": "hagelnd",
    "hagelnder": "hagelnd",
    "hagelndes": "hagelnd",
    "hagelst": "hageln",
    "hagelt": "hageln",
    "hagelte": "hageln",
    "hagelten": "hageln",
    "hageltest": "hageln",
    "hageltet": "hageln",
    "hagerem": "hager",
    "hageren": "hager",
    "hagerer": "hager",
    "hagerere": "hager",
    "hagererem": "hager",
    "hagereren": "hager",
    "hagererer": "hager",
    "hagereres": "hager",
    "hageres": "hager",
    "hagerste": "hager",
    "hagerstem": "hager",
    "hagersten": "hager",
    "hagerster": "hager",
    "hagerstes": "hager",
    "hagle": "hageln",
    "hake": "haken",
    "hakend": "haken",
    "hakende": "hakend",
    "hakendem": "hakend",
    "hakenden": "hakend",
    "hakender": "hakend",
    "hakendes": "hakend",
    "hakest": "haken",
    "haket": "haken",
    "hakst": "haken",
    "hakt": "haken",
    "hakte": "haken",
    "hakten": "haken",
    "haktest": "haken",
    "haktet": "haken",
    "halbautomatischem": "halbautomatisch",
    "halbautomatischen": "halbautomatisch",
    "halbautomatischer": "halbautomatisch",
    "halbautomatisches": "halbautomatisch",
    "halbem": "halb",
    "halben": "halb",
    "halber": "halb",
    "halbes": "halb",
    "halbfertigem": "halbfertig",
    "halbfertigen": "halbfertig",
    "halbfertiger": "halbfertig",
    "halbfertiges": "halbfertig",
    "halbfette": "halbfett",
    "halbfettem": "halbfett",
    "halbfetten": "halbfett",
    "halbfetter": "halbfett",
    "halbfettes": "halbfett",
    "halbherzigem": "halbherzig",
    "halbherzigen": "halbherzig",
    "halbherziger": "halbherzig",
    "halbherzigere": "halbherzig",
    "halbherzigerem": "halbherzig",
    "halbherzigeren": "halbherzig",
    "halbherzigerer": "halbherzig",
    "halbherzigeres": "halbherzig",
    "halbherziges": "halbherzig",
    "halbherzigste": "halbherzig",
    "halbherzigstem": "halbherzig",
    "halbherzigsten": "halbherzig",
    "halbherzigster": "halbherzig",
    "halbherzigstes": "halbherzig",
    "halbiere": "halbieren",
    "halbierend": "halbieren",
    "halbierende": "halbierend",
    "halbierendem": "halbierend",
    "halbierenden": "halbierend",
    "halbierender": "halbierend",
    "halbierendes": "halbierend",
    "halbierest": "halbieren",
    "halbieret": "halbieren",
    "halbierst": "halbieren",
    "halbiert": "halbieren",
    "halbierte": "halbieren",
    "halbiertem": "halbiert",
    "halbierten": "halbieren",
    "halbierter": "halbiert",
    "halbiertes": "halbiert",
    "halbiertest": "halbieren",
    "halbiertet": "halbieren",
    "halbjährigem": "halbjährig",
    "halbjährigen": "halbjährig",
    "halbjähriger": "halbjährig",
    "halbjähriges": "halbjährig",
    "halbjährliche": "halbjährlich",
    "halbjährlichem": "halbjährlich",
    "halbjährlichen": "halbjährlich",
    "halbjährlicher": "halbjährlich",
    "halbjährliches": "halbjährlich",
    "halbkugelförmigem": "halbkugelförmig",
    "halbkugelförmigen": "halbkugelförmig",
    "halbkugelförmiger": "halbkugelförmig",
    "halbkugelförmiges": "halbkugelförmig",
    "halbnacktem": "halbnackt",
    "halbnackten": "halbnackt",
    "halbnackter": "halbnackt",
    "halbnacktes": "halbnackt",
    "halbstündigem": "halbstündig",
    "halbstündigen": "halbstündig",
    "halbstündiger": "halbstündig",
    "halbstündiges": "halbstündig",
    "halbtägige": "halbtägig",
    "halbtägigem": "halbtägig",
    "halbtägigen": "halbtägig",
    "halbtägiger": "halbtägig",
    "halbtägiges": "halbtägig",
    "half": "helfen",
    "halfen": "helfen",
    "halfst": "helfen",
    "halft": "helfen",
    "halftere": "halftern",
    "halfternd": "halftern",
    "halfternde": "halfternd",
    "halfterndem": "halfternd",
    "halfternden": "halfternd",
    "halfternder": "halfternd",
    "halfterndes": "halfternd",
    "halfterst": "halftern",
    "halftert": "halftern",
    "halfterte": "halftern",
    "halfterten": "halftern",
    "halftertest": "halftern",
    "halftertet": "halftern",
    "hallend": "hallen",
    "hallende": "hallend",
    "hallendem": "hallend",
    "hallenden": "hallend",
    "hallender": "hallend",
    "hallendere": "hallend",
    "hallenderem": "hallend",
    "hallenderen": "hallend",
    "hallenderer": "hallend",
    "hallenderes": "hallend",
    "hallendes": "hallend",
    "hallendste": "hallend",
    "hallendstem": "hallend",
    "hallendsten": "hallend",
    "hallendster": "hallend",
    "hallendstes": "hallend",
    "hallest": "hallen",
    "hallet": "hallen",
    "hallst": "hallen",
    "hallt": "hallen",
    "hallte": "hallen",
    "hallten": "hallen",
    "halltest": "hallen",
    "halltet": "hallen",
    "halluzinierend": "halluzinieren",
    "halluzinierende": "halluzinierend",
    "halluzinierendem": "halluzinierend",
    "halluzinierenden": "halluzinierend",
    "halluzinierender": "halluzinierend",
    "halluzinierendere": "halluzinierend",
    "halluzinierenderem": "halluzinierend",
    "halluzinierenderen": "halluzinierend",
    "halluzinierenderer": "halluzinierend",
    "halluzinierenderes": "halluzinierend",
    "halluzinierendes": "halluzinierend",
    "halluzinierendste": "halluzinierend",
    "halluzinierendstem": "halluzinierend",
    "halluzinierendsten": "halluzinierend",
    "halluzinierendster": "halluzinierend",
    "halluzinierendstes": "halluzinierend",
    "halluzinierest": "halluzinieren",
    "halluzinieret": "halluzinieren",
    "halluzinierst": "halluzinieren",
    "halluziniert": "halluzinieren",
    "halluzinierte": "halluzinieren",
    "halluziniertem": "halluziniert",
    "halluzinierten": "halluzinieren",
    "halluzinierter": "halluziniert",
    "halluziniertes": "halluziniert",
    "halluziniertest": "halluzinieren",
    "halluziniertet": "halluzinieren",
    "halogenem": "halogen",
    "halogenen": "halogen",
    "halogener": "halogen",
    "halogenes": "halogen",
    "halsbrecherischem": "halsbrecherisch",
    "halsbrecherischen": "halsbrecherisch",
    "halsbrecherischer": "halsbrecherisch",
    "halsbrecherischere": "halsbrecherisch",
    "halsbrecherischerem": "halsbrecherisch",
    "halsbrecherischeren": "halsbrecherisch",
    "halsbrecherischerer": "halsbrecherisch",
    "halsbrecherischeres": "halsbrecherisch",
    "halsbrecherisches": "halsbrecherisch",
    "halsbrecherischste": "halsbrecherisch",
    "halsbrecherischstem": "halsbrecherisch",
    "halsbrecherischsten": "halsbrecherisch",
    "halsbrecherischster": "halsbrecherisch",
    "halsbrecherischstes": "halsbrecherisch",
    "halsend": "halsen",
    "halsende": "halsend",
    "halsendem": "halsend",
    "halsenden": "halsend",
    "halsender": "halsend",
    "halsendes": "halsend",
    "halsest": "halsen",
    "halset": "halsen",
    "halsferne": "halsfern",
    "halsfernem": "halsfern",
    "halsfernen": "halsfern",
    "halsferner": "halsfern",
    "halsfernes": "halsfern",
    "halsstarrigem": "halsstarrig",
    "halsstarrigen": "halsstarrig",
    "halsstarriger": "halsstarrig",
    "halsstarrigere": "halsstarrig",
    "halsstarrigerem": "halsstarrig",
    "halsstarrigeren": "halsstarrig",
    "halsstarrigerer": "halsstarrig",
    "halsstarrigeres": "halsstarrig",
    "halsstarriges": "halsstarrig",
    "halsstarrigste": "halsstarrig",
    "halsstarrigstem": "halsstarrig",
    "halsstarrigsten": "halsstarrig",
    "halsstarrigster": "halsstarrig",
    "halsstarrigstes": "halsstarrig",
    "halst": "halsen",
    "halste": "halsen",
    "halsten": "halsen",
    "halstest": "halsen",
    "halstet": "halsen",
    "haltbare": "haltbar",
    "haltbarem": "haltbar",
    "haltbaren": "haltbar",
    "haltbarer": "haltbar",
    "haltbarere": "haltbar",
    "haltbarerem": "haltbar",
    "haltbareren": "haltbar",
    "haltbarerer": "haltbar",
    "haltbareres": "haltbar",
    "haltbares": "haltbar",
    "haltbarste": "haltbar",
    "haltbarstem": "haltbar",
    "haltbarsten": "haltbar",
    "haltbarster": "haltbar",
    "haltbarstes": "haltbar",
    "haltend": "halten",
    "haltende": "haltend",
    "haltendem": "haltend",
    "haltenden": "haltend",
    "haltender": "haltend",
    "haltendes": "haltend",
    "haltest": "halten",
    "haltet": "halten",
    "haltgemacht": "haltmachen",
    "haltgemachte": "haltgemacht",
    "haltgemachtem": "haltgemacht",
    "haltgemachten": "haltgemacht",
    "haltgemachter": "haltgemacht",
    "haltgemachtes": "haltgemacht",
    "haltlose": "haltlos",
    "haltlosem": "haltlos",
    "haltlosen": "haltlos",
    "haltloser": "haltlos",
    "haltlosere": "haltlos",
    "haltloserem": "haltlos",
    "haltloseren": "haltlos",
    "haltloserer": "haltlos",
    "haltloseres": "haltlos",
    "haltloses": "haltlos",
    "haltloseste": "haltlos",
    "haltlosestem": "haltlos",
    "haltlosesten": "haltlos",
    "haltlosester": "haltlos",
    "haltlosestes": "haltlos",
    "haltmache": "haltmachen",
    "haltmachend": "haltmachen",
    "haltmachende": "haltmachend",
    "haltmachendem": "haltmachend",
    "haltmachenden": "haltmachend",
    "haltmachender": "haltmachend",
    "haltmachendes": "haltmachend",
    "haltmachest": "haltmachen",
    "haltmachet": "haltmachen",
    "haltmachst": "haltmachen",
    "haltmacht": "haltmachen",
    "haltmachte": "haltmachen",
    "haltmachten": "haltmachen",
    "haltmachtest": "haltmachen",
    "haltmachtet": "haltmachen",
    "haltzumachen": "haltmachen",
    "hampele": "hampeln",
    "hampelnd": "hampeln",
    "hampelnde": "hampelnd",
    "hampelndem": "hampelnd",
    "hampelnden": "hampelnd",
    "hampelnder": "hampelnd",
    "hampelndes": "hampelnd",
    "hampelst": "hampeln",
    "hampelt": "hampeln",
    "hampelte": "hampeln",
    "hampelten": "hampeln",
    "hampeltest": "hampeln",
    "hampeltet": "hampeln",
    "hample": "hampeln",
    "hamstere": "hamstern",
    "hamsternd": "hamstern",
    "hamsternde": "hamsternd",
    "hamsterndem": "hamsternd",
    "hamsternden": "hamsternd",
    "hamsternder": "hamsternd",
    "hamsterndere": "hamsternd",
    "hamsternderem": "hamsternd",
    "hamsternderen": "hamsternd",
    "hamsternderer": "hamsternd",
    "hamsternderes": "hamsternd",
    "hamsterndes": "hamsternd",
    "hamsterndste": "hamsternd",
    "hamsterndstem": "hamsternd",
    "hamsterndsten": "hamsternd",
    "hamsterndster": "hamsternd",
    "hamsterndstes": "hamsternd",
    "hamsterst": "hamstern",
    "hamstert": "hamstern",
    "hamsterte": "hamstern",
    "hamsterten": "hamstern",
    "hamstertest": "hamstern",
    "hamstertet": "hamstern",
    "handbreitem": "handbreit",
    "handbreiten": "handbreit",
    "handbreiter": "handbreit",
    "handbreites": "handbreit",
    "handele": "handeln",
    "handelnd": "handeln",
    "handelnde": "handelnd",
    "handelndem": "handelnd",
    "handelnden": "handelnd",
    "handelnder": "handelnd",
    "handelndes": "handelnd",
    "handelsfähigem": "handelsfähig",
    "handelsfähigen": "handelsfähig",
    "handelsfähiger": "handelsfähig",
    "handelsfähigere": "handelsfähig",
    "handelsfähigerem": "handelsfähig",
    "handelsfähigeren": "handelsfähig",
    "handelsfähigerer": "handelsfähig",
    "handelsfähigeres": "handelsfähig",
    "handelsfähiges": "handelsfähig",
    "handelsfähigste": "handelsfähig",
    "handelsfähigstem": "handelsfähig",
    "handelsfähigsten": "handelsfähig",
    "handelsfähigster": "handelsfähig",
    "handelsfähigstes": "handelsfähig",
    "handelsgerichtliche": "handelsgerichtlich",
    "handelsgerichtlichem": "handelsgerichtlich",
    "handelsgerichtlichen": "handelsgerichtlich",
    "handelsgerichtlicher": "handelsgerichtlich",
    "handelsgerichtliches": "handelsgerichtlich",
    "handelspolitischem": "handelspolitisch",
    "handelspolitischen": "handelspolitisch",
    "handelspolitischer": "handelspolitisch",
    "handelspolitisches": "handelspolitisch",
    "handelst": "handeln",
    "handelsübliche": "handelsüblich",
    "handelsüblichem": "handelsüblich",
    "handelsüblichen": "handelsüblich",
    "handelsüblicher": "handelsüblich",
    "handelsübliches": "handelsüblich",
    "handelt": "handeln",
    "handelte": "handeln",
    "handelten": "handeln",
    "handeltest": "handeln",
    "handeltet": "handeln",
    "handfeste": "handfest",
    "handfestem": "handfest",
    "handfesten": "handfest",
    "handfester": "handfest",
    "handfestere": "handfest",
    "handfesterem": "handfest",
    "handfesteren": "handfest",
    "handfesterer": "handfest",
    "handfesteres": "handfest",
    "handfestes": "handfest",
    "handfesteste": "handfest",
    "handfestestem": "handfest",
    "handfestesten": "handfest",
    "handfestester": "handfest",
    "handfestestes": "handfest",
    "handgearbeitete": "handgearbeitet",
    "handgearbeitetem": "handgearbeitet",
    "handgearbeiteten": "handgearbeitet",
    "handgearbeiteter": "handgearbeitet",
    "handgearbeitetes": "handgearbeitet",
    "handgebundene": "handgebunden",
    "handgebundenem": "handgebunden",
    "handgebundenen": "handgebunden",
    "handgebundener": "handgebunden",
    "handgebundenes": "handgebunden",
    "handgenähte": "handgenäht",
    "handgenähtem": "handgenäht",
    "handgenähten": "handgenäht",
    "handgenähter": "handgenäht",
    "handgenähtes": "handgenäht",
    "handgestrickte": "handgestrickt",
    "handgestricktem": "handgestrickt",
    "handgestrickten": "handgestrickt",
    "handgestrickter": "handgestrickt",
    "handgestricktes": "handgestrickt",
    "handgewebte": "handgewebt",
    "handgewebtem": "handgewebt",
    "handgewebten": "handgewebt",
    "handgewebter": "handgewebt",
    "handgewebtes": "handgewebt",
    "handgreifliche": "handgreiflich",
    "handgreiflichem": "handgreiflich",
    "handgreiflichen": "handgreiflich",
    "handgreiflicher": "handgreiflich",
    "handgreifliches": "handgreiflich",
    "handhabe": "handhaben",
    "handhabend": "handhaben",
    "handhabende": "handhabend",
    "handhabendem": "handhabend",
    "handhabenden": "handhabend",
    "handhabender": "handhabend",
    "handhabendes": "handhabend",
    "handhabest": "handhaben",
    "handhabet": "handhaben",
    "handhabst": "handhaben",
    "handhabt": "handhaben",
    "handhabte": "handhaben",
    "handhabten": "handhaben",
    "handhabtest": "handhaben",
    "handhabtet": "handhaben",
    "handle": "handeln",
    "handlichem": "handlich",
    "handlichen": "handlich",
    "handlicher": "handlich",
    "handlichere": "handlich",
    "handlicherem": "handlich",
    "handlicheren": "handlich",
    "handlicherer": "handlich",
    "handlicheres": "handlich",
    "handliches": "handlich",
    "handlichste": "handlich",
    "handlichstem": "handlich",
    "handlichsten": "handlich",
    "handlichster": "handlich",
    "handlichstes": "handlich",
    "handlungsfähigem": "handlungsfähig",
    "handlungsfähigen": "handlungsfähig",
    "handlungsfähiger": "handlungsfähig",
    "handlungsfähigere": "handlungsfähig",
    "handlungsfähigerem": "handlungsfähig",
    "handlungsfähigeren": "handlungsfähig",
    "handlungsfähigerer": "handlungsfähig",
    "handlungsfähigeres": "handlungsfähig",
    "handlungsfähiges": "handlungsfähig",
    "handlungsfähigste": "handlungsfähig",
    "handlungsfähigstem": "handlungsfähig",
    "handlungsfähigsten": "handlungsfähig",
    "handlungsfähigster": "handlungsfähig",
    "handlungsfähigstes": "handlungsfähig",
    "handlungsleitende": "handlungsleitend",
    "handlungsleitendem": "handlungsleitend",
    "handlungsleitenden": "handlungsleitend",
    "handlungsleitender": "handlungsleitend",
    "handlungsleitendes": "handlungsleitend",
    "handschriftliche": "handschriftlich",
    "handschriftlichem": "handschriftlich",
    "handschriftlichen": "handschriftlich",
    "handschriftlicher": "handschriftlich",
    "handschriftliches": "handschriftlich",
    "handwarmem": "handwarm",
    "handwarmen": "handwarm",
    "handwarmer": "handwarm",
    "handwarmes": "handwarm",
    "handwerklichem": "handwerklich",
    "handwerklichen": "handwerklich",
    "handwerklicher": "handwerklich",
    "handwerklichere": "handwerklich",
    "handwerklicherem": "handwerklich",
    "handwerklicheren": "handwerklich",
    "handwerklicherer": "handwerklich",
    "handwerklicheres": "handwerklich",
    "handwerkliches": "handwerklich",
    "handwerklichste": "handwerklich",
    "handwerklichstem": "handwerklich",
    "handwerklichsten": "handwerklich",
    "handwerklichster": "handwerklich",
    "handwerklichstes": "handwerklich",
    "hanebüchene": "hanebüchen",
    "hanebüchenem": "hanebüchen",
    "hanebüchenen": "hanebüchen",
    "hanebüchener": "hanebüchen",
    "hanebüchenere": "hanebüchen",
    "hanebüchenerem": "hanebüchen",
    "hanebücheneren": "hanebüchen",
    "hanebüchenerer": "hanebüchen",
    "hanebücheneres": "hanebüchen",
    "hanebüchenes": "hanebüchen",
    "hanebüchenste": "hanebüchen",
    "hanebüchenstem": "hanebüchen",
    "hanebüchensten": "hanebüchen",
    "hanebüchenster": "hanebüchen",
    "hanebüchenstes": "hanebüchen",
    "hangele": "hangeln",
    "hangelnd": "hangeln",
    "hangelnde": "hangelnd",
    "hangelndem": "hangelnd",
    "hangelnden": "hangelnd",
    "hangelnder": "hangelnd",
    "hangelndere": "hangelnd",
    "hangelnderem": "hangelnd",
    "hangelnderen": "hangelnd",
    "hangelnderer": "hangelnd",
    "hangelnderes": "hangelnd",
    "hangelndes": "hangelnd",
    "hangelndste": "hangelnd",
    "hangelndstem": "hangelnd",
    "hangelndsten": "hangelnd",
    "hangelndster": "hangelnd",
    "hangelndstes": "hangelnd",
    "hangelst": "hangeln",
    "hangelt": "hangeln",
    "hangelte": "hangeln",
    "hangelten": "hangeln",
    "hangeltest": "hangeln",
    "hangeltet": "hangeln",
    "hangle": "hangeln",
    "hansischem": "hansisch",
    "hansischen": "hansisch",
    "hansischer": "hansisch",
    "hansisches": "hansisch",
    "hantiere": "hantieren",
    "hantierend": "hantieren",
    "hantierende": "hantierend",
    "hantierendem": "hantierend",
    "hantierenden": "hantierend",
    "hantierender": "hantierend",
    "hantierendere": "hantierend",
    "hantierenderem": "hantierend",
    "hantierenderen": "hantierend",
    "hantierenderer": "hantierend",
    "hantierenderes": "hantierend",
    "hantierendes": "hantierend",
    "hantierendste": "hantierend",
    "hantierendstem": "hantierend",
    "hantierendsten": "hantierend",
    "hantierendster": "hantierend",
    "hantierendstes": "hantierend",
    "hantierest": "hantieren",
    "hantieret": "hantieren",
    "hantierst": "hantieren",
    "hantiert": "hantieren",
    "hantierte": "hantieren",
    "hantiertem": "hantiert",
    "hantierten": "hantieren",
    "hantierter": "hantiert",
    "hantiertes": "hantiert",
    "hantiertest": "hantieren",
    "hantiertet": "hantieren",
    "hapere": "hapern",
    "hapernd": "hapern",
    "hapernde": "hapernd",
    "haperndem": "hapernd",
    "hapernden": "hapernd",
    "hapernder": "hapernd",
    "haperndere": "hapernd",
    "hapernderem": "hapernd",
    "hapernderen": "hapernd",
    "hapernderer": "hapernd",
    "hapernderes": "hapernd",
    "haperndes": "hapernd",
    "haperndste": "hapernd",
    "haperndstem": "hapernd",
    "haperndsten": "hapernd",
    "haperndster": "hapernd",
    "haperndstes": "hapernd",
    "haperst": "hapern",
    "hapert": "hapern",
    "haperte": "hapern",
    "haperten": "hapern",
    "hapertest": "hapern",
    "hapertet": "hapern",
    "happigem": "happig",
    "happigen": "happig",
    "happiger": "happig",
    "happigere": "happig",
    "happigerem": "happig",
    "happigeren": "happig",
    "happigerer": "happig",
    "happigeres": "happig",
    "happiges": "happig",
    "happigste": "happig",
    "happigstem": "happig",
    "happigsten": "happig",
    "happigster": "happig",
    "happigstes": "happig",
    "harmlosem": "harmlos",
    "harmlosen": "harmlos",
    "harmloser": "harmlos",
    "harmlosere": "harmlos",
    "harmloserem": "harmlos",
    "harmloseren": "harmlos",
    "harmloserer": "harmlos",
    "harmloseres": "harmlos",
    "harmloses": "harmlos",
    "harmloseste": "harmlos",
    "harmlosestem": "harmlos",
    "harmlosesten": "harmlos",
    "harmlosester": "harmlos",
    "harmlosestes": "harmlos",
    "harmoniere": "harmonieren",
    "harmonierend": "harmonieren",
    "harmonierende": "harmonierend",
    "harmonierendem": "harmonierend",
    "harmonierenden": "harmonierend",
    "harmonierender": "harmonierend",
    "harmonierendere": "harmonierend",
    "harmonierenderem": "harmonierend",
    "harmonierenderen": "harmonierend",
    "harmonierenderer": "harmonierend",
    "harmonierenderes": "harmonierend",
    "harmonierendes": "harmonierend",
    "harmonierendste": "harmonierend",
    "harmonierendstem": "harmonierend",
    "harmonierendsten": "harmonierend",
    "harmonierendster": "harmonierend",
    "harmonierendstes": "harmonierend",
    "harmonierest": "harmonieren",
    "harmonieret": "harmonieren",
    "harmonierst": "harmonieren",
    "harmoniert": "harmonieren",
    "harmonierte": "harmonieren",
    "harmoniertem": "harmoniert",
    "harmonierten": "harmonieren",
    "harmonierter": "harmoniert",
    "harmoniertere": "harmoniert",
    "harmonierterem": "harmoniert",
    "harmonierteren": "harmoniert",
    "harmonierterer": "harmoniert",
    "harmonierteres": "harmoniert",
    "harmoniertes": "harmoniert",
    "harmoniertest": "harmonieren",
    "harmonierteste": "harmoniert",
    "harmoniertestem": "harmoniert",
    "harmoniertesten": "harmoniert",
    "harmoniertester": "harmoniert",
    "harmoniertestes": "harmoniert",
    "harmoniertet": "harmonieren",
    "harmonischem": "harmonisch",
    "harmonischen": "harmonisch",
    "harmonischer": "harmonisch",
    "harmonischere": "harmonisch",
    "harmonischerem": "harmonisch",
    "harmonischeren": "harmonisch",
    "harmonischerer": "harmonisch",
    "harmonischeres": "harmonisch",
    "harmonisches": "harmonisch",
    "harmonischste": "harmonisch",
    "harmonischstem": "harmonisch",
    "harmonischsten": "harmonisch",
    "harmonischster": "harmonisch",
    "harmonischstes": "harmonisch",
    "harmonisiere": "harmonisieren",
    "harmonisierend": "harmonisieren",
    "harmonisierende": "harmonisierend",
    "harmonisierendem": "harmonisierend",
    "harmonisierenden": "harmonisierend",
    "harmonisierender": "harmonisierend",
    "harmonisierendere": "harmonisierend",
    "harmonisierenderem": "harmonisierend",
    "harmonisierenderen": "harmonisierend",
    "harmonisierenderer": "harmonisierend",
    "harmonisierenderes": "harmonisierend",
    "harmonisierendes": "harmonisierend",
    "harmonisierendste": "harmonisierend",
    "harmonisierendstem": "harmonisierend",
    "harmonisierendsten": "harmonisierend",
    "harmonisierendster": "harmonisierend",
    "harmonisierendstes": "harmonisierend",
    "harmonisierest": "harmonisieren",
    "harmonisieret": "harmonisieren",
    "harmonisierst": "harmonisieren",
    "harmonisiert": "harmonisieren",
    "harmonisierte": "harmonisieren",
    "harmonisiertem": "harmonisiert",
    "harmonisierten": "harmonisieren",
    "harmonisierter": "harmonisiert",
    "harmonisiertere": "harmonisiert",
    "harmonisierterem": "harmonisiert",
    "harmonisierteren": "harmonisiert",
    "harmonisierterer": "harmonisiert",
    "harmonisierteres": "harmonisiert",
    "harmonisiertes": "harmonisiert",
    "harmonisiertest": "harmonisieren",
    "harmonisierteste": "harmonisiert",
    "harmonisiertestem": "harmonisiert",
    "harmonisiertesten": "harmonisiert",
    "harmonisiertester": "harmonisiert",
    "harmonisiertestes": "harmonisiert",
    "harmonisiertet": "harmonisieren",
    "harntreibendem": "harntreibend",
    "harntreibenden": "harntreibend",
    "harntreibender": "harntreibend",
    "harntreibendere": "harntreibend",
    "harntreibenderem": "harntreibend",
    "harntreibenderen": "harntreibend",
    "harntreibenderer": "harntreibend",
    "harntreibenderes": "harntreibend",
    "harntreibendes": "harntreibend",
    "harntreibendste": "harntreibend",
    "harntreibendstem": "harntreibend",
    "harntreibendsten": "harntreibend",
    "harntreibendster": "harntreibend",
    "harntreibendstes": "harntreibend",
    "harpuniere": "harpunieren",
    "harpunierend": "harpunieren",
    "harpunierende": "harpunierend",
    "harpunierendem": "harpunierend",
    "harpunierenden": "harpunierend",
    "harpunierender": "harpunierend",
    "harpunierendes": "harpunierend",
    "harpunierest": "harpunieren",
    "harpunieret": "harpunieren",
    "harpunierst": "harpunieren",
    "harpuniert": "harpunieren",
    "harpunierte": "harpunieren",
    "harpuniertem": "harpuniert",
    "harpunierten": "harpunieren",
    "harpunierter": "harpuniert",
    "harpuniertes": "harpuniert",
    "harpuniertest": "harpunieren",
    "harpuniertet": "harpunieren",
    "harre": "harren",
    "harrend": "harren",
    "harrende": "harrend",
    "harrendem": "harrend",
    "harrenden": "harrend",
    "harrender": "harrend",
    "harrendes": "harrend",
    "harrest": "harren",
    "harret": "harren",
    "harrst": "harren",
    "harrt": "harren",
    "harrte": "harren",
    "harrten": "harren",
    "harrtest": "harren",
    "harrtet": "harren",
    "harschem": "harsch",
    "harschen": "harsch",
    "harscher": "harsch",
    "harschere": "harsch",
    "harscherem": "harsch",
    "harscheren": "harsch",
    "harscherer": "harsch",
    "harscheres": "harsch",
    "harsches": "harsch",
    "harschige": "harschig",
    "harschigem": "harschig",
    "harschigen": "harschig",
    "harschiger": "harschig",
    "harschigere": "harschig",
    "harschigerem": "harschig",
    "harschigeren": "harschig",
    "harschigerer": "harschig",
    "harschigeres": "harschig",
    "harschiges": "harschig",
    "harschigste": "harschig",
    "harschigstem": "harschig",
    "harschigsten": "harschig",
    "harschigster": "harschig",
    "harschigstes": "harschig",
    "harschste": "harsch",
    "harschstem": "harsch",
    "harschsten": "harsch",
    "harschster": "harsch",
    "harschstes": "harsch",
    "harte": "hart",
    "hartem": "hart",
    "harter": "hart",
    "hartes": "hart",
    "hartgelötet": "hartlöten",
    "hartgelötete": "hartgelötet",
    "hartgelötetem": "hartgelötet",
    "hartgelöteten": "hartgelötet",
    "hartgelöteter": "hartgelötet",
    "hartgelötetes": "hartgelötet",
    "hartgesottene": "hartgesotten",
    "hartgesottenem": "hartgesotten",
    "hartgesottenen": "hartgesotten",
    "hartgesottener": "hartgesotten",
    "hartgesottenere": "hartgesotten",
    "hartgesottenerem": "hartgesotten",
    "hartgesotteneren": "hartgesotten",
    "hartgesottenerer": "hartgesotten",
    "hartgesotteneres": "hartgesotten",
    "hartgesottenes": "hartgesotten",
    "hartgesottenste": "hartgesotten",
    "hartgesottenstem": "hartgesotten",
    "hartgesottensten": "hartgesotten",
    "hartgesottenster": "hartgesotten",
    "hartgesottenstes": "hartgesotten",
    "hartherzigem": "hartherzig",
    "hartherzigen": "hartherzig",
    "hartherziger": "hartherzig",
    "hartherzigere": "hartherzig",
    "hartherzigerem": "hartherzig",
    "hartherzigeren": "hartherzig",
    "hartherzigerer": "hartherzig",
    "hartherzigeres": "hartherzig",
    "hartherziges": "hartherzig",
    "hartherzigste": "hartherzig",
    "hartherzigstem": "hartherzig",
    "hartherzigsten": "hartherzig",
    "hartherzigster": "hartherzig",
    "hartherzigstes": "hartherzig",
    "hartlöte": "hartlöten",
    "hartlötend": "hartlöten",
    "hartlötende": "hartlötend",
    "hartlötendem": "hartlötend",
    "hartlötenden": "hartlötend",
    "hartlötender": "hartlötend",
    "hartlötendes": "hartlötend",
    "hartlötest": "hartlöten",
    "hartlötet": "hartlöten",
    "hartlötete": "hartlöten",
    "hartlöteten": "hartlöten",
    "hartlötetest": "hartlöten",
    "hartlötetet": "hartlöten",
    "hartnäckigem": "hartnäckig",
    "hartnäckigen": "hartnäckig",
    "hartnäckiger": "hartnäckig",
    "hartnäckigere": "hartnäckig",
    "hartnäckigerem": "hartnäckig",
    "hartnäckigeren": "hartnäckig",
    "hartnäckigerer": "hartnäckig",
    "hartnäckigeres": "hartnäckig",
    "hartnäckiges": "hartnäckig",
    "hartnäckigste": "hartnäckig",
    "hartnäckigstem": "hartnäckig",
    "hartnäckigsten": "hartnäckig",
    "hartnäckigster": "hartnäckig",
    "hartnäckigstes": "hartnäckig",
    "hartzulöten": "hartlöten",
    "harze": "harzen",
    "harzend": "harzen",
    "harzende": "harzend",
    "harzendem": "harzend",
    "harzenden": "harzend",
    "harzender": "harzend",
    "harzendere": "harzend",
    "harzenderem": "harzend",
    "harzenderen": "harzend",
    "harzenderer": "harzend",
    "harzenderes": "harzend",
    "harzendes": "harzend",
    "harzendste": "harzend",
    "harzendstem": "harzend",
    "harzendsten": "harzend",
    "harzendster": "harzend",
    "harzendstes": "harzend",
    "harzest": "harzen",
    "harzet": "harzen",
    "harzige": "harzig",
    "harzigem": "harzig",
    "harzigen": "harzig",
    "harziger": "harzig",
    "harzigere": "harzig",
    "harzigerem": "harzig",
    "harzigeren": "harzig",
    "harzigerer": "harzig",
    "harzigeres": "harzig",
    "harziges": "harzig",
    "harzigste": "harzig",
    "harzigstem": "harzig",
    "harzigsten": "harzig",
    "harzigster": "harzig",
    "harzigstes": "harzig",
    "harzt": "harzen",
    "harzte": "harzen",
    "harzten": "harzen",
    "harztest": "harzen",
    "harztet": "harzen",
    "hasche": "haschen",
    "haschend": "haschen",
    "haschende": "haschend",
    "haschendem": "haschend",
    "haschenden": "haschend",
    "haschender": "haschend",
    "haschendere": "haschend",
    "haschenderem": "haschend",
    "haschenderen": "haschend",
    "haschenderer": "haschend",
    "haschenderes": "haschend",
    "haschendes": "haschend",
    "haschendste": "haschend",
    "haschendstem": "haschend",
    "haschendsten": "haschend",
    "haschendster": "haschend",
    "haschendstes": "haschend",
    "haschest": "haschen",
    "haschet": "haschen",
    "haschst": "haschen",
    "hascht": "haschen",
    "haschte": "haschen",
    "haschten": "haschen",
    "haschtest": "haschen",
    "haschtet": "haschen",
    "haspele": "haspeln",
    "haspelnd": "haspeln",
    "haspelnde": "haspelnd",
    "haspelndem": "haspelnd",
    "haspelnden": "haspelnd",
    "haspelnder": "haspelnd",
    "haspelndere": "haspelnd",
    "haspelnderem": "haspelnd",
    "haspelnderen": "haspelnd",
    "haspelnderer": "haspelnd",
    "haspelnderes": "haspelnd",
    "haspelndes": "haspelnd",
    "haspelndste": "haspelnd",
    "haspelndstem": "haspelnd",
    "haspelndsten": "haspelnd",
    "haspelndster": "haspelnd",
    "haspelndstes": "haspelnd",
    "haspelst": "haspeln",
    "haspelt": "haspeln",
    "haspelte": "haspeln",
    "haspelten": "haspeln",
    "haspeltest": "haspeln",
    "haspeltet": "haspeln",
    "hasple": "haspeln",
    "hassend": "hassen",
    "hassende": "hassend",
    "hassendem": "hassend",
    "hassenden": "hassend",
    "hassender": "hassend",
    "hassendere": "hassend",
    "hassenderem": "hassend",
    "hassenderen": "hassend",
    "hassenderer": "hassend",
    "hassenderes": "hassend",
    "hassendes": "hassend",
    "hassendste": "hassend",
    "hassendstem": "hassend",
    "hassendsten": "hassend",
    "hassendster": "hassend",
    "hassendstes": "hassend",
    "hassest": "hassen",
    "hasset": "hassen",
    "hast": "haben",
    "haste": "hasten",
    "hastend": "hasten",
    "hastende": "hastend",
    "hastendem": "hastend",
    "hastenden": "hastend",
    "hastender": "hastend",
    "hastendere": "hastend",
    "hastenderem": "hastend",
    "hastenderen": "hastend",
    "hastenderer": "hastend",
    "hastenderes": "hastend",
    "hastendes": "hastend",
    "hastendste": "hastend",
    "hastendstem": "hastend",
    "hastendsten": "hastend",
    "hastendster": "hastend",
    "hastendstes": "hastend",
    "hastest": "hasten",
    "hastet": "hasten",
    "hastete": "hasten",
    "hasteten": "hasten",
    "hastetest": "hasten",
    "hastetet": "hasten",
    "hastige": "hastig",
    "hastigem": "hastig",
    "hastigen": "hastig",
    "hastiger": "hastig",
    "hastigere": "hastig",
    "hastigerem": "hastig",
    "hastigeren": "hastig",
    "hastigerer": "hastig",
    "hastigeres": "hastig",
    "hastiges": "hastig",
    "hastigste": "hastig",
    "hastigstem": "hastig",
    "hastigsten": "hastig",
    "hastigster": "hastig",
    "hastigstes": "hastig",
    "hat": "haben",
    "hatte": "haben",
    "hatten": "haben",
    "hattest": "haben",
    "hattet": "haben",
    "hauchdünnem": "hauchdünn",
    "hauchdünnen": "hauchdünn",
    "hauchdünner": "hauchdünn",
    "hauchdünnes": "hauchdünn",
    "hauchend": "hauchen",
    "hauchende": "hauchend",
    "hauchendem": "hauchend",
    "hauchenden": "hauchend",
    "hauchender": "hauchend",
    "hauchendere": "hauchend",
    "hauchenderem": "hauchend",
    "hauchenderen": "hauchend",
    "hauchenderer": "hauchend",
    "hauchenderes": "hauchend",
    "hauchendes": "hauchend",
    "hauchendste": "hauchend",
    "hauchendstem": "hauchend",
    "hauchendsten": "hauchend",
    "hauchendster": "hauchend",
    "hauchendstes": "hauchend",
    "hauchest": "hauchen",
    "hauchet": "hauchen",
    "hauchst": "hauchen",
    "haucht": "hauchen",
    "hauchte": "hauchen",
    "hauchten": "hauchen",
    "hauchtest": "hauchen",
    "hauchtet": "hauchen",
    "hauchzarte": "hauchzart",
    "hauchzartem": "hauchzart",
    "hauchzarten": "hauchzart",
    "hauchzarter": "hauchzart",
    "hauchzartere": "hauchzart",
    "hauchzarterem": "hauchzart",
    "hauchzarteren": "hauchzart",
    "hauchzarterer": "hauchzart",
    "hauchzarteres": "hauchzart",
    "hauchzartes": "hauchzart",
    "hauchzarteste": "hauchzart",
    "hauchzartestem": "hauchzart",
    "hauchzartesten": "hauchzart",
    "hauchzartester": "hauchzart",
    "hauchzartestes": "hauchzart",
    "haue": "hauen",
    "hauend": "hauen",
    "hauende": "hauend",
    "hauendem": "hauend",
    "hauenden": "hauend",
    "hauender": "hauend",
    "hauendes": "hauend",
    "hauest": "hauen",
    "hauet": "hauen",
    "hauptamtliche": "hauptamtlich",
    "hauptamtlichem": "hauptamtlich",
    "hauptamtlichen": "hauptamtlich",
    "hauptamtlicher": "hauptamtlich",
    "hauptamtliches": "hauptamtlich",
    "hauptberuflichem": "hauptberuflich",
    "hauptberuflichen": "hauptberuflich",
    "hauptberuflicher": "hauptberuflich",
    "hauptberufliches": "hauptberuflich",
    "hauptstädtischem": "hauptstädtisch",
    "hauptstädtischen": "hauptstädtisch",
    "hauptstädtischer": "hauptstädtisch",
    "hauptstädtisches": "hauptstädtisch",
    "hauptsächlichem": "hauptsächlich",
    "hauptsächlichen": "hauptsächlich",
    "hauptsächlicher": "hauptsächlich",
    "hauptsächliches": "hauptsächlich",
    "hausend": "hausen",
    "hausende": "hausend",
    "hausendem": "hausend",
    "hausenden": "hausend",
    "hausender": "hausend",
    "hausendes": "hausend",
    "hausest": "hausen",
    "hauset": "hausen",
    "hausgemachte": "hausgemacht",
    "hausgemachtem": "hausgemacht",
    "hausgemachten": "hausgemacht",
    "hausgemachter": "hausgemacht",
    "hausgemachtes": "hausgemacht",
    "hausiere": "hausieren",
    "hausierend": "hausieren",
    "hausierende": "hausierend",
    "hausierendem": "hausierend",
    "hausierenden": "hausierend",
    "hausierender": "hausierend",
    "hausierendes": "hausierend",
    "hausierest": "hausieren",
    "hausieret": "hausieren",
    "hausierst": "hausieren",
    "hausiert": "hausieren",
    "hausierte": "hausieren",
    "hausiertem": "hausiert",
    "hausierten": "hausieren",
    "hausierter": "hausiert",
    "hausiertes": "hausiert",
    "hausiertest": "hausieren",
    "hausiertet": "hausieren",
    "haust": "hausen",
    "hauste": "hausen",
    "hausten": "hausen",
    "haustest": "hausen",
    "haustet": "hausen",
    "haute": "hauen",
    "hauten": "hauen",
    "hautenge": "hauteng",
    "hautengem": "hauteng",
    "hautengen": "hauteng",
    "hautenger": "hauteng",
    "hautenges": "hauteng",
    "hautest": "hauen",
    "hautet": "hauen",
    "hawaiischem": "hawaiisch",
    "hawaiischen": "hawaiisch",
    "hawaiischer": "hawaiisch",
    "hawaiisches": "hawaiisch",
    "haßerfülltem": "haßerfüllt",
    "haßerfüllten": "haßerfüllt",
    "haßerfüllter": "haßerfüllt",
    "haßerfülltere": "haßerfüllt",
    "haßerfüllterem": "haßerfüllt",
    "haßerfüllteren": "haßerfüllt",
    "haßerfüllterer": "haßerfüllt",
    "haßerfüllteres": "haßerfüllt",
    "haßerfülltes": "haßerfüllt",
    "haßerfüllteste": "haßerfüllt",
    "haßerfülltestem": "haßerfüllt",
    "haßerfülltesten": "haßerfüllt",
    "haßerfülltester": "haßerfüllt",
    "haßerfülltestes": "haßerfüllt",
    "haßt": "hassen",
    "haßte": "hassen",
    "haßten": "hassen",
    "haßtest": "hassen",
    "haßtet": "hassen",
    "hebe": "heben",
    "hebend": "heben",
    "hebende": "hebend",
    "hebendem": "hebend",
    "hebenden": "hebend",
    "hebender": "hebend",
    "hebendes": "hebend",
    "hebest": "heben",
    "hebet": "heben",
    "hebst": "heben",
    "hebt": "heben",
    "hechele": "hecheln",
    "hechelnd": "hecheln",
    "hechelnde": "hechelnd",
    "hechelndem": "hechelnd",
    "hechelnden": "hechelnd",
    "hechelnder": "hechelnd",
    "hechelndere": "hechelnd",
    "hechelnderem": "hechelnd",
    "hechelnderen": "hechelnd",
    "hechelnderer": "hechelnd",
    "hechelnderes": "hechelnd",
    "hechelndes": "hechelnd",
    "hechelndste": "hechelnd",
    "hechelndstem": "hechelnd",
    "hechelndsten": "hechelnd",
    "hechelndster": "hechelnd",
    "hechelndstes": "hechelnd",
    "hechelst": "hecheln",
    "hechelt": "hecheln",
    "hechelte": "hecheln",
    "hechelten": "hecheln",
    "hecheltest": "hecheln",
    "hecheltet": "hecheln",
    "hechle": "hecheln",
    "hechte": "hechten",
    "hechtend": "hechten",
    "hechtende": "hechtend",
    "hechtendem": "hechtend",
    "hechtenden": "hechtend",
    "hechtender": "hechtend",
    "hechtendere": "hechtend",
    "hechtenderem": "hechtend",
    "hechtenderen": "hechtend",
    "hechtenderer": "hechtend",
    "hechtenderes": "hechtend",
    "hechtendes": "hechtend",
    "hechtendste": "hechtend",
    "hechtendstem": "hechtend",
    "hechtendsten": "hechtend",
    "hechtendster": "hechtend",
    "hechtendstes": "hechtend",
    "hechtest": "hechten",
    "hechtet": "hechten",
    "hechtete": "hechten",
    "hechteten": "hechten",
    "hechtetest": "hechten",
    "hechtetet": "hechten",
    "heftend": "heften",
    "heftende": "heftend",
    "heftendem": "heftend",
    "heftenden": "heftend",
    "heftender": "heftend",
    "heftendes": "heftend",
    "heftest": "heften",
    "heftet": "heften",
    "heftete": "heften",
    "hefteten": "heften",
    "heftetest": "heften",
    "heftetet": "heften",
    "heftige": "heftig",
    "heftigem": "heftig",
    "heftigen": "heftig",
    "heftiger": "heftig",
    "heftigere": "heftig",
    "heftigerem": "heftig",
    "heftigeren": "heftig",
    "heftigerer": "heftig",
    "heftigeres": "heftig",
    "heftiges": "heftig",
    "heftigstem": "heftig",
    "heftigsten": "heftig",
    "heftigster": "heftig",
    "heftigstes": "heftig",
    "hege": "hegen",
    "hegend": "hegen",
    "hegende": "hegend",
    "hegendem": "hegend",
    "hegenden": "hegend",
    "hegender": "hegend",
    "hegendere": "hegend",
    "hegenderem": "hegend",
    "hegenderen": "hegend",
    "hegenderer": "hegend",
    "hegenderes": "hegend",
    "hegendes": "hegend",
    "hegendste": "hegend",
    "hegendstem": "hegend",
    "hegendsten": "hegend",
    "hegendster": "hegend",
    "hegendstes": "hegend",
    "hegest": "hegen",
    "heget": "hegen",
    "hegst": "hegen",
    "hegt": "hegen",
    "hegte": "hegen",
    "hegten": "hegen",
    "hegtest": "hegen",
    "hegtet": "hegen",
    "heidnischem": "heidnisch",
    "heidnischen": "heidnisch",
    "heidnischer": "heidnisch",
    "heidnischere": "heidnisch",
    "heidnischerem": "heidnisch",
    "heidnischeren": "heidnisch",
    "heidnischerer": "heidnisch",
    "heidnischeres": "heidnisch",
    "heidnisches": "heidnisch",
    "heidnischste": "heidnisch",
    "heidnischstem": "heidnisch",
    "heidnischsten": "heidnisch",
    "heidnischster": "heidnisch",
    "heidnischstes": "heidnisch",
    "heikelste": "heikel",
    "heikelstem": "heikel",
    "heikelsten": "heikel",
    "heikelster": "heikel",
    "heikelstes": "heikel",
    "heiklem": "heikel",
    "heiklen": "heikel",
    "heikler": "heikel",
    "heiklere": "heikel",
    "heiklerem": "heikel",
    "heikleren": "heikel",
    "heiklerer": "heikel",
    "heikleres": "heikel",
    "heikles": "heikel",
    "heilbarem": "heilbar",
    "heilbaren": "heilbar",
    "heilbarer": "heilbar",
    "heilbares": "heilbar",
    "heilbringende": "heilbringend",
    "heilbringendem": "heilbringend",
    "heilbringenden": "heilbringend",
    "heilbringender": "heilbringend",
    "heilbringendes": "heilbringend",
    "heilend": "heilen",
    "heilende": "heilend",
    "heilendem": "heilend",
    "heilenden": "heilend",
    "heilender": "heilend",
    "heilendes": "heilend",
    "heilest": "heilen",
    "heilet": "heilen",
    "heilfrohe": "heilfroh",
    "heilfrohem": "heilfroh",
    "heilfrohen": "heilfroh",
    "heilfroher": "heilfroh",
    "heilfrohes": "heilfroh",
    "heilige": "heilig",
    "heiligem": "heilig",
    "heiligen": "heilig",
    "heiliger": "heilig",
    "heiligere": "heilig",
    "heiligerem": "heilig",
    "heiligeren": "heilig",
    "heiligerer": "heilig",
    "heiligeres": "heilig",
    "heiliges": "heilig",
    "heiliggesprochen": "heiligsprechen",
    "heiliggesprochene": "heiliggesprochen",
    "heiliggesprochenem": "heiliggesprochen",
    "heiliggesprochenen": "heiliggesprochen",
    "heiliggesprochener": "heiliggesprochen",
    "heiliggesprochenes": "heiliggesprochen",
    "heiligsprach": "heiligsprechen",
    "heiligsprachen": "heiligsprechen",
    "heiligsprachst": "heiligsprechen",
    "heiligspracht": "heiligsprechen",
    "heiligspreche": "heiligsprechen",
    "heiligsprechend": "heiligsprechen",
    "heiligsprechende": "heiligsprechend",
    "heiligsprechendem": "heiligsprechend",
    "heiligsprechenden": "heiligsprechend",
    "heiligsprechender": "heiligsprechend",
    "heiligsprechendes": "heiligsprechend",
    "heiligsprechest": "heiligsprechen",
    "heiligsprechet": "heiligsprechen",
    "heiligsprecht": "heiligsprechen",
    "heiligsprichst": "heiligsprechen",
    "heiligspricht": "heiligsprechen",
    "heiligspräche": "heiligsprechen",
    "heiligsprächen": "heiligsprechen",
    "heiligsprächest": "heiligsprechen",
    "heiligsprächet": "heiligsprechen",
    "heiligste": "heilig",
    "heiligstem": "heilig",
    "heiligsten": "heilig",
    "heiligster": "heilig",
    "heiligstes": "heilig",
    "heiligzusprechen": "heiligsprechen",
    "heillosem": "heillos",
    "heillosen": "heillos",
    "heilloser": "heillos",
    "heilloses": "heillos",
    "heilsamem": "heilsam",
    "heilsamen": "heilsam",
    "heilsamer": "heilsam",
    "heilsamere": "heilsam",
    "heilsamerem": "heilsam",
    "heilsameren": "heilsam",
    "heilsamerer": "heilsam",
    "heilsameres": "heilsam",
    "heilsames": "heilsam",
    "heilsamste": "heilsam",
    "heilsamstem": "heilsam",
    "heilsamsten": "heilsam",
    "heilsamster": "heilsam",
    "heilsamstes": "heilsam",
    "heilst": "heilen",
    "heilt": "heilen",
    "heilte": "heilen",
    "heilten": "heilen",
    "heiltest": "heilen",
    "heiltet": "heilen",
    "heimatlichem": "heimatlich",
    "heimatlichen": "heimatlich",
    "heimatlicher": "heimatlich",
    "heimatlichere": "heimatlich",
    "heimatlicherem": "heimatlich",
    "heimatlicheren": "heimatlich",
    "heimatlicherer": "heimatlich",
    "heimatlicheres": "heimatlich",
    "heimatliches": "heimatlich",
    "heimatlichste": "heimatlich",
    "heimatlichstem": "heimatlich",
    "heimatlichsten": "heimatlich",
    "heimatlichster": "heimatlich",
    "heimatlichstes": "heimatlich",
    "heimatlose": "heimatlos",
    "heimatlosem": "heimatlos",
    "heimatlosen": "heimatlos",
    "heimatloser": "heimatlos",
    "heimatloses": "heimatlos",
    "heimbegab": "heimbegeben",
    "heimbegaben": "heimbegeben",
    "heimbegabst": "heimbegeben",
    "heimbegabt": "heimbegeben",
    "heimbegebe": "heimbegeben",
    "heimbegebend": "heimbegeben",
    "heimbegebende": "heimbegebend",
    "heimbegebendem": "heimbegebend",
    "heimbegebenden": "heimbegebend",
    "heimbegebender": "heimbegebend",
    "heimbegebendes": "heimbegebend",
    "heimbegebene": "heimbegeben",
    "heimbegebenem": "heimbegeben",
    "heimbegebenen": "heimbegeben",
    "heimbegebener": "heimbegeben",
    "heimbegebenes": "heimbegeben",
    "heimbegebest": "heimbegeben",
    "heimbegebet": "heimbegeben",
    "heimbegebt": "heimbegeben",
    "heimbegibst": "heimbegeben",
    "heimbegibt": "heimbegeben",
    "heimbegleite": "heimbegleiten",
    "heimbegleitend": "heimbegleiten",
    "heimbegleitende": "heimbegleitend",
    "heimbegleitendem": "heimbegleitend",
    "heimbegleitenden": "heimbegleitend",
    "heimbegleitender": "heimbegleitend",
    "heimbegleitendes": "heimbegleitend",
    "heimbegleitest": "heimbegleiten",
    "heimbegleitet": "heimbegleiten",
    "heimbegleitete": "heimbegleiten",
    "heimbegleitetem": "heimbegleitet",
    "heimbegleiteten": "heimbegleiten",
    "heimbegleiteter": "heimbegleitet",
    "heimbegleitetes": "heimbegleitet",
    "heimbegleitetest": "heimbegleiten",
    "heimbegleitetet": "heimbegleiten",
    "heimbegäbe": "heimbegeben",
    "heimbegäben": "heimbegeben",
    "heimbegäbest": "heimbegeben",
    "heimbegäbet": "heimbegeben",
    "heimbrachte": "heimbringen",
    "heimbrachten": "heimbringen",
    "heimbrachtest": "heimbringen",
    "heimbrachtet": "heimbringen",
    "heimbringe": "heimbringen",
    "heimbringend": "heimbringen",
    "heimbringende": "heimbringend",
    "heimbringendem": "heimbringend",
    "heimbringenden": "heimbringend",
    "heimbringender": "heimbringend",
    "heimbringendes": "heimbringend",
    "heimbringest": "heimbringen",
    "heimbringet": "heimbringen",
    "heimbringst": "heimbringen",
    "heimbringt": "heimbringen",
    "heimbrächte": "heimbringen",
    "heimbrächten": "heimbringen",
    "heimbrächtest": "heimbringen",
    "heimbrächtet": "heimbringen",
    "heimele": "heimeln",
    "heimelige": "heimelig",
    "heimeligem": "heimelig",
    "heimeligen": "heimelig",
    "heimeliger": "heimelig",
    "heimeligere": "heimelig",
    "heimeligerem": "heimelig",
    "heimeligeren": "heimelig",
    "heimeligerer": "heimelig",
    "heimeligeres": "heimelig",
    "heimeliges": "heimelig",
    "heimeligste": "heimelig",
    "heimeligstem": "heimelig",
    "heimeligsten": "heimelig",
    "heimeligster": "heimelig",
    "heimeligstes": "heimelig",
    "heimelnd": "heimeln",
    "heimelnde": "heimelnd",
    "heimelndem": "heimelnd",
    "heimelnden": "heimelnd",
    "heimelnder": "heimelnd",
    "heimelndere": "heimelnd",
    "heimelnderem": "heimelnd",
    "heimelnderen": "heimelnd",
    "heimelnderer": "heimelnd",
    "heimelnderes": "heimelnd",
    "heimelndes": "heimelnd",
    "heimelndste": "heimelnd",
    "heimelndstem": "heimelnd",
    "heimelndsten": "heimelnd",
    "heimelndster": "heimelnd",
    "heimelndstes": "heimelnd",
    "heimelst": "heimeln",
    "heimelt": "heimeln",
    "heimelte": "heimeln",
    "heimelten": "heimeln",
    "heimeltest": "heimeln",
    "heimeltet": "heimeln",
    "heimfalle": "heimfallen",
    "heimfallend": "heimfallen",
    "heimfallende": "heimfallend",
    "heimfallendem": "heimfallend",
    "heimfallenden": "heimfallend",
    "heimfallender": "heimfallend",
    "heimfallendes": "heimfallend",
    "heimfallest": "heimfallen",
    "heimfallet": "heimfallen",
    "heimfallt": "heimfallen",
    "heimfand": "heimfinden",
    "heimfanden": "heimfinden",
    "heimfandest": "heimfinden",
    "heimfandet": "heimfinden",
    "heimfiel": "heimfallen",
    "heimfiele": "heimfallen",
    "heimfielen": "heimfallen",
    "heimfielest": "heimfallen",
    "heimfielet": "heimfallen",
    "heimfielst": "heimfallen",
    "heimfielt": "heimfallen",
    "heimfinde": "heimfinden",
    "heimfindend": "heimfinden",
    "heimfindende": "heimfindend",
    "heimfindendem": "heimfindend",
    "heimfindenden": "heimfindend",
    "heimfindender": "heimfindend",
    "heimfindendes": "heimfindend",
    "heimfindest": "heimfinden",
    "heimfindet": "heimfinden",
    "heimfällst": "heimfallen",
    "heimfällt": "heimfallen",
    "heimfände": "heimfinden",
    "heimfänden": "heimfinden",
    "heimfändest": "heimfinden",
    "heimfändet": "heimfinden",
    "heimführe": "heimführen",
    "heimführend": "heimführen",
    "heimführende": "heimführend",
    "heimführendem": "heimführend",
    "heimführenden": "heimführend",
    "heimführender": "heimführend",
    "heimführendes": "heimführend",
    "heimführest": "heimführen",
    "heimführet": "heimführen",
    "heimführst": "heimführen",
    "heimführt": "heimführen",
    "heimführte": "heimführen",
    "heimführten": "heimführen",
    "heimführtest": "heimführen",
    "heimführtet": "heimführen",
    "heimgebracht": "heimbringen",
    "heimgebrachte": "heimgebracht",
    "heimgebrachtem": "heimgebracht",
    "heimgebrachten": "heimgebracht",
    "heimgebrachter": "heimgebracht",
    "heimgebrachtes": "heimgebracht",
    "heimgefallen": "heimfallen",
    "heimgefallene": "heimgefallen",
    "heimgefallenem": "heimgefallen",
    "heimgefallenen": "heimgefallen",
    "heimgefallener": "heimgefallen",
    "heimgefallenes": "heimgefallen",
    "heimgefunden": "heimfinden",
    "heimgefundene": "heimgefunden",
    "heimgefundenem": "heimgefunden",
    "heimgefundenen": "heimgefunden",
    "heimgefundener": "heimgefunden",
    "heimgefundenes": "heimgefunden",
    "heimgeführt": "heimführen",
    "heimgeführte": "heimgeführt",
    "heimgeführtem": "heimgeführt",
    "heimgeführten": "heimgeführt",
    "heimgeführter": "heimgeführt",
    "heimgeführtes": "heimgeführt",
    "heimgegeigt": "heimgeigen",
    "heimgegeigte": "heimgegeigt",
    "heimgegeigtem": "heimgegeigt",
    "heimgegeigten": "heimgegeigt",
    "heimgegeigter": "heimgegeigt",
    "heimgegeigtes": "heimgegeigt",
    "heimgeholt": "heimholen",
    "heimgeholte": "heimgeholt",
    "heimgeholtem": "heimgeholt",
    "heimgeholten": "heimgeholt",
    "heimgeholter": "heimgeholt",
    "heimgeholtes": "heimgeholt",
    "heimgeige": "heimgeigen",
    "heimgeigend": "heimgeigen",
    "heimgeigende": "heimgeigend",
    "heimgeigendem": "heimgeigend",
    "heimgeigenden": "heimgeigend",
    "heimgeigender": "heimgeigend",
    "heimgeigendes": "heimgeigend",
    "heimgeigest": "heimgeigen",
    "heimgeiget": "heimgeigen",
    "heimgeigst": "heimgeigen",
    "heimgeigt": "heimgeigen",
    "heimgeigte": "heimgeigen",
    "heimgeigten": "heimgeigen",
    "heimgeigtest": "heimgeigen",
    "heimgeigtet": "heimgeigen",
    "heimgekehrt": "heimkehren",
    "heimgekehrte": "heimgekehrt",
    "heimgekehrtem": "heimgekehrt",
    "heimgekehrten": "heimgekehrt",
    "heimgekehrter": "heimgekehrt",
    "heimgekehrtes": "heimgekehrt",
    "heimgekommen": "heimkommen",
    "heimgekommene": "heimgekommen",
    "heimgekommenem": "heimgekommen",
    "heimgekommenen": "heimgekommen",
    "heimgekommener": "heimgekommen",
    "heimgekommenes": "heimgekommen",
    "heimgeleuchtet": "heimleuchten",
    "heimgeleuchtete": "heimgeleuchtet",
    "heimgeleuchtetem": "heimgeleuchtet",
    "heimgeleuchteten": "heimgeleuchtet",
    "heimgeleuchteter": "heimgeleuchtet",
    "heimgeleuchtetes": "heimgeleuchtet",
    "heimgenommen": "heimnehmen",
    "heimgenommene": "heimgenommen",
    "heimgenommenem": "heimgenommen",
    "heimgenommenen": "heimgenommen",
    "heimgenommener": "heimgenommen",
    "heimgenommenes": "heimgenommen",
    "heimgereist": "heimreisen",
    "heimgereiste": "heimgereist",
    "heimgereistem": "heimgereist",
    "heimgereisten": "heimgereist",
    "heimgereister": "heimgereist",
    "heimgereistes": "heimgereist",
    "heimgesucht": "heimsuchen",
    "heimgesuchte": "heimgesucht",
    "heimgesuchtem": "heimgesucht",
    "heimgesuchten": "heimgesucht",
    "heimgesuchter": "heimgesucht",
    "heimgesuchtes": "heimgesucht",
    "heimgetragen": "heimtragen",
    "heimgetragene": "heimgetragen",
    "heimgetragenem": "heimgetragen",
    "heimgetragenen": "heimgetragen",
    "heimgetragener": "heimgetragen",
    "heimgetragenes": "heimgetragen",
    "heimgezahlt": "heimzahlen",
    "heimgezahlte": "heimgezahlt",
    "heimgezahltem": "heimgezahlt",
    "heimgezahlten": "heimgezahlt",
    "heimgezahlter": "heimgezahlt",
    "heimgezahltes": "heimgezahlt",
    "heimhole": "heimholen",
    "heimholend": "heimholen",
    "heimholende": "heimholend",
    "heimholendem": "heimholend",
    "heimholenden": "heimholend",
    "heimholender": "heimholend",
    "heimholendes": "heimholend",
    "heimholest": "heimholen",
    "heimholet": "heimholen",
    "heimholst": "heimholen",
    "heimholt": "heimholen",
    "heimholte": "heimholen",
    "heimholten": "heimholen",
    "heimholtest": "heimholen",
    "heimholtet": "heimholen",
    "heimische": "heimisch",
    "heimischem": "heimisch",
    "heimischen": "heimisch",
    "heimischer": "heimisch",
    "heimischere": "heimisch",
    "heimischerem": "heimisch",
    "heimischeren": "heimisch",
    "heimischerer": "heimisch",
    "heimischeres": "heimisch",
    "heimisches": "heimisch",
    "heimischste": "heimisch",
    "heimischstem": "heimisch",
    "heimischsten": "heimisch",
    "heimischster": "heimisch",
    "heimischstes": "heimisch",
    "heimkam": "heimkommen",
    "heimkamen": "heimkommen",
    "heimkamst": "heimkommen",
    "heimkamt": "heimkommen",
    "heimkehre": "heimkehren",
    "heimkehrend": "heimkehren",
    "heimkehrende": "heimkehrend",
    "heimkehrendem": "heimkehrend",
    "heimkehrenden": "heimkehrend",
    "heimkehrender": "heimkehrend",
    "heimkehrendes": "heimkehrend",
    "heimkehrest": "heimkehren",
    "heimkehret": "heimkehren",
    "heimkehrst": "heimkehren",
    "heimkehrt": "heimkehren",
    "heimkehrte": "heimkehren",
    "heimkehrten": "heimkehren",
    "heimkehrtest": "heimkehren",
    "heimkehrtet": "heimkehren",
    "heimkomme": "heimkommen",
    "heimkommend": "heimkommen",
    "heimkommende": "heimkommend",
    "heimkommendem": "heimkommend",
    "heimkommenden": "heimkommend",
    "heimkommender": "heimkommend",
    "heimkommendes": "heimkommend",
    "heimkommest": "heimkommen",
    "heimkommet": "heimkommen",
    "heimkommst": "heimkommen",
    "heimkommt": "heimkommen",
    "heimkäme": "heimkommen",
    "heimkämen": "heimkommen",
    "heimkämest": "heimkommen",
    "heimkämet": "heimkommen",
    "heimle": "heimeln",
    "heimleuchte": "heimleuchten",
    "heimleuchtend": "heimleuchten",
    "heimleuchtende": "heimleuchtend",
    "heimleuchtendem": "heimleuchtend",
    "heimleuchtenden": "heimleuchtend",
    "heimleuchtender": "heimleuchtend",
    "heimleuchtendes": "heimleuchtend",
    "heimleuchtest": "heimleuchten",
    "heimleuchtet": "heimleuchten",
    "heimleuchtete": "heimleuchten",
    "heimleuchteten": "heimleuchten",
    "heimleuchtetest": "heimleuchten",
    "heimleuchtetet": "heimleuchten",
    "heimliche": "heimlich",
    "heimlichem": "heimlich",
    "heimlichen": "heimlich",
    "heimlicher": "heimlich",
    "heimlichere": "heimlich",
    "heimlicherem": "heimlich",
    "heimlicheren": "heimlich",
    "heimlicherer": "heimlich",
    "heimlicheres": "heimlich",
    "heimliches": "heimlich",
    "heimlichste": "heimlich",
    "heimlichstem": "heimlich",
    "heimlichsten": "heimlich",
    "heimlichster": "heimlich",
    "heimlichstes": "heimlich",
    "heimnahm": "heimnehmen",
    "heimnahmen": "heimnehmen",
    "heimnahmst": "heimnehmen",
    "heimnahmt": "heimnehmen",
    "heimnehme": "heimnehmen",
    "heimnehmend": "heimnehmen",
    "heimnehmende": "heimnehmend",
    "heimnehmendem": "heimnehmend",
    "heimnehmenden": "heimnehmend",
    "heimnehmender": "heimnehmend",
    "heimnehmendes": "heimnehmend",
    "heimnehmest": "heimnehmen",
    "heimnehmet": "heimnehmen",
    "heimnehmt": "heimnehmen",
    "heimnimmst": "heimnehmen",
    "heimnimmt": "heimnehmen",
    "heimnähme": "heimnehmen",
    "heimnähmen": "heimnehmen",
    "heimnähmest": "heimnehmen",
    "heimnähmet": "heimnehmen",
    "heimreise": "heimreisen",
    "heimreisend": "heimreisen",
    "heimreisende": "heimreisend",
    "heimreisendem": "heimreisend",
    "heimreisenden": "heimreisend",
    "heimreisender": "heimreisend",
    "heimreisendes": "heimreisend",
    "heimreisest": "heimreisen",
    "heimreiset": "heimreisen",
    "heimreist": "heimreisen",
    "heimreiste": "heimreisen",
    "heimreisten": "heimreisen",
    "heimreistest": "heimreisen",
    "heimreistet": "heimreisen",
    "heimse": "heimsen",
    "heimsend": "heimsen",
    "heimsende": "heimsend",
    "heimsendem": "heimsend",
    "heimsenden": "heimsend",
    "heimsender": "heimsend",
    "heimsendes": "heimsend",
    "heimsest": "heimsen",
    "heimset": "heimsen",
    "heimst": "heimsen",
    "heimste": "heimsen",
    "heimsten": "heimsen",
    "heimstest": "heimsen",
    "heimstet": "heimsen",
    "heimsuche": "heimsuchen",
    "heimsuchend": "heimsuchen",
    "heimsuchende": "heimsuchend",
    "heimsuchendem": "heimsuchend",
    "heimsuchenden": "heimsuchend",
    "heimsuchender": "heimsuchend",
    "heimsuchendes": "heimsuchend",
    "heimsuchest": "heimsuchen",
    "heimsuchet": "heimsuchen",
    "heimsuchst": "heimsuchen",
    "heimsucht": "heimsuchen",
    "heimsuchte": "heimsuchen",
    "heimsuchten": "heimsuchen",
    "heimsuchtest": "heimsuchen",
    "heimsuchtet": "heimsuchen",
    "heimtrage": "heimtragen",
    "heimtragend": "heimtragen",
    "heimtragende": "heimtragend",
    "heimtragendem": "heimtragend",
    "heimtragenden": "heimtragend",
    "heimtragender": "heimtragend",
    "heimtragendes": "heimtragend",
    "heimtragest": "heimtragen",
    "heimtraget": "heimtragen",
    "heimtragt": "heimtragen",
    "heimtrug": "heimtragen",
    "heimtrugen": "heimtragen",
    "heimtrugst": "heimtragen",
    "heimtrugt": "heimtragen",
    "heimträgst": "heimtragen",
    "heimträgt": "heimtragen",
    "heimtrüge": "heimtragen",
    "heimtrügen": "heimtragen",
    "heimtrügest": "heimtragen",
    "heimtrüget": "heimtragen",
    "heimzahle": "heimzahlen",
    "heimzahlend": "heimzahlen",
    "heimzahlende": "heimzahlend",
    "heimzahlendem": "heimzahlend",
    "heimzahlenden": "heimzahlend",
    "heimzahlender": "heimzahlend",
    "heimzahlendes": "heimzahlend",
    "heimzahlest": "heimzahlen",
    "heimzahlet": "heimzahlen",
    "heimzahlst": "heimzahlen",
    "heimzahlt": "heimzahlen",
    "heimzahlte": "heimzahlen",
    "heimzahlten": "heimzahlen",
    "heimzahltest": "heimzahlen",
    "heimzahltet": "heimzahlen",
    "heimzubegeben": "heimbegeben",
    "heimzubegleiten": "heimbegleiten",
    "heimzubringen": "heimbringen",
    "heimzufallen": "heimfallen",
    "heimzufinden": "heimfinden",
    "heimzuführen": "heimführen",
    "heimzugeigen": "heimgeigen",
    "heimzuholen": "heimholen",
    "heimzukehren": "heimkehren",
    "heimzukommen": "heimkommen",
    "heimzuleuchten": "heimleuchten",
    "heimzunehmen": "heimnehmen",
    "heimzureisen": "heimreisen",
    "heimzusuchen": "heimsuchen",
    "heimzutragen": "heimtragen",
    "heimzuzahlen": "heimzahlen",
    "heirate": "heiraten",
    "heiratend": "heiraten",
    "heiratende": "heiratend",
    "heiratendem": "heiratend",
    "heiratenden": "heiratend",
    "heiratender": "heiratend",
    "heiratendes": "heiratend",
    "heiratest": "heiraten",
    "heiratet": "heiraten",
    "heiratete": "heiraten",
    "heirateten": "heiraten",
    "heiratetest": "heiraten",
    "heiratetet": "heiraten",
    "heiratsfähige": "heiratsfähig",
    "heiratsfähigem": "heiratsfähig",
    "heiratsfähigen": "heiratsfähig",
    "heiratsfähiger": "heiratsfähig",
    "heiratsfähigere": "heiratsfähig",
    "heiratsfähigerem": "heiratsfähig",
    "heiratsfähigeren": "heiratsfähig",
    "heiratsfähigerer": "heiratsfähig",
    "heiratsfähigeres": "heiratsfähig",
    "heiratsfähiges": "heiratsfähig",
    "heiratsfähigste": "heiratsfähig",
    "heiratsfähigstem": "heiratsfähig",
    "heiratsfähigsten": "heiratsfähig",
    "heiratsfähigster": "heiratsfähig",
    "heiratsfähigstes": "heiratsfähig",
    "heiratslustige": "heiratslustig",
    "heiratslustigem": "heiratslustig",
    "heiratslustigen": "heiratslustig",
    "heiratslustiger": "heiratslustig",
    "heiratslustigere": "heiratslustig",
    "heiratslustigerem": "heiratslustig",
    "heiratslustigeren": "heiratslustig",
    "heiratslustigerer": "heiratslustig",
    "heiratslustigeres": "heiratslustig",
    "heiratslustiges": "heiratslustig",
    "heiratslustigste": "heiratslustig",
    "heiratslustigstem": "heiratslustig",
    "heiratslustigsten": "heiratslustig",
    "heiratslustigster": "heiratslustig",
    "heiratslustigstes": "heiratslustig",
    "heisere": "heiser",
    "heiserem": "heiser",
    "heiseren": "heiser",
    "heiserer": "heiser",
    "heiserere": "heiser",
    "heisererem": "heiser",
    "heisereren": "heiser",
    "heisererer": "heiser",
    "heisereres": "heiser",
    "heiseres": "heiser",
    "heiserste": "heiser",
    "heiserstem": "heiser",
    "heisersten": "heiser",
    "heiserster": "heiser",
    "heiserstes": "heiser",
    "heiter": "heitern",
    "heitere": "heiter",
    "heiterem": "heiter",
    "heiteren": "heiter",
    "heiterer": "heiter",
    "heiterere": "heiter",
    "heitererem": "heiter",
    "heitereren": "heiter",
    "heitererer": "heiter",
    "heitereres": "heiter",
    "heiteres": "heiter",
    "heiternd": "heitern",
    "heiternde": "heiternd",
    "heiterndem": "heiternd",
    "heiternden": "heiternd",
    "heiternder": "heiternd",
    "heiterndes": "heiternd",
    "heiterst": "heitern",
    "heiterste": "heiter",
    "heiterstem": "heiter",
    "heitersten": "heiter",
    "heiterster": "heiter",
    "heiterstes": "heiter",
    "heitert": "heitern",
    "heiterte": "heitern",
    "heiterten": "heitern",
    "heitertest": "heitern",
    "heitertet": "heitern",
    "heizbarem": "heizbar",
    "heizbaren": "heizbar",
    "heizbarer": "heizbar",
    "heizbarere": "heizbar",
    "heizbarerem": "heizbar",
    "heizbareren": "heizbar",
    "heizbarerer": "heizbar",
    "heizbareres": "heizbar",
    "heizbares": "heizbar",
    "heizbarste": "heizbar",
    "heizbarstem": "heizbar",
    "heizbarsten": "heizbar",
    "heizbarster": "heizbar",
    "heizbarstes": "heizbar",
    "heize": "heizen",
    "heizend": "heizen",
    "heizende": "heizend",
    "heizendem": "heizend",
    "heizenden": "heizend",
    "heizender": "heizend",
    "heizendere": "heizend",
    "heizenderem": "heizend",
    "heizenderen": "heizend",
    "heizenderer": "heizend",
    "heizenderes": "heizend",
    "heizendes": "heizend",
    "heizendste": "heizend",
    "heizendstem": "heizend",
    "heizendsten": "heizend",
    "heizendster": "heizend",
    "heizendstes": "heizend",
    "heizest": "heizen",
    "heizet": "heizen",
    "heizt": "heizen",
    "heizte": "heizen",
    "heizten": "heizen",
    "heiztest": "heizen",
    "heiztet": "heizen",
    "heiß": "heißen",
    "heißblütige": "heißblütig",
    "heißblütigem": "heißblütig",
    "heißblütigen": "heißblütig",
    "heißblütiger": "heißblütig",
    "heißblütigere": "heißblütig",
    "heißblütigerem": "heißblütig",
    "heißblütigeren": "heißblütig",
    "heißblütigerer": "heißblütig",
    "heißblütigeres": "heißblütig",
    "heißblütiges": "heißblütig",
    "heißblütigste": "heißblütig",
    "heißblütigstem": "heißblütig",
    "heißblütigsten": "heißblütig",
    "heißblütigster": "heißblütig",
    "heißblütigstes": "heißblütig",
    "heiße": "heiß",
    "heißem": "heiß",
    "heißen": "heiß",
    "heißend": "heißen",
    "heißende": "heißend",
    "heißendem": "heißend",
    "heißenden": "heißend",
    "heißender": "heißend",
    "heißendes": "heißend",
    "heißer": "heiß",
    "heißere": "heiß",
    "heißerem": "heiß",
    "heißeren": "heiß",
    "heißerer": "heiß",
    "heißeres": "heiß",
    "heißersehnte": "heißersehnt",
    "heißersehntem": "heißersehnt",
    "heißersehnten": "heißersehnt",
    "heißersehnter": "heißersehnt",
    "heißersehntes": "heißersehnt",
    "heißes": "heiß",
    "heißest": "heißen",
    "heißeste": "heiß",
    "heißestem": "heiß",
    "heißesten": "heiß",
    "heißester": "heiß",
    "heißestes": "heiß",
    "heißet": "heißen",
    "heißgeliebte": "heißgeliebt",
    "heißgeliebtem": "heißgeliebt",
    "heißgeliebten": "heißgeliebt",
    "heißgeliebter": "heißgeliebt",
    "heißgeliebtes": "heißgeliebt",
    "heißhungrigem": "heißhungrig",
    "heißhungrigen": "heißhungrig",
    "heißhungriger": "heißhungrig",
    "heißhungrigere": "heißhungrig",
    "heißhungrigerem": "heißhungrig",
    "heißhungrigeren": "heißhungrig",
    "heißhungrigerer": "heißhungrig",
    "heißhungrigeres": "heißhungrig",
    "heißhungriges": "heißhungrig",
    "heißhungrigste": "heißhungrig",
    "heißhungrigstem": "heißhungrig",
    "heißhungrigsten": "heißhungrig",
    "heißhungrigster": "heißhungrig",
    "heißhungrigstes": "heißhungrig",
    "heißt": "heißen",
    "heißumkämpfte": "heißumkämpft",
    "heißumkämpftem": "heißumkämpft",
    "heißumkämpften": "heißumkämpft",
    "heißumkämpfter": "heißumkämpft",
    "heißumkämpftes": "heißumkämpft",
    "heißumstrittene": "heißumstritten",
    "heißumstrittenem": "heißumstritten",
    "heißumstrittenen": "heißumstritten",
    "heißumstrittener": "heißumstritten",
    "heißumstrittenes": "heißumstritten",
    "hektarweisem": "hektarweise",
    "hektarweisen": "hektarweise",
    "hektarweiser": "hektarweise",
    "hektarweises": "hektarweise",
    "hektischem": "hektisch",
    "hektischen": "hektisch",
    "hektischer": "hektisch",
    "hektischere": "hektisch",
    "hektischerem": "hektisch",
    "hektischeren": "hektisch",
    "hektischerer": "hektisch",
    "hektischeres": "hektisch",
    "hektisches": "hektisch",
    "hektischste": "hektisch",
    "hektischstem": "hektisch",
    "hektischsten": "hektisch",
    "hektischster": "hektisch",
    "hektischstes": "hektisch",
    "heldenhaftem": "heldenhaft",
    "heldenhaften": "heldenhaft",
    "heldenhafter": "heldenhaft",
    "heldenhaftere": "heldenhaft",
    "heldenhafterem": "heldenhaft",
    "heldenhafteren": "heldenhaft",
    "heldenhafterer": "heldenhaft",
    "heldenhafteres": "heldenhaft",
    "heldenhaftes": "heldenhaft",
    "heldenhafteste": "heldenhaft",
    "heldenhaftestem": "heldenhaft",
    "heldenhaftesten": "heldenhaft",
    "heldenhaftester": "heldenhaft",
    "heldenhaftestes": "heldenhaft",
    "heldenmütige": "heldenmütig",
    "heldenmütigem": "heldenmütig",
    "heldenmütigen": "heldenmütig",
    "heldenmütiger": "heldenmütig",
    "heldenmütiges": "heldenmütig",
    "helfe": "helfen",
    "helfend": "helfen",
    "helfende": "helfend",
    "helfendem": "helfend",
    "helfenden": "helfend",
    "helfender": "helfend",
    "helfendes": "helfend",
    "helfest": "helfen",
    "helfet": "helfen",
    "helft": "helfen",
    "hell": "hellen",
    "helle": "hell",
    "hellem": "hell",
    "hellen": "hell",
    "hellend": "hellen",
    "hellende": "hellend",
    "hellendem": "hellend",
    "hellenden": "hellend",
    "hellender": "hellend",
    "hellendes": "hellend",
    "hellere": "hell",
    "hellerem": "hell",
    "helleren": "hell",
    "hellerer": "hell",
    "helleres": "hell",
    "helles": "hell",
    "hellest": "hellen",
    "hellet": "hellen",
    "hellhörige": "hellhörig",
    "hellhörigem": "hellhörig",
    "hellhörigen": "hellhörig",
    "hellhöriger": "hellhörig",
    "hellhörigere": "hellhörig",
    "hellhörigerem": "hellhörig",
    "hellhörigeren": "hellhörig",
    "hellhörigerer": "hellhörig",
    "hellhörigeres": "hellhörig",
    "hellhöriges": "hellhörig",
    "hellhörigste": "hellhörig",
    "hellhörigstem": "hellhörig",
    "hellhörigsten": "hellhörig",
    "hellhörigster": "hellhörig",
    "hellhörigstes": "hellhörig",
    "hellst": "hellen",
    "hellste": "hell",
    "hellstem": "hell",
    "hellsten": "hell",
    "hellster": "hell",
    "hellstes": "hell",
    "hellt": "hellen",
    "hellte": "hellen",
    "hellten": "hellen",
    "helltest": "hellen",
    "helltet": "hellen",
    "hellwache": "hellwach",
    "hellwachem": "hellwach",
    "hellwachen": "hellwach",
    "hellwacher": "hellwach",
    "hellwachere": "hellwach",
    "hellwacherem": "hellwach",
    "hellwacheren": "hellwach",
    "hellwacherer": "hellwach",
    "hellwacheres": "hellwach",
    "hellwaches": "hellwach",
    "hellwachste": "hellwach",
    "hellwachstem": "hellwach",
    "hellwachsten": "hellwach",
    "hellwachster": "hellwach",
    "hellwachstes": "hellwach",
    "hemme": "hemmen",
    "hemmend": "hemmen",
    "hemmende": "hemmend",
    "hemmendem": "hemmend",
    "hemmenden": "hemmend",
    "hemmender": "hemmend",
    "hemmendere": "hemmend",
    "hemmenderem": "hemmend",
    "hemmenderen": "hemmend",
    "hemmenderer": "hemmend",
    "hemmenderes": "hemmend",
    "hemmendes": "hemmend",
    "hemmendste": "hemmend",
    "hemmendstem": "hemmend",
    "hemmendsten": "hemmend",
    "hemmendster": "hemmend",
    "hemmendstes": "hemmend",
    "hemmest": "hemmen",
    "hemmet": "hemmen",
    "hemmst": "hemmen",
    "hemmt": "hemmen",
    "hemmte": "hemmen",
    "hemmten": "hemmen",
    "hemmtest": "hemmen",
    "hemmtet": "hemmen",
    "hemmungslosem": "hemmungslos",
    "hemmungslosen": "hemmungslos",
    "hemmungsloser": "hemmungslos",
    "hemmungslosere": "hemmungslos",
    "hemmungsloserem": "hemmungslos",
    "hemmungsloseren": "hemmungslos",
    "hemmungsloserer": "hemmungslos",
    "hemmungsloseres": "hemmungslos",
    "hemmungsloses": "hemmungslos",
    "hemmungsloseste": "hemmungslos",
    "hemmungslosestem": "hemmungslos",
    "hemmungslosesten": "hemmungslos",
    "hemmungslosester": "hemmungslos",
    "hemmungslosestes": "hemmungslos",
    "herabfließe": "herabfließen",
    "herabfließend": "herabfließen",
    "herabfließende": "herabfließend",
    "herabfließendem": "herabfließend",
    "herabfließenden": "herabfließend",
    "herabfließender": "herabfließend",
    "herabfließendes": "herabfließend",
    "herabfließest": "herabfließen",
    "herabfließet": "herabfließen",
    "herabfließt": "herabfließen",
    "herabflossen": "herabfließen",
    "herabfloß": "herabfließen",
    "herabfloßt": "herabfließen",
    "herabflösse": "herabfließen",
    "herabflössen": "herabfließen",
    "herabflössest": "herabfließen",
    "herabflösset": "herabfließen",
    "herabgeflossen": "herabfließen",
    "herabgeflossene": "herabgeflossen",
    "herabgeflossenem": "herabgeflossen",
    "herabgeflossenen": "herabgeflossen",
    "herabgeflossener": "herabgeflossen",
    "herabgeflossenes": "herabgeflossen",
    "herabgeregnet": "herabregnen",
    "herabgeregnete": "herabgeregnet",
    "herabgeregnetem": "herabgeregnet",
    "herabgeregneten": "herabgeregnet",
    "herabgeregneter": "herabgeregnet",
    "herabgeregnetes": "herabgeregnet",
    "herabgerissen": "herabreißen",
    "herabgerissene": "herabgerissen",
    "herabgerissenem": "herabgerissen",
    "herabgerissenen": "herabgerissen",
    "herabgerissener": "herabgerissen",
    "herabgerissenes": "herabgerissen",
    "herabgeschoben": "herabschieben",
    "herabgeschobene": "herabgeschoben",
    "herabgeschobenem": "herabgeschoben",
    "herabgeschobenen": "herabgeschoben",
    "herabgeschobener": "herabgeschoben",
    "herabgeschobenere": "herabgeschoben",
    "herabgeschobenerem": "herabgeschoben",
    "herabgeschobeneren": "herabgeschoben",
    "herabgeschobenerer": "herabgeschoben",
    "herabgeschobeneres": "herabgeschoben",
    "herabgeschobenes": "herabgeschoben",
    "herabgeschobenste": "herabgeschoben",
    "herabgeschobenstem": "herabgeschoben",
    "herabgeschobensten": "herabgeschoben",
    "herabgeschobenster": "herabgeschoben",
    "herabgeschobenstes": "herabgeschoben",
    "herabgeschossen": "herabschießen",
    "herabgeschossene": "herabgeschossen",
    "herabgeschossenem": "herabgeschossen",
    "herabgeschossenen": "herabgeschossen",
    "herabgeschossener": "herabgeschossen",
    "herabgeschossenes": "herabgeschossen",
    "herabgesetzt": "herabsetzen",
    "herabgesetzte": "herabgesetzt",
    "herabgesetztem": "herabgesetzt",
    "herabgesetzten": "herabgesetzt",
    "herabgesetzter": "herabgesetzt",
    "herabgesetztere": "herabgesetzt",
    "herabgesetzterem": "herabgesetzt",
    "herabgesetzteren": "herabgesetzt",
    "herabgesetzterer": "herabgesetzt",
    "herabgesetzteres": "herabgesetzt",
    "herabgesetztes": "herabgesetzt",
    "herabgesetzteste": "herabgesetzt",
    "herabgesetztestem": "herabgesetzt",
    "herabgesetztesten": "herabgesetzt",
    "herabgesetztester": "herabgesetzt",
    "herabgesetztestes": "herabgesetzt",
    "herabgesunken": "herabsinken",
    "herabgesunkene": "herabgesunken",
    "herabgesunkenem": "herabgesunken",
    "herabgesunkenen": "herabgesunken",
    "herabgesunkener": "herabgesunken",
    "herabgesunkenere": "herabgesunken",
    "herabgesunkenerem": "herabgesunken",
    "herabgesunkeneren": "herabgesunken",
    "herabgesunkenerer": "herabgesunken",
    "herabgesunkeneres": "herabgesunken",
    "herabgesunkenes": "herabgesunken",
    "herabgesunkenste": "herabgesunken",
    "herabgesunkenstem": "herabgesunken",
    "herabgesunkensten": "herabgesunken",
    "herabgesunkenster": "herabgesunken",
    "herabgesunkenstes": "herabgesunken",
    "herabregne": "herabregnen",
    "herabregnend": "herabregnen",
    "herabregnende": "herabregnend",
    "herabregnendem": "herabregnend",
    "herabregnenden": "herabregnend",
    "herabregnender": "herabregnend",
    "herabregnendes": "herabregnend",
    "herabregnest": "herabregnen",
    "herabregnet": "herabregnen",
    "herabregnete": "herabregnen",
    "herabregneten": "herabregnen",
    "herabregnetest": "herabregnen",
    "herabregnetet": "herabregnen",
    "herabreiße": "herabreißen",
    "herabreißend": "herabreißen",
    "herabreißende": "herabreißend",
    "herabreißendem": "herabreißend",
    "herabreißenden": "herabreißend",
    "herabreißender": "herabreißend",
    "herabreißendes": "herabreißend",
    "herabreißest": "herabreißen",
    "herabreißet": "herabreißen",
    "herabreißt": "herabreißen",
    "herabrisse": "herabreißen",
    "herabrissen": "herabreißen",
    "herabrissest": "herabreißen",
    "herabrisset": "herabreißen",
    "herabriß": "herabreißen",
    "herabrißt": "herabreißen",
    "herabsank": "herabsinken",
    "herabsanken": "herabsinken",
    "herabsankst": "herabsinken",
    "herabsankt": "herabsinken",
    "herabschiebe": "herabschieben",
    "herabschiebend": "herabschieben",
    "herabschiebende": "herabschiebend",
    "herabschiebendem": "herabschiebend",
    "herabschiebenden": "herabschiebend",
    "herabschiebender": "herabschiebend",
    "herabschiebendes": "herabschiebend",
    "herabschiebest": "herabschieben",
    "herabschiebet": "herabschieben",
    "herabschiebst": "herabschieben",
    "herabschiebt": "herabschieben",
    "herabschieße": "herabschießen",
    "herabschießend": "herabschießen",
    "herabschießende": "herabschießend",
    "herabschießendem": "herabschießend",
    "herabschießenden": "herabschießend",
    "herabschießender": "herabschießend",
    "herabschießendes": "herabschießend",
    "herabschießest": "herabschießen",
    "herabschießet": "herabschießen",
    "herabschießt": "herabschießen",
    "herabschob": "herabschieben",
    "herabschoben": "herabschieben",
    "herabschobst": "herabschieben",
    "herabschobt": "herabschieben",
    "herabschossen": "herabschießen",
    "herabschoß": "herabschießen",
    "herabschoßt": "herabschießen",
    "herabschöbe": "herabschieben",
    "herabschöben": "herabschieben",
    "herabschöbest": "herabschieben",
    "herabschöbet": "herabschieben",
    "herabschösse": "herabschießen",
    "herabschössen": "herabschießen",
    "herabschössest": "herabschießen",
    "herabschösset": "herabschießen",
    "herabsetze": "herabsetzen",
    "herabsetzend": "herabsetzen",
    "herabsetzende": "herabsetzend",
    "herabsetzendem": "herabsetzend",
    "herabsetzenden": "herabsetzend",
    "herabsetzender": "herabsetzend",
    "herabsetzendes": "herabsetzend",
    "herabsetzest": "herabsetzen",
    "herabsetzet": "herabsetzen",
    "herabsetzt": "herabsetzen",
    "herabsetzte": "herabsetzen",
    "herabsetzten": "herabsetzen",
    "herabsetztest": "herabsetzen",
    "herabsetztet": "herabsetzen",
    "herabsinke": "herabsinken",
    "herabsinkend": "herabsinken",
    "herabsinkende": "herabsinkend",
    "herabsinkendem": "herabsinkend",
    "herabsinkenden": "herabsinkend",
    "herabsinkender": "herabsinkend",
    "herabsinkendere": "herabsinkend",
    "herabsinkenderem": "herabsinkend",
    "herabsinkenderen": "herabsinkend",
    "herabsinkenderer": "herabsinkend",
    "herabsinkenderes": "herabsinkend",
    "herabsinkendes": "herabsinkend",
    "herabsinkendste": "herabsinkend",
    "herabsinkendstem": "herabsinkend",
    "herabsinkendsten": "herabsinkend",
    "herabsinkendster": "herabsinkend",
    "herabsinkendstes": "herabsinkend",
    "herabsinkest": "herabsinken",
    "herabsinket": "herabsinken",
    "herabsinkst": "herabsinken",
    "herabsinkt": "herabsinken",
    "herabsänke": "herabsinken",
    "herabsänken": "herabsinken",
    "herabsänkest": "herabsinken",
    "herabsänket": "herabsinken",
    "herabzufließen": "herabfließen",
    "herabzuregnen": "herabregnen",
    "herabzureißen": "herabreißen",
    "herabzuschieben": "herabschieben",
    "herabzuschießen": "herabschießen",
    "herabzusetzen": "herabsetzen",
    "herabzusinken": "herabsinken",
    "herangegangen": "herangehen",
    "herangegangene": "herangegangen",
    "herangegangenem": "herangegangen",
    "herangegangenen": "herangegangen",
    "herangegangener": "herangegangen",
    "herangegangenes": "herangegangen",
    "herangehe": "herangehen",
    "herangehend": "herangehen",
    "herangehende": "herangehend",
    "herangehendem": "herangehend",
    "herangehenden": "herangehend",
    "herangehender": "herangehend",
    "herangehendes": "herangehend",
    "herangehest": "herangehen",
    "herangehet": "herangehen",
    "herangehst": "herangehen",
    "herangeht": "herangehen",
    "herangekrochen": "herankriechen",
    "herangekrochene": "herangekrochen",
    "herangekrochenem": "herangekrochen",
    "herangekrochenen": "herangekrochen",
    "herangekrochener": "herangekrochen",
    "herangekrochenes": "herangekrochen",
    "herangemacht": "heranmachen",
    "herangemachte": "herangemacht",
    "herangemachtem": "herangemacht",
    "herangemachten": "herangemacht",
    "herangemachter": "herangemacht",
    "herangemachtes": "herangemacht",
    "herangereift": "heranreifen",
    "herangereifte": "herangereift",
    "herangereiftem": "herangereift",
    "herangereiften": "herangereift",
    "herangereifter": "herangereift",
    "herangereiftes": "herangereift",
    "herangerückt": "heranrücken",
    "herangerückte": "herangerückt",
    "herangerücktem": "herangerückt",
    "herangerückten": "herangerückt",
    "herangerückter": "herangerückt",
    "herangerücktes": "herangerückt",
    "herangeschlichen": "heranschleichen",
    "herangeschlichene": "herangeschlichen",
    "herangeschlichenem": "herangeschlichen",
    "herangeschlichenen": "herangeschlichen",
    "herangeschlichener": "herangeschlichen",
    "herangeschlichenes": "herangeschlichen",
    "herangeschmissen": "heranschmeißen",
    "herangeschmissene": "herangeschmissen",
    "herangeschmissenem": "herangeschmissen",
    "herangeschmissenen": "herangeschmissen",
    "herangeschmissener": "herangeschmissen",
    "herangeschmissenes": "herangeschmissen",
    "herangespielt": "heranspielen",
    "herangespielte": "herangespielt",
    "herangespieltem": "herangespielt",
    "herangespielten": "herangespielt",
    "herangespielter": "herangespielt",
    "herangespieltes": "herangespielt",
    "herangewachsen": "heranwachsen",
    "herangewachsene": "herangewachsen",
    "herangewachsenem": "herangewachsen",
    "herangewachsenen": "herangewachsen",
    "herangewachsener": "herangewachsen",
    "herangewachsenes": "herangewachsen",
    "herangewachst": "heranwachsen",
    "herangewachste": "herangewachst",
    "herangewachstem": "herangewachst",
    "herangewachsten": "herangewachst",
    "herangewachster": "herangewachst",
    "herangewachstes": "herangewachst",
    "herangezogene": "herangezogen",
    "herangezogenem": "herangezogen",
    "herangezogenen": "herangezogen",
    "herangezogener": "herangezogen",
    "herangezogenes": "herangezogen",
    "herangezüchtet": "heranzüchten",
    "herangezüchtete": "herangezüchtet",
    "herangezüchtetem": "herangezüchtet",
    "herangezüchteten": "herangezüchtet",
    "herangezüchteter": "herangezüchtet",
    "herangezüchtetes": "herangezüchtet",
    "heranging": "herangehen",
    "heranginge": "herangehen",
    "herangingen": "herangehen",
    "herangingest": "herangehen",
    "heranginget": "herangehen",
    "herangingst": "herangehen",
    "herangingt": "herangehen",
    "herankrieche": "herankriechen",
    "herankriechend": "herankriechen",
    "herankriechende": "herankriechend",
    "herankriechendem": "herankriechend",
    "herankriechenden": "herankriechend",
    "herankriechender": "herankriechend",
    "herankriechendes": "herankriechend",
    "herankriechest": "herankriechen",
    "herankriechet": "herankriechen",
    "herankriechst": "herankriechen",
    "herankriecht": "herankriechen",
    "herankroch": "herankriechen",
    "herankrochen": "herankriechen",
    "herankrochst": "herankriechen",
    "herankrocht": "herankriechen",
    "herankröche": "herankriechen",
    "herankröchen": "herankriechen",
    "herankröchest": "herankriechen",
    "herankröchet": "herankriechen",
    "heranmache": "heranmachen",
    "heranmachend": "heranmachen",
    "heranmachende": "heranmachend",
    "heranmachendem": "heranmachend",
    "heranmachenden": "heranmachend",
    "heranmachender": "heranmachend",
    "heranmachendes": "heranmachend",
    "heranmachest": "heranmachen",
    "heranmachet": "heranmachen",
    "heranmachst": "heranmachen",
    "heranmacht": "heranmachen",
    "heranmachte": "heranmachen",
    "heranmachten": "heranmachen",
    "heranmachtest": "heranmachen",
    "heranmachtet": "heranmachen",
    "heranreife": "heranreifen",
    "heranreifend": "heranreifen",
    "heranreifende": "heranreifend",
    "heranreifendem": "heranreifend",
    "heranreifenden": "heranreifend",
    "heranreifender": "heranreifend",
    "heranreifendere": "heranreifend",
    "heranreifenderem": "heranreifend",
    "heranreifenderen": "heranreifend",
    "heranreifenderer": "heranreifend",
    "heranreifenderes": "heranreifend",
    "heranreifendes": "heranreifend",
    "heranreifendste": "heranreifend",
    "heranreifendstem": "heranreifend",
    "heranreifendsten": "heranreifend",
    "heranreifendster": "heranreifend",
    "heranreifendstes": "heranreifend",
    "heranreifest": "heranreifen",
    "heranreifet": "heranreifen",
    "heranreifst": "heranreifen",
    "heranreift": "heranreifen",
    "heranreifte": "heranreifen",
    "heranreiften": "heranreifen",
    "heranreiftest": "heranreifen",
    "heranreiftet": "heranreifen",
    "heranrücke": "heranrücken",
    "heranrückend": "heranrücken",
    "heranrückende": "heranrückend",
    "heranrückendem": "heranrückend",
    "heranrückenden": "heranrückend",
    "heranrückender": "heranrückend",
    "heranrückendes": "heranrückend",
    "heranrückest": "heranrücken",
    "heranrücket": "heranrücken",
    "heranrückst": "heranrücken",
    "heranrückt": "heranrücken",
    "heranrückte": "heranrücken",
    "heranrückten": "heranrücken",
    "heranrücktest": "heranrücken",
    "heranrücktet": "heranrücken",
    "heranschleiche": "heranschleichen",
    "heranschleichend": "heranschleichen",
    "heranschleichende": "heranschleichend",
    "heranschleichendem": "heranschleichend",
    "heranschleichenden": "heranschleichend",
    "heranschleichender": "heranschleichend",
    "heranschleichendes": "heranschleichend",
    "heranschleichest": "heranschleichen",
    "heranschleichet": "heranschleichen",
    "heranschleichst": "heranschleichen",
    "heranschleicht": "heranschleichen",
    "heranschlich": "heranschleichen",
    "heranschliche": "heranschleichen",
    "heranschlichen": "heranschleichen",
    "heranschlichest": "heranschleichen",
    "heranschlichet": "heranschleichen",
    "heranschlichst": "heranschleichen",
    "heranschlicht": "heranschleichen",
    "heranschmeiße": "heranschmeißen",
    "heranschmeißend": "heranschmeißen",
    "heranschmeißende": "heranschmeißend",
    "heranschmeißendem": "heranschmeißend",
    "heranschmeißenden": "heranschmeißend",
    "heranschmeißender": "heranschmeißend",
    "heranschmeißendes": "heranschmeißend",
    "heranschmeißest": "heranschmeißen",
    "heranschmeißet": "heranschmeißen",
    "heranschmeißt": "heranschmeißen",
    "heranschmisse": "heranschmeißen",
    "heranschmissen": "heranschmeißen",
    "heranschmissest": "heranschmeißen",
    "heranschmisset": "heranschmeißen",
    "heranschmiß": "heranschmeißen",
    "heranschmißt": "heranschmeißen",
    "heranspiele": "heranspielen",
    "heranspielend": "heranspielen",
    "heranspielende": "heranspielend",
    "heranspielendem": "heranspielend",
    "heranspielenden": "heranspielend",
    "heranspielender": "heranspielend",
    "heranspielendes": "heranspielend",
    "heranspielest": "heranspielen",
    "heranspielet": "heranspielen",
    "heranspielst": "heranspielen",
    "heranspielt": "heranspielen",
    "heranspielte": "heranspielen",
    "heranspielten": "heranspielen",
    "heranspieltest": "heranspielen",
    "heranspieltet": "heranspielen",
    "heranwachse": "heranwachsen",
    "heranwachsend": "heranwachsen",
    "heranwachsende": "heranwachsend",
    "heranwachsendem": "heranwachsend",
    "heranwachsenden": "heranwachsend",
    "heranwachsender": "heranwachsend",
    "heranwachsendes": "heranwachsend",
    "heranwachsest": "heranwachsen",
    "heranwachset": "heranwachsen",
    "heranwachst": "heranwachsen",
    "heranwachste": "heranwachsen",
    "heranwachsten": "heranwachsen",
    "heranwachstest": "heranwachsen",
    "heranwachstet": "heranwachsen",
    "heranwuchs": "heranwachsen",
    "heranwuchsen": "heranwachsen",
    "heranwuchst": "heranwachsen",
    "heranwächst": "heranwachsen",
    "heranwüchse": "heranwachsen",
    "heranwüchsen": "heranwachsen",
    "heranwüchsest": "heranwachsen",
    "heranwüchset": "heranwachsen",
    "heranziehende": "heranziehend",
    "heranziehendem": "heranziehend",
    "heranziehenden": "heranziehend",
    "heranziehender": "heranziehend",
    "heranziehendes": "heranziehend",
    "heranzugehen": "herangehen",
    "heranzukriechen": "herankriechen",
    "heranzumachen": "heranmachen",
    "heranzureifen": "heranreifen",
    "heranzurücken": "heranrücken",
    "heranzuschleichen": "heranschleichen",
    "heranzuschmeißen": "heranschmeißen",
    "heranzuspielen": "heranspielen",
    "heranzuwachsen": "heranwachsen",
    "heranzuzüchten": "heranzüchten",
    "heranzüchte": "heranzüchten",
    "heranzüchtend": "heranzüchten",
    "heranzüchtende": "heranzüchtend",
    "heranzüchtendem": "heranzüchtend",
    "heranzüchtenden": "heranzüchtend",
    "heranzüchtender": "heranzüchtend",
    "heranzüchtendes": "heranzüchtend",
    "heranzüchtest": "heranzüchten",
    "heranzüchtet": "heranzüchten",
    "heranzüchtete": "heranzüchten",
    "heranzüchteten": "heranzüchten",
    "heranzüchtetest": "heranzüchten",
    "heranzüchtetet": "heranzüchten",
    "heraufbemühe": "heraufbemühen",
    "heraufbemühend": "heraufbemühen",
    "heraufbemühende": "heraufbemühend",
    "heraufbemühendem": "heraufbemühend",
    "heraufbemühenden": "heraufbemühend",
    "heraufbemühender": "heraufbemühend",
    "heraufbemühendes": "heraufbemühend",
    "heraufbemühest": "heraufbemühen",
    "heraufbemühet": "heraufbemühen",
    "heraufbemühst": "heraufbemühen",
    "heraufbemüht": "heraufbemühen",
    "heraufbemühte": "heraufbemühen",
    "heraufbemühtem": "heraufbemüht",
    "heraufbemühten": "heraufbemühen",
    "heraufbemühter": "heraufbemüht",
    "heraufbemühtes": "heraufbemüht",
    "heraufbemühtest": "heraufbemühen",
    "heraufbemühtet": "heraufbemühen",
    "herauffalle": "herauffallen",
    "herauffallend": "herauffallen",
    "herauffallende": "herauffallend",
    "herauffallendem": "herauffallend",
    "herauffallenden": "herauffallend",
    "herauffallender": "herauffallend",
    "herauffallendes": "herauffallend",
    "herauffallest": "herauffallen",
    "herauffallet": "herauffallen",
    "herauffallt": "herauffallen",
    "herauffiel": "herauffallen",
    "herauffiele": "herauffallen",
    "herauffielen": "herauffallen",
    "herauffielest": "herauffallen",
    "herauffielet": "herauffallen",
    "herauffielst": "herauffallen",
    "herauffielt": "herauffallen",
    "herauffließe": "herauffließen",
    "herauffließend": "herauffließen",
    "herauffließende": "herauffließend",
    "herauffließendem": "herauffließend",
    "herauffließenden": "herauffließend",
    "herauffließender": "herauffließend",
    "herauffließendes": "herauffließend",
    "herauffließest": "herauffließen",
    "herauffließet": "herauffließen",
    "herauffließt": "herauffließen",
    "heraufflossen": "herauffließen",
    "herauffloß": "herauffließen",
    "herauffloßt": "herauffließen",
    "heraufflösse": "herauffließen",
    "heraufflössen": "herauffließen",
    "heraufflössest": "herauffließen",
    "heraufflösset": "herauffließen",
    "herauffällst": "herauffallen",
    "herauffällt": "herauffallen",
    "heraufführe": "heraufführen",
    "heraufführend": "heraufführen",
    "heraufführende": "heraufführend",
    "heraufführendem": "heraufführend",
    "heraufführenden": "heraufführend",
    "heraufführender": "heraufführend",
    "heraufführendes": "heraufführend",
    "heraufführest": "heraufführen",
    "heraufführet": "heraufführen",
    "heraufführst": "heraufführen",
    "heraufführt": "heraufführen",
    "heraufführte": "heraufführen",
    "heraufführten": "heraufführen",
    "heraufführtest": "heraufführen",
    "heraufführtet": "heraufführen",
    "heraufgefallen": "herauffallen",
    "heraufgefallene": "heraufgefallen",
    "heraufgefallenem": "heraufgefallen",
    "heraufgefallenen": "heraufgefallen",
    "heraufgefallener": "heraufgefallen",
    "heraufgefallenes": "heraufgefallen",
    "heraufgeflossen": "herauffließen",
    "heraufgeflossene": "heraufgeflossen",
    "heraufgeflossenem": "heraufgeflossen",
    "heraufgeflossenen": "heraufgeflossen",
    "heraufgeflossener": "heraufgeflossen",
    "heraufgeflossenes": "heraufgeflossen",
    "heraufgeführt": "heraufführen",
    "heraufgeführte": "heraufgeführt",
    "heraufgeführtem": "heraufgeführt",
    "heraufgeführten": "heraufgeführt",
    "heraufgeführter": "heraufgeführt",
    "heraufgeführtes": "heraufgeführt",
    "heraufgereicht": "heraufreichen",
    "heraufgereichte": "heraufgereicht",
    "heraufgereichtem": "heraufgereicht",
    "heraufgereichten": "heraufgereicht",
    "heraufgereichter": "heraufgereicht",
    "heraufgereichtes": "heraufgereicht",
    "heraufgerollt": "heraufrollen",
    "heraufgerollte": "heraufgerollt",
    "heraufgerolltem": "heraufgerollt",
    "heraufgerollten": "heraufgerollt",
    "heraufgerollter": "heraufgerollt",
    "heraufgerolltere": "heraufgerollt",
    "heraufgerollterem": "heraufgerollt",
    "heraufgerollteren": "heraufgerollt",
    "heraufgerollterer": "heraufgerollt",
    "heraufgerollteres": "heraufgerollt",
    "heraufgerolltes": "heraufgerollt",
    "heraufgerollteste": "heraufgerollt",
    "heraufgerolltestem": "heraufgerollt",
    "heraufgerolltesten": "heraufgerollt",
    "heraufgerolltester": "heraufgerollt",
    "heraufgerolltestes": "heraufgerollt",
    "heraufgesetzt": "heraufsetzen",
    "heraufgesetzte": "heraufgesetzt",
    "heraufgesetztem": "heraufgesetzt",
    "heraufgesetzten": "heraufgesetzt",
    "heraufgesetzter": "heraufgesetzt",
    "heraufgesetztere": "heraufgesetzt",
    "heraufgesetzterem": "heraufgesetzt",
    "heraufgesetzteren": "heraufgesetzt",
    "heraufgesetzterer": "heraufgesetzt",
    "heraufgesetzteres": "heraufgesetzt",
    "heraufgesetztes": "heraufgesetzt",
    "heraufgesetzteste": "heraufgesetzt",
    "heraufgesetztestem": "heraufgesetzt",
    "heraufgesetztesten": "heraufgesetzt",
    "heraufgesetztester": "heraufgesetzt",
    "heraufgesetztestes": "heraufgesetzt",
    "heraufreiche": "heraufreichen",
    "heraufreichend": "heraufreichen",
    "heraufreichende": "heraufreichend",
    "heraufreichendem": "heraufreichend",
    "heraufreichenden": "heraufreichend",
    "heraufreichender": "heraufreichend",
    "heraufreichendes": "heraufreichend",
    "heraufreichest": "heraufreichen",
    "heraufreichet": "heraufreichen",
    "heraufreichst": "heraufreichen",
    "heraufreicht": "heraufreichen",
    "heraufreichte": "heraufreichen",
    "heraufreichten": "heraufreichen",
    "heraufreichtest": "heraufreichen",
    "heraufreichtet": "heraufreichen",
    "heraufrolle": "heraufrollen",
    "heraufrollend": "heraufrollen",
    "heraufrollende": "heraufrollend",
    "heraufrollendem": "heraufrollend",
    "heraufrollenden": "heraufrollend",
    "heraufrollender": "heraufrollend",
    "heraufrollendere": "heraufrollend",
    "heraufrollenderem": "heraufrollend",
    "heraufrollenderen": "heraufrollend",
    "heraufrollenderer": "heraufrollend",
    "heraufrollenderes": "heraufrollend",
    "heraufrollendes": "heraufrollend",
    "heraufrollendste": "heraufrollend",
    "heraufrollendstem": "heraufrollend",
    "heraufrollendsten": "heraufrollend",
    "heraufrollendster": "heraufrollend",
    "heraufrollendstes": "heraufrollend",
    "heraufrollest": "heraufrollen",
    "heraufrollet": "heraufrollen",
    "heraufrollst": "heraufrollen",
    "heraufrollt": "heraufrollen",
    "heraufrollte": "heraufrollen",
    "heraufrollten": "heraufrollen",
    "heraufrolltest": "heraufrollen",
    "heraufrolltet": "heraufrollen",
    "heraufsetze": "heraufsetzen",
    "heraufsetzend": "heraufsetzen",
    "heraufsetzende": "heraufsetzend",
    "heraufsetzendem": "heraufsetzend",
    "heraufsetzenden": "heraufsetzend",
    "heraufsetzender": "heraufsetzend",
    "heraufsetzendes": "heraufsetzend",
    "heraufsetzest": "heraufsetzen",
    "heraufsetzet": "heraufsetzen",
    "heraufsetzt": "heraufsetzen",
    "heraufsetzte": "heraufsetzen",
    "heraufsetzten": "heraufsetzen",
    "heraufsetztest": "heraufsetzen",
    "heraufsetztet": "heraufsetzen",
    "heraufzubemühen": "heraufbemühen",
    "heraufzufallen": "herauffallen",
    "heraufzufließen": "herauffließen",
    "heraufzuführen": "heraufführen",
    "heraufzureichen": "heraufreichen",
    "heraufzurollen": "heraufrollen",
    "heraufzusetzen": "heraufsetzen",
    "herausarbeite": "herausarbeiten",
    "herausarbeitend": "herausarbeiten",
    "herausarbeitende": "herausarbeitend",
    "herausarbeitendem": "herausarbeitend",
    "herausarbeitenden": "herausarbeitend",
    "herausarbeitender": "herausarbeitend",
    "herausarbeitendes": "herausarbeitend",
    "herausarbeitest": "herausarbeiten",
    "herausarbeitet": "herausarbeiten",
    "herausarbeitete": "herausarbeiten",
    "herausarbeiteten": "herausarbeiten",
    "herausarbeitetest": "herausarbeiten",
    "herausarbeitetet": "herausarbeiten",
    "herausbeiße": "herausbeißen",
    "herausbeißend": "herausbeißen",
    "herausbeißende": "herausbeißend",
    "herausbeißendem": "herausbeißend",
    "herausbeißenden": "herausbeißend",
    "herausbeißender": "herausbeißend",
    "herausbeißendes": "herausbeißend",
    "herausbeißest": "herausbeißen",
    "herausbeißet": "herausbeißen",
    "herausbeißt": "herausbeißen",
    "herausbisse": "herausbeißen",
    "herausbissen": "herausbeißen",
    "herausbissest": "herausbeißen",
    "herausbisset": "herausbeißen",
    "herausbiß": "herausbeißen",
    "herausbißt": "herausbeißen",
    "herausbrach": "herausbrechen",
    "herausbrachen": "herausbrechen",
    "herausbrachst": "herausbrechen",
    "herausbracht": "herausbrechen",
    "herausbreche": "herausbrechen",
    "herausbrechend": "herausbrechen",
    "herausbrechende": "herausbrechend",
    "herausbrechendem": "herausbrechend",
    "herausbrechenden": "herausbrechend",
    "herausbrechender": "herausbrechend",
    "herausbrechendes": "herausbrechend",
    "herausbrechest": "herausbrechen",
    "herausbrechet": "herausbrechen",
    "herausbrecht": "herausbrechen",
    "herausbrichst": "herausbrechen",
    "herausbricht": "herausbrechen",
    "herausbräche": "herausbrechen",
    "herausbrächen": "herausbrechen",
    "herausbrächest": "herausbrechen",
    "herausbrächet": "herausbrechen",
    "herausfiltere": "herausfiltern",
    "herausfilternd": "herausfiltern",
    "herausfilternde": "herausfilternd",
    "herausfilterndem": "herausfilternd",
    "herausfilternden": "herausfilternd",
    "herausfilternder": "herausfilternd",
    "herausfilterndes": "herausfilternd",
    "herausfilterst": "herausfiltern",
    "herausfiltert": "herausfiltern",
    "herausfilterte": "herausfiltern",
    "herausfilterten": "herausfiltern",
    "herausfiltertest": "herausfiltern",
    "herausfiltertet": "herausfiltern",
    "herausführe": "herausführen",
    "herausführend": "herausführen",
    "herausführende": "herausführend",
    "herausführendem": "herausführend",
    "herausführenden": "herausführend",
    "herausführender": "herausführend",
    "herausführendes": "herausführend",
    "herausführest": "herausführen",
    "herausführet": "herausführen",
    "herausführst": "herausführen",
    "herausführt": "herausführen",
    "herausführte": "herausführen",
    "herausführten": "herausführen",
    "herausführtest": "herausführen",
    "herausführtet": "herausführen",
    "herausgab": "herausgeben",
    "herausgaben": "herausgeben",
    "herausgabst": "herausgeben",
    "herausgabt": "herausgeben",
    "herausgearbeitet": "herausarbeiten",
    "herausgearbeitete": "herausgearbeitet",
    "herausgearbeitetem": "herausgearbeitet",
    "herausgearbeiteten": "herausgearbeitet",
    "herausgearbeiteter": "herausgearbeitet",
    "herausgearbeitetere": "herausgearbeitet",
    "herausgearbeiteterem": "herausgearbeitet",
    "herausgearbeiteteren": "herausgearbeitet",
    "herausgearbeiteterer": "herausgearbeitet",
    "herausgearbeiteteres": "herausgearbeitet",
    "herausgearbeitetes": "herausgearbeitet",
    "herausgearbeiteteste": "herausgearbeitet",
    "herausgearbeitetestem": "herausgearbeitet",
    "herausgearbeitetesten": "herausgearbeitet",
    "herausgearbeitetester": "herausgearbeitet",
    "herausgearbeitetestes": "herausgearbeitet",
    "herausgebe": "herausgeben",
    "herausgebend": "herausgeben",
    "herausgebende": "herausgebend",
    "herausgebendem": "herausgebend",
    "herausgebenden": "herausgebend",
    "herausgebender": "herausgebend",
    "herausgebendes": "herausgebend",
    "herausgebest": "herausgeben",
    "herausgebet": "herausgeben",
    "herausgebissen": "herausbeißen",
    "herausgebissene": "herausgebissen",
    "herausgebissenem": "herausgebissen",
    "herausgebissenen": "herausgebissen",
    "herausgebissener": "herausgebissen",
    "herausgebissenes": "herausgebissen",
    "herausgebrochen": "herausbrechen",
    "herausgebrochene": "herausgebrochen",
    "herausgebrochenem": "herausgebrochen",
    "herausgebrochenen": "herausgebrochen",
    "herausgebrochener": "herausgebrochen",
    "herausgebrochenes": "herausgebrochen",
    "herausgebt": "herausgeben",
    "herausgefiltert": "herausfiltern",
    "herausgefilterte": "herausgefiltert",
    "herausgefiltertem": "herausgefiltert",
    "herausgefilterten": "herausgefiltert",
    "herausgefilterter": "herausgefiltert",
    "herausgefiltertes": "herausgefiltert",
    "herausgeführt": "herausführen",
    "herausgeführte": "herausgeführt",
    "herausgeführtem": "herausgeführt",
    "herausgeführten": "herausgeführt",
    "herausgeführter": "herausgeführt",
    "herausgeführtes": "herausgeführt",
    "herausgegeben": "herausgeben",
    "herausgegebene": "herausgegeben",
    "herausgegebenem": "herausgegeben",
    "herausgegebenen": "herausgegeben",
    "herausgegebener": "herausgegeben",
    "herausgegebenes": "herausgegeben",
    "herausgehalten": "heraushalten",
    "herausgehaltene": "herausgehalten",
    "herausgehaltenem": "herausgehalten",
    "herausgehaltenen": "herausgehalten",
    "herausgehaltener": "herausgehalten",
    "herausgehaltenes": "herausgehalten",
    "herausgehoben": "herausheben",
    "herausgehobene": "herausgehoben",
    "herausgehobenem": "herausgehoben",
    "herausgehobenen": "herausgehoben",
    "herausgehobener": "herausgehoben",
    "herausgehobenere": "herausgehoben",
    "herausgehobenerem": "herausgehoben",
    "herausgehobeneren": "herausgehoben",
    "herausgehobenerer": "herausgehoben",
    "herausgehobeneres": "herausgehoben",
    "herausgehobenes": "herausgehoben",
    "herausgehobenste": "herausgehoben",
    "herausgehobenstem": "herausgehoben",
    "herausgehobensten": "herausgehoben",
    "herausgehobenster": "herausgehoben",
    "herausgehobenstes": "herausgehoben",
    "herausgelugt": "herauslugen",
    "herausgelugte": "herausgelugt",
    "herausgelugtem": "herausgelugt",
    "herausgelugten": "herausgelugt",
    "herausgelugter": "herausgelugt",
    "herausgelugtes": "herausgelugt",
    "herausgeputzt": "herausputzen",
    "herausgeputzte": "herausgeputzt",
    "herausgeputztem": "herausgeputzt",
    "herausgeputzten": "herausgeputzt",
    "herausgeputzter": "herausgeputzt",
    "herausgeputztere": "herausgeputzt",
    "herausgeputzterem": "herausgeputzt",
    "herausgeputzteren": "herausgeputzt",
    "herausgeputzterer": "herausgeputzt",
    "herausgeputzteres": "herausgeputzt",
    "herausgeputztes": "herausgeputzt",
    "herausgeputzteste": "herausgeputzt",
    "herausgeputztestem": "herausgeputzt",
    "herausgeputztesten": "herausgeputzt",
    "herausgeputztester": "herausgeputzt",
    "herausgeputztestes": "herausgeputzt",
    "herausgereicht": "herausreichen",
    "herausgereichte": "herausgereicht",
    "herausgereichtem": "herausgereicht",
    "herausgereichten": "herausgereicht",
    "herausgereichter": "herausgereicht",
    "herausgereichtes": "herausgereicht",
    "herausgerückt": "herausrücken",
    "herausgerückte": "herausgerückt",
    "herausgerücktem": "herausgerückt",
    "herausgerückten": "herausgerückt",
    "herausgerückter": "herausgerückt",
    "herausgerücktes": "herausgerückt",
    "herausgeschossen": "herausschießen",
    "herausgeschossene": "herausgeschossen",
    "herausgeschossenem": "herausgeschossen",
    "herausgeschossenen": "herausgeschossen",
    "herausgeschossener": "herausgeschossen",
    "herausgeschossenes": "herausgeschossen",
    "herausgeschunden": "herausschinden",
    "herausgeschundene": "herausgeschunden",
    "herausgeschundenem": "herausgeschunden",
    "herausgeschundenen": "herausgeschunden",
    "herausgeschundener": "herausgeschunden",
    "herausgeschundenere": "herausgeschunden",
    "herausgeschundenerem": "herausgeschunden",
    "herausgeschundeneren": "herausgeschunden",
    "herausgeschundenerer": "herausgeschunden",
    "herausgeschundeneres": "herausgeschunden",
    "herausgeschundenes": "herausgeschunden",
    "herausgeschundenste": "herausgeschunden",
    "herausgeschundenstem": "herausgeschunden",
    "herausgeschundensten": "herausgeschunden",
    "herausgeschundenster": "herausgeschunden",
    "herausgeschundenstes": "herausgeschunden",
    "herausgespielt": "herausspielen",
    "herausgespielte": "herausgespielt",
    "herausgespieltem": "herausgespielt",
    "herausgespielten": "herausgespielt",
    "herausgespielter": "herausgespielt",
    "herausgespieltere": "herausgespielt",
    "herausgespielterem": "herausgespielt",
    "herausgespielteren": "herausgespielt",
    "herausgespielterer": "herausgespielt",
    "herausgespielteres": "herausgespielt",
    "herausgespieltes": "herausgespielt",
    "herausgespielteste": "herausgespielt",
    "herausgespieltestem": "herausgespielt",
    "herausgespieltesten": "herausgespielt",
    "herausgespieltester": "herausgespielt",
    "herausgespieltestes": "herausgespielt",
    "herausgesprengt": "heraussprengen",
    "herausgesprengte": "herausgesprengt",
    "herausgesprengtem": "herausgesprengt",
    "herausgesprengten": "herausgesprengt",
    "herausgesprengter": "herausgesprengt",
    "herausgesprengtes": "herausgesprengt",
    "herausgespritzt": "herausspritzen",
    "herausgespritzte": "herausgespritzt",
    "herausgespritztem": "herausgespritzt",
    "herausgespritzten": "herausgespritzt",
    "herausgespritzter": "herausgespritzt",
    "herausgespritztes": "herausgespritzt",
    "herausgesprossen": "heraussprießen",
    "herausgesprossene": "herausgesprossen",
    "herausgesprossenem": "herausgesprossen",
    "herausgesprossenen": "herausgesprossen",
    "herausgesprossener": "herausgesprossen",
    "herausgesprossenes": "herausgesprossen",
    "herausgesprudelt": "heraussprudeln",
    "herausgesprudelte": "herausgesprudelt",
    "herausgesprudeltem": "herausgesprudelt",
    "herausgesprudelten": "herausgesprudelt",
    "herausgesprudelter": "herausgesprudelt",
    "herausgesprudeltes": "herausgesprudelt",
    "herausgestellt": "herausstellen",
    "herausgestellte": "herausgestellt",
    "herausgestelltem": "herausgestellt",
    "herausgestellten": "herausgestellt",
    "herausgestellter": "herausgestellt",
    "herausgestelltes": "herausgestellt",
    "herausgesucht": "heraussuchen",
    "herausgesuchte": "herausgesucht",
    "herausgesuchtem": "herausgesucht",
    "herausgesuchten": "herausgesucht",
    "herausgesuchter": "herausgesucht",
    "herausgesuchtes": "herausgesucht",
    "herausgeworfen": "herauswerfen",
    "herausgeworfene": "herausgeworfen",
    "herausgeworfenem": "herausgeworfen",
    "herausgeworfenen": "herausgeworfen",
    "herausgeworfener": "herausgeworfen",
    "herausgeworfenes": "herausgeworfen",
    "herausgezogene": "herausgezogen",
    "herausgezogenem": "herausgezogen",
    "herausgezogenen": "herausgezogen",
    "herausgezogener": "herausgezogen",
    "herausgezogenes": "herausgezogen",
    "herausgibst": "herausgeben",
    "herausgibt": "herausgeben",
    "herausgäbe": "herausgeben",
    "herausgäben": "herausgeben",
    "herausgäbest": "herausgeben",
    "herausgäbet": "herausgeben",
    "heraushalte": "heraushalten",
    "heraushaltend": "heraushalten",
    "heraushaltende": "heraushaltend",
    "heraushaltendem": "heraushaltend",
    "heraushaltenden": "heraushaltend",
    "heraushaltender": "heraushaltend",
    "heraushaltendes": "heraushaltend",
    "heraushaltest": "heraushalten",
    "heraushaltet": "heraushalten",
    "heraushebe": "herausheben",
    "heraushebend": "herausheben",
    "heraushebende": "heraushebend",
    "heraushebendem": "heraushebend",
    "heraushebenden": "heraushebend",
    "heraushebender": "heraushebend",
    "heraushebendes": "heraushebend",
    "heraushebest": "herausheben",
    "heraushebet": "herausheben",
    "heraushebst": "herausheben",
    "heraushebt": "herausheben",
    "heraushielt": "heraushalten",
    "heraushielte": "heraushalten",
    "heraushielten": "heraushalten",
    "heraushieltest": "heraushalten",
    "heraushieltet": "heraushalten",
    "heraushob": "herausheben",
    "heraushoben": "herausheben",
    "heraushobst": "herausheben",
    "heraushobt": "herausheben",
    "heraushält": "heraushalten",
    "heraushältst": "heraushalten",
    "heraushöbe": "herausheben",
    "heraushöben": "herausheben",
    "heraushöbest": "herausheben",
    "heraushöbet": "herausheben",
    "herauskristallisiere": "herauskristallisi",
    "herauskristallisieren": "herauskristallisi",
    "herauskristallisierend": "herauskristallisi",
    "herauskristallisierest": "herauskristallisi",
    "herauskristallisieret": "herauskristallisi",
    "herauskristallisierst": "herauskristallisi",
    "herauskristallisiert": "herauskristallisi",
    "herauskristallisierte": "herauskristallisi",
    "herauskristallisiertem": "herauskristallisiert",
    "herauskristallisierten": "herauskristallisi",
    "herauskristallisierter": "herauskristallisiert",
    "herauskristallisiertes": "herauskristallisiert",
    "herauskristallisiertest": "herauskristallisi",
    "herauskristallisiertet": "herauskristallisi",
    "herausluge": "herauslugen",
    "herauslugend": "herauslugen",
    "herauslugende": "herauslugend",
    "herauslugendem": "herauslugend",
    "herauslugenden": "herauslugend",
    "herauslugender": "herauslugend",
    "herauslugendere": "herauslugend",
    "herauslugenderem": "herauslugend",
    "herauslugenderen": "herauslugend",
    "herauslugenderer": "herauslugend",
    "herauslugenderes": "herauslugend",
    "herauslugendes": "herauslugend",
    "herauslugendste": "herauslugend",
    "herauslugendstem": "herauslugend",
    "herauslugendsten": "herauslugend",
    "herauslugendster": "herauslugend",
    "herauslugendstes": "herauslugend",
    "herauslugest": "herauslugen",
    "herausluget": "herauslugen",
    "herauslugst": "herauslugen",
    "herauslugt": "herauslugen",
    "herauslugte": "herauslugen",
    "herauslugten": "herauslugen",
    "herauslugtest": "herauslugen",
    "herauslugtet": "herauslugen",
    "herausputze": "herausputzen",
    "herausputzend": "herausputzen",
    "herausputzende": "herausputzend",
    "herausputzendem": "herausputzend",
    "herausputzenden": "herausputzend",
    "herausputzender": "herausputzend",
    "herausputzendes": "herausputzend",
    "herausputzest": "herausputzen",
    "herausputzet": "herausputzen",
    "herausputzt": "herausputzen",
    "herausputzte": "herausputzen",
    "herausputzten": "herausputzen",
    "herausputztest": "herausputzen",
    "herausputztet": "herausputzen",
    "herausreiche": "herausreichen",
    "herausreichend": "herausreichen",
    "herausreichende": "herausreichend",
    "herausreichendem": "herausreichend",
    "herausreichenden": "herausreichend",
    "herausreichender": "herausreichend",
    "herausreichendes": "herausreichend",
    "herausreichest": "herausreichen",
    "herausreichet": "herausreichen",
    "herausreichst": "herausreichen",
    "herausreicht": "herausreichen",
    "herausreichte": "herausreichen",
    "herausreichten": "herausreichen",
    "herausreichtest": "herausreichen",
    "herausreichtet": "herausreichen",
    "herausrücke": "herausrücken",
    "herausrückend": "herausrücken",
    "herausrückende": "herausrückend",
    "herausrückendem": "herausrückend",
    "herausrückenden": "herausrückend",
    "herausrückender": "herausrückend",
    "herausrückendes": "herausrückend",
    "herausrückest": "herausrücken",
    "herausrücket": "herausrücken",
    "herausrückst": "herausrücken",
    "herausrückt": "herausrücken",
    "herausrückte": "herausrücken",
    "herausrückten": "herausrücken",
    "herausrücktest": "herausrücken",
    "herausrücktet": "herausrücken",
    "herausschieße": "herausschießen",
    "herausschießend": "herausschießen",
    "herausschießende": "herausschießend",
    "herausschießendem": "herausschießend",
    "herausschießenden": "herausschießend",
    "herausschießender": "herausschießend",
    "herausschießendes": "herausschießend",
    "herausschießest": "herausschießen",
    "herausschießet": "herausschießen",
    "herausschießt": "herausschießen",
    "herausschinde": "herausschinden",
    "herausschindend": "herausschinden",
    "herausschindende": "herausschindend",
    "herausschindendem": "herausschindend",
    "herausschindenden": "herausschindend",
    "herausschindender": "herausschindend",
    "herausschindendere": "herausschindend",
    "herausschindenderem": "herausschindend",
    "herausschindenderen": "herausschindend",
    "herausschindenderer": "herausschindend",
    "herausschindenderes": "herausschindend",
    "herausschindendes": "herausschindend",
    "herausschindendste": "herausschindend",
    "herausschindendstem": "herausschindend",
    "herausschindendsten": "herausschindend",
    "herausschindendster": "herausschindend",
    "herausschindendstes": "herausschindend",
    "herausschindest": "herausschinden",
    "herausschindet": "herausschinden",
    "herausschindete": "herausschinden",
    "herausschindeten": "herausschinden",
    "herausschindetest": "herausschinden",
    "herausschindetet": "herausschinden",
    "herausschossen": "herausschießen",
    "herausschoß": "herausschießen",
    "herausschoßt": "herausschießen",
    "herausschösse": "herausschießen",
    "herausschössen": "herausschießen",
    "herausschössest": "herausschießen",
    "herausschösset": "herausschießen",
    "herausspiele": "herausspielen",
    "herausspielend": "herausspielen",
    "herausspielende": "herausspielend",
    "herausspielendem": "herausspielend",
    "herausspielenden": "herausspielend",
    "herausspielender": "herausspielend",
    "herausspielendes": "herausspielend",
    "herausspielest": "herausspielen",
    "herausspielet": "herausspielen",
    "herausspielst": "herausspielen",
    "herausspielt": "herausspielen",
    "herausspielte": "herausspielen",
    "herausspielten": "herausspielen",
    "herausspieltest": "herausspielen",
    "herausspieltet": "herausspielen",
    "heraussprenge": "heraussprengen",
    "heraussprengend": "heraussprengen",
    "heraussprengende": "heraussprengend",
    "heraussprengendem": "heraussprengend",
    "heraussprengenden": "heraussprengend",
    "heraussprengender": "heraussprengend",
    "heraussprengendes": "heraussprengend",
    "heraussprengest": "heraussprengen",
    "heraussprenget": "heraussprengen",
    "heraussprengst": "heraussprengen",
    "heraussprengt": "heraussprengen",
    "heraussprengte": "heraussprengen",
    "heraussprengten": "heraussprengen",
    "heraussprengtest": "heraussprengen",
    "heraussprengtet": "heraussprengen",
    "heraussprieße": "heraussprießen",
    "heraussprießend": "heraussprießen",
    "heraussprießende": "heraussprießend",
    "heraussprießendem": "heraussprießend",
    "heraussprießenden": "heraussprießend",
    "heraussprießender": "heraussprießend",
    "heraussprießendes": "heraussprießend",
    "heraussprießest": "heraussprießen",
    "heraussprießet": "heraussprießen",
    "heraussprießt": "heraussprießen",
    "herausspritze": "herausspritzen",
    "herausspritzend": "herausspritzen",
    "herausspritzende": "herausspritzend",
    "herausspritzendem": "herausspritzend",
    "herausspritzenden": "herausspritzend",
    "herausspritzender": "herausspritzend",
    "herausspritzendes": "herausspritzend",
    "herausspritzest": "herausspritzen",
    "herausspritzet": "herausspritzen",
    "herausspritzt": "herausspritzen",
    "herausspritzte": "herausspritzen",
    "herausspritzten": "herausspritzen",
    "herausspritztest": "herausspritzen",
    "herausspritztet": "herausspritzen",
    "heraussprossen": "heraussprießen",
    "heraussproß": "heraussprießen",
    "heraussproßt": "heraussprießen",
    "heraussprudele": "heraussprudeln",
    "heraussprudelnd": "heraussprudeln",
    "heraussprudelnde": "heraussprudelnd",
    "heraussprudelndem": "heraussprudelnd",
    "heraussprudelnden": "heraussprudelnd",
    "heraussprudelnder": "heraussprudelnd",
    "heraussprudelndes": "heraussprudelnd",
    "heraussprudelst": "heraussprudeln",
    "heraussprudelt": "heraussprudeln",
    "heraussprudelte": "heraussprudeln",
    "heraussprudelten": "heraussprudeln",
    "heraussprudeltest": "heraussprudeln",
    "heraussprudeltet": "heraussprudeln",
    "heraussprudle": "heraussprudeln",
    "heraussprösse": "heraussprießen",
    "heraussprössen": "heraussprießen",
    "heraussprössest": "heraussprießen",
    "heraussprösset": "heraussprießen",
    "herausstelle": "herausstellen",
    "herausstellend": "herausstellen",
    "herausstellende": "herausstellend",
    "herausstellendem": "herausstellend",
    "herausstellenden": "herausstellend",
    "herausstellender": "herausstellend",
    "herausstellendes": "herausstellend",
    "herausstellest": "herausstellen",
    "herausstellet": "herausstellen",
    "herausstellst": "herausstellen",
    "herausstellt": "herausstellen",
    "herausstellte": "herausstellen",
    "herausstellten": "herausstellen",
    "herausstelltest": "herausstellen",
    "herausstelltet": "herausstellen",
    "heraussuche": "heraussuchen",
    "heraussuchend": "heraussuchen",
    "heraussuchende": "heraussuchend",
    "heraussuchendem": "heraussuchend",
    "heraussuchenden": "heraussuchend",
    "heraussuchender": "heraussuchend",
    "heraussuchendes": "heraussuchend",
    "heraussuchest": "heraussuchen",
    "heraussuchet": "heraussuchen",
    "heraussuchst": "heraussuchen",
    "heraussucht": "heraussuchen",
    "heraussuchte": "heraussuchen",
    "heraussuchten": "heraussuchen",
    "heraussuchtest": "heraussuchen",
    "heraussuchtet": "heraussuchen",
    "herauswarf": "herauswerfen",
    "herauswarfen": "herauswerfen",
    "herauswarfst": "herauswerfen",
    "herauswarft": "herauswerfen",
    "herauswerfe": "herauswerfen",
    "herauswerfend": "herauswerfen",
    "herauswerfende": "herauswerfend",
    "herauswerfendem": "herauswerfend",
    "herauswerfenden": "herauswerfend",
    "herauswerfender": "herauswerfend",
    "herauswerfendes": "herauswerfend",
    "herauswerfest": "herauswerfen",
    "herauswerfet": "herauswerfen",
    "herauswerft": "herauswerfen",
    "herauswirfst": "herauswerfen",
    "herauswirft": "herauswerfen",
    "herauswärfe": "herauswerfen",
    "herauswärfen": "herauswerfen",
    "herauswärfest": "herauswerfen",
    "herauswärfet": "herauswerfen",
    "herausziehbare": "herausziehbar",
    "herausziehbarem": "herausziehbar",
    "herausziehbaren": "herausziehbar",
    "herausziehbarer": "herausziehbar",
    "herausziehbares": "herausziehbar",
    "herausziehende": "herausziehend",
    "herausziehendem": "herausziehend",
    "herausziehenden": "herausziehend",
    "herausziehender": "herausziehend",
    "herausziehendes": "herausziehend",
    "herauszuarbeiten": "herausarbeiten",
    "herauszubeißen": "herausbeißen",
    "herauszubrechen": "herausbrechen",
    "herauszufiltern": "herausfiltern",
    "herauszuführen": "herausführen",
    "herauszugeben": "herausgeben",
    "herauszuhalten": "heraushalten",
    "herauszuheben": "herausheben",
    "herauszukristallisieren": "herauskristallisi",
    "herauszulugen": "herauslugen",
    "herauszuputzen": "herausputzen",
    "herauszureichen": "herausreichen",
    "herauszurücken": "herausrücken",
    "herauszuschießen": "herausschießen",
    "herauszuschinden": "herausschinden",
    "herauszuspielen": "herausspielen",
    "herauszusprengen": "heraussprengen",
    "herauszusprießen": "heraussprießen",
    "herauszuspritzen": "herausspritzen",
    "herauszusprudeln": "heraussprudeln",
    "herauszustellen": "herausstellen",
    "herauszusuchen": "heraussuchen",
    "herauszuwerfen": "herauswerfen",
    "herbat": "herbitten",
    "herbaten": "herbitten",
    "herbatest": "herbitten",
    "herbatet": "herbitten",
    "herbe": "herb",
    "herbegleite": "herbegleiten",
    "herbegleitend": "herbegleiten",
    "herbegleitende": "herbegleitend",
    "herbegleitendem": "herbegleitend",
    "herbegleitenden": "herbegleitend",
    "herbegleitender": "herbegleitend",
    "herbegleitendes": "herbegleitend",
    "herbegleitest": "herbegleiten",
    "herbegleitet": "herbegleiten",
    "herbegleitete": "herbegleiten",
    "herbegleitetem": "herbegleitet",
    "herbegleiteten": "herbegleiten",
    "herbegleiteter": "herbegleitet",
    "herbegleitetes": "herbegleitet",
    "herbegleitetest": "herbegleiten",
    "herbegleitetet": "herbegleiten",
    "herbeibrachte": "herbeibringen",
    "herbeibrachten": "herbeibringen",
    "herbeibrachtest": "herbeibringen",
    "herbeibrachtet": "herbeibringen",
    "herbeibringe": "herbeibringen",
    "herbeibringend": "herbeibringen",
    "herbeibringende": "herbeibringend",
    "herbeibringendem": "herbeibringend",
    "herbeibringenden": "herbeibringend",
    "herbeibringender": "herbeibringend",
    "herbeibringendes": "herbeibringend",
    "herbeibringest": "herbeibringen",
    "herbeibringet": "herbeibringen",
    "herbeibringst": "herbeibringen",
    "herbeibringt": "herbeibringen",
    "herbeibrächte": "herbeibringen",
    "herbeibrächten": "herbeibringen",
    "herbeibrächtest": "herbeibringen",
    "herbeibrächtet": "herbeibringen",
    "herbeidränge": "herbeidrängen",
    "herbeidrängend": "herbeidrängen",
    "herbeidrängende": "herbeidrängend",
    "herbeidrängendem": "herbeidrängend",
    "herbeidrängenden": "herbeidrängend",
    "herbeidrängender": "herbeidrängend",
    "herbeidrängendes": "herbeidrängend",
    "herbeidrängest": "herbeidrängen",
    "herbeidränget": "herbeidrängen",
    "herbeidrängst": "herbeidrängen",
    "herbeidrängt": "herbeidrängen",
    "herbeidrängte": "herbeidrängen",
    "herbeidrängten": "herbeidrängen",
    "herbeidrängtest": "herbeidrängen",
    "herbeidrängtet": "herbeidrängen",
    "herbeieile": "herbeieilen",
    "herbeieilend": "herbeieilen",
    "herbeieilende": "herbeieilend",
    "herbeieilendem": "herbeieilend",
    "herbeieilenden": "herbeieilend",
    "herbeieilender": "herbeieilend",
    "herbeieilendes": "herbeieilend",
    "herbeieilest": "herbeieilen",
    "herbeieilet": "herbeieilen",
    "herbeieilst": "herbeieilen",
    "herbeieilt": "herbeieilen",
    "herbeieilte": "herbeieilen",
    "herbeieilten": "herbeieilen",
    "herbeieiltest": "herbeieilen",
    "herbeieiltet": "herbeieilen",
    "herbeifliege": "herbeifliegen",
    "herbeifliegend": "herbeifliegen",
    "herbeifliegende": "herbeifliegend",
    "herbeifliegendem": "herbeifliegend",
    "herbeifliegenden": "herbeifliegend",
    "herbeifliegender": "herbeifliegend",
    "herbeifliegendes": "herbeifliegend",
    "herbeifliegest": "herbeifliegen",
    "herbeiflieget": "herbeifliegen",
    "herbeifliegst": "herbeifliegen",
    "herbeifliegt": "herbeifliegen",
    "herbeiflog": "herbeifliegen",
    "herbeiflogen": "herbeifliegen",
    "herbeiflogst": "herbeifliegen",
    "herbeiflogt": "herbeifliegen",
    "herbeiflöge": "herbeifliegen",
    "herbeiflögen": "herbeifliegen",
    "herbeiflögest": "herbeifliegen",
    "herbeiflöget": "herbeifliegen",
    "herbeiführe": "herbeiführen",
    "herbeiführend": "herbeiführen",
    "herbeiführende": "herbeiführend",
    "herbeiführendem": "herbeiführend",
    "herbeiführenden": "herbeiführend",
    "herbeiführender": "herbeiführend",
    "herbeiführendes": "herbeiführend",
    "herbeiführest": "herbeiführen",
    "herbeiführet": "herbeiführen",
    "herbeiführst": "herbeiführen",
    "herbeiführt": "herbeiführen",
    "herbeiführte": "herbeiführen",
    "herbeiführten": "herbeiführen",
    "herbeiführtest": "herbeiführen",
    "herbeiführtet": "herbeiführen",
    "herbeigebracht": "herbeibringen",
    "herbeigebrachte": "herbeigebracht",
    "herbeigebrachtem": "herbeigebracht",
    "herbeigebrachten": "herbeigebracht",
    "herbeigebrachter": "herbeigebracht",
    "herbeigebrachtes": "herbeigebracht",
    "herbeigedrängt": "herbeidrängen",
    "herbeigedrängte": "herbeigedrängt",
    "herbeigedrängtem": "herbeigedrängt",
    "herbeigedrängten": "herbeigedrängt",
    "herbeigedrängter": "herbeigedrängt",
    "herbeigedrängtes": "herbeigedrängt",
    "herbeigeeilt": "herbeieilen",
    "herbeigeeilte": "herbeigeeilt",
    "herbeigeeiltem": "herbeigeeilt",
    "herbeigeeilten": "herbeigeeilt",
    "herbeigeeilter": "herbeigeeilt",
    "herbeigeeiltes": "herbeigeeilt",
    "herbeigeflogen": "herbeifliegen",
    "herbeigeflogene": "herbeigeflogen",
    "herbeigeflogenem": "herbeigeflogen",
    "herbeigeflogenen": "herbeigeflogen",
    "herbeigeflogener": "herbeigeflogen",
    "herbeigeflogenes": "herbeigeflogen",
    "herbeigeführt": "herbeiführen",
    "herbeigeführte": "herbeigeführt",
    "herbeigeführtem": "herbeigeführt",
    "herbeigeführten": "herbeigeführt",
    "herbeigeführter": "herbeigeführt",
    "herbeigeführtes": "herbeigeführt",
    "herbeigeholt": "herbeiholen",
    "herbeigeholte": "herbeigeholt",
    "herbeigeholtem": "herbeigeholt",
    "herbeigeholten": "herbeigeholt",
    "herbeigeholter": "herbeigeholt",
    "herbeigeholtes": "herbeigeholt",
    "herbeigelaufen": "herbeilaufen",
    "herbeigelaufene": "herbeigelaufen",
    "herbeigelaufenem": "herbeigelaufen",
    "herbeigelaufenen": "herbeigelaufen",
    "herbeigelaufener": "herbeigelaufen",
    "herbeigelaufenes": "herbeigelaufen",
    "herbeigerannt": "herbeirennen",
    "herbeigerannte": "herbeigerannt",
    "herbeigeranntem": "herbeigerannt",
    "herbeigerannten": "herbeigerannt",
    "herbeigerannter": "herbeigerannt",
    "herbeigeranntes": "herbeigerannt",
    "herbeigerufen": "herbeirufen",
    "herbeigerufene": "herbeigerufen",
    "herbeigerufenem": "herbeigerufen",
    "herbeigerufenen": "herbeigerufen",
    "herbeigerufener": "herbeigerufen",
    "herbeigerufenes": "herbeigerufen",
    "herbeigeschaffen": "herbeischaffen",
    "herbeigeschaffene": "herbeigeschaffen",
    "herbeigeschaffenem": "herbeigeschaffen",
    "herbeigeschaffenen": "herbeigeschaffen",
    "herbeigeschaffener": "herbeigeschaffen",
    "herbeigeschaffenes": "herbeigeschaffen",
    "herbeigeschafft": "herbeischaffen",
    "herbeigeschaffte": "herbeigeschafft",
    "herbeigeschafftem": "herbeigeschafft",
    "herbeigeschafften": "herbeigeschafft",
    "herbeigeschaffter": "herbeigeschafft",
    "herbeigeschafftes": "herbeigeschafft",
    "herbeigeschleppt": "herbeischleppen",
    "herbeigeschleppte": "herbeigeschleppt",
    "herbeigeschlepptem": "herbeigeschleppt",
    "herbeigeschleppten": "herbeigeschleppt",
    "herbeigeschleppter": "herbeigeschleppt",
    "herbeigeschlepptes": "herbeigeschleppt",
    "herbeigeschworen": "herbeischwören",
    "herbeigeschworene": "herbeigeschworen",
    "herbeigeschworenem": "herbeigeschworen",
    "herbeigeschworenen": "herbeigeschworen",
    "herbeigeschworener": "herbeigeschworen",
    "herbeigeschworenes": "herbeigeschworen",
    "herbeigesehnt": "herbeisehnen",
    "herbeigesehnte": "herbeigesehnt",
    "herbeigesehntem": "herbeigesehnt",
    "herbeigesehnten": "herbeigesehnt",
    "herbeigesehnter": "herbeigesehnt",
    "herbeigesehntere": "herbeigesehnt",
    "herbeigesehnterem": "herbeigesehnt",
    "herbeigesehnteren": "herbeigesehnt",
    "herbeigesehnterer": "herbeigesehnt",
    "herbeigesehnteres": "herbeigesehnt",
    "herbeigesehntes": "herbeigesehnt",
    "herbeigesehnteste": "herbeigesehnt",
    "herbeigesehntestem": "herbeigesehnt",
    "herbeigesehntesten": "herbeigesehnt",
    "herbeigesehntester": "herbeigesehnt",
    "herbeigesehntestes": "herbeigesehnt",
    "herbeigesprungen": "herbeispringen",
    "herbeigesprungene": "herbeigesprungen",
    "herbeigesprungenem": "herbeigesprungen",
    "herbeigesprungenen": "herbeigesprungen",
    "herbeigesprungener": "herbeigesprungen",
    "herbeigesprungenes": "herbeigesprungen",
    "herbeigeströmt": "herbeiströmen",
    "herbeigeströmte": "herbeigeströmt",
    "herbeigeströmtem": "herbeigeströmt",
    "herbeigeströmten": "herbeigeströmt",
    "herbeigeströmter": "herbeigeströmt",
    "herbeigeströmtes": "herbeigeströmt",
    "herbeigestürzt": "herbeistürzen",
    "herbeigestürzte": "herbeigestürzt",
    "herbeigestürztem": "herbeigestürzt",
    "herbeigestürzten": "herbeigestürzt",
    "herbeigestürzter": "herbeigestürzt",
    "herbeigestürztes": "herbeigestürzt",
    "herbeigetragen": "herbeitragen",
    "herbeigetragene": "herbeigetragen",
    "herbeigetragenem": "herbeigetragen",
    "herbeigetragenen": "herbeigetragen",
    "herbeigetragener": "herbeigetragen",
    "herbeigetragenes": "herbeigetragen",
    "herbeigewinkt": "herbeiwinken",
    "herbeigewinkte": "herbeigewinkt",
    "herbeigewinktem": "herbeigewinkt",
    "herbeigewinkten": "herbeigewinkt",
    "herbeigewinkter": "herbeigewinkt",
    "herbeigewinktes": "herbeigewinkt",
    "herbeigewünscht": "herbeiwünschen",
    "herbeigewünschte": "herbeigewünscht",
    "herbeigewünschtem": "herbeigewünscht",
    "herbeigewünschten": "herbeigewünscht",
    "herbeigewünschter": "herbeigewünscht",
    "herbeigewünschtes": "herbeigewünscht",
    "herbeihole": "herbeiholen",
    "herbeiholend": "herbeiholen",
    "herbeiholende": "herbeiholend",
    "herbeiholendem": "herbeiholend",
    "herbeiholenden": "herbeiholend",
    "herbeiholender": "herbeiholend",
    "herbeiholendes": "herbeiholend",
    "herbeiholest": "herbeiholen",
    "herbeiholet": "herbeiholen",
    "herbeiholst": "herbeiholen",
    "herbeiholt": "herbeiholen",
    "herbeiholte": "herbeiholen",
    "herbeiholten": "herbeiholen",
    "herbeiholtest": "herbeiholen",
    "herbeiholtet": "herbeiholen",
    "herbeilaufe": "herbeilaufen",
    "herbeilaufend": "herbeilaufen",
    "herbeilaufende": "herbeilaufend",
    "herbeilaufendem": "herbeilaufend",
    "herbeilaufenden": "herbeilaufend",
    "herbeilaufender": "herbeilaufend",
    "herbeilaufendes": "herbeilaufend",
    "herbeilaufest": "herbeilaufen",
    "herbeilaufet": "herbeilaufen",
    "herbeilauft": "herbeilaufen",
    "herbeilief": "herbeilaufen",
    "herbeiliefe": "herbeilaufen",
    "herbeiliefen": "herbeilaufen",
    "herbeiliefest": "herbeilaufen",
    "herbeiliefet": "herbeilaufen",
    "herbeiliefst": "herbeilaufen",
    "herbeilieft": "herbeilaufen",
    "herbeiläufst": "herbeilaufen",
    "herbeiläuft": "herbeilaufen",
    "herbeirannte": "herbeirennen",
    "herbeirannten": "herbeirennen",
    "herbeiranntest": "herbeirennen",
    "herbeiranntet": "herbeirennen",
    "herbeirenne": "herbeirennen",
    "herbeirennend": "herbeirennen",
    "herbeirennende": "herbeirennend",
    "herbeirennendem": "herbeirennend",
    "herbeirennenden": "herbeirennend",
    "herbeirennender": "herbeirennend",
    "herbeirennendes": "herbeirennend",
    "herbeirennest": "herbeirennen",
    "herbeirennet": "herbeirennen",
    "herbeirennst": "herbeirennen",
    "herbeirennt": "herbeirennen",
    "herbeirief": "herbeirufen",
    "herbeiriefe": "herbeirufen",
    "herbeiriefen": "herbeirufen",
    "herbeiriefest": "herbeirufen",
    "herbeiriefet": "herbeirufen",
    "herbeiriefst": "herbeirufen",
    "herbeirieft": "herbeirufen",
    "herbeirufe": "herbeirufen",
    "herbeirufend": "herbeirufen",
    "herbeirufende": "herbeirufend",
    "herbeirufendem": "herbeirufend",
    "herbeirufenden": "herbeirufend",
    "herbeirufender": "herbeirufend",
    "herbeirufendes": "herbeirufend",
    "herbeirufest": "herbeirufen",
    "herbeirufet": "herbeirufen",
    "herbeirufst": "herbeirufen",
    "herbeiruft": "herbeirufen",
    "herbeischaffe": "herbeischaffen",
    "herbeischaffend": "herbeischaffen",
    "herbeischaffende": "herbeischaffend",
    "herbeischaffendem": "herbeischaffend",
    "herbeischaffenden": "herbeischaffend",
    "herbeischaffender": "herbeischaffend",
    "herbeischaffendes": "herbeischaffend",
    "herbeischaffest": "herbeischaffen",
    "herbeischaffet": "herbeischaffen",
    "herbeischaffst": "herbeischaffen",
    "herbeischafft": "herbeischaffen",
    "herbeischaffte": "herbeischaffen",
    "herbeischafften": "herbeischaffen",
    "herbeischafftest": "herbeischaffen",
    "herbeischafftet": "herbeischaffen",
    "herbeischleppe": "herbeischleppen",
    "herbeischleppend": "herbeischleppen",
    "herbeischleppende": "herbeischleppend",
    "herbeischleppendem": "herbeischleppend",
    "herbeischleppenden": "herbeischleppend",
    "herbeischleppender": "herbeischleppend",
    "herbeischleppendes": "herbeischleppend",
    "herbeischleppest": "herbeischleppen",
    "herbeischleppet": "herbeischleppen",
    "herbeischleppst": "herbeischleppen",
    "herbeischleppt": "herbeischleppen",
    "herbeischleppte": "herbeischleppen",
    "herbeischleppten": "herbeischleppen",
    "herbeischlepptest": "herbeischleppen",
    "herbeischlepptet": "herbeischleppen",
    "herbeischuf": "herbeischaffen",
    "herbeischufen": "herbeischaffen",
    "herbeischufst": "herbeischaffen",
    "herbeischuft": "herbeischaffen",
    "herbeischwor": "herbeischwören",
    "herbeischworen": "herbeischwören",
    "herbeischworst": "herbeischwören",
    "herbeischwort": "herbeischwören",
    "herbeischwöre": "herbeischwören",
    "herbeischwörend": "herbeischwören",
    "herbeischwörende": "herbeischwörend",
    "herbeischwörendem": "herbeischwörend",
    "herbeischwörenden": "herbeischwörend",
    "herbeischwörender": "herbeischwörend",
    "herbeischwörendes": "herbeischwörend",
    "herbeischwörest": "herbeischwören",
    "herbeischwöret": "herbeischwören",
    "herbeischwörst": "herbeischwören",
    "herbeischwört": "herbeischwören",
    "herbeischüfe": "herbeischaffen",
    "herbeischüfen": "herbeischaffen",
    "herbeischüfest": "herbeischaffen",
    "herbeischüfet": "herbeischaffen",
    "herbeisehne": "herbeisehnen",
    "herbeisehnend": "herbeisehnen",
    "herbeisehnende": "herbeisehnend",
    "herbeisehnendem": "herbeisehnend",
    "herbeisehnenden": "herbeisehnend",
    "herbeisehnender": "herbeisehnend",
    "herbeisehnendere": "herbeisehnend",
    "herbeisehnenderem": "herbeisehnend",
    "herbeisehnenderen": "herbeisehnend",
    "herbeisehnenderer": "herbeisehnend",
    "herbeisehnenderes": "herbeisehnend",
    "herbeisehnendes": "herbeisehnend",
    "herbeisehnendste": "herbeisehnend",
    "herbeisehnendstem": "herbeisehnend",
    "herbeisehnendsten": "herbeisehnend",
    "herbeisehnendster": "herbeisehnend",
    "herbeisehnendstes": "herbeisehnend",
    "herbeisehnest": "herbeisehnen",
    "herbeisehnet": "herbeisehnen",
    "herbeisehnst": "herbeisehnen",
    "herbeisehnt": "herbeisehnen",
    "herbeisehnte": "herbeisehnen",
    "herbeisehnten": "herbeisehnen",
    "herbeisehntest": "herbeisehnen",
    "herbeisehntet": "herbeisehnen",
    "herbeisprang": "herbeispringen",
    "herbeisprangen": "herbeispringen",
    "herbeisprangst": "herbeispringen",
    "herbeisprangt": "herbeispringen",
    "herbeispringe": "herbeispringen",
    "herbeispringend": "herbeispringen",
    "herbeispringende": "herbeispringend",
    "herbeispringendem": "herbeispringend",
    "herbeispringenden": "herbeispringend",
    "herbeispringender": "herbeispringend",
    "herbeispringendes": "herbeispringend",
    "herbeispringest": "herbeispringen",
    "herbeispringet": "herbeispringen",
    "herbeispringst": "herbeispringen",
    "herbeispringt": "herbeispringen",
    "herbeispränge": "herbeispringen",
    "herbeisprängen": "herbeispringen",
    "herbeisprängest": "herbeispringen",
    "herbeispränget": "herbeispringen",
    "herbeiströme": "herbeiströmen",
    "herbeiströmend": "herbeiströmen",
    "herbeiströmende": "herbeiströmend",
    "herbeiströmendem": "herbeiströmend",
    "herbeiströmenden": "herbeiströmend",
    "herbeiströmender": "herbeiströmend",
    "herbeiströmendes": "herbeiströmend",
    "herbeiströmest": "herbeiströmen",
    "herbeiströmet": "herbeiströmen",
    "herbeiströmst": "herbeiströmen",
    "herbeiströmt": "herbeiströmen",
    "herbeiströmte": "herbeiströmen",
    "herbeiströmten": "herbeiströmen",
    "herbeiströmtest": "herbeiströmen",
    "herbeiströmtet": "herbeiströmen",
    "herbeistürze": "herbeistürzen",
    "herbeistürzend": "herbeistürzen",
    "herbeistürzende": "herbeistürzend",
    "herbeistürzendem": "herbeistürzend",
    "herbeistürzenden": "herbeistürzend",
    "herbeistürzender": "herbeistürzend",
    "herbeistürzendes": "herbeistürzend",
    "herbeistürzest": "herbeistürzen",
    "herbeistürzet": "herbeistürzen",
    "herbeistürzt": "herbeistürzen",
    "herbeistürzte": "herbeistürzen",
    "herbeistürzten": "herbeistürzen",
    "herbeistürztest": "herbeistürzen",
    "herbeistürztet": "herbeistürzen",
    "herbeitrage": "herbeitragen",
    "herbeitragend": "herbeitragen",
    "herbeitragende": "herbeitragend",
    "herbeitragendem": "herbeitragend",
    "herbeitragenden": "herbeitragend",
    "herbeitragender": "herbeitragend",
    "herbeitragendes": "herbeitragend",
    "herbeitragest": "herbeitragen",
    "herbeitraget": "herbeitragen",
    "herbeitragt": "herbeitragen",
    "herbeitrug": "herbeitragen",
    "herbeitrugen": "herbeitragen",
    "herbeitrugst": "herbeitragen",
    "herbeitrugt": "herbeitragen",
    "herbeiträgst": "herbeitragen",
    "herbeiträgt": "herbeitragen",
    "herbeitrüge": "herbeitragen",
    "herbeitrügen": "herbeitragen",
    "herbeitrügest": "herbeitragen",
    "herbeitrüget": "herbeitragen",
    "herbeiwinke": "herbeiwinken",
    "herbeiwinkend": "herbeiwinken",
    "herbeiwinkende": "herbeiwinkend",
    "herbeiwinkendem": "herbeiwinkend",
    "herbeiwinkenden": "herbeiwinkend",
    "herbeiwinkender": "herbeiwinkend",
    "herbeiwinkendes": "herbeiwinkend",
    "herbeiwinkest": "herbeiwinken",
    "herbeiwinket": "herbeiwinken",
    "herbeiwinkst": "herbeiwinken",
    "herbeiwinkt": "herbeiwinken",
    "herbeiwinkte": "herbeiwinken",
    "herbeiwinkten": "herbeiwinken",
    "herbeiwinktest": "herbeiwinken",
    "herbeiwinktet": "herbeiwinken",
    "herbeiwünsche": "herbeiwünschen",
    "herbeiwünschend": "herbeiwünschen",
    "herbeiwünschende": "herbeiwünschend",
    "herbeiwünschendem": "herbeiwünschend",
    "herbeiwünschenden": "herbeiwünschend",
    "herbeiwünschender": "herbeiwünschend",
    "herbeiwünschendes": "herbeiwünschend",
    "herbeiwünschest": "herbeiwünschen",
    "herbeiwünschet": "herbeiwünschen",
    "herbeiwünschst": "herbeiwünschen",
    "herbeiwünscht": "herbeiwünschen",
    "herbeiwünschte": "herbeiwünschen",
    "herbeiwünschten": "herbeiwünschen",
    "herbeiwünschtest": "herbeiwünschen",
    "herbeiwünschtet": "herbeiwünschen",
    "herbeizitiere": "herbeizitieren",
    "herbeizitierend": "herbeizitieren",
    "herbeizitierende": "herbeizitierend",
    "herbeizitierendem": "herbeizitierend",
    "herbeizitierenden": "herbeizitierend",
    "herbeizitierender": "herbeizitierend",
    "herbeizitierendes": "herbeizitierend",
    "herbeizitierest": "herbeizitieren",
    "herbeizitieret": "herbeizitieren",
    "herbeizitierst": "herbeizitieren",
    "herbeizitiert": "herbeizitieren",
    "herbeizitierte": "herbeizitieren",
    "herbeizitiertem": "herbeizitiert",
    "herbeizitierten": "herbeizitieren",
    "herbeizitierter": "herbeizitiert",
    "herbeizitiertes": "herbeizitiert",
    "herbeizitiertest": "herbeizitieren",
    "herbeizitiertet": "herbeizitieren",
    "herbeizubringen": "herbeibringen",
    "herbeizudrängen": "herbeidrängen",
    "herbeizueilen": "herbeieilen",
    "herbeizufliegen": "herbeifliegen",
    "herbeizuführen": "herbeiführen",
    "herbeizuholen": "herbeiholen",
    "herbeizulaufen": "herbeilaufen",
    "herbeizurennen": "herbeirennen",
    "herbeizurufen": "herbeirufen",
    "herbeizuschaffen": "herbeischaffen",
    "herbeizuschleppen": "herbeischleppen",
    "herbeizuschwören": "herbeischwören",
    "herbeizusehnen": "herbeisehnen",
    "herbeizuspringen": "herbeispringen",
    "herbeizuströmen": "herbeiströmen",
    "herbeizustürzen": "herbeistürzen",
    "herbeizutragen": "herbeitragen",
    "herbeizuwinken": "herbeiwinken",
    "herbeizuwünschen": "herbeiwünschen",
    "herbeizuzitieren": "herbeizitieren",
    "herbekam": "herbekommen",
    "herbekamen": "herbekommen",
    "herbekamst": "herbekommen",
    "herbekamt": "herbekommen",
    "herbekomme": "herbekommen",
    "herbekommend": "herbekommen",
    "herbekommende": "herbekommend",
    "herbekommendem": "herbekommend",
    "herbekommenden": "herbekommend",
    "herbekommender": "herbekommend",
    "herbekommendes": "herbekommend",
    "herbekommene": "herbekommen",
    "herbekommenem": "herbekommen",
    "herbekommenen": "herbekommen",
    "herbekommener": "herbekommen",
    "herbekommenes": "herbekommen",
    "herbekommest": "herbekommen",
    "herbekommet": "herbekommen",
    "herbekommst": "herbekommen",
    "herbekommt": "herbekommen",
    "herbekäme": "herbekommen",
    "herbekämen": "herbekommen",
    "herbekämest": "herbekommen",
    "herbekämet": "herbekommen",
    "herbem": "herb",
    "herbemühe": "herbemühen",
    "herbemühend": "herbemühen",
    "herbemühende": "herbemühend",
    "herbemühendem": "herbemühend",
    "herbemühenden": "herbemühend",
    "herbemühender": "herbemühend",
    "herbemühendes": "herbemühend",
    "herbemühest": "herbemühen",
    "herbemühet": "herbemühen",
    "herbemühst": "herbemühen",
    "herbemüht": "herbemühen",
    "herbemühte": "herbemühen",
    "herbemühtem": "herbemüht",
    "herbemühten": "herbemühen",
    "herbemühter": "herbemüht",
    "herbemühtes": "herbemüht",
    "herbemühtest": "herbemühen",
    "herbemühtet": "herbemühen",
    "herben": "herb",
    "herbeordere": "herbeordern",
    "herbeordernd": "herbeordern",
    "herbeordernde": "herbeordernd",
    "herbeorderndem": "herbeordernd",
    "herbeordernden": "herbeordernd",
    "herbeordernder": "herbeordernd",
    "herbeorderndes": "herbeordernd",
    "herbeorderst": "herbeordern",
    "herbeordert": "herbeordern",
    "herbeorderte": "herbeordern",
    "herbeordertem": "herbeordert",
    "herbeorderten": "herbeordern",
    "herbeorderter": "herbeordert",
    "herbeordertes": "herbeordert",
    "herbeordertest": "herbeordern",
    "herbeordertet": "herbeordern",
    "herbequeme": "herbequemen",
    "herbequemend": "herbequemen",
    "herbequemende": "herbequemend",
    "herbequemendem": "herbequemend",
    "herbequemenden": "herbequemend",
    "herbequemender": "herbequemend",
    "herbequemendes": "herbequemend",
    "herbequemest": "herbequemen",
    "herbequemet": "herbequemen",
    "herbequemst": "herbequemen",
    "herbequemt": "herbequemen",
    "herbequemte": "herbequemen",
    "herbequemtem": "herbequemt",
    "herbequemten": "herbequemen",
    "herbequemter": "herbequemt",
    "herbequemtes": "herbequemt",
    "herbequemtest": "herbequemen",
    "herbequemtet": "herbequemen",
    "herber": "herb",
    "herbere": "herb",
    "herberem": "herb",
    "herberen": "herb",
    "herberer": "herb",
    "herberes": "herb",
    "herbes": "herb",
    "herbestelle": "herbestellen",
    "herbestellend": "herbestellen",
    "herbestellende": "herbestellend",
    "herbestellendem": "herbestellend",
    "herbestellenden": "herbestellend",
    "herbestellender": "herbestellend",
    "herbestellendes": "herbestellend",
    "herbestellest": "herbestellen",
    "herbestellet": "herbestellen",
    "herbestellst": "herbestellen",
    "herbestellt": "herbestellen",
    "herbestellte": "herbestellen",
    "herbestelltem": "herbestellt",
    "herbestellten": "herbestellen",
    "herbestellter": "herbestellt",
    "herbestelltes": "herbestellt",
    "herbestelltest": "herbestellen",
    "herbestelltet": "herbestellen",
    "herbete": "herbeten",
    "herbetend": "herbeten",
    "herbetende": "herbetend",
    "herbetendem": "herbetend",
    "herbetenden": "herbetend",
    "herbetender": "herbetend",
    "herbetendes": "herbetend",
    "herbetest": "herbeten",
    "herbetet": "herbeten",
    "herbetete": "herbeten",
    "herbeteten": "herbeten",
    "herbetetest": "herbeten",
    "herbetetet": "herbeten",
    "herbitte": "herbitten",
    "herbittend": "herbitten",
    "herbittende": "herbittend",
    "herbittendem": "herbittend",
    "herbittenden": "herbittend",
    "herbittender": "herbittend",
    "herbittendes": "herbittend",
    "herbittest": "herbitten",
    "herbittet": "herbitten",
    "herbrachte": "herbringen",
    "herbrachten": "herbringen",
    "herbrachtest": "herbringen",
    "herbrachtet": "herbringen",
    "herbringe": "herbringen",
    "herbringend": "herbringen",
    "herbringende": "herbringend",
    "herbringendem": "herbringend",
    "herbringenden": "herbringend",
    "herbringender": "herbringend",
    "herbringendes": "herbringend",
    "herbringest": "herbringen",
    "herbringet": "herbringen",
    "herbringst": "herbringen",
    "herbringt": "herbringen",
    "herbrächte": "herbringen",
    "herbrächten": "herbringen",
    "herbrächtest": "herbringen",
    "herbrächtet": "herbringen",
    "herbste": "herb",
    "herbstem": "herb",
    "herbsten": "herb",
    "herbster": "herb",
    "herbstes": "herb",
    "herbstlichem": "herbstlich",
    "herbstlichen": "herbstlich",
    "herbstlicher": "herbstlich",
    "herbstlichere": "herbstlich",
    "herbstlicherem": "herbstlich",
    "herbstlicheren": "herbstlich",
    "herbstlicherer": "herbstlich",
    "herbstlicheres": "herbstlich",
    "herbstliches": "herbstlich",
    "herbstlichste": "herbstlich",
    "herbstlichstem": "herbstlich",
    "herbstlichsten": "herbstlich",
    "herbstlichster": "herbstlich",
    "herbstlichstes": "herbstlich",
    "herbäte": "herbitten",
    "herbäten": "herbitten",
    "herbätest": "herbitten",
    "herbätet": "herbitten",
    "herdachte": "herdenken",
    "herdachten": "herdenken",
    "herdachtest": "herdenken",
    "herdachtet": "herdenken",
    "herdenke": "herdenken",
    "herdenkend": "herdenken",
    "herdenkende": "herdenkend",
    "herdenkendem": "herdenkend",
    "herdenkenden": "herdenkend",
    "herdenkender": "herdenkend",
    "herdenkendes": "herdenkend",
    "herdenkest": "herdenken",
    "herdenket": "herdenken",
    "herdenkst": "herdenken",
    "herdenkt": "herdenken",
    "herdächte": "herdenken",
    "herdächten": "herdenken",
    "herdächtest": "herdenken",
    "herdächtet": "herdenken",
    "hereinfalle": "hereinfallen",
    "hereinfallend": "hereinfallen",
    "hereinfallende": "hereinfallend",
    "hereinfallendem": "hereinfallend",
    "hereinfallenden": "hereinfallend",
    "hereinfallender": "hereinfallend",
    "hereinfallendes": "hereinfallend",
    "hereinfallest": "hereinfallen",
    "hereinfallet": "hereinfallen",
    "hereinfallt": "hereinfallen",
    "hereinfiel": "hereinfallen",
    "hereinfiele": "hereinfallen",
    "hereinfielen": "hereinfallen",
    "hereinfielest": "hereinfallen",
    "hereinfielet": "hereinfallen",
    "hereinfielst": "hereinfallen",
    "hereinfielt": "hereinfallen",
    "hereinfällst": "hereinfallen",
    "hereinfällt": "hereinfallen",
    "hereingefallen": "hereinfallen",
    "hereingefallene": "hereingefallen",
    "hereingefallenem": "hereingefallen",
    "hereingefallenen": "hereingefallen",
    "hereingefallener": "hereingefallen",
    "hereingefallenere": "hereingefallen",
    "hereingefallenerem": "hereingefallen",
    "hereingefalleneren": "hereingefallen",
    "hereingefallenerer": "hereingefallen",
    "hereingefalleneres": "hereingefallen",
    "hereingefallenes": "hereingefallen",
    "hereingefallenste": "hereingefallen",
    "hereingefallenstem": "hereingefallen",
    "hereingefallensten": "hereingefallen",
    "hereingefallenster": "hereingefallen",
    "hereingefallenstes": "hereingefallen",
    "hereingereicht": "hereinreichen",
    "hereingereichte": "hereingereicht",
    "hereingereichtem": "hereingereicht",
    "hereingereichten": "hereingereicht",
    "hereingereichter": "hereingereicht",
    "hereingereichtes": "hereingereicht",
    "hereingerufen": "hereinrufen",
    "hereingerufene": "hereingerufen",
    "hereingerufenem": "hereingerufen",
    "hereingerufenen": "hereingerufen",
    "hereingerufener": "hereingerufen",
    "hereingerufenes": "hereingerufen",
    "hereinreiche": "hereinreichen",
    "hereinreichend": "hereinreichen",
    "hereinreichende": "hereinreichend",
    "hereinreichendem": "hereinreichend",
    "hereinreichenden": "hereinreichend",
    "hereinreichender": "hereinreichend",
    "hereinreichendes": "hereinreichend",
    "hereinreichest": "hereinreichen",
    "hereinreichet": "hereinreichen",
    "hereinreichst": "hereinreichen",
    "hereinreicht": "hereinreichen",
    "hereinreichte": "hereinreichen",
    "hereinreichten": "hereinreichen",
    "hereinreichtest": "hereinreichen",
    "hereinreichtet": "hereinreichen",
    "hereinrief": "hereinrufen",
    "hereinriefe": "hereinrufen",
    "hereinriefen": "hereinrufen",
    "hereinriefest": "hereinrufen",
    "hereinriefet": "hereinrufen",
    "hereinriefst": "hereinrufen",
    "hereinrieft": "hereinrufen",
    "hereinrufe": "hereinrufen",
    "hereinrufend": "hereinrufen",
    "hereinrufende": "hereinrufend",
    "hereinrufendem": "hereinrufend",
    "hereinrufenden": "hereinrufend",
    "hereinrufender": "hereinrufend",
    "hereinrufendes": "hereinrufend",
    "hereinrufest": "hereinrufen",
    "hereinrufet": "hereinrufen",
    "hereinrufst": "hereinrufen",
    "hereinruft": "hereinrufen",
    "hereinzufallen": "hereinfallen",
    "hereinzureichen": "hereinreichen",
    "hereinzurufen": "hereinrufen",
    "herfalle": "herfallen",
    "herfallend": "herfallen",
    "herfallende": "herfallend",
    "herfallendem": "herfallend",
    "herfallenden": "herfallend",
    "herfallender": "herfallend",
    "herfallendes": "herfallend",
    "herfallest": "herfallen",
    "herfallet": "herfallen",
    "herfallt": "herfallen",
    "herfand": "herfinden",
    "herfanden": "herfinden",
    "herfandest": "herfinden",
    "herfandet": "herfinden",
    "herfiel": "herfallen",
    "herfiele": "herfallen",
    "herfielen": "herfallen",
    "herfielest": "herfallen",
    "herfielet": "herfallen",
    "herfielst": "herfallen",
    "herfielt": "herfallen",
    "herfinde": "herfinden",
    "herfindend": "herfinden",
    "herfindende": "herfindend",
    "herfindendem": "herfindend",
    "herfindenden": "herfindend",
    "herfindender": "herfindend",
    "herfindendes": "herfindend",
    "herfindest": "herfinden",
    "herfindet": "herfinden",
    "herfliege": "herfliegen",
    "herfliegend": "herfliegen",
    "herfliegende": "herfliegend",
    "herfliegendem": "herfliegend",
    "herfliegenden": "herfliegend",
    "herfliegender": "herfliegend",
    "herfliegendes": "herfliegend",
    "herfliegest": "herfliegen",
    "herflieget": "herfliegen",
    "herfliegst": "herfliegen",
    "herfliegt": "herfliegen",
    "herflog": "herfliegen",
    "herflogen": "herfliegen",
    "herflogst": "herfliegen",
    "herflogt": "herfliegen",
    "herflöge": "herfliegen",
    "herflögen": "herfliegen",
    "herflögest": "herfliegen",
    "herflöget": "herfliegen",
    "herfällst": "herfallen",
    "herfällt": "herfallen",
    "herfände": "herfinden",
    "herfänden": "herfinden",
    "herfändest": "herfinden",
    "herfändet": "herfinden",
    "herführe": "herführen",
    "herführend": "herführen",
    "herführende": "herführend",
    "herführendem": "herführend",
    "herführenden": "herführend",
    "herführender": "herführend",
    "herführendes": "herführend",
    "herführest": "herführen",
    "herführet": "herführen",
    "herführst": "herführen",
    "herführt": "herführen",
    "herführte": "herführen",
    "herführten": "herführen",
    "herführtest": "herführen",
    "herführtet": "herführen",
    "hergab": "hergeben",
    "hergaben": "hergeben",
    "hergabst": "hergeben",
    "hergabt": "hergeben",
    "hergebe": "hergeben",
    "hergebend": "hergeben",
    "hergebende": "hergebend",
    "hergebendem": "hergebend",
    "hergebenden": "hergebend",
    "hergebender": "hergebend",
    "hergebendes": "hergebend",
    "hergebest": "hergeben",
    "hergebet": "hergeben",
    "hergebeten": "herbitten",
    "hergebetene": "hergebeten",
    "hergebetenem": "hergebeten",
    "hergebetenen": "hergebeten",
    "hergebetener": "hergebeten",
    "hergebetenes": "hergebeten",
    "hergebetet": "herbeten",
    "hergebetete": "hergebetet",
    "hergebetetem": "hergebetet",
    "hergebeteten": "hergebetet",
    "hergebeteter": "hergebetet",
    "hergebetetes": "hergebetet",
    "hergebracht": "herbringen",
    "hergebrachte": "hergebracht",
    "hergebrachtem": "hergebracht",
    "hergebrachten": "hergebracht",
    "hergebrachter": "hergebracht",
    "hergebrachtes": "hergebracht",
    "hergebt": "hergeben",
    "hergedacht": "herdenken",
    "hergedachte": "hergedacht",
    "hergedachtem": "hergedacht",
    "hergedachten": "hergedacht",
    "hergedachter": "hergedacht",
    "hergedachtes": "hergedacht",
    "hergefallen": "herfallen",
    "hergefallene": "hergefallen",
    "hergefallenem": "hergefallen",
    "hergefallenen": "hergefallen",
    "hergefallener": "hergefallen",
    "hergefallenes": "hergefallen",
    "hergeflogen": "herfliegen",
    "hergeflogene": "hergeflogen",
    "hergeflogenem": "hergeflogen",
    "hergeflogenen": "hergeflogen",
    "hergeflogener": "hergeflogen",
    "hergeflogenes": "hergeflogen",
    "hergefunden": "herfinden",
    "hergefundene": "hergefunden",
    "hergefundenem": "hergefunden",
    "hergefundenen": "hergefunden",
    "hergefundener": "hergefunden",
    "hergefundenes": "hergefunden",
    "hergeführt": "herführen",
    "hergeführte": "hergeführt",
    "hergeführtem": "hergeführt",
    "hergeführten": "hergeführt",
    "hergeführter": "hergeführt",
    "hergeführtes": "hergeführt",
    "hergegeben": "hergeben",
    "hergegebene": "hergegeben",
    "hergegebenem": "hergegeben",
    "hergegebenen": "hergegeben",
    "hergegebener": "hergegeben",
    "hergegebenes": "hergegeben",
    "hergehalten": "herhalten",
    "hergehaltene": "hergehalten",
    "hergehaltenem": "hergehalten",
    "hergehaltenen": "hergehalten",
    "hergehaltener": "hergehalten",
    "hergehaltenes": "hergehalten",
    "hergeholt": "herholen",
    "hergeholte": "hergeholt",
    "hergeholtem": "hergeholt",
    "hergeholten": "hergeholt",
    "hergeholter": "hergeholt",
    "hergeholtes": "hergeholt",
    "hergehört": "herhören",
    "hergehörte": "hergehört",
    "hergehörtem": "hergehört",
    "hergehörten": "hergehört",
    "hergehörter": "hergehört",
    "hergehörtes": "hergehört",
    "hergejagt": "herjagen",
    "hergejagte": "hergejagt",
    "hergejagtem": "hergejagt",
    "hergejagten": "hergejagt",
    "hergejagter": "hergejagt",
    "hergejagtes": "hergejagt",
    "hergekommen": "herkommen",
    "hergekommene": "hergekommen",
    "hergekommenem": "hergekommen",
    "hergekommenen": "hergekommen",
    "hergekommener": "hergekommen",
    "hergekommenes": "hergekommen",
    "hergekriegt": "herkriegen",
    "hergekriegte": "hergekriegt",
    "hergekriegtem": "hergekriegt",
    "hergekriegten": "hergekriegt",
    "hergekriegter": "hergekriegt",
    "hergekriegtes": "hergekriegt",
    "hergelangt": "herlangen",
    "hergelangte": "hergelangt",
    "hergelangtem": "hergelangt",
    "hergelangten": "hergelangt",
    "hergelangter": "hergelangt",
    "hergelangtes": "hergelangt",
    "hergelaufen": "herlaufen",
    "hergelaufene": "hergelaufen",
    "hergelaufenem": "hergelaufen",
    "hergelaufenen": "hergelaufen",
    "hergelaufener": "hergelaufen",
    "hergelaufenes": "hergelaufen",
    "hergelegt": "herlegen",
    "hergelegte": "hergelegt",
    "hergelegtem": "hergelegt",
    "hergelegten": "hergelegt",
    "hergelegter": "hergelegt",
    "hergelegtes": "hergelegt",
    "hergeleiert": "herleiern",
    "hergeleierte": "hergeleiert",
    "hergeleiertem": "hergeleiert",
    "hergeleierten": "hergeleiert",
    "hergeleierter": "hergeleiert",
    "hergeleiertes": "hergeleiert",
    "hergeleitet": "herleiten",
    "hergeleitete": "hergeleitet",
    "hergeleitetem": "hergeleitet",
    "hergeleiteten": "hergeleitet",
    "hergeleiteter": "hergeleitet",
    "hergeleitetes": "hergeleitet",
    "hergeliehen": "herleihen",
    "hergeliehene": "hergeliehen",
    "hergeliehenem": "hergeliehen",
    "hergeliehenen": "hergeliehen",
    "hergeliehener": "hergeliehen",
    "hergeliehenes": "hergeliehen",
    "hergemacht": "hermachen",
    "hergemachte": "hergemacht",
    "hergemachtem": "hergemacht",
    "hergemachten": "hergemacht",
    "hergemachter": "hergemacht",
    "hergemachtere": "hergemacht",
    "hergemachterem": "hergemacht",
    "hergemachteren": "hergemacht",
    "hergemachterer": "hergemacht",
    "hergemachteres": "hergemacht",
    "hergemachtes": "hergemacht",
    "hergemachteste": "hergemacht",
    "hergemachtestem": "hergemacht",
    "hergemachtesten": "hergemacht",
    "hergemachtester": "hergemacht",
    "hergemachtestes": "hergemacht",
    "hergenommen": "hernehmen",
    "hergenommene": "hergenommen",
    "hergenommenem": "hergenommen",
    "hergenommenen": "hergenommen",
    "hergenommener": "hergenommen",
    "hergenommenes": "hergenommen",
    "hergereicht": "herreichen",
    "hergereichte": "hergereicht",
    "hergereichtem": "hergereicht",
    "hergereichten": "hergereicht",
    "hergereichter": "hergereicht",
    "hergereichtes": "hergereicht",
    "hergerichtet": "herrichten",
    "hergerichtete": "hergerichtet",
    "hergerichtetem": "hergerichtet",
    "hergerichteten": "hergerichtet",
    "hergerichteter": "hergerichtet",
    "hergerichtetes": "hergerichtet",
    "hergerufen": "herrufen",
    "hergerufene": "hergerufen",
    "hergerufenem": "hergerufen",
    "hergerufenen": "hergerufen",
    "hergerufener": "hergerufen",
    "hergerufenes": "hergerufen",
    "hergerückt": "herrücken",
    "hergerückte": "hergerückt",
    "hergerücktem": "hergerückt",
    "hergerückten": "hergerückt",
    "hergerückter": "hergerückt",
    "hergerücktes": "hergerückt",
    "hergerührt": "herrühren",
    "hergerührte": "hergerührt",
    "hergerührtem": "hergerührt",
    "hergerührten": "hergerührt",
    "hergerührter": "hergerührt",
    "hergerührtes": "hergerührt",
    "hergesagt": "hersagen",
    "hergesagte": "hergesagt",
    "hergesagtem": "hergesagt",
    "hergesagten": "hergesagt",
    "hergesagter": "hergesagt",
    "hergesagtes": "hergesagt",
    "hergeschaffen": "herschaffen",
    "hergeschaffene": "hergeschaffen",
    "hergeschaffenem": "hergeschaffen",
    "hergeschaffenen": "hergeschaffen",
    "hergeschaffener": "hergeschaffen",
    "hergeschaffenes": "hergeschaffen",
    "hergeschafft": "herschaffen",
    "hergeschaffte": "hergeschafft",
    "hergeschafftem": "hergeschafft",
    "hergeschafften": "hergeschafft",
    "hergeschaffter": "hergeschafft",
    "hergeschafftes": "hergeschafft",
    "hergeschaut": "herschauen",
    "hergeschaute": "hergeschaut",
    "hergeschautem": "hergeschaut",
    "hergeschauten": "hergeschaut",
    "hergeschauter": "hergeschaut",
    "hergeschautes": "hergeschaut",
    "hergeschleppt": "herschleppen",
    "hergeschleppte": "hergeschleppt",
    "hergeschlepptem": "hergeschleppt",
    "hergeschleppten": "hergeschleppt",
    "hergeschleppter": "hergeschleppt",
    "hergeschlepptes": "hergeschleppt",
    "hergeschoben": "herschieben",
    "hergeschobene": "hergeschoben",
    "hergeschobenem": "hergeschoben",
    "hergeschobenen": "hergeschoben",
    "hergeschobener": "hergeschoben",
    "hergeschobenes": "hergeschoben",
    "hergesehen": "hersehen",
    "hergesehene": "hergesehen",
    "hergesehenem": "hergesehen",
    "hergesehenen": "hergesehen",
    "hergesehener": "hergesehen",
    "hergesehenes": "hergesehen",
    "hergesehnt": "hersehnen",
    "hergesehnte": "hergesehnt",
    "hergesehntem": "hergesehnt",
    "hergesehnten": "hergesehnt",
    "hergesehnter": "hergesehnt",
    "hergesehntere": "hergesehnt",
    "hergesehnterem": "hergesehnt",
    "hergesehnteren": "hergesehnt",
    "hergesehnterer": "hergesehnt",
    "hergesehnteres": "hergesehnt",
    "hergesehntes": "hergesehnt",
    "hergesehnteste": "hergesehnt",
    "hergesehntestem": "hergesehnt",
    "hergesehntesten": "hergesehnt",
    "hergesehntester": "hergesehnt",
    "hergesehntestes": "hergesehnt",
    "hergesetzt": "hersetzen",
    "hergesetzte": "hergesetzt",
    "hergesetztem": "hergesetzt",
    "hergesetzten": "hergesetzt",
    "hergesetzter": "hergesetzt",
    "hergesetztes": "hergesetzt",
    "hergesprungen": "herspringen",
    "hergesprungene": "hergesprungen",
    "hergesprungenem": "hergesprungen",
    "hergesprungenen": "hergesprungen",
    "hergesprungener": "hergesprungen",
    "hergesprungenes": "hergesprungen",
    "hergestammt": "herstammen",
    "hergestammte": "hergestammt",
    "hergestammtem": "hergestammt",
    "hergestammten": "hergestammt",
    "hergestammter": "hergestammt",
    "hergestammtes": "hergestammt",
    "hergestellt": "herstellen",
    "hergestellte": "hergestellt",
    "hergestelltem": "hergestellt",
    "hergestellten": "hergestellt",
    "hergestellter": "hergestellt",
    "hergestelltes": "hergestellt",
    "hergetragen": "hertragen",
    "hergetragene": "hergetragen",
    "hergetragenem": "hergetragen",
    "hergetragenen": "hergetragen",
    "hergetragener": "hergetragen",
    "hergetragenes": "hergetragen",
    "hergetrieben": "hertreiben",
    "hergetriebene": "hergetrieben",
    "hergetriebenem": "hergetrieben",
    "hergetriebenen": "hergetrieben",
    "hergetriebener": "hergetrieben",
    "hergetriebenes": "hergetrieben",
    "hergewinkt": "herwinken",
    "hergewinkte": "hergewinkt",
    "hergewinktem": "hergewinkt",
    "hergewinkten": "hergewinkt",
    "hergewinkter": "hergewinkt",
    "hergewinktes": "hergewinkt",
    "hergeworfen": "herwerfen",
    "hergeworfene": "hergeworfen",
    "hergeworfenem": "hergeworfen",
    "hergeworfenen": "hergeworfen",
    "hergeworfener": "hergeworfen",
    "hergeworfenes": "hergeworfen",
    "hergezaubert": "herzaubern",
    "hergezauberte": "hergezaubert",
    "hergezaubertem": "hergezaubert",
    "hergezauberten": "hergezaubert",
    "hergezauberter": "hergezaubert",
    "hergezaubertes": "hergezaubert",
    "hergezeigt": "herzeigen",
    "hergezeigte": "hergezeigt",
    "hergezeigtem": "hergezeigt",
    "hergezeigten": "hergezeigt",
    "hergezeigter": "hergezeigt",
    "hergezeigtes": "hergezeigt",
    "hergezogen": "herziehen",
    "hergezogene": "hergezogen",
    "hergezogenem": "hergezogen",
    "hergezogenen": "hergezogen",
    "hergezogener": "hergezogen",
    "hergezogenes": "hergezogen",
    "hergezählt": "herzählen",
    "hergezählte": "hergezählt",
    "hergezähltem": "hergezählt",
    "hergezählten": "hergezählt",
    "hergezählter": "hergezählt",
    "hergezähltes": "hergezählt",
    "hergibst": "hergeben",
    "hergibt": "hergeben",
    "hergäbe": "hergeben",
    "hergäben": "hergeben",
    "hergäbest": "hergeben",
    "hergäbet": "hergeben",
    "herhalte": "herhalten",
    "herhaltend": "herhalten",
    "herhaltende": "herhaltend",
    "herhaltendem": "herhaltend",
    "herhaltenden": "herhaltend",
    "herhaltender": "herhaltend",
    "herhaltendes": "herhaltend",
    "herhaltest": "herhalten",
    "herhaltet": "herhalten",
    "herhielt": "herhalten",
    "herhielte": "herhalten",
    "herhielten": "herhalten",
    "herhieltest": "herhalten",
    "herhieltet": "herhalten",
    "herhole": "herholen",
    "herholend": "herholen",
    "herholende": "herholend",
    "herholendem": "herholend",
    "herholenden": "herholend",
    "herholender": "herholend",
    "herholendes": "herholend",
    "herholest": "herholen",
    "herholet": "herholen",
    "herholst": "herholen",
    "herholt": "herholen",
    "herholte": "herholen",
    "herholten": "herholen",
    "herholtest": "herholen",
    "herholtet": "herholen",
    "herhält": "herhalten",
    "herhältst": "herhalten",
    "herhöre": "herhören",
    "herhörend": "herhören",
    "herhörende": "herhörend",
    "herhörendem": "herhörend",
    "herhörenden": "herhörend",
    "herhörender": "herhörend",
    "herhörendere": "herhörend",
    "herhörenderem": "herhörend",
    "herhörenderen": "herhörend",
    "herhörenderer": "herhörend",
    "herhörenderes": "herhörend",
    "herhörendes": "herhörend",
    "herhörendste": "herhörend",
    "herhörendstem": "herhörend",
    "herhörendsten": "herhörend",
    "herhörendster": "herhörend",
    "herhörendstes": "herhörend",
    "herhörest": "herhören",
    "herhöret": "herhören",
    "herhörst": "herhören",
    "herhört": "herhören",
    "herhörte": "herhören",
    "herhörten": "herhören",
    "herhörtest": "herhören",
    "herhörtet": "herhören",
    "herjage": "herjagen",
    "herjagend": "herjagen",
    "herjagende": "herjagend",
    "herjagendem": "herjagend",
    "herjagenden": "herjagend",
    "herjagender": "herjagend",
    "herjagendes": "herjagend",
    "herjagest": "herjagen",
    "herjaget": "herjagen",
    "herjagst": "herjagen",
    "herjagt": "herjagen",
    "herjagte": "herjagen",
    "herjagten": "herjagen",
    "herjagtest": "herjagen",
    "herjagtet": "herjagen",
    "herkam": "herkommen",
    "herkamen": "herkommen",
    "herkamst": "herkommen",
    "herkamt": "herkommen",
    "herkomme": "herkommen",
    "herkommend": "herkommen",
    "herkommende": "herkommend",
    "herkommendem": "herkommend",
    "herkommenden": "herkommend",
    "herkommender": "herkommend",
    "herkommendes": "herkommend",
    "herkommest": "herkommen",
    "herkommet": "herkommen",
    "herkommst": "herkommen",
    "herkommt": "herkommen",
    "herkriege": "herkriegen",
    "herkriegend": "herkriegen",
    "herkriegende": "herkriegend",
    "herkriegendem": "herkriegend",
    "herkriegenden": "herkriegend",
    "herkriegender": "herkriegend",
    "herkriegendes": "herkriegend",
    "herkriegest": "herkriegen",
    "herkrieget": "herkriegen",
    "herkriegst": "herkriegen",
    "herkriegt": "herkriegen",
    "herkriegte": "herkriegen",
    "herkriegten": "herkriegen",
    "herkriegtest": "herkriegen",
    "herkriegtet": "herkriegen",
    "herkäme": "herkommen",
    "herkämen": "herkommen",
    "herkämest": "herkommen",
    "herkämet": "herkommen",
    "herkömmliche": "herkömmlich",
    "herkömmlichem": "herkömmlich",
    "herkömmlichen": "herkömmlich",
    "herkömmlicher": "herkömmlich",
    "herkömmlichere": "herkömmlich",
    "herkömmlicherem": "herkömmlich",
    "herkömmlicheren": "herkömmlich",
    "herkömmlicherer": "herkömmlich",
    "herkömmlicheres": "herkömmlich",
    "herkömmliches": "herkömmlich",
    "herkömmlichste": "herkömmlich",
    "herkömmlichstem": "herkömmlich",
    "herkömmlichsten": "herkömmlich",
    "herkömmlichster": "herkömmlich",
    "herkömmlichstes": "herkömmlich",
    "herlange": "herlangen",
    "herlangend": "herlangen",
    "herlangende": "herlangend",
    "herlangendem": "herlangend",
    "herlangenden": "herlangend",
    "herlangender": "herlangend",
    "herlangendes": "herlangend",
    "herlangest": "herlangen",
    "herlanget": "herlangen",
    "herlangst": "herlangen",
    "herlangt": "herlangen",
    "herlangte": "herlangen",
    "herlangten": "herlangen",
    "herlangtest": "herlangen",
    "herlangtet": "herlangen",
    "herlaufe": "herlaufen",
    "herlaufend": "herlaufen",
    "herlaufende": "herlaufend",
    "herlaufendem": "herlaufend",
    "herlaufenden": "herlaufend",
    "herlaufender": "herlaufend",
    "herlaufendes": "herlaufend",
    "herlaufest": "herlaufen",
    "herlaufet": "herlaufen",
    "herlauft": "herlaufen",
    "herlege": "herlegen",
    "herlegend": "herlegen",
    "herlegende": "herlegend",
    "herlegendem": "herlegend",
    "herlegenden": "herlegend",
    "herlegender": "herlegend",
    "herlegendes": "herlegend",
    "herlegest": "herlegen",
    "herleget": "herlegen",
    "herlegst": "herlegen",
    "herlegt": "herlegen",
    "herlegte": "herlegen",
    "herlegten": "herlegen",
    "herlegtest": "herlegen",
    "herlegtet": "herlegen",
    "herleiere": "herleiern",
    "herleiernd": "herleiern",
    "herleiernde": "herleiernd",
    "herleierndem": "herleiernd",
    "herleiernden": "herleiernd",
    "herleiernder": "herleiernd",
    "herleierndes": "herleiernd",
    "herleierst": "herleiern",
    "herleiert": "herleiern",
    "herleierte": "herleiern",
    "herleierten": "herleiern",
    "herleiertest": "herleiern",
    "herleiertet": "herleiern",
    "herleihe": "herleihen",
    "herleihend": "herleihen",
    "herleihende": "herleihend",
    "herleihendem": "herleihend",
    "herleihenden": "herleihend",
    "herleihender": "herleihend",
    "herleihendes": "herleihend",
    "herleihest": "herleihen",
    "herleihet": "herleihen",
    "herleihst": "herleihen",
    "herleiht": "herleihen",
    "herleite": "herleiten",
    "herleitend": "herleiten",
    "herleitende": "herleitend",
    "herleitendem": "herleitend",
    "herleitenden": "herleitend",
    "herleitender": "herleitend",
    "herleitendes": "herleitend",
    "herleitest": "herleiten",
    "herleitet": "herleiten",
    "herleitete": "herleiten",
    "herleiteten": "herleiten",
    "herleitetest": "herleiten",
    "herleitetet": "herleiten",
    "herlief": "herlaufen",
    "herliefe": "herlaufen",
    "herliefen": "herlaufen",
    "herliefest": "herlaufen",
    "herliefet": "herlaufen",
    "herliefst": "herlaufen",
    "herlieft": "herlaufen",
    "herlieh": "herleihen",
    "herliehe": "herleihen",
    "herliehen": "herleihen",
    "herliehest": "herleihen",
    "herliehet": "herleihen",
    "herliehst": "herleihen",
    "herlieht": "herleihen",
    "herläufst": "herlaufen",
    "herläuft": "herlaufen",
    "hermache": "hermachen",
    "hermachend": "hermachen",
    "hermachende": "hermachend",
    "hermachendem": "hermachend",
    "hermachenden": "hermachend",
    "hermachender": "hermachend",
    "hermachendes": "hermachend",
    "hermachest": "hermachen",
    "hermachet": "hermachen",
    "hermachst": "hermachen",
    "hermacht": "hermachen",
    "hermachte": "hermachen",
    "hermachten": "hermachen",
    "hermachtest": "hermachen",
    "hermachtet": "hermachen",
    "hermeneutischem": "hermeneutisch",
    "hermeneutischen": "hermeneutisch",
    "hermeneutischer": "hermeneutisch",
    "hermeneutisches": "hermeneutisch",
    "hermetische": "hermetisch",
    "hermetischem": "hermetisch",
    "hermetischen": "hermetisch",
    "hermetischer": "hermetisch",
    "hermetisches": "hermetisch",
    "hernahm": "hernehmen",
    "hernahmen": "hernehmen",
    "hernahmst": "hernehmen",
    "hernahmt": "hernehmen",
    "hernehme": "hernehmen",
    "hernehmend": "hernehmen",
    "hernehmende": "hernehmend",
    "hernehmendem": "hernehmend",
    "hernehmenden": "hernehmend",
    "hernehmender": "hernehmend",
    "hernehmendes": "hernehmend",
    "hernehmest": "hernehmen",
    "hernehmet": "hernehmen",
    "hernehmt": "hernehmen",
    "hernimmst": "hernehmen",
    "hernimmt": "hernehmen",
    "hernähme": "hernehmen",
    "hernähmen": "hernehmen",
    "hernähmest": "hernehmen",
    "hernähmet": "hernehmen",
    "heroischem": "heroisch",
    "heroischen": "heroisch",
    "heroischer": "heroisch",
    "heroischere": "heroisch",
    "heroischerem": "heroisch",
    "heroischeren": "heroisch",
    "heroischerer": "heroisch",
    "heroischeres": "heroisch",
    "heroisches": "heroisch",
    "heroischste": "heroisch",
    "heroischstem": "heroisch",
    "heroischsten": "heroisch",
    "heroischster": "heroisch",
    "heroischstes": "heroisch",
    "heroisiere": "heroisieren",
    "heroisierend": "heroisieren",
    "heroisierende": "heroisierend",
    "heroisierendem": "heroisierend",
    "heroisierenden": "heroisierend",
    "heroisierender": "heroisierend",
    "heroisierendere": "heroisierend",
    "heroisierenderem": "heroisierend",
    "heroisierenderen": "heroisierend",
    "heroisierenderer": "heroisierend",
    "heroisierenderes": "heroisierend",
    "heroisierendes": "heroisierend",
    "heroisierendste": "heroisierend",
    "heroisierendstem": "heroisierend",
    "heroisierendsten": "heroisierend",
    "heroisierendster": "heroisierend",
    "heroisierendstes": "heroisierend",
    "heroisierest": "heroisieren",
    "heroisieret": "heroisieren",
    "heroisierst": "heroisieren",
    "heroisiert": "heroisieren",
    "heroisierte": "heroisieren",
    "heroisiertem": "heroisiert",
    "heroisierten": "heroisieren",
    "heroisierter": "heroisiert",
    "heroisiertere": "heroisiert",
    "heroisierterem": "heroisiert",
    "heroisierteren": "heroisiert",
    "heroisierterer": "heroisiert",
    "heroisierteres": "heroisiert",
    "heroisiertes": "heroisiert",
    "heroisiertest": "heroisieren",
    "heroisierteste": "heroisiert",
    "heroisiertestem": "heroisiert",
    "heroisiertesten": "heroisiert",
    "heroisiertester": "heroisiert",
    "heroisiertestes": "heroisiert",
    "heroisiertet": "heroisieren",
    "herreiche": "herreichen",
    "herreichend": "herreichen",
    "herreichende": "herreichend",
    "herreichendem": "herreichend",
    "herreichenden": "herreichend",
    "herreichender": "herreichend",
    "herreichendes": "herreichend",
    "herreichest": "herreichen",
    "herreichet": "herreichen",
    "herreichst": "herreichen",
    "herreicht": "herreichen",
    "herreichte": "herreichen",
    "herreichten": "herreichen",
    "herreichtest": "herreichen",
    "herreichtet": "herreichen",
    "herrenlosem": "herrenlos",
    "herrenlosen": "herrenlos",
    "herrenloser": "herrenlos",
    "herrenloses": "herrenlos",
    "herrichte": "herrichten",
    "herrichtend": "herrichten",
    "herrichtende": "herrichtend",
    "herrichtendem": "herrichtend",
    "herrichtenden": "herrichtend",
    "herrichtender": "herrichtend",
    "herrichtendes": "herrichtend",
    "herrichtest": "herrichten",
    "herrichtet": "herrichten",
    "herrichtete": "herrichten",
    "herrichteten": "herrichten",
    "herrichtetest": "herrichten",
    "herrichtetet": "herrichten",
    "herrief": "herrufen",
    "herriefe": "herrufen",
    "herriefen": "herrufen",
    "herriefest": "herrufen",
    "herriefet": "herrufen",
    "herriefst": "herrufen",
    "herrieft": "herrufen",
    "herrische": "herrisch",
    "herrischem": "herrisch",
    "herrischen": "herrisch",
    "herrischer": "herrisch",
    "herrisches": "herrisch",
    "herrliche": "herrlich",
    "herrlichem": "herrlich",
    "herrlichen": "herrlich",
    "herrlicher": "herrlich",
    "herrlichere": "herrlich",
    "herrlicherem": "herrlich",
    "herrlicheren": "herrlich",
    "herrlicherer": "herrlich",
    "herrlicheres": "herrlich",
    "herrliches": "herrlich",
    "herrlichstem": "herrlich",
    "herrlichsten": "herrlich",
    "herrlichster": "herrlich",
    "herrlichstes": "herrlich",
    "herrschaftlichem": "herrschaftlich",
    "herrschaftlichen": "herrschaftlich",
    "herrschaftlicher": "herrschaftlich",
    "herrschaftliches": "herrschaftlich",
    "herrsche": "herrschen",
    "herrschend": "herrschen",
    "herrschende": "herrschend",
    "herrschendem": "herrschend",
    "herrschenden": "herrschend",
    "herrschender": "herrschend",
    "herrschendere": "herrschend",
    "herrschenderem": "herrschend",
    "herrschenderen": "herrschend",
    "herrschenderer": "herrschend",
    "herrschenderes": "herrschend",
    "herrschendes": "herrschend",
    "herrschendste": "herrschend",
    "herrschendstem": "herrschend",
    "herrschendsten": "herrschend",
    "herrschendster": "herrschend",
    "herrschendstes": "herrschend",
    "herrschest": "herrschen",
    "herrschet": "herrschen",
    "herrschst": "herrschen",
    "herrschsüchtige": "herrschsüchtig",
    "herrschsüchtigem": "herrschsüchtig",
    "herrschsüchtigen": "herrschsüchtig",
    "herrschsüchtiger": "herrschsüchtig",
    "herrschsüchtigere": "herrschsüchtig",
    "herrschsüchtigerem": "herrschsüchtig",
    "herrschsüchtigeren": "herrschsüchtig",
    "herrschsüchtigerer": "herrschsüchtig",
    "herrschsüchtigeres": "herrschsüchtig",
    "herrschsüchtiges": "herrschsüchtig",
    "herrschsüchtigste": "herrschsüchtig",
    "herrschsüchtigstem": "herrschsüchtig",
    "herrschsüchtigsten": "herrschsüchtig",
    "herrschsüchtigster": "herrschsüchtig",
    "herrschsüchtigstes": "herrschsüchtig",
    "herrscht": "herrschen",
    "herrschte": "herrschen",
    "herrschten": "herrschen",
    "herrschtest": "herrschen",
    "herrschtet": "herrschen",
    "herrufe": "herrufen",
    "herrufend": "herrufen",
    "herrufende": "herrufend",
    "herrufendem": "herrufend",
    "herrufenden": "herrufend",
    "herrufender": "herrufend",
    "herrufendes": "herrufend",
    "herrufest": "herrufen",
    "herrufet": "herrufen",
    "herrufst": "herrufen",
    "herruft": "herrufen",
    "herrücke": "herrücken",
    "herrückend": "herrücken",
    "herrückende": "herrückend",
    "herrückendem": "herrückend",
    "herrückenden": "herrückend",
    "herrückender": "herrückend",
    "herrückendes": "herrückend",
    "herrückest": "herrücken",
    "herrücket": "herrücken",
    "herrückst": "herrücken",
    "herrückt": "herrücken",
    "herrückte": "herrücken",
    "herrückten": "herrücken",
    "herrücktest": "herrücken",
    "herrücktet": "herrücken",
    "herrühre": "herrühren",
    "herrührend": "herrühren",
    "herrührende": "herrührend",
    "herrührendem": "herrührend",
    "herrührenden": "herrührend",
    "herrührender": "herrührend",
    "herrührendes": "herrührend",
    "herrührest": "herrühren",
    "herrühret": "herrühren",
    "herrührst": "herrühren",
    "herrührt": "herrühren",
    "herrührte": "herrühren",
    "herrührten": "herrühren",
    "herrührtest": "herrühren",
    "herrührtet": "herrühren",
    "hersage": "hersagen",
    "hersagend": "hersagen",
    "hersagende": "hersagend",
    "hersagendem": "hersagend",
    "hersagenden": "hersagend",
    "hersagender": "hersagend",
    "hersagendes": "hersagend",
    "hersagest": "hersagen",
    "hersaget": "hersagen",
    "hersagst": "hersagen",
    "hersagt": "hersagen",
    "hersagte": "hersagen",
    "hersagten": "hersagen",
    "hersagtest": "hersagen",
    "hersagtet": "hersagen",
    "hersah": "hersehen",
    "hersahen": "hersehen",
    "hersahst": "hersehen",
    "hersaht": "hersehen",
    "herschaffe": "herschaffen",
    "herschaffend": "herschaffen",
    "herschaffende": "herschaffend",
    "herschaffendem": "herschaffend",
    "herschaffenden": "herschaffend",
    "herschaffender": "herschaffend",
    "herschaffendes": "herschaffend",
    "herschaffest": "herschaffen",
    "herschaffet": "herschaffen",
    "herschaffst": "herschaffen",
    "herschafft": "herschaffen",
    "herschaffte": "herschaffen",
    "herschafften": "herschaffen",
    "herschafftest": "herschaffen",
    "herschafftet": "herschaffen",
    "herschaue": "herschauen",
    "herschauend": "herschauen",
    "herschauende": "herschauend",
    "herschauendem": "herschauend",
    "herschauenden": "herschauend",
    "herschauender": "herschauend",
    "herschauendes": "herschauend",
    "herschauest": "herschauen",
    "herschauet": "herschauen",
    "herschaust": "herschauen",
    "herschaut": "herschauen",
    "herschaute": "herschauen",
    "herschauten": "herschauen",
    "herschautest": "herschauen",
    "herschautet": "herschauen",
    "herschiebe": "herschieben",
    "herschiebend": "herschieben",
    "herschiebende": "herschiebend",
    "herschiebendem": "herschiebend",
    "herschiebenden": "herschiebend",
    "herschiebender": "herschiebend",
    "herschiebendes": "herschiebend",
    "herschiebest": "herschieben",
    "herschiebet": "herschieben",
    "herschiebst": "herschieben",
    "herschiebt": "herschieben",
    "herschleppe": "herschleppen",
    "herschleppend": "herschleppen",
    "herschleppende": "herschleppend",
    "herschleppendem": "herschleppend",
    "herschleppenden": "herschleppend",
    "herschleppender": "herschleppend",
    "herschleppendes": "herschleppend",
    "herschleppest": "herschleppen",
    "herschleppet": "herschleppen",
    "herschleppst": "herschleppen",
    "herschleppt": "herschleppen",
    "herschleppte": "herschleppen",
    "herschleppten": "herschleppen",
    "herschlepptest": "herschleppen",
    "herschlepptet": "herschleppen",
    "herschob": "herschieben",
    "herschoben": "herschieben",
    "herschobst": "herschieben",
    "herschobt": "herschieben",
    "herschuf": "herschaffen",
    "herschufen": "herschaffen",
    "herschufst": "herschaffen",
    "herschuft": "herschaffen",
    "herschöbe": "herschieben",
    "herschöben": "herschieben",
    "herschöbest": "herschieben",
    "herschöbet": "herschieben",
    "herschüfe": "herschaffen",
    "herschüfen": "herschaffen",
    "herschüfest": "herschaffen",
    "herschüfet": "herschaffen",
    "hersehe": "hersehen",
    "hersehend": "hersehen",
    "hersehende": "hersehend",
    "hersehendem": "hersehend",
    "hersehenden": "hersehend",
    "hersehender": "hersehend",
    "hersehendes": "hersehend",
    "hersehest": "hersehen",
    "hersehet": "hersehen",
    "hersehne": "hersehnen",
    "hersehnend": "hersehnen",
    "hersehnende": "hersehnend",
    "hersehnendem": "hersehnend",
    "hersehnenden": "hersehnend",
    "hersehnender": "hersehnend",
    "hersehnendere": "hersehnend",
    "hersehnenderem": "hersehnend",
    "hersehnenderen": "hersehnend",
    "hersehnenderer": "hersehnend",
    "hersehnenderes": "hersehnend",
    "hersehnendes": "hersehnend",
    "hersehnendste": "hersehnend",
    "hersehnendstem": "hersehnend",
    "hersehnendsten": "hersehnend",
    "hersehnendster": "hersehnend",
    "hersehnendstes": "hersehnend",
    "hersehnest": "hersehnen",
    "hersehnet": "hersehnen",
    "hersehnst": "hersehnen",
    "hersehnt": "hersehnen",
    "hersehnte": "hersehnen",
    "hersehnten": "hersehnen",
    "hersehntest": "hersehnen",
    "hersehntet": "hersehnen",
    "herseht": "hersehen",
    "hersetze": "hersetzen",
    "hersetzend": "hersetzen",
    "hersetzende": "hersetzend",
    "hersetzendem": "hersetzend",
    "hersetzenden": "hersetzend",
    "hersetzender": "hersetzend",
    "hersetzendes": "hersetzend",
    "hersetzest": "hersetzen",
    "hersetzet": "hersetzen",
    "hersetzt": "hersetzen",
    "hersetzte": "hersetzen",
    "hersetzten": "hersetzen",
    "hersetztest": "hersetzen",
    "hersetztet": "hersetzen",
    "hersiehst": "hersehen",
    "hersieht": "hersehen",
    "hersprang": "herspringen",
    "hersprangen": "herspringen",
    "hersprangst": "herspringen",
    "hersprangt": "herspringen",
    "herspringe": "herspringen",
    "herspringend": "herspringen",
    "herspringende": "herspringend",
    "herspringendem": "herspringend",
    "herspringenden": "herspringend",
    "herspringender": "herspringend",
    "herspringendes": "herspringend",
    "herspringest": "herspringen",
    "herspringet": "herspringen",
    "herspringst": "herspringen",
    "herspringt": "herspringen",
    "herspränge": "herspringen",
    "hersprängen": "herspringen",
    "hersprängest": "herspringen",
    "herspränget": "herspringen",
    "herstamme": "herstammen",
    "herstammend": "herstammen",
    "herstammende": "herstammend",
    "herstammendem": "herstammend",
    "herstammenden": "herstammend",
    "herstammender": "herstammend",
    "herstammendes": "herstammend",
    "herstammest": "herstammen",
    "herstammet": "herstammen",
    "herstammst": "herstammen",
    "herstammt": "herstammen",
    "herstammte": "herstammen",
    "herstammten": "herstammen",
    "herstammtest": "herstammen",
    "herstammtet": "herstammen",
    "herstelle": "herstellen",
    "herstellend": "herstellen",
    "herstellende": "herstellend",
    "herstellendem": "herstellend",
    "herstellenden": "herstellend",
    "herstellender": "herstellend",
    "herstellendes": "herstellend",
    "herstellest": "herstellen",
    "herstellet": "herstellen",
    "herstellst": "herstellen",
    "herstellt": "herstellen",
    "herstellte": "herstellen",
    "herstellten": "herstellen",
    "herstelltest": "herstellen",
    "herstelltet": "herstellen",
    "hersähe": "hersehen",
    "hersähen": "hersehen",
    "hersähest": "hersehen",
    "hersähet": "hersehen",
    "hertrage": "hertragen",
    "hertragend": "hertragen",
    "hertragende": "hertragend",
    "hertragendem": "hertragend",
    "hertragenden": "hertragend",
    "hertragender": "hertragend",
    "hertragendes": "hertragend",
    "hertragest": "hertragen",
    "hertraget": "hertragen",
    "hertragt": "hertragen",
    "hertreibe": "hertreiben",
    "hertreibend": "hertreiben",
    "hertreibende": "hertreibend",
    "hertreibendem": "hertreibend",
    "hertreibenden": "hertreibend",
    "hertreibender": "hertreibend",
    "hertreibendes": "hertreibend",
    "hertreibest": "hertreiben",
    "hertreibet": "hertreiben",
    "hertreibst": "hertreiben",
    "hertreibt": "hertreiben",
    "hertrieb": "hertreiben",
    "hertriebe": "hertreiben",
    "hertrieben": "hertreiben",
    "hertriebest": "hertreiben",
    "hertriebet": "hertreiben",
    "hertriebst": "hertreiben",
    "hertriebt": "hertreiben",
    "hertrug": "hertragen",
    "hertrugen": "hertragen",
    "hertrugst": "hertragen",
    "hertrugt": "hertragen",
    "herträgst": "hertragen",
    "herträgt": "hertragen",
    "hertrüge": "hertragen",
    "hertrügen": "hertragen",
    "hertrügest": "hertragen",
    "hertrüget": "hertragen",
    "herumfahre": "herumfahren",
    "herumfahrend": "herumfahren",
    "herumfahrende": "herumfahrend",
    "herumfahrendem": "herumfahrend",
    "herumfahrenden": "herumfahrend",
    "herumfahrender": "herumfahrend",
    "herumfahrendes": "herumfahrend",
    "herumfahrest": "herumfahren",
    "herumfahret": "herumfahren",
    "herumfahrt": "herumfahren",
    "herumfliege": "herumfliegen",
    "herumfliegend": "herumfliegen",
    "herumfliegende": "herumfliegend",
    "herumfliegendem": "herumfliegend",
    "herumfliegenden": "herumfliegend",
    "herumfliegender": "herumfliegend",
    "herumfliegendere": "herumfliegend",
    "herumfliegenderem": "herumfliegend",
    "herumfliegenderen": "herumfliegend",
    "herumfliegenderer": "herumfliegend",
    "herumfliegenderes": "herumfliegend",
    "herumfliegendes": "herumfliegend",
    "herumfliegendste": "herumfliegend",
    "herumfliegendstem": "herumfliegend",
    "herumfliegendsten": "herumfliegend",
    "herumfliegendster": "herumfliegend",
    "herumfliegendstes": "herumfliegend",
    "herumfliegest": "herumfliegen",
    "herumflieget": "herumfliegen",
    "herumfliegst": "herumfliegen",
    "herumfliegt": "herumfliegen",
    "herumflog": "herumfliegen",
    "herumflogen": "herumfliegen",
    "herumflogst": "herumfliegen",
    "herumflogt": "herumfliegen",
    "herumflöge": "herumfliegen",
    "herumflögen": "herumfliegen",
    "herumflögest": "herumfliegen",
    "herumflöget": "herumfliegen",
    "herumfuhr": "herumfahren",
    "herumfuhren": "herumfahren",
    "herumfuhrst": "herumfahren",
    "herumfuhrt": "herumfahren",
    "herumfährst": "herumfahren",
    "herumfährt": "herumfahren",
    "herumführe": "herumführen",
    "herumführen": "herumfahren",
    "herumführend": "herumführen",
    "herumführende": "herumführend",
    "herumführendem": "herumführend",
    "herumführenden": "herumführend",
    "herumführender": "herumführend",
    "herumführendes": "herumführend",
    "herumführest": "herumführen",
    "herumführet": "herumführen",
    "herumführst": "herumführen",
    "herumführt": "herumführen",
    "herumführte": "herumführen",
    "herumführten": "herumführen",
    "herumführtest": "herumführen",
    "herumführtet": "herumführen",
    "herumgefahren": "herumfahren",
    "herumgefahrene": "herumgefahren",
    "herumgefahrenem": "herumgefahren",
    "herumgefahrenen": "herumgefahren",
    "herumgefahrener": "herumgefahren",
    "herumgefahrenes": "herumgefahren",
    "herumgeflogen": "herumfliegen",
    "herumgeflogene": "herumgeflogen",
    "herumgeflogenem": "herumgeflogen",
    "herumgeflogenen": "herumgeflogen",
    "herumgeflogener": "herumgeflogen",
    "herumgeflogenere": "herumgeflogen",
    "herumgeflogenerem": "herumgeflogen",
    "herumgeflogeneren": "herumgeflogen",
    "herumgeflogenerer": "herumgeflogen",
    "herumgeflogeneres": "herumgeflogen",
    "herumgeflogenes": "herumgeflogen",
    "herumgeflogenste": "herumgeflogen",
    "herumgeflogenstem": "herumgeflogen",
    "herumgeflogensten": "herumgeflogen",
    "herumgeflogenster": "herumgeflogen",
    "herumgeflogenstes": "herumgeflogen",
    "herumgeführt": "herumführen",
    "herumgeführte": "herumgeführt",
    "herumgeführtem": "herumgeführt",
    "herumgeführten": "herumgeführt",
    "herumgeführter": "herumgeführt",
    "herumgeführtes": "herumgeführt",
    "herumgehangen": "herumhängen",
    "herumgehangene": "herumgehangen",
    "herumgehangenem": "herumgehangen",
    "herumgehangenen": "herumgehangen",
    "herumgehangener": "herumgehangen",
    "herumgehangenes": "herumgehangen",
    "herumgehängt": "herumhängen",
    "herumgehängte": "herumgehängt",
    "herumgehängtem": "herumgehängt",
    "herumgehängten": "herumgehängt",
    "herumgehängter": "herumgehängt",
    "herumgehängtes": "herumgehängt",
    "herumgelegen": "herumliegen",
    "herumgelegene": "herumgelegen",
    "herumgelegenem": "herumgelegen",
    "herumgelegenen": "herumgelegen",
    "herumgelegener": "herumgelegen",
    "herumgelegenes": "herumgelegen",
    "herumgelungert": "herumlungern",
    "herumgelungerte": "herumgelungert",
    "herumgelungertem": "herumgelungert",
    "herumgelungerten": "herumgelungert",
    "herumgelungerter": "herumgelungert",
    "herumgelungertes": "herumgelungert",
    "herumgereicht": "herumreichen",
    "herumgereichte": "herumgereicht",
    "herumgereichtem": "herumgereicht",
    "herumgereichten": "herumgereicht",
    "herumgereichter": "herumgereicht",
    "herumgereichtes": "herumgereicht",
    "herumgeschlagen": "herumschlagen",
    "herumgeschlagene": "herumgeschlagen",
    "herumgeschlagenem": "herumgeschlagen",
    "herumgeschlagenen": "herumgeschlagen",
    "herumgeschlagener": "herumgeschlagen",
    "herumgeschlagenes": "herumgeschlagen",
    "herumgespritzt": "herumspritzen",
    "herumgespritzte": "herumgespritzt",
    "herumgespritztem": "herumgespritzt",
    "herumgespritzten": "herumgespritzt",
    "herumgespritzter": "herumgespritzt",
    "herumgespritztes": "herumgespritzt",
    "herumgesprochen": "herumsprechen",
    "herumgesprochene": "herumgesprochen",
    "herumgesprochenem": "herumgesprochen",
    "herumgesprochenen": "herumgesprochen",
    "herumgesprochener": "herumgesprochen",
    "herumgesprochenes": "herumgesprochen",
    "herumgetönt": "herumtönen",
    "herumgetönte": "herumgetönt",
    "herumgetöntem": "herumgetönt",
    "herumgetönten": "herumgetönt",
    "herumgetönter": "herumgetönt",
    "herumgetöntes": "herumgetönt",
    "herumgewirbelt": "herumwirbeln",
    "herumgewirbelte": "herumgewirbelt",
    "herumgewirbeltem": "herumgewirbelt",
    "herumgewirbelten": "herumgewirbelt",
    "herumgewirbelter": "herumgewirbelt",
    "herumgewirbeltes": "herumgewirbelt",
    "herumgezogen": "herumziehen",
    "herumgezogene": "herumgezogen",
    "herumgezogenem": "herumgezogen",
    "herumgezogenen": "herumgezogen",
    "herumgezogener": "herumgezogen",
    "herumgezogenes": "herumgezogen",
    "herumhing": "herumhängen",
    "herumhinge": "herumhängen",
    "herumhingen": "herumhängen",
    "herumhingest": "herumhängen",
    "herumhinget": "herumhängen",
    "herumhingst": "herumhängen",
    "herumhingt": "herumhängen",
    "herumhänge": "herumhängen",
    "herumhängend": "herumhängen",
    "herumhängende": "herumhängend",
    "herumhängendem": "herumhängend",
    "herumhängenden": "herumhängend",
    "herumhängender": "herumhängend",
    "herumhängendere": "herumhängend",
    "herumhängenderem": "herumhängend",
    "herumhängenderen": "herumhängend",
    "herumhängenderer": "herumhängend",
    "herumhängenderes": "herumhängend",
    "herumhängendes": "herumhängend",
    "herumhängendste": "herumhängend",
    "herumhängendstem": "herumhängend",
    "herumhängendsten": "herumhängend",
    "herumhängendster": "herumhängend",
    "herumhängendstes": "herumhängend",
    "herumhängest": "herumhängen",
    "herumhänget": "herumhängen",
    "herumhängst": "herumhängen",
    "herumhängt": "herumhängen",
    "herumhängte": "herumhängen",
    "herumhängten": "herumhängen",
    "herumhängtest": "herumhängen",
    "herumhängtet": "herumhängen",
    "herumlag": "herumliegen",
    "herumlagen": "herumliegen",
    "herumlagst": "herumliegen",
    "herumlagt": "herumliegen",
    "herumliege": "herumliegen",
    "herumliegend": "herumliegen",
    "herumliegende": "herumliegend",
    "herumliegendem": "herumliegend",
    "herumliegenden": "herumliegend",
    "herumliegender": "herumliegend",
    "herumliegendere": "herumliegend",
    "herumliegenderem": "herumliegend",
    "herumliegenderen": "herumliegend",
    "herumliegenderer": "herumliegend",
    "herumliegenderes": "herumliegend",
    "herumliegendes": "herumliegend",
    "herumliegendste": "herumliegend",
    "herumliegendstem": "herumliegend",
    "herumliegendsten": "herumliegend",
    "herumliegendster": "herumliegend",
    "herumliegendstes": "herumliegend",
    "herumliegest": "herumliegen",
    "herumlieget": "herumliegen",
    "herumliegst": "herumliegen",
    "herumliegt": "herumliegen",
    "herumlungere": "herumlungern",
    "herumlungernd": "herumlungern",
    "herumlungernde": "herumlungernd",
    "herumlungerndem": "herumlungernd",
    "herumlungernden": "herumlungernd",
    "herumlungernder": "herumlungernd",
    "herumlungerndes": "herumlungernd",
    "herumlungerst": "herumlungern",
    "herumlungert": "herumlungern",
    "herumlungerte": "herumlungern",
    "herumlungerten": "herumlungern",
    "herumlungertest": "herumlungern",
    "herumlungertet": "herumlungern",
    "herumläge": "herumliegen",
    "herumlägen": "herumliegen",
    "herumlägest": "herumliegen",
    "herumläget": "herumliegen",
    "herumreiche": "herumreichen",
    "herumreichend": "herumreichen",
    "herumreichende": "herumreichend",
    "herumreichendem": "herumreichend",
    "herumreichenden": "herumreichend",
    "herumreichender": "herumreichend",
    "herumreichendes": "herumreichend",
    "herumreichest": "herumreichen",
    "herumreichet": "herumreichen",
    "herumreichst": "herumreichen",
    "herumreicht": "herumreichen",
    "herumreichte": "herumreichen",
    "herumreichten": "herumreichen",
    "herumreichtest": "herumreichen",
    "herumreichtet": "herumreichen",
    "herumschlage": "herumschlagen",
    "herumschlagend": "herumschlagen",
    "herumschlagende": "herumschlagend",
    "herumschlagendem": "herumschlagend",
    "herumschlagenden": "herumschlagend",
    "herumschlagender": "herumschlagend",
    "herumschlagendes": "herumschlagend",
    "herumschlagest": "herumschlagen",
    "herumschlaget": "herumschlagen",
    "herumschlagt": "herumschlagen",
    "herumschlug": "herumschlagen",
    "herumschlugen": "herumschlagen",
    "herumschlugst": "herumschlagen",
    "herumschlugt": "herumschlagen",
    "herumschlägst": "herumschlagen",
    "herumschlägt": "herumschlagen",
    "herumschlüge": "herumschlagen",
    "herumschlügen": "herumschlagen",
    "herumschlügest": "herumschlagen",
    "herumschlüget": "herumschlagen",
    "herumsprach": "herumsprechen",
    "herumsprachen": "herumsprechen",
    "herumsprachst": "herumsprechen",
    "herumspracht": "herumsprechen",
    "herumspreche": "herumsprechen",
    "herumsprechend": "herumsprechen",
    "herumsprechende": "herumsprechend",
    "herumsprechendem": "herumsprechend",
    "herumsprechenden": "herumsprechend",
    "herumsprechender": "herumsprechend",
    "herumsprechendes": "herumsprechend",
    "herumsprechest": "herumsprechen",
    "herumsprechet": "herumsprechen",
    "herumsprecht": "herumsprechen",
    "herumsprichst": "herumsprechen",
    "herumspricht": "herumsprechen",
    "herumspritze": "herumspritzen",
    "herumspritzend": "herumspritzen",
    "herumspritzende": "herumspritzend",
    "herumspritzendem": "herumspritzend",
    "herumspritzenden": "herumspritzend",
    "herumspritzender": "herumspritzend",
    "herumspritzendes": "herumspritzend",
    "herumspritzest": "herumspritzen",
    "herumspritzet": "herumspritzen",
    "herumspritzt": "herumspritzen",
    "herumspritzte": "herumspritzen",
    "herumspritzten": "herumspritzen",
    "herumspritztest": "herumspritzen",
    "herumspritztet": "herumspritzen",
    "herumspräche": "herumsprechen",
    "herumsprächen": "herumsprechen",
    "herumsprächest": "herumsprechen",
    "herumsprächet": "herumsprechen",
    "herumtöne": "herumtönen",
    "herumtönend": "herumtönen",
    "herumtönende": "herumtönend",
    "herumtönendem": "herumtönend",
    "herumtönenden": "herumtönend",
    "herumtönender": "herumtönend",
    "herumtönendere": "herumtönend",
    "herumtönenderem": "herumtönend",
    "herumtönenderen": "herumtönend",
    "herumtönenderer": "herumtönend",
    "herumtönenderes": "herumtönend",
    "herumtönendes": "herumtönend",
    "herumtönendste": "herumtönend",
    "herumtönendstem": "herumtönend",
    "herumtönendsten": "herumtönend",
    "herumtönendster": "herumtönend",
    "herumtönendstes": "herumtönend",
    "herumtönest": "herumtönen",
    "herumtönet": "herumtönen",
    "herumtönst": "herumtönen",
    "herumtönt": "herumtönen",
    "herumtönte": "herumtönen",
    "herumtönten": "herumtönen",
    "herumtöntest": "herumtönen",
    "herumtöntet": "herumtönen",
    "herumwirbele": "herumwirbeln",
    "herumwirbelnd": "herumwirbeln",
    "herumwirbelnde": "herumwirbelnd",
    "herumwirbelndem": "herumwirbelnd",
    "herumwirbelnden": "herumwirbelnd",
    "herumwirbelnder": "herumwirbelnd",
    "herumwirbelndes": "herumwirbelnd",
    "herumwirbelst": "herumwirbeln",
    "herumwirbelt": "herumwirbeln",
    "herumwirbelte": "herumwirbeln",
    "herumwirbelten": "herumwirbeln",
    "herumwirbeltest": "herumwirbeln",
    "herumwirbeltet": "herumwirbeln",
    "herumwirble": "herumwirbeln",
    "herumziehe": "herumziehen",
    "herumziehend": "herumziehen",
    "herumziehende": "herumziehend",
    "herumziehendem": "herumziehend",
    "herumziehenden": "herumziehend",
    "herumziehender": "herumziehend",
    "herumziehendes": "herumziehend",
    "herumziehest": "herumziehen",
    "herumziehet": "herumziehen",
    "herumziehst": "herumziehen",
    "herumzieht": "herumziehen",
    "herumzog": "herumziehen",
    "herumzogen": "herumziehen",
    "herumzogst": "herumziehen",
    "herumzogt": "herumziehen",
    "herumzufahren": "herumfahren",
    "herumzufliegen": "herumfliegen",
    "herumzuführen": "herumführen",
    "herumzuhängen": "herumhängen",
    "herumzuliegen": "herumliegen",
    "herumzulungern": "herumlungern",
    "herumzureichen": "herumreichen",
    "herumzuschlagen": "herumschlagen",
    "herumzusprechen": "herumsprechen",
    "herumzuspritzen": "herumspritzen",
    "herumzutönen": "herumtönen",
    "herumzuwirbeln": "herumwirbeln",
    "herumzuziehen": "herumziehen",
    "herumzöge": "herumziehen",
    "herumzögen": "herumziehen",
    "herumzögest": "herumziehen",
    "herumzöget": "herumziehen",
    "herunterbemühe": "herunterbemühen",
    "herunterbemühend": "herunterbemühen",
    "herunterbemühende": "herunterbemühend",
    "herunterbemühendem": "herunterbemühend",
    "herunterbemühenden": "herunterbemühend",
    "herunterbemühender": "herunterbemühend",
    "herunterbemühendes": "herunterbemühend",
    "herunterbemühest": "herunterbemühen",
    "herunterbemühet": "herunterbemühen",
    "herunterbemühst": "herunterbemühen",
    "herunterbemüht": "herunterbemühen",
    "herunterbemühte": "herunterbemühen",
    "herunterbemühtem": "herunterbemüht",
    "herunterbemühten": "herunterbemühen",
    "herunterbemühter": "herunterbemüht",
    "herunterbemühtes": "herunterbemüht",
    "herunterbemühtest": "herunterbemühen",
    "herunterbemühtet": "herunterbemühen",
    "herunterbrachte": "herunterbringen",
    "herunterbrachten": "herunterbringen",
    "herunterbrachtest": "herunterbringen",
    "herunterbrachtet": "herunterbringen",
    "herunterbringe": "herunterbringen",
    "herunterbringend": "herunterbringen",
    "herunterbringende": "herunterbringend",
    "herunterbringendem": "herunterbringend",
    "herunterbringenden": "herunterbringend",
    "herunterbringender": "herunterbringend",
    "herunterbringendes": "herunterbringend",
    "herunterbringest": "herunterbringen",
    "herunterbringet": "herunterbringen",
    "herunterbringst": "herunterbringen",
    "herunterbringt": "herunterbringen",
    "herunterbrächte": "herunterbringen",
    "herunterbrächten": "herunterbringen",
    "herunterbrächtest": "herunterbringen",
    "herunterbrächtet": "herunterbringen",
    "herunterdrücke": "herunterdrücken",
    "herunterdrückend": "herunterdrücken",
    "herunterdrückende": "herunterdrückend",
    "herunterdrückendem": "herunterdrückend",
    "herunterdrückenden": "herunterdrückend",
    "herunterdrückender": "herunterdrückend",
    "herunterdrückendes": "herunterdrückend",
    "herunterdrückest": "herunterdrücken",
    "herunterdrücket": "herunterdrücken",
    "herunterdrückst": "herunterdrücken",
    "herunterdrückt": "herunterdrücken",
    "herunterdrückte": "herunterdrücken",
    "herunterdrückten": "herunterdrücken",
    "herunterdrücktest": "herunterdrücken",
    "herunterdrücktet": "herunterdrücken",
    "herunterfalle": "herunterfallen",
    "herunterfallend": "herunterfallen",
    "herunterfallende": "herunterfallend",
    "herunterfallendem": "herunterfallend",
    "herunterfallenden": "herunterfallend",
    "herunterfallender": "herunterfallend",
    "herunterfallendes": "herunterfallend",
    "herunterfallest": "herunterfallen",
    "herunterfallet": "herunterfallen",
    "herunterfallt": "herunterfallen",
    "herunterfiel": "herunterfallen",
    "herunterfiele": "herunterfallen",
    "herunterfielen": "herunterfallen",
    "herunterfielest": "herunterfallen",
    "herunterfielet": "herunterfallen",
    "herunterfielst": "herunterfallen",
    "herunterfielt": "herunterfallen",
    "herunterfällst": "herunterfallen",
    "herunterfällt": "herunterfallen",
    "heruntergebracht": "herunterbringen",
    "heruntergebrachte": "heruntergebracht",
    "heruntergebrachtem": "heruntergebracht",
    "heruntergebrachten": "heruntergebracht",
    "heruntergebrachter": "heruntergebracht",
    "heruntergebrachtes": "heruntergebracht",
    "heruntergedrückt": "herunterdrücken",
    "heruntergedrückte": "heruntergedrückt",
    "heruntergedrücktem": "heruntergedrückt",
    "heruntergedrückten": "heruntergedrückt",
    "heruntergedrückter": "heruntergedrückt",
    "heruntergedrücktes": "heruntergedrückt",
    "heruntergefallen": "herunterfallen",
    "heruntergefallene": "heruntergefallen",
    "heruntergefallenem": "heruntergefallen",
    "heruntergefallenen": "heruntergefallen",
    "heruntergefallener": "heruntergefallen",
    "heruntergefallenes": "heruntergefallen",
    "heruntergekommen": "herunterkommen",
    "heruntergekommene": "heruntergekommen",
    "heruntergekommenem": "heruntergekommen",
    "heruntergekommenen": "heruntergekommen",
    "heruntergekommener": "heruntergekommen",
    "heruntergekommenere": "heruntergekommen",
    "heruntergekommenerem": "heruntergekommen",
    "heruntergekommeneren": "heruntergekommen",
    "heruntergekommenerer": "heruntergekommen",
    "heruntergekommeneres": "heruntergekommen",
    "heruntergekommenes": "heruntergekommen",
    "heruntergekommenste": "heruntergekommen",
    "heruntergekommenstem": "heruntergekommen",
    "heruntergekommensten": "heruntergekommen",
    "heruntergekommenster": "heruntergekommen",
    "heruntergekommenstes": "heruntergekommen",
    "heruntergemacht": "heruntermachen",
    "heruntergemachte": "heruntergemacht",
    "heruntergemachtem": "heruntergemacht",
    "heruntergemachten": "heruntergemacht",
    "heruntergemachter": "heruntergemacht",
    "heruntergemachtere": "heruntergemacht",
    "heruntergemachterem": "heruntergemacht",
    "heruntergemachteren": "heruntergemacht",
    "heruntergemachterer": "heruntergemacht",
    "heruntergemachteres": "heruntergemacht",
    "heruntergemachtes": "heruntergemacht",
    "heruntergemachteste": "heruntergemacht",
    "heruntergemachtestem": "heruntergemacht",
    "heruntergemachtesten": "heruntergemacht",
    "heruntergemachtester": "heruntergemacht",
    "heruntergemachtestes": "heruntergemacht",
    "heruntergenommen": "herunternehmen",
    "heruntergenommene": "heruntergenommen",
    "heruntergenommenem": "heruntergenommen",
    "heruntergenommenen": "heruntergenommen",
    "heruntergenommener": "heruntergenommen",
    "heruntergenommenes": "heruntergenommen",
    "heruntergerannt": "herunterrennen",
    "heruntergerannte": "heruntergerannt",
    "heruntergeranntem": "heruntergerannt",
    "heruntergerannten": "heruntergerannt",
    "heruntergerannter": "heruntergerannt",
    "heruntergeranntes": "heruntergerannt",
    "heruntergerasselt": "herunterrasseln",
    "heruntergerasselte": "heruntergerasselt",
    "heruntergerasseltem": "heruntergerasselt",
    "heruntergerasselten": "heruntergerasselt",
    "heruntergerasselter": "heruntergerasselt",
    "heruntergerasseltes": "heruntergerasselt",
    "heruntergereicht": "herunterreichen",
    "heruntergereichte": "heruntergereicht",
    "heruntergereichtem": "heruntergereicht",
    "heruntergereichten": "heruntergereicht",
    "heruntergereichter": "heruntergereicht",
    "heruntergereichtes": "heruntergereicht",
    "heruntergerissen": "herunterreißen",
    "heruntergerissene": "heruntergerissen",
    "heruntergerissenem": "heruntergerissen",
    "heruntergerissenen": "heruntergerissen",
    "heruntergerissener": "heruntergerissen",
    "heruntergerissenere": "heruntergerissen",
    "heruntergerissenerem": "heruntergerissen",
    "heruntergerisseneren": "heruntergerissen",
    "heruntergerissenerer": "heruntergerissen",
    "heruntergerisseneres": "heruntergerissen",
    "heruntergerissenes": "heruntergerissen",
    "heruntergerissenste": "heruntergerissen",
    "heruntergerissenstem": "heruntergerissen",
    "heruntergerissensten": "heruntergerissen",
    "heruntergerissenster": "heruntergerissen",
    "heruntergerissenstes": "heruntergerissen",
    "heruntergerollt": "herunterrollen",
    "heruntergerollte": "heruntergerollt",
    "heruntergerolltem": "heruntergerollt",
    "heruntergerollten": "heruntergerollt",
    "heruntergerollter": "heruntergerollt",
    "heruntergerolltere": "heruntergerollt",
    "heruntergerollterem": "heruntergerollt",
    "heruntergerollteren": "heruntergerollt",
    "heruntergerollterer": "heruntergerollt",
    "heruntergerollteres": "heruntergerollt",
    "heruntergerolltes": "heruntergerollt",
    "heruntergerollteste": "heruntergerollt",
    "heruntergerolltestem": "heruntergerollt",
    "heruntergerolltesten": "heruntergerollt",
    "heruntergerolltester": "heruntergerollt",
    "heruntergerolltestes": "heruntergerollt",
    "heruntergeschoben": "herunterschieben",
    "heruntergeschobene": "heruntergeschoben",
    "heruntergeschobenem": "heruntergeschoben",
    "heruntergeschobenen": "heruntergeschoben",
    "heruntergeschobener": "heruntergeschoben",
    "heruntergeschobenere": "heruntergeschoben",
    "heruntergeschobenerem": "heruntergeschoben",
    "heruntergeschobeneren": "heruntergeschoben",
    "heruntergeschobenerer": "heruntergeschoben",
    "heruntergeschobeneres": "heruntergeschoben",
    "heruntergeschobenes": "heruntergeschoben",
    "heruntergeschobenste": "heruntergeschoben",
    "heruntergeschobenstem": "heruntergeschoben",
    "heruntergeschobensten": "heruntergeschoben",
    "heruntergeschobenster": "heruntergeschoben",
    "heruntergeschobenstes": "heruntergeschoben",
    "heruntergeschossen": "herunterschießen",
    "heruntergeschossene": "heruntergeschossen",
    "heruntergeschossenem": "heruntergeschossen",
    "heruntergeschossenen": "heruntergeschossen",
    "heruntergeschossener": "heruntergeschossen",
    "heruntergeschossenes": "heruntergeschossen",
    "heruntergesetzt": "heruntersetzen",
    "heruntergesetzte": "heruntergesetzt",
    "heruntergesetztem": "heruntergesetzt",
    "heruntergesetzten": "heruntergesetzt",
    "heruntergesetzter": "heruntergesetzt",
    "heruntergesetztere": "heruntergesetzt",
    "heruntergesetzterem": "heruntergesetzt",
    "heruntergesetzteren": "heruntergesetzt",
    "heruntergesetzterer": "heruntergesetzt",
    "heruntergesetzteres": "heruntergesetzt",
    "heruntergesetztes": "heruntergesetzt",
    "heruntergesetzteste": "heruntergesetzt",
    "heruntergesetztestem": "heruntergesetzt",
    "heruntergesetztesten": "heruntergesetzt",
    "heruntergesetztester": "heruntergesetzt",
    "heruntergesetztestes": "heruntergesetzt",
    "heruntergetragen": "heruntertragen",
    "heruntergetragene": "heruntergetragen",
    "heruntergetragenem": "heruntergetragen",
    "heruntergetragenen": "heruntergetragen",
    "heruntergetragener": "heruntergetragen",
    "heruntergetragenes": "heruntergetragen",
    "heruntergezogene": "heruntergezogen",
    "heruntergezogenem": "heruntergezogen",
    "heruntergezogenen": "heruntergezogen",
    "heruntergezogener": "heruntergezogen",
    "heruntergezogenes": "heruntergezogen",
    "herunterkam": "herunterkommen",
    "herunterkamen": "herunterkommen",
    "herunterkamst": "herunterkommen",
    "herunterkamt": "herunterkommen",
    "herunterkomme": "herunterkommen",
    "herunterkommend": "herunterkommen",
    "herunterkommende": "herunterkommend",
    "herunterkommendem": "herunterkommend",
    "herunterkommenden": "herunterkommend",
    "herunterkommender": "herunterkommend",
    "herunterkommendere": "herunterkommend",
    "herunterkommenderem": "herunterkommend",
    "herunterkommenderen": "herunterkommend",
    "herunterkommenderer": "herunterkommend",
    "herunterkommenderes": "herunterkommend",
    "herunterkommendes": "herunterkommend",
    "herunterkommendste": "herunterkommend",
    "herunterkommendstem": "herunterkommend",
    "herunterkommendsten": "herunterkommend",
    "herunterkommendster": "herunterkommend",
    "herunterkommendstes": "herunterkommend",
    "herunterkommest": "herunterkommen",
    "herunterkommet": "herunterkommen",
    "herunterkommst": "herunterkommen",
    "herunterkommt": "herunterkommen",
    "herunterkäme": "herunterkommen",
    "herunterkämen": "herunterkommen",
    "herunterkämest": "herunterkommen",
    "herunterkämet": "herunterkommen",
    "heruntermache": "heruntermachen",
    "heruntermachend": "heruntermachen",
    "heruntermachende": "heruntermachend",
    "heruntermachendem": "heruntermachend",
    "heruntermachenden": "heruntermachend",
    "heruntermachender": "heruntermachend",
    "heruntermachendere": "heruntermachend",
    "heruntermachenderem": "heruntermachend",
    "heruntermachenderen": "heruntermachend",
    "heruntermachenderer": "heruntermachend",
    "heruntermachenderes": "heruntermachend",
    "heruntermachendes": "heruntermachend",
    "heruntermachendste": "heruntermachend",
    "heruntermachendstem": "heruntermachend",
    "heruntermachendsten": "heruntermachend",
    "heruntermachendster": "heruntermachend",
    "heruntermachendstes": "heruntermachend",
    "heruntermachest": "heruntermachen",
    "heruntermachet": "heruntermachen",
    "heruntermachst": "heruntermachen",
    "heruntermacht": "heruntermachen",
    "heruntermachte": "heruntermachen",
    "heruntermachten": "heruntermachen",
    "heruntermachtest": "heruntermachen",
    "heruntermachtet": "heruntermachen",
    "herunternahm": "herunternehmen",
    "herunternahmen": "herunternehmen",
    "herunternahmst": "herunternehmen",
    "herunternahmt": "herunternehmen",
    "herunternehme": "herunternehmen",
    "herunternehmend": "herunternehmen",
    "herunternehmende": "herunternehmend",
    "herunternehmendem": "herunternehmend",
    "herunternehmenden": "herunternehmend",
    "herunternehmender": "herunternehmend",
    "herunternehmendes": "herunternehmend",
    "herunternehmest": "herunternehmen",
    "herunternehmet": "herunternehmen",
    "herunternehmt": "herunternehmen",
    "herunternimmst": "herunternehmen",
    "herunternimmt": "herunternehmen",
    "herunternähme": "herunternehmen",
    "herunternähmen": "herunternehmen",
    "herunternähmest": "herunternehmen",
    "herunternähmet": "herunternehmen",
    "herunterrannte": "herunterrennen",
    "herunterrannten": "herunterrennen",
    "herunterranntest": "herunterrennen",
    "herunterranntet": "herunterrennen",
    "herunterrassele": "herunterrasseln",
    "herunterrasselnd": "herunterrasseln",
    "herunterrasselnde": "herunterrasselnd",
    "herunterrasselndem": "herunterrasselnd",
    "herunterrasselnden": "herunterrasselnd",
    "herunterrasselnder": "herunterrasselnd",
    "herunterrasselndes": "herunterrasselnd",
    "herunterrasselst": "herunterrasseln",
    "herunterrasselt": "herunterrasseln",
    "herunterrasselte": "herunterrasseln",
    "herunterrasselten": "herunterrasseln",
    "herunterrasseltest": "herunterrasseln",
    "herunterrasseltet": "herunterrasseln",
    "herunterrassle": "herunterrasseln",
    "herunterreiche": "herunterreichen",
    "herunterreichend": "herunterreichen",
    "herunterreichende": "herunterreichend",
    "herunterreichendem": "herunterreichend",
    "herunterreichenden": "herunterreichend",
    "herunterreichender": "herunterreichend",
    "herunterreichendes": "herunterreichend",
    "herunterreichest": "herunterreichen",
    "herunterreichet": "herunterreichen",
    "herunterreichst": "herunterreichen",
    "herunterreicht": "herunterreichen",
    "herunterreichte": "herunterreichen",
    "herunterreichten": "herunterreichen",
    "herunterreichtest": "herunterreichen",
    "herunterreichtet": "herunterreichen",
    "herunterreiße": "herunterreißen",
    "herunterreißend": "herunterreißen",
    "herunterreißende": "herunterreißend",
    "herunterreißendem": "herunterreißend",
    "herunterreißenden": "herunterreißend",
    "herunterreißender": "herunterreißend",
    "herunterreißendes": "herunterreißend",
    "herunterreißest": "herunterreißen",
    "herunterreißet": "herunterreißen",
    "herunterreißt": "herunterreißen",
    "herunterrenne": "herunterrennen",
    "herunterrennend": "herunterrennen",
    "herunterrennende": "herunterrennend",
    "herunterrennendem": "herunterrennend",
    "herunterrennenden": "herunterrennend",
    "herunterrennender": "herunterrennend",
    "herunterrennendes": "herunterrennend",
    "herunterrennest": "herunterrennen",
    "herunterrennet": "herunterrennen",
    "herunterrennst": "herunterrennen",
    "herunterrennt": "herunterrennen",
    "herunterrisse": "herunterreißen",
    "herunterrissen": "herunterreißen",
    "herunterrissest": "herunterreißen",
    "herunterrisset": "herunterreißen",
    "herunterriß": "herunterreißen",
    "herunterrißt": "herunterreißen",
    "herunterrolle": "herunterrollen",
    "herunterrollend": "herunterrollen",
    "herunterrollende": "herunterrollend",
    "herunterrollendem": "herunterrollend",
    "herunterrollenden": "herunterrollend",
    "herunterrollender": "herunterrollend",
    "herunterrollendes": "herunterrollend",
    "herunterrollest": "herunterrollen",
    "herunterrollet": "herunterrollen",
    "herunterrollst": "herunterrollen",
    "herunterrollt": "herunterrollen",
    "herunterrollte": "herunterrollen",
    "herunterrollten": "herunterrollen",
    "herunterrolltest": "herunterrollen",
    "herunterrolltet": "herunterrollen",
    "herunterschiebe": "herunterschieben",
    "herunterschiebend": "herunterschieben",
    "herunterschiebende": "herunterschiebend",
    "herunterschiebendem": "herunterschiebend",
    "herunterschiebenden": "herunterschiebend",
    "herunterschiebender": "herunterschiebend",
    "herunterschiebendes": "herunterschiebend",
    "herunterschiebest": "herunterschieben",
    "herunterschiebet": "herunterschieben",
    "herunterschiebst": "herunterschieben",
    "herunterschiebt": "herunterschieben",
    "herunterschieße": "herunterschießen",
    "herunterschießend": "herunterschießen",
    "herunterschießende": "herunterschießend",
    "herunterschießendem": "herunterschießend",
    "herunterschießenden": "herunterschießend",
    "herunterschießender": "herunterschießend",
    "herunterschießendes": "herunterschießend",
    "herunterschießest": "herunterschießen",
    "herunterschießet": "herunterschießen",
    "herunterschießt": "herunterschießen",
    "herunterschob": "herunterschieben",
    "herunterschoben": "herunterschieben",
    "herunterschobst": "herunterschieben",
    "herunterschobt": "herunterschieben",
    "herunterschossen": "herunterschießen",
    "herunterschoß": "herunterschießen",
    "herunterschoßt": "herunterschießen",
    "herunterschöbe": "herunterschieben",
    "herunterschöben": "herunterschieben",
    "herunterschöbest": "herunterschieben",
    "herunterschöbet": "herunterschieben",
    "herunterschösse": "herunterschießen",
    "herunterschössen": "herunterschießen",
    "herunterschössest": "herunterschießen",
    "herunterschösset": "herunterschießen",
    "heruntersetze": "heruntersetzen",
    "heruntersetzend": "heruntersetzen",
    "heruntersetzende": "heruntersetzend",
    "heruntersetzendem": "heruntersetzend",
    "heruntersetzenden": "heruntersetzend",
    "heruntersetzender": "heruntersetzend",
    "heruntersetzendes": "heruntersetzend",
    "heruntersetzest": "heruntersetzen",
    "heruntersetzet": "heruntersetzen",
    "heruntersetzt": "heruntersetzen",
    "heruntersetzte": "heruntersetzen",
    "heruntersetzten": "heruntersetzen",
    "heruntersetztest": "heruntersetzen",
    "heruntersetztet": "heruntersetzen",
    "heruntertrage": "heruntertragen",
    "heruntertragend": "heruntertragen",
    "heruntertragende": "heruntertragend",
    "heruntertragendem": "heruntertragend",
    "heruntertragenden": "heruntertragend",
    "heruntertragender": "heruntertragend",
    "heruntertragendes": "heruntertragend",
    "heruntertragest": "heruntertragen",
    "heruntertraget": "heruntertragen",
    "heruntertragt": "heruntertragen",
    "heruntertrug": "heruntertragen",
    "heruntertrugen": "heruntertragen",
    "heruntertrugst": "heruntertragen",
    "heruntertrugt": "heruntertragen",
    "herunterträgst": "heruntertragen",
    "herunterträgt": "heruntertragen",
    "heruntertrüge": "heruntertragen",
    "heruntertrügen": "heruntertragen",
    "heruntertrügest": "heruntertragen",
    "heruntertrüget": "heruntertragen",
    "herunterziehende": "herunterziehend",
    "herunterziehendem": "herunterziehend",
    "herunterziehenden": "herunterziehend",
    "herunterziehender": "herunterziehend",
    "herunterziehendes": "herunterziehend",
    "herunterzubemühen": "herunterbemühen",
    "herunterzubringen": "herunterbringen",
    "herunterzudrücken": "herunterdrücken",
    "herunterzufallen": "herunterfallen",
    "herunterzukommen": "herunterkommen",
    "herunterzumachen": "heruntermachen",
    "herunterzunehmen": "herunternehmen",
    "herunterzurasseln": "herunterrasseln",
    "herunterzureichen": "herunterreichen",
    "herunterzureißen": "herunterreißen",
    "herunterzurennen": "herunterrennen",
    "herunterzurollen": "herunterrollen",
    "herunterzuschieben": "herunterschieben",
    "herunterzuschießen": "herunterschießen",
    "herunterzusetzen": "heruntersetzen",
    "herunterzutragen": "heruntertragen",
    "hervorbrach": "hervorbrechen",
    "hervorbrachen": "hervorbrechen",
    "hervorbrachst": "hervorbrechen",
    "hervorbracht": "hervorbrechen",
    "hervorbrachte": "hervorbringen",
    "hervorbrachten": "hervorbringen",
    "hervorbrachtest": "hervorbringen",
    "hervorbrachtet": "hervorbringen",
    "hervorbreche": "hervorbrechen",
    "hervorbrechend": "hervorbrechen",
    "hervorbrechende": "hervorbrechend",
    "hervorbrechendem": "hervorbrechend",
    "hervorbrechenden": "hervorbrechend",
    "hervorbrechender": "hervorbrechend",
    "hervorbrechendes": "hervorbrechend",
    "hervorbrechest": "hervorbrechen",
    "hervorbrechet": "hervorbrechen",
    "hervorbrecht": "hervorbrechen",
    "hervorbrichst": "hervorbrechen",
    "hervorbricht": "hervorbrechen",
    "hervorbringe": "hervorbringen",
    "hervorbringend": "hervorbringen",
    "hervorbringende": "hervorbringend",
    "hervorbringendem": "hervorbringend",
    "hervorbringenden": "hervorbringend",
    "hervorbringender": "hervorbringend",
    "hervorbringendes": "hervorbringend",
    "hervorbringest": "hervorbringen",
    "hervorbringet": "hervorbringen",
    "hervorbringst": "hervorbringen",
    "hervorbringt": "hervorbringen",
    "hervorbräche": "hervorbrechen",
    "hervorbrächen": "hervorbrechen",
    "hervorbrächest": "hervorbrechen",
    "hervorbrächet": "hervorbrechen",
    "hervorbrächte": "hervorbringen",
    "hervorbrächten": "hervorbringen",
    "hervorbrächtest": "hervorbringen",
    "hervorbrächtet": "hervorbringen",
    "hervordrang": "hervordringen",
    "hervordrangen": "hervordringen",
    "hervordrangst": "hervordringen",
    "hervordrangt": "hervordringen",
    "hervordringe": "hervordringen",
    "hervordringend": "hervordringen",
    "hervordringende": "hervordringend",
    "hervordringendem": "hervordringend",
    "hervordringenden": "hervordringend",
    "hervordringender": "hervordringend",
    "hervordringendes": "hervordringend",
    "hervordringest": "hervordringen",
    "hervordringet": "hervordringen",
    "hervordringst": "hervordringen",
    "hervordringt": "hervordringen",
    "hervordränge": "hervordringen",
    "hervordrängen": "hervordringen",
    "hervordrängend": "hervordrängen",
    "hervordrängende": "hervordrängend",
    "hervordrängendem": "hervordrängend",
    "hervordrängenden": "hervordrängend",
    "hervordrängender": "hervordrängend",
    "hervordrängendes": "hervordrängend",
    "hervordrängest": "hervordringen",
    "hervordränget": "hervordringen",
    "hervordrängst": "hervordrängen",
    "hervordrängt": "hervordrängen",
    "hervordrängte": "hervordrängen",
    "hervordrängten": "hervordrängen",
    "hervordrängtest": "hervordrängen",
    "hervordrängtet": "hervordrängen",
    "hervorgebracht": "hervorbringen",
    "hervorgebrachte": "hervorgebracht",
    "hervorgebrachtem": "hervorgebracht",
    "hervorgebrachten": "hervorgebracht",
    "hervorgebrachter": "hervorgebracht",
    "hervorgebrachtes": "hervorgebracht",
    "hervorgebrochen": "hervorbrechen",
    "hervorgebrochene": "hervorgebrochen",
    "hervorgebrochenem": "hervorgebrochen",
    "hervorgebrochenen": "hervorgebrochen",
    "hervorgebrochener": "hervorgebrochen",
    "hervorgebrochenes": "hervorgebrochen",
    "hervorgedrungen": "hervordringen",
    "hervorgedrungene": "hervorgedrungen",
    "hervorgedrungenem": "hervorgedrungen",
    "hervorgedrungenen": "hervorgedrungen",
    "hervorgedrungener": "hervorgedrungen",
    "hervorgedrungenes": "hervorgedrungen",
    "hervorgedrängt": "hervordrängen",
    "hervorgedrängte": "hervorgedrängt",
    "hervorgedrängtem": "hervorgedrängt",
    "hervorgedrängten": "hervorgedrängt",
    "hervorgedrängter": "hervorgedrängt",
    "hervorgedrängtes": "hervorgedrängt",
    "hervorgegangen": "hervorgehen",
    "hervorgegangene": "hervorgegangen",
    "hervorgegangenem": "hervorgegangen",
    "hervorgegangenen": "hervorgegangen",
    "hervorgegangener": "hervorgegangen",
    "hervorgegangenes": "hervorgegangen",
    "hervorgehe": "hervorgehen",
    "hervorgehend": "hervorgehen",
    "hervorgehende": "hervorgehend",
    "hervorgehendem": "hervorgehend",
    "hervorgehenden": "hervorgehend",
    "hervorgehender": "hervorgehend",
    "hervorgehendes": "hervorgehend",
    "hervorgehest": "hervorgehen",
    "hervorgehet": "hervorgehen",
    "hervorgehoben": "hervorheben",
    "hervorgehobene": "hervorgehoben",
    "hervorgehobenem": "hervorgehoben",
    "hervorgehobenen": "hervorgehoben",
    "hervorgehobener": "hervorgehoben",
    "hervorgehobenere": "hervorgehoben",
    "hervorgehobenerem": "hervorgehoben",
    "hervorgehobeneren": "hervorgehoben",
    "hervorgehobenerer": "hervorgehoben",
    "hervorgehobeneres": "hervorgehoben",
    "hervorgehobenes": "hervorgehoben",
    "hervorgehobenste": "hervorgehoben",
    "hervorgehobenstem": "hervorgehoben",
    "hervorgehobensten": "hervorgehoben",
    "hervorgehobenster": "hervorgehoben",
    "hervorgehobenstes": "hervorgehoben",
    "hervorgehst": "hervorgehen",
    "hervorgeht": "hervorgehen",
    "hervorgekehrt": "hervorkehren",
    "hervorgekehrte": "hervorgekehrt",
    "hervorgekehrtem": "hervorgekehrt",
    "hervorgekehrten": "hervorgekehrt",
    "hervorgekehrter": "hervorgekehrt",
    "hervorgekehrtes": "hervorgekehrt",
    "hervorgekeimt": "hervorkeimen",
    "hervorgekeimte": "hervorgekeimt",
    "hervorgekeimtem": "hervorgekeimt",
    "hervorgekeimten": "hervorgekeimt",
    "hervorgekeimter": "hervorgekeimt",
    "hervorgekeimtere": "hervorgekeimt",
    "hervorgekeimterem": "hervorgekeimt",
    "hervorgekeimteren": "hervorgekeimt",
    "hervorgekeimterer": "hervorgekeimt",
    "hervorgekeimteres": "hervorgekeimt",
    "hervorgekeimtes": "hervorgekeimt",
    "hervorgekeimteste": "hervorgekeimt",
    "hervorgekeimtestem": "hervorgekeimt",
    "hervorgekeimtesten": "hervorgekeimt",
    "hervorgekeimtester": "hervorgekeimt",
    "hervorgekeimtestes": "hervorgekeimt",
    "hervorgekommen": "hervorkommen",
    "hervorgekommene": "hervorgekommen",
    "hervorgekommenem": "hervorgekommen",
    "hervorgekommenen": "hervorgekommen",
    "hervorgekommener": "hervorgekommen",
    "hervorgekommenes": "hervorgekommen",
    "hervorgeleuchtet": "hervorleuchten",
    "hervorgeleuchtete": "hervorgeleuchtet",
    "hervorgeleuchtetem": "hervorgeleuchtet",
    "hervorgeleuchteten": "hervorgeleuchtet",
    "hervorgeleuchteter": "hervorgeleuchtet",
    "hervorgeleuchtetes": "hervorgeleuchtet",
    "hervorgequellt": "hervorquellen",
    "hervorgequellte": "hervorgequellt",
    "hervorgequelltem": "hervorgequellt",
    "hervorgequellten": "hervorgequellt",
    "hervorgequellter": "hervorgequellt",
    "hervorgequelltes": "hervorgequellt",
    "hervorgequollen": "hervorquellen",
    "hervorgequollene": "hervorgequollen",
    "hervorgequollenem": "hervorgequollen",
    "hervorgequollenen": "hervorgequollen",
    "hervorgequollener": "hervorgequollen",
    "hervorgequollenes": "hervorgequollen",
    "hervorgeragt": "hervorragen",
    "hervorgeragte": "hervorgeragt",
    "hervorgeragtem": "hervorgeragt",
    "hervorgeragten": "hervorgeragt",
    "hervorgeragter": "hervorgeragt",
    "hervorgeragtes": "hervorgeragt",
    "hervorgerufen": "hervorrufen",
    "hervorgerufene": "hervorgerufen",
    "hervorgerufenem": "hervorgerufen",
    "hervorgerufenen": "hervorgerufen",
    "hervorgerufener": "hervorgerufen",
    "hervorgerufenes": "hervorgerufen",
    "hervorgeschaut": "hervorschauen",
    "hervorgeschaute": "hervorgeschaut",
    "hervorgeschautem": "hervorgeschaut",
    "hervorgeschauten": "hervorgeschaut",
    "hervorgeschauter": "hervorgeschaut",
    "hervorgeschautes": "hervorgeschaut",
    "hervorgeschimmert": "hervorschimmern",
    "hervorgeschimmerte": "hervorgeschimmert",
    "hervorgeschimmertem": "hervorgeschimmert",
    "hervorgeschimmerten": "hervorgeschimmert",
    "hervorgeschimmerter": "hervorgeschimmert",
    "hervorgeschimmertere": "hervorgeschimmert",
    "hervorgeschimmerterem": "hervorgeschimmert",
    "hervorgeschimmerteren": "hervorgeschimmert",
    "hervorgeschimmerterer": "hervorgeschimmert",
    "hervorgeschimmerteres": "hervorgeschimmert",
    "hervorgeschimmertes": "hervorgeschimmert",
    "hervorgeschimmerteste": "hervorgeschimmert",
    "hervorgeschimmertestem": "hervorgeschimmert",
    "hervorgeschimmertesten": "hervorgeschimmert",
    "hervorgeschimmertester": "hervorgeschimmert",
    "hervorgeschimmertestes": "hervorgeschimmert",
    "hervorgeschossen": "hervorschießen",
    "hervorgeschossene": "hervorgeschossen",
    "hervorgeschossenem": "hervorgeschossen",
    "hervorgeschossenen": "hervorgeschossen",
    "hervorgeschossener": "hervorgeschossen",
    "hervorgeschossenes": "hervorgeschossen",
    "hervorgesprudelt": "hervorsprudeln",
    "hervorgesprudelte": "hervorgesprudelt",
    "hervorgesprudeltem": "hervorgesprudelt",
    "hervorgesprudelten": "hervorgesprudelt",
    "hervorgesprudelter": "hervorgesprudelt",
    "hervorgesprudeltes": "hervorgesprudelt",
    "hervorgesprungen": "hervorspringen",
    "hervorgesprungene": "hervorgesprungen",
    "hervorgesprungenem": "hervorgesprungen",
    "hervorgesprungenen": "hervorgesprungen",
    "hervorgesprungener": "hervorgesprungen",
    "hervorgesprungenes": "hervorgesprungen",
    "hervorgestanden": "hervorstehen",
    "hervorgestandene": "hervorgestanden",
    "hervorgestandenem": "hervorgestanden",
    "hervorgestandenen": "hervorgestanden",
    "hervorgestandener": "hervorgestanden",
    "hervorgestandenes": "hervorgestanden",
    "hervorgestochen": "hervorstechen",
    "hervorgestochene": "hervorgestochen",
    "hervorgestochenem": "hervorgestochen",
    "hervorgestochenen": "hervorgestochen",
    "hervorgestochener": "hervorgestochen",
    "hervorgestochenere": "hervorgestochen",
    "hervorgestochenerem": "hervorgestochen",
    "hervorgestocheneren": "hervorgestochen",
    "hervorgestochenerer": "hervorgestochen",
    "hervorgestocheneres": "hervorgestochen",
    "hervorgestochenes": "hervorgestochen",
    "hervorgestochenste": "hervorgestochen",
    "hervorgestochenstem": "hervorgestochen",
    "hervorgestochensten": "hervorgestochen",
    "hervorgestochenster": "hervorgestochen",
    "hervorgestochenstes": "hervorgestochen",
    "hervorgestoßen": "hervorstoßen",
    "hervorgestoßene": "hervorgestoßen",
    "hervorgestoßenem": "hervorgestoßen",
    "hervorgestoßenen": "hervorgestoßen",
    "hervorgestoßener": "hervorgestoßen",
    "hervorgestoßenes": "hervorgestoßen",
    "hervorgestürzt": "hervorstürzen",
    "hervorgestürzte": "hervorgestürzt",
    "hervorgestürztem": "hervorgestürzt",
    "hervorgestürzten": "hervorgestürzt",
    "hervorgestürzter": "hervorgestürzt",
    "hervorgestürztes": "hervorgestürzt",
    "hervorgesucht": "hervorsuchen",
    "hervorgesuchte": "hervorgesucht",
    "hervorgesuchtem": "hervorgesucht",
    "hervorgesuchten": "hervorgesucht",
    "hervorgesuchter": "hervorgesucht",
    "hervorgesuchtes": "hervorgesucht",
    "hervorgetaucht": "hervortauchen",
    "hervorgetauchte": "hervorgetaucht",
    "hervorgetauchtem": "hervorgetaucht",
    "hervorgetauchten": "hervorgetaucht",
    "hervorgetauchter": "hervorgetaucht",
    "hervorgetauchtes": "hervorgetaucht",
    "hervorgewagt": "hervorwagen",
    "hervorgewagte": "hervorgewagt",
    "hervorgewagtem": "hervorgewagt",
    "hervorgewagten": "hervorgewagt",
    "hervorgewagter": "hervorgewagt",
    "hervorgewagtes": "hervorgewagt",
    "hervorgezaubert": "hervorzaubern",
    "hervorgezauberte": "hervorgezaubert",
    "hervorgezaubertem": "hervorgezaubert",
    "hervorgezauberten": "hervorgezaubert",
    "hervorgezauberter": "hervorgezaubert",
    "hervorgezaubertes": "hervorgezaubert",
    "hervorging": "hervorgehen",
    "hervorginge": "hervorgehen",
    "hervorgingen": "hervorgehen",
    "hervorgingest": "hervorgehen",
    "hervorginget": "hervorgehen",
    "hervorgingst": "hervorgehen",
    "hervorgingt": "hervorgehen",
    "hervorhebe": "hervorheben",
    "hervorhebend": "hervorheben",
    "hervorhebende": "hervorhebend",
    "hervorhebendem": "hervorhebend",
    "hervorhebenden": "hervorhebend",
    "hervorhebender": "hervorhebend",
    "hervorhebendes": "hervorhebend",
    "hervorhebest": "hervorheben",
    "hervorhebet": "hervorheben",
    "hervorhebst": "hervorheben",
    "hervorhebt": "hervorheben",
    "hervorhob": "hervorheben",
    "hervorhoben": "hervorheben",
    "hervorhobst": "hervorheben",
    "hervorhobt": "hervorheben",
    "hervorhöbe": "hervorheben",
    "hervorhöben": "hervorheben",
    "hervorhöbest": "hervorheben",
    "hervorhöbet": "hervorheben",
    "hervorkam": "hervorkommen",
    "hervorkamen": "hervorkommen",
    "hervorkamst": "hervorkommen",
    "hervorkamt": "hervorkommen",
    "hervorkehre": "hervorkehren",
    "hervorkehrend": "hervorkehren",
    "hervorkehrende": "hervorkehrend",
    "hervorkehrendem": "hervorkehrend",
    "hervorkehrenden": "hervorkehrend",
    "hervorkehrender": "hervorkehrend",
    "hervorkehrendes": "hervorkehrend",
    "hervorkehrest": "hervorkehren",
    "hervorkehret": "hervorkehren",
    "hervorkehrst": "hervorkehren",
    "hervorkehrt": "hervorkehren",
    "hervorkehrte": "hervorkehren",
    "hervorkehrten": "hervorkehren",
    "hervorkehrtest": "hervorkehren",
    "hervorkehrtet": "hervorkehren",
    "hervorkeime": "hervorkeimen",
    "hervorkeimend": "hervorkeimen",
    "hervorkeimende": "hervorkeimend",
    "hervorkeimendem": "hervorkeimend",
    "hervorkeimenden": "hervorkeimend",
    "hervorkeimender": "hervorkeimend",
    "hervorkeimendere": "hervorkeimend",
    "hervorkeimenderem": "hervorkeimend",
    "hervorkeimenderen": "hervorkeimend",
    "hervorkeimenderer": "hervorkeimend",
    "hervorkeimenderes": "hervorkeimend",
    "hervorkeimendes": "hervorkeimend",
    "hervorkeimendste": "hervorkeimend",
    "hervorkeimendstem": "hervorkeimend",
    "hervorkeimendsten": "hervorkeimend",
    "hervorkeimendster": "hervorkeimend",
    "hervorkeimendstes": "hervorkeimend",
    "hervorkeimest": "hervorkeimen",
    "hervorkeimet": "hervorkeimen",
    "hervorkeimst": "hervorkeimen",
    "hervorkeimt": "hervorkeimen",
    "hervorkeimte": "hervorkeimen",
    "hervorkeimten": "hervorkeimen",
    "hervorkeimtest": "hervorkeimen",
    "hervorkeimtet": "hervorkeimen",
    "hervorkomme": "hervorkommen",
    "hervorkommend": "hervorkommen",
    "hervorkommende": "hervorkommend",
    "hervorkommendem": "hervorkommend",
    "hervorkommenden": "hervorkommend",
    "hervorkommender": "hervorkommend",
    "hervorkommendes": "hervorkommend",
    "hervorkommest": "hervorkommen",
    "hervorkommet": "hervorkommen",
    "hervorkommst": "hervorkommen",
    "hervorkommt": "hervorkommen",
    "hervorkäme": "hervorkommen",
    "hervorkämen": "hervorkommen",
    "hervorkämest": "hervorkommen",
    "hervorkämet": "hervorkommen",
    "hervorleuchte": "hervorleuchten",
    "hervorleuchtend": "hervorleuchten",
    "hervorleuchtende": "hervorleuchtend",
    "hervorleuchtendem": "hervorleuchtend",
    "hervorleuchtenden": "hervorleuchtend",
    "hervorleuchtender": "hervorleuchtend",
    "hervorleuchtendes": "hervorleuchtend",
    "hervorleuchtest": "hervorleuchten",
    "hervorleuchtet": "hervorleuchten",
    "hervorleuchtete": "hervorleuchten",
    "hervorleuchteten": "hervorleuchten",
    "hervorleuchtetest": "hervorleuchten",
    "hervorleuchtetet": "hervorleuchten",
    "hervorquelle": "hervorquellen",
    "hervorquellend": "hervorquellen",
    "hervorquellende": "hervorquellend",
    "hervorquellendem": "hervorquellend",
    "hervorquellenden": "hervorquellend",
    "hervorquellender": "hervorquellend",
    "hervorquellendes": "hervorquellend",
    "hervorquellest": "hervorquellen",
    "hervorquellet": "hervorquellen",
    "hervorquellst": "hervorquellen",
    "hervorquellt": "hervorquellen",
    "hervorquellte": "hervorquellen",
    "hervorquellten": "hervorquellen",
    "hervorquelltest": "hervorquellen",
    "hervorquelltet": "hervorquellen",
    "hervorquillst": "hervorquellen",
    "hervorquillt": "hervorquellen",
    "hervorquoll": "hervorquellen",
    "hervorquollen": "hervorquellen",
    "hervorquollst": "hervorquellen",
    "hervorquollt": "hervorquellen",
    "hervorquölle": "hervorquellen",
    "hervorquöllen": "hervorquellen",
    "hervorquöllest": "hervorquellen",
    "hervorquöllet": "hervorquellen",
    "hervorrage": "hervorragen",
    "hervorragend": "hervorragen",
    "hervorragende": "hervorragend",
    "hervorragendem": "hervorragend",
    "hervorragenden": "hervorragend",
    "hervorragender": "hervorragend",
    "hervorragendere": "hervorragend",
    "hervorragenderem": "hervorragend",
    "hervorragenderen": "hervorragend",
    "hervorragenderer": "hervorragend",
    "hervorragenderes": "hervorragend",
    "hervorragendes": "hervorragend",
    "hervorragendste": "hervorragend",
    "hervorragendstem": "hervorragend",
    "hervorragendsten": "hervorragend",
    "hervorragendster": "hervorragend",
    "hervorragendstes": "hervorragend",
    "hervorragest": "hervorragen",
    "hervorraget": "hervorragen",
    "hervorragst": "hervorragen",
    "hervorragt": "hervorragen",
    "hervorragte": "hervorragen",
    "hervorragten": "hervorragen",
    "hervorragtest": "hervorragen",
    "hervorragtet": "hervorragen",
    "hervorrief": "hervorrufen",
    "hervorriefe": "hervorrufen",
    "hervorriefen": "hervorrufen",
    "hervorriefest": "hervorrufen",
    "hervorriefet": "hervorrufen",
    "hervorriefst": "hervorrufen",
    "hervorrieft": "hervorrufen",
    "hervorrufe": "hervorrufen",
    "hervorrufend": "hervorrufen",
    "hervorrufende": "hervorrufend",
    "hervorrufendem": "hervorrufend",
    "hervorrufenden": "hervorrufend",
    "hervorrufender": "hervorrufend",
    "hervorrufendes": "hervorrufend",
    "hervorrufest": "hervorrufen",
    "hervorrufet": "hervorrufen",
    "hervorrufst": "hervorrufen",
    "hervorruft": "hervorrufen",
    "hervorschaue": "hervorschauen",
    "hervorschauend": "hervorschauen",
    "hervorschauende": "hervorschauend",
    "hervorschauendem": "hervorschauend",
    "hervorschauenden": "hervorschauend",
    "hervorschauender": "hervorschauend",
    "hervorschauendes": "hervorschauend",
    "hervorschauest": "hervorschauen",
    "hervorschauet": "hervorschauen",
    "hervorschaust": "hervorschauen",
    "hervorschaut": "hervorschauen",
    "hervorschaute": "hervorschauen",
    "hervorschauten": "hervorschauen",
    "hervorschautest": "hervorschauen",
    "hervorschautet": "hervorschauen",
    "hervorschieße": "hervorschießen",
    "hervorschießend": "hervorschießen",
    "hervorschießende": "hervorschießend",
    "hervorschießendem": "hervorschießend",
    "hervorschießenden": "hervorschießend",
    "hervorschießender": "hervorschießend",
    "hervorschießendes": "hervorschießend",
    "hervorschießest": "hervorschießen",
    "hervorschießet": "hervorschießen",
    "hervorschießt": "hervorschießen",
    "hervorschimmere": "hervorschimmern",
    "hervorschimmernd": "hervorschimmern",
    "hervorschimmernde": "hervorschimmernd",
    "hervorschimmerndem": "hervorschimmernd",
    "hervorschimmernden": "hervorschimmernd",
    "hervorschimmernder": "hervorschimmernd",
    "hervorschimmerndere": "hervorschimmernd",
    "hervorschimmernderem": "hervorschimmernd",
    "hervorschimmernderen": "hervorschimmernd",
    "hervorschimmernderer": "hervorschimmernd",
    "hervorschimmernderes": "hervorschimmernd",
    "hervorschimmerndes": "hervorschimmernd",
    "hervorschimmerndste": "hervorschimmernd",
    "hervorschimmerndstem": "hervorschimmernd",
    "hervorschimmerndsten": "hervorschimmernd",
    "hervorschimmerndster": "hervorschimmernd",
    "hervorschimmerndstes": "hervorschimmernd",
    "hervorschimmerst": "hervorschimmern",
    "hervorschimmert": "hervorschimmern",
    "hervorschimmerte": "hervorschimmern",
    "hervorschimmerten": "hervorschimmern",
    "hervorschimmertest": "hervorschimmern",
    "hervorschimmertet": "hervorschimmern",
    "hervorschossen": "hervorschießen",
    "hervorschoß": "hervorschießen",
    "hervorschoßt": "hervorschießen",
    "hervorschösse": "hervorschießen",
    "hervorschössen": "hervorschießen",
    "hervorschössest": "hervorschießen",
    "hervorschösset": "hervorschießen",
    "hervorsprang": "hervorspringen",
    "hervorsprangen": "hervorspringen",
    "hervorsprangst": "hervorspringen",
    "hervorsprangt": "hervorspringen",
    "hervorspringe": "hervorspringen",
    "hervorspringend": "hervorspringen",
    "hervorspringende": "hervorspringend",
    "hervorspringendem": "hervorspringend",
    "hervorspringenden": "hervorspringend",
    "hervorspringender": "hervorspringend",
    "hervorspringendes": "hervorspringend",
    "hervorspringest": "hervorspringen",
    "hervorspringet": "hervorspringen",
    "hervorspringst": "hervorspringen",
    "hervorspringt": "hervorspringen",
    "hervorsprudele": "hervorsprudeln",
    "hervorsprudelnd": "hervorsprudeln",
    "hervorsprudelnde": "hervorsprudelnd",
    "hervorsprudelndem": "hervorsprudelnd",
    "hervorsprudelnden": "hervorsprudelnd",
    "hervorsprudelnder": "hervorsprudelnd",
    "hervorsprudelndes": "hervorsprudelnd",
    "hervorsprudelst": "hervorsprudeln",
    "hervorsprudelt": "hervorsprudeln",
    "hervorsprudelte": "hervorsprudeln",
    "hervorsprudelten": "hervorsprudeln",
    "hervorsprudeltest": "hervorsprudeln",
    "hervorsprudeltet": "hervorsprudeln",
    "hervorsprudle": "hervorsprudeln",
    "hervorspränge": "hervorspringen",
    "hervorsprängen": "hervorspringen",
    "hervorsprängest": "hervorspringen",
    "hervorspränget": "hervorspringen",
    "hervorstach": "hervorstechen",
    "hervorstachen": "hervorstechen",
    "hervorstachst": "hervorstechen",
    "hervorstacht": "hervorstechen",
    "hervorstand": "hervorstehen",
    "hervorstanden": "hervorstehen",
    "hervorstandest": "hervorstehen",
    "hervorstandet": "hervorstehen",
    "hervorsteche": "hervorstechen",
    "hervorstechend": "hervorstechen",
    "hervorstechende": "hervorstechend",
    "hervorstechendem": "hervorstechend",
    "hervorstechenden": "hervorstechend",
    "hervorstechender": "hervorstechend",
    "hervorstechendere": "hervorstechend",
    "hervorstechenderem": "hervorstechend",
    "hervorstechenderen": "hervorstechend",
    "hervorstechenderer": "hervorstechend",
    "hervorstechenderes": "hervorstechend",
    "hervorstechendes": "hervorstechend",
    "hervorstechendste": "hervorstechend",
    "hervorstechendstem": "hervorstechend",
    "hervorstechendsten": "hervorstechend",
    "hervorstechendster": "hervorstechend",
    "hervorstechendstes": "hervorstechend",
    "hervorstechest": "hervorstechen",
    "hervorstechet": "hervorstechen",
    "hervorstecht": "hervorstechen",
    "hervorstehe": "hervorstehen",
    "hervorstehend": "hervorstehen",
    "hervorstehende": "hervorstehend",
    "hervorstehendem": "hervorstehend",
    "hervorstehenden": "hervorstehend",
    "hervorstehender": "hervorstehend",
    "hervorstehendere": "hervorstehend",
    "hervorstehenderem": "hervorstehend",
    "hervorstehenderen": "hervorstehend",
    "hervorstehenderer": "hervorstehend",
    "hervorstehenderes": "hervorstehend",
    "hervorstehendes": "hervorstehend",
    "hervorstehendste": "hervorstehend",
    "hervorstehendstem": "hervorstehend",
    "hervorstehendsten": "hervorstehend",
    "hervorstehendster": "hervorstehend",
    "hervorstehendstes": "hervorstehend",
    "hervorstehest": "hervorstehen",
    "hervorstehet": "hervorstehen",
    "hervorstehst": "hervorstehen",
    "hervorsteht": "hervorstehen",
    "hervorstichst": "hervorstechen",
    "hervorsticht": "hervorstechen",
    "hervorstieß": "hervorstoßen",
    "hervorstieße": "hervorstoßen",
    "hervorstießen": "hervorstoßen",
    "hervorstießest": "hervorstoßen",
    "hervorstießet": "hervorstoßen",
    "hervorstießt": "hervorstoßen",
    "hervorstoße": "hervorstoßen",
    "hervorstoßend": "hervorstoßen",
    "hervorstoßende": "hervorstoßend",
    "hervorstoßendem": "hervorstoßend",
    "hervorstoßenden": "hervorstoßend",
    "hervorstoßender": "hervorstoßend",
    "hervorstoßendes": "hervorstoßend",
    "hervorstoßest": "hervorstoßen",
    "hervorstoßet": "hervorstoßen",
    "hervorstoßt": "hervorstoßen",
    "hervorstäche": "hervorstechen",
    "hervorstächen": "hervorstechen",
    "hervorstächest": "hervorstechen",
    "hervorstächet": "hervorstechen",
    "hervorstößt": "hervorstoßen",
    "hervorstünde": "hervorstehen",
    "hervorstünden": "hervorstehen",
    "hervorstündest": "hervorstehen",
    "hervorstündet": "hervorstehen",
    "hervorstürze": "hervorstürzen",
    "hervorstürzend": "hervorstürzen",
    "hervorstürzende": "hervorstürzend",
    "hervorstürzendem": "hervorstürzend",
    "hervorstürzenden": "hervorstürzend",
    "hervorstürzender": "hervorstürzend",
    "hervorstürzendes": "hervorstürzend",
    "hervorstürzest": "hervorstürzen",
    "hervorstürzet": "hervorstürzen",
    "hervorstürzt": "hervorstürzen",
    "hervorstürzte": "hervorstürzen",
    "hervorstürzten": "hervorstürzen",
    "hervorstürztest": "hervorstürzen",
    "hervorstürztet": "hervorstürzen",
    "hervorsuche": "hervorsuchen",
    "hervorsuchend": "hervorsuchen",
    "hervorsuchende": "hervorsuchend",
    "hervorsuchendem": "hervorsuchend",
    "hervorsuchenden": "hervorsuchend",
    "hervorsuchender": "hervorsuchend",
    "hervorsuchendes": "hervorsuchend",
    "hervorsuchest": "hervorsuchen",
    "hervorsuchet": "hervorsuchen",
    "hervorsuchst": "hervorsuchen",
    "hervorsucht": "hervorsuchen",
    "hervorsuchte": "hervorsuchen",
    "hervorsuchten": "hervorsuchen",
    "hervorsuchtest": "hervorsuchen",
    "hervorsuchtet": "hervorsuchen",
    "hervortauche": "hervortauchen",
    "hervortauchend": "hervortauchen",
    "hervortauchende": "hervortauchend",
    "hervortauchendem": "hervortauchend",
    "hervortauchenden": "hervortauchend",
    "hervortauchender": "hervortauchend",
    "hervortauchendes": "hervortauchend",
    "hervortauchest": "hervortauchen",
    "hervortauchet": "hervortauchen",
    "hervortauchst": "hervortauchen",
    "hervortaucht": "hervortauchen",
    "hervortauchte": "hervortauchen",
    "hervortauchten": "hervortauchen",
    "hervortauchtest": "hervortauchen",
    "hervortauchtet": "hervortauchen",
    "hervorwage": "hervorwagen",
    "hervorwagend": "hervorwagen",
    "hervorwagende": "hervorwagend",
    "hervorwagendem": "hervorwagend",
    "hervorwagenden": "hervorwagend",
    "hervorwagender": "hervorwagend",
    "hervorwagendes": "hervorwagend",
    "hervorwagest": "hervorwagen",
    "hervorwaget": "hervorwagen",
    "hervorwagst": "hervorwagen",
    "hervorwagt": "hervorwagen",
    "hervorwagte": "hervorwagen",
    "hervorwagten": "hervorwagen",
    "hervorwagtest": "hervorwagen",
    "hervorwagtet": "hervorwagen",
    "hervorzaubere": "hervorzaubern",
    "hervorzaubernd": "hervorzaubern",
    "hervorzaubernde": "hervorzaubernd",
    "hervorzauberndem": "hervorzaubernd",
    "hervorzaubernden": "hervorzaubernd",
    "hervorzaubernder": "hervorzaubernd",
    "hervorzauberndes": "hervorzaubernd",
    "hervorzauberst": "hervorzaubern",
    "hervorzaubert": "hervorzaubern",
    "hervorzauberte": "hervorzaubern",
    "hervorzauberten": "hervorzaubern",
    "hervorzaubertest": "hervorzaubern",
    "hervorzaubertet": "hervorzaubern",
    "hervorzubrechen": "hervorbrechen",
    "hervorzubringen": "hervorbringen",
    "hervorzudringen": "hervordringen",
    "hervorzudrängen": "hervordrängen",
    "hervorzugehen": "hervorgehen",
    "hervorzuheben": "hervorheben",
    "hervorzukehren": "hervorkehren",
    "hervorzukeimen": "hervorkeimen",
    "hervorzukommen": "hervorkommen",
    "hervorzuleuchten": "hervorleuchten",
    "hervorzuquellen": "hervorquellen",
    "hervorzuragen": "hervorragen",
    "hervorzurufen": "hervorrufen",
    "hervorzuschauen": "hervorschauen",
    "hervorzuschießen": "hervorschießen",
    "hervorzuschimmern": "hervorschimmern",
    "hervorzuspringen": "hervorspringen",
    "hervorzusprudeln": "hervorsprudeln",
    "hervorzustechen": "hervorstechen",
    "hervorzustehen": "hervorstehen",
    "hervorzustoßen": "hervorstoßen",
    "hervorzustürzen": "hervorstürzen",
    "hervorzusuchen": "hervorsuchen",
    "hervorzutauchen": "hervortauchen",
    "hervorzuwagen": "hervorwagen",
    "hervorzuzaubern": "hervorzaubern",
    "herwarf": "herwerfen",
    "herwarfen": "herwerfen",
    "herwarfst": "herwerfen",
    "herwarft": "herwerfen",
    "herwerfe": "herwerfen",
    "herwerfend": "herwerfen",
    "herwerfende": "herwerfend",
    "herwerfendem": "herwerfend",
    "herwerfenden": "herwerfend",
    "herwerfender": "herwerfend",
    "herwerfendes": "herwerfend",
    "herwerfest": "herwerfen",
    "herwerfet": "herwerfen",
    "herwerft": "herwerfen",
    "herwinke": "herwinken",
    "herwinkend": "herwinken",
    "herwinkende": "herwinkend",
    "herwinkendem": "herwinkend",
    "herwinkenden": "herwinkend",
    "herwinkender": "herwinkend",
    "herwinkendes": "herwinkend",
    "herwinkest": "herwinken",
    "herwinket": "herwinken",
    "herwinkst": "herwinken",
    "herwinkt": "herwinken",
    "herwinkte": "herwinken",
    "herwinkten": "herwinken",
    "herwinktest": "herwinken",
    "herwinktet": "herwinken",
    "herwirfst": "herwerfen",
    "herwirft": "herwerfen",
    "herwärfe": "herwerfen",
    "herwärfen": "herwerfen",
    "herwärfest": "herwerfen",
    "herwärfet": "herwerfen",
    "herzallerliebe": "herzallerlieb",
    "herzallerliebem": "herzallerlieb",
    "herzallerlieben": "herzallerlieb",
    "herzallerlieber": "herzallerlieb",
    "herzallerliebes": "herzallerlieb",
    "herzaubere": "herzaubern",
    "herzaubernd": "herzaubern",
    "herzaubernde": "herzaubernd",
    "herzauberndem": "herzaubernd",
    "herzaubernden": "herzaubernd",
    "herzaubernder": "herzaubernd",
    "herzauberndes": "herzaubernd",
    "herzauberst": "herzaubern",
    "herzaubert": "herzaubern",
    "herzauberte": "herzaubern",
    "herzauberten": "herzaubern",
    "herzaubertest": "herzaubern",
    "herzaubertet": "herzaubern",
    "herzbeklemmende": "herzbeklemmend",
    "herzbeklemmendem": "herzbeklemmend",
    "herzbeklemmenden": "herzbeklemmend",
    "herzbeklemmender": "herzbeklemmend",
    "herzbeklemmendere": "herzbeklemmend",
    "herzbeklemmenderem": "herzbeklemmend",
    "herzbeklemmenderen": "herzbeklemmend",
    "herzbeklemmenderer": "herzbeklemmend",
    "herzbeklemmenderes": "herzbeklemmend",
    "herzbeklemmendes": "herzbeklemmend",
    "herzbeklemmendste": "herzbeklemmend",
    "herzbeklemmendstem": "herzbeklemmend",
    "herzbeklemmendsten": "herzbeklemmend",
    "herzbeklemmendster": "herzbeklemmend",
    "herzbeklemmendstes": "herzbeklemmend",
    "herze": "herzen",
    "herzeige": "herzeigen",
    "herzeigend": "herzeigen",
    "herzeigende": "herzeigend",
    "herzeigendem": "herzeigend",
    "herzeigenden": "herzeigend",
    "herzeigender": "herzeigend",
    "herzeigendes": "herzeigend",
    "herzeigest": "herzeigen",
    "herzeiget": "herzeigen",
    "herzeigst": "herzeigen",
    "herzeigt": "herzeigen",
    "herzeigte": "herzeigen",
    "herzeigten": "herzeigen",
    "herzeigtest": "herzeigen",
    "herzeigtet": "herzeigen",
    "herzend": "herzen",
    "herzende": "herzend",
    "herzendem": "herzend",
    "herzenden": "herzend",
    "herzender": "herzend",
    "herzendere": "herzend",
    "herzenderem": "herzend",
    "herzenderen": "herzend",
    "herzenderer": "herzend",
    "herzenderes": "herzend",
    "herzendes": "herzend",
    "herzendste": "herzend",
    "herzendstem": "herzend",
    "herzendsten": "herzend",
    "herzendster": "herzend",
    "herzendstes": "herzend",
    "herzensgutem": "herzensgut",
    "herzensguten": "herzensgut",
    "herzensguter": "herzensgut",
    "herzensgutes": "herzensgut",
    "herzerfrischende": "herzerfrischend",
    "herzerfrischendem": "herzerfrischend",
    "herzerfrischenden": "herzerfrischend",
    "herzerfrischender": "herzerfrischend",
    "herzerfrischendere": "herzerfrischend",
    "herzerfrischenderem": "herzerfrischend",
    "herzerfrischenderen": "herzerfrischend",
    "herzerfrischenderer": "herzerfrischend",
    "herzerfrischenderes": "herzerfrischend",
    "herzerfrischendes": "herzerfrischend",
    "herzerfrischendste": "herzerfrischend",
    "herzerfrischendstem": "herzerfrischend",
    "herzerfrischendsten": "herzerfrischend",
    "herzerfrischendster": "herzerfrischend",
    "herzerfrischendstes": "herzerfrischend",
    "herzergreifende": "herzergreifend",
    "herzergreifendem": "herzergreifend",
    "herzergreifenden": "herzergreifend",
    "herzergreifender": "herzergreifend",
    "herzergreifendere": "herzergreifend",
    "herzergreifenderem": "herzergreifend",
    "herzergreifenderen": "herzergreifend",
    "herzergreifenderer": "herzergreifend",
    "herzergreifenderes": "herzergreifend",
    "herzergreifendes": "herzergreifend",
    "herzergreifendste": "herzergreifend",
    "herzergreifendstem": "herzergreifend",
    "herzergreifendsten": "herzergreifend",
    "herzergreifendster": "herzergreifend",
    "herzergreifendstes": "herzergreifend",
    "herzest": "herzen",
    "herzet": "herzen",
    "herzhafte": "herzhaft",
    "herzhaftem": "herzhaft",
    "herzhaften": "herzhaft",
    "herzhafter": "herzhaft",
    "herzhaftere": "herzhaft",
    "herzhafterem": "herzhaft",
    "herzhafteren": "herzhaft",
    "herzhafterer": "herzhaft",
    "herzhafteres": "herzhaft",
    "herzhaftes": "herzhaft",
    "herzhafteste": "herzhaft",
    "herzhaftestem": "herzhaft",
    "herzhaftesten": "herzhaft",
    "herzhaftester": "herzhaft",
    "herzhaftestes": "herzhaft",
    "herziehe": "herziehen",
    "herziehend": "herziehen",
    "herziehende": "herziehend",
    "herziehendem": "herziehend",
    "herziehenden": "herziehend",
    "herziehender": "herziehend",
    "herziehendes": "herziehend",
    "herziehest": "herziehen",
    "herziehet": "herziehen",
    "herziehst": "herziehen",
    "herzieht": "herziehen",
    "herzliche": "herzlich",
    "herzlichem": "herzlich",
    "herzlichen": "herzlich",
    "herzlicher": "herzlich",
    "herzlichere": "herzlich",
    "herzlicherem": "herzlich",
    "herzlicheren": "herzlich",
    "herzlicherer": "herzlich",
    "herzlicheres": "herzlich",
    "herzliches": "herzlich",
    "herzlichste": "herzlich",
    "herzlichstem": "herzlich",
    "herzlichsten": "herzlich",
    "herzlichster": "herzlich",
    "herzlichstes": "herzlich",
    "herzlose": "herzlos",
    "herzlosem": "herzlos",
    "herzlosen": "herzlos",
    "herzloser": "herzlos",
    "herzlosere": "herzlos",
    "herzloserem": "herzlos",
    "herzloseren": "herzlos",
    "herzloserer": "herzlos",
    "herzloseres": "herzlos",
    "herzloses": "herzlos",
    "herzloseste": "herzlos",
    "herzlosestem": "herzlos",
    "herzlosesten": "herzlos",
    "herzlosester": "herzlos",
    "herzlosestes": "herzlos",
    "herzog": "herziehen",
    "herzogen": "herziehen",
    "herzogst": "herziehen",
    "herzogt": "herziehen",
    "herzt": "herzen",
    "herzte": "herzen",
    "herzten": "herzen",
    "herztest": "herzen",
    "herztet": "herzen",
    "herzubegleiten": "herbegleiten",
    "herzubekommen": "herbekommen",
    "herzubemühen": "herbemühen",
    "herzubeordern": "herbeordern",
    "herzubequemen": "herbequemen",
    "herzubestellen": "herbestellen",
    "herzubeten": "herbeten",
    "herzubitten": "herbitten",
    "herzubringen": "herbringen",
    "herzudenken": "herdenken",
    "herzueile": "herzueilen",
    "herzueilend": "herzueilen",
    "herzueilende": "herzueilend",
    "herzueilendem": "herzueilend",
    "herzueilenden": "herzueilend",
    "herzueilender": "herzueilend",
    "herzueilendes": "herzueilend",
    "herzueilest": "herzueilen",
    "herzueilet": "herzueilen",
    "herzueilst": "herzueilen",
    "herzueilt": "herzueilen",
    "herzueilte": "herzueilen",
    "herzueilten": "herzueilen",
    "herzueiltest": "herzueilen",
    "herzueiltet": "herzueilen",
    "herzufallen": "herfallen",
    "herzufinden": "herfinden",
    "herzufliegen": "herfliegen",
    "herzuführen": "herführen",
    "herzugeben": "hergeben",
    "herzugeeilt": "herzueilen",
    "herzugeeilte": "herzugeeilt",
    "herzugeeiltem": "herzugeeilt",
    "herzugeeilten": "herzugeeilt",
    "herzugeeilter": "herzugeeilt",
    "herzugeeiltes": "herzugeeilt",
    "herzuhalten": "herhalten",
    "herzuholen": "herholen",
    "herzuhören": "herhören",
    "herzujagen": "herjagen",
    "herzukommen": "herkommen",
    "herzukriegen": "herkriegen",
    "herzulangen": "herlangen",
    "herzulaufen": "herlaufen",
    "herzulegen": "herlegen",
    "herzuleiern": "herleiern",
    "herzuleihen": "herleihen",
    "herzuleiten": "herleiten",
    "herzumachen": "hermachen",
    "herzunehmen": "hernehmen",
    "herzureichen": "herreichen",
    "herzurichten": "herrichten",
    "herzurufen": "herrufen",
    "herzurücken": "herrücken",
    "herzurühren": "herrühren",
    "herzusagen": "hersagen",
    "herzuschaffen": "herschaffen",
    "herzuschauen": "herschauen",
    "herzuschieben": "herschieben",
    "herzuschleppen": "herschleppen",
    "herzusehen": "hersehen",
    "herzusehnen": "hersehnen",
    "herzusetzen": "hersetzen",
    "herzuspringen": "herspringen",
    "herzustammen": "herstammen",
    "herzustellen": "herstellen",
    "herzutragen": "hertragen",
    "herzutreiben": "hertreiben",
    "herzuwerfen": "herwerfen",
    "herzuwinken": "herwinken",
    "herzuzaubern": "herzaubern",
    "herzuzeigen": "herzeigen",
    "herzuziehen": "herziehen",
    "herzuzueilen": "herzueilen",
    "herzuzählen": "herzählen",
    "herzzerreißende": "herzzerreißend",
    "herzzerreißendem": "herzzerreißend",
    "herzzerreißenden": "herzzerreißend",
    "herzzerreißender": "herzzerreißend",
    "herzzerreißendere": "herzzerreißend",
    "herzzerreißenderem": "herzzerreißend",
    "herzzerreißenderen": "herzzerreißend",
    "herzzerreißenderer": "herzzerreißend",
    "herzzerreißenderes": "herzzerreißend",
    "herzzerreißendes": "herzzerreißend",
    "herzzerreißendste": "herzzerreißend",
    "herzzerreißendstem": "herzzerreißend",
    "herzzerreißendsten": "herzzerreißend",
    "herzzerreißendster": "herzzerreißend",
    "herzzerreißendstes": "herzzerreißend",
    "herzähle": "herzählen",
    "herzählend": "herzählen",
    "herzählende": "herzählend",
    "herzählendem": "herzählend",
    "herzählenden": "herzählend",
    "herzählender": "herzählend",
    "herzählendes": "herzählend",
    "herzählest": "herzählen",
    "herzählet": "herzählen",
    "herzählst": "herzählen",
    "herzählt": "herzählen",
    "herzählte": "herzählen",
    "herzählten": "herzählen",
    "herzähltest": "herzählen",
    "herzähltet": "herzählen",
    "herzöge": "herziehen",
    "herzögen": "herziehen",
    "herzögest": "herziehen",
    "herzöget": "herziehen",
    "herüberbemühe": "herüberbemühen",
    "herüberbemühend": "herüberbemühen",
    "herüberbemühende": "herüberbemühend",
    "herüberbemühendem": "herüberbemühend",
    "herüberbemühenden": "herüberbemühend",
    "herüberbemühender": "herüberbemühend",
    "herüberbemühendes": "herüberbemühend",
    "herüberbemühest": "herüberbemühen",
    "herüberbemühet": "herüberbemühen",
    "herüberbemühst": "herüberbemühen",
    "herüberbemüht": "herüberbemühen",
    "herüberbemühte": "herüberbemühen",
    "herüberbemühtem": "herüberbemüht",
    "herüberbemühten": "herüberbemühen",
    "herüberbemühter": "herüberbemüht",
    "herüberbemühtes": "herüberbemüht",
    "herüberbemühtest": "herüberbemühen",
    "herüberbemühtet": "herüberbemühen",
    "herüberführe": "herüberführen",
    "herüberführend": "herüberführen",
    "herüberführende": "herüberführend",
    "herüberführendem": "herüberführend",
    "herüberführenden": "herüberführend",
    "herüberführender": "herüberführend",
    "herüberführendes": "herüberführend",
    "herüberführest": "herüberführen",
    "herüberführet": "herüberführen",
    "herüberführst": "herüberführen",
    "herüberführt": "herüberführen",
    "herüberführte": "herüberführen",
    "herüberführten": "herüberführen",
    "herüberführtest": "herüberführen",
    "herüberführtet": "herüberführen",
    "herübergeführt": "herüberführen",
    "herübergeführte": "herübergeführt",
    "herübergeführtem": "herübergeführt",
    "herübergeführten": "herübergeführt",
    "herübergeführter": "herübergeführt",
    "herübergeführtes": "herübergeführt",
    "herübergelangt": "herüberlangen",
    "herübergelangte": "herübergelangt",
    "herübergelangtem": "herübergelangt",
    "herübergelangten": "herübergelangt",
    "herübergelangter": "herübergelangt",
    "herübergelangtes": "herübergelangt",
    "herübergereicht": "herüberreichen",
    "herübergereichte": "herübergereicht",
    "herübergereichtem": "herübergereicht",
    "herübergereichten": "herübergereicht",
    "herübergereichter": "herübergereicht",
    "herübergereichtes": "herübergereicht",
    "herübergerückt": "herüberrücken",
    "herübergerückte": "herübergerückt",
    "herübergerücktem": "herübergerückt",
    "herübergerückten": "herübergerückt",
    "herübergerückter": "herübergerückt",
    "herübergerücktes": "herübergerückt",
    "herübergetragen": "herübertragen",
    "herübergetragene": "herübergetragen",
    "herübergetragenem": "herübergetragen",
    "herübergetragenen": "herübergetragen",
    "herübergetragener": "herübergetragen",
    "herübergetragenes": "herübergetragen",
    "herübergezogen": "herüberziehen",
    "herübergezogene": "herübergezogen",
    "herübergezogenem": "herübergezogen",
    "herübergezogenen": "herübergezogen",
    "herübergezogener": "herübergezogen",
    "herübergezogenes": "herübergezogen",
    "herüberlange": "herüberlangen",
    "herüberlangend": "herüberlangen",
    "herüberlangende": "herüberlangend",
    "herüberlangendem": "herüberlangend",
    "herüberlangenden": "herüberlangend",
    "herüberlangender": "herüberlangend",
    "herüberlangendes": "herüberlangend",
    "herüberlangest": "herüberlangen",
    "herüberlanget": "herüberlangen",
    "herüberlangst": "herüberlangen",
    "herüberlangt": "herüberlangen",
    "herüberlangte": "herüberlangen",
    "herüberlangten": "herüberlangen",
    "herüberlangtest": "herüberlangen",
    "herüberlangtet": "herüberlangen",
    "herüberreiche": "herüberreichen",
    "herüberreichend": "herüberreichen",
    "herüberreichende": "herüberreichend",
    "herüberreichendem": "herüberreichend",
    "herüberreichenden": "herüberreichend",
    "herüberreichender": "herüberreichend",
    "herüberreichendes": "herüberreichend",
    "herüberreichest": "herüberreichen",
    "herüberreichet": "herüberreichen",
    "herüberreichst": "herüberreichen",
    "herüberreicht": "herüberreichen",
    "herüberreichte": "herüberreichen",
    "herüberreichten": "herüberreichen",
    "herüberreichtest": "herüberreichen",
    "herüberreichtet": "herüberreichen",
    "herüberrücke": "herüberrücken",
    "herüberrückend": "herüberrücken",
    "herüberrückende": "herüberrückend",
    "herüberrückendem": "herüberrückend",
    "herüberrückenden": "herüberrückend",
    "herüberrückender": "herüberrückend",
    "herüberrückendes": "herüberrückend",
    "herüberrückest": "herüberrücken",
    "herüberrücket": "herüberrücken",
    "herüberrückst": "herüberrücken",
    "herüberrückt": "herüberrücken",
    "herüberrückte": "herüberrücken",
    "herüberrückten": "herüberrücken",
    "herüberrücktest": "herüberrücken",
    "herüberrücktet": "herüberrücken",
    "herübertrage": "herübertragen",
    "herübertragend": "herübertragen",
    "herübertragende": "herübertragend",
    "herübertragendem": "herübertragend",
    "herübertragenden": "herübertragend",
    "herübertragender": "herübertragend",
    "herübertragendes": "herübertragend",
    "herübertragest": "herübertragen",
    "herübertraget": "herübertragen",
    "herübertragt": "herübertragen",
    "herübertrug": "herübertragen",
    "herübertrugen": "herübertragen",
    "herübertrugst": "herübertragen",
    "herübertrugt": "herübertragen",
    "herüberträgst": "herübertragen",
    "herüberträgt": "herübertragen",
    "herübertrüge": "herübertragen",
    "herübertrügen": "herübertragen",
    "herübertrügest": "herübertragen",
    "herübertrüget": "herübertragen",
    "herüberziehe": "herüberziehen",
    "herüberziehend": "herüberziehen",
    "herüberziehende": "herüberziehend",
    "herüberziehendem": "herüberziehend",
    "herüberziehenden": "herüberziehend",
    "herüberziehender": "herüberziehend",
    "herüberziehendes": "herüberziehend",
    "herüberziehest": "herüberziehen",
    "herüberziehet": "herüberziehen",
    "herüberziehst": "herüberziehen",
    "herüberzieht": "herüberziehen",
    "herüberzog": "herüberziehen",
    "herüberzogen": "herüberziehen",
    "herüberzogst": "herüberziehen",
    "herüberzogt": "herüberziehen",
    "herüberzubemühen": "herüberbemühen",
    "herüberzuführen": "herüberführen",
    "herüberzulangen": "herüberlangen",
    "herüberzureichen": "herüberreichen",
    "herüberzurücken": "herüberrücken",
    "herüberzutragen": "herübertragen",
    "herüberzuziehen": "herüberziehen",
    "herüberzöge": "herüberziehen",
    "herüberzögen": "herüberziehen",
    "herüberzögest": "herüberziehen",
    "herüberzöget": "herüberziehen",
    "hessischem": "hessisch",
    "hessischen": "hessisch",
    "hessischer": "hessisch",
    "hessischere": "hessisch",
    "hessischerem": "hessisch",
    "hessischeren": "hessisch",
    "hessischerer": "hessisch",
    "hessischeres": "hessisch",
    "hessisches": "hessisch",
    "hessischste": "hessisch",
    "hessischstem": "hessisch",
    "hessischsten": "hessisch",
    "hessischster": "hessisch",
    "hessischstes": "hessisch",
    "heterogene": "heterogen",
    "heterogenem": "heterogen",
    "heterogenen": "heterogen",
    "heterogener": "heterogen",
    "heterogenere": "heterogen",
    "heterogenerem": "heterogen",
    "heterogeneren": "heterogen",
    "heterogenerer": "heterogen",
    "heterogeneres": "heterogen",
    "heterogenes": "heterogen",
    "heterogenste": "heterogen",
    "heterogenstem": "heterogen",
    "heterogensten": "heterogen",
    "heterogenster": "heterogen",
    "heterogenstes": "heterogen",
    "hetze": "hetzen",
    "hetzend": "hetzen",
    "hetzende": "hetzend",
    "hetzendem": "hetzend",
    "hetzenden": "hetzend",
    "hetzender": "hetzend",
    "hetzendere": "hetzend",
    "hetzenderem": "hetzend",
    "hetzenderen": "hetzend",
    "hetzenderer": "hetzend",
    "hetzenderes": "hetzend",
    "hetzendes": "hetzend",
    "hetzendste": "hetzend",
    "hetzendstem": "hetzend",
    "hetzendsten": "hetzend",
    "hetzendster": "hetzend",
    "hetzendstes": "hetzend",
    "hetzerischem": "hetzerisch",
    "hetzerischen": "hetzerisch",
    "hetzerischer": "hetzerisch",
    "hetzerischere": "hetzerisch",
    "hetzerischerem": "hetzerisch",
    "hetzerischeren": "hetzerisch",
    "hetzerischerer": "hetzerisch",
    "hetzerischeres": "hetzerisch",
    "hetzerisches": "hetzerisch",
    "hetzerischste": "hetzerisch",
    "hetzerischstem": "hetzerisch",
    "hetzerischsten": "hetzerisch",
    "hetzerischster": "hetzerisch",
    "hetzerischstes": "hetzerisch",
    "hetzest": "hetzen",
    "hetzet": "hetzen",
    "hetzt": "hetzen",
    "hetzte": "hetzen",
    "hetzten": "hetzen",
    "hetztest": "hetzen",
    "hetztet": "hetzen",
    "heuchele": "heucheln",
    "heuchelnd": "heucheln",
    "heuchelnde": "heuchelnd",
    "heuchelndem": "heuchelnd",
    "heuchelnden": "heuchelnd",
    "heuchelnder": "heuchelnd",
    "heuchelndere": "heuchelnd",
    "heuchelnderem": "heuchelnd",
    "heuchelnderen": "heuchelnd",
    "heuchelnderer": "heuchelnd",
    "heuchelnderes": "heuchelnd",
    "heuchelndes": "heuchelnd",
    "heuchelndste": "heuchelnd",
    "heuchelndstem": "heuchelnd",
    "heuchelndsten": "heuchelnd",
    "heuchelndster": "heuchelnd",
    "heuchelndstes": "heuchelnd",
    "heuchelst": "heucheln",
    "heuchelt": "heucheln",
    "heuchelte": "heucheln",
    "heuchelten": "heucheln",
    "heucheltest": "heucheln",
    "heucheltet": "heucheln",
    "heuchle": "heucheln",
    "heuchlerische": "heuchlerisch",
    "heuchlerischem": "heuchlerisch",
    "heuchlerischen": "heuchlerisch",
    "heuchlerischer": "heuchlerisch",
    "heuchlerischere": "heuchlerisch",
    "heuchlerischerem": "heuchlerisch",
    "heuchlerischeren": "heuchlerisch",
    "heuchlerischerer": "heuchlerisch",
    "heuchlerischeres": "heuchlerisch",
    "heuchlerisches": "heuchlerisch",
    "heuchlerischste": "heuchlerisch",
    "heuchlerischstem": "heuchlerisch",
    "heuchlerischsten": "heuchlerisch",
    "heuchlerischster": "heuchlerisch",
    "heuchlerischstes": "heuchlerisch",
    "heuere": "heuern",
    "heuernd": "heuern",
    "heuernde": "heuernd",
    "heuerndem": "heuernd",
    "heuernden": "heuernd",
    "heuernder": "heuernd",
    "heuerndes": "heuernd",
    "heuerst": "heuern",
    "heuert": "heuern",
    "heuerte": "heuern",
    "heuerten": "heuern",
    "heuertest": "heuern",
    "heuertet": "heuern",
    "heule": "heulen",
    "heulend": "heulen",
    "heulende": "heulend",
    "heulendem": "heulend",
    "heulenden": "heulend",
    "heulender": "heulend",
    "heulendere": "heulend",
    "heulenderem": "heulend",
    "heulenderen": "heulend",
    "heulenderer": "heulend",
    "heulenderes": "heulend",
    "heulendes": "heulend",
    "heulendste": "heulend",
    "heulendstem": "heulend",
    "heulendsten": "heulend",
    "heulendster": "heulend",
    "heulendstes": "heulend",
    "heulest": "heulen",
    "heulet": "heulen",
    "heulst": "heulen",
    "heult": "heulen",
    "heulte": "heulen",
    "heulten": "heulen",
    "heultest": "heulen",
    "heultet": "heulen",
    "heuristische": "heuristisch",
    "heuristischem": "heuristisch",
    "heuristischen": "heuristisch",
    "heuristischer": "heuristisch",
    "heuristisches": "heuristisch",
    "heutigem": "heutig",
    "heutigen": "heutig",
    "heutiger": "heutig",
    "heutiges": "heutig",
    "hexend": "hexen",
    "hexende": "hexend",
    "hexendem": "hexend",
    "hexenden": "hexend",
    "hexender": "hexend",
    "hexendere": "hexend",
    "hexenderem": "hexend",
    "hexenderen": "hexend",
    "hexenderer": "hexend",
    "hexenderes": "hexend",
    "hexendes": "hexend",
    "hexendste": "hexend",
    "hexendstem": "hexend",
    "hexendsten": "hexend",
    "hexendster": "hexend",
    "hexendstes": "hexend",
    "hexest": "hexen",
    "hexet": "hexen",
    "hext": "hexen",
    "hexte": "hexen",
    "hexten": "hexen",
    "hextest": "hexen",
    "hextet": "hexen",
    "hiebfestem": "hiebfest",
    "hiebfesten": "hiebfest",
    "hiebfester": "hiebfest",
    "hiebfestere": "hiebfest",
    "hiebfesterem": "hiebfest",
    "hiebfesteren": "hiebfest",
    "hiebfesterer": "hiebfest",
    "hiebfesteres": "hiebfest",
    "hiebfestes": "hiebfest",
    "hiebfesteste": "hiebfest",
    "hiebfestestem": "hiebfest",
    "hiebfestesten": "hiebfest",
    "hiebfestester": "hiebfest",
    "hiebfestestes": "hiebfest",
    "hielt": "halten",
    "hielte": "halten",
    "hielten": "halten",
    "hieltest": "halten",
    "hieltet": "halten",
    "hierbehalte": "hierbehalten",
    "hierbehaltend": "hierbehalten",
    "hierbehaltende": "hierbehaltend",
    "hierbehaltendem": "hierbehaltend",
    "hierbehaltenden": "hierbehaltend",
    "hierbehaltender": "hierbehaltend",
    "hierbehaltendes": "hierbehaltend",
    "hierbehaltene": "hierbehalten",
    "hierbehaltenem": "hierbehalten",
    "hierbehaltenen": "hierbehalten",
    "hierbehaltener": "hierbehalten",
    "hierbehaltenes": "hierbehalten",
    "hierbehaltest": "hierbehalten",
    "hierbehaltet": "hierbehalten",
    "hierbehielt": "hierbehalten",
    "hierbehielte": "hierbehalten",
    "hierbehielten": "hierbehalten",
    "hierbehieltest": "hierbehalten",
    "hierbehieltet": "hierbehalten",
    "hierbehält": "hierbehalten",
    "hierbehältst": "hierbehalten",
    "hierbleibe": "hierbleiben",
    "hierbleibend": "hierbleiben",
    "hierbleibende": "hierbleibend",
    "hierbleibendem": "hierbleibend",
    "hierbleibenden": "hierbleibend",
    "hierbleibender": "hierbleibend",
    "hierbleibendes": "hierbleibend",
    "hierbleibest": "hierbleiben",
    "hierbleibet": "hierbleiben",
    "hierbleibst": "hierbleiben",
    "hierbleibt": "hierbleiben",
    "hierblieb": "hierbleiben",
    "hierbliebe": "hierbleiben",
    "hierblieben": "hierbleiben",
    "hierbliebest": "hierbleiben",
    "hierbliebet": "hierbleiben",
    "hierbliebst": "hierbleiben",
    "hierbliebt": "hierbleiben",
    "hiergeblieben": "hierbleiben",
    "hiergebliebene": "hiergeblieben",
    "hiergebliebenem": "hiergeblieben",
    "hiergebliebenen": "hiergeblieben",
    "hiergebliebener": "hiergeblieben",
    "hiergebliebenes": "hiergeblieben",
    "hierherbat": "hierherbitten",
    "hierherbaten": "hierherbitten",
    "hierherbatest": "hierherbitten",
    "hierherbatet": "hierherbitten",
    "hierherbemühe": "hierherbemühen",
    "hierherbemühend": "hierherbemühen",
    "hierherbemühende": "hierherbemühend",
    "hierherbemühendem": "hierherbemühend",
    "hierherbemühenden": "hierherbemühend",
    "hierherbemühender": "hierherbemühend",
    "hierherbemühendes": "hierherbemühend",
    "hierherbemühest": "hierherbemühen",
    "hierherbemühet": "hierherbemühen",
    "hierherbemühst": "hierherbemühen",
    "hierherbemüht": "hierherbemühen",
    "hierherbemühte": "hierherbemühen",
    "hierherbemühtem": "hierherbemüht",
    "hierherbemühten": "hierherbemühen",
    "hierherbemühter": "hierherbemüht",
    "hierherbemühtes": "hierherbemüht",
    "hierherbemühtest": "hierherbemühen",
    "hierherbemühtet": "hierherbemühen",
    "hierherbitte": "hierherbitten",
    "hierherbittend": "hierherbitten",
    "hierherbittende": "hierherbittend",
    "hierherbittendem": "hierherbittend",
    "hierherbittenden": "hierherbittend",
    "hierherbittender": "hierherbittend",
    "hierherbittendes": "hierherbittend",
    "hierherbittest": "hierherbitten",
    "hierherbittet": "hierherbitten",
    "hierherbrachte": "hierherbringen",
    "hierherbrachten": "hierherbringen",
    "hierherbrachtest": "hierherbringen",
    "hierherbrachtet": "hierherbringen",
    "hierherbringe": "hierherbringen",
    "hierherbringend": "hierherbringen",
    "hierherbringende": "hierherbringend",
    "hierherbringendem": "hierherbringend",
    "hierherbringenden": "hierherbringend",
    "hierherbringender": "hierherbringend",
    "hierherbringendes": "hierherbringend",
    "hierherbringest": "hierherbringen",
    "hierherbringet": "hierherbringen",
    "hierherbringst": "hierherbringen",
    "hierherbringt": "hierherbringen",
    "hierherbrächte": "hierherbringen",
    "hierherbrächten": "hierherbringen",
    "hierherbrächtest": "hierherbringen",
    "hierherbrächtet": "hierherbringen",
    "hierherbäte": "hierherbitten",
    "hierherbäten": "hierherbitten",
    "hierherbätest": "hierherbitten",
    "hierherbätet": "hierherbitten",
    "hierhereile": "hierhereilen",
    "hierhereilend": "hierhereilen",
    "hierhereilende": "hierhereilend",
    "hierhereilendem": "hierhereilend",
    "hierhereilenden": "hierhereilend",
    "hierhereilender": "hierhereilend",
    "hierhereilendes": "hierhereilend",
    "hierhereilest": "hierhereilen",
    "hierhereilet": "hierhereilen",
    "hierhereilst": "hierhereilen",
    "hierhereilt": "hierhereilen",
    "hierhereilte": "hierhereilen",
    "hierhereilten": "hierhereilen",
    "hierhereiltest": "hierhereilen",
    "hierhereiltet": "hierhereilen",
    "hierherführe": "hierherführen",
    "hierherführend": "hierherführen",
    "hierherführende": "hierherführend",
    "hierherführendem": "hierherführend",
    "hierherführenden": "hierherführend",
    "hierherführender": "hierherführend",
    "hierherführendes": "hierherführend",
    "hierherführest": "hierherführen",
    "hierherführet": "hierherführen",
    "hierherführst": "hierherführen",
    "hierherführt": "hierherführen",
    "hierherführte": "hierherführen",
    "hierherführten": "hierherführen",
    "hierherführtest": "hierherführen",
    "hierherführtet": "hierherführen",
    "hierhergebeten": "hierherbitten",
    "hierhergebetene": "hierhergebeten",
    "hierhergebetenem": "hierhergebeten",
    "hierhergebetenen": "hierhergebeten",
    "hierhergebetener": "hierhergebeten",
    "hierhergebetenes": "hierhergebeten",
    "hierhergebracht": "hierherbringen",
    "hierhergebrachte": "hierhergebracht",
    "hierhergebrachtem": "hierhergebracht",
    "hierhergebrachten": "hierhergebracht",
    "hierhergebrachter": "hierhergebracht",
    "hierhergebrachtes": "hierhergebracht",
    "hierhergeeilt": "hierhereilen",
    "hierhergeeilte": "hierhergeeilt",
    "hierhergeeiltem": "hierhergeeilt",
    "hierhergeeilten": "hierhergeeilt",
    "hierhergeeilter": "hierhergeeilt",
    "hierhergeeiltes": "hierhergeeilt",
    "hierhergeführt": "hierherführen",
    "hierhergeführte": "hierhergeführt",
    "hierhergeführtem": "hierhergeführt",
    "hierhergeführten": "hierhergeführt",
    "hierhergeführter": "hierhergeführt",
    "hierhergeführtes": "hierhergeführt",
    "hierhergeholt": "hierherholen",
    "hierhergeholte": "hierhergeholt",
    "hierhergeholtem": "hierhergeholt",
    "hierhergeholten": "hierhergeholt",
    "hierhergeholter": "hierhergeholt",
    "hierhergeholtes": "hierhergeholt",
    "hierhergehöre": "hierhergehören",
    "hierhergehörend": "hierhergehören",
    "hierhergehörende": "hierhergehörend",
    "hierhergehörendem": "hierhergehörend",
    "hierhergehörenden": "hierhergehörend",
    "hierhergehörender": "hierhergehörend",
    "hierhergehörendes": "hierhergehörend",
    "hierhergehörest": "hierhergehören",
    "hierhergehöret": "hierhergehören",
    "hierhergehörst": "hierhergehören",
    "hierhergehört": "hierhergehören",
    "hierhergehörte": "hierhergehören",
    "hierhergehörtem": "hierhergehört",
    "hierhergehörten": "hierhergehören",
    "hierhergehörter": "hierhergehört",
    "hierhergehörtes": "hierhergehört",
    "hierhergehörtest": "hierhergehören",
    "hierhergehörtet": "hierhergehören",
    "hierhergekommen": "hierherkommen",
    "hierhergekommene": "hierhergekommen",
    "hierhergekommenem": "hierhergekommen",
    "hierhergekommenen": "hierhergekommen",
    "hierhergekommener": "hierhergekommen",
    "hierhergekommenes": "hierhergekommen",
    "hierhergelegt": "hierherlegen",
    "hierhergelegte": "hierhergelegt",
    "hierhergelegtem": "hierhergelegt",
    "hierhergelegten": "hierhergelegt",
    "hierhergelegter": "hierhergelegt",
    "hierhergelegtes": "hierhergelegt",
    "hierhergereist": "hierherreisen",
    "hierhergereiste": "hierhergereist",
    "hierhergereistem": "hierhergereist",
    "hierhergereisten": "hierhergereist",
    "hierhergereister": "hierhergereist",
    "hierhergereistes": "hierhergereist",
    "hierhergeschaffen": "hierherschaffen",
    "hierhergeschaffene": "hierhergeschaffen",
    "hierhergeschaffenem": "hierhergeschaffen",
    "hierhergeschaffenen": "hierhergeschaffen",
    "hierhergeschaffener": "hierhergeschaffen",
    "hierhergeschaffenes": "hierhergeschaffen",
    "hierhergeschafft": "hierherschaffen",
    "hierhergeschaffte": "hierhergeschafft",
    "hierhergeschafftem": "hierhergeschafft",
    "hierhergeschafften": "hierhergeschafft",
    "hierhergeschaffter": "hierhergeschafft",
    "hierhergeschafftes": "hierhergeschafft",
    "hierhergeschaut": "hierherschauen",
    "hierhergeschaute": "hierhergeschaut",
    "hierhergeschautem": "hierhergeschaut",
    "hierhergeschauten": "hierhergeschaut",
    "hierhergeschauter": "hierhergeschaut",
    "hierhergeschautes": "hierhergeschaut",
    "hierhergeschleppt": "hierherschleppen",
    "hierhergeschleppte": "hierhergeschleppt",
    "hierhergeschlepptem": "hierhergeschleppt",
    "hierhergeschleppten": "hierhergeschleppt",
    "hierhergeschleppter": "hierhergeschleppt",
    "hierhergeschlepptes": "hierhergeschleppt",
    "hierhergeschoben": "hierherschieben",
    "hierhergeschobene": "hierhergeschoben",
    "hierhergeschobenem": "hierhergeschoben",
    "hierhergeschobenen": "hierhergeschoben",
    "hierhergeschobener": "hierhergeschoben",
    "hierhergeschobenes": "hierhergeschoben",
    "hierhergesetzt": "hierhersetzen",
    "hierhergesetzte": "hierhergesetzt",
    "hierhergesetztem": "hierhergesetzt",
    "hierhergesetzten": "hierhergesetzt",
    "hierhergesetzter": "hierhergesetzt",
    "hierhergesetztes": "hierhergesetzt",
    "hierhergestellt": "hierherstellen",
    "hierhergestellte": "hierhergestellt",
    "hierhergestelltem": "hierhergestellt",
    "hierhergestellten": "hierhergestellt",
    "hierhergestellter": "hierhergestellt",
    "hierhergestelltes": "hierhergestellt",
    "hierhergetragen": "hierhertragen",
    "hierhergetragene": "hierhergetragen",
    "hierhergetragenem": "hierhergetragen",
    "hierhergetragenen": "hierhergetragen",
    "hierhergetragener": "hierhergetragen",
    "hierhergetragenes": "hierhergetragen",
    "hierhergetrieben": "hierhertreiben",
    "hierhergetriebene": "hierhergetrieben",
    "hierhergetriebenem": "hierhergetrieben",
    "hierhergetriebenen": "hierhergetrieben",
    "hierhergetriebener": "hierhergetrieben",
    "hierhergetriebenes": "hierhergetrieben",
    "hierhergewagt": "hierherwagen",
    "hierhergewagte": "hierhergewagt",
    "hierhergewagtem": "hierhergewagt",
    "hierhergewagten": "hierhergewagt",
    "hierhergewagter": "hierhergewagt",
    "hierhergewagtes": "hierhergewagt",
    "hierherhole": "hierherholen",
    "hierherholend": "hierherholen",
    "hierherholende": "hierherholend",
    "hierherholendem": "hierherholend",
    "hierherholenden": "hierherholend",
    "hierherholender": "hierherholend",
    "hierherholendes": "hierherholend",
    "hierherholest": "hierherholen",
    "hierherholet": "hierherholen",
    "hierherholst": "hierherholen",
    "hierherholt": "hierherholen",
    "hierherholte": "hierherholen",
    "hierherholten": "hierherholen",
    "hierherholtest": "hierherholen",
    "hierherholtet": "hierherholen",
    "hierherkam": "hierherkommen",
    "hierherkamen": "hierherkommen",
    "hierherkamst": "hierherkommen",
    "hierherkamt": "hierherkommen",
    "hierherkomme": "hierherkommen",
    "hierherkommend": "hierherkommen",
    "hierherkommende": "hierherkommend",
    "hierherkommendem": "hierherkommend",
    "hierherkommenden": "hierherkommend",
    "hierherkommender": "hierherkommend",
    "hierherkommendes": "hierherkommend",
    "hierherkommest": "hierherkommen",
    "hierherkommet": "hierherkommen",
    "hierherkommst": "hierherkommen",
    "hierherkommt": "hierherkommen",
    "hierherkäme": "hierherkommen",
    "hierherkämen": "hierherkommen",
    "hierherkämest": "hierherkommen",
    "hierherkämet": "hierherkommen",
    "hierherlege": "hierherlegen",
    "hierherlegend": "hierherlegen",
    "hierherlegende": "hierherlegend",
    "hierherlegendem": "hierherlegend",
    "hierherlegenden": "hierherlegend",
    "hierherlegender": "hierherlegend",
    "hierherlegendes": "hierherlegend",
    "hierherlegest": "hierherlegen",
    "hierherleget": "hierherlegen",
    "hierherlegst": "hierherlegen",
    "hierherlegt": "hierherlegen",
    "hierherlegte": "hierherlegen",
    "hierherlegten": "hierherlegen",
    "hierherlegtest": "hierherlegen",
    "hierherlegtet": "hierherlegen",
    "hierherreise": "hierherreisen",
    "hierherreisend": "hierherreisen",
    "hierherreisende": "hierherreisend",
    "hierherreisendem": "hierherreisend",
    "hierherreisenden": "hierherreisend",
    "hierherreisender": "hierherreisend",
    "hierherreisendes": "hierherreisend",
    "hierherreisest": "hierherreisen",
    "hierherreiset": "hierherreisen",
    "hierherreist": "hierherreisen",
    "hierherreiste": "hierherreisen",
    "hierherreisten": "hierherreisen",
    "hierherreistest": "hierherreisen",
    "hierherreistet": "hierherreisen",
    "hierherschaffe": "hierherschaffen",
    "hierherschaffend": "hierherschaffen",
    "hierherschaffende": "hierherschaffend",
    "hierherschaffendem": "hierherschaffend",
    "hierherschaffenden": "hierherschaffend",
    "hierherschaffender": "hierherschaffend",
    "hierherschaffendes": "hierherschaffend",
    "hierherschaffest": "hierherschaffen",
    "hierherschaffet": "hierherschaffen",
    "hierherschaffst": "hierherschaffen",
    "hierherschafft": "hierherschaffen",
    "hierherschaffte": "hierherschaffen",
    "hierherschafften": "hierherschaffen",
    "hierherschafftest": "hierherschaffen",
    "hierherschafftet": "hierherschaffen",
    "hierherschaue": "hierherschauen",
    "hierherschauend": "hierherschauen",
    "hierherschauende": "hierherschauend",
    "hierherschauendem": "hierherschauend",
    "hierherschauenden": "hierherschauend",
    "hierherschauender": "hierherschauend",
    "hierherschauendes": "hierherschauend",
    "hierherschauest": "hierherschauen",
    "hierherschauet": "hierherschauen",
    "hierherschaust": "hierherschauen",
    "hierherschaut": "hierherschauen",
    "hierherschaute": "hierherschauen",
    "hierherschauten": "hierherschauen",
    "hierherschautest": "hierherschauen",
    "hierherschautet": "hierherschauen",
    "hierherschiebe": "hierherschieben",
    "hierherschiebend": "hierherschieben",
    "hierherschiebende": "hierherschiebend",
    "hierherschiebendem": "hierherschiebend",
    "hierherschiebenden": "hierherschiebend",
    "hierherschiebender": "hierherschiebend",
    "hierherschiebendes": "hierherschiebend",
    "hierherschiebest": "hierherschieben",
    "hierherschiebet": "hierherschieben",
    "hierherschiebst": "hierherschieben",
    "hierherschiebt": "hierherschieben",
    "hierherschleppe": "hierherschleppen",
    "hierherschleppend": "hierherschleppen",
    "hierherschleppende": "hierherschleppend",
    "hierherschleppendem": "hierherschleppend",
    "hierherschleppenden": "hierherschleppend",
    "hierherschleppender": "hierherschleppend",
    "hierherschleppendes": "hierherschleppend",
    "hierherschleppest": "hierherschleppen",
    "hierherschleppet": "hierherschleppen",
    "hierherschleppst": "hierherschleppen",
    "hierherschleppt": "hierherschleppen",
    "hierherschleppte": "hierherschleppen",
    "hierherschleppten": "hierherschleppen",
    "hierherschlepptest": "hierherschleppen",
    "hierherschlepptet": "hierherschleppen",
    "hierherschob": "hierherschieben",
    "hierherschoben": "hierherschieben",
    "hierherschobst": "hierherschieben",
    "hierherschobt": "hierherschieben",
    "hierherschuf": "hierherschaffen",
    "hierherschufen": "hierherschaffen",
    "hierherschufst": "hierherschaffen",
    "hierherschuft": "hierherschaffen",
    "hierherschöbe": "hierherschieben",
    "hierherschöben": "hierherschieben",
    "hierherschöbest": "hierherschieben",
    "hierherschöbet": "hierherschieben",
    "hierherschüfe": "hierherschaffen",
    "hierherschüfen": "hierherschaffen",
    "hierherschüfest": "hierherschaffen",
    "hierherschüfet": "hierherschaffen",
    "hierhersetze": "hierhersetzen",
    "hierhersetzend": "hierhersetzen",
    "hierhersetzende": "hierhersetzend",
    "hierhersetzendem": "hierhersetzend",
    "hierhersetzenden": "hierhersetzend",
    "hierhersetzender": "hierhersetzend",
    "hierhersetzendes": "hierhersetzend",
    "hierhersetzest": "hierhersetzen",
    "hierhersetzet": "hierhersetzen",
    "hierhersetzt": "hierhersetzen",
    "hierhersetzte": "hierhersetzen",
    "hierhersetzten": "hierhersetzen",
    "hierhersetztest": "hierhersetzen",
    "hierhersetztet": "hierhersetzen",
    "hierherstelle": "hierherstellen",
    "hierherstellend": "hierherstellen",
    "hierherstellende": "hierherstellend",
    "hierherstellendem": "hierherstellend",
    "hierherstellenden": "hierherstellend",
    "hierherstellender": "hierherstellend",
    "hierherstellendes": "hierherstellend",
    "hierherstellest": "hierherstellen",
    "hierherstellet": "hierherstellen",
    "hierherstellst": "hierherstellen",
    "hierherstellt": "hierherstellen",
    "hierherstellte": "hierherstellen",
    "hierherstellten": "hierherstellen",
    "hierherstelltest": "hierherstellen",
    "hierherstelltet": "hierherstellen",
    "hierhertrage": "hierhertragen",
    "hierhertragend": "hierhertragen",
    "hierhertragende": "hierhertragend",
    "hierhertragendem": "hierhertragend",
    "hierhertragenden": "hierhertragend",
    "hierhertragender": "hierhertragend",
    "hierhertragendes": "hierhertragend",
    "hierhertragest": "hierhertragen",
    "hierhertraget": "hierhertragen",
    "hierhertragt": "hierhertragen",
    "hierhertreibe": "hierhertreiben",
    "hierhertreibend": "hierhertreiben",
    "hierhertreibende": "hierhertreibend",
    "hierhertreibendem": "hierhertreibend",
    "hierhertreibenden": "hierhertreibend",
    "hierhertreibender": "hierhertreibend",
    "hierhertreibendes": "hierhertreibend",
    "hierhertreibest": "hierhertreiben",
    "hierhertreibet": "hierhertreiben",
    "hierhertreibst": "hierhertreiben",
    "hierhertreibt": "hierhertreiben",
    "hierhertrieb": "hierhertreiben",
    "hierhertriebe": "hierhertreiben",
    "hierhertrieben": "hierhertreiben",
    "hierhertriebest": "hierhertreiben",
    "hierhertriebet": "hierhertreiben",
    "hierhertriebst": "hierhertreiben",
    "hierhertriebt": "hierhertreiben",
    "hierhertrug": "hierhertragen",
    "hierhertrugen": "hierhertragen",
    "hierhertrugst": "hierhertragen",
    "hierhertrugt": "hierhertragen",
    "hierherträgst": "hierhertragen",
    "hierherträgt": "hierhertragen",
    "hierhertrüge": "hierhertragen",
    "hierhertrügen": "hierhertragen",
    "hierhertrügest": "hierhertragen",
    "hierhertrüget": "hierhertragen",
    "hierherwage": "hierherwagen",
    "hierherwagend": "hierherwagen",
    "hierherwagende": "hierherwagend",
    "hierherwagendem": "hierherwagend",
    "hierherwagenden": "hierherwagend",
    "hierherwagender": "hierherwagend",
    "hierherwagendes": "hierherwagend",
    "hierherwagest": "hierherwagen",
    "hierherwaget": "hierherwagen",
    "hierherwagst": "hierherwagen",
    "hierherwagt": "hierherwagen",
    "hierherwagte": "hierherwagen",
    "hierherwagten": "hierherwagen",
    "hierherwagtest": "hierherwagen",
    "hierherwagtet": "hierherwagen",
    "hierherzubemühen": "hierherbemühen",
    "hierherzubitten": "hierherbitten",
    "hierherzubringen": "hierherbringen",
    "hierherzueilen": "hierhereilen",
    "hierherzuführen": "hierherführen",
    "hierherzugehören": "hierhergehören",
    "hierherzuholen": "hierherholen",
    "hierherzukommen": "hierherkommen",
    "hierherzulegen": "hierherlegen",
    "hierherzureisen": "hierherreisen",
    "hierherzuschaffen": "hierherschaffen",
    "hierherzuschauen": "hierherschauen",
    "hierherzuschieben": "hierherschieben",
    "hierherzuschleppen": "hierherschleppen",
    "hierherzusetzen": "hierhersetzen",
    "hierherzustellen": "hierherstellen",
    "hierherzutragen": "hierhertragen",
    "hierherzutreiben": "hierhertreiben",
    "hierherzuwagen": "hierherwagen",
    "hierzubehalten": "hierbehalten",
    "hierzubleiben": "hierbleiben",
    "hiesige": "hiesig",
    "hiesigem": "hiesig",
    "hiesigen": "hiesig",
    "hiesiger": "hiesig",
    "hiesiges": "hiesig",
    "hieve": "hieven",
    "hievend": "hieven",
    "hievende": "hievend",
    "hievendem": "hievend",
    "hievenden": "hievend",
    "hievender": "hievend",
    "hievendes": "hievend",
    "hievest": "hieven",
    "hievet": "hieven",
    "hievst": "hieven",
    "hievt": "hieven",
    "hievte": "hieven",
    "hievten": "hieven",
    "hievtest": "hieven",
    "hievtet": "hieven",
    "hieß": "heißen",
    "hieße": "heißen",
    "hießen": "heißen",
    "hießest": "heißen",
    "hießet": "heißen",
    "hießt": "heißen",
    "hilf": "helfen",
    "hilfesuchendem": "hilfesuchend",
    "hilfesuchenden": "hilfesuchend",
    "hilfesuchender": "hilfesuchend",
    "hilfesuchendes": "hilfesuchend",
    "hilflose": "hilflos",
    "hilflosem": "hilflos",
    "hilflosen": "hilflos",
    "hilfloser": "hilflos",
    "hilflosere": "hilflos",
    "hilfloserem": "hilflos",
    "hilfloseren": "hilflos",
    "hilfloserer": "hilflos",
    "hilfloseres": "hilflos",
    "hilfloses": "hilflos",
    "hilfloseste": "hilflos",
    "hilflosestem": "hilflos",
    "hilflosesten": "hilflos",
    "hilflosester": "hilflos",
    "hilflosestes": "hilflos",
    "hilfreichem": "hilfreich",
    "hilfreichen": "hilfreich",
    "hilfreicher": "hilfreich",
    "hilfreichere": "hilfreich",
    "hilfreicherem": "hilfreich",
    "hilfreicheren": "hilfreich",
    "hilfreicherer": "hilfreich",
    "hilfreicheres": "hilfreich",
    "hilfreiches": "hilfreich",
    "hilfreichste": "hilfreich",
    "hilfreichstem": "hilfreich",
    "hilfreichsten": "hilfreich",
    "hilfreichster": "hilfreich",
    "hilfreichstes": "hilfreich",
    "hilfsbedürftigem": "hilfsbedürftig",
    "hilfsbedürftigen": "hilfsbedürftig",
    "hilfsbedürftiger": "hilfsbedürftig",
    "hilfsbedürftigere": "hilfsbedürftig",
    "hilfsbedürftigerem": "hilfsbedürftig",
    "hilfsbedürftigeren": "hilfsbedürftig",
    "hilfsbedürftigerer": "hilfsbedürftig",
    "hilfsbedürftigeres": "hilfsbedürftig",
    "hilfsbedürftiges": "hilfsbedürftig",
    "hilfsbedürftigste": "hilfsbedürftig",
    "hilfsbedürftigstem": "hilfsbedürftig",
    "hilfsbedürftigsten": "hilfsbedürftig",
    "hilfsbedürftigster": "hilfsbedürftig",
    "hilfsbedürftigstes": "hilfsbedürftig",
    "hilfsbereite": "hilfsbereit",
    "hilfsbereitem": "hilfsbereit",
    "hilfsbereiten": "hilfsbereit",
    "hilfsbereiter": "hilfsbereit",
    "hilfsbereitere": "hilfsbereit",
    "hilfsbereiterem": "hilfsbereit",
    "hilfsbereiteren": "hilfsbereit",
    "hilfsbereiterer": "hilfsbereit",
    "hilfsbereiteres": "hilfsbereit",
    "hilfsbereites": "hilfsbereit",
    "hilfsbereiteste": "hilfsbereit",
    "hilfsbereitestem": "hilfsbereit",
    "hilfsbereitesten": "hilfsbereit",
    "hilfsbereitester": "hilfsbereit",
    "hilfsbereitestes": "hilfsbereit",
    "hilfst": "helfen",
    "hilft": "helfen",
    "himmele": "himmeln",
    "himmelnd": "himmeln",
    "himmelnde": "himmelnd",
    "himmelndem": "himmelnd",
    "himmelnden": "himmelnd",
    "himmelnder": "himmelnd",
    "himmelndes": "himmelnd",
    "himmelschreiendem": "himmelschreiend",
    "himmelschreienden": "himmelschreiend",
    "himmelschreiender": "himmelschreiend",
    "himmelschreiendes": "himmelschreiend",
    "himmelst": "himmeln",
    "himmelt": "himmeln",
    "himmelte": "himmeln",
    "himmelten": "himmeln",
    "himmeltest": "himmeln",
    "himmeltet": "himmeln",
    "himmelweite": "himmelweit",
    "himmelweitem": "himmelweit",
    "himmelweiten": "himmelweit",
    "himmelweiter": "himmelweit",
    "himmelweites": "himmelweit",
    "himmle": "himmeln",
    "himmlische": "himmlisch",
    "himmlischem": "himmlisch",
    "himmlischen": "himmlisch",
    "himmlischer": "himmlisch",
    "himmlischere": "himmlisch",
    "himmlischerem": "himmlisch",
    "himmlischeren": "himmlisch",
    "himmlischerer": "himmlisch",
    "himmlischeres": "himmlisch",
    "himmlisches": "himmlisch",
    "himmlischste": "himmlisch",
    "himmlischstem": "himmlisch",
    "himmlischsten": "himmlisch",
    "himmlischster": "himmlisch",
    "himmlischstes": "himmlisch",
    "hinabgesehen": "hinabsehen",
    "hinabgesehene": "hinabgesehen",
    "hinabgesehenem": "hinabgesehen",
    "hinabgesehenen": "hinabgesehen",
    "hinabgesehener": "hinabgesehen",
    "hinabgesehenes": "hinabgesehen",
    "hinabgesunken": "hinabsinken",
    "hinabgesunkene": "hinabgesunken",
    "hinabgesunkenem": "hinabgesunken",
    "hinabgesunkenen": "hinabgesunken",
    "hinabgesunkener": "hinabgesunken",
    "hinabgesunkenere": "hinabgesunken",
    "hinabgesunkenerem": "hinabgesunken",
    "hinabgesunkeneren": "hinabgesunken",
    "hinabgesunkenerer": "hinabgesunken",
    "hinabgesunkeneres": "hinabgesunken",
    "hinabgesunkenes": "hinabgesunken",
    "hinabgesunkenste": "hinabgesunken",
    "hinabgesunkenstem": "hinabgesunken",
    "hinabgesunkensten": "hinabgesunken",
    "hinabgesunkenster": "hinabgesunken",
    "hinabgesunkenstes": "hinabgesunken",
    "hinabsah": "hinabsehen",
    "hinabsahen": "hinabsehen",
    "hinabsahst": "hinabsehen",
    "hinabsaht": "hinabsehen",
    "hinabsank": "hinabsinken",
    "hinabsanken": "hinabsinken",
    "hinabsankst": "hinabsinken",
    "hinabsankt": "hinabsinken",
    "hinabsehe": "hinabsehen",
    "hinabsehend": "hinabsehen",
    "hinabsehende": "hinabsehend",
    "hinabsehendem": "hinabsehend",
    "hinabsehenden": "hinabsehend",
    "hinabsehender": "hinabsehend",
    "hinabsehendes": "hinabsehend",
    "hinabsehest": "hinabsehen",
    "hinabsehet": "hinabsehen",
    "hinabseht": "hinabsehen",
    "hinabsiehst": "hinabsehen",
    "hinabsieht": "hinabsehen",
    "hinabsinke": "hinabsinken",
    "hinabsinkend": "hinabsinken",
    "hinabsinkende": "hinabsinkend",
    "hinabsinkendem": "hinabsinkend",
    "hinabsinkenden": "hinabsinkend",
    "hinabsinkender": "hinabsinkend",
    "hinabsinkendere": "hinabsinkend",
    "hinabsinkenderem": "hinabsinkend",
    "hinabsinkenderen": "hinabsinkend",
    "hinabsinkenderer": "hinabsinkend",
    "hinabsinkenderes": "hinabsinkend",
    "hinabsinkendes": "hinabsinkend",
    "hinabsinkendste": "hinabsinkend",
    "hinabsinkendstem": "hinabsinkend",
    "hinabsinkendsten": "hinabsinkend",
    "hinabsinkendster": "hinabsinkend",
    "hinabsinkendstes": "hinabsinkend",
    "hinabsinkest": "hinabsinken",
    "hinabsinket": "hinabsinken",
    "hinabsinkst": "hinabsinken",
    "hinabsinkt": "hinabsinken",
    "hinabsähe": "hinabsehen",
    "hinabsähen": "hinabsehen",
    "hinabsähest": "hinabsehen",
    "hinabsähet": "hinabsehen",
    "hinabsänke": "hinabsinken",
    "hinabsänken": "hinabsinken",
    "hinabsänkest": "hinabsinken",
    "hinabsänket": "hinabsinken",
    "hinabzusehen": "hinabsehen",
    "hinabzusinken": "hinabsinken",
    "hinarbeite": "hinarbeiten",
    "hinarbeitend": "hinarbeiten",
    "hinarbeitende": "hinarbeitend",
    "hinarbeitendem": "hinarbeitend",
    "hinarbeitenden": "hinarbeitend",
    "hinarbeitender": "hinarbeitend",
    "hinarbeitendes": "hinarbeitend",
    "hinarbeitest": "hinarbeiten",
    "hinarbeitet": "hinarbeiten",
    "hinarbeitete": "hinarbeiten",
    "hinarbeiteten": "hinarbeiten",
    "hinarbeitetest": "hinarbeiten",
    "hinarbeitetet": "hinarbeiten",
    "hinaufbemühe": "hinaufbemühen",
    "hinaufbemühend": "hinaufbemühen",
    "hinaufbemühende": "hinaufbemühend",
    "hinaufbemühendem": "hinaufbemühend",
    "hinaufbemühenden": "hinaufbemühend",
    "hinaufbemühender": "hinaufbemühend",
    "hinaufbemühendes": "hinaufbemühend",
    "hinaufbemühest": "hinaufbemühen",
    "hinaufbemühet": "hinaufbemühen",
    "hinaufbemühst": "hinaufbemühen",
    "hinaufbemüht": "hinaufbemühen",
    "hinaufbemühte": "hinaufbemühen",
    "hinaufbemühtem": "hinaufbemüht",
    "hinaufbemühten": "hinaufbemühen",
    "hinaufbemühter": "hinaufbemüht",
    "hinaufbemühtes": "hinaufbemüht",
    "hinaufbemühtest": "hinaufbemühen",
    "hinaufbemühtet": "hinaufbemühen",
    "hinaufgereicht": "hinaufreichen",
    "hinaufgereichte": "hinaufgereicht",
    "hinaufgereichtem": "hinaufgereicht",
    "hinaufgereichten": "hinaufgereicht",
    "hinaufgereichter": "hinaufgereicht",
    "hinaufgereichtes": "hinaufgereicht",
    "hinaufgeschaffen": "hinaufschaffen",
    "hinaufgeschaffene": "hinaufgeschaffen",
    "hinaufgeschaffenem": "hinaufgeschaffen",
    "hinaufgeschaffenen": "hinaufgeschaffen",
    "hinaufgeschaffener": "hinaufgeschaffen",
    "hinaufgeschaffenes": "hinaufgeschaffen",
    "hinaufgeschafft": "hinaufschaffen",
    "hinaufgeschaffte": "hinaufgeschafft",
    "hinaufgeschafftem": "hinaufgeschafft",
    "hinaufgeschafften": "hinaufgeschafft",
    "hinaufgeschaffter": "hinaufgeschafft",
    "hinaufgeschafftes": "hinaufgeschafft",
    "hinaufgestellt": "hinaufstellen",
    "hinaufgestellte": "hinaufgestellt",
    "hinaufgestelltem": "hinaufgestellt",
    "hinaufgestellten": "hinaufgestellt",
    "hinaufgestellter": "hinaufgestellt",
    "hinaufgestelltes": "hinaufgestellt",
    "hinaufgewunden": "hinaufwinden",
    "hinaufgewundene": "hinaufgewunden",
    "hinaufgewundenem": "hinaufgewunden",
    "hinaufgewundenen": "hinaufgewunden",
    "hinaufgewundener": "hinaufgewunden",
    "hinaufgewundenes": "hinaufgewunden",
    "hinaufgezogen": "hinaufziehen",
    "hinaufgezogene": "hinaufgezogen",
    "hinaufgezogenem": "hinaufgezogen",
    "hinaufgezogenen": "hinaufgezogen",
    "hinaufgezogener": "hinaufgezogen",
    "hinaufgezogenes": "hinaufgezogen",
    "hinaufreiche": "hinaufreichen",
    "hinaufreichend": "hinaufreichen",
    "hinaufreichende": "hinaufreichend",
    "hinaufreichendem": "hinaufreichend",
    "hinaufreichenden": "hinaufreichend",
    "hinaufreichender": "hinaufreichend",
    "hinaufreichendes": "hinaufreichend",
    "hinaufreichest": "hinaufreichen",
    "hinaufreichet": "hinaufreichen",
    "hinaufreichst": "hinaufreichen",
    "hinaufreicht": "hinaufreichen",
    "hinaufreichte": "hinaufreichen",
    "hinaufreichten": "hinaufreichen",
    "hinaufreichtest": "hinaufreichen",
    "hinaufreichtet": "hinaufreichen",
    "hinaufschaffe": "hinaufschaffen",
    "hinaufschaffend": "hinaufschaffen",
    "hinaufschaffende": "hinaufschaffend",
    "hinaufschaffendem": "hinaufschaffend",
    "hinaufschaffenden": "hinaufschaffend",
    "hinaufschaffender": "hinaufschaffend",
    "hinaufschaffendes": "hinaufschaffend",
    "hinaufschaffest": "hinaufschaffen",
    "hinaufschaffet": "hinaufschaffen",
    "hinaufschaffst": "hinaufschaffen",
    "hinaufschafft": "hinaufschaffen",
    "hinaufschaffte": "hinaufschaffen",
    "hinaufschafften": "hinaufschaffen",
    "hinaufschafftest": "hinaufschaffen",
    "hinaufschafftet": "hinaufschaffen",
    "hinaufschuf": "hinaufschaffen",
    "hinaufschufen": "hinaufschaffen",
    "hinaufschufst": "hinaufschaffen",
    "hinaufschuft": "hinaufschaffen",
    "hinaufschüfe": "hinaufschaffen",
    "hinaufschüfen": "hinaufschaffen",
    "hinaufschüfest": "hinaufschaffen",
    "hinaufschüfet": "hinaufschaffen",
    "hinaufstelle": "hinaufstellen",
    "hinaufstellend": "hinaufstellen",
    "hinaufstellende": "hinaufstellend",
    "hinaufstellendem": "hinaufstellend",
    "hinaufstellenden": "hinaufstellend",
    "hinaufstellender": "hinaufstellend",
    "hinaufstellendes": "hinaufstellend",
    "hinaufstellest": "hinaufstellen",
    "hinaufstellet": "hinaufstellen",
    "hinaufstellst": "hinaufstellen",
    "hinaufstellt": "hinaufstellen",
    "hinaufstellte": "hinaufstellen",
    "hinaufstellten": "hinaufstellen",
    "hinaufstelltest": "hinaufstellen",
    "hinaufstelltet": "hinaufstellen",
    "hinaufwand": "hinaufwinden",
    "hinaufwanden": "hinaufwinden",
    "hinaufwandest": "hinaufwinden",
    "hinaufwandet": "hinaufwinden",
    "hinaufwinde": "hinaufwinden",
    "hinaufwindend": "hinaufwinden",
    "hinaufwindende": "hinaufwindend",
    "hinaufwindendem": "hinaufwindend",
    "hinaufwindenden": "hinaufwindend",
    "hinaufwindender": "hinaufwindend",
    "hinaufwindendes": "hinaufwindend",
    "hinaufwindest": "hinaufwinden",
    "hinaufwindet": "hinaufwinden",
    "hinaufwände": "hinaufwinden",
    "hinaufwänden": "hinaufwinden",
    "hinaufwändest": "hinaufwinden",
    "hinaufwändet": "hinaufwinden",
    "hinaufziehe": "hinaufziehen",
    "hinaufziehend": "hinaufziehen",
    "hinaufziehende": "hinaufziehend",
    "hinaufziehendem": "hinaufziehend",
    "hinaufziehenden": "hinaufziehend",
    "hinaufziehender": "hinaufziehend",
    "hinaufziehendes": "hinaufziehend",
    "hinaufziehest": "hinaufziehen",
    "hinaufziehet": "hinaufziehen",
    "hinaufziehst": "hinaufziehen",
    "hinaufzieht": "hinaufziehen",
    "hinaufzog": "hinaufziehen",
    "hinaufzogen": "hinaufziehen",
    "hinaufzogst": "hinaufziehen",
    "hinaufzogt": "hinaufziehen",
    "hinaufzubemühen": "hinaufbemühen",
    "hinaufzureichen": "hinaufreichen",
    "hinaufzuschaffen": "hinaufschaffen",
    "hinaufzustellen": "hinaufstellen",
    "hinaufzuwinden": "hinaufwinden",
    "hinaufzuziehen": "hinaufziehen",
    "hinaufzöge": "hinaufziehen",
    "hinaufzögen": "hinaufziehen",
    "hinaufzögest": "hinaufziehen",
    "hinaufzöget": "hinaufziehen",
    "hinausgereicht": "hinausreichen",
    "hinausgereichte": "hinausgereicht",
    "hinausgereichtem": "hinausgereicht",
    "hinausgereichten": "hinausgereicht",
    "hinausgereichter": "hinausgereicht",
    "hinausgereichtes": "hinausgereicht",
    "hinausgeschossen": "hinausschießen",
    "hinausgeschossene": "hinausgeschossen",
    "hinausgeschossenem": "hinausgeschossen",
    "hinausgeschossenen": "hinausgeschossen",
    "hinausgeschossener": "hinausgeschossen",
    "hinausgeschossenes": "hinausgeschossen",
    "hinausgeschrien": "hinausschreien",
    "hinausgeschriene": "hinausgeschrien",
    "hinausgeschrienem": "hinausgeschrien",
    "hinausgeschrienen": "hinausgeschrien",
    "hinausgeschriener": "hinausgeschrien",
    "hinausgeschrienes": "hinausgeschrien",
    "hinausgestürzt": "hinausstürzen",
    "hinausgestürzte": "hinausgestürzt",
    "hinausgestürztem": "hinausgestürzt",
    "hinausgestürzten": "hinausgestürzt",
    "hinausgestürzter": "hinausgestürzt",
    "hinausgestürztes": "hinausgestürzt",
    "hinauskomplimentiere": "hinauskomplimenti",
    "hinauskomplimentieree": "hinauskomplimentiere",
    "hinauskomplimentiereem": "hinauskomplimentiere",
    "hinauskomplimentiereen": "hinauskomplimentiere",
    "hinauskomplimentiereer": "hinauskomplimentiere",
    "hinauskomplimentierees": "hinauskomplimentiere",
    "hinauskomplimentieren": "hinauskomplimenti",
    "hinauskomplimentierend": "hinauskomplimenti",
    "hinauskomplimentierest": "hinauskomplimenti",
    "hinauskomplimentieret": "hinauskomplimenti",
    "hinauskomplimentierst": "hinauskomplimenti",
    "hinauskomplimentiert": "hinauskomplimenti",
    "hinauskomplimentierte": "hinauskomplimenti",
    "hinauskomplimentiertem": "hinauskomplimentiert",
    "hinauskomplimentierten": "hinauskomplimenti",
    "hinauskomplimentierter": "hinauskomplimentiert",
    "hinauskomplimentiertes": "hinauskomplimentiert",
    "hinauskomplimentiertest": "hinauskomplimenti",
    "hinauskomplimentiertet": "hinauskomplimenti",
    "hinausreiche": "hinausreichen",
    "hinausreichend": "hinausreichen",
    "hinausreichende": "hinausreichend",
    "hinausreichendem": "hinausreichend",
    "hinausreichenden": "hinausreichend",
    "hinausreichender": "hinausreichend",
    "hinausreichendes": "hinausreichend",
    "hinausreichest": "hinausreichen",
    "hinausreichet": "hinausreichen",
    "hinausreichst": "hinausreichen",
    "hinausreicht": "hinausreichen",
    "hinausreichte": "hinausreichen",
    "hinausreichten": "hinausreichen",
    "hinausreichtest": "hinausreichen",
    "hinausreichtet": "hinausreichen",
    "hinausschieße": "hinausschießen",
    "hinausschießend": "hinausschießen",
    "hinausschießende": "hinausschießend",
    "hinausschießendem": "hinausschießend",
    "hinausschießenden": "hinausschießend",
    "hinausschießender": "hinausschießend",
    "hinausschießendes": "hinausschießend",
    "hinausschießest": "hinausschießen",
    "hinausschießet": "hinausschießen",
    "hinausschießt": "hinausschießen",
    "hinausschossen": "hinausschießen",
    "hinausschoß": "hinausschießen",
    "hinausschoßt": "hinausschießen",
    "hinausschreie": "hinausschreien",
    "hinausschreiend": "hinausschreien",
    "hinausschreiende": "hinausschreiend",
    "hinausschreiendem": "hinausschreiend",
    "hinausschreienden": "hinausschreiend",
    "hinausschreiender": "hinausschreiend",
    "hinausschreiendes": "hinausschreiend",
    "hinausschreiest": "hinausschreien",
    "hinausschreiet": "hinausschreien",
    "hinausschreist": "hinausschreien",
    "hinausschreit": "hinausschreien",
    "hinausschrie": "hinausschreien",
    "hinausschriee": "hinausschreien",
    "hinausschrieen": "hinausschreien",
    "hinausschrieest": "hinausschreien",
    "hinausschrieet": "hinausschreien",
    "hinausschrien": "hinausschreien",
    "hinausschriest": "hinausschreien",
    "hinausschriet": "hinausschreien",
    "hinausschösse": "hinausschießen",
    "hinausschössen": "hinausschießen",
    "hinausschössest": "hinausschießen",
    "hinausschösset": "hinausschießen",
    "hinausstürze": "hinausstürzen",
    "hinausstürzend": "hinausstürzen",
    "hinausstürzende": "hinausstürzend",
    "hinausstürzendem": "hinausstürzend",
    "hinausstürzenden": "hinausstürzend",
    "hinausstürzender": "hinausstürzend",
    "hinausstürzendes": "hinausstürzend",
    "hinausstürzest": "hinausstürzen",
    "hinausstürzet": "hinausstürzen",
    "hinausstürzt": "hinausstürzen",
    "hinausstürzte": "hinausstürzen",
    "hinausstürzten": "hinausstürzen",
    "hinausstürztest": "hinausstürzen",
    "hinausstürztet": "hinausstürzen",
    "hinauszukomplimentieren": "hinauskomplimenti",
    "hinauszureichen": "hinausreichen",
    "hinauszuschießen": "hinausschießen",
    "hinauszuschreien": "hinausschreien",
    "hinauszustürzen": "hinausstürzen",
    "hinbegleite": "hinbegleiten",
    "hinbegleitend": "hinbegleiten",
    "hinbegleitende": "hinbegleitend",
    "hinbegleitendem": "hinbegleitend",
    "hinbegleitenden": "hinbegleitend",
    "hinbegleitender": "hinbegleitend",
    "hinbegleitendes": "hinbegleitend",
    "hinbegleitest": "hinbegleiten",
    "hinbegleitet": "hinbegleiten",
    "hinbegleitete": "hinbegleiten",
    "hinbegleitetem": "hinbegleitet",
    "hinbegleiteten": "hinbegleiten",
    "hinbegleiteter": "hinbegleitet",
    "hinbegleitetes": "hinbegleitet",
    "hinbegleitetest": "hinbegleiten",
    "hinbegleitetet": "hinbegleiten",
    "hinbemühe": "hinbemühen",
    "hinbemühend": "hinbemühen",
    "hinbemühende": "hinbemühend",
    "hinbemühendem": "hinbemühend",
    "hinbemühenden": "hinbemühend",
    "hinbemühender": "hinbemühend",
    "hinbemühendes": "hinbemühend",
    "hinbemühest": "hinbemühen",
    "hinbemühet": "hinbemühen",
    "hinbemühst": "hinbemühen",
    "hinbemüht": "hinbemühen",
    "hinbemühte": "hinbemühen",
    "hinbemühtem": "hinbemüht",
    "hinbemühten": "hinbemühen",
    "hinbemühter": "hinbemüht",
    "hinbemühtes": "hinbemüht",
    "hinbemühtest": "hinbemühen",
    "hinbemühtet": "hinbemühen",
    "hinbestelle": "hinbestellen",
    "hinbestellend": "hinbestellen",
    "hinbestellende": "hinbestellend",
    "hinbestellendem": "hinbestellend",
    "hinbestellenden": "hinbestellend",
    "hinbestellender": "hinbestellend",
    "hinbestellendes": "hinbestellend",
    "hinbestellest": "hinbestellen",
    "hinbestellet": "hinbestellen",
    "hinbestellst": "hinbestellen",
    "hinbestellt": "hinbestellen",
    "hinbestellte": "hinbestellen",
    "hinbestelltem": "hinbestellt",
    "hinbestellten": "hinbestellen",
    "hinbestellter": "hinbestellt",
    "hinbestelltes": "hinbestellt",
    "hinbestelltest": "hinbestellen",
    "hinbestelltet": "hinbestellen",
    "hinbiege": "hinbiegen",
    "hinbiegend": "hinbiegen",
    "hinbiegende": "hinbiegend",
    "hinbiegendem": "hinbiegend",
    "hinbiegenden": "hinbiegend",
    "hinbiegender": "hinbiegend",
    "hinbiegendes": "hinbiegend",
    "hinbiegest": "hinbiegen",
    "hinbieget": "hinbiegen",
    "hinbiegst": "hinbiegen",
    "hinbiegt": "hinbiegen",
    "hinblättere": "hinblättern",
    "hinblätternd": "hinblättern",
    "hinblätternde": "hinblätternd",
    "hinblätterndem": "hinblätternd",
    "hinblätternden": "hinblätternd",
    "hinblätternder": "hinblätternd",
    "hinblätterndes": "hinblätternd",
    "hinblätterst": "hinblättern",
    "hinblättert": "hinblättern",
    "hinblätterte": "hinblättern",
    "hinblätterten": "hinblättern",
    "hinblättertest": "hinblättern",
    "hinblättertet": "hinblättern",
    "hinbog": "hinbiegen",
    "hinbogen": "hinbiegen",
    "hinbogst": "hinbiegen",
    "hinbogt": "hinbiegen",
    "hinbrachte": "hinbringen",
    "hinbrachten": "hinbringen",
    "hinbrachtest": "hinbringen",
    "hinbrachtet": "hinbringen",
    "hinbringe": "hinbringen",
    "hinbringend": "hinbringen",
    "hinbringende": "hinbringend",
    "hinbringendem": "hinbringend",
    "hinbringenden": "hinbringend",
    "hinbringender": "hinbringend",
    "hinbringendes": "hinbringend",
    "hinbringest": "hinbringen",
    "hinbringet": "hinbringen",
    "hinbringst": "hinbringen",
    "hinbringt": "hinbringen",
    "hinbrächte": "hinbringen",
    "hinbrächten": "hinbringen",
    "hinbrächtest": "hinbringen",
    "hinbrächtet": "hinbringen",
    "hinbrüte": "hinbrüten",
    "hinbrütend": "hinbrüten",
    "hinbrütende": "hinbrütend",
    "hinbrütendem": "hinbrütend",
    "hinbrütenden": "hinbrütend",
    "hinbrütender": "hinbrütend",
    "hinbrütendes": "hinbrütend",
    "hinbrütest": "hinbrüten",
    "hinbrütet": "hinbrüten",
    "hinbrütete": "hinbrüten",
    "hinbrüteten": "hinbrüten",
    "hinbrütetest": "hinbrüten",
    "hinbrütetet": "hinbrüten",
    "hinböge": "hinbiegen",
    "hinbögen": "hinbiegen",
    "hinbögest": "hinbiegen",
    "hinböget": "hinbiegen",
    "hindachte": "hindenken",
    "hindachten": "hindenken",
    "hindachtest": "hindenken",
    "hindachtet": "hindenken",
    "hindenke": "hindenken",
    "hindenkend": "hindenken",
    "hindenkende": "hindenkend",
    "hindenkendem": "hindenkend",
    "hindenkenden": "hindenkend",
    "hindenkender": "hindenkend",
    "hindenkendes": "hindenkend",
    "hindenkest": "hindenken",
    "hindenket": "hindenken",
    "hindenkst": "hindenken",
    "hindenkt": "hindenken",
    "hindere": "hindern",
    "hinderliche": "hinderlich",
    "hinderlichem": "hinderlich",
    "hinderlichen": "hinderlich",
    "hinderlicher": "hinderlich",
    "hinderlichere": "hinderlich",
    "hinderlicherem": "hinderlich",
    "hinderlicheren": "hinderlich",
    "hinderlicherer": "hinderlich",
    "hinderlicheres": "hinderlich",
    "hinderliches": "hinderlich",
    "hinderlichste": "hinderlich",
    "hinderlichstem": "hinderlich",
    "hinderlichsten": "hinderlich",
    "hinderlichster": "hinderlich",
    "hinderlichstes": "hinderlich",
    "hindernd": "hindern",
    "hindernde": "hindernd",
    "hinderndem": "hindernd",
    "hindernden": "hindernd",
    "hindernder": "hindernd",
    "hinderndes": "hindernd",
    "hinderst": "hindern",
    "hindert": "hindern",
    "hinderte": "hindern",
    "hinderten": "hindern",
    "hindertest": "hindern",
    "hindertet": "hindern",
    "hindeute": "hindeuten",
    "hindeutend": "hindeuten",
    "hindeutende": "hindeutend",
    "hindeutendem": "hindeutend",
    "hindeutenden": "hindeutend",
    "hindeutender": "hindeutend",
    "hindeutendes": "hindeutend",
    "hindeutest": "hindeuten",
    "hindeutet": "hindeuten",
    "hindeutete": "hindeuten",
    "hindeuteten": "hindeuten",
    "hindeutetest": "hindeuten",
    "hindeutetet": "hindeuten",
    "hindränge": "hindrängen",
    "hindrängend": "hindrängen",
    "hindrängende": "hindrängend",
    "hindrängendem": "hindrängend",
    "hindrängenden": "hindrängend",
    "hindrängender": "hindrängend",
    "hindrängendes": "hindrängend",
    "hindrängest": "hindrängen",
    "hindränget": "hindrängen",
    "hindrängst": "hindrängen",
    "hindrängt": "hindrängen",
    "hindrängte": "hindrängen",
    "hindrängten": "hindrängen",
    "hindrängtest": "hindrängen",
    "hindrängtet": "hindrängen",
    "hindurcharbeite": "hindurcharbeiten",
    "hindurcharbeitend": "hindurcharbeiten",
    "hindurcharbeitende": "hindurcharbeitend",
    "hindurcharbeitendem": "hindurcharbeitend",
    "hindurcharbeitenden": "hindurcharbeitend",
    "hindurcharbeitender": "hindurcharbeitend",
    "hindurcharbeitendes": "hindurcharbeitend",
    "hindurcharbeitest": "hindurcharbeiten",
    "hindurcharbeitet": "hindurcharbeiten",
    "hindurcharbeitete": "hindurcharbeiten",
    "hindurcharbeiteten": "hindurcharbeiten",
    "hindurcharbeitetest": "hindurcharbeiten",
    "hindurcharbeitetet": "hindurcharbeiten",
    "hindurchfließe": "hindurchfließen",
    "hindurchfließend": "hindurchfließen",
    "hindurchfließende": "hindurchfließend",
    "hindurchfließendem": "hindurchfließend",
    "hindurchfließenden": "hindurchfließend",
    "hindurchfließender": "hindurchfließend",
    "hindurchfließendes": "hindurchfließend",
    "hindurchfließest": "hindurchfließen",
    "hindurchfließet": "hindurchfließen",
    "hindurchfließt": "hindurchfließen",
    "hindurchflossen": "hindurchfließen",
    "hindurchfloß": "hindurchfließen",
    "hindurchfloßt": "hindurchfließen",
    "hindurchflösse": "hindurchfließen",
    "hindurchflössen": "hindurchfließen",
    "hindurchflössest": "hindurchfließen",
    "hindurchflösset": "hindurchfließen",
    "hindurchgearbeitet": "hindurcharbeiten",
    "hindurchgearbeitete": "hindurchgearbeitet",
    "hindurchgearbeitetem": "hindurchgearbeitet",
    "hindurchgearbeiteten": "hindurchgearbeitet",
    "hindurchgearbeiteter": "hindurchgearbeitet",
    "hindurchgearbeitetes": "hindurchgearbeitet",
    "hindurchgeflossen": "hindurchfließen",
    "hindurchgeflossene": "hindurchgeflossen",
    "hindurchgeflossenem": "hindurchgeflossen",
    "hindurchgeflossenen": "hindurchgeflossen",
    "hindurchgeflossener": "hindurchgeflossen",
    "hindurchgeflossenes": "hindurchgeflossen",
    "hindurchgekrochen": "hindurchkriechen",
    "hindurchgekrochene": "hindurchgekrochen",
    "hindurchgekrochenem": "hindurchgekrochen",
    "hindurchgekrochenen": "hindurchgekrochen",
    "hindurchgekrochener": "hindurchgekrochen",
    "hindurchgekrochenes": "hindurchgekrochen",
    "hindurchgezwängt": "hindurchzwängen",
    "hindurchgezwängte": "hindurchgezwängt",
    "hindurchgezwängtem": "hindurchgezwängt",
    "hindurchgezwängten": "hindurchgezwängt",
    "hindurchgezwängter": "hindurchgezwängt",
    "hindurchgezwängtes": "hindurchgezwängt",
    "hindurchkrieche": "hindurchkriechen",
    "hindurchkriechend": "hindurchkriechen",
    "hindurchkriechende": "hindurchkriechend",
    "hindurchkriechendem": "hindurchkriechend",
    "hindurchkriechenden": "hindurchkriechend",
    "hindurchkriechender": "hindurchkriechend",
    "hindurchkriechendes": "hindurchkriechend",
    "hindurchkriechest": "hindurchkriechen",
    "hindurchkriechet": "hindurchkriechen",
    "hindurchkriechst": "hindurchkriechen",
    "hindurchkriecht": "hindurchkriechen",
    "hindurchkroch": "hindurchkriechen",
    "hindurchkrochen": "hindurchkriechen",
    "hindurchkrochst": "hindurchkriechen",
    "hindurchkrocht": "hindurchkriechen",
    "hindurchkröche": "hindurchkriechen",
    "hindurchkröchen": "hindurchkriechen",
    "hindurchkröchest": "hindurchkriechen",
    "hindurchkröchet": "hindurchkriechen",
    "hindurchzuarbeiten": "hindurcharbeiten",
    "hindurchzufließen": "hindurchfließen",
    "hindurchzukriechen": "hindurchkriechen",
    "hindurchzuzwängen": "hindurchzwängen",
    "hindurchzwänge": "hindurchzwängen",
    "hindurchzwängend": "hindurchzwängen",
    "hindurchzwängende": "hindurchzwängend",
    "hindurchzwängendem": "hindurchzwängend",
    "hindurchzwängenden": "hindurchzwängend",
    "hindurchzwängender": "hindurchzwängend",
    "hindurchzwängendes": "hindurchzwängend",
    "hindurchzwängest": "hindurchzwängen",
    "hindurchzwänget": "hindurchzwängen",
    "hindurchzwängst": "hindurchzwängen",
    "hindurchzwängt": "hindurchzwängen",
    "hindurchzwängte": "hindurchzwängen",
    "hindurchzwängten": "hindurchzwängen",
    "hindurchzwängtest": "hindurchzwängen",
    "hindurchzwängtet": "hindurchzwängen",
    "hindächte": "hindenken",
    "hindächten": "hindenken",
    "hindächtest": "hindenken",
    "hindächtet": "hindenken",
    "hindämmere": "hindämmern",
    "hindämmernd": "hindämmern",
    "hindämmernde": "hindämmernd",
    "hindämmerndem": "hindämmernd",
    "hindämmernden": "hindämmernd",
    "hindämmernder": "hindämmernd",
    "hindämmerndes": "hindämmernd",
    "hindämmerst": "hindämmern",
    "hindämmert": "hindämmern",
    "hindämmerte": "hindämmern",
    "hindämmerten": "hindämmern",
    "hindämmertest": "hindämmern",
    "hindämmertet": "hindämmern",
    "hineile": "hineilen",
    "hineilend": "hineilen",
    "hineilende": "hineilend",
    "hineilendem": "hineilend",
    "hineilenden": "hineilend",
    "hineilender": "hineilend",
    "hineilendes": "hineilend",
    "hineilest": "hineilen",
    "hineilet": "hineilen",
    "hineilst": "hineilen",
    "hineilt": "hineilen",
    "hineilte": "hineilen",
    "hineilten": "hineilen",
    "hineiltest": "hineilen",
    "hineiltet": "hineilen",
    "hineinbemühe": "hineinbemühen",
    "hineinbemühend": "hineinbemühen",
    "hineinbemühende": "hineinbemühend",
    "hineinbemühendem": "hineinbemühend",
    "hineinbemühenden": "hineinbemühend",
    "hineinbemühender": "hineinbemühend",
    "hineinbemühendes": "hineinbemühend",
    "hineinbemühest": "hineinbemühen",
    "hineinbemühet": "hineinbemühen",
    "hineinbemühst": "hineinbemühen",
    "hineinbemüht": "hineinbemühen",
    "hineinbemühte": "hineinbemühen",
    "hineinbemühtem": "hineinbemüht",
    "hineinbemühten": "hineinbemühen",
    "hineinbemühter": "hineinbemüht",
    "hineinbemühtes": "hineinbemüht",
    "hineinbemühtest": "hineinbemühen",
    "hineinbemühtet": "hineinbemühen",
    "hineinbohre": "hineinbohren",
    "hineinbohrend": "hineinbohren",
    "hineinbohrende": "hineinbohrend",
    "hineinbohrendem": "hineinbohrend",
    "hineinbohrenden": "hineinbohrend",
    "hineinbohrender": "hineinbohrend",
    "hineinbohrendes": "hineinbohrend",
    "hineinbohrest": "hineinbohren",
    "hineinbohret": "hineinbohren",
    "hineinbohrst": "hineinbohren",
    "hineinbohrt": "hineinbohren",
    "hineinbohrte": "hineinbohren",
    "hineinbohrten": "hineinbohren",
    "hineinbohrtest": "hineinbohren",
    "hineinbohrtet": "hineinbohren",
    "hineinfraß": "hineinfressen",
    "hineinfraßen": "hineinfressen",
    "hineinfraßt": "hineinfressen",
    "hineinfresse": "hineinfressen",
    "hineinfressend": "hineinfressen",
    "hineinfressende": "hineinfressend",
    "hineinfressendem": "hineinfressend",
    "hineinfressenden": "hineinfressend",
    "hineinfressender": "hineinfressend",
    "hineinfressendes": "hineinfressend",
    "hineinfressest": "hineinfressen",
    "hineinfresset": "hineinfressen",
    "hineinfreßt": "hineinfressen",
    "hineinfrißt": "hineinfressen",
    "hineinfräße": "hineinfressen",
    "hineinfräßen": "hineinfressen",
    "hineinfräßest": "hineinfressen",
    "hineinfräßet": "hineinfressen",
    "hineinführe": "hineinführen",
    "hineinführend": "hineinführen",
    "hineinführende": "hineinführend",
    "hineinführendem": "hineinführend",
    "hineinführenden": "hineinführend",
    "hineinführender": "hineinführend",
    "hineinführendes": "hineinführend",
    "hineinführest": "hineinführen",
    "hineinführet": "hineinführen",
    "hineinführst": "hineinführen",
    "hineinführt": "hineinführen",
    "hineinführte": "hineinführen",
    "hineinführten": "hineinführen",
    "hineinführtest": "hineinführen",
    "hineinführtet": "hineinführen",
    "hineingebohrt": "hineinbohren",
    "hineingebohrte": "hineingebohrt",
    "hineingebohrtem": "hineingebohrt",
    "hineingebohrten": "hineingebohrt",
    "hineingebohrter": "hineingebohrt",
    "hineingebohrtes": "hineingebohrt",
    "hineingefressen": "hineinfressen",
    "hineingefressene": "hineingefressen",
    "hineingefressenem": "hineingefressen",
    "hineingefressenen": "hineingefressen",
    "hineingefressener": "hineingefressen",
    "hineingefressenes": "hineingefressen",
    "hineingeführt": "hineinführen",
    "hineingeführte": "hineingeführt",
    "hineingeführtem": "hineingeführt",
    "hineingeführten": "hineingeführt",
    "hineingeführter": "hineingeführt",
    "hineingeführtes": "hineingeführt",
    "hineingehangen": "hineinhängen",
    "hineingehangene": "hineingehangen",
    "hineingehangenem": "hineingehangen",
    "hineingehangenen": "hineingehangen",
    "hineingehangener": "hineingehangen",
    "hineingehangenes": "hineingehangen",
    "hineingehängt": "hineinhängen",
    "hineingehängte": "hineingehängt",
    "hineingehängtem": "hineingehängt",
    "hineingehängten": "hineingehängt",
    "hineingehängter": "hineingehängt",
    "hineingehängtes": "hineingehängt",
    "hineingelesen": "hineinlesen",
    "hineingelesene": "hineingelesen",
    "hineingelesenem": "hineingelesen",
    "hineingelesenen": "hineingelesen",
    "hineingelesener": "hineingelesen",
    "hineingelesenes": "hineingelesen",
    "hineingepaßt": "hineinpassen",
    "hineingepaßte": "hineingepaßt",
    "hineingepaßtem": "hineingepaßt",
    "hineingepaßten": "hineingepaßt",
    "hineingepaßter": "hineingepaßt",
    "hineingepaßtere": "hineingepaßt",
    "hineingepaßterem": "hineingepaßt",
    "hineingepaßteren": "hineingepaßt",
    "hineingepaßterer": "hineingepaßt",
    "hineingepaßteres": "hineingepaßt",
    "hineingepaßtes": "hineingepaßt",
    "hineingepaßteste": "hineingepaßt",
    "hineingepaßtestem": "hineingepaßt",
    "hineingepaßtesten": "hineingepaßt",
    "hineingepaßtester": "hineingepaßt",
    "hineingepaßtestes": "hineingepaßt",
    "hineingereicht": "hineinreichen",
    "hineingereichte": "hineingereicht",
    "hineingereichtem": "hineingereicht",
    "hineingereichten": "hineingereicht",
    "hineingereichter": "hineingereicht",
    "hineingereichtes": "hineingereicht",
    "hineingeritten": "hineinreiten",
    "hineingerittene": "hineingeritten",
    "hineingerittenem": "hineingeritten",
    "hineingerittenen": "hineingeritten",
    "hineingerittener": "hineingeritten",
    "hineingerittenes": "hineingeritten",
    "hineingeschlungen": "hineinschlingen",
    "hineingeschlungene": "hineingeschlungen",
    "hineingeschlungenem": "hineingeschlungen",
    "hineingeschlungenen": "hineingeschlungen",
    "hineingeschlungener": "hineingeschlungen",
    "hineingeschlungenes": "hineingeschlungen",
    "hineingestürzt": "hineinstürzen",
    "hineingestürzte": "hineingestürzt",
    "hineingestürztem": "hineingestürzt",
    "hineingestürzten": "hineingestürzt",
    "hineingestürzter": "hineingestürzt",
    "hineingestürztes": "hineingestürzt",
    "hineingezogen": "hineinziehen",
    "hineingezogene": "hineingezogen",
    "hineingezogenem": "hineingezogen",
    "hineingezogenen": "hineingezogen",
    "hineingezogener": "hineingezogen",
    "hineingezogenes": "hineingezogen",
    "hineinhing": "hineinhängen",
    "hineinhinge": "hineinhängen",
    "hineinhingen": "hineinhängen",
    "hineinhingest": "hineinhängen",
    "hineinhinget": "hineinhängen",
    "hineinhingst": "hineinhängen",
    "hineinhingt": "hineinhängen",
    "hineinhänge": "hineinhängen",
    "hineinhängend": "hineinhängen",
    "hineinhängende": "hineinhängend",
    "hineinhängendem": "hineinhängend",
    "hineinhängenden": "hineinhängend",
    "hineinhängender": "hineinhängend",
    "hineinhängendes": "hineinhängend",
    "hineinhängest": "hineinhängen",
    "hineinhänget": "hineinhängen",
    "hineinhängst": "hineinhängen",
    "hineinhängt": "hineinhängen",
    "hineinhängte": "hineinhängen",
    "hineinhängten": "hineinhängen",
    "hineinhängtest": "hineinhängen",
    "hineinhängtet": "hineinhängen",
    "hineinlas": "hineinlesen",
    "hineinlasen": "hineinlesen",
    "hineinlast": "hineinlesen",
    "hineinlese": "hineinlesen",
    "hineinlesend": "hineinlesen",
    "hineinlesende": "hineinlesend",
    "hineinlesendem": "hineinlesend",
    "hineinlesenden": "hineinlesend",
    "hineinlesender": "hineinlesend",
    "hineinlesendes": "hineinlesend",
    "hineinlesest": "hineinlesen",
    "hineinleset": "hineinlesen",
    "hineinlest": "hineinlesen",
    "hineinliest": "hineinlesen",
    "hineinläse": "hineinlesen",
    "hineinläsen": "hineinlesen",
    "hineinläsest": "hineinlesen",
    "hineinläset": "hineinlesen",
    "hineinpasse": "hineinpassen",
    "hineinpassend": "hineinpassen",
    "hineinpassende": "hineinpassend",
    "hineinpassendem": "hineinpassend",
    "hineinpassenden": "hineinpassend",
    "hineinpassender": "hineinpassend",
    "hineinpassendere": "hineinpassend",
    "hineinpassenderem": "hineinpassend",
    "hineinpassenderen": "hineinpassend",
    "hineinpassenderer": "hineinpassend",
    "hineinpassenderes": "hineinpassend",
    "hineinpassendes": "hineinpassend",
    "hineinpassendste": "hineinpassend",
    "hineinpassendstem": "hineinpassend",
    "hineinpassendsten": "hineinpassend",
    "hineinpassendster": "hineinpassend",
    "hineinpassendstes": "hineinpassend",
    "hineinpassest": "hineinpassen",
    "hineinpasset": "hineinpassen",
    "hineinpaßt": "hineinpassen",
    "hineinpaßte": "hineinpassen",
    "hineinpaßten": "hineinpassen",
    "hineinpaßtest": "hineinpassen",
    "hineinpaßtet": "hineinpassen",
    "hineinprojiziere": "hineinprojizieren",
    "hineinprojizierend": "hineinprojizieren",
    "hineinprojizierende": "hineinprojizierend",
    "hineinprojizierendem": "hineinprojizierend",
    "hineinprojizierenden": "hineinprojizierend",
    "hineinprojizierender": "hineinprojizierend",
    "hineinprojizierendes": "hineinprojizierend",
    "hineinprojizierest": "hineinprojizieren",
    "hineinprojizieret": "hineinprojizieren",
    "hineinprojizierst": "hineinprojizieren",
    "hineinprojiziert": "hineinprojizieren",
    "hineinprojizierte": "hineinprojizieren",
    "hineinprojiziertem": "hineinprojiziert",
    "hineinprojizierten": "hineinprojizieren",
    "hineinprojizierter": "hineinprojiziert",
    "hineinprojiziertes": "hineinprojiziert",
    "hineinprojiziertest": "hineinprojizieren",
    "hineinprojiziertet": "hineinprojizieren",
    "hineinreiche": "hineinreichen",
    "hineinreichend": "hineinreichen",
    "hineinreichende": "hineinreichend",
    "hineinreichendem": "hineinreichend",
    "hineinreichenden": "hineinreichend",
    "hineinreichender": "hineinreichend",
    "hineinreichendes": "hineinreichend",
    "hineinreichest": "hineinreichen",
    "hineinreichet": "hineinreichen",
    "hineinreichst": "hineinreichen",
    "hineinreicht": "hineinreichen",
    "hineinreichte": "hineinreichen",
    "hineinreichten": "hineinreichen",
    "hineinreichtest": "hineinreichen",
    "hineinreichtet": "hineinreichen",
    "hineinreite": "hineinreiten",
    "hineinreitend": "hineinreiten",
    "hineinreitende": "hineinreitend",
    "hineinreitendem": "hineinreitend",
    "hineinreitenden": "hineinreitend",
    "hineinreitender": "hineinreitend",
    "hineinreitendes": "hineinreitend",
    "hineinreitest": "hineinreiten",
    "hineinreitet": "hineinreiten",
    "hineinritt": "hineinreiten",
    "hineinritte": "hineinreiten",
    "hineinritten": "hineinreiten",
    "hineinrittest": "hineinreiten",
    "hineinrittet": "hineinreiten",
    "hineinschlang": "hineinschlingen",
    "hineinschlangen": "hineinschlingen",
    "hineinschlangst": "hineinschlingen",
    "hineinschlangt": "hineinschlingen",
    "hineinschlinge": "hineinschlingen",
    "hineinschlingend": "hineinschlingen",
    "hineinschlingende": "hineinschlingend",
    "hineinschlingendem": "hineinschlingend",
    "hineinschlingenden": "hineinschlingend",
    "hineinschlingender": "hineinschlingend",
    "hineinschlingendes": "hineinschlingend",
    "hineinschlingest": "hineinschlingen",
    "hineinschlinget": "hineinschlingen",
    "hineinschlingst": "hineinschlingen",
    "hineinschlingt": "hineinschlingen",
    "hineinschlänge": "hineinschlingen",
    "hineinschlängen": "hineinschlingen",
    "hineinschlängest": "hineinschlingen",
    "hineinschlänget": "hineinschlingen",
    "hineinstürze": "hineinstürzen",
    "hineinstürzend": "hineinstürzen",
    "hineinstürzende": "hineinstürzend",
    "hineinstürzendem": "hineinstürzend",
    "hineinstürzenden": "hineinstürzend",
    "hineinstürzender": "hineinstürzend",
    "hineinstürzendes": "hineinstürzend",
    "hineinstürzest": "hineinstürzen",
    "hineinstürzet": "hineinstürzen",
    "hineinstürzt": "hineinstürzen",
    "hineinstürzte": "hineinstürzen",
    "hineinstürzten": "hineinstürzen",
    "hineinstürztest": "hineinstürzen",
    "hineinstürztet": "hineinstürzen",
    "hineinziehe": "hineinziehen",
    "hineinziehend": "hineinziehen",
    "hineinziehende": "hineinziehend",
    "hineinziehendem": "hineinziehend",
    "hineinziehenden": "hineinziehend",
    "hineinziehender": "hineinziehend",
    "hineinziehendes": "hineinziehend",
    "hineinziehest": "hineinziehen",
    "hineinziehet": "hineinziehen",
    "hineinziehst": "hineinziehen",
    "hineinzieht": "hineinziehen",
    "hineinzog": "hineinziehen",
    "hineinzogen": "hineinziehen",
    "hineinzogst": "hineinziehen",
    "hineinzogt": "hineinziehen",
    "hineinzubemühen": "hineinbemühen",
    "hineinzubohren": "hineinbohren",
    "hineinzufressen": "hineinfressen",
    "hineinzuführen": "hineinführen",
    "hineinzuhängen": "hineinhängen",
    "hineinzulesen": "hineinlesen",
    "hineinzupassen": "hineinpassen",
    "hineinzuprojizieren": "hineinprojizieren",
    "hineinzureichen": "hineinreichen",
    "hineinzureiten": "hineinreiten",
    "hineinzuschlingen": "hineinschlingen",
    "hineinzustürzen": "hineinstürzen",
    "hineinzuziehen": "hineinziehen",
    "hineinzöge": "hineinziehen",
    "hineinzögen": "hineinziehen",
    "hineinzögest": "hineinziehen",
    "hineinzöget": "hineinziehen",
    "hinfahre": "hinfahren",
    "hinfahrend": "hinfahren",
    "hinfahrende": "hinfahrend",
    "hinfahrendem": "hinfahrend",
    "hinfahrenden": "hinfahrend",
    "hinfahrender": "hinfahrend",
    "hinfahrendes": "hinfahrend",
    "hinfahrest": "hinfahren",
    "hinfahret": "hinfahren",
    "hinfahrt": "hinfahren",
    "hinfalle": "hinfallen",
    "hinfallend": "hinfallen",
    "hinfallende": "hinfallend",
    "hinfallendem": "hinfallend",
    "hinfallenden": "hinfallend",
    "hinfallender": "hinfallend",
    "hinfallendes": "hinfallend",
    "hinfallest": "hinfallen",
    "hinfallet": "hinfallen",
    "hinfallt": "hinfallen",
    "hinfand": "hinfinden",
    "hinfanden": "hinfinden",
    "hinfandest": "hinfinden",
    "hinfandet": "hinfinden",
    "hinfiel": "hinfallen",
    "hinfiele": "hinfallen",
    "hinfielen": "hinfallen",
    "hinfielest": "hinfallen",
    "hinfielet": "hinfallen",
    "hinfielst": "hinfallen",
    "hinfielt": "hinfallen",
    "hinfinde": "hinfinden",
    "hinfindend": "hinfinden",
    "hinfindende": "hinfindend",
    "hinfindendem": "hinfindend",
    "hinfindenden": "hinfindend",
    "hinfindender": "hinfindend",
    "hinfindendes": "hinfindend",
    "hinfindest": "hinfinden",
    "hinfindet": "hinfinden",
    "hinflegele": "hinflegeln",
    "hinflegelnd": "hinflegeln",
    "hinflegelnde": "hinflegelnd",
    "hinflegelndem": "hinflegelnd",
    "hinflegelnden": "hinflegelnd",
    "hinflegelnder": "hinflegelnd",
    "hinflegelndere": "hinflegelnd",
    "hinflegelnderem": "hinflegelnd",
    "hinflegelnderen": "hinflegelnd",
    "hinflegelnderer": "hinflegelnd",
    "hinflegelnderes": "hinflegelnd",
    "hinflegelndes": "hinflegelnd",
    "hinflegelndste": "hinflegelnd",
    "hinflegelndstem": "hinflegelnd",
    "hinflegelndsten": "hinflegelnd",
    "hinflegelndster": "hinflegelnd",
    "hinflegelndstes": "hinflegelnd",
    "hinflegelst": "hinflegeln",
    "hinflegelt": "hinflegeln",
    "hinflegelte": "hinflegeln",
    "hinflegelten": "hinflegeln",
    "hinflegeltest": "hinflegeln",
    "hinflegeltet": "hinflegeln",
    "hinflegle": "hinflegeln",
    "hinfliege": "hinfliegen",
    "hinfliegend": "hinfliegen",
    "hinfliegende": "hinfliegend",
    "hinfliegendem": "hinfliegend",
    "hinfliegenden": "hinfliegend",
    "hinfliegender": "hinfliegend",
    "hinfliegendes": "hinfliegend",
    "hinfliegest": "hinfliegen",
    "hinflieget": "hinfliegen",
    "hinfliegst": "hinfliegen",
    "hinfliegt": "hinfliegen",
    "hinfließe": "hinfließen",
    "hinfließend": "hinfließen",
    "hinfließende": "hinfließend",
    "hinfließendem": "hinfließend",
    "hinfließenden": "hinfließend",
    "hinfließender": "hinfließend",
    "hinfließendes": "hinfließend",
    "hinfließest": "hinfließen",
    "hinfließet": "hinfließen",
    "hinfließt": "hinfließen",
    "hinflog": "hinfliegen",
    "hinflogen": "hinfliegen",
    "hinflogst": "hinfliegen",
    "hinflogt": "hinfliegen",
    "hinflossen": "hinfließen",
    "hinfloß": "hinfließen",
    "hinfloßt": "hinfließen",
    "hinfläze": "hinfläzen",
    "hinfläzend": "hinfläzen",
    "hinfläzende": "hinfläzend",
    "hinfläzendem": "hinfläzend",
    "hinfläzenden": "hinfläzend",
    "hinfläzender": "hinfläzend",
    "hinfläzendere": "hinfläzend",
    "hinfläzenderem": "hinfläzend",
    "hinfläzenderen": "hinfläzend",
    "hinfläzenderer": "hinfläzend",
    "hinfläzenderes": "hinfläzend",
    "hinfläzendes": "hinfläzend",
    "hinfläzendste": "hinfläzend",
    "hinfläzendstem": "hinfläzend",
    "hinfläzendsten": "hinfläzend",
    "hinfläzendster": "hinfläzend",
    "hinfläzendstes": "hinfläzend",
    "hinfläzest": "hinfläzen",
    "hinfläzet": "hinfläzen",
    "hinfläzt": "hinfläzen",
    "hinfläzte": "hinfläzen",
    "hinfläzten": "hinfläzen",
    "hinfläztest": "hinfläzen",
    "hinfläztet": "hinfläzen",
    "hinflöge": "hinfliegen",
    "hinflögen": "hinfliegen",
    "hinflögest": "hinfliegen",
    "hinflöget": "hinfliegen",
    "hinflösse": "hinfließen",
    "hinflössen": "hinfließen",
    "hinflössest": "hinfließen",
    "hinflösset": "hinfließen",
    "hinfuhr": "hinfahren",
    "hinfuhren": "hinfahren",
    "hinfuhrst": "hinfahren",
    "hinfuhrt": "hinfahren",
    "hinfährst": "hinfahren",
    "hinfährt": "hinfahren",
    "hinfällige": "hinfällig",
    "hinfälligem": "hinfällig",
    "hinfälligen": "hinfällig",
    "hinfälliger": "hinfällig",
    "hinfälliges": "hinfällig",
    "hinfällst": "hinfallen",
    "hinfällt": "hinfallen",
    "hinfände": "hinfinden",
    "hinfänden": "hinfinden",
    "hinfändest": "hinfinden",
    "hinfändet": "hinfinden",
    "hinführe": "hinführen",
    "hinführen": "hinfahren",
    "hinführend": "hinführen",
    "hinführende": "hinführend",
    "hinführendem": "hinführend",
    "hinführenden": "hinführend",
    "hinführender": "hinführend",
    "hinführendes": "hinführend",
    "hinführest": "hinführen",
    "hinführet": "hinführen",
    "hinführst": "hinführen",
    "hinführt": "hinführen",
    "hinführte": "hinführen",
    "hinführten": "hinführen",
    "hinführtest": "hinführen",
    "hinführtet": "hinführen",
    "hing": "hängen",
    "hingab": "hingeben",
    "hingabefähige": "hingabefähig",
    "hingabefähigem": "hingabefähig",
    "hingabefähigen": "hingabefähig",
    "hingabefähiger": "hingabefähig",
    "hingabefähigere": "hingabefähig",
    "hingabefähigerem": "hingabefähig",
    "hingabefähigeren": "hingabefähig",
    "hingabefähigerer": "hingabefähig",
    "hingabefähigeres": "hingabefähig",
    "hingabefähiges": "hingabefähig",
    "hingabefähigste": "hingabefähig",
    "hingabefähigstem": "hingabefähig",
    "hingabefähigsten": "hingabefähig",
    "hingabefähigster": "hingabefähig",
    "hingabefähigstes": "hingabefähig",
    "hingaben": "hingeben",
    "hingabst": "hingeben",
    "hingabt": "hingeben",
    "hinge": "hängen",
    "hingearbeitet": "hinarbeiten",
    "hingearbeitete": "hingearbeitet",
    "hingearbeitetem": "hingearbeitet",
    "hingearbeiteten": "hingearbeitet",
    "hingearbeiteter": "hingearbeitet",
    "hingearbeitetes": "hingearbeitet",
    "hingebe": "hingeben",
    "hingebend": "hingeben",
    "hingebende": "hingebend",
    "hingebendem": "hingebend",
    "hingebenden": "hingebend",
    "hingebender": "hingebend",
    "hingebendes": "hingebend",
    "hingebest": "hingeben",
    "hingebet": "hingeben",
    "hingeblättert": "hinblättern",
    "hingeblätterte": "hingeblättert",
    "hingeblättertem": "hingeblättert",
    "hingeblätterten": "hingeblättert",
    "hingeblätterter": "hingeblättert",
    "hingeblättertes": "hingeblättert",
    "hingebogen": "hinbiegen",
    "hingebogene": "hingebogen",
    "hingebogenem": "hingebogen",
    "hingebogenen": "hingebogen",
    "hingebogener": "hingebogen",
    "hingebogenes": "hingebogen",
    "hingebracht": "hinbringen",
    "hingebrachte": "hingebracht",
    "hingebrachtem": "hingebracht",
    "hingebrachten": "hingebracht",
    "hingebrachter": "hingebracht",
    "hingebrachtes": "hingebracht",
    "hingebrütet": "hinbrüten",
    "hingebrütete": "hingebrütet",
    "hingebrütetem": "hingebrütet",
    "hingebrüteten": "hingebrütet",
    "hingebrüteter": "hingebrütet",
    "hingebrütetes": "hingebrütet",
    "hingebt": "hingeben",
    "hingebungsvolle": "hingebungsvoll",
    "hingebungsvollem": "hingebungsvoll",
    "hingebungsvollen": "hingebungsvoll",
    "hingebungsvoller": "hingebungsvoll",
    "hingebungsvollere": "hingebungsvoll",
    "hingebungsvollerem": "hingebungsvoll",
    "hingebungsvolleren": "hingebungsvoll",
    "hingebungsvollerer": "hingebungsvoll",
    "hingebungsvolleres": "hingebungsvoll",
    "hingebungsvolles": "hingebungsvoll",
    "hingebungsvollste": "hingebungsvoll",
    "hingebungsvollstem": "hingebungsvoll",
    "hingebungsvollsten": "hingebungsvoll",
    "hingebungsvollster": "hingebungsvoll",
    "hingebungsvollstes": "hingebungsvoll",
    "hingedacht": "hindenken",
    "hingedachte": "hingedacht",
    "hingedachtem": "hingedacht",
    "hingedachten": "hingedacht",
    "hingedachter": "hingedacht",
    "hingedachtes": "hingedacht",
    "hingedeutet": "hindeuten",
    "hingedeutete": "hingedeutet",
    "hingedeutetem": "hingedeutet",
    "hingedeuteten": "hingedeutet",
    "hingedeuteter": "hingedeutet",
    "hingedeutetes": "hingedeutet",
    "hingedrängt": "hindrängen",
    "hingedrängte": "hingedrängt",
    "hingedrängtem": "hingedrängt",
    "hingedrängten": "hingedrängt",
    "hingedrängter": "hingedrängt",
    "hingedrängtes": "hingedrängt",
    "hingedämmert": "hindämmern",
    "hingedämmerte": "hingedämmert",
    "hingedämmertem": "hingedämmert",
    "hingedämmerten": "hingedämmert",
    "hingedämmerter": "hingedämmert",
    "hingedämmertes": "hingedämmert",
    "hingeeilt": "hineilen",
    "hingeeilte": "hingeeilt",
    "hingeeiltem": "hingeeilt",
    "hingeeilten": "hingeeilt",
    "hingeeilter": "hingeeilt",
    "hingeeiltes": "hingeeilt",
    "hingefahren": "hinfahren",
    "hingefahrene": "hingefahren",
    "hingefahrenem": "hingefahren",
    "hingefahrenen": "hingefahren",
    "hingefahrener": "hingefahren",
    "hingefahrenes": "hingefahren",
    "hingefallen": "hinfallen",
    "hingefallene": "hingefallen",
    "hingefallenem": "hingefallen",
    "hingefallenen": "hingefallen",
    "hingefallener": "hingefallen",
    "hingefallenes": "hingefallen",
    "hingeflegelt": "hinflegeln",
    "hingeflegelte": "hingeflegelt",
    "hingeflegeltem": "hingeflegelt",
    "hingeflegelten": "hingeflegelt",
    "hingeflegelter": "hingeflegelt",
    "hingeflegeltes": "hingeflegelt",
    "hingeflogen": "hinfliegen",
    "hingeflogene": "hingeflogen",
    "hingeflogenem": "hingeflogen",
    "hingeflogenen": "hingeflogen",
    "hingeflogener": "hingeflogen",
    "hingeflogenes": "hingeflogen",
    "hingeflossen": "hinfließen",
    "hingeflossene": "hingeflossen",
    "hingeflossenem": "hingeflossen",
    "hingeflossenen": "hingeflossen",
    "hingeflossener": "hingeflossen",
    "hingeflossenes": "hingeflossen",
    "hingefläzt": "hinfläzen",
    "hingefläzte": "hingefläzt",
    "hingefläztem": "hingefläzt",
    "hingefläzten": "hingefläzt",
    "hingefläzter": "hingefläzt",
    "hingefläztere": "hingefläzt",
    "hingefläzterem": "hingefläzt",
    "hingefläzteren": "hingefläzt",
    "hingefläzterer": "hingefläzt",
    "hingefläzteres": "hingefläzt",
    "hingefläztes": "hingefläzt",
    "hingefläzteste": "hingefläzt",
    "hingefläztestem": "hingefläzt",
    "hingefläztesten": "hingefläzt",
    "hingefläztester": "hingefläzt",
    "hingefläztestes": "hingefläzt",
    "hingefunden": "hinfinden",
    "hingefundene": "hingefunden",
    "hingefundenem": "hingefunden",
    "hingefundenen": "hingefunden",
    "hingefundener": "hingefunden",
    "hingefundenes": "hingefunden",
    "hingeführt": "hinführen",
    "hingeführte": "hingeführt",
    "hingeführtem": "hingeführt",
    "hingeführten": "hingeführt",
    "hingeführter": "hingeführt",
    "hingeführtes": "hingeführt",
    "hingegangen": "hingehen",
    "hingegangene": "hingegangen",
    "hingegangenem": "hingegangen",
    "hingegangenen": "hingegangen",
    "hingegangener": "hingegangen",
    "hingegangenes": "hingegangen",
    "hingegeben": "hingeben",
    "hingegebene": "hingegeben",
    "hingegebenem": "hingegeben",
    "hingegebenen": "hingegeben",
    "hingegebener": "hingegeben",
    "hingegebenes": "hingegeben",
    "hingegossen": "hingießen",
    "hingegossene": "hingegossen",
    "hingegossenem": "hingegossen",
    "hingegossenen": "hingegossen",
    "hingegossener": "hingegossen",
    "hingegossenes": "hingegossen",
    "hingehalten": "hinhalten",
    "hingehaltene": "hingehalten",
    "hingehaltenem": "hingehalten",
    "hingehaltenen": "hingehalten",
    "hingehaltener": "hingehalten",
    "hingehaltenere": "hingehalten",
    "hingehaltenerem": "hingehalten",
    "hingehalteneren": "hingehalten",
    "hingehaltenerer": "hingehalten",
    "hingehalteneres": "hingehalten",
    "hingehaltenes": "hingehalten",
    "hingehaltenste": "hingehalten",
    "hingehaltenstem": "hingehalten",
    "hingehaltensten": "hingehalten",
    "hingehaltenster": "hingehalten",
    "hingehaltenstes": "hingehalten",
    "hingehangen": "hinhängen",
    "hingehangene": "hingehangen",
    "hingehangenem": "hingehangen",
    "hingehangenen": "hingehangen",
    "hingehangener": "hingehangen",
    "hingehangenes": "hingehangen",
    "hingehaucht": "hinhauchen",
    "hingehauchte": "hingehaucht",
    "hingehauchtem": "hingehaucht",
    "hingehauchten": "hingehaucht",
    "hingehauchter": "hingehaucht",
    "hingehauchtes": "hingehaucht",
    "hingehauen": "hinhauen",
    "hingehauene": "hingehauen",
    "hingehauenem": "hingehauen",
    "hingehauenen": "hingehauen",
    "hingehauener": "hingehauen",
    "hingehauenes": "hingehauen",
    "hingehe": "hingehen",
    "hingehend": "hingehen",
    "hingehende": "hingehend",
    "hingehendem": "hingehend",
    "hingehenden": "hingehend",
    "hingehender": "hingehend",
    "hingehendes": "hingehend",
    "hingehest": "hingehen",
    "hingehet": "hingehen",
    "hingehorcht": "hinhorchen",
    "hingehorchte": "hingehorcht",
    "hingehorchtem": "hingehorcht",
    "hingehorchten": "hingehorcht",
    "hingehorchter": "hingehorcht",
    "hingehorchtere": "hingehorcht",
    "hingehorchterem": "hingehorcht",
    "hingehorchteren": "hingehorcht",
    "hingehorchterer": "hingehorcht",
    "hingehorchteres": "hingehorcht",
    "hingehorchtes": "hingehorcht",
    "hingehorchteste": "hingehorcht",
    "hingehorchtestem": "hingehorcht",
    "hingehorchtesten": "hingehorcht",
    "hingehorchtester": "hingehorcht",
    "hingehorchtestes": "hingehorcht",
    "hingehst": "hingehen",
    "hingeht": "hingehen",
    "hingehängt": "hinhängen",
    "hingehängte": "hingehängt",
    "hingehängtem": "hingehängt",
    "hingehängten": "hingehängt",
    "hingehängter": "hingehängt",
    "hingehängtes": "hingehängt",
    "hingehöre": "hingehören",
    "hingehörend": "hingehören",
    "hingehörende": "hingehörend",
    "hingehörendem": "hingehörend",
    "hingehörenden": "hingehörend",
    "hingehörender": "hingehörend",
    "hingehörendes": "hingehörend",
    "hingehörest": "hingehören",
    "hingehöret": "hingehören",
    "hingehörst": "hingehören",
    "hingehört": "hinhören",
    "hingehörte": "hingehören",
    "hingehörtem": "hingehört",
    "hingehörten": "hingehören",
    "hingehörter": "hingehört",
    "hingehörtes": "hingehört",
    "hingehörtest": "hingehören",
    "hingehörtet": "hingehören",
    "hingekauert": "hinkauern",
    "hingekauerte": "hingekauert",
    "hingekauertem": "hingekauert",
    "hingekauerten": "hingekauert",
    "hingekauerter": "hingekauert",
    "hingekauertere": "hingekauert",
    "hingekauerterem": "hingekauert",
    "hingekauerteren": "hingekauert",
    "hingekauerterer": "hingekauert",
    "hingekauerteres": "hingekauert",
    "hingekauertes": "hingekauert",
    "hingekauerteste": "hingekauert",
    "hingekauertestem": "hingekauert",
    "hingekauertesten": "hingekauert",
    "hingekauertester": "hingekauert",
    "hingekauertestes": "hingekauert",
    "hingeklotzt": "hinklotzen",
    "hingeklotzte": "hingeklotzt",
    "hingeklotztem": "hingeklotzt",
    "hingeklotzten": "hingeklotzt",
    "hingeklotzter": "hingeklotzt",
    "hingeklotztes": "hingeklotzt",
    "hingekniet": "hinknien",
    "hingekniete": "hingekniet",
    "hingeknietem": "hingekniet",
    "hingeknieten": "hingekniet",
    "hingeknieter": "hingekniet",
    "hingeknietes": "hingekniet",
    "hingekommen": "hinkommen",
    "hingekommene": "hingekommen",
    "hingekommenem": "hingekommen",
    "hingekommenen": "hingekommen",
    "hingekommener": "hingekommen",
    "hingekommenes": "hingekommen",
    "hingekriegt": "hinkriegen",
    "hingekriegte": "hingekriegt",
    "hingekriegtem": "hingekriegt",
    "hingekriegten": "hingekriegt",
    "hingekriegter": "hingekriegt",
    "hingekriegtes": "hingekriegt",
    "hingelangt": "hinlangen",
    "hingelangte": "hingelangt",
    "hingelangtem": "hingelangt",
    "hingelangten": "hingelangt",
    "hingelangter": "hingelangt",
    "hingelangtes": "hingelangt",
    "hingelassen": "hinlassen",
    "hingelassene": "hingelassen",
    "hingelassenem": "hingelassen",
    "hingelassenen": "hingelassen",
    "hingelassener": "hingelassen",
    "hingelassenes": "hingelassen",
    "hingelaufen": "hinlaufen",
    "hingelaufene": "hingelaufen",
    "hingelaufenem": "hingelaufen",
    "hingelaufenen": "hingelaufen",
    "hingelaufener": "hingelaufen",
    "hingelaufenes": "hingelaufen",
    "hingelegt": "hinlegen",
    "hingelegte": "hingelegt",
    "hingelegtem": "hingelegt",
    "hingelegten": "hingelegt",
    "hingelegter": "hingelegt",
    "hingelegtes": "hingelegt",
    "hingelümmelt": "hinlümmeln",
    "hingelümmelte": "hingelümmelt",
    "hingelümmeltem": "hingelümmelt",
    "hingelümmelten": "hingelümmelt",
    "hingelümmelter": "hingelümmelt",
    "hingelümmeltere": "hingelümmelt",
    "hingelümmelterem": "hingelümmelt",
    "hingelümmelteren": "hingelümmelt",
    "hingelümmelterer": "hingelümmelt",
    "hingelümmelteres": "hingelümmelt",
    "hingelümmeltes": "hingelümmelt",
    "hingelümmelteste": "hingelümmelt",
    "hingelümmeltestem": "hingelümmelt",
    "hingelümmeltesten": "hingelümmelt",
    "hingelümmeltester": "hingelümmelt",
    "hingelümmeltestes": "hingelümmelt",
    "hingemacht": "hinmachen",
    "hingemachte": "hingemacht",
    "hingemachtem": "hingemacht",
    "hingemachten": "hingemacht",
    "hingemachter": "hingemacht",
    "hingemachtes": "hingemacht",
    "hingen": "hängen",
    "hingeneigt": "hinneigen",
    "hingeneigte": "hingeneigt",
    "hingeneigtem": "hingeneigt",
    "hingeneigten": "hingeneigt",
    "hingeneigter": "hingeneigt",
    "hingeneigtes": "hingeneigt",
    "hingenommen": "hinnehmen",
    "hingenommene": "hingenommen",
    "hingenommenem": "hingenommen",
    "hingenommenen": "hingenommen",
    "hingenommener": "hingenommen",
    "hingenommenes": "hingenommen",
    "hingepurzelt": "hinpurzeln",
    "hingepurzelte": "hingepurzelt",
    "hingepurzeltem": "hingepurzelt",
    "hingepurzelten": "hingepurzelt",
    "hingepurzelter": "hingepurzelt",
    "hingepurzeltes": "hingepurzelt",
    "hingerafft": "hinraffen",
    "hingeraffte": "hingerafft",
    "hingerafftem": "hingerafft",
    "hingerafften": "hingerafft",
    "hingeraffter": "hingerafft",
    "hingerafftes": "hingerafft",
    "hingerannt": "hinrennen",
    "hingerannte": "hingerannt",
    "hingeranntem": "hingerannt",
    "hingerannten": "hingerannt",
    "hingerannter": "hingerannt",
    "hingeranntes": "hingerannt",
    "hingerate": "hingeraten",
    "hingeratend": "hingeraten",
    "hingeratende": "hingeratend",
    "hingeratendem": "hingeratend",
    "hingeratenden": "hingeratend",
    "hingeratender": "hingeratend",
    "hingeratendes": "hingeratend",
    "hingeratene": "hingeraten",
    "hingeratenem": "hingeraten",
    "hingeratenen": "hingeraten",
    "hingeratener": "hingeraten",
    "hingeratenes": "hingeraten",
    "hingeratest": "hingeraten",
    "hingeratet": "hingeraten",
    "hingereicht": "hinreichen",
    "hingereichte": "hingereicht",
    "hingereichtem": "hingereicht",
    "hingereichten": "hingereicht",
    "hingereichter": "hingereicht",
    "hingereichtes": "hingereicht",
    "hingereist": "hinreisen",
    "hingereiste": "hingereist",
    "hingereistem": "hingereist",
    "hingereisten": "hingereist",
    "hingereister": "hingereist",
    "hingereistes": "hingereist",
    "hingerichtet": "hinrichten",
    "hingerichtete": "hingerichtet",
    "hingerichtetem": "hingerichtet",
    "hingerichteten": "hingerichtet",
    "hingerichteter": "hingerichtet",
    "hingerichtetes": "hingerichtet",
    "hingerieben": "hinreiben",
    "hingeriebene": "hingerieben",
    "hingeriebenem": "hingerieben",
    "hingeriebenen": "hingerieben",
    "hingeriebener": "hingerieben",
    "hingeriebenes": "hingerieben",
    "hingeriet": "hingeraten",
    "hingeriete": "hingeraten",
    "hingerieten": "hingeraten",
    "hingerietest": "hingeraten",
    "hingerietet": "hingeraten",
    "hingerissen": "hinreißen",
    "hingerissene": "hingerissen",
    "hingerissenem": "hingerissen",
    "hingerissenen": "hingerissen",
    "hingerissener": "hingerissen",
    "hingerissenere": "hingerissen",
    "hingerissenerem": "hingerissen",
    "hingerisseneren": "hingerissen",
    "hingerissenerer": "hingerissen",
    "hingerisseneres": "hingerissen",
    "hingerissenes": "hingerissen",
    "hingerissenste": "hingerissen",
    "hingerissenstem": "hingerissen",
    "hingerissensten": "hingerissen",
    "hingerissenster": "hingerissen",
    "hingerissenstes": "hingerissen",
    "hingerät": "hingeraten",
    "hingerätst": "hingeraten",
    "hingesagt": "hinsagen",
    "hingesagte": "hingesagt",
    "hingesagtem": "hingesagt",
    "hingesagten": "hingesagt",
    "hingesagter": "hingesagt",
    "hingesagtes": "hingesagt",
    "hingeschaffen": "hinschaffen",
    "hingeschaffene": "hingeschaffen",
    "hingeschaffenem": "hingeschaffen",
    "hingeschaffenen": "hingeschaffen",
    "hingeschaffener": "hingeschaffen",
    "hingeschaffenes": "hingeschaffen",
    "hingeschafft": "hinschaffen",
    "hingeschaffte": "hingeschafft",
    "hingeschafftem": "hingeschafft",
    "hingeschafften": "hingeschafft",
    "hingeschaffter": "hingeschafft",
    "hingeschafftes": "hingeschafft",
    "hingeschaut": "hinschauen",
    "hingeschaute": "hingeschaut",
    "hingeschautem": "hingeschaut",
    "hingeschauten": "hingeschaut",
    "hingeschauter": "hingeschaut",
    "hingeschautes": "hingeschaut",
    "hingeschieden": "hinscheiden",
    "hingeschiedene": "hingeschieden",
    "hingeschiedenem": "hingeschieden",
    "hingeschiedenen": "hingeschieden",
    "hingeschiedener": "hingeschieden",
    "hingeschiedenes": "hingeschieden",
    "hingeschlachtet": "hinschlachten",
    "hingeschlachtete": "hingeschlachtet",
    "hingeschlachtetem": "hingeschlachtet",
    "hingeschlachteten": "hingeschlachtet",
    "hingeschlachteter": "hingeschlachtet",
    "hingeschlachtetes": "hingeschlachtet",
    "hingeschlagen": "hinschlagen",
    "hingeschlagene": "hingeschlagen",
    "hingeschlagenem": "hingeschlagen",
    "hingeschlagenen": "hingeschlagen",
    "hingeschlagener": "hingeschlagen",
    "hingeschlagenes": "hingeschlagen",
    "hingeschleppt": "hinschleppen",
    "hingeschleppte": "hingeschleppt",
    "hingeschlepptem": "hingeschleppt",
    "hingeschleppten": "hingeschleppt",
    "hingeschleppter": "hingeschleppt",
    "hingeschlepptes": "hingeschleppt",
    "hingeschlichen": "hinschleichen",
    "hingeschlichene": "hingeschlichen",
    "hingeschlichenem": "hingeschlichen",
    "hingeschlichenen": "hingeschlichen",
    "hingeschlichener": "hingeschlichen",
    "hingeschlichenes": "hingeschlichen",
    "hingeschmiert": "hinschmieren",
    "hingeschmierte": "hingeschmiert",
    "hingeschmiertem": "hingeschmiert",
    "hingeschmierten": "hingeschmiert",
    "hingeschmierter": "hingeschmiert",
    "hingeschmiertes": "hingeschmiert",
    "hingeschmissen": "hinschmeißen",
    "hingeschmissene": "hingeschmissen",
    "hingeschmissenem": "hingeschmissen",
    "hingeschmissenen": "hingeschmissen",
    "hingeschmissener": "hingeschmissen",
    "hingeschmissenes": "hingeschmissen",
    "hingeschmolzen": "hinschmelzen",
    "hingeschmolzene": "hingeschmolzen",
    "hingeschmolzenem": "hingeschmolzen",
    "hingeschmolzenen": "hingeschmolzen",
    "hingeschmolzener": "hingeschmolzen",
    "hingeschmolzenere": "hingeschmolzen",
    "hingeschmolzenerem": "hingeschmolzen",
    "hingeschmolzeneren": "hingeschmolzen",
    "hingeschmolzenerer": "hingeschmolzen",
    "hingeschmolzeneres": "hingeschmolzen",
    "hingeschmolzenes": "hingeschmolzen",
    "hingeschmolzenste": "hingeschmolzen",
    "hingeschmolzenstem": "hingeschmolzen",
    "hingeschmolzensten": "hingeschmolzen",
    "hingeschmolzenster": "hingeschmolzen",
    "hingeschmolzenstes": "hingeschmolzen",
    "hingeschoben": "hinschieben",
    "hingeschobene": "hingeschoben",
    "hingeschobenem": "hingeschoben",
    "hingeschobenen": "hingeschoben",
    "hingeschobener": "hingeschoben",
    "hingeschobenes": "hingeschoben",
    "hingeschrieben": "hinschreiben",
    "hingeschriebene": "hingeschrieben",
    "hingeschriebenem": "hingeschrieben",
    "hingeschriebenen": "hingeschrieben",
    "hingeschriebener": "hingeschrieben",
    "hingeschriebenes": "hingeschrieben",
    "hingeschwommen": "hinschwimmen",
    "hingeschwommene": "hingeschwommen",
    "hingeschwommenem": "hingeschwommen",
    "hingeschwommenen": "hingeschwommen",
    "hingeschwommener": "hingeschwommen",
    "hingeschwommenes": "hingeschwommen",
    "hingeschwunden": "hinschwinden",
    "hingeschwundene": "hingeschwunden",
    "hingeschwundenem": "hingeschwunden",
    "hingeschwundenen": "hingeschwunden",
    "hingeschwundener": "hingeschwunden",
    "hingeschwundenes": "hingeschwunden",
    "hingeschüttet": "hinschütten",
    "hingeschüttete": "hingeschüttet",
    "hingeschüttetem": "hingeschüttet",
    "hingeschütteten": "hingeschüttet",
    "hingeschütteter": "hingeschüttet",
    "hingeschüttetes": "hingeschüttet",
    "hingesehen": "hinsehen",
    "hingesehene": "hingesehen",
    "hingesehenem": "hingesehen",
    "hingesehenen": "hingesehen",
    "hingesehener": "hingesehen",
    "hingesehenes": "hingesehen",
    "hingesetzt": "hinsetzen",
    "hingesetzte": "hingesetzt",
    "hingesetztem": "hingesetzt",
    "hingesetzten": "hingesetzt",
    "hingesetzter": "hingesetzt",
    "hingesetztes": "hingesetzt",
    "hingesiecht": "hinsiechen",
    "hingesiechte": "hingesiecht",
    "hingesiechtem": "hingesiecht",
    "hingesiechten": "hingesiecht",
    "hingesiechter": "hingesiecht",
    "hingesiechtere": "hingesiecht",
    "hingesiechterem": "hingesiecht",
    "hingesiechteren": "hingesiecht",
    "hingesiechterer": "hingesiecht",
    "hingesiechteres": "hingesiecht",
    "hingesiechtes": "hingesiecht",
    "hingesiechteste": "hingesiecht",
    "hingesiechtestem": "hingesiecht",
    "hingesiechtesten": "hingesiecht",
    "hingesiechtester": "hingesiecht",
    "hingesiechtestes": "hingesiecht",
    "hingest": "hängen",
    "hingestellt": "hinstellen",
    "hingestellte": "hingestellt",
    "hingestelltem": "hingestellt",
    "hingestellten": "hingestellt",
    "hingestellter": "hingestellt",
    "hingestelltes": "hingestellt",
    "hingesteuert": "hinsteuern",
    "hingesteuerte": "hingesteuert",
    "hingesteuertem": "hingesteuert",
    "hingesteuerten": "hingesteuert",
    "hingesteuerter": "hingesteuert",
    "hingesteuertes": "hingesteuert",
    "hingestorben": "hinsterben",
    "hingestorbene": "hingestorben",
    "hingestorbenem": "hingestorben",
    "hingestorbenen": "hingestorben",
    "hingestorbener": "hingestorben",
    "hingestorbenes": "hingestorben",
    "hingestrebt": "hinstreben",
    "hingestrebte": "hingestrebt",
    "hingestrebtem": "hingestrebt",
    "hingestrebten": "hingestrebt",
    "hingestrebter": "hingestrebt",
    "hingestrebtes": "hingestrebt",
    "hingeströmt": "hinströmen",
    "hingeströmte": "hingeströmt",
    "hingeströmtem": "hingeströmt",
    "hingeströmten": "hingeströmt",
    "hingeströmter": "hingeströmt",
    "hingeströmtes": "hingeströmt",
    "hingestürzt": "hinstürzen",
    "hingestürzte": "hingestürzt",
    "hingestürztem": "hingestürzt",
    "hingestürzten": "hingestürzt",
    "hingestürzter": "hingestürzt",
    "hingestürztes": "hingestürzt",
    "hingesunken": "hinsinken",
    "hingesunkene": "hingesunken",
    "hingesunkenem": "hingesunken",
    "hingesunkenen": "hingesunken",
    "hingesunkener": "hingesunken",
    "hingesunkenes": "hingesunken",
    "hinget": "hängen",
    "hingetragen": "hintragen",
    "hingetragene": "hingetragen",
    "hingetragenem": "hingetragen",
    "hingetragenen": "hingetragen",
    "hingetragener": "hingetragen",
    "hingetragenes": "hingetragen",
    "hingetreten": "hintreten",
    "hingetretene": "hingetreten",
    "hingetretenem": "hingetreten",
    "hingetretenen": "hingetreten",
    "hingetretener": "hingetreten",
    "hingetretenes": "hingetreten",
    "hingetrieben": "hintreiben",
    "hingetriebene": "hingetrieben",
    "hingetriebenem": "hingetrieben",
    "hingetriebenen": "hingetrieben",
    "hingetriebener": "hingetrieben",
    "hingetriebenes": "hingetrieben",
    "hingewandt": "hinwenden",
    "hingewandte": "hingewandt",
    "hingewandtem": "hingewandt",
    "hingewandten": "hingewandt",
    "hingewandter": "hingewandt",
    "hingewandtes": "hingewandt",
    "hingewelkt": "hinwelken",
    "hingewelkte": "hingewelkt",
    "hingewelktem": "hingewelkt",
    "hingewelkten": "hingewelkt",
    "hingewelkter": "hingewelkt",
    "hingewelktere": "hingewelkt",
    "hingewelkterem": "hingewelkt",
    "hingewelkteren": "hingewelkt",
    "hingewelkterer": "hingewelkt",
    "hingewelkteres": "hingewelkt",
    "hingewelktes": "hingewelkt",
    "hingewelkteste": "hingewelkt",
    "hingewelktestem": "hingewelkt",
    "hingewelktesten": "hingewelkt",
    "hingewelktester": "hingewelkt",
    "hingewelktestes": "hingewelkt",
    "hingewendet": "hinwenden",
    "hingewendete": "hingewendet",
    "hingewendetem": "hingewendet",
    "hingewendeten": "hingewendet",
    "hingewendeter": "hingewendet",
    "hingewendetes": "hingewendet",
    "hingewiesen": "hinweisen",
    "hingewiesene": "hingewiesen",
    "hingewiesenem": "hingewiesen",
    "hingewiesenen": "hingewiesen",
    "hingewiesener": "hingewiesen",
    "hingewiesenes": "hingewiesen",
    "hingewirkt": "hinwirken",
    "hingewirkte": "hingewirkt",
    "hingewirktem": "hingewirkt",
    "hingewirkten": "hingewirkt",
    "hingewirkter": "hingewirkt",
    "hingewirktes": "hingewirkt",
    "hingeworfen": "hinwerfen",
    "hingeworfene": "hingeworfen",
    "hingeworfenem": "hingeworfen",
    "hingeworfenen": "hingeworfen",
    "hingeworfener": "hingeworfen",
    "hingeworfenes": "hingeworfen",
    "hingezaubert": "hinzaubern",
    "hingezauberte": "hingezaubert",
    "hingezaubertem": "hingezaubert",
    "hingezauberten": "hingezaubert",
    "hingezauberter": "hingezaubert",
    "hingezaubertes": "hingezaubert",
    "hingezeigt": "hinzeigen",
    "hingezeigte": "hingezeigt",
    "hingezeigtem": "hingezeigt",
    "hingezeigten": "hingezeigt",
    "hingezeigter": "hingezeigt",
    "hingezeigtes": "hingezeigt",
    "hingezogen": "hinziehen",
    "hingezogene": "hingezogen",
    "hingezogenem": "hingezogen",
    "hingezogenen": "hingezogen",
    "hingezogener": "hingezogen",
    "hingezogenere": "hingezogen",
    "hingezogenerem": "hingezogen",
    "hingezogeneren": "hingezogen",
    "hingezogenerer": "hingezogen",
    "hingezogeneres": "hingezogen",
    "hingezogenes": "hingezogen",
    "hingezogenste": "hingezogen",
    "hingezogenstem": "hingezogen",
    "hingezogensten": "hingezogen",
    "hingezogenster": "hingezogen",
    "hingezogenstes": "hingezogen",
    "hingezählt": "hinzählen",
    "hingezählte": "hingezählt",
    "hingezähltem": "hingezählt",
    "hingezählten": "hingezählt",
    "hingezählter": "hingezählt",
    "hingezähltes": "hingezählt",
    "hingibst": "hingeben",
    "hingibt": "hingeben",
    "hingieße": "hingießen",
    "hingießend": "hingießen",
    "hingießende": "hingießend",
    "hingießendem": "hingießend",
    "hingießenden": "hingießend",
    "hingießender": "hingießend",
    "hingießendes": "hingießend",
    "hingießest": "hingießen",
    "hingießet": "hingießen",
    "hingießt": "hingießen",
    "hinging": "hingehen",
    "hinginge": "hingehen",
    "hingingen": "hingehen",
    "hingingest": "hingehen",
    "hinginget": "hingehen",
    "hingingst": "hingehen",
    "hingingt": "hingehen",
    "hingossen": "hingießen",
    "hingoß": "hingießen",
    "hingoßt": "hingießen",
    "hingst": "hängen",
    "hingt": "hängen",
    "hingäbe": "hingeben",
    "hingäben": "hingeben",
    "hingäbest": "hingeben",
    "hingäbet": "hingeben",
    "hingösse": "hingießen",
    "hingössen": "hingießen",
    "hingössest": "hingießen",
    "hingösset": "hingießen",
    "hinhalte": "hinhalten",
    "hinhaltend": "hinhalten",
    "hinhaltende": "hinhaltend",
    "hinhaltendem": "hinhaltend",
    "hinhaltenden": "hinhaltend",
    "hinhaltender": "hinhaltend",
    "hinhaltendere": "hinhaltend",
    "hinhaltenderem": "hinhaltend",
    "hinhaltenderen": "hinhaltend",
    "hinhaltenderer": "hinhaltend",
    "hinhaltenderes": "hinhaltend",
    "hinhaltendes": "hinhaltend",
    "hinhaltendste": "hinhaltend",
    "hinhaltendstem": "hinhaltend",
    "hinhaltendsten": "hinhaltend",
    "hinhaltendster": "hinhaltend",
    "hinhaltendstes": "hinhaltend",
    "hinhaltest": "hinhalten",
    "hinhaltet": "hinhalten",
    "hinhauche": "hinhauchen",
    "hinhauchend": "hinhauchen",
    "hinhauchende": "hinhauchend",
    "hinhauchendem": "hinhauchend",
    "hinhauchenden": "hinhauchend",
    "hinhauchender": "hinhauchend",
    "hinhauchendes": "hinhauchend",
    "hinhauchest": "hinhauchen",
    "hinhauchet": "hinhauchen",
    "hinhauchst": "hinhauchen",
    "hinhaucht": "hinhauchen",
    "hinhauchte": "hinhauchen",
    "hinhauchten": "hinhauchen",
    "hinhauchtest": "hinhauchen",
    "hinhauchtet": "hinhauchen",
    "hinhaue": "hinhauen",
    "hinhauend": "hinhauen",
    "hinhauende": "hinhauend",
    "hinhauendem": "hinhauend",
    "hinhauenden": "hinhauend",
    "hinhauender": "hinhauend",
    "hinhauendes": "hinhauend",
    "hinhauest": "hinhauen",
    "hinhauet": "hinhauen",
    "hinhaust": "hinhauen",
    "hinhaut": "hinhauen",
    "hinhaute": "hinhauen",
    "hinhauten": "hinhauen",
    "hinhautest": "hinhauen",
    "hinhautet": "hinhauen",
    "hinhielt": "hinhalten",
    "hinhielte": "hinhalten",
    "hinhielten": "hinhalten",
    "hinhieltest": "hinhalten",
    "hinhieltet": "hinhalten",
    "hinhing": "hinhängen",
    "hinhinge": "hinhängen",
    "hinhingen": "hinhängen",
    "hinhingest": "hinhängen",
    "hinhinget": "hinhängen",
    "hinhingst": "hinhängen",
    "hinhingt": "hinhängen",
    "hinhorche": "hinhorchen",
    "hinhorchend": "hinhorchen",
    "hinhorchende": "hinhorchend",
    "hinhorchendem": "hinhorchend",
    "hinhorchenden": "hinhorchend",
    "hinhorchender": "hinhorchend",
    "hinhorchendere": "hinhorchend",
    "hinhorchenderem": "hinhorchend",
    "hinhorchenderen": "hinhorchend",
    "hinhorchenderer": "hinhorchend",
    "hinhorchenderes": "hinhorchend",
    "hinhorchendes": "hinhorchend",
    "hinhorchendste": "hinhorchend",
    "hinhorchendstem": "hinhorchend",
    "hinhorchendsten": "hinhorchend",
    "hinhorchendster": "hinhorchend",
    "hinhorchendstes": "hinhorchend",
    "hinhorchest": "hinhorchen",
    "hinhorchet": "hinhorchen",
    "hinhorchst": "hinhorchen",
    "hinhorcht": "hinhorchen",
    "hinhorchte": "hinhorchen",
    "hinhorchten": "hinhorchen",
    "hinhorchtest": "hinhorchen",
    "hinhorchtet": "hinhorchen",
    "hinhält": "hinhalten",
    "hinhältst": "hinhalten",
    "hinhänge": "hinhängen",
    "hinhängend": "hinhängen",
    "hinhängende": "hinhängend",
    "hinhängendem": "hinhängend",
    "hinhängenden": "hinhängend",
    "hinhängender": "hinhängend",
    "hinhängendes": "hinhängend",
    "hinhängest": "hinhängen",
    "hinhänget": "hinhängen",
    "hinhängst": "hinhängen",
    "hinhängt": "hinhängen",
    "hinhängte": "hinhängen",
    "hinhängten": "hinhängen",
    "hinhängtest": "hinhängen",
    "hinhängtet": "hinhängen",
    "hinhöre": "hinhören",
    "hinhörend": "hinhören",
    "hinhörende": "hinhörend",
    "hinhörendem": "hinhörend",
    "hinhörenden": "hinhörend",
    "hinhörender": "hinhörend",
    "hinhörendere": "hinhörend",
    "hinhörenderem": "hinhörend",
    "hinhörenderen": "hinhörend",
    "hinhörenderer": "hinhörend",
    "hinhörenderes": "hinhörend",
    "hinhörendes": "hinhörend",
    "hinhörendste": "hinhörend",
    "hinhörendstem": "hinhörend",
    "hinhörendsten": "hinhörend",
    "hinhörendster": "hinhörend",
    "hinhörendstes": "hinhörend",
    "hinhörest": "hinhören",
    "hinhöret": "hinhören",
    "hinhörst": "hinhören",
    "hinhört": "hinhören",
    "hinhörte": "hinhören",
    "hinhörten": "hinhören",
    "hinhörtest": "hinhören",
    "hinhörtet": "hinhören",
    "hinkam": "hinkommen",
    "hinkamen": "hinkommen",
    "hinkamst": "hinkommen",
    "hinkamt": "hinkommen",
    "hinkauere": "hinkauern",
    "hinkauernd": "hinkauern",
    "hinkauernde": "hinkauernd",
    "hinkauerndem": "hinkauernd",
    "hinkauernden": "hinkauernd",
    "hinkauernder": "hinkauernd",
    "hinkauerndere": "hinkauernd",
    "hinkauernderem": "hinkauernd",
    "hinkauernderen": "hinkauernd",
    "hinkauernderer": "hinkauernd",
    "hinkauernderes": "hinkauernd",
    "hinkauerndes": "hinkauernd",
    "hinkauerndste": "hinkauernd",
    "hinkauerndstem": "hinkauernd",
    "hinkauerndsten": "hinkauernd",
    "hinkauerndster": "hinkauernd",
    "hinkauerndstes": "hinkauernd",
    "hinkauerst": "hinkauern",
    "hinkauert": "hinkauern",
    "hinkauerte": "hinkauern",
    "hinkauerten": "hinkauern",
    "hinkauertest": "hinkauern",
    "hinkauertet": "hinkauern",
    "hinke": "hinken",
    "hinkend": "hinken",
    "hinkende": "hinkend",
    "hinkendem": "hinkend",
    "hinkenden": "hinkend",
    "hinkender": "hinkend",
    "hinkendere": "hinkend",
    "hinkenderem": "hinkend",
    "hinkenderen": "hinkend",
    "hinkenderer": "hinkend",
    "hinkenderes": "hinkend",
    "hinkendes": "hinkend",
    "hinkendste": "hinkend",
    "hinkendstem": "hinkend",
    "hinkendsten": "hinkend",
    "hinkendster": "hinkend",
    "hinkendstes": "hinkend",
    "hinkest": "hinken",
    "hinket": "hinken",
    "hinklotze": "hinklotzen",
    "hinklotzend": "hinklotzen",
    "hinklotzende": "hinklotzend",
    "hinklotzendem": "hinklotzend",
    "hinklotzenden": "hinklotzend",
    "hinklotzender": "hinklotzend",
    "hinklotzendes": "hinklotzend",
    "hinklotzest": "hinklotzen",
    "hinklotzet": "hinklotzen",
    "hinklotzt": "hinklotzen",
    "hinklotzte": "hinklotzen",
    "hinklotzten": "hinklotzen",
    "hinklotztest": "hinklotzen",
    "hinklotztet": "hinklotzen",
    "hinknie": "hinknien",
    "hinkniend": "hinknien",
    "hinkniende": "hinkniend",
    "hinkniendem": "hinkniend",
    "hinknienden": "hinkniend",
    "hinkniender": "hinkniend",
    "hinkniendes": "hinkniend",
    "hinkniest": "hinknien",
    "hinkniet": "hinknien",
    "hinkniete": "hinknien",
    "hinknieten": "hinknien",
    "hinknietest": "hinknien",
    "hinknietet": "hinknien",
    "hinkomme": "hinkommen",
    "hinkommend": "hinkommen",
    "hinkommende": "hinkommend",
    "hinkommendem": "hinkommend",
    "hinkommenden": "hinkommend",
    "hinkommender": "hinkommend",
    "hinkommendes": "hinkommend",
    "hinkommest": "hinkommen",
    "hinkommet": "hinkommen",
    "hinkommst": "hinkommen",
    "hinkommt": "hinkommen",
    "hinkriege": "hinkriegen",
    "hinkriegend": "hinkriegen",
    "hinkriegende": "hinkriegend",
    "hinkriegendem": "hinkriegend",
    "hinkriegenden": "hinkriegend",
    "hinkriegender": "hinkriegend",
    "hinkriegendes": "hinkriegend",
    "hinkriegest": "hinkriegen",
    "hinkrieget": "hinkriegen",
    "hinkriegst": "hinkriegen",
    "hinkriegt": "hinkriegen",
    "hinkriegte": "hinkriegen",
    "hinkriegten": "hinkriegen",
    "hinkriegtest": "hinkriegen",
    "hinkriegtet": "hinkriegen",
    "hinkst": "hinken",
    "hinkt": "hinken",
    "hinkte": "hinken",
    "hinkten": "hinken",
    "hinktest": "hinken",
    "hinktet": "hinken",
    "hinkäme": "hinkommen",
    "hinkämen": "hinkommen",
    "hinkämest": "hinkommen",
    "hinkämet": "hinkommen",
    "hinlange": "hinlangen",
    "hinlangend": "hinlangen",
    "hinlangende": "hinlangend",
    "hinlangendem": "hinlangend",
    "hinlangenden": "hinlangend",
    "hinlangender": "hinlangend",
    "hinlangendes": "hinlangend",
    "hinlangest": "hinlangen",
    "hinlanget": "hinlangen",
    "hinlangst": "hinlangen",
    "hinlangt": "hinlangen",
    "hinlangte": "hinlangen",
    "hinlangten": "hinlangen",
    "hinlangtest": "hinlangen",
    "hinlangtet": "hinlangen",
    "hinlasse": "hinlassen",
    "hinlassend": "hinlassen",
    "hinlassende": "hinlassend",
    "hinlassendem": "hinlassend",
    "hinlassenden": "hinlassend",
    "hinlassender": "hinlassend",
    "hinlassendes": "hinlassend",
    "hinlassest": "hinlassen",
    "hinlasset": "hinlassen",
    "hinlaufe": "hinlaufen",
    "hinlaufend": "hinlaufen",
    "hinlaufende": "hinlaufend",
    "hinlaufendem": "hinlaufend",
    "hinlaufenden": "hinlaufend",
    "hinlaufender": "hinlaufend",
    "hinlaufendes": "hinlaufend",
    "hinlaufest": "hinlaufen",
    "hinlaufet": "hinlaufen",
    "hinlauft": "hinlaufen",
    "hinlaßt": "hinlassen",
    "hinlege": "hinlegen",
    "hinlegend": "hinlegen",
    "hinlegende": "hinlegend",
    "hinlegendem": "hinlegend",
    "hinlegenden": "hinlegend",
    "hinlegender": "hinlegend",
    "hinlegendes": "hinlegend",
    "hinlegest": "hinlegen",
    "hinleget": "hinlegen",
    "hinlegst": "hinlegen",
    "hinlegt": "hinlegen",
    "hinlegte": "hinlegen",
    "hinlegten": "hinlegen",
    "hinlegtest": "hinlegen",
    "hinlegtet": "hinlegen",
    "hinlief": "hinlaufen",
    "hinliefe": "hinlaufen",
    "hinliefen": "hinlaufen",
    "hinliefest": "hinlaufen",
    "hinliefet": "hinlaufen",
    "hinliefst": "hinlaufen",
    "hinlieft": "hinlaufen",
    "hinließ": "hinlassen",
    "hinließe": "hinlassen",
    "hinließen": "hinlassen",
    "hinließest": "hinlassen",
    "hinließet": "hinlassen",
    "hinließt": "hinlassen",
    "hinläufst": "hinlaufen",
    "hinläuft": "hinlaufen",
    "hinläßt": "hinlassen",
    "hinlümmele": "hinlümmeln",
    "hinlümmelnd": "hinlümmeln",
    "hinlümmelnde": "hinlümmelnd",
    "hinlümmelndem": "hinlümmelnd",
    "hinlümmelnden": "hinlümmelnd",
    "hinlümmelnder": "hinlümmelnd",
    "hinlümmelndere": "hinlümmelnd",
    "hinlümmelnderem": "hinlümmelnd",
    "hinlümmelnderen": "hinlümmelnd",
    "hinlümmelnderer": "hinlümmelnd",
    "hinlümmelnderes": "hinlümmelnd",
    "hinlümmelndes": "hinlümmelnd",
    "hinlümmelndste": "hinlümmelnd",
    "hinlümmelndstem": "hinlümmelnd",
    "hinlümmelndsten": "hinlümmelnd",
    "hinlümmelndster": "hinlümmelnd",
    "hinlümmelndstes": "hinlümmelnd",
    "hinlümmelst": "hinlümmeln",
    "hinlümmelt": "hinlümmeln",
    "hinlümmelte": "hinlümmeln",
    "hinlümmelten": "hinlümmeln",
    "hinlümmeltest": "hinlümmeln",
    "hinlümmeltet": "hinlümmeln",
    "hinlümmle": "hinlümmeln",
    "hinmache": "hinmachen",
    "hinmachend": "hinmachen",
    "hinmachende": "hinmachend",
    "hinmachendem": "hinmachend",
    "hinmachenden": "hinmachend",
    "hinmachender": "hinmachend",
    "hinmachendes": "hinmachend",
    "hinmachest": "hinmachen",
    "hinmachet": "hinmachen",
    "hinmachst": "hinmachen",
    "hinmacht": "hinmachen",
    "hinmachte": "hinmachen",
    "hinmachten": "hinmachen",
    "hinmachtest": "hinmachen",
    "hinmachtet": "hinmachen",
    "hinnahm": "hinnehmen",
    "hinnahmen": "hinnehmen",
    "hinnahmst": "hinnehmen",
    "hinnahmt": "hinnehmen",
    "hinnehme": "hinnehmen",
    "hinnehmend": "hinnehmen",
    "hinnehmende": "hinnehmend",
    "hinnehmendem": "hinnehmend",
    "hinnehmenden": "hinnehmend",
    "hinnehmender": "hinnehmend",
    "hinnehmendes": "hinnehmend",
    "hinnehmest": "hinnehmen",
    "hinnehmet": "hinnehmen",
    "hinnehmt": "hinnehmen",
    "hinneige": "hinneigen",
    "hinneigend": "hinneigen",
    "hinneigende": "hinneigend",
    "hinneigendem": "hinneigend",
    "hinneigenden": "hinneigend",
    "hinneigender": "hinneigend",
    "hinneigendes": "hinneigend",
    "hinneigest": "hinneigen",
    "hinneiget": "hinneigen",
    "hinneigst": "hinneigen",
    "hinneigt": "hinneigen",
    "hinneigte": "hinneigen",
    "hinneigten": "hinneigen",
    "hinneigtest": "hinneigen",
    "hinneigtet": "hinneigen",
    "hinnimmst": "hinnehmen",
    "hinnimmt": "hinnehmen",
    "hinnähme": "hinnehmen",
    "hinnähmen": "hinnehmen",
    "hinnähmest": "hinnehmen",
    "hinnähmet": "hinnehmen",
    "hinpurzele": "hinpurzeln",
    "hinpurzelnd": "hinpurzeln",
    "hinpurzelnde": "hinpurzelnd",
    "hinpurzelndem": "hinpurzelnd",
    "hinpurzelnden": "hinpurzelnd",
    "hinpurzelnder": "hinpurzelnd",
    "hinpurzelndes": "hinpurzelnd",
    "hinpurzelst": "hinpurzeln",
    "hinpurzelt": "hinpurzeln",
    "hinpurzelte": "hinpurzeln",
    "hinpurzelten": "hinpurzeln",
    "hinpurzeltest": "hinpurzeln",
    "hinpurzeltet": "hinpurzeln",
    "hinpurzle": "hinpurzeln",
    "hinraffe": "hinraffen",
    "hinraffend": "hinraffen",
    "hinraffende": "hinraffend",
    "hinraffendem": "hinraffend",
    "hinraffenden": "hinraffend",
    "hinraffender": "hinraffend",
    "hinraffendes": "hinraffend",
    "hinraffest": "hinraffen",
    "hinraffet": "hinraffen",
    "hinraffst": "hinraffen",
    "hinrafft": "hinraffen",
    "hinraffte": "hinraffen",
    "hinrafften": "hinraffen",
    "hinrafftest": "hinraffen",
    "hinrafftet": "hinraffen",
    "hinrannte": "hinrennen",
    "hinrannten": "hinrennen",
    "hinranntest": "hinrennen",
    "hinranntet": "hinrennen",
    "hinreibe": "hinreiben",
    "hinreibend": "hinreiben",
    "hinreibende": "hinreibend",
    "hinreibendem": "hinreibend",
    "hinreibenden": "hinreibend",
    "hinreibender": "hinreibend",
    "hinreibendes": "hinreibend",
    "hinreibest": "hinreiben",
    "hinreibet": "hinreiben",
    "hinreibst": "hinreiben",
    "hinreibt": "hinreiben",
    "hinreiche": "hinreichen",
    "hinreichend": "hinreichen",
    "hinreichende": "hinreichend",
    "hinreichendem": "hinreichend",
    "hinreichenden": "hinreichend",
    "hinreichender": "hinreichend",
    "hinreichendere": "hinreichend",
    "hinreichenderem": "hinreichend",
    "hinreichenderen": "hinreichend",
    "hinreichenderer": "hinreichend",
    "hinreichenderes": "hinreichend",
    "hinreichendes": "hinreichend",
    "hinreichendste": "hinreichend",
    "hinreichendstem": "hinreichend",
    "hinreichendsten": "hinreichend",
    "hinreichendster": "hinreichend",
    "hinreichendstes": "hinreichend",
    "hinreichest": "hinreichen",
    "hinreichet": "hinreichen",
    "hinreichst": "hinreichen",
    "hinreicht": "hinreichen",
    "hinreichte": "hinreichen",
    "hinreichten": "hinreichen",
    "hinreichtest": "hinreichen",
    "hinreichtet": "hinreichen",
    "hinreise": "hinreisen",
    "hinreisend": "hinreisen",
    "hinreisende": "hinreisend",
    "hinreisendem": "hinreisend",
    "hinreisenden": "hinreisend",
    "hinreisender": "hinreisend",
    "hinreisendes": "hinreisend",
    "hinreisest": "hinreisen",
    "hinreiset": "hinreisen",
    "hinreist": "hinreisen",
    "hinreiste": "hinreisen",
    "hinreisten": "hinreisen",
    "hinreistest": "hinreisen",
    "hinreistet": "hinreisen",
    "hinreiße": "hinreißen",
    "hinreißend": "hinreißen",
    "hinreißende": "hinreißend",
    "hinreißendem": "hinreißend",
    "hinreißenden": "hinreißend",
    "hinreißender": "hinreißend",
    "hinreißendere": "hinreißend",
    "hinreißenderem": "hinreißend",
    "hinreißenderen": "hinreißend",
    "hinreißenderer": "hinreißend",
    "hinreißenderes": "hinreißend",
    "hinreißendes": "hinreißend",
    "hinreißendste": "hinreißend",
    "hinreißendstem": "hinreißend",
    "hinreißendsten": "hinreißend",
    "hinreißendster": "hinreißend",
    "hinreißendstes": "hinreißend",
    "hinreißest": "hinreißen",
    "hinreißet": "hinreißen",
    "hinreißt": "hinreißen",
    "hinrenne": "hinrennen",
    "hinrennend": "hinrennen",
    "hinrennende": "hinrennend",
    "hinrennendem": "hinrennend",
    "hinrennenden": "hinrennend",
    "hinrennender": "hinrennend",
    "hinrennendes": "hinrennend",
    "hinrennest": "hinrennen",
    "hinrennet": "hinrennen",
    "hinrennst": "hinrennen",
    "hinrennt": "hinrennen",
    "hinrichte": "hinrichten",
    "hinrichtend": "hinrichten",
    "hinrichtende": "hinrichtend",
    "hinrichtendem": "hinrichtend",
    "hinrichtenden": "hinrichtend",
    "hinrichtender": "hinrichtend",
    "hinrichtendes": "hinrichtend",
    "hinrichtest": "hinrichten",
    "hinrichtet": "hinrichten",
    "hinrichtete": "hinrichten",
    "hinrichteten": "hinrichten",
    "hinrichtetest": "hinrichten",
    "hinrichtetet": "hinrichten",
    "hinrieb": "hinreiben",
    "hinriebe": "hinreiben",
    "hinrieben": "hinreiben",
    "hinriebest": "hinreiben",
    "hinriebet": "hinreiben",
    "hinriebst": "hinreiben",
    "hinriebt": "hinreiben",
    "hinrisse": "hinreißen",
    "hinrissen": "hinreißen",
    "hinrissest": "hinreißen",
    "hinrisset": "hinreißen",
    "hinriß": "hinreißen",
    "hinrißt": "hinreißen",
    "hinsage": "hinsagen",
    "hinsagend": "hinsagen",
    "hinsagende": "hinsagend",
    "hinsagendem": "hinsagend",
    "hinsagenden": "hinsagend",
    "hinsagender": "hinsagend",
    "hinsagendes": "hinsagend",
    "hinsagest": "hinsagen",
    "hinsaget": "hinsagen",
    "hinsagst": "hinsagen",
    "hinsagt": "hinsagen",
    "hinsagte": "hinsagen",
    "hinsagten": "hinsagen",
    "hinsagtest": "hinsagen",
    "hinsagtet": "hinsagen",
    "hinsah": "hinsehen",
    "hinsahen": "hinsehen",
    "hinsahst": "hinsehen",
    "hinsaht": "hinsehen",
    "hinsank": "hinsinken",
    "hinsanken": "hinsinken",
    "hinsankst": "hinsinken",
    "hinsankt": "hinsinken",
    "hinschaffe": "hinschaffen",
    "hinschaffend": "hinschaffen",
    "hinschaffende": "hinschaffend",
    "hinschaffendem": "hinschaffend",
    "hinschaffenden": "hinschaffend",
    "hinschaffender": "hinschaffend",
    "hinschaffendes": "hinschaffend",
    "hinschaffest": "hinschaffen",
    "hinschaffet": "hinschaffen",
    "hinschaffst": "hinschaffen",
    "hinschafft": "hinschaffen",
    "hinschaffte": "hinschaffen",
    "hinschafften": "hinschaffen",
    "hinschafftest": "hinschaffen",
    "hinschafftet": "hinschaffen",
    "hinschaue": "hinschauen",
    "hinschauend": "hinschauen",
    "hinschauende": "hinschauend",
    "hinschauendem": "hinschauend",
    "hinschauenden": "hinschauend",
    "hinschauender": "hinschauend",
    "hinschauendes": "hinschauend",
    "hinschauest": "hinschauen",
    "hinschauet": "hinschauen",
    "hinschaust": "hinschauen",
    "hinschaut": "hinschauen",
    "hinschaute": "hinschauen",
    "hinschauten": "hinschauen",
    "hinschautest": "hinschauen",
    "hinschautet": "hinschauen",
    "hinscheide": "hinscheiden",
    "hinscheidend": "hinscheiden",
    "hinscheidende": "hinscheidend",
    "hinscheidendem": "hinscheidend",
    "hinscheidenden": "hinscheidend",
    "hinscheidender": "hinscheidend",
    "hinscheidendes": "hinscheidend",
    "hinscheidest": "hinscheiden",
    "hinscheidet": "hinscheiden",
    "hinschiebe": "hinschieben",
    "hinschiebend": "hinschieben",
    "hinschiebende": "hinschiebend",
    "hinschiebendem": "hinschiebend",
    "hinschiebenden": "hinschiebend",
    "hinschiebender": "hinschiebend",
    "hinschiebendes": "hinschiebend",
    "hinschiebest": "hinschieben",
    "hinschiebet": "hinschieben",
    "hinschiebst": "hinschieben",
    "hinschiebt": "hinschieben",
    "hinschied": "hinscheiden",
    "hinschiede": "hinscheiden",
    "hinschieden": "hinscheiden",
    "hinschiedest": "hinscheiden",
    "hinschiedet": "hinscheiden",
    "hinschlachte": "hinschlachten",
    "hinschlachtend": "hinschlachten",
    "hinschlachtende": "hinschlachtend",
    "hinschlachtendem": "hinschlachtend",
    "hinschlachtenden": "hinschlachtend",
    "hinschlachtender": "hinschlachtend",
    "hinschlachtendes": "hinschlachtend",
    "hinschlachtest": "hinschlachten",
    "hinschlachtet": "hinschlachten",
    "hinschlachtete": "hinschlachten",
    "hinschlachteten": "hinschlachten",
    "hinschlachtetest": "hinschlachten",
    "hinschlachtetet": "hinschlachten",
    "hinschlage": "hinschlagen",
    "hinschlagend": "hinschlagen",
    "hinschlagende": "hinschlagend",
    "hinschlagendem": "hinschlagend",
    "hinschlagenden": "hinschlagend",
    "hinschlagender": "hinschlagend",
    "hinschlagendes": "hinschlagend",
    "hinschlagest": "hinschlagen",
    "hinschlaget": "hinschlagen",
    "hinschlagt": "hinschlagen",
    "hinschleiche": "hinschleichen",
    "hinschleichend": "hinschleichen",
    "hinschleichende": "hinschleichend",
    "hinschleichendem": "hinschleichend",
    "hinschleichenden": "hinschleichend",
    "hinschleichender": "hinschleichend",
    "hinschleichendes": "hinschleichend",
    "hinschleichest": "hinschleichen",
    "hinschleichet": "hinschleichen",
    "hinschleichst": "hinschleichen",
    "hinschleicht": "hinschleichen",
    "hinschleppe": "hinschleppen",
    "hinschleppend": "hinschleppen",
    "hinschleppende": "hinschleppend",
    "hinschleppendem": "hinschleppend",
    "hinschleppenden": "hinschleppend",
    "hinschleppender": "hinschleppend",
    "hinschleppendes": "hinschleppend",
    "hinschleppest": "hinschleppen",
    "hinschleppet": "hinschleppen",
    "hinschleppst": "hinschleppen",
    "hinschleppt": "hinschleppen",
    "hinschleppte": "hinschleppen",
    "hinschleppten": "hinschleppen",
    "hinschlepptest": "hinschleppen",
    "hinschlepptet": "hinschleppen",
    "hinschlich": "hinschleichen",
    "hinschliche": "hinschleichen",
    "hinschlichen": "hinschleichen",
    "hinschlichest": "hinschleichen",
    "hinschlichet": "hinschleichen",
    "hinschlichst": "hinschleichen",
    "hinschlicht": "hinschleichen",
    "hinschlug": "hinschlagen",
    "hinschlugen": "hinschlagen",
    "hinschlugst": "hinschlagen",
    "hinschlugt": "hinschlagen",
    "hinschlägst": "hinschlagen",
    "hinschlägt": "hinschlagen",
    "hinschlüge": "hinschlagen",
    "hinschlügen": "hinschlagen",
    "hinschlügest": "hinschlagen",
    "hinschlüget": "hinschlagen",
    "hinschmeiße": "hinschmeißen",
    "hinschmeißend": "hinschmeißen",
    "hinschmeißende": "hinschmeißend",
    "hinschmeißendem": "hinschmeißend",
    "hinschmeißenden": "hinschmeißend",
    "hinschmeißender": "hinschmeißend",
    "hinschmeißendes": "hinschmeißend",
    "hinschmeißest": "hinschmeißen",
    "hinschmeißet": "hinschmeißen",
    "hinschmeißt": "hinschmeißen",
    "hinschmelze": "hinschmelzen",
    "hinschmelzend": "hinschmelzen",
    "hinschmelzende": "hinschmelzend",
    "hinschmelzendem": "hinschmelzend",
    "hinschmelzenden": "hinschmelzend",
    "hinschmelzender": "hinschmelzend",
    "hinschmelzendere": "hinschmelzend",
    "hinschmelzenderem": "hinschmelzend",
    "hinschmelzenderen": "hinschmelzend",
    "hinschmelzenderer": "hinschmelzend",
    "hinschmelzenderes": "hinschmelzend",
    "hinschmelzendes": "hinschmelzend",
    "hinschmelzendste": "hinschmelzend",
    "hinschmelzendstem": "hinschmelzend",
    "hinschmelzendsten": "hinschmelzend",
    "hinschmelzendster": "hinschmelzend",
    "hinschmelzendstes": "hinschmelzend",
    "hinschmelzest": "hinschmelzen",
    "hinschmelzet": "hinschmelzen",
    "hinschmelzt": "hinschmelzen",
    "hinschmiere": "hinschmieren",
    "hinschmierend": "hinschmieren",
    "hinschmierende": "hinschmierend",
    "hinschmierendem": "hinschmierend",
    "hinschmierenden": "hinschmierend",
    "hinschmierender": "hinschmierend",
    "hinschmierendes": "hinschmierend",
    "hinschmierest": "hinschmieren",
    "hinschmieret": "hinschmieren",
    "hinschmierst": "hinschmieren",
    "hinschmiert": "hinschmieren",
    "hinschmierte": "hinschmieren",
    "hinschmierten": "hinschmieren",
    "hinschmiertest": "hinschmieren",
    "hinschmiertet": "hinschmieren",
    "hinschmilzt": "hinschmelzen",
    "hinschmisse": "hinschmeißen",
    "hinschmissen": "hinschmeißen",
    "hinschmissest": "hinschmeißen",
    "hinschmisset": "hinschmeißen",
    "hinschmiß": "hinschmeißen",
    "hinschmißt": "hinschmeißen",
    "hinschmolz": "hinschmelzen",
    "hinschmolzen": "hinschmelzen",
    "hinschmolzst": "hinschmelzen",
    "hinschmolzt": "hinschmelzen",
    "hinschmölze": "hinschmelzen",
    "hinschmölzen": "hinschmelzen",
    "hinschmölzest": "hinschmelzen",
    "hinschmölzet": "hinschmelzen",
    "hinschob": "hinschieben",
    "hinschoben": "hinschieben",
    "hinschobst": "hinschieben",
    "hinschobt": "hinschieben",
    "hinschreibe": "hinschreiben",
    "hinschreibend": "hinschreiben",
    "hinschreibende": "hinschreibend",
    "hinschreibendem": "hinschreibend",
    "hinschreibenden": "hinschreibend",
    "hinschreibender": "hinschreibend",
    "hinschreibendes": "hinschreibend",
    "hinschreibest": "hinschreiben",
    "hinschreibet": "hinschreiben",
    "hinschreibst": "hinschreiben",
    "hinschreibt": "hinschreiben",
    "hinschrieb": "hinschreiben",
    "hinschriebe": "hinschreiben",
    "hinschrieben": "hinschreiben",
    "hinschriebest": "hinschreiben",
    "hinschriebet": "hinschreiben",
    "hinschriebst": "hinschreiben",
    "hinschriebt": "hinschreiben",
    "hinschuf": "hinschaffen",
    "hinschufen": "hinschaffen",
    "hinschufst": "hinschaffen",
    "hinschuft": "hinschaffen",
    "hinschwamm": "hinschwimmen",
    "hinschwammen": "hinschwimmen",
    "hinschwammst": "hinschwimmen",
    "hinschwammt": "hinschwimmen",
    "hinschwand": "hinschwinden",
    "hinschwanden": "hinschwinden",
    "hinschwandest": "hinschwinden",
    "hinschwandet": "hinschwinden",
    "hinschwimme": "hinschwimmen",
    "hinschwimmend": "hinschwimmen",
    "hinschwimmende": "hinschwimmend",
    "hinschwimmendem": "hinschwimmend",
    "hinschwimmenden": "hinschwimmend",
    "hinschwimmender": "hinschwimmend",
    "hinschwimmendes": "hinschwimmend",
    "hinschwimmest": "hinschwimmen",
    "hinschwimmet": "hinschwimmen",
    "hinschwimmst": "hinschwimmen",
    "hinschwimmt": "hinschwimmen",
    "hinschwinde": "hinschwinden",
    "hinschwindend": "hinschwinden",
    "hinschwindende": "hinschwindend",
    "hinschwindendem": "hinschwindend",
    "hinschwindenden": "hinschwindend",
    "hinschwindender": "hinschwindend",
    "hinschwindendes": "hinschwindend",
    "hinschwindest": "hinschwinden",
    "hinschwindet": "hinschwinden",
    "hinschwämme": "hinschwimmen",
    "hinschwämmen": "hinschwimmen",
    "hinschwämmest": "hinschwimmen",
    "hinschwämmet": "hinschwimmen",
    "hinschwände": "hinschwinden",
    "hinschwänden": "hinschwinden",
    "hinschwändest": "hinschwinden",
    "hinschwändet": "hinschwinden",
    "hinschöbe": "hinschieben",
    "hinschöben": "hinschieben",
    "hinschöbest": "hinschieben",
    "hinschöbet": "hinschieben",
    "hinschüfe": "hinschaffen",
    "hinschüfen": "hinschaffen",
    "hinschüfest": "hinschaffen",
    "hinschüfet": "hinschaffen",
    "hinschütte": "hinschütten",
    "hinschüttend": "hinschütten",
    "hinschüttende": "hinschüttend",
    "hinschüttendem": "hinschüttend",
    "hinschüttenden": "hinschüttend",
    "hinschüttender": "hinschüttend",
    "hinschüttendes": "hinschüttend",
    "hinschüttest": "hinschütten",
    "hinschüttet": "hinschütten",
    "hinschüttete": "hinschütten",
    "hinschütteten": "hinschütten",
    "hinschüttetest": "hinschütten",
    "hinschüttetet": "hinschütten",
    "hinsehe": "hinsehen",
    "hinsehend": "hinsehen",
    "hinsehende": "hinsehend",
    "hinsehendem": "hinsehend",
    "hinsehenden": "hinsehend",
    "hinsehender": "hinsehend",
    "hinsehendes": "hinsehend",
    "hinsehest": "hinsehen",
    "hinsehet": "hinsehen",
    "hinseht": "hinsehen",
    "hinsetze": "hinsetzen",
    "hinsetzend": "hinsetzen",
    "hinsetzende": "hinsetzend",
    "hinsetzendem": "hinsetzend",
    "hinsetzenden": "hinsetzend",
    "hinsetzender": "hinsetzend",
    "hinsetzendes": "hinsetzend",
    "hinsetzest": "hinsetzen",
    "hinsetzet": "hinsetzen",
    "hinsetzt": "hinsetzen",
    "hinsetzte": "hinsetzen",
    "hinsetzten": "hinsetzen",
    "hinsetztest": "hinsetzen",
    "hinsetztet": "hinsetzen",
    "hinsieche": "hinsiechen",
    "hinsiechend": "hinsiechen",
    "hinsiechende": "hinsiechend",
    "hinsiechendem": "hinsiechend",
    "hinsiechenden": "hinsiechend",
    "hinsiechender": "hinsiechend",
    "hinsiechendere": "hinsiechend",
    "hinsiechenderem": "hinsiechend",
    "hinsiechenderen": "hinsiechend",
    "hinsiechenderer": "hinsiechend",
    "hinsiechenderes": "hinsiechend",
    "hinsiechendes": "hinsiechend",
    "hinsiechendste": "hinsiechend",
    "hinsiechendstem": "hinsiechend",
    "hinsiechendsten": "hinsiechend",
    "hinsiechendster": "hinsiechend",
    "hinsiechendstes": "hinsiechend",
    "hinsiechest": "hinsiechen",
    "hinsiechet": "hinsiechen",
    "hinsiechst": "hinsiechen",
    "hinsiecht": "hinsiechen",
    "hinsiechte": "hinsiechen",
    "hinsiechten": "hinsiechen",
    "hinsiechtest": "hinsiechen",
    "hinsiechtet": "hinsiechen",
    "hinsiehst": "hinsehen",
    "hinsieht": "hinsehen",
    "hinsinke": "hinsinken",
    "hinsinkend": "hinsinken",
    "hinsinkende": "hinsinkend",
    "hinsinkendem": "hinsinkend",
    "hinsinkenden": "hinsinkend",
    "hinsinkender": "hinsinkend",
    "hinsinkendes": "hinsinkend",
    "hinsinkest": "hinsinken",
    "hinsinket": "hinsinken",
    "hinsinkst": "hinsinken",
    "hinsinkt": "hinsinken",
    "hinstarb": "hinsterben",
    "hinstarben": "hinsterben",
    "hinstarbst": "hinsterben",
    "hinstarbt": "hinsterben",
    "hinstelle": "hinstellen",
    "hinstellend": "hinstellen",
    "hinstellende": "hinstellend",
    "hinstellendem": "hinstellend",
    "hinstellenden": "hinstellend",
    "hinstellender": "hinstellend",
    "hinstellendes": "hinstellend",
    "hinstellest": "hinstellen",
    "hinstellet": "hinstellen",
    "hinstellst": "hinstellen",
    "hinstellt": "hinstellen",
    "hinstellte": "hinstellen",
    "hinstellten": "hinstellen",
    "hinstelltest": "hinstellen",
    "hinstelltet": "hinstellen",
    "hinsterbe": "hinsterben",
    "hinsterbend": "hinsterben",
    "hinsterbende": "hinsterbend",
    "hinsterbendem": "hinsterbend",
    "hinsterbenden": "hinsterbend",
    "hinsterbender": "hinsterbend",
    "hinsterbendes": "hinsterbend",
    "hinsterbest": "hinsterben",
    "hinsterbet": "hinsterben",
    "hinsterbt": "hinsterben",
    "hinsteuere": "hinsteuern",
    "hinsteuernd": "hinsteuern",
    "hinsteuernde": "hinsteuernd",
    "hinsteuerndem": "hinsteuernd",
    "hinsteuernden": "hinsteuernd",
    "hinsteuernder": "hinsteuernd",
    "hinsteuerndes": "hinsteuernd",
    "hinsteuerst": "hinsteuern",
    "hinsteuert": "hinsteuern",
    "hinsteuerte": "hinsteuern",
    "hinsteuerten": "hinsteuern",
    "hinsteuertest": "hinsteuern",
    "hinsteuertet": "hinsteuern",
    "hinstirbst": "hinsterben",
    "hinstirbt": "hinsterben",
    "hinstrebe": "hinstreben",
    "hinstrebend": "hinstreben",
    "hinstrebende": "hinstrebend",
    "hinstrebendem": "hinstrebend",
    "hinstrebenden": "hinstrebend",
    "hinstrebender": "hinstrebend",
    "hinstrebendes": "hinstrebend",
    "hinstrebest": "hinstreben",
    "hinstrebet": "hinstreben",
    "hinstrebst": "hinstreben",
    "hinstrebt": "hinstreben",
    "hinstrebte": "hinstreben",
    "hinstrebten": "hinstreben",
    "hinstrebtest": "hinstreben",
    "hinstrebtet": "hinstreben",
    "hinströme": "hinströmen",
    "hinströmend": "hinströmen",
    "hinströmende": "hinströmend",
    "hinströmendem": "hinströmend",
    "hinströmenden": "hinströmend",
    "hinströmender": "hinströmend",
    "hinströmendes": "hinströmend",
    "hinströmest": "hinströmen",
    "hinströmet": "hinströmen",
    "hinströmst": "hinströmen",
    "hinströmt": "hinströmen",
    "hinströmte": "hinströmen",
    "hinströmten": "hinströmen",
    "hinströmtest": "hinströmen",
    "hinströmtet": "hinströmen",
    "hinstärbe": "hinsterben",
    "hinstärben": "hinsterben",
    "hinstärbest": "hinsterben",
    "hinstärbet": "hinsterben",
    "hinstürze": "hinstürzen",
    "hinstürzend": "hinstürzen",
    "hinstürzende": "hinstürzend",
    "hinstürzendem": "hinstürzend",
    "hinstürzenden": "hinstürzend",
    "hinstürzender": "hinstürzend",
    "hinstürzendes": "hinstürzend",
    "hinstürzest": "hinstürzen",
    "hinstürzet": "hinstürzen",
    "hinstürzt": "hinstürzen",
    "hinstürzte": "hinstürzen",
    "hinstürzten": "hinstürzen",
    "hinstürztest": "hinstürzen",
    "hinstürztet": "hinstürzen",
    "hinsähe": "hinsehen",
    "hinsähen": "hinsehen",
    "hinsähest": "hinsehen",
    "hinsähet": "hinsehen",
    "hinsänke": "hinsinken",
    "hinsänken": "hinsinken",
    "hinsänkest": "hinsinken",
    "hinsänket": "hinsinken",
    "hintenangestellt": "hintenanstellen",
    "hintenangestellte": "hintenangestellt",
    "hintenangestelltem": "hintenangestellt",
    "hintenangestellten": "hintenangestellt",
    "hintenangestellter": "hintenangestellt",
    "hintenangestelltes": "hintenangestellt",
    "hintenanstelle": "hintenanstellen",
    "hintenanstellend": "hintenanstellen",
    "hintenanstellende": "hintenanstellend",
    "hintenanstellendem": "hintenanstellend",
    "hintenanstellenden": "hintenanstellend",
    "hintenanstellender": "hintenanstellend",
    "hintenanstellendes": "hintenanstellend",
    "hintenanstellest": "hintenanstellen",
    "hintenanstellet": "hintenanstellen",
    "hintenanstellst": "hintenanstellen",
    "hintenanstellt": "hintenanstellen",
    "hintenanstellte": "hintenanstellen",
    "hintenanstellten": "hintenanstellen",
    "hintenanstelltest": "hintenanstellen",
    "hintenanstelltet": "hintenanstellen",
    "hintenanzustellen": "hintenanstellen",
    "hintenüberfalle": "hintenüberfallen",
    "hintenüberfallend": "hintenüberfallen",
    "hintenüberfallende": "hintenüberfallend",
    "hintenüberfallendem": "hintenüberfallend",
    "hintenüberfallenden": "hintenüberfallend",
    "hintenüberfallender": "hintenüberfallend",
    "hintenüberfallendes": "hintenüberfallend",
    "hintenüberfallest": "hintenüberfallen",
    "hintenüberfallet": "hintenüberfallen",
    "hintenüberfallt": "hintenüberfallen",
    "hintenüberfiel": "hintenüberfallen",
    "hintenüberfiele": "hintenüberfallen",
    "hintenüberfielen": "hintenüberfallen",
    "hintenüberfielest": "hintenüberfallen",
    "hintenüberfielet": "hintenüberfallen",
    "hintenüberfielst": "hintenüberfallen",
    "hintenüberfielt": "hintenüberfallen",
    "hintenüberfällst": "hintenüberfallen",
    "hintenüberfällt": "hintenüberfallen",
    "hintenübergefallen": "hintenübergefalle",
    "hintenübergefallene": "hintenübergefallen",
    "hintenübergefallenem": "hintenübergefallen",
    "hintenübergefallenen": "hintenübergefallen",
    "hintenübergefallener": "hintenübergefallen",
    "hintenübergefallenes": "hintenübergefallen",
    "hintenübergekippt": "hintenüberkippen",
    "hintenübergekippte": "hintenübergekippe",
    "hintenübergekipptem": "hintenübergekippt",
    "hintenübergekippten": "hintenübergekippe",
    "hintenübergekippter": "hintenübergekippt",
    "hintenübergekipptes": "hintenübergekippt",
    "hintenüberkippe": "hintenüberkippen",
    "hintenüberkippend": "hintenüberkippen",
    "hintenüberkippende": "hintenüberkippend",
    "hintenüberkippendem": "hintenüberkippend",
    "hintenüberkippenden": "hintenüberkippend",
    "hintenüberkippender": "hintenüberkippend",
    "hintenüberkippendes": "hintenüberkippend",
    "hintenüberkippest": "hintenüberkippen",
    "hintenüberkippet": "hintenüberkippen",
    "hintenüberkippst": "hintenüberkippen",
    "hintenüberkippt": "hintenüberkippen",
    "hintenüberkippte": "hintenüberkippen",
    "hintenüberkippten": "hintenüberkippen",
    "hintenüberkipptest": "hintenüberkippen",
    "hintenüberkipptet": "hintenüberkippen",
    "hintenüberzufallen": "hintenüberzufalle",
    "hintenüberzukippen": "hintenüberzukippe",
    "hinteraß": "hinteressen",
    "hinteraßen": "hinteressen",
    "hinteraßt": "hinteressen",
    "hinterem": "hinter",
    "hinteren": "hinter",
    "hinterer": "hinter",
    "hinterere": "hinter",
    "hintererem": "hinter",
    "hintereren": "hinter",
    "hintererer": "hinter",
    "hintereres": "hinter",
    "hinteres": "hinter",
    "hinteresse": "hinteressen",
    "hinteressend": "hinteressen",
    "hinteressende": "hinteressend",
    "hinteressendem": "hinteressend",
    "hinteressenden": "hinteressend",
    "hinteressender": "hinteressend",
    "hinteressendes": "hinteressend",
    "hinteressest": "hinteressen",
    "hinteresset": "hinteressen",
    "hintereßt": "hinteressen",
    "hinterfotzige": "hinterfotzig",
    "hinterfotzigem": "hinterfotzig",
    "hinterfotzigen": "hinterfotzig",
    "hinterfotziger": "hinterfotzig",
    "hinterfotzigere": "hinterfotzig",
    "hinterfotzigerem": "hinterfotzig",
    "hinterfotzigeren": "hinterfotzig",
    "hinterfotzigerer": "hinterfotzig",
    "hinterfotzigeres": "hinterfotzig",
    "hinterfotziges": "hinterfotzig",
    "hinterfotzigste": "hinterfotzig",
    "hinterfotzigstem": "hinterfotzig",
    "hinterfotzigsten": "hinterfotzig",
    "hinterfotzigster": "hinterfotzig",
    "hinterfotzigstes": "hinterfotzig",
    "hinterfrage": "hinterfragen",
    "hinterfragend": "hinterfragen",
    "hinterfragende": "hinterfragend",
    "hinterfragendem": "hinterfragend",
    "hinterfragenden": "hinterfragend",
    "hinterfragender": "hinterfragend",
    "hinterfragendere": "hinterfragend",
    "hinterfragenderem": "hinterfragend",
    "hinterfragenderen": "hinterfragend",
    "hinterfragenderer": "hinterfragend",
    "hinterfragenderes": "hinterfragend",
    "hinterfragendes": "hinterfragend",
    "hinterfragendste": "hinterfragend",
    "hinterfragendstem": "hinterfragend",
    "hinterfragendsten": "hinterfragend",
    "hinterfragendster": "hinterfragend",
    "hinterfragendstes": "hinterfragend",
    "hinterfragest": "hinterfragen",
    "hinterfraget": "hinterfragen",
    "hinterfragst": "hinterfragen",
    "hinterfragt": "hinterfragen",
    "hinterfragte": "hinterfragen",
    "hinterfragtem": "hinterfragt",
    "hinterfragten": "hinterfragen",
    "hinterfragter": "hinterfragt",
    "hinterfragtere": "hinterfragt",
    "hinterfragterem": "hinterfragt",
    "hinterfragteren": "hinterfragt",
    "hinterfragterer": "hinterfragt",
    "hinterfragteres": "hinterfragt",
    "hinterfragtes": "hinterfragt",
    "hinterfragtest": "hinterfragen",
    "hinterfragteste": "hinterfragt",
    "hinterfragtestem": "hinterfragt",
    "hinterfragtesten": "hinterfragt",
    "hinterfragtester": "hinterfragt",
    "hinterfragtestes": "hinterfragt",
    "hinterfragtet": "hinterfragen",
    "hintergangen": "hintergehen",
    "hintergangene": "hintergangen",
    "hintergangenem": "hintergangen",
    "hintergangenen": "hintergangen",
    "hintergangener": "hintergangen",
    "hintergangenes": "hintergangen",
    "hintergegessen": "hinteressen",
    "hintergegessene": "hintergegessen",
    "hintergegessenem": "hintergegessen",
    "hintergegessenen": "hintergegessen",
    "hintergegessener": "hintergegessen",
    "hintergegessenes": "hintergegessen",
    "hintergegossen": "hintergießen",
    "hintergegossene": "hintergegossen",
    "hintergegossenem": "hintergegossen",
    "hintergegossenen": "hintergegossen",
    "hintergegossener": "hintergegossen",
    "hintergegossenes": "hintergegossen",
    "hintergehakt": "hinterhaken",
    "hintergehakte": "hintergehakt",
    "hintergehaktem": "hintergehakt",
    "hintergehakten": "hintergehakt",
    "hintergehakter": "hintergehakt",
    "hintergehaktes": "hintergehakt",
    "hintergehe": "hintergehen",
    "hintergehend": "hintergehen",
    "hintergehende": "hintergehend",
    "hintergehendem": "hintergehend",
    "hintergehenden": "hintergehend",
    "hintergehender": "hintergehend",
    "hintergehendes": "hintergehend",
    "hintergehest": "hintergehen",
    "hintergehet": "hintergehen",
    "hintergehst": "hintergehen",
    "hintergeht": "hintergehen",
    "hintergekaut": "hinterkauen",
    "hintergekaute": "hintergekaut",
    "hintergekautem": "hintergekaut",
    "hintergekauten": "hintergekaut",
    "hintergekauter": "hintergekaut",
    "hintergekautes": "hintergekaut",
    "hintergieße": "hintergießen",
    "hintergießend": "hintergießen",
    "hintergießende": "hintergießend",
    "hintergießendem": "hintergießend",
    "hintergießenden": "hintergießend",
    "hintergießender": "hintergießend",
    "hintergießendes": "hintergießend",
    "hintergießest": "hintergießen",
    "hintergießet": "hintergießen",
    "hintergießt": "hintergießen",
    "hinterging": "hintergehen",
    "hinterginge": "hintergehen",
    "hintergingen": "hintergehen",
    "hintergingest": "hintergehen",
    "hinterginget": "hintergehen",
    "hintergingst": "hintergehen",
    "hintergingt": "hintergehen",
    "hintergossen": "hintergießen",
    "hintergoß": "hintergießen",
    "hintergoßt": "hintergießen",
    "hintergründigem": "hintergründig",
    "hintergründigen": "hintergründig",
    "hintergründiger": "hintergründig",
    "hintergründigere": "hintergründig",
    "hintergründigerem": "hintergründig",
    "hintergründigeren": "hintergründig",
    "hintergründigerer": "hintergründig",
    "hintergründigeres": "hintergründig",
    "hintergründiges": "hintergründig",
    "hintergründigste": "hintergründig",
    "hintergründigstem": "hintergründig",
    "hintergründigsten": "hintergründig",
    "hintergründigster": "hintergründig",
    "hintergründigstes": "hintergründig",
    "hintergösse": "hintergießen",
    "hintergössen": "hintergießen",
    "hintergössest": "hintergießen",
    "hintergösset": "hintergießen",
    "hinterhake": "hinterhaken",
    "hinterhakend": "hinterhaken",
    "hinterhakende": "hinterhakend",
    "hinterhakendem": "hinterhakend",
    "hinterhakenden": "hinterhakend",
    "hinterhakender": "hinterhakend",
    "hinterhakendes": "hinterhakend",
    "hinterhakest": "hinterhaken",
    "hinterhaket": "hinterhaken",
    "hinterhakst": "hinterhaken",
    "hinterhakt": "hinterhaken",
    "hinterhakte": "hinterhaken",
    "hinterhakten": "hinterhaken",
    "hinterhaktest": "hinterhaken",
    "hinterhaktet": "hinterhaken",
    "hinterherfahre": "hinterherfahren",
    "hinterherfahrend": "hinterherfahren",
    "hinterherfahrende": "hinterherfahrend",
    "hinterherfahrendem": "hinterherfahrend",
    "hinterherfahrenden": "hinterherfahrend",
    "hinterherfahrender": "hinterherfahrend",
    "hinterherfahrendes": "hinterherfahrend",
    "hinterherfahrest": "hinterherfahren",
    "hinterherfahret": "hinterherfahren",
    "hinterherfahrt": "hinterherfahren",
    "hinterherfuhr": "hinterherfahren",
    "hinterherfuhren": "hinterherfahren",
    "hinterherfuhrst": "hinterherfahren",
    "hinterherfuhrt": "hinterherfahren",
    "hinterherfährst": "hinterherfahren",
    "hinterherfährt": "hinterherfahren",
    "hinterherführe": "hinterherfahren",
    "hinterherführen": "hinterherfahren",
    "hinterherführest": "hinterherfahren",
    "hinterherführet": "hinterherfahren",
    "hinterhergefahren": "hinterherfahren",
    "hinterhergefahrene": "hinterhergefahren",
    "hinterhergefahrenem": "hinterhergefahren",
    "hinterhergefahrenen": "hinterhergefahren",
    "hinterhergefahrener": "hinterhergefahren",
    "hinterhergefahrenes": "hinterhergefahren",
    "hinterhergeräumt": "hinterherräumen",
    "hinterhergeräumte": "hinterhergeräumt",
    "hinterhergeräumtem": "hinterhergeräumt",
    "hinterhergeräumten": "hinterhergeräumt",
    "hinterhergeräumter": "hinterhergeräumt",
    "hinterhergeräumtes": "hinterhergeräumt",
    "hinterhergesandt": "hinterhersenden",
    "hinterhergesandte": "hinterhergesandt",
    "hinterhergesandtem": "hinterhergesandt",
    "hinterhergesandten": "hinterhergesandt",
    "hinterhergesandter": "hinterhergesandt",
    "hinterhergesandtes": "hinterhergesandt",
    "hinterhergeschwommen": "hinterherschwimme",
    "hinterhergeschwommene": "hinterhergeschwommen",
    "hinterhergeschwommenem": "hinterhergeschwommen",
    "hinterhergeschwommenen": "hinterhergeschwommen",
    "hinterhergeschwommener": "hinterhergeschwommen",
    "hinterhergeschwommenes": "hinterhergeschwommen",
    "hinterhergesendet": "hinterhersenden",
    "hinterhergesendete": "hinterhergesendet",
    "hinterhergesendetem": "hinterhergesendet",
    "hinterhergesendeten": "hinterhergesendet",
    "hinterhergesendeter": "hinterhergesendet",
    "hinterhergesendetes": "hinterhergesendet",
    "hinterhergesprungen": "hinterherspringen",
    "hinterhergesprungene": "hinterhergesprungen",
    "hinterhergesprungenem": "hinterhergesprungen",
    "hinterhergesprungenen": "hinterhergesprungen",
    "hinterhergesprungener": "hinterhergesprungen",
    "hinterhergesprungenes": "hinterhergesprungen",
    "hinterherräume": "hinterherräumen",
    "hinterherräumend": "hinterherräumen",
    "hinterherräumende": "hinterherräumend",
    "hinterherräumendem": "hinterherräumend",
    "hinterherräumenden": "hinterherräumend",
    "hinterherräumender": "hinterherräumend",
    "hinterherräumendes": "hinterherräumend",
    "hinterherräumest": "hinterherräumen",
    "hinterherräumet": "hinterherräumen",
    "hinterherräumst": "hinterherräumen",
    "hinterherräumt": "hinterherräumen",
    "hinterherräumte": "hinterherräumen",
    "hinterherräumten": "hinterherräumen",
    "hinterherräumtest": "hinterherräumen",
    "hinterherräumtet": "hinterherräumen",
    "hinterhersandte": "hinterhersenden",
    "hinterhersandten": "hinterhersenden",
    "hinterhersandtest": "hinterhersenden",
    "hinterhersandtet": "hinterhersenden",
    "hinterherschwamm": "hinterherschwimme",
    "hinterherschwammen": "hinterherschwimme",
    "hinterherschwammst": "hinterherschwimme",
    "hinterherschwammt": "hinterherschwimme",
    "hinterherschwimmen": "hinterherschwimme",
    "hinterherschwimmend": "hinterherschwimme",
    "hinterherschwimmende": "hinterherschwimmend",
    "hinterherschwimmendem": "hinterherschwimmend",
    "hinterherschwimmenden": "hinterherschwimmend",
    "hinterherschwimmender": "hinterherschwimmend",
    "hinterherschwimmendes": "hinterherschwimmend",
    "hinterherschwimmest": "hinterherschwimme",
    "hinterherschwimmet": "hinterherschwimme",
    "hinterherschwimmst": "hinterherschwimme",
    "hinterherschwimmt": "hinterherschwimme",
    "hinterherschwämme": "hinterherschwimme",
    "hinterherschwämmen": "hinterherschwimme",
    "hinterherschwämmest": "hinterherschwimme",
    "hinterherschwämmet": "hinterherschwimme",
    "hinterhersende": "hinterhersenden",
    "hinterhersendend": "hinterhersenden",
    "hinterhersendende": "hinterhersendend",
    "hinterhersendendem": "hinterhersendend",
    "hinterhersendenden": "hinterhersendend",
    "hinterhersendender": "hinterhersendend",
    "hinterhersendendes": "hinterhersendend",
    "hinterhersendest": "hinterhersenden",
    "hinterhersendet": "hinterhersenden",
    "hinterhersendete": "hinterhersenden",
    "hinterhersendeten": "hinterhersenden",
    "hinterhersendetest": "hinterhersenden",
    "hinterhersendetet": "hinterhersenden",
    "hinterhersprang": "hinterherspringen",
    "hinterhersprangen": "hinterherspringen",
    "hinterhersprangst": "hinterherspringen",
    "hinterhersprangt": "hinterherspringen",
    "hinterherspringe": "hinterherspringen",
    "hinterherspringend": "hinterherspringen",
    "hinterherspringende": "hinterherspringend",
    "hinterherspringendem": "hinterherspringend",
    "hinterherspringenden": "hinterherspringend",
    "hinterherspringender": "hinterherspringend",
    "hinterherspringendes": "hinterherspringend",
    "hinterherspringest": "hinterherspringen",
    "hinterherspringet": "hinterherspringen",
    "hinterherspringst": "hinterherspringen",
    "hinterherspringt": "hinterherspringen",
    "hinterherspränge": "hinterherspringen",
    "hinterhersprängen": "hinterherspringen",
    "hinterhersprängest": "hinterherspringen",
    "hinterherspränget": "hinterherspringen",
    "hinterherzufahren": "hinterherfahren",
    "hinterherzuräumen": "hinterherräumen",
    "hinterherzuschwimmen": "hinterherschwimme",
    "hinterherzusenden": "hinterhersenden",
    "hinterherzuspringen": "hinterherspringen",
    "hinterhältige": "hinterhältig",
    "hinterhältigem": "hinterhältig",
    "hinterhältigen": "hinterhältig",
    "hinterhältiger": "hinterhältig",
    "hinterhältigere": "hinterhältig",
    "hinterhältigerem": "hinterhältig",
    "hinterhältigeren": "hinterhältig",
    "hinterhältigerer": "hinterhältig",
    "hinterhältigeres": "hinterhältig",
    "hinterhältiges": "hinterhältig",
    "hinterhältigste": "hinterhältig",
    "hinterhältigstem": "hinterhältig",
    "hinterhältigsten": "hinterhältig",
    "hinterhältigster": "hinterhältig",
    "hinterhältigstes": "hinterhältig",
    "hinterißt": "hinteressen",
    "hinterkaue": "hinterkauen",
    "hinterkauend": "hinterkauen",
    "hinterkauende": "hinterkauend",
    "hinterkauendem": "hinterkauend",
    "hinterkauenden": "hinterkauend",
    "hinterkauender": "hinterkauend",
    "hinterkauendes": "hinterkauend",
    "hinterkauest": "hinterkauen",
    "hinterkauet": "hinterkauen",
    "hinterkaust": "hinterkauen",
    "hinterkaut": "hinterkauen",
    "hinterkaute": "hinterkauen",
    "hinterkauten": "hinterkauen",
    "hinterkautest": "hinterkauen",
    "hinterkautet": "hinterkauen",
    "hinterlasse": "hinterlassen",
    "hinterlassend": "hinterlassen",
    "hinterlassende": "hinterlassend",
    "hinterlassendem": "hinterlassend",
    "hinterlassenden": "hinterlassend",
    "hinterlassender": "hinterlassend",
    "hinterlassendes": "hinterlassend",
    "hinterlassene": "hinterlassen",
    "hinterlassenem": "hinterlassen",
    "hinterlassenen": "hinterlassen",
    "hinterlassener": "hinterlassen",
    "hinterlassenes": "hinterlassen",
    "hinterlassest": "hinterlassen",
    "hinterlasset": "hinterlassen",
    "hinterlaß": "hinterlassen",
    "hinterlaßt": "hinterlassen",
    "hinterlege": "hinterlegen",
    "hinterlegend": "hinterlegen",
    "hinterlegende": "hinterlegend",
    "hinterlegendem": "hinterlegend",
    "hinterlegenden": "hinterlegend",
    "hinterlegender": "hinterlegend",
    "hinterlegendes": "hinterlegend",
    "hinterlegest": "hinterlegen",
    "hinterleget": "hinterlegen",
    "hinterlegst": "hinterlegen",
    "hinterlegt": "hinterlegen",
    "hinterlegte": "hinterlegen",
    "hinterlegtem": "hinterlegt",
    "hinterlegten": "hinterlegen",
    "hinterlegter": "hinterlegt",
    "hinterlegtes": "hinterlegt",
    "hinterlegtest": "hinterlegen",
    "hinterlegtet": "hinterlegen",
    "hinterließ": "hinterlassen",
    "hinterließe": "hinterlassen",
    "hinterließen": "hinterlassen",
    "hinterließest": "hinterlassen",
    "hinterließet": "hinterlassen",
    "hinterließt": "hinterlassen",
    "hinterlistige": "hinterlistig",
    "hinterlistigem": "hinterlistig",
    "hinterlistigen": "hinterlistig",
    "hinterlistiger": "hinterlistig",
    "hinterlistigere": "hinterlistig",
    "hinterlistigerem": "hinterlistig",
    "hinterlistigeren": "hinterlistig",
    "hinterlistigerer": "hinterlistig",
    "hinterlistigeres": "hinterlistig",
    "hinterlistiges": "hinterlistig",
    "hinterlistigste": "hinterlistig",
    "hinterlistigstem": "hinterlistig",
    "hinterlistigsten": "hinterlistig",
    "hinterlistigster": "hinterlistig",
    "hinterlistigstes": "hinterlistig",
    "hinterläßt": "hinterlassen",
    "hintersinnigem": "hintersinnig",
    "hintersinnigen": "hintersinnig",
    "hintersinniger": "hintersinnig",
    "hintersinnigere": "hintersinnig",
    "hintersinnigerem": "hintersinnig",
    "hintersinnigeren": "hintersinnig",
    "hintersinnigerer": "hintersinnig",
    "hintersinnigeres": "hintersinnig",
    "hintersinniges": "hintersinnig",
    "hintersinnigste": "hintersinnig",
    "hintersinnigstem": "hintersinnig",
    "hintersinnigsten": "hintersinnig",
    "hintersinnigster": "hintersinnig",
    "hintersinnigstes": "hintersinnig",
    "hinterste": "hinter",
    "hinterstem": "hinter",
    "hintersten": "hinter",
    "hinterster": "hinter",
    "hinterstes": "hinter",
    "hinterwäldlerischem": "hinterwäldlerisch",
    "hinterwäldlerischen": "hinterwäldlerisch",
    "hinterwäldlerischer": "hinterwäldlerisch",
    "hinterwäldlerischere": "hinterwäldlerisch",
    "hinterwäldlerischerem": "hinterwäldlerisch",
    "hinterwäldlerischeren": "hinterwäldlerisch",
    "hinterwäldlerischerer": "hinterwäldlerisch",
    "hinterwäldlerischeres": "hinterwäldlerisch",
    "hinterwäldlerisches": "hinterwäldlerisch",
    "hinterwäldlerischste": "hinterwäldlerisch",
    "hinterwäldlerischstem": "hinterwäldlerisch",
    "hinterwäldlerischsten": "hinterwäldlerisch",
    "hinterwäldlerischster": "hinterwäldlerisch",
    "hinterwäldlerischstes": "hinterwäldlerisch",
    "hinterziehe": "hinterziehen",
    "hinterziehend": "hinterziehen",
    "hinterziehende": "hinterziehend",
    "hinterziehendem": "hinterziehend",
    "hinterziehenden": "hinterziehend",
    "hinterziehender": "hinterziehend",
    "hinterziehendes": "hinterziehend",
    "hinterziehest": "hinterziehen",
    "hinterziehet": "hinterziehen",
    "hinterziehst": "hinterziehen",
    "hinterzieht": "hinterziehen",
    "hinterzog": "hinterziehen",
    "hinterzogen": "hinterziehen",
    "hinterzogene": "hinterzogen",
    "hinterzogenem": "hinterzogen",
    "hinterzogenen": "hinterzogen",
    "hinterzogener": "hinterzogen",
    "hinterzogenes": "hinterzogen",
    "hinterzogst": "hinterziehen",
    "hinterzogt": "hinterziehen",
    "hinterzuessen": "hinteressen",
    "hinterzugießen": "hintergießen",
    "hinterzuhaken": "hinterhaken",
    "hinterzukauen": "hinterkauen",
    "hinterzöge": "hinterziehen",
    "hinterzögen": "hinterziehen",
    "hinterzögest": "hinterziehen",
    "hinterzöget": "hinterziehen",
    "hinteräße": "hinteressen",
    "hinteräßen": "hinteressen",
    "hinteräßest": "hinteressen",
    "hinteräßet": "hinteressen",
    "hintrage": "hintragen",
    "hintragend": "hintragen",
    "hintragende": "hintragend",
    "hintragendem": "hintragend",
    "hintragenden": "hintragend",
    "hintragender": "hintragend",
    "hintragendes": "hintragend",
    "hintragest": "hintragen",
    "hintraget": "hintragen",
    "hintragt": "hintragen",
    "hintrat": "hintreten",
    "hintraten": "hintreten",
    "hintratest": "hintreten",
    "hintratet": "hintreten",
    "hintreibe": "hintreiben",
    "hintreibend": "hintreiben",
    "hintreibende": "hintreibend",
    "hintreibendem": "hintreibend",
    "hintreibenden": "hintreibend",
    "hintreibender": "hintreibend",
    "hintreibendes": "hintreibend",
    "hintreibest": "hintreiben",
    "hintreibet": "hintreiben",
    "hintreibst": "hintreiben",
    "hintreibt": "hintreiben",
    "hintrete": "hintreten",
    "hintretend": "hintreten",
    "hintretende": "hintretend",
    "hintretendem": "hintretend",
    "hintretenden": "hintretend",
    "hintretender": "hintretend",
    "hintretendes": "hintretend",
    "hintretest": "hintreten",
    "hintretet": "hintreten",
    "hintrieb": "hintreiben",
    "hintriebe": "hintreiben",
    "hintrieben": "hintreiben",
    "hintriebest": "hintreiben",
    "hintriebet": "hintreiben",
    "hintriebst": "hintreiben",
    "hintriebt": "hintreiben",
    "hintritt": "hintreten",
    "hintrittst": "hintreten",
    "hintrug": "hintragen",
    "hintrugen": "hintragen",
    "hintrugst": "hintragen",
    "hintrugt": "hintragen",
    "hinträgst": "hintragen",
    "hinträgt": "hintragen",
    "hinträte": "hintreten",
    "hinträten": "hintreten",
    "hinträtest": "hintreten",
    "hinträtet": "hintreten",
    "hintrüge": "hintragen",
    "hintrügen": "hintragen",
    "hintrügest": "hintragen",
    "hintrüget": "hintragen",
    "hinunterbemühe": "hinunterbemühen",
    "hinunterbemühend": "hinunterbemühen",
    "hinunterbemühende": "hinunterbemühend",
    "hinunterbemühendem": "hinunterbemühend",
    "hinunterbemühenden": "hinunterbemühend",
    "hinunterbemühender": "hinunterbemühend",
    "hinunterbemühendes": "hinunterbemühend",
    "hinunterbemühest": "hinunterbemühen",
    "hinunterbemühet": "hinunterbemühen",
    "hinunterbemühst": "hinunterbemühen",
    "hinunterbemüht": "hinunterbemühen",
    "hinunterbemühte": "hinunterbemühen",
    "hinunterbemühtem": "hinunterbemüht",
    "hinunterbemühten": "hinunterbemühen",
    "hinunterbemühter": "hinunterbemüht",
    "hinunterbemühtes": "hinunterbemüht",
    "hinunterbemühtest": "hinunterbemühen",
    "hinunterbemühtet": "hinunterbemühen",
    "hinunterfließe": "hinunterfließen",
    "hinunterfließend": "hinunterfließen",
    "hinunterfließende": "hinunterfließend",
    "hinunterfließendem": "hinunterfließend",
    "hinunterfließenden": "hinunterfließend",
    "hinunterfließender": "hinunterfließend",
    "hinunterfließendes": "hinunterfließend",
    "hinunterfließest": "hinunterfließen",
    "hinunterfließet": "hinunterfließen",
    "hinunterfließt": "hinunterfließen",
    "hinunterflossen": "hinunterfließen",
    "hinunterfloß": "hinunterfließen",
    "hinunterfloßt": "hinunterfließen",
    "hinunterflösse": "hinunterfließen",
    "hinunterflössen": "hinunterfließen",
    "hinunterflössest": "hinunterfließen",
    "hinunterflösset": "hinunterfließen",
    "hinunterführe": "hinunterführen",
    "hinunterführend": "hinunterführen",
    "hinunterführende": "hinunterführend",
    "hinunterführendem": "hinunterführend",
    "hinunterführenden": "hinunterführend",
    "hinunterführender": "hinunterführend",
    "hinunterführendes": "hinunterführend",
    "hinunterführest": "hinunterführen",
    "hinunterführet": "hinunterführen",
    "hinunterführst": "hinunterführen",
    "hinunterführt": "hinunterführen",
    "hinunterführte": "hinunterführen",
    "hinunterführten": "hinunterführen",
    "hinunterführtest": "hinunterführen",
    "hinunterführtet": "hinunterführen",
    "hinuntergeflossen": "hinunterfließen",
    "hinuntergeflossene": "hinuntergeflossen",
    "hinuntergeflossenem": "hinuntergeflossen",
    "hinuntergeflossenen": "hinuntergeflossen",
    "hinuntergeflossener": "hinuntergeflossen",
    "hinuntergeflossenes": "hinuntergeflossen",
    "hinuntergeführt": "hinunterführen",
    "hinuntergeführte": "hinuntergeführt",
    "hinuntergeführtem": "hinuntergeführt",
    "hinuntergeführten": "hinuntergeführt",
    "hinuntergeführter": "hinuntergeführt",
    "hinuntergeführtes": "hinuntergeführt",
    "hinuntergestürzt": "hinunterstürzen",
    "hinuntergestürzte": "hinuntergestürzt",
    "hinuntergestürztem": "hinuntergestürzt",
    "hinuntergestürzten": "hinuntergestürzt",
    "hinuntergestürzter": "hinuntergestürzt",
    "hinuntergestürztes": "hinuntergestürzt",
    "hinuntergezogen": "hinunterziehen",
    "hinuntergezogene": "hinuntergezogen",
    "hinuntergezogenem": "hinuntergezogen",
    "hinuntergezogenen": "hinuntergezogen",
    "hinuntergezogener": "hinuntergezogen",
    "hinuntergezogenes": "hinuntergezogen",
    "hinunterstürze": "hinunterstürzen",
    "hinunterstürzend": "hinunterstürzen",
    "hinunterstürzende": "hinunterstürzend",
    "hinunterstürzendem": "hinunterstürzend",
    "hinunterstürzenden": "hinunterstürzend",
    "hinunterstürzender": "hinunterstürzend",
    "hinunterstürzendes": "hinunterstürzend",
    "hinunterstürzest": "hinunterstürzen",
    "hinunterstürzet": "hinunterstürzen",
    "hinunterstürzt": "hinunterstürzen",
    "hinunterstürzte": "hinunterstürzen",
    "hinunterstürzten": "hinunterstürzen",
    "hinunterstürztest": "hinunterstürzen",
    "hinunterstürztet": "hinunterstürzen",
    "hinunterziehe": "hinunterziehen",
    "hinunterziehend": "hinunterziehen",
    "hinunterziehende": "hinunterziehend",
    "hinunterziehendem": "hinunterziehend",
    "hinunterziehenden": "hinunterziehend",
    "hinunterziehender": "hinunterziehend",
    "hinunterziehendes": "hinunterziehend",
    "hinunterziehest": "hinunterziehen",
    "hinunterziehet": "hinunterziehen",
    "hinunterziehst": "hinunterziehen",
    "hinunterzieht": "hinunterziehen",
    "hinunterzog": "hinunterziehen",
    "hinunterzogen": "hinunterziehen",
    "hinunterzogst": "hinunterziehen",
    "hinunterzogt": "hinunterziehen",
    "hinunterzubemühen": "hinunterbemühen",
    "hinunterzufließen": "hinunterfließen",
    "hinunterzuführen": "hinunterführen",
    "hinunterzustürzen": "hinunterstürzen",
    "hinunterzuziehen": "hinunterziehen",
    "hinunterzöge": "hinunterziehen",
    "hinunterzögen": "hinunterziehen",
    "hinunterzögest": "hinunterziehen",
    "hinunterzöget": "hinunterziehen",
    "hinwandte": "hinwenden",
    "hinwandten": "hinwenden",
    "hinwandtest": "hinwenden",
    "hinwandtet": "hinwenden",
    "hinwarf": "hinwerfen",
    "hinwarfen": "hinwerfen",
    "hinwarfst": "hinwerfen",
    "hinwarft": "hinwerfen",
    "hinweggekommen": "hinwegkommen",
    "hinweggekommene": "hinweggekommen",
    "hinweggekommenem": "hinweggekommen",
    "hinweggekommenen": "hinweggekommen",
    "hinweggekommener": "hinweggekommen",
    "hinweggekommenes": "hinweggekommen",
    "hinweggesehen": "hinwegsehen",
    "hinweggesehene": "hinweggesehen",
    "hinweggesehenem": "hinweggesehen",
    "hinweggesehenen": "hinweggesehen",
    "hinweggesehener": "hinweggesehen",
    "hinweggesehenes": "hinweggesehen",
    "hinweggesetzt": "hinwegsetzen",
    "hinweggesetzte": "hinweggesetzt",
    "hinweggesetztem": "hinweggesetzt",
    "hinweggesetzten": "hinweggesetzt",
    "hinweggesetzter": "hinweggesetzt",
    "hinweggesetztes": "hinweggesetzt",
    "hinweggetröstet": "hinwegtrösten",
    "hinweggetröstete": "hinweggetröstet",
    "hinweggetröstetem": "hinweggetröstet",
    "hinweggetrösteten": "hinweggetröstet",
    "hinweggetrösteter": "hinweggetröstet",
    "hinweggetröstetes": "hinweggetröstet",
    "hinweggetäuscht": "hinwegtäuschen",
    "hinweggetäuschte": "hinweggetäuscht",
    "hinweggetäuschtem": "hinweggetäuscht",
    "hinweggetäuschten": "hinweggetäuscht",
    "hinweggetäuschter": "hinweggetäuscht",
    "hinweggetäuschtes": "hinweggetäuscht",
    "hinwegkam": "hinwegkommen",
    "hinwegkamen": "hinwegkommen",
    "hinwegkamst": "hinwegkommen",
    "hinwegkamt": "hinwegkommen",
    "hinwegkomme": "hinwegkommen",
    "hinwegkommend": "hinwegkommen",
    "hinwegkommende": "hinwegkommend",
    "hinwegkommendem": "hinwegkommend",
    "hinwegkommenden": "hinwegkommend",
    "hinwegkommender": "hinwegkommend",
    "hinwegkommendes": "hinwegkommend",
    "hinwegkommest": "hinwegkommen",
    "hinwegkommet": "hinwegkommen",
    "hinwegkommst": "hinwegkommen",
    "hinwegkommt": "hinwegkommen",
    "hinwegkäme": "hinwegkommen",
    "hinwegkämen": "hinwegkommen",
    "hinwegkämest": "hinwegkommen",
    "hinwegkämet": "hinwegkommen",
    "hinwegsah": "hinwegsehen",
    "hinwegsahen": "hinwegsehen",
    "hinwegsahst": "hinwegsehen",
    "hinwegsaht": "hinwegsehen",
    "hinwegsehe": "hinwegsehen",
    "hinwegsehend": "hinwegsehen",
    "hinwegsehende": "hinwegsehend",
    "hinwegsehendem": "hinwegsehend",
    "hinwegsehenden": "hinwegsehend",
    "hinwegsehender": "hinwegsehend",
    "hinwegsehendes": "hinwegsehend",
    "hinwegsehest": "hinwegsehen",
    "hinwegsehet": "hinwegsehen",
    "hinwegseht": "hinwegsehen",
    "hinwegsetze": "hinwegsetzen",
    "hinwegsetzend": "hinwegsetzen",
    "hinwegsetzende": "hinwegsetzend",
    "hinwegsetzendem": "hinwegsetzend",
    "hinwegsetzenden": "hinwegsetzend",
    "hinwegsetzender": "hinwegsetzend",
    "hinwegsetzendes": "hinwegsetzend",
    "hinwegsetzest": "hinwegsetzen",
    "hinwegsetzet": "hinwegsetzen",
    "hinwegsetzt": "hinwegsetzen",
    "hinwegsetzte": "hinwegsetzen",
    "hinwegsetzten": "hinwegsetzen",
    "hinwegsetztest": "hinwegsetzen",
    "hinwegsetztet": "hinwegsetzen",
    "hinwegsiehst": "hinwegsehen",
    "hinwegsieht": "hinwegsehen",
    "hinwegsähe": "hinwegsehen",
    "hinwegsähen": "hinwegsehen",
    "hinwegsähest": "hinwegsehen",
    "hinwegsähet": "hinwegsehen",
    "hinwegtröste": "hinwegtrösten",
    "hinwegtröstend": "hinwegtrösten",
    "hinwegtröstende": "hinwegtröstend",
    "hinwegtröstendem": "hinwegtröstend",
    "hinwegtröstenden": "hinwegtröstend",
    "hinwegtröstender": "hinwegtröstend",
    "hinwegtröstendes": "hinwegtröstend",
    "hinwegtröstest": "hinwegtrösten",
    "hinwegtröstet": "hinwegtrösten",
    "hinwegtröstete": "hinwegtrösten",
    "hinwegtrösteten": "hinwegtrösten",
    "hinwegtröstetest": "hinwegtrösten",
    "hinwegtröstetet": "hinwegtrösten",
    "hinwegtäusche": "hinwegtäuschen",
    "hinwegtäuschend": "hinwegtäuschen",
    "hinwegtäuschende": "hinwegtäuschend",
    "hinwegtäuschendem": "hinwegtäuschend",
    "hinwegtäuschenden": "hinwegtäuschend",
    "hinwegtäuschender": "hinwegtäuschend",
    "hinwegtäuschendes": "hinwegtäuschend",
    "hinwegtäuschest": "hinwegtäuschen",
    "hinwegtäuschet": "hinwegtäuschen",
    "hinwegtäuschst": "hinwegtäuschen",
    "hinwegtäuscht": "hinwegtäuschen",
    "hinwegtäuschte": "hinwegtäuschen",
    "hinwegtäuschten": "hinwegtäuschen",
    "hinwegtäuschtest": "hinwegtäuschen",
    "hinwegtäuschtet": "hinwegtäuschen",
    "hinwegzukommen": "hinwegkommen",
    "hinwegzusehen": "hinwegsehen",
    "hinwegzusetzen": "hinwegsetzen",
    "hinwegzutrösten": "hinwegtrösten",
    "hinwegzutäuschen": "hinwegtäuschen",
    "hinweisend": "hinweisen",
    "hinweisende": "hinweisend",
    "hinweisendem": "hinweisend",
    "hinweisenden": "hinweisend",
    "hinweisender": "hinweisend",
    "hinweisendes": "hinweisend",
    "hinweisest": "hinweisen",
    "hinweiset": "hinweisen",
    "hinweist": "hinweisen",
    "hinwelke": "hinwelken",
    "hinwelkend": "hinwelken",
    "hinwelkende": "hinwelkend",
    "hinwelkendem": "hinwelkend",
    "hinwelkenden": "hinwelkend",
    "hinwelkender": "hinwelkend",
    "hinwelkendere": "hinwelkend",
    "hinwelkenderem": "hinwelkend",
    "hinwelkenderen": "hinwelkend",
    "hinwelkenderer": "hinwelkend",
    "hinwelkenderes": "hinwelkend",
    "hinwelkendes": "hinwelkend",
    "hinwelkendste": "hinwelkend",
    "hinwelkendstem": "hinwelkend",
    "hinwelkendsten": "hinwelkend",
    "hinwelkendster": "hinwelkend",
    "hinwelkendstes": "hinwelkend",
    "hinwelkest": "hinwelken",
    "hinwelket": "hinwelken",
    "hinwelkst": "hinwelken",
    "hinwelkt": "hinwelken",
    "hinwelkte": "hinwelken",
    "hinwelkten": "hinwelken",
    "hinwelktest": "hinwelken",
    "hinwelktet": "hinwelken",
    "hinwende": "hinwenden",
    "hinwendend": "hinwenden",
    "hinwendende": "hinwendend",
    "hinwendendem": "hinwendend",
    "hinwendenden": "hinwendend",
    "hinwendender": "hinwendend",
    "hinwendendes": "hinwendend",
    "hinwendest": "hinwenden",
    "hinwendet": "hinwenden",
    "hinwendete": "hinwenden",
    "hinwendeten": "hinwenden",
    "hinwendetest": "hinwenden",
    "hinwendetet": "hinwenden",
    "hinwerfe": "hinwerfen",
    "hinwerfend": "hinwerfen",
    "hinwerfende": "hinwerfend",
    "hinwerfendem": "hinwerfend",
    "hinwerfenden": "hinwerfend",
    "hinwerfender": "hinwerfend",
    "hinwerfendes": "hinwerfend",
    "hinwerfest": "hinwerfen",
    "hinwerfet": "hinwerfen",
    "hinwerft": "hinwerfen",
    "hinwies": "hinweisen",
    "hinwiese": "hinweisen",
    "hinwiesen": "hinweisen",
    "hinwiesest": "hinweisen",
    "hinwieset": "hinweisen",
    "hinwiest": "hinweisen",
    "hinwirfst": "hinwerfen",
    "hinwirft": "hinwerfen",
    "hinwirke": "hinwirken",
    "hinwirkend": "hinwirken",
    "hinwirkende": "hinwirkend",
    "hinwirkendem": "hinwirkend",
    "hinwirkenden": "hinwirkend",
    "hinwirkender": "hinwirkend",
    "hinwirkendes": "hinwirkend",
    "hinwirkest": "hinwirken",
    "hinwirket": "hinwirken",
    "hinwirkst": "hinwirken",
    "hinwirkt": "hinwirken",
    "hinwirkte": "hinwirken",
    "hinwirkten": "hinwirken",
    "hinwirktest": "hinwirken",
    "hinwirktet": "hinwirken",
    "hinwärfe": "hinwerfen",
    "hinwärfen": "hinwerfen",
    "hinwärfest": "hinwerfen",
    "hinwärfet": "hinwerfen",
    "hinzaubere": "hinzaubern",
    "hinzaubernd": "hinzaubern",
    "hinzaubernde": "hinzaubernd",
    "hinzauberndem": "hinzaubernd",
    "hinzaubernden": "hinzaubernd",
    "hinzaubernder": "hinzaubernd",
    "hinzauberndes": "hinzaubernd",
    "hinzauberst": "hinzaubern",
    "hinzaubert": "hinzaubern",
    "hinzauberte": "hinzaubern",
    "hinzauberten": "hinzaubern",
    "hinzaubertest": "hinzaubern",
    "hinzaubertet": "hinzaubern",
    "hinzeige": "hinzeigen",
    "hinzeigend": "hinzeigen",
    "hinzeigende": "hinzeigend",
    "hinzeigendem": "hinzeigend",
    "hinzeigenden": "hinzeigend",
    "hinzeigender": "hinzeigend",
    "hinzeigendes": "hinzeigend",
    "hinzeigest": "hinzeigen",
    "hinzeiget": "hinzeigen",
    "hinzeigst": "hinzeigen",
    "hinzeigt": "hinzeigen",
    "hinzeigte": "hinzeigen",
    "hinzeigten": "hinzeigen",
    "hinzeigtest": "hinzeigen",
    "hinzeigtet": "hinzeigen",
    "hinziehe": "hinziehen",
    "hinziehend": "hinziehen",
    "hinziehende": "hinziehend",
    "hinziehendem": "hinziehend",
    "hinziehenden": "hinziehend",
    "hinziehender": "hinziehend",
    "hinziehendes": "hinziehend",
    "hinziehest": "hinziehen",
    "hinziehet": "hinziehen",
    "hinziehst": "hinziehen",
    "hinzieht": "hinziehen",
    "hinzog": "hinziehen",
    "hinzogen": "hinziehen",
    "hinzogst": "hinziehen",
    "hinzogt": "hinziehen",
    "hinzuarbeiten": "hinarbeiten",
    "hinzubegleiten": "hinbegleiten",
    "hinzubemühen": "hinbemühen",
    "hinzubestellen": "hinbestellen",
    "hinzubiegen": "hinbiegen",
    "hinzublättern": "hinblättern",
    "hinzubringen": "hinbringen",
    "hinzubrüten": "hinbrüten",
    "hinzudachte": "hinzudenken",
    "hinzudachten": "hinzudenken",
    "hinzudachtest": "hinzudenken",
    "hinzudachtet": "hinzudenken",
    "hinzudenke": "hinzudenken",
    "hinzudenken": "hindenken",
    "hinzudenkend": "hinzudenken",
    "hinzudenkende": "hinzudenkend",
    "hinzudenkendem": "hinzudenkend",
    "hinzudenkenden": "hinzudenkend",
    "hinzudenkender": "hinzudenkend",
    "hinzudenkendes": "hinzudenkend",
    "hinzudenkest": "hinzudenken",
    "hinzudenket": "hinzudenken",
    "hinzudenkst": "hinzudenken",
    "hinzudenkt": "hinzudenken",
    "hinzudeuten": "hindeuten",
    "hinzudrängen": "hindrängen",
    "hinzudächte": "hinzudenken",
    "hinzudächten": "hinzudenken",
    "hinzudächtest": "hinzudenken",
    "hinzudächtet": "hinzudenken",
    "hinzudämmern": "hindämmern",
    "hinzueilen": "hineilen",
    "hinzufahren": "hinfahren",
    "hinzufallen": "hinfallen",
    "hinzufinden": "hinfinden",
    "hinzuflegeln": "hinflegeln",
    "hinzufliegen": "hinfliegen",
    "hinzufließen": "hinfließen",
    "hinzufläzen": "hinfläzen",
    "hinzufüge": "hinzufügen",
    "hinzufügend": "hinzufügen",
    "hinzufügende": "hinzufügend",
    "hinzufügendem": "hinzufügend",
    "hinzufügenden": "hinzufügend",
    "hinzufügender": "hinzufügend",
    "hinzufügendes": "hinzufügend",
    "hinzufügest": "hinzufügen",
    "hinzufüget": "hinzufügen",
    "hinzufügst": "hinzufügen",
    "hinzufügt": "hinzufügen",
    "hinzufügte": "hinzufügen",
    "hinzufügten": "hinzufügen",
    "hinzufügtest": "hinzufügen",
    "hinzufügtet": "hinzufügen",
    "hinzuführen": "hinführen",
    "hinzugeben": "hingeben",
    "hinzugedacht": "hinzudenken",
    "hinzugedachte": "hinzugedacht",
    "hinzugedachtem": "hinzugedacht",
    "hinzugedachten": "hinzugedacht",
    "hinzugedachter": "hinzugedacht",
    "hinzugedachtes": "hinzugedacht",
    "hinzugefügt": "hinzufügen",
    "hinzugefügte": "hinzugefügt",
    "hinzugefügtem": "hinzugefügt",
    "hinzugefügten": "hinzugefügt",
    "hinzugefügter": "hinzugefügt",
    "hinzugefügtes": "hinzugefügt",
    "hinzugehen": "hingehen",
    "hinzugehören": "hingehören",
    "hinzugeraten": "hingeraten",
    "hinzugeselle": "hinzugesellen",
    "hinzugesellend": "hinzugesellen",
    "hinzugesellende": "hinzugesellend",
    "hinzugesellendem": "hinzugesellend",
    "hinzugesellenden": "hinzugesellend",
    "hinzugesellender": "hinzugesellend",
    "hinzugesellendes": "hinzugesellend",
    "hinzugesellest": "hinzugesellen",
    "hinzugesellet": "hinzugesellen",
    "hinzugesellst": "hinzugesellen",
    "hinzugesellt": "hinzugesellen",
    "hinzugesellte": "hinzugesellen",
    "hinzugeselltem": "hinzugesellt",
    "hinzugesellten": "hinzugesellen",
    "hinzugesellter": "hinzugesellt",
    "hinzugeselltes": "hinzugesellt",
    "hinzugeselltest": "hinzugesellen",
    "hinzugeselltet": "hinzugesellen",
    "hinzugesetzt": "hinzusetzen",
    "hinzugesetzte": "hinzugesetzt",
    "hinzugesetztem": "hinzugesetzt",
    "hinzugesetzten": "hinzugesetzt",
    "hinzugesetzter": "hinzugesetzt",
    "hinzugesetztes": "hinzugesetzt",
    "hinzugestellt": "hinzustellen",
    "hinzugestellte": "hinzugestellt",
    "hinzugestelltem": "hinzugestellt",
    "hinzugestellten": "hinzugestellt",
    "hinzugestellter": "hinzugestellt",
    "hinzugestelltes": "hinzugestellt",
    "hinzugetreten": "hinzutreten",
    "hinzugetretene": "hinzugetreten",
    "hinzugetretenem": "hinzugetreten",
    "hinzugetretenen": "hinzugetreten",
    "hinzugetretener": "hinzugetreten",
    "hinzugetretenes": "hinzugetreten",
    "hinzugezählt": "hinzuzählen",
    "hinzugezählte": "hinzugezählt",
    "hinzugezähltem": "hinzugezählt",
    "hinzugezählten": "hinzugezählt",
    "hinzugezählter": "hinzugezählt",
    "hinzugezähltes": "hinzugezählt",
    "hinzugießen": "hingießen",
    "hinzuhalten": "hinhalten",
    "hinzuhauchen": "hinhauchen",
    "hinzuhauen": "hinhauen",
    "hinzuhorchen": "hinhorchen",
    "hinzuhängen": "hinhängen",
    "hinzuhören": "hinhören",
    "hinzukauern": "hinkauern",
    "hinzuklotzen": "hinklotzen",
    "hinzuknien": "hinknien",
    "hinzukommen": "hinkommen",
    "hinzukriegen": "hinkriegen",
    "hinzulangen": "hinlangen",
    "hinzulassen": "hinlassen",
    "hinzulaufen": "hinlaufen",
    "hinzulegen": "hinlegen",
    "hinzulümmeln": "hinlümmeln",
    "hinzumachen": "hinmachen",
    "hinzunehmen": "hinnehmen",
    "hinzuneigen": "hinneigen",
    "hinzupurzeln": "hinpurzeln",
    "hinzuraffen": "hinraffen",
    "hinzureiben": "hinreiben",
    "hinzureichen": "hinreichen",
    "hinzureisen": "hinreisen",
    "hinzureißen": "hinreißen",
    "hinzurennen": "hinrennen",
    "hinzurichten": "hinrichten",
    "hinzusagen": "hinsagen",
    "hinzuschaffen": "hinschaffen",
    "hinzuschauen": "hinschauen",
    "hinzuscheiden": "hinscheiden",
    "hinzuschieben": "hinschieben",
    "hinzuschlachten": "hinschlachten",
    "hinzuschlagen": "hinschlagen",
    "hinzuschleichen": "hinschleichen",
    "hinzuschleppen": "hinschleppen",
    "hinzuschmeißen": "hinschmeißen",
    "hinzuschmelzen": "hinschmelzen",
    "hinzuschmieren": "hinschmieren",
    "hinzuschreiben": "hinschreiben",
    "hinzuschwimmen": "hinschwimmen",
    "hinzuschwinden": "hinschwinden",
    "hinzuschütten": "hinschütten",
    "hinzusehen": "hinsehen",
    "hinzusetze": "hinzusetzen",
    "hinzusetzen": "hinsetzen",
    "hinzusetzend": "hinzusetzen",
    "hinzusetzende": "hinzusetzend",
    "hinzusetzendem": "hinzusetzend",
    "hinzusetzenden": "hinzusetzend",
    "hinzusetzender": "hinzusetzend",
    "hinzusetzendes": "hinzusetzend",
    "hinzusetzest": "hinzusetzen",
    "hinzusetzet": "hinzusetzen",
    "hinzusetzt": "hinzusetzen",
    "hinzusetzte": "hinzusetzen",
    "hinzusetzten": "hinzusetzen",
    "hinzusetztest": "hinzusetzen",
    "hinzusetztet": "hinzusetzen",
    "hinzusiechen": "hinsiechen",
    "hinzusinken": "hinsinken",
    "hinzustellen": "hinstellen",
    "hinzustellend": "hinzustellen",
    "hinzustellende": "hinzustellend",
    "hinzustellendem": "hinzustellend",
    "hinzustellenden": "hinzustellend",
    "hinzustellender": "hinzustellend",
    "hinzustellendes": "hinzustellend",
    "hinzusterben": "hinsterben",
    "hinzusteuern": "hinsteuern",
    "hinzustreben": "hinstreben",
    "hinzuströmen": "hinströmen",
    "hinzustürzen": "hinstürzen",
    "hinzutragen": "hintragen",
    "hinzutrat": "hinzutreten",
    "hinzutraten": "hinzutreten",
    "hinzutratest": "hinzutreten",
    "hinzutratet": "hinzutreten",
    "hinzutreiben": "hintreiben",
    "hinzutrete": "hinzutreten",
    "hinzutreten": "hintreten",
    "hinzutretend": "hinzutreten",
    "hinzutretende": "hinzutretend",
    "hinzutretendem": "hinzutretend",
    "hinzutretenden": "hinzutretend",
    "hinzutretender": "hinzutretend",
    "hinzutretendes": "hinzutretend",
    "hinzutretest": "hinzutreten",
    "hinzutretet": "hinzutreten",
    "hinzutritt": "hinzutreten",
    "hinzutrittst": "hinzutreten",
    "hinzuträte": "hinzutreten",
    "hinzuträten": "hinzutreten",
    "hinzuträtest": "hinzutreten",
    "hinzuträtet": "hinzutreten",
    "hinzuweisen": "hinweisen",
    "hinzuwelken": "hinwelken",
    "hinzuwenden": "hinwenden",
    "hinzuwerfen": "hinwerfen",
    "hinzuwirken": "hinwirken",
    "hinzuzaubern": "hinzaubern",
    "hinzuzeigen": "hinzeigen",
    "hinzuziehen": "hinziehen",
    "hinzuzudenken": "hinzudenken",
    "hinzuzufügen": "hinzufügen",
    "hinzuzugesellen": "hinzugesellen",
    "hinzuzusetzen": "hinzusetzen",
    "hinzuzutreten": "hinzutreten",
    "hinzuzuzählen": "hinzuzählen",
    "hinzuzähle": "hinzuzählen",
    "hinzuzählen": "hinzählen",
    "hinzuzählend": "hinzuzählen",
    "hinzuzählende": "hinzuzählend",
    "hinzuzählendem": "hinzuzählend",
    "hinzuzählenden": "hinzuzählend",
    "hinzuzählender": "hinzuzählend",
    "hinzuzählendes": "hinzuzählend",
    "hinzuzählest": "hinzuzählen",
    "hinzuzählet": "hinzuzählen",
    "hinzuzählst": "hinzuzählen",
    "hinzuzählt": "hinzuzählen",
    "hinzuzählte": "hinzuzählen",
    "hinzuzählten": "hinzuzählen",
    "hinzuzähltest": "hinzuzählen",
    "hinzuzähltet": "hinzuzählen",
    "hinzähle": "hinzählen",
    "hinzählend": "hinzählen",
    "hinzählende": "hinzählend",
    "hinzählendem": "hinzählend",
    "hinzählenden": "hinzählend",
    "hinzählender": "hinzählend",
    "hinzählendes": "hinzählend",
    "hinzählest": "hinzählen",
    "hinzählet": "hinzählen",
    "hinzählst": "hinzählen",
    "hinzählt": "hinzählen",
    "hinzählte": "hinzählen",
    "hinzählten": "hinzählen",
    "hinzähltest": "hinzählen",
    "hinzähltet": "hinzählen",
    "hinzöge": "hinziehen",
    "hinzögen": "hinziehen",
    "hinzögest": "hinziehen",
    "hinzöget": "hinziehen",
    "hinüberbemühe": "hinüberbemühen",
    "hinüberbemühend": "hinüberbemühen",
    "hinüberbemühende": "hinüberbemühend",
    "hinüberbemühendem": "hinüberbemühend",
    "hinüberbemühenden": "hinüberbemühend",
    "hinüberbemühender": "hinüberbemühend",
    "hinüberbemühendes": "hinüberbemühend",
    "hinüberbemühest": "hinüberbemühen",
    "hinüberbemühet": "hinüberbemühen",
    "hinüberbemühst": "hinüberbemühen",
    "hinüberbemüht": "hinüberbemühen",
    "hinüberbemühte": "hinüberbemühen",
    "hinüberbemühtem": "hinüberbemüht",
    "hinüberbemühten": "hinüberbemühen",
    "hinüberbemühter": "hinüberbemüht",
    "hinüberbemühtes": "hinüberbemüht",
    "hinüberbemühtest": "hinüberbemühen",
    "hinüberbemühtet": "hinüberbemühen",
    "hinüberführe": "hinüberführen",
    "hinüberführend": "hinüberführen",
    "hinüberführende": "hinüberführend",
    "hinüberführendem": "hinüberführend",
    "hinüberführenden": "hinüberführend",
    "hinüberführender": "hinüberführend",
    "hinüberführendes": "hinüberführend",
    "hinüberführest": "hinüberführen",
    "hinüberführet": "hinüberführen",
    "hinüberführst": "hinüberführen",
    "hinüberführt": "hinüberführen",
    "hinüberführte": "hinüberführen",
    "hinüberführten": "hinüberführen",
    "hinüberführtest": "hinüberführen",
    "hinüberführtet": "hinüberführen",
    "hinübergeführt": "hinüberführen",
    "hinübergeführte": "hinübergeführt",
    "hinübergeführtem": "hinübergeführt",
    "hinübergeführten": "hinübergeführt",
    "hinübergeführter": "hinübergeführt",
    "hinübergeführtes": "hinübergeführt",
    "hinübergelappt": "hinüberlappen",
    "hinübergelappte": "hinübergelappt",
    "hinübergelapptem": "hinübergelappt",
    "hinübergelappten": "hinübergelappt",
    "hinübergelappter": "hinübergelappt",
    "hinübergelapptes": "hinübergelappt",
    "hinübergereicht": "hinüberreichen",
    "hinübergereichte": "hinübergereicht",
    "hinübergereichtem": "hinübergereicht",
    "hinübergereichten": "hinübergereicht",
    "hinübergereichter": "hinübergereicht",
    "hinübergereichtes": "hinübergereicht",
    "hinübergerückt": "hinüberrücken",
    "hinübergerückte": "hinübergerückt",
    "hinübergerücktem": "hinübergerückt",
    "hinübergerückten": "hinübergerückt",
    "hinübergerückter": "hinübergerückt",
    "hinübergerücktes": "hinübergerückt",
    "hinübergeschaut": "hinüberschauen",
    "hinübergeschaute": "hinübergeschaut",
    "hinübergeschautem": "hinübergeschaut",
    "hinübergeschauten": "hinübergeschaut",
    "hinübergeschauter": "hinübergeschaut",
    "hinübergeschautes": "hinübergeschaut",
    "hinübergezogen": "hinüberziehen",
    "hinübergezogene": "hinübergezogen",
    "hinübergezogenem": "hinübergezogen",
    "hinübergezogenen": "hinübergezogen",
    "hinübergezogener": "hinübergezogen",
    "hinübergezogenes": "hinübergezogen",
    "hinüberlappe": "hinüberlappen",
    "hinüberlappend": "hinüberlappen",
    "hinüberlappende": "hinüberlappend",
    "hinüberlappendem": "hinüberlappend",
    "hinüberlappenden": "hinüberlappend",
    "hinüberlappender": "hinüberlappend",
    "hinüberlappendere": "hinüberlappend",
    "hinüberlappenderem": "hinüberlappend",
    "hinüberlappenderen": "hinüberlappend",
    "hinüberlappenderer": "hinüberlappend",
    "hinüberlappenderes": "hinüberlappend",
    "hinüberlappendes": "hinüberlappend",
    "hinüberlappendste": "hinüberlappend",
    "hinüberlappendstem": "hinüberlappend",
    "hinüberlappendsten": "hinüberlappend",
    "hinüberlappendster": "hinüberlappend",
    "hinüberlappendstes": "hinüberlappend",
    "hinüberlappest": "hinüberlappen",
    "hinüberlappet": "hinüberlappen",
    "hinüberlappst": "hinüberlappen",
    "hinüberlappt": "hinüberlappen",
    "hinüberlappte": "hinüberlappen",
    "hinüberlappten": "hinüberlappen",
    "hinüberlapptest": "hinüberlappen",
    "hinüberlapptet": "hinüberlappen",
    "hinüberreiche": "hinüberreichen",
    "hinüberreichend": "hinüberreichen",
    "hinüberreichende": "hinüberreichend",
    "hinüberreichendem": "hinüberreichend",
    "hinüberreichenden": "hinüberreichend",
    "hinüberreichender": "hinüberreichend",
    "hinüberreichendes": "hinüberreichend",
    "hinüberreichest": "hinüberreichen",
    "hinüberreichet": "hinüberreichen",
    "hinüberreichst": "hinüberreichen",
    "hinüberreicht": "hinüberreichen",
    "hinüberreichte": "hinüberreichen",
    "hinüberreichten": "hinüberreichen",
    "hinüberreichtest": "hinüberreichen",
    "hinüberreichtet": "hinüberreichen",
    "hinüberrücke": "hinüberrücken",
    "hinüberrückend": "hinüberrücken",
    "hinüberrückende": "hinüberrückend",
    "hinüberrückendem": "hinüberrückend",
    "hinüberrückenden": "hinüberrückend",
    "hinüberrückender": "hinüberrückend",
    "hinüberrückendes": "hinüberrückend",
    "hinüberrückest": "hinüberrücken",
    "hinüberrücket": "hinüberrücken",
    "hinüberrückst": "hinüberrücken",
    "hinüberrückt": "hinüberrücken",
    "hinüberrückte": "hinüberrücken",
    "hinüberrückten": "hinüberrücken",
    "hinüberrücktest": "hinüberrücken",
    "hinüberrücktet": "hinüberrücken",
    "hinüberschaue": "hinüberschauen",
    "hinüberschauend": "hinüberschauen",
    "hinüberschauende": "hinüberschauend",
    "hinüberschauendem": "hinüberschauend",
    "hinüberschauenden": "hinüberschauend",
    "hinüberschauender": "hinüberschauend",
    "hinüberschauendes": "hinüberschauend",
    "hinüberschauest": "hinüberschauen",
    "hinüberschauet": "hinüberschauen",
    "hinüberschaust": "hinüberschauen",
    "hinüberschaut": "hinüberschauen",
    "hinüberschaute": "hinüberschauen",
    "hinüberschauten": "hinüberschauen",
    "hinüberschautest": "hinüberschauen",
    "hinüberschautet": "hinüberschauen",
    "hinüberziehe": "hinüberziehen",
    "hinüberziehend": "hinüberziehen",
    "hinüberziehende": "hinüberziehend",
    "hinüberziehendem": "hinüberziehend",
    "hinüberziehenden": "hinüberziehend",
    "hinüberziehender": "hinüberziehend",
    "hinüberziehendes": "hinüberziehend",
    "hinüberziehest": "hinüberziehen",
    "hinüberziehet": "hinüberziehen",
    "hinüberziehst": "hinüberziehen",
    "hinüberzieht": "hinüberziehen",
    "hinüberzog": "hinüberziehen",
    "hinüberzogen": "hinüberziehen",
    "hinüberzogst": "hinüberziehen",
    "hinüberzogt": "hinüberziehen",
    "hinüberzubemühen": "hinüberbemühen",
    "hinüberzuführen": "hinüberführen",
    "hinüberzulappen": "hinüberlappen",
    "hinüberzureichen": "hinüberreichen",
    "hinüberzurücken": "hinüberrücken",
    "hinüberzuschauen": "hinüberschauen",
    "hinüberzuziehen": "hinüberziehen",
    "hinüberzöge": "hinüberziehen",
    "hinüberzögen": "hinüberziehen",
    "hinüberzögest": "hinüberziehen",
    "hinüberzöget": "hinüberziehen",
    "hippokratischem": "hippokratisch",
    "hippokratischen": "hippokratisch",
    "hippokratischer": "hippokratisch",
    "hippokratisches": "hippokratisch",
    "hirngeschädigtem": "hirngeschädigt",
    "hirngeschädigten": "hirngeschädigt",
    "hirngeschädigter": "hirngeschädigt",
    "hirngeschädigtes": "hirngeschädigt",
    "hirnlose": "hirnlos",
    "hirnlosem": "hirnlos",
    "hirnlosen": "hirnlos",
    "hirnloser": "hirnlos",
    "hirnlosere": "hirnlos",
    "hirnloserem": "hirnlos",
    "hirnloseren": "hirnlos",
    "hirnloserer": "hirnlos",
    "hirnloseres": "hirnlos",
    "hirnloses": "hirnlos",
    "hirnloseste": "hirnlos",
    "hirnlosestem": "hirnlos",
    "hirnlosesten": "hirnlos",
    "hirnlosester": "hirnlos",
    "hirnlosestes": "hirnlos",
    "hirnrissige": "hirnrissig",
    "hirnrissigem": "hirnrissig",
    "hirnrissigen": "hirnrissig",
    "hirnrissiger": "hirnrissig",
    "hirnrissigere": "hirnrissig",
    "hirnrissigerem": "hirnrissig",
    "hirnrissigeren": "hirnrissig",
    "hirnrissigerer": "hirnrissig",
    "hirnrissigeres": "hirnrissig",
    "hirnrissiges": "hirnrissig",
    "hirnrissigste": "hirnrissig",
    "hirnrissigstem": "hirnrissig",
    "hirnrissigsten": "hirnrissig",
    "hirnrissigster": "hirnrissig",
    "hirnrissigstes": "hirnrissig",
    "hirnverbranntem": "hirnverbrannt",
    "hirnverbrannten": "hirnverbrannt",
    "hirnverbrannter": "hirnverbrannt",
    "hirnverbranntere": "hirnverbrannt",
    "hirnverbrannterem": "hirnverbrannt",
    "hirnverbrannteren": "hirnverbrannt",
    "hirnverbrannterer": "hirnverbrannt",
    "hirnverbrannteres": "hirnverbrannt",
    "hirnverbranntes": "hirnverbrannt",
    "hirnverbrannteste": "hirnverbrannt",
    "hirnverbranntestem": "hirnverbrannt",
    "hirnverbranntesten": "hirnverbrannt",
    "hirnverbranntester": "hirnverbrannt",
    "hirnverbranntestes": "hirnverbrannt",
    "historischem": "historisch",
    "historischen": "historisch",
    "historischer": "historisch",
    "historisches": "historisch",
    "hitzebeständigem": "hitzebeständig",
    "hitzebeständigen": "hitzebeständig",
    "hitzebeständiger": "hitzebeständig",
    "hitzebeständigere": "hitzebeständig",
    "hitzebeständigerem": "hitzebeständig",
    "hitzebeständigeren": "hitzebeständig",
    "hitzebeständigerer": "hitzebeständig",
    "hitzebeständigeres": "hitzebeständig",
    "hitzebeständiges": "hitzebeständig",
    "hitzebeständigste": "hitzebeständig",
    "hitzebeständigstem": "hitzebeständig",
    "hitzebeständigsten": "hitzebeständig",
    "hitzebeständigster": "hitzebeständig",
    "hitzebeständigstes": "hitzebeständig",
    "hitzeempfindliche": "hitzeempfindlich",
    "hitzeempfindlichem": "hitzeempfindlich",
    "hitzeempfindlichen": "hitzeempfindlich",
    "hitzeempfindlicher": "hitzeempfindlich",
    "hitzeempfindlichere": "hitzeempfindlich",
    "hitzeempfindlicherem": "hitzeempfindlich",
    "hitzeempfindlicheren": "hitzeempfindlich",
    "hitzeempfindlicherer": "hitzeempfindlich",
    "hitzeempfindlicheres": "hitzeempfindlich",
    "hitzeempfindliches": "hitzeempfindlich",
    "hitzeempfindlichste": "hitzeempfindlich",
    "hitzeempfindlichstem": "hitzeempfindlich",
    "hitzeempfindlichsten": "hitzeempfindlich",
    "hitzeempfindlichster": "hitzeempfindlich",
    "hitzeempfindlichstes": "hitzeempfindlich",
    "hitzegeplagte": "hitzegeplagt",
    "hitzegeplagtem": "hitzegeplagt",
    "hitzegeplagten": "hitzegeplagt",
    "hitzegeplagter": "hitzegeplagt",
    "hitzegeplagtere": "hitzegeplagt",
    "hitzegeplagterem": "hitzegeplagt",
    "hitzegeplagteren": "hitzegeplagt",
    "hitzegeplagterer": "hitzegeplagt",
    "hitzegeplagteres": "hitzegeplagt",
    "hitzegeplagtes": "hitzegeplagt",
    "hitzegeplagteste": "hitzegeplagt",
    "hitzegeplagtestem": "hitzegeplagt",
    "hitzegeplagtesten": "hitzegeplagt",
    "hitzegeplagtester": "hitzegeplagt",
    "hitzegeplagtestes": "hitzegeplagt",
    "hitzige": "hitzig",
    "hitzigem": "hitzig",
    "hitzigen": "hitzig",
    "hitziger": "hitzig",
    "hitzigere": "hitzig",
    "hitzigerem": "hitzig",
    "hitzigeren": "hitzig",
    "hitzigerer": "hitzig",
    "hitzigeres": "hitzig",
    "hitziges": "hitzig",
    "hitzigste": "hitzig",
    "hitzigstem": "hitzig",
    "hitzigsten": "hitzig",
    "hitzigster": "hitzig",
    "hitzigstes": "hitzig",
    "hob": "heben",
    "hobele": "hobeln",
    "hobelnd": "hobeln",
    "hobelnde": "hobelnd",
    "hobelndem": "hobelnd",
    "hobelnden": "hobelnd",
    "hobelnder": "hobelnd",
    "hobelndes": "hobelnd",
    "hobelst": "hobeln",
    "hobelt": "hobeln",
    "hobelte": "hobeln",
    "hobelten": "hobeln",
    "hobeltest": "hobeln",
    "hobeltet": "hobeln",
    "hoben": "heben",
    "hoble": "hobeln",
    "hobst": "heben",
    "hobt": "heben",
    "hochachte": "hochachten",
    "hochachtend": "hochachten",
    "hochachtende": "hochachtend",
    "hochachtendem": "hochachtend",
    "hochachtenden": "hochachtend",
    "hochachtender": "hochachtend",
    "hochachtendere": "hochachtend",
    "hochachtenderem": "hochachtend",
    "hochachtenderen": "hochachtend",
    "hochachtenderer": "hochachtend",
    "hochachtenderes": "hochachtend",
    "hochachtendes": "hochachtend",
    "hochachtendste": "hochachtend",
    "hochachtendstem": "hochachtend",
    "hochachtendsten": "hochachtend",
    "hochachtendster": "hochachtend",
    "hochachtendstes": "hochachtend",
    "hochachtest": "hochachten",
    "hochachtet": "hochachten",
    "hochachtete": "hochachten",
    "hochachteten": "hochachten",
    "hochachtetest": "hochachten",
    "hochachtetet": "hochachten",
    "hochachtungsvolle": "hochachtungsvoll",
    "hochachtungsvollem": "hochachtungsvoll",
    "hochachtungsvollen": "hochachtungsvoll",
    "hochachtungsvoller": "hochachtungsvoll",
    "hochachtungsvolles": "hochachtungsvoll",
    "hochadelige": "hochadelig",
    "hochadeligem": "hochadelig",
    "hochadeligen": "hochadelig",
    "hochadeliger": "hochadelig",
    "hochadeliges": "hochadelig",
    "hochaktuelle": "hochaktuell",
    "hochaktuellem": "hochaktuell",
    "hochaktuellen": "hochaktuell",
    "hochaktueller": "hochaktuell",
    "hochaktuellere": "hochaktuell",
    "hochaktuellerem": "hochaktuell",
    "hochaktuelleren": "hochaktuell",
    "hochaktuellerer": "hochaktuell",
    "hochaktuelleres": "hochaktuell",
    "hochaktuelles": "hochaktuell",
    "hochaktuellste": "hochaktuell",
    "hochaktuellstem": "hochaktuell",
    "hochaktuellsten": "hochaktuell",
    "hochaktuellster": "hochaktuell",
    "hochaktuellstes": "hochaktuell",
    "hochanständigem": "hochanständig",
    "hochanständigen": "hochanständig",
    "hochanständiger": "hochanständig",
    "hochanständigere": "hochanständig",
    "hochanständigerem": "hochanständig",
    "hochanständigeren": "hochanständig",
    "hochanständigerer": "hochanständig",
    "hochanständigeres": "hochanständig",
    "hochanständiges": "hochanständig",
    "hochanständigste": "hochanständig",
    "hochanständigstem": "hochanständig",
    "hochanständigsten": "hochanständig",
    "hochanständigster": "hochanständig",
    "hochanständigstes": "hochanständig",
    "hocharbeite": "hocharbeiten",
    "hocharbeitend": "hocharbeiten",
    "hocharbeitende": "hocharbeitend",
    "hocharbeitendem": "hocharbeitend",
    "hocharbeitenden": "hocharbeitend",
    "hocharbeitender": "hocharbeitend",
    "hocharbeitendere": "hocharbeitend",
    "hocharbeitenderem": "hocharbeitend",
    "hocharbeitenderen": "hocharbeitend",
    "hocharbeitenderer": "hocharbeitend",
    "hocharbeitenderes": "hocharbeitend",
    "hocharbeitendes": "hocharbeitend",
    "hocharbeitendste": "hocharbeitend",
    "hocharbeitendstem": "hocharbeitend",
    "hocharbeitendsten": "hocharbeitend",
    "hocharbeitendster": "hocharbeitend",
    "hocharbeitendstes": "hocharbeitend",
    "hocharbeitest": "hocharbeiten",
    "hocharbeitet": "hocharbeiten",
    "hocharbeitete": "hocharbeiten",
    "hocharbeiteten": "hocharbeiten",
    "hocharbeitetest": "hocharbeiten",
    "hocharbeitetet": "hocharbeiten",
    "hochaufgeschossene": "hochaufgeschossen",
    "hochaufgeschossenem": "hochaufgeschossen",
    "hochaufgeschossenen": "hochaufgeschossen",
    "hochaufgeschossener": "hochaufgeschossen",
    "hochaufgeschossenes": "hochaufgeschossen",
    "hochband": "hochbinden",
    "hochbanden": "hochbinden",
    "hochbandest": "hochbinden",
    "hochbandet": "hochbinden",
    "hochbegabtem": "hochbegabt",
    "hochbegabten": "hochbegabt",
    "hochbegabter": "hochbegabt",
    "hochbegabtes": "hochbegabt",
    "hochbeglückte": "hochbeglückt",
    "hochbeglücktem": "hochbeglückt",
    "hochbeglückten": "hochbeglückt",
    "hochbeglückter": "hochbeglückt",
    "hochbeglücktes": "hochbeglückt",
    "hochbetagtem": "hochbetagt",
    "hochbetagten": "hochbetagt",
    "hochbetagter": "hochbetagt",
    "hochbetagtere": "hochbetagt",
    "hochbetagterem": "hochbetagt",
    "hochbetagteren": "hochbetagt",
    "hochbetagterer": "hochbetagt",
    "hochbetagteres": "hochbetagt",
    "hochbetagtes": "hochbetagt",
    "hochbetagteste": "hochbetagt",
    "hochbetagtestem": "hochbetagt",
    "hochbetagtesten": "hochbetagt",
    "hochbetagtester": "hochbetagt",
    "hochbetagtestes": "hochbetagt",
    "hochbinde": "hochbinden",
    "hochbindend": "hochbinden",
    "hochbindende": "hochbindend",
    "hochbindendem": "hochbindend",
    "hochbindenden": "hochbindend",
    "hochbindender": "hochbindend",
    "hochbindendes": "hochbindend",
    "hochbindest": "hochbinden",
    "hochbindet": "hochbinden",
    "hochbrachte": "hochbringen",
    "hochbrachten": "hochbringen",
    "hochbrachtest": "hochbringen",
    "hochbrachtet": "hochbringen",
    "hochbringe": "hochbringen",
    "hochbringend": "hochbringen",
    "hochbringende": "hochbringend",
    "hochbringendem": "hochbringend",
    "hochbringenden": "hochbringend",
    "hochbringender": "hochbringend",
    "hochbringendes": "hochbringend",
    "hochbringest": "hochbringen",
    "hochbringet": "hochbringen",
    "hochbringst": "hochbringen",
    "hochbringt": "hochbringen",
    "hochbrisante": "hochbrisant",
    "hochbrisantem": "hochbrisant",
    "hochbrisanten": "hochbrisant",
    "hochbrisanter": "hochbrisant",
    "hochbrisantere": "hochbrisant",
    "hochbrisanterem": "hochbrisant",
    "hochbrisanteren": "hochbrisant",
    "hochbrisanterer": "hochbrisant",
    "hochbrisanteres": "hochbrisant",
    "hochbrisantes": "hochbrisant",
    "hochbrisanteste": "hochbrisant",
    "hochbrisantestem": "hochbrisant",
    "hochbrisantesten": "hochbrisant",
    "hochbrisantester": "hochbrisant",
    "hochbrisantestes": "hochbrisant",
    "hochbrächte": "hochbringen",
    "hochbrächten": "hochbringen",
    "hochbrächtest": "hochbringen",
    "hochbrächtet": "hochbringen",
    "hochbände": "hochbinden",
    "hochbänden": "hochbinden",
    "hochbändest": "hochbinden",
    "hochbändet": "hochbinden",
    "hochdeutschem": "hochdeutsch",
    "hochdeutschen": "hochdeutsch",
    "hochdeutscher": "hochdeutsch",
    "hochdeutsches": "hochdeutsch",
    "hochdiene": "hochdienen",
    "hochdienend": "hochdienen",
    "hochdienende": "hochdienend",
    "hochdienendem": "hochdienend",
    "hochdienenden": "hochdienend",
    "hochdienender": "hochdienend",
    "hochdienendes": "hochdienend",
    "hochdienest": "hochdienen",
    "hochdienet": "hochdienen",
    "hochdienst": "hochdienen",
    "hochdient": "hochdienen",
    "hochdiente": "hochdienen",
    "hochdienten": "hochdienen",
    "hochdientest": "hochdienen",
    "hochdientet": "hochdienen",
    "hochempfindlichem": "hochempfindlich",
    "hochempfindlichen": "hochempfindlich",
    "hochempfindlicher": "hochempfindlich",
    "hochempfindliches": "hochempfindlich",
    "hocherfreute": "hocherfreut",
    "hocherfreutem": "hocherfreut",
    "hocherfreuten": "hocherfreut",
    "hocherfreuter": "hocherfreut",
    "hocherfreutes": "hocherfreut",
    "hocherhitzte": "hocherhitzt",
    "hocherhitztem": "hocherhitzt",
    "hocherhitzten": "hocherhitzt",
    "hocherhitzter": "hocherhitzt",
    "hocherhitztes": "hocherhitzt",
    "hochexplosive": "hochexplosiv",
    "hochexplosivem": "hochexplosiv",
    "hochexplosiven": "hochexplosiv",
    "hochexplosiver": "hochexplosiv",
    "hochexplosives": "hochexplosiv",
    "hochfahre": "hochfahren",
    "hochfahrend": "hochfahren",
    "hochfahrende": "hochfahrend",
    "hochfahrendem": "hochfahrend",
    "hochfahrenden": "hochfahrend",
    "hochfahrender": "hochfahrend",
    "hochfahrendes": "hochfahrend",
    "hochfahrest": "hochfahren",
    "hochfahret": "hochfahren",
    "hochfahrt": "hochfahren",
    "hochfrequentem": "hochfrequent",
    "hochfrequenten": "hochfrequent",
    "hochfrequenter": "hochfrequent",
    "hochfrequentes": "hochfrequent",
    "hochfuhr": "hochfahren",
    "hochfuhren": "hochfahren",
    "hochfuhrst": "hochfahren",
    "hochfuhrt": "hochfahren",
    "hochfährst": "hochfahren",
    "hochfährt": "hochfahren",
    "hochführe": "hochfahren",
    "hochführen": "hochfahren",
    "hochführest": "hochfahren",
    "hochführet": "hochfahren",
    "hochgeachtet": "hochachten",
    "hochgeachtete": "hochgeachtet",
    "hochgeachtetem": "hochgeachtet",
    "hochgeachteten": "hochgeachtet",
    "hochgeachteter": "hochgeachtet",
    "hochgeachtetere": "hochgeachtet",
    "hochgeachteterem": "hochgeachtet",
    "hochgeachteteren": "hochgeachtet",
    "hochgeachteterer": "hochgeachtet",
    "hochgeachteteres": "hochgeachtet",
    "hochgeachtetes": "hochgeachtet",
    "hochgeachteteste": "hochgeachtet",
    "hochgeachtetestem": "hochgeachtet",
    "hochgeachtetesten": "hochgeachtet",
    "hochgeachtetester": "hochgeachtet",
    "hochgeachtetestes": "hochgeachtet",
    "hochgearbeitet": "hocharbeiten",
    "hochgearbeitete": "hochgearbeitet",
    "hochgearbeitetem": "hochgearbeitet",
    "hochgearbeiteten": "hochgearbeitet",
    "hochgearbeiteter": "hochgearbeitet",
    "hochgearbeitetere": "hochgearbeitet",
    "hochgearbeiteterem": "hochgearbeitet",
    "hochgearbeiteteren": "hochgearbeitet",
    "hochgearbeiteterer": "hochgearbeitet",
    "hochgearbeiteteres": "hochgearbeitet",
    "hochgearbeitetes": "hochgearbeitet",
    "hochgearbeiteteste": "hochgearbeitet",
    "hochgearbeitetestem": "hochgearbeitet",
    "hochgearbeitetesten": "hochgearbeitet",
    "hochgearbeitetester": "hochgearbeitet",
    "hochgearbeitetestes": "hochgearbeitet",
    "hochgebildete": "hochgebildet",
    "hochgebildetem": "hochgebildet",
    "hochgebildeten": "hochgebildet",
    "hochgebildeter": "hochgebildet",
    "hochgebildetes": "hochgebildet",
    "hochgebracht": "hochbringen",
    "hochgebrachte": "hochgebracht",
    "hochgebrachtem": "hochgebracht",
    "hochgebrachten": "hochgebracht",
    "hochgebrachter": "hochgebracht",
    "hochgebrachtes": "hochgebracht",
    "hochgebunden": "hochbinden",
    "hochgebundene": "hochgebunden",
    "hochgebundenem": "hochgebunden",
    "hochgebundenen": "hochgebunden",
    "hochgebundener": "hochgebunden",
    "hochgebundenes": "hochgebunden",
    "hochgedient": "hochdienen",
    "hochgediente": "hochgedient",
    "hochgedientem": "hochgedient",
    "hochgedienten": "hochgedient",
    "hochgedienter": "hochgedient",
    "hochgedientes": "hochgedient",
    "hochgeehrte": "hochgeehrt",
    "hochgeehrtem": "hochgeehrt",
    "hochgeehrten": "hochgeehrt",
    "hochgeehrter": "hochgeehrt",
    "hochgeehrtes": "hochgeehrt",
    "hochgefahren": "hochfahren",
    "hochgefahrene": "hochgefahren",
    "hochgefahrenem": "hochgefahren",
    "hochgefahrenen": "hochgefahren",
    "hochgefahrener": "hochgefahren",
    "hochgefahrenes": "hochgefahren",
    "hochgegangen": "hochgehen",
    "hochgegangene": "hochgegangen",
    "hochgegangenem": "hochgegangen",
    "hochgegangenen": "hochgegangen",
    "hochgegangener": "hochgegangen",
    "hochgegangenes": "hochgegangen",
    "hochgehe": "hochgehen",
    "hochgehend": "hochgehen",
    "hochgehende": "hochgehend",
    "hochgehendem": "hochgehend",
    "hochgehenden": "hochgehend",
    "hochgehender": "hochgehend",
    "hochgehendes": "hochgehend",
    "hochgehest": "hochgehen",
    "hochgehet": "hochgehen",
    "hochgehoben": "hochheben",
    "hochgehobene": "hochgehoben",
    "hochgehobenem": "hochgehoben",
    "hochgehobenen": "hochgehoben",
    "hochgehobener": "hochgehoben",
    "hochgehobenes": "hochgehoben",
    "hochgehst": "hochgehen",
    "hochgeht": "hochgehen",
    "hochgejagt": "hochjagen",
    "hochgejagte": "hochgejagt",
    "hochgejagtem": "hochgejagt",
    "hochgejagten": "hochgejagt",
    "hochgejagter": "hochgejagt",
    "hochgejagtes": "hochgejagt",
    "hochgejubelt": "hochjubeln",
    "hochgejubelte": "hochgejubelt",
    "hochgejubeltem": "hochgejubelt",
    "hochgejubelten": "hochgejubelt",
    "hochgejubelter": "hochgejubelt",
    "hochgejubeltere": "hochgejubelt",
    "hochgejubelterem": "hochgejubelt",
    "hochgejubelteren": "hochgejubelt",
    "hochgejubelterer": "hochgejubelt",
    "hochgejubelteres": "hochgejubelt",
    "hochgejubeltes": "hochgejubelt",
    "hochgejubelteste": "hochgejubelt",
    "hochgejubeltestem": "hochgejubelt",
    "hochgejubeltesten": "hochgejubelt",
    "hochgejubeltester": "hochgejubelt",
    "hochgejubeltestes": "hochgejubelt",
    "hochgeklappt": "hochklappen",
    "hochgeklappte": "hochgeklappt",
    "hochgeklapptem": "hochgeklappt",
    "hochgeklappten": "hochgeklappt",
    "hochgeklappter": "hochgeklappt",
    "hochgeklapptes": "hochgeklappt",
    "hochgekämmt": "hochkämmen",
    "hochgekämmte": "hochgekämmt",
    "hochgekämmtem": "hochgekämmt",
    "hochgekämmten": "hochgekämmt",
    "hochgekämmter": "hochgekämmt",
    "hochgekämmtes": "hochgekämmt",
    "hochgelebt": "hochleben",
    "hochgelebte": "hochgelebt",
    "hochgelebtem": "hochgelebt",
    "hochgelebten": "hochgelebt",
    "hochgelebter": "hochgelebt",
    "hochgelebtes": "hochgelebt",
    "hochgenommen": "hochnehmen",
    "hochgenommene": "hochgenommen",
    "hochgenommenem": "hochgenommen",
    "hochgenommenen": "hochgenommen",
    "hochgenommener": "hochgenommen",
    "hochgenommenes": "hochgenommen",
    "hochgepäppelt": "hochpäppeln",
    "hochgepäppelte": "hochgepäppelt",
    "hochgepäppeltem": "hochgepäppelt",
    "hochgepäppelten": "hochgepäppelt",
    "hochgepäppelter": "hochgepäppelt",
    "hochgepäppeltes": "hochgepäppelt",
    "hochgerannt": "hochrennen",
    "hochgerannte": "hochgerannt",
    "hochgeranntem": "hochgerannt",
    "hochgerannten": "hochgerannt",
    "hochgerannter": "hochgerannt",
    "hochgeranntes": "hochgerannt",
    "hochgerechnet": "hochrechnen",
    "hochgerechnete": "hochgerechnet",
    "hochgerechnetem": "hochgerechnet",
    "hochgerechneten": "hochgerechnet",
    "hochgerechneter": "hochgerechnet",
    "hochgerechnetes": "hochgerechnet",
    "hochgerissen": "hochreißen",
    "hochgerissene": "hochgerissen",
    "hochgerissenem": "hochgerissen",
    "hochgerissenen": "hochgerissen",
    "hochgerissener": "hochgerissen",
    "hochgerissenes": "hochgerissen",
    "hochgeschaukelt": "hochschaukeln",
    "hochgeschaukelte": "hochgeschaukelt",
    "hochgeschaukeltem": "hochgeschaukelt",
    "hochgeschaukelten": "hochgeschaukelt",
    "hochgeschaukelter": "hochgeschaukelt",
    "hochgeschaukeltere": "hochgeschaukelt",
    "hochgeschaukelterem": "hochgeschaukelt",
    "hochgeschaukelteren": "hochgeschaukelt",
    "hochgeschaukelterer": "hochgeschaukelt",
    "hochgeschaukelteres": "hochgeschaukelt",
    "hochgeschaukeltes": "hochgeschaukelt",
    "hochgeschaukelteste": "hochgeschaukelt",
    "hochgeschaukeltestem": "hochgeschaukelt",
    "hochgeschaukeltesten": "hochgeschaukelt",
    "hochgeschaukeltester": "hochgeschaukelt",
    "hochgeschaukeltestes": "hochgeschaukelt",
    "hochgeschnellt": "hochschnellen",
    "hochgeschnellte": "hochgeschnellt",
    "hochgeschnelltem": "hochgeschnellt",
    "hochgeschnellten": "hochgeschnellt",
    "hochgeschnellter": "hochgeschnellt",
    "hochgeschnelltes": "hochgeschnellt",
    "hochgeschreckt": "hochschrecken",
    "hochgeschreckte": "hochgeschreckt",
    "hochgeschrecktem": "hochgeschreckt",
    "hochgeschreckten": "hochgeschreckt",
    "hochgeschreckter": "hochgeschreckt",
    "hochgeschrecktere": "hochgeschreckt",
    "hochgeschreckterem": "hochgeschreckt",
    "hochgeschreckteren": "hochgeschreckt",
    "hochgeschreckterer": "hochgeschreckt",
    "hochgeschreckteres": "hochgeschreckt",
    "hochgeschrecktes": "hochgeschreckt",
    "hochgeschreckteste": "hochgeschreckt",
    "hochgeschrecktestem": "hochgeschreckt",
    "hochgeschrecktesten": "hochgeschreckt",
    "hochgeschrecktester": "hochgeschreckt",
    "hochgeschrecktestes": "hochgeschreckt",
    "hochgeschrocken": "hochschrecken",
    "hochgeschrockene": "hochgeschrocken",
    "hochgeschrockenem": "hochgeschrocken",
    "hochgeschrockenen": "hochgeschrocken",
    "hochgeschrockener": "hochgeschrocken",
    "hochgeschrockenere": "hochgeschrocken",
    "hochgeschrockenerem": "hochgeschrocken",
    "hochgeschrockeneren": "hochgeschrocken",
    "hochgeschrockenerer": "hochgeschrocken",
    "hochgeschrockeneres": "hochgeschrocken",
    "hochgeschrockenes": "hochgeschrocken",
    "hochgeschrockenste": "hochgeschrocken",
    "hochgeschrockenstem": "hochgeschrocken",
    "hochgeschrockensten": "hochgeschrocken",
    "hochgeschrockenster": "hochgeschrocken",
    "hochgeschrockenstes": "hochgeschrocken",
    "hochgeschätzt": "hochschätzen",
    "hochgeschätzte": "hochgeschätzt",
    "hochgeschätztem": "hochgeschätzt",
    "hochgeschätzten": "hochgeschätzt",
    "hochgeschätzter": "hochgeschätzt",
    "hochgeschätztere": "hochgeschätzt",
    "hochgeschätzterem": "hochgeschätzt",
    "hochgeschätzteren": "hochgeschätzt",
    "hochgeschätzterer": "hochgeschätzt",
    "hochgeschätzteres": "hochgeschätzt",
    "hochgeschätztes": "hochgeschätzt",
    "hochgeschätzteste": "hochgeschätzt",
    "hochgeschätztestem": "hochgeschätzt",
    "hochgeschätztesten": "hochgeschätzt",
    "hochgeschätztester": "hochgeschätzt",
    "hochgeschätztestes": "hochgeschätzt",
    "hochgesehen": "hochsehen",
    "hochgesehene": "hochgesehen",
    "hochgesehenem": "hochgesehen",
    "hochgesehenen": "hochgesehen",
    "hochgesehener": "hochgesehen",
    "hochgesehenes": "hochgesehen",
    "hochgesetzt": "hochsetzen",
    "hochgesetzte": "hochgesetzt",
    "hochgesetztem": "hochgesetzt",
    "hochgesetzten": "hochgesetzt",
    "hochgesetzter": "hochgesetzt",
    "hochgesetztere": "hochgesetzt",
    "hochgesetzterem": "hochgesetzt",
    "hochgesetzteren": "hochgesetzt",
    "hochgesetzterer": "hochgesetzt",
    "hochgesetzteres": "hochgesetzt",
    "hochgesetztes": "hochgesetzt",
    "hochgesetzteste": "hochgesetzt",
    "hochgesetztestem": "hochgesetzt",
    "hochgesetztesten": "hochgesetzt",
    "hochgesetztester": "hochgesetzt",
    "hochgesetztestes": "hochgesetzt",
    "hochgespielt": "hochspielen",
    "hochgespielte": "hochgespielt",
    "hochgespieltem": "hochgespielt",
    "hochgespielten": "hochgespielt",
    "hochgespielter": "hochgespielt",
    "hochgespieltes": "hochgespielt",
    "hochgespült": "hochspülen",
    "hochgespülte": "hochgespült",
    "hochgespültem": "hochgespült",
    "hochgespülten": "hochgespült",
    "hochgespülter": "hochgespült",
    "hochgespültes": "hochgespült",
    "hochgestapelt": "hochstapeln",
    "hochgestapelte": "hochgestapelt",
    "hochgestapeltem": "hochgestapelt",
    "hochgestapelten": "hochgestapelt",
    "hochgestapelter": "hochgestapelt",
    "hochgestapeltes": "hochgestapelt",
    "hochgestellt": "hochstellen",
    "hochgestellte": "hochgestellt",
    "hochgestelltem": "hochgestellt",
    "hochgestellten": "hochgestellt",
    "hochgestellter": "hochgestellt",
    "hochgestelltes": "hochgestellt",
    "hochgestiegen": "hochsteigen",
    "hochgestiegene": "hochgestiegen",
    "hochgestiegenem": "hochgestiegen",
    "hochgestiegenen": "hochgestiegen",
    "hochgestiegener": "hochgestiegen",
    "hochgestiegenere": "hochgestiegen",
    "hochgestiegenerem": "hochgestiegen",
    "hochgestiegeneren": "hochgestiegen",
    "hochgestiegenerer": "hochgestiegen",
    "hochgestiegeneres": "hochgestiegen",
    "hochgestiegenes": "hochgestiegen",
    "hochgestiegenste": "hochgestiegen",
    "hochgestiegenstem": "hochgestiegen",
    "hochgestiegensten": "hochgestiegen",
    "hochgestiegenster": "hochgestiegen",
    "hochgestiegenstes": "hochgestiegen",
    "hochgestrebt": "hochstreben",
    "hochgestrebte": "hochgestrebt",
    "hochgestrebtem": "hochgestrebt",
    "hochgestrebten": "hochgestrebt",
    "hochgestrebter": "hochgestrebt",
    "hochgestrebtes": "hochgestrebt",
    "hochgetragen": "hochtragen",
    "hochgetragene": "hochgetragen",
    "hochgetragenem": "hochgetragen",
    "hochgetragenen": "hochgetragen",
    "hochgetragener": "hochgetragen",
    "hochgetragenes": "hochgetragen",
    "hochgetrieben": "hochtreiben",
    "hochgetriebene": "hochgetrieben",
    "hochgetriebenem": "hochgetrieben",
    "hochgetriebenen": "hochgetrieben",
    "hochgetriebener": "hochgetrieben",
    "hochgetriebenes": "hochgetrieben",
    "hochgezogen": "hochziehen",
    "hochgezogene": "hochgezogen",
    "hochgezogenem": "hochgezogen",
    "hochgezogenen": "hochgezogen",
    "hochgezogener": "hochgezogen",
    "hochgezogenere": "hochgezogen",
    "hochgezogenerem": "hochgezogen",
    "hochgezogeneren": "hochgezogen",
    "hochgezogenerer": "hochgezogen",
    "hochgezogeneres": "hochgezogen",
    "hochgezogenes": "hochgezogen",
    "hochgezogenste": "hochgezogen",
    "hochgezogenstem": "hochgezogen",
    "hochgezogensten": "hochgezogen",
    "hochgezogenster": "hochgezogen",
    "hochgezogenstes": "hochgezogen",
    "hochgezüchtet": "hochzüchten",
    "hochgezüchtete": "hochgezüchtet",
    "hochgezüchtetem": "hochgezüchtet",
    "hochgezüchteten": "hochgezüchtet",
    "hochgezüchteter": "hochgezüchtet",
    "hochgezüchtetere": "hochgezüchtet",
    "hochgezüchteterem": "hochgezüchtet",
    "hochgezüchteteren": "hochgezüchtet",
    "hochgezüchteterer": "hochgezüchtet",
    "hochgezüchteteres": "hochgezüchtet",
    "hochgezüchtetes": "hochgezüchtet",
    "hochgezüchteteste": "hochgezüchtet",
    "hochgezüchtetestem": "hochgezüchtet",
    "hochgezüchtetesten": "hochgezüchtet",
    "hochgezüchtetester": "hochgezüchtet",
    "hochgezüchtetestes": "hochgezüchtet",
    "hochging": "hochgehen",
    "hochginge": "hochgehen",
    "hochgingen": "hochgehen",
    "hochgingest": "hochgehen",
    "hochginget": "hochgehen",
    "hochgingst": "hochgehen",
    "hochgingt": "hochgehen",
    "hochgradige": "hochgradig",
    "hochgradigem": "hochgradig",
    "hochgradigen": "hochgradig",
    "hochgradiger": "hochgradig",
    "hochgradiges": "hochgradig",
    "hochhebe": "hochheben",
    "hochhebend": "hochheben",
    "hochhebende": "hochhebend",
    "hochhebendem": "hochhebend",
    "hochhebenden": "hochhebend",
    "hochhebender": "hochhebend",
    "hochhebendes": "hochhebend",
    "hochhebest": "hochheben",
    "hochhebet": "hochheben",
    "hochhebst": "hochheben",
    "hochhebt": "hochheben",
    "hochherrschaftlichem": "hochherrschaftlich",
    "hochherrschaftlichen": "hochherrschaftlich",
    "hochherrschaftlicher": "hochherrschaftlich",
    "hochherrschaftliches": "hochherrschaftlich",
    "hochhob": "hochheben",
    "hochhoben": "hochheben",
    "hochhobst": "hochheben",
    "hochhobt": "hochheben",
    "hochhöbe": "hochheben",
    "hochhöben": "hochheben",
    "hochhöbest": "hochheben",
    "hochhöbet": "hochheben",
    "hochintelligente": "hochintelligent",
    "hochintelligentem": "hochintelligent",
    "hochintelligenten": "hochintelligent",
    "hochintelligenter": "hochintelligent",
    "hochintelligentes": "hochintelligent",
    "hochjage": "hochjagen",
    "hochjagend": "hochjagen",
    "hochjagende": "hochjagend",
    "hochjagendem": "hochjagend",
    "hochjagenden": "hochjagend",
    "hochjagender": "hochjagend",
    "hochjagendes": "hochjagend",
    "hochjagest": "hochjagen",
    "hochjaget": "hochjagen",
    "hochjagst": "hochjagen",
    "hochjagt": "hochjagen",
    "hochjagte": "hochjagen",
    "hochjagten": "hochjagen",
    "hochjagtest": "hochjagen",
    "hochjagtet": "hochjagen",
    "hochjubele": "hochjubeln",
    "hochjubelnd": "hochjubeln",
    "hochjubelnde": "hochjubelnd",
    "hochjubelndem": "hochjubelnd",
    "hochjubelnden": "hochjubelnd",
    "hochjubelnder": "hochjubelnd",
    "hochjubelndere": "hochjubelnd",
    "hochjubelnderem": "hochjubelnd",
    "hochjubelnderen": "hochjubelnd",
    "hochjubelnderer": "hochjubelnd",
    "hochjubelnderes": "hochjubelnd",
    "hochjubelndes": "hochjubelnd",
    "hochjubelndste": "hochjubelnd",
    "hochjubelndstem": "hochjubelnd",
    "hochjubelndsten": "hochjubelnd",
    "hochjubelndster": "hochjubelnd",
    "hochjubelndstes": "hochjubelnd",
    "hochjubelst": "hochjubeln",
    "hochjubelt": "hochjubeln",
    "hochjubelte": "hochjubeln",
    "hochjubelten": "hochjubeln",
    "hochjubeltest": "hochjubeln",
    "hochjubeltet": "hochjubeln",
    "hochjuble": "hochjubeln",
    "hochkarätige": "hochkarätig",
    "hochkarätigem": "hochkarätig",
    "hochkarätigen": "hochkarätig",
    "hochkarätiger": "hochkarätig",
    "hochkarätigere": "hochkarätig",
    "hochkarätigerem": "hochkarätig",
    "hochkarätigeren": "hochkarätig",
    "hochkarätigerer": "hochkarätig",
    "hochkarätigeres": "hochkarätig",
    "hochkarätiges": "hochkarätig",
    "hochkarätigste": "hochkarätig",
    "hochkarätigstem": "hochkarätig",
    "hochkarätigsten": "hochkarätig",
    "hochkarätigster": "hochkarätig",
    "hochkarätigstes": "hochkarätig",
    "hochklappe": "hochklappen",
    "hochklappend": "hochklappen",
    "hochklappende": "hochklappend",
    "hochklappendem": "hochklappend",
    "hochklappenden": "hochklappend",
    "hochklappender": "hochklappend",
    "hochklappendes": "hochklappend",
    "hochklappest": "hochklappen",
    "hochklappet": "hochklappen",
    "hochklappst": "hochklappen",
    "hochklappt": "hochklappen",
    "hochklappte": "hochklappen",
    "hochklappten": "hochklappen",
    "hochklapptest": "hochklappen",
    "hochklapptet": "hochklappen",
    "hochkämme": "hochkämmen",
    "hochkämmend": "hochkämmen",
    "hochkämmende": "hochkämmend",
    "hochkämmendem": "hochkämmend",
    "hochkämmenden": "hochkämmend",
    "hochkämmender": "hochkämmend",
    "hochkämmendes": "hochkämmend",
    "hochkämmest": "hochkämmen",
    "hochkämmet": "hochkämmen",
    "hochkämmst": "hochkämmen",
    "hochkämmt": "hochkämmen",
    "hochkämmte": "hochkämmen",
    "hochkämmten": "hochkämmen",
    "hochkämmtest": "hochkämmen",
    "hochkämmtet": "hochkämmen",
    "hochlebe": "hochleben",
    "hochlebend": "hochleben",
    "hochlebende": "hochlebend",
    "hochlebendem": "hochlebend",
    "hochlebenden": "hochlebend",
    "hochlebender": "hochlebend",
    "hochlebendes": "hochlebend",
    "hochlebest": "hochleben",
    "hochlebet": "hochleben",
    "hochlebst": "hochleben",
    "hochlebt": "hochleben",
    "hochlebte": "hochleben",
    "hochlebten": "hochleben",
    "hochlebtest": "hochleben",
    "hochlebtet": "hochleben",
    "hochmodernem": "hochmodern",
    "hochmodernen": "hochmodern",
    "hochmoderner": "hochmodern",
    "hochmodernes": "hochmodern",
    "hochmütigem": "hochmütig",
    "hochmütigen": "hochmütig",
    "hochmütiger": "hochmütig",
    "hochmütigere": "hochmütig",
    "hochmütigerem": "hochmütig",
    "hochmütigeren": "hochmütig",
    "hochmütigerer": "hochmütig",
    "hochmütigeres": "hochmütig",
    "hochmütiges": "hochmütig",
    "hochmütigste": "hochmütig",
    "hochmütigstem": "hochmütig",
    "hochmütigsten": "hochmütig",
    "hochmütigster": "hochmütig",
    "hochmütigstes": "hochmütig",
    "hochnahm": "hochnehmen",
    "hochnahmen": "hochnehmen",
    "hochnahmst": "hochnehmen",
    "hochnahmt": "hochnehmen",
    "hochnehme": "hochnehmen",
    "hochnehmend": "hochnehmen",
    "hochnehmende": "hochnehmend",
    "hochnehmendem": "hochnehmend",
    "hochnehmenden": "hochnehmend",
    "hochnehmender": "hochnehmend",
    "hochnehmendes": "hochnehmend",
    "hochnehmest": "hochnehmen",
    "hochnehmet": "hochnehmen",
    "hochnehmt": "hochnehmen",
    "hochnimmst": "hochnehmen",
    "hochnimmt": "hochnehmen",
    "hochnähme": "hochnehmen",
    "hochnähmen": "hochnehmen",
    "hochnähmest": "hochnehmen",
    "hochnähmet": "hochnehmen",
    "hochnäsige": "hochnäsig",
    "hochnäsigem": "hochnäsig",
    "hochnäsigen": "hochnäsig",
    "hochnäsiger": "hochnäsig",
    "hochnäsigere": "hochnäsig",
    "hochnäsigerem": "hochnäsig",
    "hochnäsigeren": "hochnäsig",
    "hochnäsigerer": "hochnäsig",
    "hochnäsigeres": "hochnäsig",
    "hochnäsiges": "hochnäsig",
    "hochnäsigste": "hochnäsig",
    "hochnäsigstem": "hochnäsig",
    "hochnäsigsten": "hochnäsig",
    "hochnäsigster": "hochnäsig",
    "hochnäsigstes": "hochnäsig",
    "hochprozentige": "hochprozentig",
    "hochprozentigem": "hochprozentig",
    "hochprozentigen": "hochprozentig",
    "hochprozentiger": "hochprozentig",
    "hochprozentigere": "hochprozentig",
    "hochprozentigerem": "hochprozentig",
    "hochprozentigeren": "hochprozentig",
    "hochprozentigerer": "hochprozentig",
    "hochprozentigeres": "hochprozentig",
    "hochprozentiges": "hochprozentig",
    "hochprozentigste": "hochprozentig",
    "hochprozentigstem": "hochprozentig",
    "hochprozentigsten": "hochprozentig",
    "hochprozentigster": "hochprozentig",
    "hochprozentigstes": "hochprozentig",
    "hochpäppele": "hochpäppeln",
    "hochpäppelnd": "hochpäppeln",
    "hochpäppelnde": "hochpäppelnd",
    "hochpäppelndem": "hochpäppelnd",
    "hochpäppelnden": "hochpäppelnd",
    "hochpäppelnder": "hochpäppelnd",
    "hochpäppelndes": "hochpäppelnd",
    "hochpäppelst": "hochpäppeln",
    "hochpäppelt": "hochpäppeln",
    "hochpäppelte": "hochpäppeln",
    "hochpäppelten": "hochpäppeln",
    "hochpäppeltest": "hochpäppeln",
    "hochpäppeltet": "hochpäppeln",
    "hochpäpple": "hochpäppeln",
    "hochqualifizierte": "hochqualifiziert",
    "hochqualifiziertem": "hochqualifiziert",
    "hochqualifizierten": "hochqualifiziert",
    "hochqualifizierter": "hochqualifiziert",
    "hochqualifiziertes": "hochqualifiziert",
    "hochrannte": "hochrennen",
    "hochrannten": "hochrennen",
    "hochranntest": "hochrennen",
    "hochranntet": "hochrennen",
    "hochrechne": "hochrechnen",
    "hochrechnend": "hochrechnen",
    "hochrechnende": "hochrechnend",
    "hochrechnendem": "hochrechnend",
    "hochrechnenden": "hochrechnend",
    "hochrechnender": "hochrechnend",
    "hochrechnendes": "hochrechnend",
    "hochrechnest": "hochrechnen",
    "hochrechnet": "hochrechnen",
    "hochrechnete": "hochrechnen",
    "hochrechneten": "hochrechnen",
    "hochrechnetest": "hochrechnen",
    "hochrechnetet": "hochrechnen",
    "hochreiße": "hochreißen",
    "hochreißend": "hochreißen",
    "hochreißende": "hochreißend",
    "hochreißendem": "hochreißend",
    "hochreißenden": "hochreißend",
    "hochreißender": "hochreißend",
    "hochreißendes": "hochreißend",
    "hochreißest": "hochreißen",
    "hochreißet": "hochreißen",
    "hochreißt": "hochreißen",
    "hochrenne": "hochrennen",
    "hochrennend": "hochrennen",
    "hochrennende": "hochrennend",
    "hochrennendem": "hochrennend",
    "hochrennenden": "hochrennend",
    "hochrennender": "hochrennend",
    "hochrennendes": "hochrennend",
    "hochrennest": "hochrennen",
    "hochrennet": "hochrennen",
    "hochrennst": "hochrennen",
    "hochrennt": "hochrennen",
    "hochrisse": "hochreißen",
    "hochrissen": "hochreißen",
    "hochrissest": "hochreißen",
    "hochrisset": "hochreißen",
    "hochriß": "hochreißen",
    "hochrißt": "hochreißen",
    "hochsah": "hochsehen",
    "hochsahen": "hochsehen",
    "hochsahst": "hochsehen",
    "hochsaht": "hochsehen",
    "hochschaukele": "hochschaukeln",
    "hochschaukelnd": "hochschaukeln",
    "hochschaukelnde": "hochschaukelnd",
    "hochschaukelndem": "hochschaukelnd",
    "hochschaukelnden": "hochschaukelnd",
    "hochschaukelnder": "hochschaukelnd",
    "hochschaukelndere": "hochschaukelnd",
    "hochschaukelnderem": "hochschaukelnd",
    "hochschaukelnderen": "hochschaukelnd",
    "hochschaukelnderer": "hochschaukelnd",
    "hochschaukelnderes": "hochschaukelnd",
    "hochschaukelndes": "hochschaukelnd",
    "hochschaukelndste": "hochschaukelnd",
    "hochschaukelndstem": "hochschaukelnd",
    "hochschaukelndsten": "hochschaukelnd",
    "hochschaukelndster": "hochschaukelnd",
    "hochschaukelndstes": "hochschaukelnd",
    "hochschaukelst": "hochschaukeln",
    "hochschaukelt": "hochschaukeln",
    "hochschaukelte": "hochschaukeln",
    "hochschaukelten": "hochschaukeln",
    "hochschaukeltest": "hochschaukeln",
    "hochschaukeltet": "hochschaukeln",
    "hochschaukle": "hochschaukeln",
    "hochschnelle": "hochschnellen",
    "hochschnellend": "hochschnellen",
    "hochschnellende": "hochschnellend",
    "hochschnellendem": "hochschnellend",
    "hochschnellenden": "hochschnellend",
    "hochschnellender": "hochschnellend",
    "hochschnellendes": "hochschnellend",
    "hochschnellest": "hochschnellen",
    "hochschnellet": "hochschnellen",
    "hochschnellst": "hochschnellen",
    "hochschnellt": "hochschnellen",
    "hochschnellte": "hochschnellen",
    "hochschnellten": "hochschnellen",
    "hochschnelltest": "hochschnellen",
    "hochschnelltet": "hochschnellen",
    "hochschrak": "hochschrecken",
    "hochschraken": "hochschrecken",
    "hochschrakst": "hochschrecken",
    "hochschrakt": "hochschrecken",
    "hochschrecke": "hochschrecken",
    "hochschreckend": "hochschrecken",
    "hochschreckende": "hochschreckend",
    "hochschreckendem": "hochschreckend",
    "hochschreckenden": "hochschreckend",
    "hochschreckender": "hochschreckend",
    "hochschreckendes": "hochschreckend",
    "hochschreckest": "hochschrecken",
    "hochschrecket": "hochschrecken",
    "hochschreckst": "hochschrecken",
    "hochschreckt": "hochschrecken",
    "hochschreckte": "hochschrecken",
    "hochschreckten": "hochschrecken",
    "hochschrecktest": "hochschrecken",
    "hochschrecktet": "hochschrecken",
    "hochschrickst": "hochschrecken",
    "hochschrickt": "hochschrecken",
    "hochschräke": "hochschrecken",
    "hochschräken": "hochschrecken",
    "hochschräkest": "hochschrecken",
    "hochschräket": "hochschrecken",
    "hochschwangerem": "hochschwanger",
    "hochschwangeren": "hochschwanger",
    "hochschwangerer": "hochschwanger",
    "hochschwangeres": "hochschwanger",
    "hochschätze": "hochschätzen",
    "hochschätzend": "hochschätzen",
    "hochschätzende": "hochschätzend",
    "hochschätzendem": "hochschätzend",
    "hochschätzenden": "hochschätzend",
    "hochschätzender": "hochschätzend",
    "hochschätzendere": "hochschätzend",
    "hochschätzenderem": "hochschätzend",
    "hochschätzenderen": "hochschätzend",
    "hochschätzenderer": "hochschätzend",
    "hochschätzenderes": "hochschätzend",
    "hochschätzendes": "hochschätzend",
    "hochschätzendste": "hochschätzend",
    "hochschätzendstem": "hochschätzend",
    "hochschätzendsten": "hochschätzend",
    "hochschätzendster": "hochschätzend",
    "hochschätzendstes": "hochschätzend",
    "hochschätzest": "hochschätzen",
    "hochschätzet": "hochschätzen",
    "hochschätzt": "hochschätzen",
    "hochschätzte": "hochschätzen",
    "hochschätzten": "hochschätzen",
    "hochschätztest": "hochschätzen",
    "hochschätztet": "hochschätzen",
    "hochsehe": "hochsehen",
    "hochsehend": "hochsehen",
    "hochsehende": "hochsehend",
    "hochsehendem": "hochsehend",
    "hochsehenden": "hochsehend",
    "hochsehender": "hochsehend",
    "hochsehendes": "hochsehend",
    "hochsehest": "hochsehen",
    "hochsehet": "hochsehen",
    "hochseht": "hochsehen",
    "hochsetze": "hochsetzen",
    "hochsetzend": "hochsetzen",
    "hochsetzende": "hochsetzend",
    "hochsetzendem": "hochsetzend",
    "hochsetzenden": "hochsetzend",
    "hochsetzender": "hochsetzend",
    "hochsetzendes": "hochsetzend",
    "hochsetzest": "hochsetzen",
    "hochsetzet": "hochsetzen",
    "hochsetzt": "hochsetzen",
    "hochsetzte": "hochsetzen",
    "hochsetzten": "hochsetzen",
    "hochsetztest": "hochsetzen",
    "hochsetztet": "hochsetzen",
    "hochsiehst": "hochsehen",
    "hochsieht": "hochsehen",
    "hochspiele": "hochspielen",
    "hochspielend": "hochspielen",
    "hochspielende": "hochspielend",
    "hochspielendem": "hochspielend",
    "hochspielenden": "hochspielend",
    "hochspielender": "hochspielend",
    "hochspielendes": "hochspielend",
    "hochspielest": "hochspielen",
    "hochspielet": "hochspielen",
    "hochspielst": "hochspielen",
    "hochspielt": "hochspielen",
    "hochspielte": "hochspielen",
    "hochspielten": "hochspielen",
    "hochspieltest": "hochspielen",
    "hochspieltet": "hochspielen",
    "hochspüle": "hochspülen",
    "hochspülend": "hochspülen",
    "hochspülende": "hochspülend",
    "hochspülendem": "hochspülend",
    "hochspülenden": "hochspülend",
    "hochspülender": "hochspülend",
    "hochspülendes": "hochspülend",
    "hochspülest": "hochspülen",
    "hochspület": "hochspülen",
    "hochspülst": "hochspülen",
    "hochspült": "hochspülen",
    "hochspülte": "hochspülen",
    "hochspülten": "hochspülen",
    "hochspültest": "hochspülen",
    "hochspültet": "hochspülen",
    "hochstapele": "hochstapeln",
    "hochstapelnd": "hochstapeln",
    "hochstapelnde": "hochstapelnd",
    "hochstapelndem": "hochstapelnd",
    "hochstapelnden": "hochstapelnd",
    "hochstapelnder": "hochstapelnd",
    "hochstapelndes": "hochstapelnd",
    "hochstapelst": "hochstapeln",
    "hochstapelt": "hochstapeln",
    "hochstapelte": "hochstapeln",
    "hochstapelten": "hochstapeln",
    "hochstapeltest": "hochstapeln",
    "hochstapeltet": "hochstapeln",
    "hochstaple": "hochstapeln",
    "hochsteige": "hochsteigen",
    "hochsteigend": "hochsteigen",
    "hochsteigende": "hochsteigend",
    "hochsteigendem": "hochsteigend",
    "hochsteigenden": "hochsteigend",
    "hochsteigender": "hochsteigend",
    "hochsteigendere": "hochsteigend",
    "hochsteigenderem": "hochsteigend",
    "hochsteigenderen": "hochsteigend",
    "hochsteigenderer": "hochsteigend",
    "hochsteigenderes": "hochsteigend",
    "hochsteigendes": "hochsteigend",
    "hochsteigendste": "hochsteigend",
    "hochsteigendstem": "hochsteigend",
    "hochsteigendsten": "hochsteigend",
    "hochsteigendster": "hochsteigend",
    "hochsteigendstes": "hochsteigend",
    "hochsteigest": "hochsteigen",
    "hochsteiget": "hochsteigen",
    "hochsteigst": "hochsteigen",
    "hochsteigt": "hochsteigen",
    "hochstelle": "hochstellen",
    "hochstellend": "hochstellen",
    "hochstellende": "hochstellend",
    "hochstellendem": "hochstellend",
    "hochstellenden": "hochstellend",
    "hochstellender": "hochstellend",
    "hochstellendes": "hochstellend",
    "hochstellest": "hochstellen",
    "hochstellet": "hochstellen",
    "hochstellst": "hochstellen",
    "hochstellt": "hochstellen",
    "hochstellte": "hochstellen",
    "hochstellten": "hochstellen",
    "hochstelltest": "hochstellen",
    "hochstelltet": "hochstellen",
    "hochstieg": "hochsteigen",
    "hochstiege": "hochsteigen",
    "hochstiegen": "hochsteigen",
    "hochstiegest": "hochsteigen",
    "hochstieget": "hochsteigen",
    "hochstiegst": "hochsteigen",
    "hochstiegt": "hochsteigen",
    "hochstilisiere": "hochstilisieren",
    "hochstilisierend": "hochstilisieren",
    "hochstilisierende": "hochstilisierend",
    "hochstilisierendem": "hochstilisierend",
    "hochstilisierenden": "hochstilisierend",
    "hochstilisierender": "hochstilisierend",
    "hochstilisierendere": "hochstilisierend",
    "hochstilisierenderem": "hochstilisierend",
    "hochstilisierenderen": "hochstilisierend",
    "hochstilisierenderer": "hochstilisierend",
    "hochstilisierenderes": "hochstilisierend",
    "hochstilisierendes": "hochstilisierend",
    "hochstilisierendste": "hochstilisierend",
    "hochstilisierendstem": "hochstilisierend",
    "hochstilisierendsten": "hochstilisierend",
    "hochstilisierendster": "hochstilisierend",
    "hochstilisierendstes": "hochstilisierend",
    "hochstilisierest": "hochstilisieren",
    "hochstilisieret": "hochstilisieren",
    "hochstilisierst": "hochstilisieren",
    "hochstilisiert": "hochstilisieren",
    "hochstilisierte": "hochstilisieren",
    "hochstilisiertem": "hochstilisiert",
    "hochstilisierten": "hochstilisieren",
    "hochstilisierter": "hochstilisiert",
    "hochstilisiertere": "hochstilisiert",
    "hochstilisierterem": "hochstilisiert",
    "hochstilisierteren": "hochstilisiert",
    "hochstilisierterer": "hochstilisiert",
    "hochstilisierteres": "hochstilisiert",
    "hochstilisiertes": "hochstilisiert",
    "hochstilisiertest": "hochstilisieren",
    "hochstilisierteste": "hochstilisiert",
    "hochstilisiertestem": "hochstilisiert",
    "hochstilisiertesten": "hochstilisiert",
    "hochstilisiertester": "hochstilisiert",
    "hochstilisiertestes": "hochstilisiert",
    "hochstilisiertet": "hochstilisieren",
    "hochstrebe": "hochstreben",
    "hochstrebend": "hochstreben",
    "hochstrebende": "hochstrebend",
    "hochstrebendem": "hochstrebend",
    "hochstrebenden": "hochstrebend",
    "hochstrebender": "hochstrebend",
    "hochstrebendes": "hochstrebend",
    "hochstrebest": "hochstreben",
    "hochstrebet": "hochstreben",
    "hochstrebst": "hochstreben",
    "hochstrebt": "hochstreben",
    "hochstrebte": "hochstreben",
    "hochstrebten": "hochstreben",
    "hochstrebtest": "hochstreben",
    "hochstrebtet": "hochstreben",
    "hochsähe": "hochsehen",
    "hochsähen": "hochsehen",
    "hochsähest": "hochsehen",
    "hochsähet": "hochsehen",
    "hochtrabendem": "hochtrabend",
    "hochtrabenden": "hochtrabend",
    "hochtrabender": "hochtrabend",
    "hochtrabendere": "hochtrabend",
    "hochtrabenderem": "hochtrabend",
    "hochtrabenderen": "hochtrabend",
    "hochtrabenderer": "hochtrabend",
    "hochtrabenderes": "hochtrabend",
    "hochtrabendes": "hochtrabend",
    "hochtrabendste": "hochtrabend",
    "hochtrabendstem": "hochtrabend",
    "hochtrabendsten": "hochtrabend",
    "hochtrabendster": "hochtrabend",
    "hochtrabendstes": "hochtrabend",
    "hochtrage": "hochtragen",
    "hochtragend": "hochtragen",
    "hochtragende": "hochtragend",
    "hochtragendem": "hochtragend",
    "hochtragenden": "hochtragend",
    "hochtragender": "hochtragend",
    "hochtragendes": "hochtragend",
    "hochtragest": "hochtragen",
    "hochtraget": "hochtragen",
    "hochtragt": "hochtragen",
    "hochtreibe": "hochtreiben",
    "hochtreibend": "hochtreiben",
    "hochtreibende": "hochtreibend",
    "hochtreibendem": "hochtreibend",
    "hochtreibenden": "hochtreibend",
    "hochtreibender": "hochtreibend",
    "hochtreibendes": "hochtreibend",
    "hochtreibest": "hochtreiben",
    "hochtreibet": "hochtreiben",
    "hochtreibst": "hochtreiben",
    "hochtreibt": "hochtreiben",
    "hochtrieb": "hochtreiben",
    "hochtriebe": "hochtreiben",
    "hochtrieben": "hochtreiben",
    "hochtriebest": "hochtreiben",
    "hochtriebet": "hochtreiben",
    "hochtriebst": "hochtreiben",
    "hochtriebt": "hochtreiben",
    "hochtrug": "hochtragen",
    "hochtrugen": "hochtragen",
    "hochtrugst": "hochtragen",
    "hochtrugt": "hochtragen",
    "hochträgst": "hochtragen",
    "hochträgt": "hochtragen",
    "hochtrüge": "hochtragen",
    "hochtrügen": "hochtragen",
    "hochtrügest": "hochtragen",
    "hochtrüget": "hochtragen",
    "hochtönendem": "hochtönend",
    "hochtönenden": "hochtönend",
    "hochtönender": "hochtönend",
    "hochtönendes": "hochtönend",
    "hochverdiente": "hochverdient",
    "hochverdientem": "hochverdient",
    "hochverdienten": "hochverdient",
    "hochverdienter": "hochverdient",
    "hochverdientes": "hochverdient",
    "hochverehrte": "hochverehrt",
    "hochverehrtem": "hochverehrt",
    "hochverehrten": "hochverehrt",
    "hochverehrter": "hochverehrt",
    "hochverehrtes": "hochverehrt",
    "hochverräterische": "hochverräterisch",
    "hochverräterischem": "hochverräterisch",
    "hochverräterischen": "hochverräterisch",
    "hochverräterischer": "hochverräterisch",
    "hochverräterisches": "hochverräterisch",
    "hochwertigem": "hochwertig",
    "hochwertigen": "hochwertig",
    "hochwertiger": "hochwertig",
    "hochwertigere": "hochwertig",
    "hochwertigerem": "hochwertig",
    "hochwertigeren": "hochwertig",
    "hochwertigerer": "hochwertig",
    "hochwertigeres": "hochwertig",
    "hochwertiges": "hochwertig",
    "hochwertigste": "hochwertig",
    "hochwertigstem": "hochwertig",
    "hochwertigsten": "hochwertig",
    "hochwertigster": "hochwertig",
    "hochwertigstes": "hochwertig",
    "hochwillkommenem": "hochwillkommen",
    "hochwillkommenen": "hochwillkommen",
    "hochwillkommener": "hochwillkommen",
    "hochwillkommenes": "hochwillkommen",
    "hochwürdige": "hochwürdig",
    "hochwürdigem": "hochwürdig",
    "hochwürdigen": "hochwürdig",
    "hochwürdiger": "hochwürdig",
    "hochwürdigere": "hochwürdig",
    "hochwürdigerem": "hochwürdig",
    "hochwürdigeren": "hochwürdig",
    "hochwürdigerer": "hochwürdig",
    "hochwürdigeres": "hochwürdig",
    "hochwürdiges": "hochwürdig",
    "hochwürdigste": "hochwürdig",
    "hochwürdigstem": "hochwürdig",
    "hochwürdigsten": "hochwürdig",
    "hochwürdigster": "hochwürdig",
    "hochwürdigstes": "hochwürdig",
    "hochzeitlichem": "hochzeitlich",
    "hochzeitlichen": "hochzeitlich",
    "hochzeitlicher": "hochzeitlich",
    "hochzeitliches": "hochzeitlich",
    "hochziehe": "hochziehen",
    "hochziehend": "hochziehen",
    "hochziehende": "hochziehend",
    "hochziehendem": "hochziehend",
    "hochziehenden": "hochziehend",
    "hochziehender": "hochziehend",
    "hochziehendere": "hochziehend",
    "hochziehenderem": "hochziehend",
    "hochziehenderen": "hochziehend",
    "hochziehenderer": "hochziehend",
    "hochziehenderes": "hochziehend",
    "hochziehendes": "hochziehend",
    "hochziehendste": "hochziehend",
    "hochziehendstem": "hochziehend",
    "hochziehendsten": "hochziehend",
    "hochziehendster": "hochziehend",
    "hochziehendstes": "hochziehend",
    "hochziehest": "hochziehen",
    "hochziehet": "hochziehen",
    "hochziehst": "hochziehen",
    "hochzieht": "hochziehen",
    "hochzog": "hochziehen",
    "hochzogen": "hochziehen",
    "hochzogst": "hochziehen",
    "hochzogt": "hochziehen",
    "hochzuachten": "hochachten",
    "hochzuarbeiten": "hocharbeiten",
    "hochzubinden": "hochbinden",
    "hochzubringen": "hochbringen",
    "hochzudienen": "hochdienen",
    "hochzufahren": "hochfahren",
    "hochzugehen": "hochgehen",
    "hochzuheben": "hochheben",
    "hochzujagen": "hochjagen",
    "hochzujubeln": "hochjubeln",
    "hochzuklappen": "hochklappen",
    "hochzukämmen": "hochkämmen",
    "hochzuleben": "hochleben",
    "hochzunehmen": "hochnehmen",
    "hochzupäppeln": "hochpäppeln",
    "hochzurechnen": "hochrechnen",
    "hochzureißen": "hochreißen",
    "hochzurennen": "hochrennen",
    "hochzuschaukeln": "hochschaukeln",
    "hochzuschnellen": "hochschnellen",
    "hochzuschrecken": "hochschrecken",
    "hochzuschätzen": "hochschätzen",
    "hochzusehen": "hochsehen",
    "hochzusetzen": "hochsetzen",
    "hochzuspielen": "hochspielen",
    "hochzuspülen": "hochspülen",
    "hochzustapeln": "hochstapeln",
    "hochzusteigen": "hochsteigen",
    "hochzustellen": "hochstellen",
    "hochzustilisieren": "hochstilisieren",
    "hochzustreben": "hochstreben",
    "hochzutragen": "hochtragen",
    "hochzutreiben": "hochtreiben",
    "hochzuziehen": "hochziehen",
    "hochzuzüchten": "hochzüchten",
    "hochzöge": "hochziehen",
    "hochzögen": "hochziehen",
    "hochzögest": "hochziehen",
    "hochzöget": "hochziehen",
    "hochzüchte": "hochzüchten",
    "hochzüchtend": "hochzüchten",
    "hochzüchtende": "hochzüchtend",
    "hochzüchtendem": "hochzüchtend",
    "hochzüchtenden": "hochzüchtend",
    "hochzüchtender": "hochzüchtend",
    "hochzüchtendere": "hochzüchtend",
    "hochzüchtenderem": "hochzüchtend",
    "hochzüchtenderen": "hochzüchtend",
    "hochzüchtenderer": "hochzüchtend",
    "hochzüchtenderes": "hochzüchtend",
    "hochzüchtendes": "hochzüchtend",
    "hochzüchtendste": "hochzüchtend",
    "hochzüchtendstem": "hochzüchtend",
    "hochzüchtendsten": "hochzüchtend",
    "hochzüchtendster": "hochzüchtend",
    "hochzüchtendstes": "hochzüchtend",
    "hochzüchtest": "hochzüchten",
    "hochzüchtet": "hochzüchten",
    "hochzüchtete": "hochzüchten",
    "hochzüchteten": "hochzüchten",
    "hochzüchtetest": "hochzüchten",
    "hochzüchtetet": "hochzüchten",
    "hocke": "hocken",
    "hockend": "hocken",
    "hockende": "hockend",
    "hockendem": "hockend",
    "hockenden": "hockend",
    "hockender": "hockend",
    "hockendere": "hockend",
    "hockenderem": "hockend",
    "hockenderen": "hockend",
    "hockenderer": "hockend",
    "hockenderes": "hockend",
    "hockendes": "hockend",
    "hockendste": "hockend",
    "hockendstem": "hockend",
    "hockendsten": "hockend",
    "hockendster": "hockend",
    "hockendstes": "hockend",
    "hockest": "hocken",
    "hocket": "hocken",
    "hockst": "hocken",
    "hockt": "hocken",
    "hockte": "hocken",
    "hockten": "hocken",
    "hocktest": "hocken",
    "hocktet": "hocken",
    "hoffe": "hoffen",
    "hoffend": "hoffen",
    "hoffende": "hoffend",
    "hoffendem": "hoffend",
    "hoffenden": "hoffend",
    "hoffender": "hoffend",
    "hoffendes": "hoffend",
    "hoffest": "hoffen",
    "hoffet": "hoffen",
    "hoffnungslosem": "hoffnungslos",
    "hoffnungslosen": "hoffnungslos",
    "hoffnungsloser": "hoffnungslos",
    "hoffnungslosere": "hoffnungslos",
    "hoffnungsloserem": "hoffnungslos",
    "hoffnungsloseren": "hoffnungslos",
    "hoffnungsloserer": "hoffnungslos",
    "hoffnungsloseres": "hoffnungslos",
    "hoffnungsloses": "hoffnungslos",
    "hoffnungsloseste": "hoffnungslos",
    "hoffnungslosestem": "hoffnungslos",
    "hoffnungslosesten": "hoffnungslos",
    "hoffnungslosester": "hoffnungslos",
    "hoffnungslosestes": "hoffnungslos",
    "hoffnungsvolle": "hoffnungsvoll",
    "hoffnungsvollem": "hoffnungsvoll",
    "hoffnungsvollen": "hoffnungsvoll",
    "hoffnungsvoller": "hoffnungsvoll",
    "hoffnungsvollere": "hoffnungsvoll",
    "hoffnungsvollerem": "hoffnungsvoll",
    "hoffnungsvolleren": "hoffnungsvoll",
    "hoffnungsvollerer": "hoffnungsvoll",
    "hoffnungsvolleres": "hoffnungsvoll",
    "hoffnungsvolles": "hoffnungsvoll",
    "hoffnungsvollste": "hoffnungsvoll",
    "hoffnungsvollstem": "hoffnungsvoll",
    "hoffnungsvollsten": "hoffnungsvoll",
    "hoffnungsvollster": "hoffnungsvoll",
    "hoffnungsvollstes": "hoffnungsvoll",
    "hoffst": "hoffen",
    "hofft": "hoffen",
    "hoffte": "hoffen",
    "hofften": "hoffen",
    "hofftest": "hoffen",
    "hofftet": "hoffen",
    "hoffähigem": "hoffähig",
    "hoffähigen": "hoffähig",
    "hoffähiger": "hoffähig",
    "hoffähigere": "hoffähig",
    "hoffähigerem": "hoffähig",
    "hoffähigeren": "hoffähig",
    "hoffähigerer": "hoffähig",
    "hoffähigeres": "hoffähig",
    "hoffähiges": "hoffähig",
    "hoffähigste": "hoffähig",
    "hoffähigstem": "hoffähig",
    "hoffähigsten": "hoffähig",
    "hoffähigster": "hoffähig",
    "hoffähigstes": "hoffähig",
    "hofiere": "hofieren",
    "hofierend": "hofieren",
    "hofierende": "hofierend",
    "hofierendem": "hofierend",
    "hofierenden": "hofierend",
    "hofierender": "hofierend",
    "hofierendes": "hofierend",
    "hofierest": "hofieren",
    "hofieret": "hofieren",
    "hofierst": "hofieren",
    "hofiert": "hofieren",
    "hofierte": "hofieren",
    "hofiertem": "hofiert",
    "hofierten": "hofieren",
    "hofierter": "hofiert",
    "hofiertere": "hofiert",
    "hofierterem": "hofiert",
    "hofierteren": "hofiert",
    "hofierterer": "hofiert",
    "hofierteres": "hofiert",
    "hofiertes": "hofiert",
    "hofiertest": "hofieren",
    "hofierteste": "hofiert",
    "hofiertestem": "hofiert",
    "hofiertesten": "hofiert",
    "hofiertester": "hofiert",
    "hofiertestes": "hofiert",
    "hofiertet": "hofieren",
    "hohe": "hoch",
    "hoheitlichem": "hoheitlich",
    "hoheitlichen": "hoheitlich",
    "hoheitlicher": "hoheitlich",
    "hoheitliches": "hoheitlich",
    "hoheitsvolle": "hoheitsvoll",
    "hoheitsvollem": "hoheitsvoll",
    "hoheitsvollen": "hoheitsvoll",
    "hoheitsvoller": "hoheitsvoll",
    "hoheitsvolles": "hoheitsvoll",
    "hohem": "hoch",
    "hohen": "hoch",
    "hoher": "hoch",
    "hohes": "hoch",
    "hohle": "hohl",
    "hohlem": "hohl",
    "hohlen": "hohl",
    "hohler": "hohl",
    "hohlere": "hohl",
    "hohlerem": "hohl",
    "hohleren": "hohl",
    "hohlerer": "hohl",
    "hohleres": "hohl",
    "hohles": "hohl",
    "hohlste": "hohl",
    "hohlstem": "hohl",
    "hohlsten": "hohl",
    "hohlster": "hohl",
    "hohlstes": "hohl",
    "holdem": "hold",
    "holden": "hold",
    "holder": "hold",
    "holdere": "hold",
    "holderem": "hold",
    "holderen": "hold",
    "holderer": "hold",
    "holderes": "hold",
    "holdes": "hold",
    "holdeste": "hold",
    "holdestem": "hold",
    "holdesten": "hold",
    "holdester": "hold",
    "holdestes": "hold",
    "hole": "holen",
    "holend": "holen",
    "holende": "holend",
    "holendem": "holend",
    "holenden": "holend",
    "holender": "holend",
    "holendes": "holend",
    "holest": "holen",
    "holet": "holen",
    "holländischem": "holländisch",
    "holländischen": "holländisch",
    "holländischer": "holländisch",
    "holländischere": "holländisch",
    "holländischerem": "holländisch",
    "holländischeren": "holländisch",
    "holländischerer": "holländisch",
    "holländischeres": "holländisch",
    "holländisches": "holländisch",
    "holländischste": "holländisch",
    "holländischstem": "holländisch",
    "holländischsten": "holländisch",
    "holländischster": "holländisch",
    "holländischstes": "holländisch",
    "holographischem": "holographisch",
    "holographischen": "holographisch",
    "holographischer": "holographisch",
    "holographisches": "holographisch",
    "holpere": "holpern",
    "holperige": "holperig",
    "holperigem": "holperig",
    "holperigen": "holperig",
    "holperiger": "holperig",
    "holperigere": "holperig",
    "holperigerem": "holperig",
    "holperigeren": "holperig",
    "holperigerer": "holperig",
    "holperigeres": "holperig",
    "holperiges": "holperig",
    "holperigste": "holperig",
    "holperigstem": "holperig",
    "holperigsten": "holperig",
    "holperigster": "holperig",
    "holperigstes": "holperig",
    "holpernd": "holpern",
    "holpernde": "holpernd",
    "holperndem": "holpernd",
    "holpernden": "holpernd",
    "holpernder": "holpernd",
    "holperndere": "holpernd",
    "holpernderem": "holpernd",
    "holpernderen": "holpernd",
    "holpernderer": "holpernd",
    "holpernderes": "holpernd",
    "holperndes": "holpernd",
    "holperndste": "holpernd",
    "holperndstem": "holpernd",
    "holperndsten": "holpernd",
    "holperndster": "holpernd",
    "holperndstes": "holpernd",
    "holperst": "holpern",
    "holpert": "holpern",
    "holperte": "holpern",
    "holperten": "holpern",
    "holpertest": "holpern",
    "holpertet": "holpern",
    "holprige": "holprig",
    "holprigem": "holprig",
    "holprigen": "holprig",
    "holpriger": "holprig",
    "holprigere": "holprig",
    "holprigerem": "holprig",
    "holprigeren": "holprig",
    "holprigerer": "holprig",
    "holprigeres": "holprig",
    "holpriges": "holprig",
    "holprigste": "holprig",
    "holprigstem": "holprig",
    "holprigsten": "holprig",
    "holprigster": "holprig",
    "holprigstes": "holprig",
    "holst": "holen",
    "holt": "holen",
    "holte": "holen",
    "holten": "holen",
    "holtest": "holen",
    "holtet": "holen",
    "holzend": "holzen",
    "holzende": "holzend",
    "holzendem": "holzend",
    "holzenden": "holzend",
    "holzender": "holzend",
    "holzendes": "holzend",
    "holzest": "holzen",
    "holzet": "holzen",
    "holzfreie": "holzfrei",
    "holzfreiem": "holzfrei",
    "holzfreien": "holzfrei",
    "holzfreier": "holzfrei",
    "holzfreies": "holzfrei",
    "holzhaltige": "holzhaltig",
    "holzhaltigem": "holzhaltig",
    "holzhaltigen": "holzhaltig",
    "holzhaltiger": "holzhaltig",
    "holzhaltiges": "holzhaltig",
    "holzige": "holzig",
    "holzigem": "holzig",
    "holzigen": "holzig",
    "holziger": "holzig",
    "holzigere": "holzig",
    "holzigerem": "holzig",
    "holzigeren": "holzig",
    "holzigerer": "holzig",
    "holzigeres": "holzig",
    "holziges": "holzig",
    "holzigste": "holzig",
    "holzigstem": "holzig",
    "holzigsten": "holzig",
    "holzigster": "holzig",
    "holzigstes": "holzig",
    "holzt": "holzen",
    "holzte": "holzen",
    "holzten": "holzen",
    "holztest": "holzen",
    "holztet": "holzen",
    "homogenem": "homogen",
    "homogenen": "homogen",
    "homogener": "homogen",
    "homogenere": "homogen",
    "homogenerem": "homogen",
    "homogeneren": "homogen",
    "homogenerer": "homogen",
    "homogeneres": "homogen",
    "homogenes": "homogen",
    "homogenisiere": "homogenisieren",
    "homogenisierend": "homogenisieren",
    "homogenisierende": "homogenisierend",
    "homogenisierendem": "homogenisierend",
    "homogenisierenden": "homogenisierend",
    "homogenisierender": "homogenisierend",
    "homogenisierendere": "homogenisierend",
    "homogenisierenderem": "homogenisierend",
    "homogenisierenderen": "homogenisierend",
    "homogenisierenderer": "homogenisierend",
    "homogenisierenderes": "homogenisierend",
    "homogenisierendes": "homogenisierend",
    "homogenisierendste": "homogenisierend",
    "homogenisierendstem": "homogenisierend",
    "homogenisierendsten": "homogenisierend",
    "homogenisierendster": "homogenisierend",
    "homogenisierendstes": "homogenisierend",
    "homogenisierest": "homogenisieren",
    "homogenisieret": "homogenisieren",
    "homogenisierst": "homogenisieren",
    "homogenisiert": "homogenisieren",
    "homogenisierte": "homogenisieren",
    "homogenisiertem": "homogenisiert",
    "homogenisierten": "homogenisieren",
    "homogenisierter": "homogenisiert",
    "homogenisiertere": "homogenisiert",
    "homogenisierterem": "homogenisiert",
    "homogenisierteren": "homogenisiert",
    "homogenisierterer": "homogenisiert",
    "homogenisierteres": "homogenisiert",
    "homogenisiertes": "homogenisiert",
    "homogenisiertest": "homogenisieren",
    "homogenisiertestem": "homogenisiert",
    "homogenisiertesten": "homogenisiert",
    "homogenisiertester": "homogenisiert",
    "homogenisiertestes": "homogenisiert",
    "homogenisiertet": "homogenisieren",
    "homogenste": "homogen",
    "homogenstem": "homogen",
    "homogensten": "homogen",
    "homogenster": "homogen",
    "homogenstes": "homogen",
    "homosexuelle": "homosexuell",
    "homosexuellem": "homosexuell",
    "homosexuellen": "homosexuell",
    "homosexueller": "homosexuell",
    "homosexuelles": "homosexuell",
    "homöopathische": "homöopathisch",
    "homöopathischem": "homöopathisch",
    "homöopathischen": "homöopathisch",
    "homöopathischer": "homöopathisch",
    "homöopathisches": "homöopathisch",
    "honorabelstem": "honorabel",
    "honorabelsten": "honorabel",
    "honorabelster": "honorabel",
    "honorabelstes": "honorabel",
    "honorable": "honorabel",
    "honorablem": "honorabel",
    "honorablen": "honorabel",
    "honorabler": "honorabel",
    "honorablere": "honorabel",
    "honorablerem": "honorabel",
    "honorableren": "honorabel",
    "honorablerer": "honorabel",
    "honorableres": "honorabel",
    "honorables": "honorabel",
    "honoriere": "honorieren",
    "honorierend": "honorieren",
    "honorierende": "honorierend",
    "honorierendem": "honorierend",
    "honorierenden": "honorierend",
    "honorierender": "honorierend",
    "honorierendere": "honorierend",
    "honorierenderem": "honorierend",
    "honorierenderen": "honorierend",
    "honorierenderer": "honorierend",
    "honorierenderes": "honorierend",
    "honorierendes": "honorierend",
    "honorierendste": "honorierend",
    "honorierendstem": "honorierend",
    "honorierendsten": "honorierend",
    "honorierendster": "honorierend",
    "honorierendstes": "honorierend",
    "honorierest": "honorieren",
    "honorieret": "honorieren",
    "honorierst": "honorieren",
    "honoriert": "honorieren",
    "honorierte": "honorieren",
    "honoriertem": "honoriert",
    "honorierten": "honorieren",
    "honorierter": "honoriert",
    "honoriertere": "honoriert",
    "honorierterem": "honoriert",
    "honorierteren": "honoriert",
    "honorierterer": "honoriert",
    "honorierteres": "honoriert",
    "honoriertes": "honoriert",
    "honoriertest": "honorieren",
    "honorierteste": "honoriert",
    "honoriertestem": "honoriert",
    "honoriertesten": "honoriert",
    "honoriertester": "honoriert",
    "honoriertestes": "honoriert",
    "honoriertet": "honorieren",
    "honorige": "honorig",
    "honorigem": "honorig",
    "honorigen": "honorig",
    "honoriger": "honorig",
    "honorigere": "honorig",
    "honorigerem": "honorig",
    "honorigeren": "honorig",
    "honorigerer": "honorig",
    "honorigeres": "honorig",
    "honoriges": "honorig",
    "honorigste": "honorig",
    "honorigstem": "honorig",
    "honorigsten": "honorig",
    "honorigster": "honorig",
    "honorigstes": "honorig",
    "hoppe": "hoppen",
    "hoppele": "hoppeln",
    "hoppelnd": "hoppeln",
    "hoppelnde": "hoppelnd",
    "hoppelndem": "hoppelnd",
    "hoppelnden": "hoppelnd",
    "hoppelnder": "hoppelnd",
    "hoppelndere": "hoppelnd",
    "hoppelnderem": "hoppelnd",
    "hoppelnderen": "hoppelnd",
    "hoppelnderer": "hoppelnd",
    "hoppelnderes": "hoppelnd",
    "hoppelndes": "hoppelnd",
    "hoppelndste": "hoppelnd",
    "hoppelndstem": "hoppelnd",
    "hoppelndsten": "hoppelnd",
    "hoppelndster": "hoppelnd",
    "hoppelndstes": "hoppelnd",
    "hoppelst": "hoppeln",
    "hoppelt": "hoppeln",
    "hoppelte": "hoppeln",
    "hoppelten": "hoppeln",
    "hoppeltest": "hoppeln",
    "hoppeltet": "hoppeln",
    "hoppend": "hoppen",
    "hoppende": "hoppend",
    "hoppendem": "hoppend",
    "hoppenden": "hoppend",
    "hoppender": "hoppend",
    "hoppendes": "hoppend",
    "hoppest": "hoppen",
    "hoppet": "hoppen",
    "hopple": "hoppeln",
    "hoppst": "hoppen",
    "hoppt": "hoppen",
    "hoppte": "hoppen",
    "hoppten": "hoppen",
    "hopptest": "hoppen",
    "hopptet": "hoppen",
    "hopse": "hopsen",
    "hopsend": "hopsen",
    "hopsende": "hopsend",
    "hopsendem": "hopsend",
    "hopsenden": "hopsend",
    "hopsender": "hopsend",
    "hopsendere": "hopsend",
    "hopsenderem": "hopsend",
    "hopsenderen": "hopsend",
    "hopsenderer": "hopsend",
    "hopsenderes": "hopsend",
    "hopsendes": "hopsend",
    "hopsendste": "hopsend",
    "hopsendstem": "hopsend",
    "hopsendsten": "hopsend",
    "hopsendster": "hopsend",
    "hopsendstes": "hopsend",
    "hopsest": "hopsen",
    "hopset": "hopsen",
    "hopsgegangen": "hopsgehen",
    "hopsgegangene": "hopsgegangen",
    "hopsgegangenem": "hopsgegangen",
    "hopsgegangenen": "hopsgegangen",
    "hopsgegangener": "hopsgegangen",
    "hopsgegangenes": "hopsgegangen",
    "hopsgehe": "hopsgehen",
    "hopsgehend": "hopsgehen",
    "hopsgehende": "hopsgehend",
    "hopsgehendem": "hopsgehend",
    "hopsgehenden": "hopsgehend",
    "hopsgehender": "hopsgehend",
    "hopsgehendes": "hopsgehend",
    "hopsgehest": "hopsgehen",
    "hopsgehet": "hopsgehen",
    "hopsgehst": "hopsgehen",
    "hopsgeht": "hopsgehen",
    "hopsgenommen": "hopsnehmen",
    "hopsgenommene": "hopsgenommen",
    "hopsgenommenem": "hopsgenommen",
    "hopsgenommenen": "hopsgenommen",
    "hopsgenommener": "hopsgenommen",
    "hopsgenommenes": "hopsgenommen",
    "hopsging": "hopsgehen",
    "hopsginge": "hopsgehen",
    "hopsgingen": "hopsgehen",
    "hopsgingest": "hopsgehen",
    "hopsginget": "hopsgehen",
    "hopsgingst": "hopsgehen",
    "hopsgingt": "hopsgehen",
    "hopsnahm": "hopsnehmen",
    "hopsnahmen": "hopsnehmen",
    "hopsnahmst": "hopsnehmen",
    "hopsnahmt": "hopsnehmen",
    "hopsnehme": "hopsnehmen",
    "hopsnehmend": "hopsnehmen",
    "hopsnehmende": "hopsnehmend",
    "hopsnehmendem": "hopsnehmend",
    "hopsnehmenden": "hopsnehmend",
    "hopsnehmender": "hopsnehmend",
    "hopsnehmendes": "hopsnehmend",
    "hopsnehmest": "hopsnehmen",
    "hopsnehmet": "hopsnehmen",
    "hopsnehmt": "hopsnehmen",
    "hopsnimmst": "hopsnehmen",
    "hopsnimmt": "hopsnehmen",
    "hopsnähme": "hopsnehmen",
    "hopsnähmen": "hopsnehmen",
    "hopsnähmest": "hopsnehmen",
    "hopsnähmet": "hopsnehmen",
    "hopst": "hopsen",
    "hopste": "hopsen",
    "hopsten": "hopsen",
    "hopstest": "hopsen",
    "hopstet": "hopsen",
    "hopszugehen": "hopsgehen",
    "hopszunehmen": "hopsnehmen",
    "horche": "horchen",
    "horchend": "horchen",
    "horchende": "horchend",
    "horchendem": "horchend",
    "horchenden": "horchend",
    "horchender": "horchend",
    "horchendes": "horchend",
    "horchest": "horchen",
    "horchet": "horchen",
    "horchst": "horchen",
    "horcht": "horchen",
    "horchte": "horchen",
    "horchten": "horchen",
    "horchtest": "horchen",
    "horchtet": "horchen",
    "horizontale": "horizontal",
    "horizontalem": "horizontal",
    "horizontalen": "horizontal",
    "horizontaler": "horizontal",
    "horizontales": "horizontal",
    "horrendem": "horrend",
    "horrenden": "horrend",
    "horrender": "horrend",
    "horrendes": "horrend",
    "hortend": "horten",
    "hortende": "hortend",
    "hortendem": "hortend",
    "hortenden": "hortend",
    "hortender": "hortend",
    "hortendere": "hortend",
    "hortenderem": "hortend",
    "hortenderen": "hortend",
    "hortenderer": "hortend",
    "hortenderes": "hortend",
    "hortendes": "hortend",
    "hortendste": "hortend",
    "hortendstem": "hortend",
    "hortendsten": "hortend",
    "hortendster": "hortend",
    "hortendstes": "hortend",
    "hortest": "horten",
    "hortet": "horten",
    "hortete": "horten",
    "horteten": "horten",
    "hortetest": "horten",
    "hortetet": "horten",
    "hospitiere": "hospitieren",
    "hospitierend": "hospitieren",
    "hospitierende": "hospitierend",
    "hospitierendem": "hospitierend",
    "hospitierenden": "hospitierend",
    "hospitierender": "hospitierend",
    "hospitierendes": "hospitierend",
    "hospitierest": "hospitieren",
    "hospitieret": "hospitieren",
    "hospitierst": "hospitieren",
    "hospitiert": "hospitieren",
    "hospitierte": "hospitieren",
    "hospitiertem": "hospitiert",
    "hospitierten": "hospitieren",
    "hospitierter": "hospitiert",
    "hospitiertes": "hospitiert",
    "hospitiertest": "hospitieren",
    "hospitiertet": "hospitieren",
    "hucklige": "hucklig",
    "huckligem": "hucklig",
    "huckligen": "hucklig",
    "huckliger": "hucklig",
    "huckligere": "hucklig",
    "huckligerem": "hucklig",
    "huckligeren": "hucklig",
    "huckligerer": "hucklig",
    "huckligeres": "hucklig",
    "huckliges": "hucklig",
    "huckligste": "hucklig",
    "huckligstem": "hucklig",
    "huckligsten": "hucklig",
    "huckligster": "hucklig",
    "huckligstes": "hucklig",
    "hufeisenförmigem": "hufeisenförmig",
    "hufeisenförmigen": "hufeisenförmig",
    "hufeisenförmiger": "hufeisenförmig",
    "hufeisenförmiges": "hufeisenförmig",
    "hugenottischem": "hugenottisch",
    "hugenottischen": "hugenottisch",
    "hugenottischer": "hugenottisch",
    "hugenottisches": "hugenottisch",
    "huldige": "huldigen",
    "huldigend": "huldigen",
    "huldigende": "huldigend",
    "huldigendem": "huldigend",
    "huldigenden": "huldigend",
    "huldigender": "huldigend",
    "huldigendes": "huldigend",
    "huldigest": "huldigen",
    "huldiget": "huldigen",
    "huldigst": "huldigen",
    "huldigt": "huldigen",
    "huldigte": "huldigen",
    "huldigten": "huldigen",
    "huldigtest": "huldigen",
    "huldigtet": "huldigen",
    "humane": "human",
    "humanem": "human",
    "humanen": "human",
    "humaner": "human",
    "humanere": "human",
    "humanerem": "human",
    "humaneren": "human",
    "humanerer": "human",
    "humaneres": "human",
    "humanes": "human",
    "humanisiere": "humanisieren",
    "humanisierend": "humanisieren",
    "humanisierende": "humanisierend",
    "humanisierendem": "humanisierend",
    "humanisierenden": "humanisierend",
    "humanisierender": "humanisierend",
    "humanisierendere": "humanisierend",
    "humanisierenderem": "humanisierend",
    "humanisierenderen": "humanisierend",
    "humanisierenderer": "humanisierend",
    "humanisierenderes": "humanisierend",
    "humanisierendes": "humanisierend",
    "humanisierendste": "humanisierend",
    "humanisierendstem": "humanisierend",
    "humanisierendsten": "humanisierend",
    "humanisierendster": "humanisierend",
    "humanisierendstes": "humanisierend",
    "humanisierest": "humanisieren",
    "humanisieret": "humanisieren",
    "humanisierst": "humanisieren",
    "humanisiert": "humanisieren",
    "humanisierte": "humanisieren",
    "humanisiertem": "humanisiert",
    "humanisierten": "humanisieren",
    "humanisierter": "humanisiert",
    "humanisiertere": "humanisiert",
    "humanisierterem": "humanisiert",
    "humanisierteren": "humanisiert",
    "humanisierterer": "humanisiert",
    "humanisierteres": "humanisiert",
    "humanisiertes": "humanisiert",
    "humanisiertest": "humanisieren",
    "humanisierteste": "humanisiert",
    "humanisiertestem": "humanisiert",
    "humanisiertesten": "humanisiert",
    "humanisiertester": "humanisiert",
    "humanisiertestes": "humanisiert",
    "humanisiertet": "humanisieren",
    "humanistischem": "humanistisch",
    "humanistischen": "humanistisch",
    "humanistischer": "humanistisch",
    "humanistisches": "humanistisch",
    "humanitäre": "humanitär",
    "humanitärem": "humanitär",
    "humanitären": "humanitär",
    "humanitärer": "humanitär",
    "humanitärere": "humanitär",
    "humanitärerem": "humanitär",
    "humanitäreren": "humanitär",
    "humanitärerer": "humanitär",
    "humanitäreres": "humanitär",
    "humanitäres": "humanitär",
    "humanitärste": "humanitär",
    "humanitärstem": "humanitär",
    "humanitärsten": "humanitär",
    "humanitärster": "humanitär",
    "humanitärstes": "humanitär",
    "humanmedizinische": "humanmedizinisch",
    "humanmedizinischem": "humanmedizinisch",
    "humanmedizinischen": "humanmedizinisch",
    "humanmedizinischer": "humanmedizinisch",
    "humanmedizinisches": "humanmedizinisch",
    "humanste": "human",
    "humanstem": "human",
    "humansten": "human",
    "humanster": "human",
    "humanstes": "human",
    "humifiziere": "humifizieren",
    "humifizierend": "humifizieren",
    "humifizierende": "humifizierend",
    "humifizierendem": "humifizierend",
    "humifizierenden": "humifizierend",
    "humifizierender": "humifizierend",
    "humifizierendes": "humifizierend",
    "humifizierest": "humifizieren",
    "humifizieret": "humifizieren",
    "humifizierst": "humifizieren",
    "humifiziert": "humifizieren",
    "humifizierte": "humifizieren",
    "humifiziertem": "humifiziert",
    "humifizierten": "humifizieren",
    "humifizierter": "humifiziert",
    "humifiziertes": "humifiziert",
    "humifiziertest": "humifizieren",
    "humifiziertet": "humifizieren",
    "humorigem": "humorig",
    "humorigen": "humorig",
    "humoriger": "humorig",
    "humorigere": "humorig",
    "humorigerem": "humorig",
    "humorigeren": "humorig",
    "humorigerer": "humorig",
    "humorigeres": "humorig",
    "humoriges": "humorig",
    "humorigste": "humorig",
    "humorigstem": "humorig",
    "humorigsten": "humorig",
    "humorigster": "humorig",
    "humorigstes": "humorig",
    "humoristischem": "humoristisch",
    "humoristischen": "humoristisch",
    "humoristischer": "humoristisch",
    "humoristisches": "humoristisch",
    "humorlose": "humorlos",
    "humorlosem": "humorlos",
    "humorlosen": "humorlos",
    "humorloser": "humorlos",
    "humorlosere": "humorlos",
    "humorloserem": "humorlos",
    "humorloseren": "humorlos",
    "humorloserer": "humorlos",
    "humorloseres": "humorlos",
    "humorloses": "humorlos",
    "humorloseste": "humorlos",
    "humorlosestem": "humorlos",
    "humorlosesten": "humorlos",
    "humorlosester": "humorlos",
    "humorlosestes": "humorlos",
    "humorvollem": "humorvoll",
    "humorvollen": "humorvoll",
    "humorvoller": "humorvoll",
    "humorvollere": "humorvoll",
    "humorvollerem": "humorvoll",
    "humorvolleren": "humorvoll",
    "humorvollerer": "humorvoll",
    "humorvolleres": "humorvoll",
    "humorvolles": "humorvoll",
    "humorvollste": "humorvoll",
    "humorvollstem": "humorvoll",
    "humorvollsten": "humorvoll",
    "humorvollster": "humorvoll",
    "humorvollstes": "humorvoll",
    "hundeelendem": "hundeelend",
    "hundeelenden": "hundeelend",
    "hundeelender": "hundeelend",
    "hundeelendes": "hundeelend",
    "hundekalte": "hundekalt",
    "hundekaltem": "hundekalt",
    "hundekalten": "hundekalt",
    "hundekalter": "hundekalt",
    "hundekaltes": "hundekalt",
    "hundertfachem": "hundertfach",
    "hundertfachen": "hundertfach",
    "hundertfacher": "hundertfach",
    "hundertfaches": "hundertfach",
    "hundertjährige": "hundertjährig",
    "hundertjährigem": "hundertjährig",
    "hundertjährigen": "hundertjährig",
    "hundertjähriger": "hundertjährig",
    "hundertjähriges": "hundertjährig",
    "hundertprozentigem": "hundertprozentig",
    "hundertprozentigen": "hundertprozentig",
    "hundertprozentiger": "hundertprozentig",
    "hundertprozentiges": "hundertprozentig",
    "hundertstem": "hundertste",
    "hundertsten": "hundertste",
    "hundertster": "hundertste",
    "hundertstes": "hundertste",
    "hundsgemeinem": "hundsgemein",
    "hundsgemeinen": "hundsgemein",
    "hundsgemeiner": "hundsgemein",
    "hundsgemeines": "hundsgemein",
    "hundsmiserable": "hundsmiserabel",
    "hundsmiserablem": "hundsmiserabel",
    "hundsmiserablen": "hundsmiserabel",
    "hundsmiserabler": "hundsmiserabel",
    "hundsmiserables": "hundsmiserabel",
    "hungere": "hungern",
    "hungernd": "hungern",
    "hungernde": "hungernd",
    "hungerndem": "hungernd",
    "hungernden": "hungernd",
    "hungernder": "hungernd",
    "hungerndere": "hungernd",
    "hungernderem": "hungernd",
    "hungernderen": "hungernd",
    "hungernderer": "hungernd",
    "hungernderes": "hungernd",
    "hungerndes": "hungernd",
    "hungerndste": "hungernd",
    "hungerndstem": "hungernd",
    "hungerndsten": "hungernd",
    "hungerndster": "hungernd",
    "hungerndstes": "hungernd",
    "hungerst": "hungern",
    "hungert": "hungern",
    "hungerte": "hungern",
    "hungerten": "hungern",
    "hungertest": "hungern",
    "hungertet": "hungern",
    "hungrige": "hungrig",
    "hungrigem": "hungrig",
    "hungrigen": "hungrig",
    "hungriger": "hungrig",
    "hungrigere": "hungrig",
    "hungrigerem": "hungrig",
    "hungrigeren": "hungrig",
    "hungrigerer": "hungrig",
    "hungrigeres": "hungrig",
    "hungriges": "hungrig",
    "hungrigste": "hungrig",
    "hungrigstem": "hungrig",
    "hungrigsten": "hungrig",
    "hungrigster": "hungrig",
    "hungrigstes": "hungrig",
    "hupend": "hupen",
    "hupende": "hupend",
    "hupendem": "hupend",
    "hupenden": "hupend",
    "hupender": "hupend",
    "hupendes": "hupend",
    "hupest": "hupen",
    "hupet": "hupen",
    "hupst": "hupen",
    "hupt": "hupen",
    "hupte": "hupen",
    "hupten": "hupen",
    "huptest": "hupen",
    "huptet": "hupen",
    "hurtigem": "hurtig",
    "hurtigen": "hurtig",
    "hurtiger": "hurtig",
    "hurtigere": "hurtig",
    "hurtigerem": "hurtig",
    "hurtigeren": "hurtig",
    "hurtigerer": "hurtig",
    "hurtigeres": "hurtig",
    "hurtiges": "hurtig",
    "hurtigste": "hurtig",
    "hurtigstem": "hurtig",
    "hurtigsten": "hurtig",
    "hurtigster": "hurtig",
    "hurtigstes": "hurtig",
    "husche": "huschen",
    "huschend": "huschen",
    "huschende": "huschend",
    "huschendem": "huschend",
    "huschenden": "huschend",
    "huschender": "huschend",
    "huschendes": "huschend",
    "huschest": "huschen",
    "huschet": "huschen",
    "huschst": "huschen",
    "huscht": "huschen",
    "huschte": "huschen",
    "huschten": "huschen",
    "huschtest": "huschen",
    "huschtet": "huschen",
    "huste": "husten",
    "hustend": "husten",
    "hustende": "hustend",
    "hustendem": "hustend",
    "hustenden": "hustend",
    "hustender": "hustend",
    "hustendere": "hustend",
    "hustenderem": "hustend",
    "hustenderen": "hustend",
    "hustenderer": "hustend",
    "hustenderes": "hustend",
    "hustendes": "hustend",
    "hustendste": "hustend",
    "hustendstem": "hustend",
    "hustendsten": "hustend",
    "hustendster": "hustend",
    "hustendstes": "hustend",
    "hustest": "husten",
    "hustet": "husten",
    "hustete": "husten",
    "husteten": "husten",
    "hustetest": "husten",
    "hustetet": "husten",
    "hybridem": "hybrid",
    "hybriden": "hybrid",
    "hybrider": "hybrid",
    "hybrides": "hybrid",
    "hydraulische": "hydraulisch",
    "hydraulischem": "hydraulisch",
    "hydraulischen": "hydraulisch",
    "hydraulischer": "hydraulisch",
    "hydraulisches": "hydraulisch",
    "hydriere": "hydrieren",
    "hydrierend": "hydrieren",
    "hydrierende": "hydrierend",
    "hydrierendem": "hydrierend",
    "hydrierenden": "hydrierend",
    "hydrierender": "hydrierend",
    "hydrierendes": "hydrierend",
    "hydrierest": "hydrieren",
    "hydrieret": "hydrieren",
    "hydrierst": "hydrieren",
    "hydriert": "hydrieren",
    "hydrierte": "hydrieren",
    "hydriertem": "hydriert",
    "hydrierten": "hydrieren",
    "hydrierter": "hydriert",
    "hydriertes": "hydriert",
    "hydriertest": "hydrieren",
    "hydriertet": "hydrieren",
    "hydrodynamische": "hydrodynamisch",
    "hydrodynamischem": "hydrodynamisch",
    "hydrodynamischen": "hydrodynamisch",
    "hydrodynamischer": "hydrodynamisch",
    "hydrodynamisches": "hydrodynamisch",
    "hydropneumatische": "hydropneumatisch",
    "hydropneumatischem": "hydropneumatisch",
    "hydropneumatischen": "hydropneumatisch",
    "hydropneumatischer": "hydropneumatisch",
    "hydropneumatisches": "hydropneumatisch",
    "hydrostatischem": "hydrostatisch",
    "hydrostatischen": "hydrostatisch",
    "hydrostatischer": "hydrostatisch",
    "hydrostatisches": "hydrostatisch",
    "hydrotechnische": "hydrotechnisch",
    "hydrotechnischem": "hydrotechnisch",
    "hydrotechnischen": "hydrotechnisch",
    "hydrotechnischer": "hydrotechnisch",
    "hydrotechnisches": "hydrotechnisch",
    "hymnischem": "hymnisch",
    "hymnischen": "hymnisch",
    "hymnischer": "hymnisch",
    "hymnisches": "hymnisch",
    "hyperbolischem": "hyperbolisch",
    "hyperbolischen": "hyperbolisch",
    "hyperbolischer": "hyperbolisch",
    "hyperbolisches": "hyperbolisch",
    "hyperkorrekte": "hyperkorrekt",
    "hyperkorrektem": "hyperkorrekt",
    "hyperkorrekten": "hyperkorrekt",
    "hyperkorrekter": "hyperkorrekt",
    "hyperkorrektes": "hyperkorrekt",
    "hyperkritische": "hyperkritisch",
    "hyperkritischem": "hyperkritisch",
    "hyperkritischen": "hyperkritisch",
    "hyperkritischer": "hyperkritisch",
    "hyperkritisches": "hyperkritisch",
    "hypermodernem": "hypermodern",
    "hypermodernen": "hypermodern",
    "hypermoderner": "hypermodern",
    "hypermodernes": "hypermodern",
    "hypersensiblem": "hypersensibel",
    "hypersensiblen": "hypersensibel",
    "hypersensibler": "hypersensibel",
    "hypersensibles": "hypersensibel",
    "hypnotisiere": "hypnotisieren",
    "hypnotisierend": "hypnotisieren",
    "hypnotisierende": "hypnotisierend",
    "hypnotisierendem": "hypnotisierend",
    "hypnotisierenden": "hypnotisierend",
    "hypnotisierender": "hypnotisierend",
    "hypnotisierendes": "hypnotisierend",
    "hypnotisierest": "hypnotisieren",
    "hypnotisieret": "hypnotisieren",
    "hypnotisierst": "hypnotisieren",
    "hypnotisiert": "hypnotisieren",
    "hypnotisierte": "hypnotisieren",
    "hypnotisiertem": "hypnotisiert",
    "hypnotisierten": "hypnotisieren",
    "hypnotisierter": "hypnotisiert",
    "hypnotisiertes": "hypnotisiert",
    "hypnotisiertest": "hypnotisieren",
    "hypnotisiertet": "hypnotisieren",
    "hypothetischem": "hypothetisch",
    "hypothetischen": "hypothetisch",
    "hypothetischer": "hypothetisch",
    "hypothetisches": "hypothetisch",
    "hysterischem": "hysterisch",
    "hysterischen": "hysterisch",
    "hysterischer": "hysterisch",
    "hysterischere": "hysterisch",
    "hysterischerem": "hysterisch",
    "hysterischeren": "hysterisch",
    "hysterischerer": "hysterisch",
    "hysterischeres": "hysterisch",
    "hysterisches": "hysterisch",
    "hysterischste": "hysterisch",
    "hysterischstem": "hysterisch",
    "hysterischsten": "hysterisch",
    "hysterischster": "hysterisch",
    "hysterischstes": "hysterisch",
    "häcksele": "häckseln",
    "häckselnd": "häckseln",
    "häckselnde": "häckselnd",
    "häckselndem": "häckselnd",
    "häckselnden": "häckselnd",
    "häckselnder": "häckselnd",
    "häckselndes": "häckselnd",
    "häckselst": "häckseln",
    "häckselt": "häckseln",
    "häckselte": "häckseln",
    "häckselten": "häckseln",
    "häckseltest": "häckseln",
    "häckseltet": "häckseln",
    "häcksle": "häckseln",
    "häkele": "häkeln",
    "häkelnd": "häkeln",
    "häkelnde": "häkelnd",
    "häkelndem": "häkelnd",
    "häkelnden": "häkelnd",
    "häkelnder": "häkelnd",
    "häkelndes": "häkelnd",
    "häkelst": "häkeln",
    "häkelt": "häkeln",
    "häkelte": "häkeln",
    "häkelten": "häkeln",
    "häkeltest": "häkeln",
    "häkeltet": "häkeln",
    "häkle": "häkeln",
    "hälfe": "helfen",
    "hälfen": "helfen",
    "hälfest": "helfen",
    "hälfet": "helfen",
    "hält": "halten",
    "hältst": "halten",
    "hämischem": "hämisch",
    "hämischen": "hämisch",
    "hämischer": "hämisch",
    "hämischere": "hämisch",
    "hämischerem": "hämisch",
    "hämischeren": "hämisch",
    "hämischerer": "hämisch",
    "hämischeres": "hämisch",
    "hämisches": "hämisch",
    "hämischste": "hämisch",
    "hämischstem": "hämisch",
    "hämischsten": "hämisch",
    "hämischster": "hämisch",
    "hämischstes": "hämisch",
    "hämmere": "hämmern",
    "hämmernd": "hämmern",
    "hämmernde": "hämmernd",
    "hämmerndem": "hämmernd",
    "hämmernden": "hämmernd",
    "hämmernder": "hämmernd",
    "hämmerndere": "hämmernd",
    "hämmernderem": "hämmernd",
    "hämmernderen": "hämmernd",
    "hämmernderer": "hämmernd",
    "hämmernderes": "hämmernd",
    "hämmerndes": "hämmernd",
    "hämmerndste": "hämmernd",
    "hämmerndstem": "hämmernd",
    "hämmerndsten": "hämmernd",
    "hämmerndster": "hämmernd",
    "hämmerndstes": "hämmernd",
    "hämmerst": "hämmern",
    "hämmert": "hämmern",
    "hämmerte": "hämmern",
    "hämmerten": "hämmern",
    "hämmertest": "hämmern",
    "hämmertet": "hämmern",
    "händeringendem": "händeringend",
    "händeringenden": "händeringend",
    "händeringender": "händeringend",
    "händeringendere": "händeringend",
    "händeringenderem": "händeringend",
    "händeringenderen": "händeringend",
    "händeringenderer": "händeringend",
    "händeringenderes": "händeringend",
    "händeringendes": "händeringend",
    "händeringendste": "händeringend",
    "händeringendstem": "händeringend",
    "händeringendsten": "händeringend",
    "händeringendster": "händeringend",
    "händeringendstes": "händeringend",
    "händige": "händigen",
    "händigend": "händigen",
    "händigende": "händigend",
    "händigendem": "händigend",
    "händigenden": "händigend",
    "händigender": "händigend",
    "händigendes": "händigend",
    "händigest": "händigen",
    "händiget": "händigen",
    "händigst": "händigen",
    "händigt": "händigen",
    "händigte": "händigen",
    "händigten": "händigen",
    "händigtest": "händigen",
    "händigtet": "händigen",
    "hängenbleibe": "hängenbleiben",
    "hängenbleibend": "hängenbleiben",
    "hängenbleibende": "hängenbleibend",
    "hängenbleibendem": "hängenbleibend",
    "hängenbleibenden": "hängenbleibend",
    "hängenbleibender": "hängenbleibend",
    "hängenbleibendes": "hängenbleibend",
    "hängenbleibest": "hängenbleiben",
    "hängenbleibet": "hängenbleiben",
    "hängenbleibst": "hängenbleiben",
    "hängenbleibt": "hängenbleiben",
    "hängenblieb": "hängenbleiben",
    "hängenbliebe": "hängenbleiben",
    "hängenblieben": "hängenbleiben",
    "hängenbliebest": "hängenbleiben",
    "hängenbliebet": "hängenbleiben",
    "hängenbliebst": "hängenbleiben",
    "hängenbliebt": "hängenbleiben",
    "hängend": "hängen",
    "hängende": "hängend",
    "hängendem": "hängend",
    "hängenden": "hängend",
    "hängender": "hängend",
    "hängendes": "hängend",
    "hängengeblieben": "hängenbleiben",
    "hängengebliebene": "hängengeblieben",
    "hängengebliebenem": "hängengeblieben",
    "hängengebliebenen": "hängengeblieben",
    "hängengebliebener": "hängengeblieben",
    "hängengebliebenes": "hängengeblieben",
    "hängenzubleiben": "hängenbleiben",
    "hängest": "hängen",
    "hänget": "hängen",
    "hängst": "hängen",
    "hängt": "hängen",
    "hängte": "hängen",
    "hängten": "hängen",
    "hängtest": "hängen",
    "hängtet": "hängen",
    "hänsele": "hänseln",
    "hänselnd": "hänseln",
    "hänselnde": "hänselnd",
    "hänselndem": "hänselnd",
    "hänselnden": "hänselnd",
    "hänselnder": "hänselnd",
    "hänselndere": "hänselnd",
    "hänselnderem": "hänselnd",
    "hänselnderen": "hänselnd",
    "hänselnderer": "hänselnd",
    "hänselnderes": "hänselnd",
    "hänselndes": "hänselnd",
    "hänselndste": "hänselnd",
    "hänselndstem": "hänselnd",
    "hänselndsten": "hänselnd",
    "hänselndster": "hänselnd",
    "hänselndstes": "hänselnd",
    "hänselst": "hänseln",
    "hänselt": "hänseln",
    "hänselte": "hänseln",
    "hänselten": "hänseln",
    "hänseltest": "hänseln",
    "hänseltet": "hänseln",
    "hänsle": "hänseln",
    "härtend": "härten",
    "härtende": "härtend",
    "härtendem": "härtend",
    "härtenden": "härtend",
    "härtender": "härtend",
    "härtendere": "härtend",
    "härtenderem": "härtend",
    "härtenderen": "härtend",
    "härtenderer": "härtend",
    "härtenderes": "härtend",
    "härtendes": "härtend",
    "härtendste": "härtend",
    "härtendstem": "härtend",
    "härtendsten": "härtend",
    "härtendster": "härtend",
    "härtendstes": "härtend",
    "härter": "hart",
    "härtere": "hart",
    "härterem": "hart",
    "härteren": "hart",
    "härterer": "hart",
    "härteres": "hart",
    "härtest": "härten",
    "härteste": "hart",
    "härtestem": "hart",
    "härtesten": "hart",
    "härtester": "hart",
    "härtestes": "hart",
    "härtet": "härten",
    "härtete": "härten",
    "härteten": "härten",
    "härtetest": "härten",
    "härtetet": "härten",
    "hätschele": "hätscheln",
    "hätschelnd": "hätscheln",
    "hätschelnde": "hätschelnd",
    "hätschelndem": "hätschelnd",
    "hätschelnden": "hätschelnd",
    "hätschelnder": "hätschelnd",
    "hätschelndere": "hätschelnd",
    "hätschelnderem": "hätschelnd",
    "hätschelnderen": "hätschelnd",
    "hätschelnderer": "hätschelnd",
    "hätschelnderes": "hätschelnd",
    "hätschelndes": "hätschelnd",
    "hätschelndste": "hätschelnd",
    "hätschelndstem": "hätschelnd",
    "hätschelndsten": "hätschelnd",
    "hätschelndster": "hätschelnd",
    "hätschelndstes": "hätschelnd",
    "hätschelst": "hätscheln",
    "hätschelt": "hätscheln",
    "hätschelte": "hätscheln",
    "hätschelten": "hätscheln",
    "hätscheltest": "hätscheln",
    "hätscheltet": "hätscheln",
    "hätschle": "hätscheln",
    "hätte": "haben",
    "hätten": "haben",
    "hättest": "haben",
    "hättet": "haben",
    "häufe": "häufen",
    "häufend": "häufen",
    "häufende": "häufend",
    "häufendem": "häufend",
    "häufenden": "häufend",
    "häufender": "häufend",
    "häufendes": "häufend",
    "häufest": "häufen",
    "häufet": "häufen",
    "häufige": "häufig",
    "häufigem": "häufig",
    "häufigen": "häufig",
    "häufiger": "häufig",
    "häufigere": "häufig",
    "häufigerem": "häufig",
    "häufigeren": "häufig",
    "häufigerer": "häufig",
    "häufigeres": "häufig",
    "häufiges": "häufig",
    "häufigstem": "häufig",
    "häufigsten": "häufig",
    "häufigster": "häufig",
    "häufigstes": "häufig",
    "häufst": "häufen",
    "häuft": "häufen",
    "häufte": "häufen",
    "häuften": "häufen",
    "häuftest": "häufen",
    "häuftet": "häufen",
    "häusliche": "häuslich",
    "häuslichem": "häuslich",
    "häuslichen": "häuslich",
    "häuslicher": "häuslich",
    "häuslichere": "häuslich",
    "häuslicherem": "häuslich",
    "häuslicheren": "häuslich",
    "häuslicherer": "häuslich",
    "häuslicheres": "häuslich",
    "häusliches": "häuslich",
    "häuslichste": "häuslich",
    "häuslichstem": "häuslich",
    "häuslichsten": "häuslich",
    "häuslichster": "häuslich",
    "häuslichstes": "häuslich",
    "häutend": "häuten",
    "häutende": "häutend",
    "häutendem": "häutend",
    "häutenden": "häutend",
    "häutender": "häutend",
    "häutendere": "häutend",
    "häutenderem": "häutend",
    "häutenderen": "häutend",
    "häutenderer": "häutend",
    "häutenderes": "häutend",
    "häutendes": "häutend",
    "häutendste": "häutend",
    "häutendstem": "häutend",
    "häutendsten": "häutend",
    "häutendster": "häutend",
    "häutendstes": "häutend",
    "häutest": "häuten",
    "häutet": "häuten",
    "häutete": "häuten",
    "häuteten": "häuten",
    "häutetest": "häuten",
    "häutetet": "häuten",
    "häßlichem": "häßlich",
    "häßlichen": "häßlich",
    "häßlicher": "häßlich",
    "häßlichere": "häßlich",
    "häßlicherem": "häßlich",
    "häßlicheren": "häßlich",
    "häßlicherer": "häßlich",
    "häßlicheres": "häßlich",
    "häßliches": "häßlich",
    "häßlichste": "häßlich",
    "häßlichstem": "häßlich",
    "häßlichsten": "häßlich",
    "häßlichster": "häßlich",
    "häßlichstes": "häßlich",
    "höbe": "heben",
    "höben": "heben",
    "höbest": "heben",
    "höbet": "heben",
    "höchste": "hoch",
    "höchstem": "hoch",
    "höchsten": "hoch",
    "höchster": "hoch",
    "höchstes": "hoch",
    "höchstpersönliche": "höchstpersönlich",
    "höchstpersönlichem": "höchstpersönlich",
    "höchstpersönlichen": "höchstpersönlich",
    "höchstpersönlicher": "höchstpersönlich",
    "höchstpersönliches": "höchstpersönlich",
    "höchstzulässigem": "höchstzulässig",
    "höchstzulässigen": "höchstzulässig",
    "höchstzulässiger": "höchstzulässig",
    "höchstzulässiges": "höchstzulässig",
    "höfische": "höfisch",
    "höfischem": "höfisch",
    "höfischen": "höfisch",
    "höfischer": "höfisch",
    "höfisches": "höfisch",
    "höfliche": "höflich",
    "höflichem": "höflich",
    "höflichen": "höflich",
    "höflicher": "höflich",
    "höflichere": "höflich",
    "höflicherem": "höflich",
    "höflicheren": "höflich",
    "höflicherer": "höflich",
    "höflicheres": "höflich",
    "höfliches": "höflich",
    "höflichstem": "höflich",
    "höflichsten": "höflich",
    "höflichster": "höflich",
    "höflichstes": "höflich",
    "höher": "hoch",
    "höhere": "hoch",
    "höherem": "hoch",
    "höheren": "hoch",
    "höherer": "hoch",
    "höheres": "hoch",
    "höhlend": "höhlen",
    "höhlende": "höhlend",
    "höhlendem": "höhlend",
    "höhlenden": "höhlend",
    "höhlender": "höhlend",
    "höhlendes": "höhlend",
    "höhlest": "höhlen",
    "höhlet": "höhlen",
    "höhlst": "höhlen",
    "höhlt": "höhlen",
    "höhlte": "höhlen",
    "höhlten": "höhlen",
    "höhltest": "höhlen",
    "höhltet": "höhlen",
    "höhnischem": "höhnisch",
    "höhnischen": "höhnisch",
    "höhnischer": "höhnisch",
    "höhnischere": "höhnisch",
    "höhnischerem": "höhnisch",
    "höhnischeren": "höhnisch",
    "höhnischerer": "höhnisch",
    "höhnischeres": "höhnisch",
    "höhnisches": "höhnisch",
    "höhnischste": "höhnisch",
    "höhnischstem": "höhnisch",
    "höhnischsten": "höhnisch",
    "höhnischster": "höhnisch",
    "höhnischstes": "höhnisch",
    "höllischem": "höllisch",
    "höllischen": "höllisch",
    "höllischer": "höllisch",
    "höllischere": "höllisch",
    "höllischerem": "höllisch",
    "höllischeren": "höllisch",
    "höllischerer": "höllisch",
    "höllischeres": "höllisch",
    "höllisches": "höllisch",
    "höllischste": "höllisch",
    "höllischstem": "höllisch",
    "höllischsten": "höllisch",
    "höllischster": "höllisch",
    "höllischstes": "höllisch",
    "hölzernem": "hölzern",
    "hölzernen": "hölzern",
    "hölzerner": "hölzern",
    "hölzernere": "hölzern",
    "hölzernerem": "hölzern",
    "hölzerneren": "hölzern",
    "hölzernerer": "hölzern",
    "hölzerneres": "hölzern",
    "hölzernes": "hölzern",
    "hölzernste": "hölzern",
    "hölzernstem": "hölzern",
    "hölzernsten": "hölzern",
    "hölzernster": "hölzern",
    "hölzernstes": "hölzern",
    "hörbare": "hörbar",
    "hörbarem": "hörbar",
    "hörbaren": "hörbar",
    "hörbarer": "hörbar",
    "hörbares": "hörbar",
    "höre": "hören",
    "hörend": "hören",
    "hörende": "hörend",
    "hörendem": "hörend",
    "hörenden": "hörend",
    "hörender": "hörend",
    "hörendes": "hörend",
    "hörenswertem": "hörenswert",
    "hörenswerten": "hörenswert",
    "hörenswerter": "hörenswert",
    "hörenswertere": "hörenswert",
    "hörenswerterem": "hörenswert",
    "hörenswerteren": "hörenswert",
    "hörenswerterer": "hörenswert",
    "hörenswerteres": "hörenswert",
    "hörenswertes": "hörenswert",
    "hörenswerteste": "hörenswert",
    "hörenswertestem": "hörenswert",
    "hörenswertesten": "hörenswert",
    "hörenswertester": "hörenswert",
    "hörenswertestes": "hörenswert",
    "hörest": "hören",
    "höret": "hören",
    "hörgeschädigtem": "hörgeschädigt",
    "hörgeschädigten": "hörgeschädigt",
    "hörgeschädigter": "hörgeschädigt",
    "hörgeschädigtes": "hörgeschädigt",
    "hörigem": "hörig",
    "hörigen": "hörig",
    "höriger": "hörig",
    "hörigere": "hörig",
    "hörigerem": "hörig",
    "hörigeren": "hörig",
    "hörigerer": "hörig",
    "hörigeres": "hörig",
    "höriges": "hörig",
    "hörigste": "hörig",
    "hörigstem": "hörig",
    "hörigsten": "hörig",
    "hörigster": "hörig",
    "hörigstes": "hörig",
    "hörnernem": "hörnern",
    "hörnernen": "hörnern",
    "hörnerner": "hörnern",
    "hörnernere": "hörnern",
    "hörnernerem": "hörnern",
    "hörnerneren": "hörnern",
    "hörnernerer": "hörnern",
    "hörnerneres": "hörnern",
    "hörnernes": "hörnern",
    "hörnernste": "hörnern",
    "hörnernstem": "hörnern",
    "hörnernsten": "hörnern",
    "hörnernster": "hörnern",
    "hörnernstes": "hörnern",
    "hörst": "hören",
    "hört": "hören",
    "hörte": "hören",
    "hörten": "hören",
    "hörtest": "hören",
    "hörtet": "hören",
    "hübschem": "hübsch",
    "hübschen": "hübsch",
    "hübscher": "hübsch",
    "hübschere": "hübsch",
    "hübscherem": "hübsch",
    "hübscheren": "hübsch",
    "hübscherer": "hübsch",
    "hübscheres": "hübsch",
    "hübsches": "hübsch",
    "hübschstem": "hübsch",
    "hübschsten": "hübsch",
    "hübschster": "hübsch",
    "hübschstes": "hübsch",
    "hügeligem": "hügelig",
    "hügeligen": "hügelig",
    "hügeliger": "hügelig",
    "hügeligere": "hügelig",
    "hügeligerem": "hügelig",
    "hügeligeren": "hügelig",
    "hügeligerer": "hügelig",
    "hügeligeres": "hügelig",
    "hügeliges": "hügelig",
    "hügeligste": "hügelig",
    "hügeligstem": "hügelig",
    "hügeligsten": "hügelig",
    "hügeligster": "hügelig",
    "hügeligstes": "hügelig",
    "hülle": "hüllen",
    "hüllend": "hüllen",
    "hüllende": "hüllend",
    "hüllendem": "hüllend",
    "hüllenden": "hüllend",
    "hüllender": "hüllend",
    "hüllendes": "hüllend",
    "hüllenlose": "hüllenlos",
    "hüllenlosem": "hüllenlos",
    "hüllenlosen": "hüllenlos",
    "hüllenloser": "hüllenlos",
    "hüllenlosere": "hüllenlos",
    "hüllenloserem": "hüllenlos",
    "hüllenloseren": "hüllenlos",
    "hüllenloserer": "hüllenlos",
    "hüllenloseres": "hüllenlos",
    "hüllenloses": "hüllenlos",
    "hüllenloseste": "hüllenlos",
    "hüllenlosestem": "hüllenlos",
    "hüllenlosesten": "hüllenlos",
    "hüllenlosester": "hüllenlos",
    "hüllenlosestes": "hüllenlos",
    "hüllest": "hüllen",
    "hüllet": "hüllen",
    "hüllst": "hüllen",
    "hüllt": "hüllen",
    "hüllte": "hüllen",
    "hüllten": "hüllen",
    "hülltest": "hüllen",
    "hülltet": "hüllen",
    "hülse": "hülsen",
    "hülsend": "hülsen",
    "hülsende": "hülsend",
    "hülsendem": "hülsend",
    "hülsenden": "hülsend",
    "hülsender": "hülsend",
    "hülsendes": "hülsend",
    "hülsest": "hülsen",
    "hülset": "hülsen",
    "hülst": "hülsen",
    "hülste": "hülsen",
    "hülsten": "hülsen",
    "hülstest": "hülsen",
    "hülstet": "hülsen",
    "hünenhafte": "hünenhaft",
    "hünenhaftem": "hünenhaft",
    "hünenhaften": "hünenhaft",
    "hünenhafter": "hünenhaft",
    "hünenhaftere": "hünenhaft",
    "hünenhafterem": "hünenhaft",
    "hünenhafteren": "hünenhaft",
    "hünenhafterer": "hünenhaft",
    "hünenhafteres": "hünenhaft",
    "hünenhaftes": "hünenhaft",
    "hünenhafteste": "hünenhaft",
    "hünenhaftestem": "hünenhaft",
    "hünenhaftesten": "hünenhaft",
    "hünenhaftester": "hünenhaft",
    "hünenhaftestes": "hünenhaft",
    "hüpfe": "hüpfen",
    "hüpfend": "hüpfen",
    "hüpfende": "hüpfend",
    "hüpfendem": "hüpfend",
    "hüpfenden": "hüpfend",
    "hüpfender": "hüpfend",
    "hüpfendere": "hüpfend",
    "hüpfenderem": "hüpfend",
    "hüpfenderen": "hüpfend",
    "hüpfenderer": "hüpfend",
    "hüpfenderes": "hüpfend",
    "hüpfendes": "hüpfend",
    "hüpfendste": "hüpfend",
    "hüpfendstem": "hüpfend",
    "hüpfendsten": "hüpfend",
    "hüpfendster": "hüpfend",
    "hüpfendstes": "hüpfend",
    "hüpfest": "hüpfen",
    "hüpfet": "hüpfen",
    "hüpfst": "hüpfen",
    "hüpft": "hüpfen",
    "hüpfte": "hüpfen",
    "hüpften": "hüpfen",
    "hüpftest": "hüpfen",
    "hüpftet": "hüpfen",
    "hütend": "hüten",
    "hütende": "hütend",
    "hütendem": "hütend",
    "hütenden": "hütend",
    "hütender": "hütend",
    "hütendere": "hütend",
    "hütenderem": "hütend",
    "hütenderen": "hütend",
    "hütenderer": "hütend",
    "hütenderes": "hütend",
    "hütendes": "hütend",
    "hütendste": "hütend",
    "hütendstem": "hütend",
    "hütendsten": "hütend",
    "hütendster": "hütend",
    "hütendstes": "hütend",
    "hütest": "hüten",
    "hütet": "hüten",
    "hütete": "hüten",
    "hüteten": "hüten",
    "hütetest": "hüten",
    "hütetet": "hüten",
    "idealem": "ideal",
    "idealen": "ideal",
    "idealer": "ideal",
    "idealere": "ideal",
    "idealerem": "ideal",
    "idealeren": "ideal",
    "idealerer": "ideal",
    "idealeres": "ideal",
    "ideales": "ideal",
    "idealisiere": "idealisieren",
    "idealisierend": "idealisieren",
    "idealisierende": "idealisierend",
    "idealisierendem": "idealisierend",
    "idealisierenden": "idealisierend",
    "idealisierender": "idealisierend",
    "idealisierendes": "idealisierend",
    "idealisierest": "idealisieren",
    "idealisieret": "idealisieren",
    "idealisierst": "idealisieren",
    "idealisiert": "idealisieren",
    "idealisierte": "idealisieren",
    "idealisiertem": "idealisiert",
    "idealisierten": "idealisieren",
    "idealisierter": "idealisiert",
    "idealisiertes": "idealisiert",
    "idealisiertest": "idealisieren",
    "idealisiertet": "idealisieren",
    "idealistischem": "idealistisch",
    "idealistischen": "idealistisch",
    "idealistischer": "idealistisch",
    "idealistischere": "idealistisch",
    "idealistischerem": "idealistisch",
    "idealistischeren": "idealistisch",
    "idealistischerer": "idealistisch",
    "idealistischeres": "idealistisch",
    "idealistisches": "idealistisch",
    "idealistischste": "idealistisch",
    "idealistischstem": "idealistisch",
    "idealistischsten": "idealistisch",
    "idealistischster": "idealistisch",
    "idealistischstes": "idealistisch",
    "idealstem": "ideal",
    "idealsten": "ideal",
    "idealster": "ideal",
    "idealstes": "ideal",
    "idealtypische": "idealtypisch",
    "idealtypischem": "idealtypisch",
    "idealtypischen": "idealtypisch",
    "idealtypischer": "idealtypisch",
    "idealtypischere": "idealtypisch",
    "idealtypischerem": "idealtypisch",
    "idealtypischeren": "idealtypisch",
    "idealtypischerer": "idealtypisch",
    "idealtypischeres": "idealtypisch",
    "idealtypisches": "idealtypisch",
    "idealtypischste": "idealtypisch",
    "idealtypischstem": "idealtypisch",
    "idealtypischsten": "idealtypisch",
    "idealtypischster": "idealtypisch",
    "idealtypischstes": "idealtypisch",
    "ideellem": "ideell",
    "ideellen": "ideell",
    "ideeller": "ideell",
    "ideellere": "ideell",
    "ideellerem": "ideell",
    "ideelleren": "ideell",
    "ideellerer": "ideell",
    "ideelleres": "ideell",
    "ideelles": "ideell",
    "ideellste": "ideell",
    "ideellstem": "ideell",
    "ideellsten": "ideell",
    "ideellster": "ideell",
    "ideellstes": "ideell",
    "identifiziere": "identifizieren",
    "identifizierend": "identifizieren",
    "identifizierende": "identifizierend",
    "identifizierendem": "identifizierend",
    "identifizierenden": "identifizierend",
    "identifizierender": "identifizierend",
    "identifizierendes": "identifizierend",
    "identifizierest": "identifizieren",
    "identifizieret": "identifizieren",
    "identifizierst": "identifizieren",
    "identifiziert": "identifizieren",
    "identifizierte": "identifizieren",
    "identifiziertem": "identifiziert",
    "identifizierten": "identifizieren",
    "identifizierter": "identifiziert",
    "identifiziertes": "identifiziert",
    "identifiziertest": "identifizieren",
    "identifiziertet": "identifizieren",
    "identischem": "identisch",
    "identischen": "identisch",
    "identischer": "identisch",
    "identisches": "identisch",
    "ideologischem": "ideologisch",
    "ideologischen": "ideologisch",
    "ideologischer": "ideologisch",
    "ideologischere": "ideologisch",
    "ideologischerem": "ideologisch",
    "ideologischeren": "ideologisch",
    "ideologischerer": "ideologisch",
    "ideologischeres": "ideologisch",
    "ideologisches": "ideologisch",
    "ideologischste": "ideologisch",
    "ideologischstem": "ideologisch",
    "ideologischsten": "ideologisch",
    "ideologischster": "ideologisch",
    "ideologischstes": "ideologisch",
    "ideologisiere": "ideologisieren",
    "ideologisierend": "ideologisieren",
    "ideologisierende": "ideologisierend",
    "ideologisierendem": "ideologisierend",
    "ideologisierenden": "ideologisierend",
    "ideologisierender": "ideologisierend",
    "ideologisierendes": "ideologisierend",
    "ideologisierest": "ideologisieren",
    "ideologisieret": "ideologisieren",
    "ideologisierst": "ideologisieren",
    "ideologisiert": "ideologisieren",
    "ideologisierte": "ideologisieren",
    "ideologisiertem": "ideologisiert",
    "ideologisierten": "ideologisieren",
    "ideologisierter": "ideologisiert",
    "ideologisiertes": "ideologisiert",
    "ideologisiertest": "ideologisieren",
    "ideologisiertet": "ideologisieren",
    "idiomatische": "idiomatisch",
    "idiomatischem": "idiomatisch",
    "idiomatischen": "idiomatisch",
    "idiomatischer": "idiomatisch",
    "idiomatisches": "idiomatisch",
    "idiomatisiere": "idiomatisieren",
    "idiomatisierend": "idiomatisieren",
    "idiomatisierende": "idiomatisierend",
    "idiomatisierendem": "idiomatisierend",
    "idiomatisierenden": "idiomatisierend",
    "idiomatisierender": "idiomatisierend",
    "idiomatisierendes": "idiomatisierend",
    "idiomatisierest": "idiomatisieren",
    "idiomatisieret": "idiomatisieren",
    "idiomatisierst": "idiomatisieren",
    "idiomatisiert": "idiomatisieren",
    "idiomatisierte": "idiomatisieren",
    "idiomatisiertem": "idiomatisiert",
    "idiomatisierten": "idiomatisieren",
    "idiomatisierter": "idiomatisiert",
    "idiomatisiertes": "idiomatisiert",
    "idiomatisiertest": "idiomatisieren",
    "idiomatisiertet": "idiomatisieren",
    "idyllischem": "idyllisch",
    "idyllischen": "idyllisch",
    "idyllischer": "idyllisch",
    "idyllischere": "idyllisch",
    "idyllischerem": "idyllisch",
    "idyllischeren": "idyllisch",
    "idyllischerer": "idyllisch",
    "idyllischeres": "idyllisch",
    "idyllisches": "idyllisch",
    "idyllischste": "idyllisch",
    "idyllischstem": "idyllisch",
    "idyllischsten": "idyllisch",
    "idyllischster": "idyllisch",
    "idyllischstes": "idyllisch",
    "igele": "igeln",
    "igelnd": "igeln",
    "igelnde": "igelnd",
    "igelndem": "igelnd",
    "igelnden": "igelnd",
    "igelnder": "igelnd",
    "igelndes": "igelnd",
    "igelst": "igeln",
    "igelt": "igeln",
    "igelte": "igeln",
    "igelten": "igeln",
    "igeltest": "igeln",
    "igeltet": "igeln",
    "igle": "igeln",
    "ignorantem": "ignorant",
    "ignoranten": "ignorant",
    "ignoranter": "ignorant",
    "ignorantere": "ignorant",
    "ignoranterem": "ignorant",
    "ignoranteren": "ignorant",
    "ignoranterer": "ignorant",
    "ignoranteres": "ignorant",
    "ignorantes": "ignorant",
    "ignoranteste": "ignorant",
    "ignorantestem": "ignorant",
    "ignorantesten": "ignorant",
    "ignorantester": "ignorant",
    "ignorantestes": "ignorant",
    "ignoriere": "ignorieren",
    "ignorierend": "ignorieren",
    "ignorierende": "ignorierend",
    "ignorierendem": "ignorierend",
    "ignorierenden": "ignorierend",
    "ignorierender": "ignorierend",
    "ignorierendere": "ignorierend",
    "ignorierenderem": "ignorierend",
    "ignorierenderen": "ignorierend",
    "ignorierenderer": "ignorierend",
    "ignorierenderes": "ignorierend",
    "ignorierendes": "ignorierend",
    "ignorierendste": "ignorierend",
    "ignorierendstem": "ignorierend",
    "ignorierendsten": "ignorierend",
    "ignorierendster": "ignorierend",
    "ignorierendstes": "ignorierend",
    "ignorierest": "ignorieren",
    "ignorieret": "ignorieren",
    "ignorierst": "ignorieren",
    "ignoriert": "ignorieren",
    "ignorierte": "ignorieren",
    "ignoriertem": "ignoriert",
    "ignorierten": "ignorieren",
    "ignorierter": "ignoriert",
    "ignoriertere": "ignoriert",
    "ignorierterem": "ignoriert",
    "ignorierteren": "ignoriert",
    "ignorierterer": "ignoriert",
    "ignorierteres": "ignoriert",
    "ignoriertes": "ignoriert",
    "ignoriertest": "ignorieren",
    "ignorierteste": "ignoriert",
    "ignoriertestem": "ignoriert",
    "ignoriertesten": "ignoriert",
    "ignoriertester": "ignoriert",
    "ignoriertestes": "ignoriert",
    "ignoriertet": "ignorieren",
    "ihm": "ich",
    "ihn": "ich",
    "ihnen": "ich",
    "ihr": "mein",
    "ihre": "mein",
    "ihrem": "mein",
    "ihren": "mein",
    "ihrer": "sich",
    "ihres": "mein",
    "ihresgleichen": "meinesgleichen",
    "illegalem": "illegal",
    "illegalen": "illegal",
    "illegaler": "illegal",
    "illegalere": "illegal",
    "illegalerem": "illegal",
    "illegaleren": "illegal",
    "illegalerer": "illegal",
    "illegaleres": "illegal",
    "illegales": "illegal",
    "illegalste": "illegal",
    "illegalstem": "illegal",
    "illegalsten": "illegal",
    "illegalster": "illegal",
    "illegalstes": "illegal",
    "illuminiere": "illuminieren",
    "illuminierend": "illuminieren",
    "illuminierende": "illuminierend",
    "illuminierendem": "illuminierend",
    "illuminierenden": "illuminierend",
    "illuminierender": "illuminierend",
    "illuminierendes": "illuminierend",
    "illuminierest": "illuminieren",
    "illuminieret": "illuminieren",
    "illuminierst": "illuminieren",
    "illuminiert": "illuminieren",
    "illuminierte": "illuminieren",
    "illuminiertem": "illuminiert",
    "illuminierten": "illuminieren",
    "illuminierter": "illuminiert",
    "illuminiertes": "illuminiert",
    "illuminiertest": "illuminieren",
    "illuminiertet": "illuminieren",
    "illusionistischem": "illusionistisch",
    "illusionistischen": "illusionistisch",
    "illusionistischer": "illusionistisch",
    "illusionistisches": "illusionistisch",
    "illusionärem": "illusionär",
    "illusionären": "illusionär",
    "illusionärer": "illusionär",
    "illusionärere": "illusionär",
    "illusionärerem": "illusionär",
    "illusionäreren": "illusionär",
    "illusionärerer": "illusionär",
    "illusionäreres": "illusionär",
    "illusionäres": "illusionär",
    "illusionärste": "illusionär",
    "illusionärstem": "illusionär",
    "illusionärsten": "illusionär",
    "illusionärster": "illusionär",
    "illusionärstes": "illusionär",
    "illusorische": "illusorisch",
    "illusorischem": "illusorisch",
    "illusorischen": "illusorisch",
    "illusorischer": "illusorisch",
    "illusorisches": "illusorisch",
    "illustre": "illuster",
    "illustrem": "illuster",
    "illustren": "illuster",
    "illustrer": "illuster",
    "illustres": "illuster",
    "illustriere": "illustrieren",
    "illustrierend": "illustrieren",
    "illustrierende": "illustrierend",
    "illustrierendem": "illustrierend",
    "illustrierenden": "illustrierend",
    "illustrierender": "illustrierend",
    "illustrierendes": "illustrierend",
    "illustrierest": "illustrieren",
    "illustrieret": "illustrieren",
    "illustrierst": "illustrieren",
    "illustriert": "illustrieren",
    "illustrierte": "illustrieren",
    "illustriertem": "illustriert",
    "illustrierten": "illustrieren",
    "illustrierter": "illustriert",
    "illustriertes": "illustriert",
    "illustriertest": "illustrieren",
    "illustriertet": "illustrieren",
    "imaginativem": "imaginativ",
    "imaginativen": "imaginativ",
    "imaginativer": "imaginativ",
    "imaginatives": "imaginativ",
    "imaginärem": "imaginär",
    "imaginären": "imaginär",
    "imaginärer": "imaginär",
    "imaginäres": "imaginär",
    "imitatorischem": "imitatorisch",
    "imitatorischen": "imitatorisch",
    "imitatorischer": "imitatorisch",
    "imitatorisches": "imitatorisch",
    "imitiere": "imitieren",
    "imitierend": "imitieren",
    "imitierende": "imitierend",
    "imitierendem": "imitierend",
    "imitierenden": "imitierend",
    "imitierender": "imitierend",
    "imitierendes": "imitierend",
    "imitierest": "imitieren",
    "imitieret": "imitieren",
    "imitierst": "imitieren",
    "imitiert": "imitieren",
    "imitierte": "imitieren",
    "imitiertem": "imitiert",
    "imitierten": "imitieren",
    "imitierter": "imitiert",
    "imitiertere": "imitiert",
    "imitierterem": "imitiert",
    "imitierteren": "imitiert",
    "imitierterer": "imitiert",
    "imitierteres": "imitiert",
    "imitiertes": "imitiert",
    "imitiertest": "imitieren",
    "imitierteste": "imitiert",
    "imitiertestem": "imitiert",
    "imitiertesten": "imitiert",
    "imitiertester": "imitiert",
    "imitiertestes": "imitiert",
    "imitiertet": "imitieren",
    "imkere": "imkern",
    "imkernd": "imkern",
    "imkernde": "imkernd",
    "imkerndem": "imkernd",
    "imkernden": "imkernd",
    "imkernder": "imkernd",
    "imkerndes": "imkernd",
    "imkerst": "imkern",
    "imkert": "imkern",
    "imkerte": "imkern",
    "imkerten": "imkern",
    "imkertest": "imkern",
    "imkertet": "imkern",
    "immanente": "immanent",
    "immanentem": "immanent",
    "immanenten": "immanent",
    "immanenter": "immanent",
    "immanentes": "immanent",
    "immerwährendem": "immerwährend",
    "immerwährenden": "immerwährend",
    "immerwährender": "immerwährend",
    "immerwährendes": "immerwährend",
    "imminentem": "imminent",
    "imminenten": "imminent",
    "imminenter": "imminent",
    "imminentes": "imminent",
    "immunem": "immun",
    "immunen": "immun",
    "immuner": "immun",
    "immunes": "immun",
    "immunisiere": "immunisieren",
    "immunisierend": "immunisieren",
    "immunisierende": "immunisierend",
    "immunisierendem": "immunisierend",
    "immunisierenden": "immunisierend",
    "immunisierender": "immunisierend",
    "immunisierendere": "immunisierend",
    "immunisierenderem": "immunisierend",
    "immunisierenderen": "immunisierend",
    "immunisierenderer": "immunisierend",
    "immunisierenderes": "immunisierend",
    "immunisierendes": "immunisierend",
    "immunisierendste": "immunisierend",
    "immunisierendstem": "immunisierend",
    "immunisierendsten": "immunisierend",
    "immunisierendster": "immunisierend",
    "immunisierendstes": "immunisierend",
    "immunisierest": "immunisieren",
    "immunisieret": "immunisieren",
    "immunisierst": "immunisieren",
    "immunisiert": "immunisieren",
    "immunisierte": "immunisieren",
    "immunisiertem": "immunisiert",
    "immunisierten": "immunisieren",
    "immunisierter": "immunisiert",
    "immunisiertere": "immunisiert",
    "immunisierterem": "immunisiert",
    "immunisierteren": "immunisiert",
    "immunisierterer": "immunisiert",
    "immunisierteres": "immunisiert",
    "immunisiertes": "immunisiert",
    "immunisiertest": "immunisieren",
    "immunisierteste": "immunisiert",
    "immunisiertestem": "immunisiert",
    "immunisiertesten": "immunisiert",
    "immunisiertester": "immunisiert",
    "immunisiertestes": "immunisiert",
    "immunisiertet": "immunisieren",
    "immunologischem": "immunologisch",
    "immunologischen": "immunologisch",
    "immunologischer": "immunologisch",
    "immunologisches": "immunologisch",
    "imperialem": "imperial",
    "imperialen": "imperial",
    "imperialer": "imperial",
    "imperiales": "imperial",
    "imperialistischem": "imperialistisch",
    "imperialistischen": "imperialistisch",
    "imperialistischer": "imperialistisch",
    "imperialistisches": "imperialistisch",
    "impertinente": "impertinent",
    "impertinentem": "impertinent",
    "impertinenten": "impertinent",
    "impertinenter": "impertinent",
    "impertinentere": "impertinent",
    "impertinenterem": "impertinent",
    "impertinenteren": "impertinent",
    "impertinenterer": "impertinent",
    "impertinenteres": "impertinent",
    "impertinentes": "impertinent",
    "impertinenteste": "impertinent",
    "impertinentestem": "impertinent",
    "impertinentesten": "impertinent",
    "impertinentester": "impertinent",
    "impertinentestes": "impertinent",
    "impfe": "impfen",
    "impfend": "impfen",
    "impfende": "impfend",
    "impfendem": "impfend",
    "impfenden": "impfend",
    "impfender": "impfend",
    "impfendes": "impfend",
    "impfest": "impfen",
    "impfet": "impfen",
    "impfst": "impfen",
    "impft": "impfen",
    "impfte": "impfen",
    "impften": "impfen",
    "impftest": "impfen",
    "impftet": "impfen",
    "impliziere": "implizieren",
    "implizierend": "implizieren",
    "implizierende": "implizierend",
    "implizierendem": "implizierend",
    "implizierenden": "implizierend",
    "implizierender": "implizierend",
    "implizierendes": "implizierend",
    "implizierest": "implizieren",
    "implizieret": "implizieren",
    "implizierst": "implizieren",
    "impliziert": "implizieren",
    "implizierte": "implizieren",
    "impliziertem": "impliziert",
    "implizierten": "implizieren",
    "implizierter": "impliziert",
    "impliziertes": "impliziert",
    "impliziertest": "implizieren",
    "impliziertet": "implizieren",
    "imponiere": "imponieren",
    "imponierend": "imponieren",
    "imponierende": "imponierend",
    "imponierendem": "imponierend",
    "imponierenden": "imponierend",
    "imponierender": "imponierend",
    "imponierendere": "imponierend",
    "imponierenderem": "imponierend",
    "imponierenderen": "imponierend",
    "imponierenderer": "imponierend",
    "imponierenderes": "imponierend",
    "imponierendes": "imponierend",
    "imponierendste": "imponierend",
    "imponierendstem": "imponierend",
    "imponierendsten": "imponierend",
    "imponierendster": "imponierend",
    "imponierendstes": "imponierend",
    "imponierest": "imponieren",
    "imponieret": "imponieren",
    "imponierst": "imponieren",
    "imponiert": "imponieren",
    "imponierte": "imponieren",
    "imponiertem": "imponiert",
    "imponierten": "imponieren",
    "imponierter": "imponiert",
    "imponiertere": "imponiert",
    "imponierterem": "imponiert",
    "imponierteren": "imponiert",
    "imponierterer": "imponiert",
    "imponierteres": "imponiert",
    "imponiertes": "imponiert",
    "imponiertest": "imponieren",
    "imponierteste": "imponiert",
    "imponiertestem": "imponiert",
    "imponiertesten": "imponiert",
    "imponiertester": "imponiert",
    "imponiertestes": "imponiert",
    "imponiertet": "imponieren",
    "importiere": "importieren",
    "importierend": "importieren",
    "importierende": "importierend",
    "importierendem": "importierend",
    "importierenden": "importierend",
    "importierender": "importierend",
    "importierendes": "importierend",
    "importierest": "importieren",
    "importieret": "importieren",
    "importierst": "importieren",
    "importiert": "importieren",
    "importierte": "importieren",
    "importiertem": "importiert",
    "importierten": "importieren",
    "importierter": "importiert",
    "importiertes": "importiert",
    "importiertest": "importieren",
    "importiertet": "importieren",
    "imposantem": "imposant",
    "imposanten": "imposant",
    "imposanter": "imposant",
    "imposantere": "imposant",
    "imposanterem": "imposant",
    "imposanteren": "imposant",
    "imposanterer": "imposant",
    "imposanteres": "imposant",
    "imposantes": "imposant",
    "imposanteste": "imposant",
    "imposantestem": "imposant",
    "imposantesten": "imposant",
    "imposantester": "imposant",
    "imposantestes": "imposant",
    "impossibelste": "impossibel",
    "impossibelstem": "impossibel",
    "impossibelsten": "impossibel",
    "impossibelster": "impossibel",
    "impossibelstes": "impossibel",
    "impossible": "impossibel",
    "impossiblem": "impossibel",
    "impossiblen": "impossibel",
    "impossibler": "impossibel",
    "impossiblere": "impossibel",
    "impossiblerem": "impossibel",
    "impossibleren": "impossibel",
    "impossiblerer": "impossibel",
    "impossibleres": "impossibel",
    "impossibles": "impossibel",
    "impotente": "impotent",
    "impotentem": "impotent",
    "impotenten": "impotent",
    "impotenter": "impotent",
    "impotentere": "impotent",
    "impotenterem": "impotent",
    "impotenteren": "impotent",
    "impotenterer": "impotent",
    "impotenteres": "impotent",
    "impotentes": "impotent",
    "impotenteste": "impotent",
    "impotentestem": "impotent",
    "impotentesten": "impotent",
    "impotentester": "impotent",
    "impotentestes": "impotent",
    "impressionistischem": "impressionistisch",
    "impressionistischen": "impressionistisch",
    "impressionistischer": "impressionistisch",
    "impressionistisches": "impressionistisch",
    "impressive": "impressiv",
    "impressivem": "impressiv",
    "impressiven": "impressiv",
    "impressiver": "impressiv",
    "impressives": "impressiv",
    "improvisiere": "improvisieren",
    "improvisierend": "improvisieren",
    "improvisierende": "improvisierend",
    "improvisierendem": "improvisierend",
    "improvisierenden": "improvisierend",
    "improvisierender": "improvisierend",
    "improvisierendere": "improvisierend",
    "improvisierenderem": "improvisierend",
    "improvisierenderen": "improvisierend",
    "improvisierenderer": "improvisierend",
    "improvisierenderes": "improvisierend",
    "improvisierendes": "improvisierend",
    "improvisierendste": "improvisierend",
    "improvisierendstem": "improvisierend",
    "improvisierendsten": "improvisierend",
    "improvisierendster": "improvisierend",
    "improvisierendstes": "improvisierend",
    "improvisierest": "improvisieren",
    "improvisieret": "improvisieren",
    "improvisierst": "improvisieren",
    "improvisiert": "improvisieren",
    "improvisierte": "improvisieren",
    "improvisiertem": "improvisiert",
    "improvisierten": "improvisieren",
    "improvisierter": "improvisiert",
    "improvisiertere": "improvisiert",
    "improvisierterem": "improvisiert",
    "improvisierteren": "improvisiert",
    "improvisierterer": "improvisiert",
    "improvisierteres": "improvisiert",
    "improvisiertes": "improvisiert",
    "improvisiertest": "improvisieren",
    "improvisierteste": "improvisiert",
    "improvisiertestem": "improvisiert",
    "improvisiertesten": "improvisiert",
    "improvisiertester": "improvisiert",
    "improvisiertestes": "improvisiert",
    "improvisiertet": "improvisieren",
    "impulsivem": "impulsiv",
    "impulsiven": "impulsiv",
    "impulsiver": "impulsiv",
    "impulsivere": "impulsiv",
    "impulsiverem": "impulsiv",
    "impulsiveren": "impulsiv",
    "impulsiverer": "impulsiv",
    "impulsiveres": "impulsiv",
    "impulsives": "impulsiv",
    "impulsivste": "impulsiv",
    "impulsivstem": "impulsiv",
    "impulsivsten": "impulsiv",
    "impulsivster": "impulsiv",
    "impulsivstes": "impulsiv",
    "inaktivem": "inaktiv",
    "inaktiven": "inaktiv",
    "inaktiver": "inaktiv",
    "inaktives": "inaktiv",
    "inakzeptable": "inakzeptabel",
    "inakzeptablem": "inakzeptabel",
    "inakzeptablen": "inakzeptabel",
    "inakzeptabler": "inakzeptabel",
    "inakzeptables": "inakzeptabel",
    "inbegriffenem": "inbegriffen",
    "inbegriffenen": "inbegriffen",
    "inbegriffener": "inbegriffen",
    "inbegriffenes": "inbegriffen",
    "inbrünstigem": "inbrünstig",
    "inbrünstigen": "inbrünstig",
    "inbrünstiger": "inbrünstig",
    "inbrünstigere": "inbrünstig",
    "inbrünstigerem": "inbrünstig",
    "inbrünstigeren": "inbrünstig",
    "inbrünstigerer": "inbrünstig",
    "inbrünstigeres": "inbrünstig",
    "inbrünstiges": "inbrünstig",
    "inbrünstigste": "inbrünstig",
    "inbrünstigstem": "inbrünstig",
    "inbrünstigsten": "inbrünstig",
    "inbrünstigster": "inbrünstig",
    "inbrünstigstes": "inbrünstig",
    "indexiere": "indexieren",
    "indexierend": "indexieren",
    "indexierende": "indexierend",
    "indexierendem": "indexierend",
    "indexierenden": "indexierend",
    "indexierender": "indexierend",
    "indexierendes": "indexierend",
    "indexierest": "indexieren",
    "indexieret": "indexieren",
    "indexierst": "indexieren",
    "indexiert": "indexieren",
    "indexierte": "indexieren",
    "indexiertem": "indexiert",
    "indexierten": "indexieren",
    "indexierter": "indexiert",
    "indexiertes": "indexiert",
    "indexiertest": "indexieren",
    "indexiertet": "indexieren",
    "indianischem": "indianisch",
    "indianischen": "indianisch",
    "indianischer": "indianisch",
    "indianisches": "indianisch",
    "indifferentem": "indifferent",
    "indifferenten": "indifferent",
    "indifferenter": "indifferent",
    "indifferentes": "indifferent",
    "indirektem": "indirekt",
    "indirekten": "indirekt",
    "indirekter": "indirekt",
    "indirektere": "indirekt",
    "indirekterem": "indirekt",
    "indirekteren": "indirekt",
    "indirekterer": "indirekt",
    "indirekteres": "indirekt",
    "indirektes": "indirekt",
    "indirekteste": "indirekt",
    "indirektestem": "indirekt",
    "indirektesten": "indirekt",
    "indirektester": "indirekt",
    "indirektestes": "indirekt",
    "indische": "indisch",
    "indischem": "indisch",
    "indischen": "indisch",
    "indischer": "indisch",
    "indisches": "indisch",
    "indiskrete": "indiskret",
    "indiskretem": "indiskret",
    "indiskreten": "indiskret",
    "indiskreter": "indiskret",
    "indiskretes": "indiskret",
    "indiskutabelstem": "indiskutabel",
    "indiskutabelsten": "indiskutabel",
    "indiskutabelster": "indiskutabel",
    "indiskutabelstes": "indiskutabel",
    "indiskutable": "indiskutabel",
    "indiskutablem": "indiskutabel",
    "indiskutablen": "indiskutabel",
    "indiskutabler": "indiskutabel",
    "indiskutablere": "indiskutabel",
    "indiskutablerem": "indiskutabel",
    "indiskutableren": "indiskutabel",
    "indiskutablerer": "indiskutabel",
    "indiskutableres": "indiskutabel",
    "indiskutables": "indiskutabel",
    "indisponierte": "indisponiert",
    "indisponiertem": "indisponiert",
    "indisponierten": "indisponiert",
    "indisponierter": "indisponiert",
    "indisponiertere": "indisponiert",
    "indisponierterem": "indisponiert",
    "indisponierteren": "indisponiert",
    "indisponierterer": "indisponiert",
    "indisponierteres": "indisponiert",
    "indisponiertes": "indisponiert",
    "indisponierteste": "indisponiert",
    "indisponiertestem": "indisponiert",
    "indisponiertesten": "indisponiert",
    "indisponiertester": "indisponiert",
    "indisponiertestes": "indisponiert",
    "individuellem": "individuell",
    "individuellen": "individuell",
    "individueller": "individuell",
    "individuellere": "individuell",
    "individuellerem": "individuell",
    "individuelleren": "individuell",
    "individuellerer": "individuell",
    "individuelleres": "individuell",
    "individuelles": "individuell",
    "individuellste": "individuell",
    "individuellstem": "individuell",
    "individuellsten": "individuell",
    "individuellster": "individuell",
    "individuellstes": "individuell",
    "indiziere": "indizieren",
    "indizierend": "indizieren",
    "indizierende": "indizierend",
    "indizierendem": "indizierend",
    "indizierenden": "indizierend",
    "indizierender": "indizierend",
    "indizierendes": "indizierend",
    "indizierest": "indizieren",
    "indizieret": "indizieren",
    "indizierst": "indizieren",
    "indiziert": "indizieren",
    "indizierte": "indizieren",
    "indiziertem": "indiziert",
    "indizierten": "indizieren",
    "indizierter": "indiziert",
    "indiziertes": "indiziert",
    "indiziertest": "indizieren",
    "indiziertet": "indizieren",
    "indogermanischem": "indogermanisch",
    "indogermanischen": "indogermanisch",
    "indogermanischer": "indogermanisch",
    "indogermanisches": "indogermanisch",
    "indonesischem": "indonesisch",
    "indonesischen": "indonesisch",
    "indonesischer": "indonesisch",
    "indonesisches": "indonesisch",
    "induktivem": "induktiv",
    "induktiven": "induktiv",
    "induktiver": "induktiv",
    "induktives": "induktiv",
    "industrialisiere": "industrialisieren",
    "industrialisierend": "industrialisieren",
    "industrialisierende": "industrialisierend",
    "industrialisierendem": "industrialisierend",
    "industrialisierenden": "industrialisierend",
    "industrialisierender": "industrialisierend",
    "industrialisierendes": "industrialisierend",
    "industrialisierest": "industrialisieren",
    "industrialisieret": "industrialisieren",
    "industrialisierst": "industrialisieren",
    "industrialisiert": "industrialisieren",
    "industrialisierte": "industrialisieren",
    "industrialisiertem": "industrialisiert",
    "industrialisierten": "industrialisieren",
    "industrialisierter": "industrialisiert",
    "industrialisiertes": "industrialisiert",
    "industrialisiertest": "industrialisieren",
    "industrialisiertet": "industrialisieren",
    "industriellem": "industriell",
    "industriellen": "industriell",
    "industrieller": "industriell",
    "industrielles": "industriell",
    "induziere": "induzieren",
    "induzierend": "induzieren",
    "induzierende": "induzierend",
    "induzierendem": "induzierend",
    "induzierenden": "induzierend",
    "induzierender": "induzierend",
    "induzierendes": "induzierend",
    "induzierest": "induzieren",
    "induzieret": "induzieren",
    "induzierst": "induzieren",
    "induziert": "induzieren",
    "induzierte": "induzieren",
    "induziertem": "induziert",
    "induzierten": "induzieren",
    "induzierter": "induziert",
    "induziertes": "induziert",
    "induziertest": "induzieren",
    "induziertet": "induzieren",
    "ineffektive": "ineffektiv",
    "ineffektivem": "ineffektiv",
    "ineffektiven": "ineffektiv",
    "ineffektiver": "ineffektiv",
    "ineffektivere": "ineffektiv",
    "ineffektiverem": "ineffektiv",
    "ineffektiveren": "ineffektiv",
    "ineffektiverer": "ineffektiv",
    "ineffektiveres": "ineffektiv",
    "ineffektives": "ineffektiv",
    "ineffektivste": "ineffektiv",
    "ineffektivstem": "ineffektiv",
    "ineffektivsten": "ineffektiv",
    "ineffektivster": "ineffektiv",
    "ineffektivstes": "ineffektiv",
    "ineinanderfüge": "ineinanderfügen",
    "ineinanderfügend": "ineinanderfügen",
    "ineinanderfügende": "ineinanderfügend",
    "ineinanderfügendem": "ineinanderfügend",
    "ineinanderfügenden": "ineinanderfügend",
    "ineinanderfügender": "ineinanderfügend",
    "ineinanderfügendes": "ineinanderfügend",
    "ineinanderfügest": "ineinanderfügen",
    "ineinanderfüget": "ineinanderfügen",
    "ineinanderfügst": "ineinanderfügen",
    "ineinanderfügt": "ineinanderfügen",
    "ineinanderfügte": "ineinanderfügen",
    "ineinanderfügten": "ineinanderfügen",
    "ineinanderfügtest": "ineinanderfügen",
    "ineinanderfügtet": "ineinanderfügen",
    "ineinandergefügt": "ineinandergefügen",
    "ineinandergefügte": "ineinandergefügen",
    "ineinandergefügtem": "ineinandergefügt",
    "ineinandergefügten": "ineinandergefügen",
    "ineinandergefügter": "ineinandergefügt",
    "ineinandergefügtes": "ineinandergefügt",
    "ineinandergegriffen": "ineinandergreifen",
    "ineinandergegriffene": "ineinandergegriffen",
    "ineinandergegriffenem": "ineinandergegriffen",
    "ineinandergegriffenen": "ineinandergegriffen",
    "ineinandergegriffener": "ineinandergegriffen",
    "ineinandergegriffenes": "ineinandergegriffen",
    "ineinandergreife": "ineinandergreifen",
    "ineinandergreifend": "ineinandergreifen",
    "ineinandergreifende": "ineinandergreifend",
    "ineinandergreifendem": "ineinandergreifend",
    "ineinandergreifenden": "ineinandergreifend",
    "ineinandergreifender": "ineinandergreifend",
    "ineinandergreifendes": "ineinandergreifend",
    "ineinandergreifest": "ineinandergreifen",
    "ineinandergreifet": "ineinandergreifen",
    "ineinandergreifst": "ineinandergreifen",
    "ineinandergreift": "ineinandergreifen",
    "ineinandergriff": "ineinandergreifen",
    "ineinandergriffe": "ineinandergreifen",
    "ineinandergriffen": "ineinandergreifen",
    "ineinandergriffest": "ineinandergreifen",
    "ineinandergriffet": "ineinandergreifen",
    "ineinandergriffst": "ineinandergreifen",
    "ineinandergrifft": "ineinandergreifen",
    "ineinanderzufügen": "ineinanderfügen",
    "ineinanderzugreifen": "ineinanderzugreif",
    "infame": "infam",
    "infamem": "infam",
    "infamen": "infam",
    "infamer": "infam",
    "infamere": "infam",
    "infamerem": "infam",
    "infameren": "infam",
    "infamerer": "infam",
    "infameres": "infam",
    "infames": "infam",
    "infamste": "infam",
    "infamstem": "infam",
    "infamsten": "infam",
    "infamster": "infam",
    "infamstes": "infam",
    "infantile": "infantil",
    "infantilem": "infantil",
    "infantilen": "infantil",
    "infantiler": "infantil",
    "infantilere": "infantil",
    "infantilerem": "infantil",
    "infantileren": "infantil",
    "infantilerer": "infantil",
    "infantileres": "infantil",
    "infantiles": "infantil",
    "infantilste": "infantil",
    "infantilstem": "infantil",
    "infantilsten": "infantil",
    "infantilster": "infantil",
    "infantilstes": "infantil",
    "infektiösem": "infektiös",
    "infektiösen": "infektiös",
    "infektiöser": "infektiös",
    "infektiöses": "infektiös",
    "infiltriere": "infiltrieren",
    "infiltrierend": "infiltrieren",
    "infiltrierende": "infiltrierend",
    "infiltrierendem": "infiltrierend",
    "infiltrierenden": "infiltrierend",
    "infiltrierender": "infiltrierend",
    "infiltrierendes": "infiltrierend",
    "infiltrierest": "infiltrieren",
    "infiltrieret": "infiltrieren",
    "infiltrierst": "infiltrieren",
    "infiltriert": "infiltrieren",
    "infiltrierte": "infiltrieren",
    "infiltriertem": "infiltriert",
    "infiltrierten": "infiltrieren",
    "infiltrierter": "infiltriert",
    "infiltriertes": "infiltriert",
    "infiltriertest": "infiltrieren",
    "infiltriertet": "infiltrieren",
    "infinite": "infinit",
    "infinitem": "infinit",
    "infiniten": "infinit",
    "infiniter": "infinit",
    "infinites": "infinit",
    "infinitesimale": "infinitesimal",
    "infinitesimalem": "infinitesimal",
    "infinitesimalen": "infinitesimal",
    "infinitesimaler": "infinitesimal",
    "infinitesimales": "infinitesimal",
    "infiziere": "infizieren",
    "infizierend": "infizieren",
    "infizierende": "infizierend",
    "infizierendem": "infizierend",
    "infizierenden": "infizierend",
    "infizierender": "infizierend",
    "infizierendes": "infizierend",
    "infizierest": "infizieren",
    "infizieret": "infizieren",
    "infizierst": "infizieren",
    "infiziert": "infizieren",
    "infizierte": "infizieren",
    "infiziertem": "infiziert",
    "infizierten": "infizieren",
    "infizierter": "infiziert",
    "infiziertes": "infiziert",
    "infiziertest": "infizieren",
    "infiziertet": "infizieren",
    "inflationärem": "inflationär",
    "inflationären": "inflationär",
    "inflationärer": "inflationär",
    "inflationäres": "inflationär",
    "inflatorischem": "inflatorisch",
    "inflatorischen": "inflatorisch",
    "inflatorischer": "inflatorisch",
    "inflatorisches": "inflatorisch",
    "informativem": "informativ",
    "informativen": "informativ",
    "informativer": "informativ",
    "informativere": "informativ",
    "informativerem": "informativ",
    "informativeren": "informativ",
    "informativerer": "informativ",
    "informativeres": "informativ",
    "informatives": "informativ",
    "informativste": "informativ",
    "informativstem": "informativ",
    "informativsten": "informativ",
    "informativster": "informativ",
    "informativstes": "informativ",
    "informelle": "informell",
    "informellem": "informell",
    "informellen": "informell",
    "informeller": "informell",
    "informelles": "informell",
    "informiere": "informieren",
    "informierend": "informieren",
    "informierende": "informierend",
    "informierendem": "informierend",
    "informierenden": "informierend",
    "informierender": "informierend",
    "informierendere": "informierend",
    "informierenderem": "informierend",
    "informierenderen": "informierend",
    "informierenderer": "informierend",
    "informierenderes": "informierend",
    "informierendes": "informierend",
    "informierendste": "informierend",
    "informierendstem": "informierend",
    "informierendsten": "informierend",
    "informierendster": "informierend",
    "informierendstes": "informierend",
    "informierest": "informieren",
    "informieret": "informieren",
    "informierst": "informieren",
    "informiert": "informieren",
    "informierte": "informieren",
    "informiertem": "informiert",
    "informierten": "informieren",
    "informierter": "informiert",
    "informiertere": "informiert",
    "informierterem": "informiert",
    "informierteren": "informiert",
    "informierterer": "informiert",
    "informierteres": "informiert",
    "informiertes": "informiert",
    "informiertest": "informieren",
    "informierteste": "informiert",
    "informiertestem": "informiert",
    "informiertesten": "informiert",
    "informiertester": "informiert",
    "informiertestes": "informiert",
    "informiertet": "informieren",
    "infrarotem": "infrarot",
    "infraroten": "infrarot",
    "infraroter": "infrarot",
    "infrarotes": "infrarot",
    "inhaftiere": "inhaftieren",
    "inhaftierend": "inhaftieren",
    "inhaftierende": "inhaftierend",
    "inhaftierendem": "inhaftierend",
    "inhaftierenden": "inhaftierend",
    "inhaftierender": "inhaftierend",
    "inhaftierendes": "inhaftierend",
    "inhaftierest": "inhaftieren",
    "inhaftieret": "inhaftieren",
    "inhaftierst": "inhaftieren",
    "inhaftiert": "inhaftieren",
    "inhaftierte": "inhaftieren",
    "inhaftiertem": "inhaftiert",
    "inhaftierten": "inhaftieren",
    "inhaftierter": "inhaftiert",
    "inhaftiertes": "inhaftiert",
    "inhaftiertest": "inhaftieren",
    "inhaftiertet": "inhaftieren",
    "inhaliere": "inhalieren",
    "inhalierend": "inhalieren",
    "inhalierende": "inhalierend",
    "inhalierendem": "inhalierend",
    "inhalierenden": "inhalierend",
    "inhalierender": "inhalierend",
    "inhalierendes": "inhalierend",
    "inhalierest": "inhalieren",
    "inhalieret": "inhalieren",
    "inhalierst": "inhalieren",
    "inhaliert": "inhalieren",
    "inhalierte": "inhalieren",
    "inhaliertem": "inhaliert",
    "inhalierten": "inhalieren",
    "inhalierter": "inhaliert",
    "inhaliertes": "inhaliert",
    "inhaliertest": "inhalieren",
    "inhaliertet": "inhalieren",
    "inhaltlichem": "inhaltlich",
    "inhaltlichen": "inhaltlich",
    "inhaltlicher": "inhaltlich",
    "inhaltliches": "inhaltlich",
    "inhaltsleerem": "inhaltsleer",
    "inhaltsleeren": "inhaltsleer",
    "inhaltsleerer": "inhaltsleer",
    "inhaltsleeres": "inhaltsleer",
    "inhaltsreiche": "inhaltsreich",
    "inhaltsreichem": "inhaltsreich",
    "inhaltsreichen": "inhaltsreich",
    "inhaltsreicher": "inhaltsreich",
    "inhaltsreichere": "inhaltsreich",
    "inhaltsreicherem": "inhaltsreich",
    "inhaltsreicheren": "inhaltsreich",
    "inhaltsreicherer": "inhaltsreich",
    "inhaltsreicheres": "inhaltsreich",
    "inhaltsreiches": "inhaltsreich",
    "inhaltsreichste": "inhaltsreich",
    "inhaltsreichstem": "inhaltsreich",
    "inhaltsreichsten": "inhaltsreich",
    "inhaltsreichster": "inhaltsreich",
    "inhaltsreichstes": "inhaltsreich",
    "inhaltsschwere": "inhaltsschwer",
    "inhaltsschwerem": "inhaltsschwer",
    "inhaltsschweren": "inhaltsschwer",
    "inhaltsschwerer": "inhaltsschwer",
    "inhaltsschwerere": "inhaltsschwer",
    "inhaltsschwererem": "inhaltsschwer",
    "inhaltsschwereren": "inhaltsschwer",
    "inhaltsschwererer": "inhaltsschwer",
    "inhaltsschwereres": "inhaltsschwer",
    "inhaltsschweres": "inhaltsschwer",
    "inhaltsschwerste": "inhaltsschwer",
    "inhaltsschwerstem": "inhaltsschwer",
    "inhaltsschwersten": "inhaltsschwer",
    "inhaltsschwerster": "inhaltsschwer",
    "inhaltsschwerstes": "inhaltsschwer",
    "inhärente": "inhärent",
    "inhärentem": "inhärent",
    "inhärenten": "inhärent",
    "inhärenter": "inhärent",
    "inhärentes": "inhärent",
    "injektivem": "injektiv",
    "injektiven": "injektiv",
    "injektiver": "injektiv",
    "injektives": "injektiv",
    "injiziere": "injizieren",
    "injizierend": "injizieren",
    "injizierende": "injizierend",
    "injizierendem": "injizierend",
    "injizierenden": "injizierend",
    "injizierender": "injizierend",
    "injizierendes": "injizierend",
    "injizierest": "injizieren",
    "injizieret": "injizieren",
    "injizierst": "injizieren",
    "injiziert": "injizieren",
    "injizierte": "injizieren",
    "injiziertem": "injiziert",
    "injizierten": "injizieren",
    "injizierter": "injiziert",
    "injiziertes": "injiziert",
    "injiziertest": "injizieren",
    "injiziertet": "injizieren",
    "inkompatibelstem": "inkompatibel",
    "inkompatibelsten": "inkompatibel",
    "inkompatibelster": "inkompatibel",
    "inkompatibelstes": "inkompatibel",
    "inkompatible": "inkompatibel",
    "inkompatiblem": "inkompatibel",
    "inkompatiblen": "inkompatibel",
    "inkompatibler": "inkompatibel",
    "inkompatiblere": "inkompatibel",
    "inkompatiblerem": "inkompatibel",
    "inkompatibleren": "inkompatibel",
    "inkompatiblerer": "inkompatibel",
    "inkompatibleres": "inkompatibel",
    "inkompatibles": "inkompatibel",
    "inkonsequente": "inkonsequent",
    "inkonsequentem": "inkonsequent",
    "inkonsequenten": "inkonsequent",
    "inkonsequenter": "inkonsequent",
    "inkonsequentere": "inkonsequent",
    "inkonsequenterem": "inkonsequent",
    "inkonsequenteren": "inkonsequent",
    "inkonsequenterer": "inkonsequent",
    "inkonsequenteres": "inkonsequent",
    "inkonsequentes": "inkonsequent",
    "inkonsequenteste": "inkonsequent",
    "inkonsequentestem": "inkonsequent",
    "inkonsequentesten": "inkonsequent",
    "inkonsequentester": "inkonsequent",
    "inkonsequentestes": "inkonsequent",
    "inkonsistentem": "inkonsistent",
    "inkonsistenten": "inkonsistent",
    "inkonsistenter": "inkonsistent",
    "inkonsistentere": "inkonsistent",
    "inkonsistenterem": "inkonsistent",
    "inkonsistenteren": "inkonsistent",
    "inkonsistenterer": "inkonsistent",
    "inkonsistenteres": "inkonsistent",
    "inkonsistentes": "inkonsistent",
    "inkonsistenteste": "inkonsistent",
    "inkonsistentestem": "inkonsistent",
    "inkonsistentesten": "inkonsistent",
    "inkonsistentester": "inkonsistent",
    "inkonsistentestes": "inkonsistent",
    "inkrementiere": "inkrementieren",
    "inkrementierend": "inkrementieren",
    "inkrementierende": "inkrementierend",
    "inkrementierendem": "inkrementierend",
    "inkrementierenden": "inkrementierend",
    "inkrementierender": "inkrementierend",
    "inkrementierendes": "inkrementierend",
    "inkrementierest": "inkrementieren",
    "inkrementieret": "inkrementieren",
    "inkrementierst": "inkrementieren",
    "inkrementiert": "inkrementieren",
    "inkrementierte": "inkrementieren",
    "inkrementiertem": "inkrementiert",
    "inkrementierten": "inkrementieren",
    "inkrementierter": "inkrementiert",
    "inkrementiertes": "inkrementiert",
    "inkrementiertest": "inkrementieren",
    "inkrementiertet": "inkrementieren",
    "inländischem": "inländisch",
    "inländischen": "inländisch",
    "inländischer": "inländisch",
    "inländisches": "inländisch",
    "innegehalten": "innehalten",
    "innegehaltene": "innegehalten",
    "innegehaltenem": "innegehalten",
    "innegehaltenen": "innegehalten",
    "innegehaltener": "innegehalten",
    "innegehaltenes": "innegehalten",
    "innegewohnt": "innewohnen",
    "innegewohnte": "innegewohnt",
    "innegewohntem": "innegewohnt",
    "innegewohnten": "innegewohnt",
    "innegewohnter": "innegewohnt",
    "innegewohntes": "innegewohnt",
    "innehalte": "innehalten",
    "innehaltend": "innehalten",
    "innehaltende": "innehaltend",
    "innehaltendem": "innehaltend",
    "innehaltenden": "innehaltend",
    "innehaltender": "innehaltend",
    "innehaltendes": "innehaltend",
    "innehaltest": "innehalten",
    "innehaltet": "innehalten",
    "innehielt": "innehalten",
    "innehielte": "innehalten",
    "innehielten": "innehalten",
    "innehieltest": "innehalten",
    "innehieltet": "innehalten",
    "innehält": "innehalten",
    "innehältst": "innehalten",
    "innenliegendem": "innenliegend",
    "innenliegenden": "innenliegend",
    "innenliegender": "innenliegend",
    "innenliegendes": "innenliegend",
    "innenpolitischem": "innenpolitisch",
    "innenpolitischen": "innenpolitisch",
    "innenpolitischer": "innenpolitisch",
    "innenpolitisches": "innenpolitisch",
    "innerbetrieblichem": "innerbetrieblich",
    "innerbetrieblichen": "innerbetrieblich",
    "innerbetrieblicher": "innerbetrieblich",
    "innerbetriebliches": "innerbetrieblich",
    "innerdeutsche": "innerdeutsch",
    "innerdeutschem": "innerdeutsch",
    "innerdeutschen": "innerdeutsch",
    "innerdeutscher": "innerdeutsch",
    "innerdeutsches": "innerdeutsch",
    "innerdienstliche": "innerdienstlich",
    "innerdienstlichem": "innerdienstlich",
    "innerdienstlichen": "innerdienstlich",
    "innerdienstlicher": "innerdienstlich",
    "innerdienstliches": "innerdienstlich",
    "innere": "inner",
    "innerem": "inner",
    "inneren": "inner",
    "innerer": "inner",
    "innerere": "inner",
    "innererem": "inner",
    "innereren": "inner",
    "innererer": "inner",
    "innereres": "inner",
    "inneres": "inner",
    "innerliche": "innerlich",
    "innerlichem": "innerlich",
    "innerlichen": "innerlich",
    "innerlicher": "innerlich",
    "innerliches": "innerlich",
    "innerpolitische": "innerpolitisch",
    "innerpolitischem": "innerpolitisch",
    "innerpolitischen": "innerpolitisch",
    "innerpolitischer": "innerpolitisch",
    "innerpolitisches": "innerpolitisch",
    "innerstaatliche": "innerstaatlich",
    "innerstaatlichem": "innerstaatlich",
    "innerstaatlichen": "innerstaatlich",
    "innerstaatlicher": "innerstaatlich",
    "innerstaatliches": "innerstaatlich",
    "innerste": "inner",
    "innerstem": "inner",
    "innersten": "inner",
    "innerster": "inner",
    "innerstes": "inner",
    "innewohne": "innewohnen",
    "innewohnend": "innewohnen",
    "innewohnende": "innewohnend",
    "innewohnendem": "innewohnend",
    "innewohnenden": "innewohnend",
    "innewohnender": "innewohnend",
    "innewohnendes": "innewohnend",
    "innewohnest": "innewohnen",
    "innewohnet": "innewohnen",
    "innewohnst": "innewohnen",
    "innewohnt": "innewohnen",
    "innewohnte": "innewohnen",
    "innewohnten": "innewohnen",
    "innewohntest": "innewohnen",
    "innewohntet": "innewohnen",
    "innezuhalten": "innehalten",
    "innezuwohnen": "innewohnen",
    "innige": "innig",
    "innigem": "innig",
    "innigen": "innig",
    "inniger": "innig",
    "innigere": "innig",
    "innigerem": "innig",
    "innigeren": "innig",
    "innigerer": "innig",
    "innigeres": "innig",
    "inniges": "innig",
    "innigste": "innig",
    "innigstem": "innig",
    "innigsten": "innig",
    "innigster": "innig",
    "innigstes": "innig",
    "innovativem": "innovativ",
    "innovativen": "innovativ",
    "innovativer": "innovativ",
    "innovativere": "innovativ",
    "innovativerem": "innovativ",
    "innovativeren": "innovativ",
    "innovativerer": "innovativ",
    "innovativeres": "innovativ",
    "innovatives": "innovativ",
    "innovativste": "innovativ",
    "innovativstem": "innovativ",
    "innovativsten": "innovativ",
    "innovativster": "innovativ",
    "innovativstes": "innovativ",
    "inoffiziellem": "inoffiziell",
    "inoffiziellen": "inoffiziell",
    "inoffizieller": "inoffiziell",
    "inoffizielles": "inoffiziell",
    "inoperable": "inoperabel",
    "inoperablem": "inoperabel",
    "inoperablen": "inoperabel",
    "inoperabler": "inoperabel",
    "inoperables": "inoperabel",
    "inquisitorischem": "inquisitorisch",
    "inquisitorischen": "inquisitorisch",
    "inquisitorischer": "inquisitorisch",
    "inquisitorisches": "inquisitorisch",
    "insektizidem": "insektizid",
    "insektiziden": "insektizid",
    "insektizider": "insektizid",
    "insektizides": "insektizid",
    "inseriere": "inserieren",
    "inserierend": "inserieren",
    "inserierende": "inserierend",
    "inserierendem": "inserierend",
    "inserierenden": "inserierend",
    "inserierender": "inserierend",
    "inserierendere": "inserierend",
    "inserierenderem": "inserierend",
    "inserierenderen": "inserierend",
    "inserierenderer": "inserierend",
    "inserierenderes": "inserierend",
    "inserierendes": "inserierend",
    "inserierendste": "inserierend",
    "inserierendstem": "inserierend",
    "inserierendsten": "inserierend",
    "inserierendster": "inserierend",
    "inserierendstes": "inserierend",
    "inserierest": "inserieren",
    "inserieret": "inserieren",
    "inserierst": "inserieren",
    "inseriert": "inserieren",
    "inserierte": "inserieren",
    "inseriertem": "inseriert",
    "inserierten": "inserieren",
    "inserierter": "inseriert",
    "inseriertes": "inseriert",
    "inseriertest": "inserieren",
    "inseriertet": "inserieren",
    "inspiriere": "inspirieren",
    "inspirierend": "inspirieren",
    "inspirierende": "inspirierend",
    "inspirierendem": "inspirierend",
    "inspirierenden": "inspirierend",
    "inspirierender": "inspirierend",
    "inspirierendere": "inspirierend",
    "inspirierenderem": "inspirierend",
    "inspirierenderen": "inspirierend",
    "inspirierenderer": "inspirierend",
    "inspirierenderes": "inspirierend",
    "inspirierendes": "inspirierend",
    "inspirierendste": "inspirierend",
    "inspirierendstem": "inspirierend",
    "inspirierendsten": "inspirierend",
    "inspirierendster": "inspirierend",
    "inspirierendstes": "inspirierend",
    "inspirierest": "inspirieren",
    "inspirieret": "inspirieren",
    "inspirierst": "inspirieren",
    "inspiriert": "inspirieren",
    "inspirierte": "inspirieren",
    "inspiriertem": "inspiriert",
    "inspirierten": "inspirieren",
    "inspirierter": "inspiriert",
    "inspiriertere": "inspiriert",
    "inspirierterem": "inspiriert",
    "inspirierteren": "inspiriert",
    "inspirierterer": "inspiriert",
    "inspirierteres": "inspiriert",
    "inspiriertes": "inspiriert",
    "inspiriertest": "inspirieren",
    "inspirierteste": "inspiriert",
    "inspiriertestem": "inspiriert",
    "inspiriertesten": "inspiriert",
    "inspiriertester": "inspiriert",
    "inspiriertestes": "inspiriert",
    "inspiriertet": "inspirieren",
    "inspiziere": "inspizieren",
    "inspizierend": "inspizieren",
    "inspizierende": "inspizierend",
    "inspizierendem": "inspizierend",
    "inspizierenden": "inspizierend",
    "inspizierender": "inspizierend",
    "inspizierendes": "inspizierend",
    "inspizierest": "inspizieren",
    "inspizieret": "inspizieren",
    "inspizierst": "inspizieren",
    "inspiziert": "inspizieren",
    "inspizierte": "inspizieren",
    "inspiziertem": "inspiziert",
    "inspizierten": "inspizieren",
    "inspizierter": "inspiziert",
    "inspiziertes": "inspiziert",
    "inspiziertest": "inspizieren",
    "inspiziertet": "inspizieren",
    "instabile": "instabil",
    "instabilem": "instabil",
    "instabilen": "instabil",
    "instabiler": "instabil",
    "instabilere": "instabil",
    "instabilerem": "instabil",
    "instabileren": "instabil",
    "instabilerer": "instabil",
    "instabileres": "instabil",
    "instabiles": "instabil",
    "instabilste": "instabil",
    "instabilstem": "instabil",
    "instabilsten": "instabil",
    "instabilster": "instabil",
    "instabilstes": "instabil",
    "installiere": "installieren",
    "installierend": "installieren",
    "installierende": "installierend",
    "installierendem": "installierend",
    "installierenden": "installierend",
    "installierender": "installierend",
    "installierendes": "installierend",
    "installierest": "installieren",
    "installieret": "installieren",
    "installierst": "installieren",
    "installiert": "installieren",
    "installierte": "installieren",
    "installiertem": "installiert",
    "installierten": "installieren",
    "installierter": "installiert",
    "installiertes": "installiert",
    "installiertest": "installieren",
    "installiertet": "installieren",
    "instinktivem": "instinktiv",
    "instinktiven": "instinktiv",
    "instinktiver": "instinktiv",
    "instinktivere": "instinktiv",
    "instinktiverem": "instinktiv",
    "instinktiveren": "instinktiv",
    "instinktiverer": "instinktiv",
    "instinktiveres": "instinktiv",
    "instinktives": "instinktiv",
    "instinktivste": "instinktiv",
    "instinktivstem": "instinktiv",
    "instinktivsten": "instinktiv",
    "instinktivster": "instinktiv",
    "instinktivstes": "instinktiv",
    "institutionalisierest": "institutionalisiere",
    "institutionalisieret": "institutionalisiere",
    "institutionalisierst": "institutionalisiere",
    "institutionalisiert": "institutionalisiere",
    "institutionalisierte": "institutionalisiere",
    "institutionalisiertem": "institutionalisiert",
    "institutionalisierten": "institutionalisiere",
    "institutionalisierter": "institutionalisiert",
    "institutionalisiertere": "institutionalisiert",
    "institutionalisierterem": "institutionalisiert",
    "institutionalisierteren": "institutionalisiert",
    "institutionalisierterer": "institutionalisiert",
    "institutionalisierteres": "institutionalisiert",
    "institutionalisiertes": "institutionalisiert",
    "institutionalisiertest": "institutionalisiere",
    "institutionalisierteste": "institutionalisiert",
    "institutionalisiertestem": "institutionalisiert",
    "institutionalisiertesten": "institutionalisiert",
    "institutionalisiertester": "institutionalisiert",
    "institutionalisiertestes": "institutionalisiert",
    "institutionalisiertet": "institutionalisiere",
    "institutionelle": "institutionell",
    "institutionellem": "institutionell",
    "institutionellen": "institutionell",
    "institutioneller": "institutionell",
    "institutionelles": "institutionell",
    "instruiere": "instruieren",
    "instruierend": "instruieren",
    "instruierende": "instruierend",
    "instruierendem": "instruierend",
    "instruierenden": "instruierend",
    "instruierender": "instruierend",
    "instruierendes": "instruierend",
    "instruierest": "instruieren",
    "instruieret": "instruieren",
    "instruierst": "instruieren",
    "instruiert": "instruieren",
    "instruierte": "instruieren",
    "instruiertem": "instruiert",
    "instruierten": "instruieren",
    "instruierter": "instruiert",
    "instruiertes": "instruiert",
    "instruiertest": "instruieren",
    "instruiertet": "instruieren",
    "instruktivem": "instruktiv",
    "instruktiven": "instruktiv",
    "instruktiver": "instruktiv",
    "instruktives": "instruktiv",
    "instrumentale": "instrumental",
    "instrumentalem": "instrumental",
    "instrumentalen": "instrumental",
    "instrumentaler": "instrumental",
    "instrumentales": "instrumental",
    "instrumentalisiere": "instrumentalisieren",
    "instrumentalisierend": "instrumentalisieren",
    "instrumentalisierende": "instrumentalisierend",
    "instrumentalisierendem": "instrumentalisierend",
    "instrumentalisierenden": "instrumentalisierend",
    "instrumentalisierender": "instrumentalisierend",
    "instrumentalisierendes": "instrumentalisierend",
    "instrumentalisierest": "instrumentalisieren",
    "instrumentalisieret": "instrumentalisieren",
    "instrumentalisierst": "instrumentalisieren",
    "instrumentalisiert": "instrumentalisieren",
    "instrumentalisierte": "instrumentalisieren",
    "instrumentalisiertem": "instrumentalisiert",
    "instrumentalisierten": "instrumentalisieren",
    "instrumentalisierter": "instrumentalisiert",
    "instrumentalisiertes": "instrumentalisiert",
    "instrumentalisiertest": "instrumentalisieren",
    "instrumentalisiertet": "instrumentalisieren",
    "instrumentellem": "instrumentell",
    "instrumentellen": "instrumentell",
    "instrumenteller": "instrumentell",
    "instrumentelles": "instrumentell",
    "instrumentiere": "instrumentieren",
    "instrumentierend": "instrumentieren",
    "instrumentierende": "instrumentierend",
    "instrumentierendem": "instrumentierend",
    "instrumentierenden": "instrumentierend",
    "instrumentierender": "instrumentierend",
    "instrumentierendes": "instrumentierend",
    "instrumentierest": "instrumentieren",
    "instrumentieret": "instrumentieren",
    "instrumentierst": "instrumentieren",
    "instrumentiert": "instrumentieren",
    "instrumentierte": "instrumentieren",
    "instrumentiertem": "instrumentiert",
    "instrumentierten": "instrumentieren",
    "instrumentierter": "instrumentiert",
    "instrumentiertes": "instrumentiert",
    "instrumentiertest": "instrumentieren",
    "instrumentiertet": "instrumentieren",
    "inständigem": "inständig",
    "inständigen": "inständig",
    "inständiger": "inständig",
    "inständiges": "inständig",
    "insuffizientem": "insuffizient",
    "insuffizienten": "insuffizient",
    "insuffizienter": "insuffizient",
    "insuffizientere": "insuffizient",
    "insuffizienterem": "insuffizient",
    "insuffizienteren": "insuffizient",
    "insuffizienterer": "insuffizient",
    "insuffizienteres": "insuffizient",
    "insuffizientes": "insuffizient",
    "insuffizienteste": "insuffizient",
    "insuffizientestem": "insuffizient",
    "insuffizientesten": "insuffizient",
    "insuffizientester": "insuffizient",
    "insuffizientestes": "insuffizient",
    "inszeniere": "inszenieren",
    "inszenierend": "inszenieren",
    "inszenierende": "inszenierend",
    "inszenierendem": "inszenierend",
    "inszenierenden": "inszenierend",
    "inszenierender": "inszenierend",
    "inszenierendes": "inszenierend",
    "inszenierest": "inszenieren",
    "inszenieret": "inszenieren",
    "inszenierst": "inszenieren",
    "inszeniert": "inszenieren",
    "inszenierte": "inszenieren",
    "inszeniertem": "inszeniert",
    "inszenierten": "inszenieren",
    "inszenierter": "inszeniert",
    "inszeniertes": "inszeniert",
    "inszeniertest": "inszenieren",
    "inszeniertet": "inszenieren",
    "intaktem": "intakt",
    "intakten": "intakt",
    "intakter": "intakt",
    "intaktere": "intakt",
    "intakterem": "intakt",
    "intakteren": "intakt",
    "intakterer": "intakt",
    "intakteres": "intakt",
    "intaktes": "intakt",
    "intakteste": "intakt",
    "intaktestem": "intakt",
    "intaktesten": "intakt",
    "intaktester": "intakt",
    "intaktestes": "intakt",
    "integerste": "integer",
    "integerstem": "integer",
    "integersten": "integer",
    "integerster": "integer",
    "integerstes": "integer",
    "integrativem": "integrativ",
    "integrativen": "integrativ",
    "integrativer": "integrativ",
    "integrativere": "integrativ",
    "integrativerem": "integrativ",
    "integrativeren": "integrativ",
    "integrativerer": "integrativ",
    "integrativeres": "integrativ",
    "integratives": "integrativ",
    "integrativste": "integrativ",
    "integrativstem": "integrativ",
    "integrativsten": "integrativ",
    "integrativster": "integrativ",
    "integrativstes": "integrativ",
    "integrem": "integer",
    "integren": "integer",
    "integrer": "integer",
    "integrere": "integer",
    "integrerem": "integer",
    "integreren": "integer",
    "integrerer": "integer",
    "integreres": "integer",
    "integres": "integer",
    "integriere": "integrieren",
    "integrierend": "integrieren",
    "integrierende": "integrierend",
    "integrierendem": "integrierend",
    "integrierenden": "integrierend",
    "integrierender": "integrierend",
    "integrierendes": "integrierend",
    "integrierest": "integrieren",
    "integrieret": "integrieren",
    "integrierst": "integrieren",
    "integriert": "integrieren",
    "integrierte": "integrieren",
    "integriertem": "integriert",
    "integrierten": "integrieren",
    "integrierter": "integriert",
    "integriertere": "integriert",
    "integrierterem": "integriert",
    "integrierteren": "integriert",
    "integrierterer": "integriert",
    "integrierteres": "integriert",
    "integriertes": "integriert",
    "integriertest": "integrieren",
    "integrierteste": "integriert",
    "integriertestem": "integriert",
    "integriertesten": "integriert",
    "integriertester": "integriert",
    "integriertestes": "integriert",
    "integriertet": "integrieren",
    "intellektuelle": "intellektuell",
    "intellektuellem": "intellektuell",
    "intellektuellen": "intellektuell",
    "intellektueller": "intellektuell",
    "intellektuellere": "intellektuell",
    "intellektuellerem": "intellektuell",
    "intellektuelleren": "intellektuell",
    "intellektuellerer": "intellektuell",
    "intellektuelleres": "intellektuell",
    "intellektuelles": "intellektuell",
    "intellektuellste": "intellektuell",
    "intellektuellstem": "intellektuell",
    "intellektuellsten": "intellektuell",
    "intellektuellster": "intellektuell",
    "intellektuellstes": "intellektuell",
    "intelligente": "intelligent",
    "intelligentem": "intelligent",
    "intelligenten": "intelligent",
    "intelligenter": "intelligent",
    "intelligentere": "intelligent",
    "intelligenterem": "intelligent",
    "intelligenteren": "intelligent",
    "intelligenterer": "intelligent",
    "intelligenteres": "intelligent",
    "intelligentes": "intelligent",
    "intelligenteste": "intelligent",
    "intelligentestem": "intelligent",
    "intelligentesten": "intelligent",
    "intelligentester": "intelligent",
    "intelligentestes": "intelligent",
    "intendiere": "intendieren",
    "intendierend": "intendieren",
    "intendierende": "intendierend",
    "intendierendem": "intendierend",
    "intendierenden": "intendierend",
    "intendierender": "intendierend",
    "intendierendes": "intendierend",
    "intendierest": "intendieren",
    "intendieret": "intendieren",
    "intendierst": "intendieren",
    "intendiert": "intendieren",
    "intendierte": "intendieren",
    "intendiertem": "intendiert",
    "intendierten": "intendieren",
    "intendierter": "intendiert",
    "intendiertes": "intendiert",
    "intendiertest": "intendieren",
    "intendiertet": "intendieren",
    "intensivem": "intensiv",
    "intensiven": "intensiv",
    "intensiver": "intensiv",
    "intensivere": "intensiv",
    "intensiverem": "intensiv",
    "intensiveren": "intensiv",
    "intensiverer": "intensiv",
    "intensiveres": "intensiv",
    "intensives": "intensiv",
    "intensivstem": "intensiv",
    "intensivsten": "intensiv",
    "intensivster": "intensiv",
    "intensivstes": "intensiv",
    "intentionale": "intentional",
    "intentionalem": "intentional",
    "intentionalen": "intentional",
    "intentionaler": "intentional",
    "intentionales": "intentional",
    "interaktivem": "interaktiv",
    "interaktiven": "interaktiv",
    "interaktiver": "interaktiv",
    "interaktivere": "interaktiv",
    "interaktiverem": "interaktiv",
    "interaktiveren": "interaktiv",
    "interaktiverer": "interaktiv",
    "interaktiveres": "interaktiv",
    "interaktives": "interaktiv",
    "interaktivste": "interaktiv",
    "interaktivstem": "interaktiv",
    "interaktivsten": "interaktiv",
    "interaktivster": "interaktiv",
    "interaktivstes": "interaktiv",
    "interdisziplinärem": "interdisziplinär",
    "interdisziplinären": "interdisziplinär",
    "interdisziplinärer": "interdisziplinär",
    "interdisziplinäres": "interdisziplinär",
    "interessantem": "interessant",
    "interessanten": "interessant",
    "interessanter": "interessant",
    "interessantere": "interessant",
    "interessanterem": "interessant",
    "interessanteren": "interessant",
    "interessanterer": "interessant",
    "interessanteres": "interessant",
    "interessantes": "interessant",
    "interessanteste": "interessant",
    "interessantestem": "interessant",
    "interessantesten": "interessant",
    "interessantester": "interessant",
    "interessantestes": "interessant",
    "interessiere": "interessieren",
    "interessierend": "interessieren",
    "interessierende": "interessierend",
    "interessierendem": "interessierend",
    "interessierenden": "interessierend",
    "interessierender": "interessierend",
    "interessierendes": "interessierend",
    "interessierest": "interessieren",
    "interessieret": "interessieren",
    "interessierst": "interessieren",
    "interessiert": "interessieren",
    "interessierte": "interessieren",
    "interessiertem": "interessiert",
    "interessierten": "interessieren",
    "interessierter": "interessiert",
    "interessiertere": "interessiert",
    "interessierterem": "interessiert",
    "interessierteren": "interessiert",
    "interessierterer": "interessiert",
    "interessierteres": "interessiert",
    "interessiertes": "interessiert",
    "interessiertest": "interessieren",
    "interessierteste": "interessiert",
    "interessiertestem": "interessiert",
    "interessiertesten": "interessiert",
    "interessiertester": "interessiert",
    "interessiertestes": "interessiert",
    "interessiertet": "interessieren",
    "interfraktionelle": "interfraktionell",
    "interfraktionellem": "interfraktionell",
    "interfraktionellen": "interfraktionell",
    "interfraktioneller": "interfraktionell",
    "interfraktionelles": "interfraktionell",
    "intergalaktische": "intergalaktisch",
    "intergalaktischem": "intergalaktisch",
    "intergalaktischen": "intergalaktisch",
    "intergalaktischer": "intergalaktisch",
    "intergalaktisches": "intergalaktisch",
    "interkonfessionellem": "interkonfessionell",
    "interkonfessionellen": "interkonfessionell",
    "interkonfessioneller": "interkonfessionell",
    "interkonfessionelles": "interkonfessionell",
    "interkontinentale": "interkontinental",
    "interkontinentalem": "interkontinental",
    "interkontinentalen": "interkontinental",
    "interkontinentaler": "interkontinental",
    "interkontinentales": "interkontinental",
    "interkulturelle": "interkulturell",
    "interkulturellem": "interkulturell",
    "interkulturellen": "interkulturell",
    "interkultureller": "interkulturell",
    "interkulturelles": "interkulturell",
    "internalisiere": "internalisieren",
    "internalisierend": "internalisieren",
    "internalisierende": "internalisierend",
    "internalisierendem": "internalisierend",
    "internalisierenden": "internalisierend",
    "internalisierender": "internalisierend",
    "internalisierendes": "internalisierend",
    "internalisierest": "internalisieren",
    "internalisieret": "internalisieren",
    "internalisierst": "internalisieren",
    "internalisiert": "internalisieren",
    "internalisierte": "internalisieren",
    "internalisiertem": "internalisiert",
    "internalisierten": "internalisieren",
    "internalisierter": "internalisiert",
    "internalisiertes": "internalisiert",
    "internalisiertest": "internalisieren",
    "internalisiertet": "internalisieren",
    "internationalem": "international",
    "internationalen": "international",
    "internationaler": "international",
    "internationalere": "international",
    "internationalerem": "international",
    "internationaleren": "international",
    "internationalerer": "international",
    "internationaleres": "international",
    "internationales": "international",
    "internationalste": "international",
    "internationalstem": "international",
    "internationalsten": "international",
    "internationalster": "international",
    "internationalstes": "international",
    "internem": "intern",
    "internen": "intern",
    "interner": "intern",
    "internes": "intern",
    "interniere": "internieren",
    "internierend": "internieren",
    "internierende": "internierend",
    "internierendem": "internierend",
    "internierenden": "internierend",
    "internierender": "internierend",
    "internierendes": "internierend",
    "internierest": "internieren",
    "internieret": "internieren",
    "internierst": "internieren",
    "interniert": "internieren",
    "internierte": "internieren",
    "interniertem": "interniert",
    "internierten": "internieren",
    "internierter": "interniert",
    "interniertes": "interniert",
    "interniertest": "internieren",
    "interniertet": "internieren",
    "interplanetarem": "interplanetar",
    "interplanetaren": "interplanetar",
    "interplanetarer": "interplanetar",
    "interplanetares": "interplanetar",
    "interpoliere": "interpolieren",
    "interpolierend": "interpolieren",
    "interpolierende": "interpolierend",
    "interpolierendem": "interpolierend",
    "interpolierenden": "interpolierend",
    "interpolierender": "interpolierend",
    "interpolierendes": "interpolierend",
    "interpolierest": "interpolieren",
    "interpolieret": "interpolieren",
    "interpolierst": "interpolieren",
    "interpoliert": "interpolieren",
    "interpolierte": "interpolieren",
    "interpoliertem": "interpoliert",
    "interpolierten": "interpolieren",
    "interpolierter": "interpoliert",
    "interpoliertes": "interpoliert",
    "interpoliertest": "interpolieren",
    "interpoliertet": "interpolieren",
    "interpretativem": "interpretativ",
    "interpretativen": "interpretativ",
    "interpretativer": "interpretativ",
    "interpretativere": "interpretativ",
    "interpretativerem": "interpretativ",
    "interpretativeren": "interpretativ",
    "interpretativerer": "interpretativ",
    "interpretativeres": "interpretativ",
    "interpretatives": "interpretativ",
    "interpretativste": "interpretativ",
    "interpretativstem": "interpretativ",
    "interpretativsten": "interpretativ",
    "interpretativster": "interpretativ",
    "interpretativstes": "interpretativ",
    "interpretiere": "interpretieren",
    "interpretierend": "interpretieren",
    "interpretierende": "interpretierend",
    "interpretierendem": "interpretierend",
    "interpretierenden": "interpretierend",
    "interpretierender": "interpretierend",
    "interpretierendes": "interpretierend",
    "interpretierest": "interpretieren",
    "interpretieret": "interpretieren",
    "interpretierst": "interpretieren",
    "interpretiert": "interpretieren",
    "interpretierte": "interpretieren",
    "interpretiertem": "interpretiert",
    "interpretierten": "interpretieren",
    "interpretierter": "interpretiert",
    "interpretiertes": "interpretiert",
    "interpretiertest": "interpretieren",
    "interpretiertet": "interpretieren",
    "interpunktiere": "interpunktieren",
    "interpunktierend": "interpunktieren",
    "interpunktierende": "interpunktierend",
    "interpunktierendem": "interpunktierend",
    "interpunktierenden": "interpunktierend",
    "interpunktierender": "interpunktierend",
    "interpunktierendes": "interpunktierend",
    "interpunktierest": "interpunktieren",
    "interpunktieret": "interpunktieren",
    "interpunktierst": "interpunktieren",
    "interpunktiert": "interpunktieren",
    "interpunktierte": "interpunktieren",
    "interpunktiertem": "interpunktiert",
    "interpunktierten": "interpunktieren",
    "interpunktierter": "interpunktiert",
    "interpunktiertes": "interpunktiert",
    "interpunktiertest": "interpunktieren",
    "interpunktiertet": "interpunktieren",
    "interrogativem": "interrogativ",
    "interrogativen": "interrogativ",
    "interrogativer": "interrogativ",
    "interrogatives": "interrogativ",
    "intersexuellem": "intersexuell",
    "intersexuellen": "intersexuell",
    "intersexueller": "intersexuell",
    "intersexuelles": "intersexuell",
    "interstellare": "interstellar",
    "interstellarem": "interstellar",
    "interstellaren": "interstellar",
    "interstellarer": "interstellar",
    "interstellares": "interstellar",
    "interterritoriale": "interterritorial",
    "interterritorialem": "interterritorial",
    "interterritorialen": "interterritorial",
    "interterritorialer": "interterritorial",
    "interterritoriales": "interterritorial",
    "interveniere": "intervenieren",
    "intervenierend": "intervenieren",
    "intervenierende": "intervenierend",
    "intervenierendem": "intervenierend",
    "intervenierenden": "intervenierend",
    "intervenierender": "intervenierend",
    "intervenierendes": "intervenierend",
    "intervenierest": "intervenieren",
    "intervenieret": "intervenieren",
    "intervenierst": "intervenieren",
    "interveniert": "intervenieren",
    "intervenierte": "intervenieren",
    "interveniertem": "interveniert",
    "intervenierten": "intervenieren",
    "intervenierter": "interveniert",
    "interveniertes": "interveniert",
    "interveniertest": "intervenieren",
    "interveniertet": "intervenieren",
    "inthronisiere": "inthronisieren",
    "inthronisierend": "inthronisieren",
    "inthronisierende": "inthronisierend",
    "inthronisierendem": "inthronisierend",
    "inthronisierenden": "inthronisierend",
    "inthronisierender": "inthronisierend",
    "inthronisierendes": "inthronisierend",
    "inthronisierest": "inthronisieren",
    "inthronisieret": "inthronisieren",
    "inthronisierst": "inthronisieren",
    "inthronisiert": "inthronisieren",
    "inthronisierte": "inthronisieren",
    "inthronisiertem": "inthronisiert",
    "inthronisierten": "inthronisieren",
    "inthronisierter": "inthronisiert",
    "inthronisiertes": "inthronisiert",
    "inthronisiertest": "inthronisieren",
    "inthronisiertet": "inthronisieren",
    "intimem": "intim",
    "intimen": "intim",
    "intimer": "intim",
    "intimere": "intim",
    "intimerem": "intim",
    "intimeren": "intim",
    "intimerer": "intim",
    "intimeres": "intim",
    "intimes": "intim",
    "intimstem": "intim",
    "intimsten": "intim",
    "intimster": "intim",
    "intimstes": "intim",
    "intolerantem": "intolerant",
    "intoleranten": "intolerant",
    "intoleranter": "intolerant",
    "intolerantere": "intolerant",
    "intoleranterem": "intolerant",
    "intoleranteren": "intolerant",
    "intoleranterer": "intolerant",
    "intoleranteres": "intolerant",
    "intolerantes": "intolerant",
    "intoleranteste": "intolerant",
    "intolerantestem": "intolerant",
    "intolerantesten": "intolerant",
    "intolerantester": "intolerant",
    "intolerantestes": "intolerant",
    "intoniere": "intonieren",
    "intonierend": "intonieren",
    "intonierende": "intonierend",
    "intonierendem": "intonierend",
    "intonierenden": "intonierend",
    "intonierender": "intonierend",
    "intonierendes": "intonierend",
    "intonierest": "intonieren",
    "intonieret": "intonieren",
    "intonierst": "intonieren",
    "intoniert": "intonieren",
    "intonierte": "intonieren",
    "intoniertem": "intoniert",
    "intonierten": "intonieren",
    "intonierter": "intoniert",
    "intoniertes": "intoniert",
    "intoniertest": "intonieren",
    "intoniertet": "intonieren",
    "intralinguale": "intralingual",
    "intralingualem": "intralingual",
    "intralingualen": "intralingual",
    "intralingualer": "intralingual",
    "intralinguales": "intralingual",
    "intramolekulare": "intramolekular",
    "intramolekularem": "intramolekular",
    "intramolekularen": "intramolekular",
    "intramolekularer": "intramolekular",
    "intramolekulares": "intramolekular",
    "intramuskuläre": "intramuskulär",
    "intramuskulärem": "intramuskulär",
    "intramuskulären": "intramuskulär",
    "intramuskulärer": "intramuskulär",
    "intramuskuläres": "intramuskulär",
    "intransitive": "intransitiv",
    "intransitivem": "intransitiv",
    "intransitiven": "intransitiv",
    "intransitiver": "intransitiv",
    "intransitives": "intransitiv",
    "intrazellulare": "intrazellular",
    "intrazellularem": "intrazellular",
    "intrazellularen": "intrazellular",
    "intrazellularer": "intrazellular",
    "intrazellulares": "intrazellular",
    "intrigante": "intrigant",
    "intrigantem": "intrigant",
    "intriganten": "intrigant",
    "intriganter": "intrigant",
    "intrigantes": "intrigant",
    "intrigiere": "intrigieren",
    "intrigierend": "intrigieren",
    "intrigierende": "intrigierend",
    "intrigierendem": "intrigierend",
    "intrigierenden": "intrigierend",
    "intrigierender": "intrigierend",
    "intrigierendes": "intrigierend",
    "intrigierest": "intrigieren",
    "intrigieret": "intrigieren",
    "intrigierst": "intrigieren",
    "intrigiert": "intrigieren",
    "intrigierte": "intrigieren",
    "intrigiertem": "intrigiert",
    "intrigierten": "intrigieren",
    "intrigierter": "intrigiert",
    "intrigiertes": "intrigiert",
    "intrigiertest": "intrigieren",
    "intrigiertet": "intrigieren",
    "intrinsische": "intrinsisch",
    "intrinsischem": "intrinsisch",
    "intrinsischen": "intrinsisch",
    "intrinsischer": "intrinsisch",
    "intrinsisches": "intrinsisch",
    "intuitivem": "intuitiv",
    "intuitiven": "intuitiv",
    "intuitiver": "intuitiv",
    "intuitivere": "intuitiv",
    "intuitiverem": "intuitiv",
    "intuitiveren": "intuitiv",
    "intuitiverer": "intuitiv",
    "intuitiveres": "intuitiv",
    "intuitives": "intuitiv",
    "intuitivste": "intuitiv",
    "intuitivstem": "intuitiv",
    "intuitivsten": "intuitiv",
    "intuitivster": "intuitiv",
    "intuitivstes": "intuitiv",
    "investiere": "investieren",
    "investierend": "investieren",
    "investierende": "investierend",
    "investierendem": "investierend",
    "investierenden": "investierend",
    "investierender": "investierend",
    "investierendes": "investierend",
    "investierest": "investieren",
    "investieret": "investieren",
    "investierst": "investieren",
    "investiert": "investieren",
    "investierte": "investieren",
    "investiertem": "investiert",
    "investierten": "investieren",
    "investierter": "investiert",
    "investiertes": "investiert",
    "investiertest": "investieren",
    "investiertet": "investieren",
    "involviere": "involvieren",
    "involvierend": "involvieren",
    "involvierende": "involvierend",
    "involvierendem": "involvierend",
    "involvierenden": "involvierend",
    "involvierender": "involvierend",
    "involvierendere": "involvierend",
    "involvierenderem": "involvierend",
    "involvierenderen": "involvierend",
    "involvierenderer": "involvierend",
    "involvierenderes": "involvierend",
    "involvierendes": "involvierend",
    "involvierendste": "involvierend",
    "involvierendstem": "involvierend",
    "involvierendsten": "involvierend",
    "involvierendster": "involvierend",
    "involvierendstes": "involvierend",
    "involvierest": "involvieren",
    "involvieret": "involvieren",
    "involvierst": "involvieren",
    "involviert": "involvieren",
    "involvierte": "involvieren",
    "involviertem": "involviert",
    "involvierten": "involvieren",
    "involvierter": "involviert",
    "involviertere": "involviert",
    "involvierterem": "involviert",
    "involvierteren": "involviert",
    "involvierterer": "involviert",
    "involvierteres": "involviert",
    "involviertes": "involviert",
    "involviertest": "involvieren",
    "involvierteste": "involviert",
    "involviertestem": "involviert",
    "involviertesten": "involviert",
    "involviertester": "involviert",
    "involviertestes": "involviert",
    "involviertet": "involvieren",
    "ionisiere": "ionisieren",
    "ionisierend": "ionisieren",
    "ionisierende": "ionisierend",
    "ionisierendem": "ionisierend",
    "ionisierenden": "ionisierend",
    "ionisierender": "ionisierend",
    "ionisierendes": "ionisierend",
    "ionisierest": "ionisieren",
    "ionisieret": "ionisieren",
    "ionisierst": "ionisieren",
    "ionisiert": "ionisieren",
    "ionisierte": "ionisieren",
    "ionisiertem": "ionisiert",
    "ionisierten": "ionisieren",
    "ionisierter": "ionisiert",
    "ionisiertes": "ionisiert",
    "ionisiertest": "ionisieren",
    "ionisiertet": "ionisieren",
    "irakischem": "irakisch",
    "irakischen": "irakisch",
    "irakischer": "irakisch",
    "irakisches": "irakisch",
    "iranischem": "iranisch",
    "iranischen": "iranisch",
    "iranischer": "iranisch",
    "iranisches": "iranisch",
    "irdischem": "irdisch",
    "irdischen": "irdisch",
    "irdischer": "irdisch",
    "irdischere": "irdisch",
    "irdischerem": "irdisch",
    "irdischeren": "irdisch",
    "irdischerer": "irdisch",
    "irdischeres": "irdisch",
    "irdisches": "irdisch",
    "irdischste": "irdisch",
    "irdischstem": "irdisch",
    "irdischsten": "irdisch",
    "irdischster": "irdisch",
    "irdischstes": "irdisch",
    "irischem": "irisch",
    "irischen": "irisch",
    "irischer": "irisch",
    "irisches": "irisch",
    "irländischem": "irländisch",
    "irländischen": "irländisch",
    "irländischer": "irländisch",
    "irländisches": "irländisch",
    "irokesischem": "irokesisch",
    "irokesischen": "irokesisch",
    "irokesischer": "irokesisch",
    "irokesisches": "irokesisch",
    "ironische": "ironisch",
    "ironischem": "ironisch",
    "ironischen": "ironisch",
    "ironischer": "ironisch",
    "ironischere": "ironisch",
    "ironischerem": "ironisch",
    "ironischeren": "ironisch",
    "ironischerer": "ironisch",
    "ironischeres": "ironisch",
    "ironisches": "ironisch",
    "ironischste": "ironisch",
    "ironischstem": "ironisch",
    "ironischsten": "ironisch",
    "ironischster": "ironisch",
    "ironischstes": "ironisch",
    "irrationale": "irrational",
    "irrationalem": "irrational",
    "irrationalen": "irrational",
    "irrationaler": "irrational",
    "irrationalere": "irrational",
    "irrationalerem": "irrational",
    "irrationaleren": "irrational",
    "irrationalerer": "irrational",
    "irrationaleres": "irrational",
    "irrationales": "irrational",
    "irrationalste": "irrational",
    "irrationalstem": "irrational",
    "irrationalsten": "irrational",
    "irrationalster": "irrational",
    "irrationalstes": "irrational",
    "irre": "irren",
    "irrealem": "irreal",
    "irrealen": "irreal",
    "irrealer": "irreal",
    "irrealere": "irreal",
    "irrealerem": "irreal",
    "irrealeren": "irreal",
    "irrealerer": "irreal",
    "irrealeres": "irreal",
    "irreales": "irreal",
    "irrealste": "irreal",
    "irrealstem": "irreal",
    "irrealsten": "irreal",
    "irrealster": "irreal",
    "irrealstes": "irreal",
    "irreduziblem": "irreduzibel",
    "irreduziblen": "irreduzibel",
    "irreduzibler": "irreduzibel",
    "irreduzibles": "irreduzibel",
    "irreführe": "irreführen",
    "irreführend": "irreführen",
    "irreführende": "irreführend",
    "irreführendem": "irreführend",
    "irreführenden": "irreführend",
    "irreführender": "irreführend",
    "irreführendes": "irreführend",
    "irreführest": "irreführen",
    "irreführet": "irreführen",
    "irreführst": "irreführen",
    "irreführt": "irreführen",
    "irreführte": "irreführen",
    "irreführten": "irreführen",
    "irreführtest": "irreführen",
    "irreführtet": "irreführen",
    "irregeführt": "irreführen",
    "irregeführte": "irregeführt",
    "irregeführtem": "irregeführt",
    "irregeführten": "irregeführt",
    "irregeführter": "irregeführt",
    "irregeführtes": "irregeführt",
    "irregeleitet": "irreleiten",
    "irregeleitete": "irregeleitet",
    "irregeleitetem": "irregeleitet",
    "irregeleiteten": "irregeleitet",
    "irregeleiteter": "irregeleitet",
    "irregeleitetes": "irregeleitet",
    "irreguläre": "irregulär",
    "irregulärem": "irregulär",
    "irregulären": "irregulär",
    "irregulärer": "irregulär",
    "irreguläres": "irregulär",
    "irreleite": "irreleiten",
    "irreleitend": "irreleiten",
    "irreleitende": "irreleitend",
    "irreleitendem": "irreleitend",
    "irreleitenden": "irreleitend",
    "irreleitender": "irreleitend",
    "irreleitendes": "irreleitend",
    "irreleitest": "irreleiten",
    "irreleitet": "irreleiten",
    "irreleitete": "irreleiten",
    "irreleiteten": "irreleiten",
    "irreleitetest": "irreleiten",
    "irreleitetet": "irreleiten",
    "irrend": "irren",
    "irrende": "irrend",
    "irrendem": "irrend",
    "irrenden": "irrend",
    "irrender": "irrend",
    "irrendes": "irrend",
    "irreparabelstem": "irreparabel",
    "irreparabelsten": "irreparabel",
    "irreparabelster": "irreparabel",
    "irreparabelstes": "irreparabel",
    "irreparable": "irreparabel",
    "irreparablem": "irreparabel",
    "irreparablen": "irreparabel",
    "irreparabler": "irreparabel",
    "irreparablere": "irreparabel",
    "irreparablerem": "irreparabel",
    "irreparableren": "irreparabel",
    "irreparablerer": "irreparabel",
    "irreparableres": "irreparabel",
    "irreparables": "irreparabel",
    "irrest": "irren",
    "irret": "irren",
    "irreversibelste": "irreversibel",
    "irreversibelstem": "irreversibel",
    "irreversibelsten": "irreversibel",
    "irreversibelster": "irreversibel",
    "irreversibelstes": "irreversibel",
    "irreversible": "irreversibel",
    "irreversiblem": "irreversibel",
    "irreversiblen": "irreversibel",
    "irreversibler": "irreversibel",
    "irreversiblere": "irreversibel",
    "irreversiblerem": "irreversibel",
    "irreversibleren": "irreversibel",
    "irreversiblerer": "irreversibel",
    "irreversibleres": "irreversibel",
    "irreversibles": "irreversibel",
    "irrezuführen": "irreführen",
    "irrezuleiten": "irreleiten",
    "irrgläubigem": "irrgläubig",
    "irrgläubigen": "irrgläubig",
    "irrgläubiger": "irrgläubig",
    "irrgläubigere": "irrgläubig",
    "irrgläubigerem": "irrgläubig",
    "irrgläubigeren": "irrgläubig",
    "irrgläubigerer": "irrgläubig",
    "irrgläubigeres": "irrgläubig",
    "irrgläubiges": "irrgläubig",
    "irrgläubigste": "irrgläubig",
    "irrgläubigstem": "irrgläubig",
    "irrgläubigsten": "irrgläubig",
    "irrgläubigster": "irrgläubig",
    "irrgläubigstes": "irrgläubig",
    "irritiere": "irritieren",
    "irritierend": "irritieren",
    "irritierende": "irritierend",
    "irritierendem": "irritierend",
    "irritierenden": "irritierend",
    "irritierender": "irritierend",
    "irritierendere": "irritierend",
    "irritierenderem": "irritierend",
    "irritierenderen": "irritierend",
    "irritierenderer": "irritierend",
    "irritierenderes": "irritierend",
    "irritierendes": "irritierend",
    "irritierendste": "irritierend",
    "irritierendstem": "irritierend",
    "irritierendsten": "irritierend",
    "irritierendster": "irritierend",
    "irritierendstes": "irritierend",
    "irritierest": "irritieren",
    "irritieret": "irritieren",
    "irritierst": "irritieren",
    "irritiert": "irritieren",
    "irritierte": "irritieren",
    "irritiertem": "irritiert",
    "irritierten": "irritieren",
    "irritierter": "irritiert",
    "irritiertere": "irritiert",
    "irritierterem": "irritiert",
    "irritierteren": "irritiert",
    "irritierterer": "irritiert",
    "irritierteres": "irritiert",
    "irritiertes": "irritiert",
    "irritiertest": "irritieren",
    "irritierteste": "irritiert",
    "irritiertestem": "irritiert",
    "irritiertesten": "irritiert",
    "irritiertester": "irritiert",
    "irritiertestes": "irritiert",
    "irritiertet": "irritieren",
    "irrsinnigem": "irrsinnig",
    "irrsinnigen": "irrsinnig",
    "irrsinniger": "irrsinnig",
    "irrsinnigere": "irrsinnig",
    "irrsinnigerem": "irrsinnig",
    "irrsinnigeren": "irrsinnig",
    "irrsinnigerer": "irrsinnig",
    "irrsinnigeres": "irrsinnig",
    "irrsinniges": "irrsinnig",
    "irrsinnigste": "irrsinnig",
    "irrsinnigstem": "irrsinnig",
    "irrsinnigsten": "irrsinnig",
    "irrsinnigster": "irrsinnig",
    "irrsinnigstes": "irrsinnig",
    "irrst": "irren",
    "irrt": "irren",
    "irrte": "irren",
    "irrten": "irren",
    "irrtest": "irren",
    "irrtet": "irren",
    "irrtümlichem": "irrtümlich",
    "irrtümlichen": "irrtümlich",
    "irrtümlicher": "irrtümlich",
    "irrtümliches": "irrtümlich",
    "islamischem": "islamisch",
    "islamischen": "islamisch",
    "islamischer": "islamisch",
    "islamisches": "islamisch",
    "islamisiere": "islamisieren",
    "islamisierend": "islamisieren",
    "islamisierende": "islamisierend",
    "islamisierendem": "islamisierend",
    "islamisierenden": "islamisierend",
    "islamisierender": "islamisierend",
    "islamisierendes": "islamisierend",
    "islamisierest": "islamisieren",
    "islamisieret": "islamisieren",
    "islamisierst": "islamisieren",
    "islamisiert": "islamisieren",
    "islamisierte": "islamisieren",
    "islamisiertem": "islamisiert",
    "islamisierten": "islamisieren",
    "islamisierter": "islamisiert",
    "islamisiertes": "islamisiert",
    "islamisiertest": "islamisieren",
    "islamisiertet": "islamisieren",
    "isländischem": "isländisch",
    "isländischen": "isländisch",
    "isländischer": "isländisch",
    "isländisches": "isländisch",
    "isoliere": "isolieren",
    "isolierend": "isolieren",
    "isolierende": "isolierend",
    "isolierendem": "isolierend",
    "isolierenden": "isolierend",
    "isolierender": "isolierend",
    "isolierendere": "isolierend",
    "isolierenderem": "isolierend",
    "isolierenderen": "isolierend",
    "isolierenderer": "isolierend",
    "isolierenderes": "isolierend",
    "isolierendes": "isolierend",
    "isolierendste": "isolierend",
    "isolierendstem": "isolierend",
    "isolierendsten": "isolierend",
    "isolierendster": "isolierend",
    "isolierendstes": "isolierend",
    "isolierest": "isolieren",
    "isolieret": "isolieren",
    "isolierst": "isolieren",
    "isoliert": "isolieren",
    "isolierte": "isolieren",
    "isoliertem": "isoliert",
    "isolierten": "isolieren",
    "isolierter": "isoliert",
    "isoliertere": "isoliert",
    "isolierterem": "isoliert",
    "isolierteren": "isoliert",
    "isolierterer": "isoliert",
    "isolierteres": "isoliert",
    "isoliertes": "isoliert",
    "isoliertest": "isolieren",
    "isolierteste": "isoliert",
    "isoliertestem": "isoliert",
    "isoliertesten": "isoliert",
    "isoliertester": "isoliert",
    "isoliertestes": "isoliert",
    "isoliertet": "isolieren",
    "isomorphem": "isomorph",
    "isomorphen": "isomorph",
    "isomorpher": "isomorph",
    "isomorphes": "isomorph",
    "isotonische": "isotonisch",
    "isotonischem": "isotonisch",
    "isotonischen": "isotonisch",
    "isotonischer": "isotonisch",
    "isotonisches": "isotonisch",
    "israelischem": "israelisch",
    "israelischen": "israelisch",
    "israelischer": "israelisch",
    "israelisches": "israelisch",
    "israelitischem": "israelitisch",
    "israelitischen": "israelitisch",
    "israelitischer": "israelitisch",
    "israelitisches": "israelitisch",
    "ist": "sein",
    "italienischem": "italienisch",
    "italienischen": "italienisch",
    "italienischer": "italienisch",
    "italienischere": "italienisch",
    "italienischerem": "italienisch",
    "italienischeren": "italienisch",
    "italienischerer": "italienisch",
    "italienischeres": "italienisch",
    "italienisches": "italienisch",
    "italienischste": "italienisch",
    "italienischstem": "italienisch",
    "italienischsten": "italienisch",
    "italienischster": "italienisch",
    "italienischstes": "italienisch",
    "iterativem": "iterativ",
    "iterativen": "iterativ",
    "iterativer": "iterativ",
    "iteratives": "iterativ",
    "iß": "essen",
    "ißt": "essen",
    "jagdberechtigtem": "jagdberechtigt",
    "jagdberechtigten": "jagdberechtigt",
    "jagdberechtigter": "jagdberechtigt",
    "jagdberechtigtes": "jagdberechtigt",
    "jage": "jagen",
    "jagend": "jagen",
    "jagende": "jagend",
    "jagendem": "jagend",
    "jagenden": "jagend",
    "jagender": "jagend",
    "jagendere": "jagend",
    "jagenderem": "jagend",
    "jagenderen": "jagend",
    "jagenderer": "jagend",
    "jagenderes": "jagend",
    "jagendes": "jagend",
    "jagendste": "jagend",
    "jagendstem": "jagend",
    "jagendsten": "jagend",
    "jagendster": "jagend",
    "jagendstes": "jagend",
    "jagest": "jagen",
    "jaget": "jagen",
    "jagst": "jagen",
    "jagt": "jagen",
    "jagte": "jagen",
    "jagten": "jagen",
    "jagtest": "jagen",
    "jagtet": "jagen",
    "jahrelangem": "jahrelang",
    "jahrelangen": "jahrelang",
    "jahrelanger": "jahrelang",
    "jahrelanges": "jahrelang",
    "jahreszeitlichem": "jahreszeitlich",
    "jahreszeitlichen": "jahreszeitlich",
    "jahreszeitlicher": "jahreszeitlich",
    "jahreszeitliches": "jahreszeitlich",
    "jahrhundertealtem": "jahrhundertealt",
    "jahrhundertealten": "jahrhundertealt",
    "jahrhundertealter": "jahrhundertealt",
    "jahrhundertealtes": "jahrhundertealt",
    "jahrhundertelange": "jahrhundertelang",
    "jahrhundertelangem": "jahrhundertelang",
    "jahrhundertelangen": "jahrhundertelang",
    "jahrhundertelanger": "jahrhundertelang",
    "jahrhundertelanges": "jahrhundertelang",
    "jahrzehntelangem": "jahrzehntelang",
    "jahrzehntelangen": "jahrzehntelang",
    "jahrzehntelanger": "jahrzehntelang",
    "jahrzehntelanges": "jahrzehntelang",
    "jammere": "jammern",
    "jammernd": "jammern",
    "jammernde": "jammernd",
    "jammerndem": "jammernd",
    "jammernden": "jammernd",
    "jammernder": "jammernd",
    "jammerndere": "jammernd",
    "jammernderem": "jammernd",
    "jammernderen": "jammernd",
    "jammernderer": "jammernd",
    "jammernderes": "jammernd",
    "jammerndes": "jammernd",
    "jammerndste": "jammernd",
    "jammerndstem": "jammernd",
    "jammerndsten": "jammernd",
    "jammerndster": "jammernd",
    "jammerndstes": "jammernd",
    "jammerst": "jammern",
    "jammert": "jammern",
    "jammerte": "jammern",
    "jammerten": "jammern",
    "jammertest": "jammern",
    "jammertet": "jammern",
    "jammervolle": "jammervoll",
    "jammervollem": "jammervoll",
    "jammervollen": "jammervoll",
    "jammervoller": "jammervoll",
    "jammervollere": "jammervoll",
    "jammervollerem": "jammervoll",
    "jammervolleren": "jammervoll",
    "jammervollerer": "jammervoll",
    "jammervolleres": "jammervoll",
    "jammervolles": "jammervoll",
    "jammervollste": "jammervoll",
    "jammervollstem": "jammervoll",
    "jammervollsten": "jammervoll",
    "jammervollster": "jammervoll",
    "jammervollstes": "jammervoll",
    "japanischem": "japanisch",
    "japanischen": "japanisch",
    "japanischer": "japanisch",
    "japanischere": "japanisch",
    "japanischerem": "japanisch",
    "japanischeren": "japanisch",
    "japanischerer": "japanisch",
    "japanischeres": "japanisch",
    "japanisches": "japanisch",
    "japanischste": "japanisch",
    "japanischstem": "japanisch",
    "japanischsten": "japanisch",
    "japanischster": "japanisch",
    "japanischstes": "japanisch",
    "japse": "japsen",
    "japsend": "japsen",
    "japsende": "japsend",
    "japsendem": "japsend",
    "japsenden": "japsend",
    "japsender": "japsend",
    "japsendere": "japsend",
    "japsenderem": "japsend",
    "japsenderen": "japsend",
    "japsenderer": "japsend",
    "japsenderes": "japsend",
    "japsendes": "japsend",
    "japsendste": "japsend",
    "japsendstem": "japsend",
    "japsendsten": "japsend",
    "japsendster": "japsend",
    "japsendstes": "japsend",
    "japsest": "japsen",
    "japset": "japsen",
    "japst": "japsen",
    "japste": "japsen",
    "japsten": "japsen",
    "japstest": "japsen",
    "japstet": "japsen",
    "jauchze": "jauchzen",
    "jauchzend": "jauchzen",
    "jauchzende": "jauchzend",
    "jauchzendem": "jauchzend",
    "jauchzenden": "jauchzend",
    "jauchzender": "jauchzend",
    "jauchzendere": "jauchzend",
    "jauchzenderem": "jauchzend",
    "jauchzenderen": "jauchzend",
    "jauchzenderer": "jauchzend",
    "jauchzenderes": "jauchzend",
    "jauchzendes": "jauchzend",
    "jauchzendste": "jauchzend",
    "jauchzendstem": "jauchzend",
    "jauchzendsten": "jauchzend",
    "jauchzendster": "jauchzend",
    "jauchzendstes": "jauchzend",
    "jauchzest": "jauchzen",
    "jauchzet": "jauchzen",
    "jauchzt": "jauchzen",
    "jauchzte": "jauchzen",
    "jauchzten": "jauchzen",
    "jauchztest": "jauchzen",
    "jauchztet": "jauchzen",
    "jaule": "jaulen",
    "jaulend": "jaulen",
    "jaulende": "jaulend",
    "jaulendem": "jaulend",
    "jaulenden": "jaulend",
    "jaulender": "jaulend",
    "jaulendes": "jaulend",
    "jaulest": "jaulen",
    "jaulet": "jaulen",
    "jaulst": "jaulen",
    "jault": "jaulen",
    "jaulte": "jaulen",
    "jaulten": "jaulen",
    "jaultest": "jaulen",
    "jaultet": "jaulen",
    "jeckem": "jeck",
    "jecken": "jeck",
    "jecker": "jeck",
    "jeckere": "jeck",
    "jeckerem": "jeck",
    "jeckeren": "jeck",
    "jeckerer": "jeck",
    "jeckeres": "jeck",
    "jeckes": "jeck",
    "jeckste": "jeck",
    "jeckstem": "jeck",
    "jecksten": "jeck",
    "jeckster": "jeck",
    "jeckstes": "jeck",
    "jede": "jed",
    "jedem": "jed",
    "jeden": "jed",
    "jeder": "jed",
    "jedes": "jed",
    "jedwede": "jedwed",
    "jedwedem": "jedwed",
    "jedweden": "jedwed",
    "jedweder": "jedwed",
    "jedwedes": "jedwed",
    "jegliche": "jeglich",
    "jeglichem": "jeglich",
    "jeglichen": "jeglich",
    "jeglicher": "jeglich",
    "jegliches": "jeglich",
    "jemandem": "jemand",
    "jemanden": "jemand",
    "jemandes": "jemand",
    "jemands": "jemand",
    "jene": "jen",
    "jenem": "jen",
    "jenen": "jen",
    "jener": "jen",
    "jenes": "jen",
    "jetzigem": "jetzig",
    "jetzigen": "jetzig",
    "jetziger": "jetzig",
    "jetziges": "jetzig",
    "jeweilige": "jeweilig",
    "jeweiligem": "jeweilig",
    "jeweiligen": "jeweilig",
    "jeweiliger": "jeweilig",
    "jeweiliges": "jeweilig",
    "jobbe": "jobben",
    "jobbend": "jobben",
    "jobbende": "jobbend",
    "jobbendem": "jobbend",
    "jobbenden": "jobbend",
    "jobbender": "jobbend",
    "jobbendes": "jobbend",
    "jobbest": "jobben",
    "jobbet": "jobben",
    "jobbst": "jobben",
    "jobbt": "jobben",
    "jobbte": "jobben",
    "jobbten": "jobben",
    "jobbtest": "jobben",
    "jobbtet": "jobben",
    "jodele": "jodeln",
    "jodelnd": "jodeln",
    "jodelnde": "jodelnd",
    "jodelndem": "jodelnd",
    "jodelnden": "jodelnd",
    "jodelnder": "jodelnd",
    "jodelndere": "jodelnd",
    "jodelnderem": "jodelnd",
    "jodelnderen": "jodelnd",
    "jodelnderer": "jodelnd",
    "jodelnderes": "jodelnd",
    "jodelndes": "jodelnd",
    "jodelndste": "jodelnd",
    "jodelndstem": "jodelnd",
    "jodelndsten": "jodelnd",
    "jodelndster": "jodelnd",
    "jodelndstes": "jodelnd",
    "jodelst": "jodeln",
    "jodelt": "jodeln",
    "jodelte": "jodeln",
    "jodelten": "jodeln",
    "jodeltest": "jodeln",
    "jodeltet": "jodeln",
    "jodle": "jodeln",
    "johle": "johlen",
    "johlend": "johlen",
    "johlende": "johlend",
    "johlendem": "johlend",
    "johlenden": "johlend",
    "johlender": "johlend",
    "johlendere": "johlend",
    "johlenderem": "johlend",
    "johlenderen": "johlend",
    "johlenderer": "johlend",
    "johlenderes": "johlend",
    "johlendes": "johlend",
    "johlendste": "johlend",
    "johlendstem": "johlend",
    "johlendsten": "johlend",
    "johlendster": "johlend",
    "johlendstes": "johlend",
    "johlest": "johlen",
    "johlet": "johlen",
    "johlst": "johlen",
    "johlt": "johlen",
    "johlte": "johlen",
    "johlten": "johlen",
    "johltest": "johlen",
    "johltet": "johlen",
    "jubele": "jubeln",
    "jubelnd": "jubeln",
    "jubelnde": "jubelnd",
    "jubelndem": "jubelnd",
    "jubelnden": "jubelnd",
    "jubelnder": "jubelnd",
    "jubelndere": "jubelnd",
    "jubelnderem": "jubelnd",
    "jubelnderen": "jubelnd",
    "jubelnderer": "jubelnd",
    "jubelnderes": "jubelnd",
    "jubelndes": "jubelnd",
    "jubelndste": "jubelnd",
    "jubelndstem": "jubelnd",
    "jubelndsten": "jubelnd",
    "jubelndster": "jubelnd",
    "jubelndstes": "jubelnd",
    "jubelst": "jubeln",
    "jubelt": "jubeln",
    "jubelte": "jubeln",
    "jubelten": "jubeln",
    "jubeltest": "jubeln",
    "jubeltet": "jubeln",
    "jubiliere": "jubilieren",
    "jubilierend": "jubilieren",
    "jubilierende": "jubilierend",
    "jubilierendem": "jubilierend",
    "jubilierenden": "jubilierend",
    "jubilierender": "jubilierend",
    "jubilierendere": "jubilierend",
    "jubilierenderem": "jubilierend",
    "jubilierenderen": "jubilierend",
    "jubilierenderer": "jubilierend",
    "jubilierenderes": "jubilierend",
    "jubilierendes": "jubilierend",
    "jubilierendste": "jubilierend",
    "jubilierendstem": "jubilierend",
    "jubilierendsten": "jubilierend",
    "jubilierendster": "jubilierend",
    "jubilierendstes": "jubilierend",
    "jubilierest": "jubilieren",
    "jubilieret": "jubilieren",
    "jubilierst": "jubilieren",
    "jubiliert": "jubilieren",
    "jubilierte": "jubilieren",
    "jubiliertem": "jubiliert",
    "jubilierten": "jubilieren",
    "jubilierter": "jubiliert",
    "jubiliertes": "jubiliert",
    "jubiliertest": "jubilieren",
    "jubiliertet": "jubilieren",
    "juble": "jubeln",
    "juchze": "juchzen",
    "juchzend": "juchzen",
    "juchzende": "juchzend",
    "juchzendem": "juchzend",
    "juchzenden": "juchzend",
    "juchzender": "juchzend",
    "juchzendere": "juchzend",
    "juchzenderem": "juchzend",
    "juchzenderen": "juchzend",
    "juchzenderer": "juchzend",
    "juchzenderes": "juchzend",
    "juchzendes": "juchzend",
    "juchzendste": "juchzend",
    "juchzendstem": "juchzend",
    "juchzendsten": "juchzend",
    "juchzendster": "juchzend",
    "juchzendstes": "juchzend",
    "juchzest": "juchzen",
    "juchzet": "juchzen",
    "juchzt": "juchzen",
    "juchzte": "juchzen",
    "juchzten": "juchzen",
    "juchztest": "juchzen",
    "juchztet": "juchzen",
    "jugendfreiem": "jugendfrei",
    "jugendfreien": "jugendfrei",
    "jugendfreier": "jugendfrei",
    "jugendfreies": "jugendfrei",
    "jugendgefährdendem": "jugendgefährdend",
    "jugendgefährdenden": "jugendgefährdend",
    "jugendgefährdender": "jugendgefährdend",
    "jugendgefährdendere": "jugendgefährdend",
    "jugendgefährdenderem": "jugendgefährdend",
    "jugendgefährdenderen": "jugendgefährdend",
    "jugendgefährdenderer": "jugendgefährdend",
    "jugendgefährdenderes": "jugendgefährdend",
    "jugendgefährdendes": "jugendgefährdend",
    "jugendgefährdendste": "jugendgefährdend",
    "jugendgefährdendstem": "jugendgefährdend",
    "jugendgefährdendsten": "jugendgefährdend",
    "jugendgefährdendster": "jugendgefährdend",
    "jugendgefährdendstes": "jugendgefährdend",
    "jugendliche": "jugendlich",
    "jugendlichem": "jugendlich",
    "jugendlichen": "jugendlich",
    "jugendlicher": "jugendlich",
    "jugendlichere": "jugendlich",
    "jugendlicherem": "jugendlich",
    "jugendlicheren": "jugendlich",
    "jugendlicherer": "jugendlich",
    "jugendlicheres": "jugendlich",
    "jugendliches": "jugendlich",
    "jugendlichste": "jugendlich",
    "jugendlichstem": "jugendlich",
    "jugendlichsten": "jugendlich",
    "jugendlichster": "jugendlich",
    "jugendlichstes": "jugendlich",
    "jugoslawischem": "jugoslawisch",
    "jugoslawischen": "jugoslawisch",
    "jugoslawischer": "jugoslawisch",
    "jugoslawisches": "jugoslawisch",
    "jungem": "jung",
    "jungen": "jung",
    "jungenhaftem": "jungenhaft",
    "jungenhaften": "jungenhaft",
    "jungenhafter": "jungenhaft",
    "jungenhaftere": "jungenhaft",
    "jungenhafterem": "jungenhaft",
    "jungenhafteren": "jungenhaft",
    "jungenhafterer": "jungenhaft",
    "jungenhafteres": "jungenhaft",
    "jungenhaftes": "jungenhaft",
    "jungenhafteste": "jungenhaft",
    "jungenhaftestem": "jungenhaft",
    "jungenhaftesten": "jungenhaft",
    "jungenhaftester": "jungenhaft",
    "jungenhaftestes": "jungenhaft",
    "junger": "jung",
    "junges": "jung",
    "jungfräulichem": "jungfräulich",
    "jungfräulichen": "jungfräulich",
    "jungfräulicher": "jungfräulich",
    "jungfräulichere": "jungfräulich",
    "jungfräulicherem": "jungfräulich",
    "jungfräulicheren": "jungfräulich",
    "jungfräulicherer": "jungfräulich",
    "jungfräulicheres": "jungfräulich",
    "jungfräuliches": "jungfräulich",
    "jungfräulichste": "jungfräulich",
    "jungfräulichstem": "jungfräulich",
    "jungfräulichsten": "jungfräulich",
    "jungfräulichster": "jungfräulich",
    "jungfräulichstes": "jungfräulich",
    "jungsteinzeitliche": "jungsteinzeitlich",
    "jungsteinzeitlichem": "jungsteinzeitlich",
    "jungsteinzeitlichen": "jungsteinzeitlich",
    "jungsteinzeitlicher": "jungsteinzeitlich",
    "jungsteinzeitliches": "jungsteinzeitlich",
    "juriere": "jurieren",
    "jurierend": "jurieren",
    "jurierende": "jurierend",
    "jurierendem": "jurierend",
    "jurierenden": "jurierend",
    "jurierender": "jurierend",
    "jurierendes": "jurierend",
    "jurierest": "jurieren",
    "jurieret": "jurieren",
    "jurierst": "jurieren",
    "juriert": "jurieren",
    "jurierte": "jurieren",
    "juriertem": "juriert",
    "jurierten": "jurieren",
    "jurierter": "juriert",
    "juriertes": "juriert",
    "juriertest": "jurieren",
    "juriertet": "jurieren",
    "juristischem": "juristisch",
    "juristischen": "juristisch",
    "juristischer": "juristisch",
    "juristisches": "juristisch",
    "justiere": "justieren",
    "justierend": "justieren",
    "justierende": "justierend",
    "justierendem": "justierend",
    "justierenden": "justierend",
    "justierender": "justierend",
    "justierendes": "justierend",
    "justierest": "justieren",
    "justieret": "justieren",
    "justierst": "justieren",
    "justiert": "justieren",
    "justierte": "justieren",
    "justiertem": "justiert",
    "justierten": "justieren",
    "justierter": "justiert",
    "justiertere": "justiert",
    "justierterem": "justiert",
    "justierteren": "justiert",
    "justierterer": "justiert",
    "justierteres": "justiert",
    "justiertes": "justiert",
    "justiertest": "justieren",
    "justierteste": "justiert",
    "justiertestem": "justiert",
    "justiertesten": "justiert",
    "justiertester": "justiert",
    "justiertestes": "justiert",
    "justiertet": "justieren",
    "justifiziere": "justifizieren",
    "justifizierend": "justifizieren",
    "justifizierende": "justifizierend",
    "justifizierendem": "justifizierend",
    "justifizierenden": "justifizierend",
    "justifizierender": "justifizierend",
    "justifizierendes": "justifizierend",
    "justifizierest": "justifizieren",
    "justifizieret": "justifizieren",
    "justifizierst": "justifizieren",
    "justifiziert": "justifizieren",
    "justifizierte": "justifizieren",
    "justifiziertem": "justifiziert",
    "justifizierten": "justifizieren",
    "justifizierter": "justifiziert",
    "justifiziertes": "justifiziert",
    "justifiziertest": "justifizieren",
    "justifiziertet": "justifizieren",
    "jähe": "jäh",
    "jähem": "jäh",
    "jähen": "jäh",
    "jäher": "jäh",
    "jähes": "jäh",
    "jährigem": "jährig",
    "jährigen": "jährig",
    "jähriger": "jährig",
    "jähriges": "jährig",
    "jährliche": "jährlich",
    "jährlichem": "jährlich",
    "jährlichen": "jährlich",
    "jährlicher": "jährlich",
    "jährliches": "jährlich",
    "jähzornigem": "jähzornig",
    "jähzornigen": "jähzornig",
    "jähzorniger": "jähzornig",
    "jähzornigere": "jähzornig",
    "jähzornigerem": "jähzornig",
    "jähzornigeren": "jähzornig",
    "jähzornigerer": "jähzornig",
    "jähzornigeres": "jähzornig",
    "jähzorniges": "jähzornig",
    "jähzornigste": "jähzornig",
    "jähzornigstem": "jähzornig",
    "jähzornigsten": "jähzornig",
    "jähzornigster": "jähzornig",
    "jähzornigstes": "jähzornig",
    "jämmerlichem": "jämmerlich",
    "jämmerlichen": "jämmerlich",
    "jämmerlicher": "jämmerlich",
    "jämmerlichere": "jämmerlich",
    "jämmerlicherem": "jämmerlich",
    "jämmerlicheren": "jämmerlich",
    "jämmerlicherer": "jämmerlich",
    "jämmerlicheres": "jämmerlich",
    "jämmerliches": "jämmerlich",
    "jämmerlichste": "jämmerlich",
    "jämmerlichstem": "jämmerlich",
    "jämmerlichsten": "jämmerlich",
    "jämmerlichster": "jämmerlich",
    "jämmerlichstes": "jämmerlich",
    "jäte": "jäten",
    "jätend": "jäten",
    "jätende": "jätend",
    "jätendem": "jätend",
    "jätenden": "jätend",
    "jätender": "jätend",
    "jätendes": "jätend",
    "jätest": "jäten",
    "jätet": "jäten",
    "jätete": "jäten",
    "jäteten": "jäten",
    "jätetest": "jäten",
    "jätetet": "jäten",
    "jüdischem": "jüdisch",
    "jüdischen": "jüdisch",
    "jüdischer": "jüdisch",
    "jüdisches": "jüdisch",
    "jünger": "jung",
    "jüngere": "jung",
    "jüngerem": "jung",
    "jüngeren": "jung",
    "jüngerer": "jung",
    "jüngeres": "jung",
    "jüngferliche": "jüngferlich",
    "jüngferlichem": "jüngferlich",
    "jüngferlichen": "jüngferlich",
    "jüngferlicher": "jüngferlich",
    "jüngferlichere": "jüngferlich",
    "jüngferlicherem": "jüngferlich",
    "jüngferlicheren": "jüngferlich",
    "jüngferlicherer": "jüngferlich",
    "jüngferlicheres": "jüngferlich",
    "jüngferliches": "jüngferlich",
    "jüngferlichste": "jüngferlich",
    "jüngferlichstem": "jüngferlich",
    "jüngferlichsten": "jüngferlich",
    "jüngferlichster": "jüngferlich",
    "jüngferlichstes": "jüngferlich",
    "jüngstem": "jung",
    "jüngsten": "jung",
    "jüngster": "jung",
    "jüngstes": "jung",
    "kabarettistischem": "kabarettistisch",
    "kabarettistischen": "kabarettistisch",
    "kabarettistischer": "kabarettistisch",
    "kabarettistisches": "kabarettistisch",
    "kachele": "kacheln",
    "kachelnd": "kacheln",
    "kachelnde": "kachelnd",
    "kachelndem": "kachelnd",
    "kachelnden": "kachelnd",
    "kachelnder": "kachelnd",
    "kachelndes": "kachelnd",
    "kachelst": "kacheln",
    "kachelt": "kacheln",
    "kachelte": "kacheln",
    "kachelten": "kacheln",
    "kacheltest": "kacheln",
    "kacheltet": "kacheln",
    "kachle": "kacheln",
    "kahlem": "kahl",
    "kahlen": "kahl",
    "kahler": "kahl",
    "kahlere": "kahl",
    "kahlerem": "kahl",
    "kahleren": "kahl",
    "kahlerer": "kahl",
    "kahleres": "kahl",
    "kahles": "kahl",
    "kahlfraß": "kahlfressen",
    "kahlfraßen": "kahlfressen",
    "kahlfraßt": "kahlfressen",
    "kahlfresse": "kahlfressen",
    "kahlfressend": "kahlfressen",
    "kahlfressende": "kahlfressend",
    "kahlfressendem": "kahlfressend",
    "kahlfressenden": "kahlfressend",
    "kahlfressender": "kahlfressend",
    "kahlfressendere": "kahlfressend",
    "kahlfressenderem": "kahlfressend",
    "kahlfressenderen": "kahlfressend",
    "kahlfressenderer": "kahlfressend",
    "kahlfressenderes": "kahlfressend",
    "kahlfressendes": "kahlfressend",
    "kahlfressendste": "kahlfressend",
    "kahlfressendstem": "kahlfressend",
    "kahlfressendsten": "kahlfressend",
    "kahlfressendster": "kahlfressend",
    "kahlfressendstes": "kahlfressend",
    "kahlfressest": "kahlfressen",
    "kahlfresset": "kahlfressen",
    "kahlfreßt": "kahlfressen",
    "kahlfrißt": "kahlfressen",
    "kahlfräße": "kahlfressen",
    "kahlfräßen": "kahlfressen",
    "kahlfräßest": "kahlfressen",
    "kahlfräßet": "kahlfressen",
    "kahlgefressen": "kahlfressen",
    "kahlgefressene": "kahlgefressen",
    "kahlgefressenem": "kahlgefressen",
    "kahlgefressenen": "kahlgefressen",
    "kahlgefressener": "kahlgefressen",
    "kahlgefressenere": "kahlgefressen",
    "kahlgefressenerem": "kahlgefressen",
    "kahlgefresseneren": "kahlgefressen",
    "kahlgefressenerer": "kahlgefressen",
    "kahlgefresseneres": "kahlgefressen",
    "kahlgefressenes": "kahlgefressen",
    "kahlgefressenste": "kahlgefressen",
    "kahlgefressenstem": "kahlgefressen",
    "kahlgefressensten": "kahlgefressen",
    "kahlgefressenster": "kahlgefressen",
    "kahlgefressenstes": "kahlgefressen",
    "kahlgeschert": "kahlscheren",
    "kahlgescherte": "kahlgeschert",
    "kahlgeschertem": "kahlgeschert",
    "kahlgescherten": "kahlgeschert",
    "kahlgescherter": "kahlgeschert",
    "kahlgeschertes": "kahlgeschert",
    "kahlgeschoren": "kahlscheren",
    "kahlgeschorene": "kahlgeschoren",
    "kahlgeschorenem": "kahlgeschoren",
    "kahlgeschorenen": "kahlgeschoren",
    "kahlgeschorener": "kahlgeschoren",
    "kahlgeschorenere": "kahlgeschoren",
    "kahlgeschorenerem": "kahlgeschoren",
    "kahlgeschoreneren": "kahlgeschoren",
    "kahlgeschorenerer": "kahlgeschoren",
    "kahlgeschoreneres": "kahlgeschoren",
    "kahlgeschorenes": "kahlgeschoren",
    "kahlgeschorenste": "kahlgeschoren",
    "kahlgeschorenstem": "kahlgeschoren",
    "kahlgeschorensten": "kahlgeschoren",
    "kahlgeschorenster": "kahlgeschoren",
    "kahlgeschorenstes": "kahlgeschoren",
    "kahlköpfige": "kahlköpfig",
    "kahlköpfigem": "kahlköpfig",
    "kahlköpfigen": "kahlköpfig",
    "kahlköpfiger": "kahlköpfig",
    "kahlköpfigere": "kahlköpfig",
    "kahlköpfigerem": "kahlköpfig",
    "kahlköpfigeren": "kahlköpfig",
    "kahlköpfigerer": "kahlköpfig",
    "kahlköpfigeres": "kahlköpfig",
    "kahlköpfiges": "kahlköpfig",
    "kahlköpfigste": "kahlköpfig",
    "kahlköpfigstem": "kahlköpfig",
    "kahlköpfigsten": "kahlköpfig",
    "kahlköpfigster": "kahlköpfig",
    "kahlköpfigstes": "kahlköpfig",
    "kahlschere": "kahlscheren",
    "kahlscherend": "kahlscheren",
    "kahlscherende": "kahlscherend",
    "kahlscherendem": "kahlscherend",
    "kahlscherenden": "kahlscherend",
    "kahlscherender": "kahlscherend",
    "kahlscherendes": "kahlscherend",
    "kahlscherest": "kahlscheren",
    "kahlscheret": "kahlscheren",
    "kahlscherst": "kahlscheren",
    "kahlschert": "kahlscheren",
    "kahlscherte": "kahlscheren",
    "kahlscherten": "kahlscheren",
    "kahlschertest": "kahlscheren",
    "kahlschertet": "kahlscheren",
    "kahlschor": "kahlscheren",
    "kahlschoren": "kahlscheren",
    "kahlschorst": "kahlscheren",
    "kahlschort": "kahlscheren",
    "kahlschöre": "kahlscheren",
    "kahlschören": "kahlscheren",
    "kahlschörest": "kahlscheren",
    "kahlschöret": "kahlscheren",
    "kahlste": "kahl",
    "kahlstem": "kahl",
    "kahlsten": "kahl",
    "kahlster": "kahl",
    "kahlstes": "kahl",
    "kahlzufressen": "kahlfressen",
    "kahlzuscheren": "kahlscheren",
    "kaiserlichem": "kaiserlich",
    "kaiserlichen": "kaiserlich",
    "kaiserlicher": "kaiserlich",
    "kaiserliches": "kaiserlich",
    "kakele": "kakeln",
    "kakelnd": "kakeln",
    "kakelnde": "kakelnd",
    "kakelndem": "kakelnd",
    "kakelnden": "kakelnd",
    "kakelnder": "kakelnd",
    "kakelndere": "kakelnd",
    "kakelnderem": "kakelnd",
    "kakelnderen": "kakelnd",
    "kakelnderer": "kakelnd",
    "kakelnderes": "kakelnd",
    "kakelndes": "kakelnd",
    "kakelndste": "kakelnd",
    "kakelndstem": "kakelnd",
    "kakelndsten": "kakelnd",
    "kakelndster": "kakelnd",
    "kakelndstes": "kakelnd",
    "kakelst": "kakeln",
    "kakelt": "kakeln",
    "kakelte": "kakeln",
    "kakelten": "kakeln",
    "kakeltest": "kakeln",
    "kakeltet": "kakeln",
    "kakle": "kakeln",
    "kalbend": "kalben",
    "kalbende": "kalbend",
    "kalbendem": "kalbend",
    "kalbenden": "kalbend",
    "kalbender": "kalbend",
    "kalbendes": "kalbend",
    "kalbest": "kalben",
    "kalbet": "kalben",
    "kalbst": "kalben",
    "kalbt": "kalben",
    "kalbte": "kalben",
    "kalbten": "kalben",
    "kalbtest": "kalben",
    "kalbtet": "kalben",
    "kalkend": "kalken",
    "kalkende": "kalkend",
    "kalkendem": "kalkend",
    "kalkenden": "kalkend",
    "kalkender": "kalkend",
    "kalkendere": "kalkend",
    "kalkenderem": "kalkend",
    "kalkenderen": "kalkend",
    "kalkenderer": "kalkend",
    "kalkenderes": "kalkend",
    "kalkendes": "kalkend",
    "kalkendste": "kalkend",
    "kalkendstem": "kalkend",
    "kalkendsten": "kalkend",
    "kalkendster": "kalkend",
    "kalkendstes": "kalkend",
    "kalkest": "kalken",
    "kalket": "kalken",
    "kalkhaltige": "kalkhaltig",
    "kalkhaltigem": "kalkhaltig",
    "kalkhaltigen": "kalkhaltig",
    "kalkhaltiger": "kalkhaltig",
    "kalkhaltigere": "kalkhaltig",
    "kalkhaltigerem": "kalkhaltig",
    "kalkhaltigeren": "kalkhaltig",
    "kalkhaltigerer": "kalkhaltig",
    "kalkhaltigeres": "kalkhaltig",
    "kalkhaltiges": "kalkhaltig",
    "kalkhaltigste": "kalkhaltig",
    "kalkhaltigstem": "kalkhaltig",
    "kalkhaltigsten": "kalkhaltig",
    "kalkhaltigster": "kalkhaltig",
    "kalkhaltigstes": "kalkhaltig",
    "kalkige": "kalkig",
    "kalkigem": "kalkig",
    "kalkigen": "kalkig",
    "kalkiger": "kalkig",
    "kalkigere": "kalkig",
    "kalkigerem": "kalkig",
    "kalkigeren": "kalkig",
    "kalkigerer": "kalkig",
    "kalkigeres": "kalkig",
    "kalkiges": "kalkig",
    "kalkigste": "kalkig",
    "kalkigstem": "kalkig",
    "kalkigsten": "kalkig",
    "kalkigster": "kalkig",
    "kalkigstes": "kalkig",
    "kalkst": "kalken",
    "kalkt": "kalken",
    "kalkte": "kalken",
    "kalkten": "kalken",
    "kalktest": "kalken",
    "kalktet": "kalken",
    "kalkulatorischem": "kalkulatorisch",
    "kalkulatorischen": "kalkulatorisch",
    "kalkulatorischer": "kalkulatorisch",
    "kalkulatorisches": "kalkulatorisch",
    "kalkuliere": "kalkulieren",
    "kalkulierend": "kalkulieren",
    "kalkulierende": "kalkulierend",
    "kalkulierendem": "kalkulierend",
    "kalkulierenden": "kalkulierend",
    "kalkulierender": "kalkulierend",
    "kalkulierendes": "kalkulierend",
    "kalkulierest": "kalkulieren",
    "kalkulieret": "kalkulieren",
    "kalkulierst": "kalkulieren",
    "kalkuliert": "kalkulieren",
    "kalkulierte": "kalkulieren",
    "kalkuliertem": "kalkuliert",
    "kalkulierten": "kalkulieren",
    "kalkulierter": "kalkuliert",
    "kalkuliertes": "kalkuliert",
    "kalkuliertest": "kalkulieren",
    "kalkuliertet": "kalkulieren",
    "kalorienarmem": "kalorienarm",
    "kalorienarmen": "kalorienarm",
    "kalorienarmer": "kalorienarm",
    "kalorienarmes": "kalorienarm",
    "kalorienbewußte": "kalorienbewußt",
    "kalorienbewußtem": "kalorienbewußt",
    "kalorienbewußten": "kalorienbewußt",
    "kalorienbewußter": "kalorienbewußt",
    "kalorienbewußtere": "kalorienbewußt",
    "kalorienbewußterem": "kalorienbewußt",
    "kalorienbewußteren": "kalorienbewußt",
    "kalorienbewußterer": "kalorienbewußt",
    "kalorienbewußteres": "kalorienbewußt",
    "kalorienbewußtes": "kalorienbewußt",
    "kalorienbewußteste": "kalorienbewußt",
    "kalorienbewußtestem": "kalorienbewußt",
    "kalorienbewußtesten": "kalorienbewußt",
    "kalorienbewußtester": "kalorienbewußt",
    "kalorienbewußtestes": "kalorienbewußt",
    "kalorienärmer": "kalorienarm",
    "kalorienärmere": "kalorienarm",
    "kalorienärmerem": "kalorienarm",
    "kalorienärmeren": "kalorienarm",
    "kalorienärmerer": "kalorienarm",
    "kalorienärmeres": "kalorienarm",
    "kalorienärmsten": "kalorienarm",
    "kaltblütigem": "kaltblütig",
    "kaltblütigen": "kaltblütig",
    "kaltblütiger": "kaltblütig",
    "kaltblütigere": "kaltblütig",
    "kaltblütigerem": "kaltblütig",
    "kaltblütigeren": "kaltblütig",
    "kaltblütigerer": "kaltblütig",
    "kaltblütigeres": "kaltblütig",
    "kaltblütiges": "kaltblütig",
    "kaltblütigste": "kaltblütig",
    "kaltblütigstem": "kaltblütig",
    "kaltblütigsten": "kaltblütig",
    "kaltblütigster": "kaltblütig",
    "kaltblütigstes": "kaltblütig",
    "kaltem": "kalt",
    "kalter": "kalt",
    "kaltes": "kalt",
    "kaltgepreßtem": "kaltgepreßt",
    "kaltgepreßten": "kaltgepreßt",
    "kaltgepreßter": "kaltgepreßt",
    "kaltgepreßtere": "kaltgepreßt",
    "kaltgepreßterem": "kaltgepreßt",
    "kaltgepreßteren": "kaltgepreßt",
    "kaltgepreßterer": "kaltgepreßt",
    "kaltgepreßteres": "kaltgepreßt",
    "kaltgepreßtes": "kaltgepreßt",
    "kaltgepreßteste": "kaltgepreßt",
    "kaltgepreßtestem": "kaltgepreßt",
    "kaltgepreßtesten": "kaltgepreßt",
    "kaltgepreßtester": "kaltgepreßt",
    "kaltgepreßtestes": "kaltgepreßt",
    "kaltgestellt": "kaltstellen",
    "kaltgestellte": "kaltgestellt",
    "kaltgestelltem": "kaltgestellt",
    "kaltgestellten": "kaltgestellt",
    "kaltgestellter": "kaltgestellt",
    "kaltgestelltes": "kaltgestellt",
    "kaltherzige": "kaltherzig",
    "kaltherzigem": "kaltherzig",
    "kaltherzigen": "kaltherzig",
    "kaltherziger": "kaltherzig",
    "kaltherzigere": "kaltherzig",
    "kaltherzigerem": "kaltherzig",
    "kaltherzigeren": "kaltherzig",
    "kaltherzigerer": "kaltherzig",
    "kaltherzigeres": "kaltherzig",
    "kaltherziges": "kaltherzig",
    "kaltherzigste": "kaltherzig",
    "kaltherzigstem": "kaltherzig",
    "kaltherzigsten": "kaltherzig",
    "kaltherzigster": "kaltherzig",
    "kaltherzigstes": "kaltherzig",
    "kaltschnäuzigem": "kaltschnäuzig",
    "kaltschnäuzigen": "kaltschnäuzig",
    "kaltschnäuziger": "kaltschnäuzig",
    "kaltschnäuzigere": "kaltschnäuzig",
    "kaltschnäuzigerem": "kaltschnäuzig",
    "kaltschnäuzigeren": "kaltschnäuzig",
    "kaltschnäuzigerer": "kaltschnäuzig",
    "kaltschnäuzigeres": "kaltschnäuzig",
    "kaltschnäuziges": "kaltschnäuzig",
    "kaltschnäuzigste": "kaltschnäuzig",
    "kaltschnäuzigstem": "kaltschnäuzig",
    "kaltschnäuzigsten": "kaltschnäuzig",
    "kaltschnäuzigster": "kaltschnäuzig",
    "kaltschnäuzigstes": "kaltschnäuzig",
    "kaltstelle": "kaltstellen",
    "kaltstellend": "kaltstellen",
    "kaltstellende": "kaltstellend",
    "kaltstellendem": "kaltstellend",
    "kaltstellenden": "kaltstellend",
    "kaltstellender": "kaltstellend",
    "kaltstellendes": "kaltstellend",
    "kaltstellest": "kaltstellen",
    "kaltstellet": "kaltstellen",
    "kaltstellst": "kaltstellen",
    "kaltstellt": "kaltstellen",
    "kaltstellte": "kaltstellen",
    "kaltstellten": "kaltstellen",
    "kaltstelltest": "kaltstellen",
    "kaltstelltet": "kaltstellen",
    "kaltzustellen": "kaltstellen",
    "kam": "kommen",
    "kamen": "kommen",
    "kameradschaftlichem": "kameradschaftlich",
    "kameradschaftlichen": "kameradschaftlich",
    "kameradschaftlicher": "kameradschaftlich",
    "kameradschaftlichere": "kameradschaftlich",
    "kameradschaftlicherem": "kameradschaftlich",
    "kameradschaftlicheren": "kameradschaftlich",
    "kameradschaftlicherer": "kameradschaftlich",
    "kameradschaftlicheres": "kameradschaftlich",
    "kameradschaftliches": "kameradschaftlich",
    "kameradschaftlichste": "kameradschaftlich",
    "kameradschaftlichstem": "kameradschaftlich",
    "kameradschaftlichsten": "kameradschaftlich",
    "kameradschaftlichster": "kameradschaftlich",
    "kameradschaftlichstes": "kameradschaftlich",
    "kampfbereitem": "kampfbereit",
    "kampfbereiten": "kampfbereit",
    "kampfbereiter": "kampfbereit",
    "kampfbereitere": "kampfbereit",
    "kampfbereiterem": "kampfbereit",
    "kampfbereiteren": "kampfbereit",
    "kampfbereiterer": "kampfbereit",
    "kampfbereiteres": "kampfbereit",
    "kampfbereites": "kampfbereit",
    "kampfbereiteste": "kampfbereit",
    "kampfbereitestem": "kampfbereit",
    "kampfbereitesten": "kampfbereit",
    "kampfbereitester": "kampfbereit",
    "kampfbereitestes": "kampfbereit",
    "kampffähige": "kampffähig",
    "kampffähigem": "kampffähig",
    "kampffähigen": "kampffähig",
    "kampffähiger": "kampffähig",
    "kampffähigere": "kampffähig",
    "kampffähigerem": "kampffähig",
    "kampffähigeren": "kampffähig",
    "kampffähigerer": "kampffähig",
    "kampffähigeres": "kampffähig",
    "kampffähiges": "kampffähig",
    "kampffähigste": "kampffähig",
    "kampffähigstem": "kampffähig",
    "kampffähigsten": "kampffähig",
    "kampffähigster": "kampffähig",
    "kampffähigstes": "kampffähig",
    "kampflose": "kampflos",
    "kampflosem": "kampflos",
    "kampflosen": "kampflos",
    "kampfloser": "kampflos",
    "kampfloses": "kampflos",
    "kampflustige": "kampflustig",
    "kampflustigem": "kampflustig",
    "kampflustigen": "kampflustig",
    "kampflustiger": "kampflustig",
    "kampflustigere": "kampflustig",
    "kampflustigerem": "kampflustig",
    "kampflustigeren": "kampflustig",
    "kampflustigerer": "kampflustig",
    "kampflustigeres": "kampflustig",
    "kampflustiges": "kampflustig",
    "kampflustigste": "kampflustig",
    "kampflustigstem": "kampflustig",
    "kampflustigsten": "kampflustig",
    "kampflustigster": "kampflustig",
    "kampflustigstes": "kampflustig",
    "kampfunfähige": "kampfunfähig",
    "kampfunfähigem": "kampfunfähig",
    "kampfunfähigen": "kampfunfähig",
    "kampfunfähiger": "kampfunfähig",
    "kampfunfähigere": "kampfunfähig",
    "kampfunfähigerem": "kampfunfähig",
    "kampfunfähigeren": "kampfunfähig",
    "kampfunfähigerer": "kampfunfähig",
    "kampfunfähigeres": "kampfunfähig",
    "kampfunfähiges": "kampfunfähig",
    "kampfunfähigste": "kampfunfähig",
    "kampfunfähigstem": "kampfunfähig",
    "kampfunfähigsten": "kampfunfähig",
    "kampfunfähigster": "kampfunfähig",
    "kampfunfähigstes": "kampfunfähig",
    "kamst": "kommen",
    "kamt": "kommen",
    "kanadischem": "kanadisch",
    "kanadischen": "kanadisch",
    "kanadischer": "kanadisch",
    "kanadisches": "kanadisch",
    "kanalisiere": "kanalisieren",
    "kanalisierend": "kanalisieren",
    "kanalisierende": "kanalisierend",
    "kanalisierendem": "kanalisierend",
    "kanalisierenden": "kanalisierend",
    "kanalisierender": "kanalisierend",
    "kanalisierendere": "kanalisierend",
    "kanalisierenderem": "kanalisierend",
    "kanalisierenderen": "kanalisierend",
    "kanalisierenderer": "kanalisierend",
    "kanalisierenderes": "kanalisierend",
    "kanalisierendes": "kanalisierend",
    "kanalisierendste": "kanalisierend",
    "kanalisierendstem": "kanalisierend",
    "kanalisierendsten": "kanalisierend",
    "kanalisierendster": "kanalisierend",
    "kanalisierendstes": "kanalisierend",
    "kanalisierest": "kanalisieren",
    "kanalisieret": "kanalisieren",
    "kanalisierst": "kanalisieren",
    "kanalisiert": "kanalisieren",
    "kanalisierte": "kanalisieren",
    "kanalisiertem": "kanalisiert",
    "kanalisierten": "kanalisieren",
    "kanalisierter": "kanalisiert",
    "kanalisiertere": "kanalisiert",
    "kanalisierterem": "kanalisiert",
    "kanalisierteren": "kanalisiert",
    "kanalisierterer": "kanalisiert",
    "kanalisierteres": "kanalisiert",
    "kanalisiertes": "kanalisiert",
    "kanalisiertest": "kanalisieren",
    "kanalisierteste": "kanalisiert",
    "kanalisiertestem": "kanalisiert",
    "kanalisiertesten": "kanalisiert",
    "kanalisiertester": "kanalisiert",
    "kanalisiertestes": "kanalisiert",
    "kanalisiertet": "kanalisieren",
    "kandidiere": "kandidieren",
    "kandidierend": "kandidieren",
    "kandidierende": "kandidierend",
    "kandidierendem": "kandidierend",
    "kandidierenden": "kandidierend",
    "kandidierender": "kandidierend",
    "kandidierendes": "kandidierend",
    "kandidierest": "kandidieren",
    "kandidieret": "kandidieren",
    "kandidierst": "kandidieren",
    "kandidiert": "kandidieren",
    "kandidierte": "kandidieren",
    "kandidiertem": "kandidiert",
    "kandidierten": "kandidieren",
    "kandidierter": "kandidiert",
    "kandidiertes": "kandidiert",
    "kandidiertest": "kandidieren",
    "kandidiertet": "kandidieren",
    "kandiere": "kandieren",
    "kandierend": "kandieren",
    "kandierende": "kandierend",
    "kandierendem": "kandierend",
    "kandierenden": "kandierend",
    "kandierender": "kandierend",
    "kandierendes": "kandierend",
    "kandierest": "kandieren",
    "kandieret": "kandieren",
    "kandierst": "kandieren",
    "kandiert": "kandieren",
    "kandierte": "kandieren",
    "kandiertem": "kandiert",
    "kandierten": "kandieren",
    "kandierter": "kandiert",
    "kandiertes": "kandiert",
    "kandiertest": "kandieren",
    "kandiertet": "kandieren",
    "kann": "können",
    "kannibalischem": "kannibalisch",
    "kannibalischen": "kannibalisch",
    "kannibalischer": "kannibalisch",
    "kannibalisches": "kannibalisch",
    "kannst": "können",
    "kannte": "kennen",
    "kannten": "kennen",
    "kanntest": "kennen",
    "kanntet": "kennen",
    "kanonierend": "kanonieren",
    "kanonierende": "kanonierend",
    "kanonierendem": "kanonierend",
    "kanonierenden": "kanonierend",
    "kanonierender": "kanonierend",
    "kanonierendes": "kanonierend",
    "kanonierest": "kanonieren",
    "kanonieret": "kanonieren",
    "kanonierst": "kanonieren",
    "kanoniert": "kanonieren",
    "kanonierte": "kanonieren",
    "kanoniertem": "kanoniert",
    "kanonierten": "kanonieren",
    "kanonierter": "kanoniert",
    "kanoniertes": "kanoniert",
    "kanoniertest": "kanonieren",
    "kanoniertet": "kanonieren",
    "kanonische": "kanonisch",
    "kanonischem": "kanonisch",
    "kanonischen": "kanonisch",
    "kanonischer": "kanonisch",
    "kanonischere": "kanonisch",
    "kanonischerem": "kanonisch",
    "kanonischeren": "kanonisch",
    "kanonischerer": "kanonisch",
    "kanonischeres": "kanonisch",
    "kanonisches": "kanonisch",
    "kanonischste": "kanonisch",
    "kanonischstem": "kanonisch",
    "kanonischsten": "kanonisch",
    "kanonischster": "kanonisch",
    "kanonischstes": "kanonisch",
    "kanonisiere": "kanonisieren",
    "kanonisierend": "kanonisieren",
    "kanonisierende": "kanonisierend",
    "kanonisierendem": "kanonisierend",
    "kanonisierenden": "kanonisierend",
    "kanonisierender": "kanonisierend",
    "kanonisierendes": "kanonisierend",
    "kanonisierest": "kanonisieren",
    "kanonisieret": "kanonisieren",
    "kanonisierst": "kanonisieren",
    "kanonisiert": "kanonisieren",
    "kanonisierte": "kanonisieren",
    "kanonisiertem": "kanonisiert",
    "kanonisierten": "kanonisieren",
    "kanonisierter": "kanonisiert",
    "kanonisiertes": "kanonisiert",
    "kanonisiertest": "kanonisieren",
    "kanonisiertet": "kanonisieren",
    "kantend": "kanten",
    "kantende": "kantend",
    "kantendem": "kantend",
    "kantenden": "kantend",
    "kantender": "kantend",
    "kantendere": "kantend",
    "kantenderem": "kantend",
    "kantenderen": "kantend",
    "kantenderer": "kantend",
    "kantenderes": "kantend",
    "kantendes": "kantend",
    "kantendste": "kantend",
    "kantendstem": "kantend",
    "kantendsten": "kantend",
    "kantendster": "kantend",
    "kantendstes": "kantend",
    "kantest": "kanten",
    "kantet": "kanten",
    "kantete": "kanten",
    "kanteten": "kanten",
    "kantetest": "kanten",
    "kantetet": "kanten",
    "kantigem": "kantig",
    "kantigen": "kantig",
    "kantiger": "kantig",
    "kantigere": "kantig",
    "kantigerem": "kantig",
    "kantigeren": "kantig",
    "kantigerer": "kantig",
    "kantigeres": "kantig",
    "kantiges": "kantig",
    "kantigste": "kantig",
    "kantigstem": "kantig",
    "kantigsten": "kantig",
    "kantigster": "kantig",
    "kantigstes": "kantig",
    "kanzele": "kanzeln",
    "kanzelnd": "kanzeln",
    "kanzelnde": "kanzelnd",
    "kanzelndem": "kanzelnd",
    "kanzelnden": "kanzelnd",
    "kanzelnder": "kanzelnd",
    "kanzelndes": "kanzelnd",
    "kanzelst": "kanzeln",
    "kanzelt": "kanzeln",
    "kanzelte": "kanzeln",
    "kanzelten": "kanzeln",
    "kanzeltest": "kanzeln",
    "kanzeltet": "kanzeln",
    "kanzle": "kanzeln",
    "kapere": "kapern",
    "kapernd": "kapern",
    "kapernde": "kapernd",
    "kaperndem": "kapernd",
    "kapernden": "kapernd",
    "kapernder": "kapernd",
    "kaperndes": "kapernd",
    "kaperst": "kapern",
    "kapert": "kapern",
    "kaperte": "kapern",
    "kaperten": "kapern",
    "kapertest": "kapern",
    "kapertet": "kapern",
    "kapiere": "kapieren",
    "kapierend": "kapieren",
    "kapierende": "kapierend",
    "kapierendem": "kapierend",
    "kapierenden": "kapierend",
    "kapierender": "kapierend",
    "kapierendes": "kapierend",
    "kapierest": "kapieren",
    "kapieret": "kapieren",
    "kapierst": "kapieren",
    "kapiert": "kapieren",
    "kapierte": "kapieren",
    "kapiertem": "kapiert",
    "kapierten": "kapieren",
    "kapierter": "kapiert",
    "kapiertes": "kapiert",
    "kapiertest": "kapieren",
    "kapiertet": "kapieren",
    "kapillare": "kapillar",
    "kapillarem": "kapillar",
    "kapillaren": "kapillar",
    "kapillarer": "kapillar",
    "kapillares": "kapillar",
    "kapitalintensive": "kapitalintensiv",
    "kapitalintensivem": "kapitalintensiv",
    "kapitalintensiven": "kapitalintensiv",
    "kapitalintensiver": "kapitalintensiv",
    "kapitalintensivere": "kapitalintensiv",
    "kapitalintensiverem": "kapitalintensiv",
    "kapitalintensiveren": "kapitalintensiv",
    "kapitalintensiverer": "kapitalintensiv",
    "kapitalintensiveres": "kapitalintensiv",
    "kapitalintensives": "kapitalintensiv",
    "kapitalintensivste": "kapitalintensiv",
    "kapitalintensivstem": "kapitalintensiv",
    "kapitalintensivsten": "kapitalintensiv",
    "kapitalintensivster": "kapitalintensiv",
    "kapitalintensivstes": "kapitalintensiv",
    "kapitalisiere": "kapitalisieren",
    "kapitalisierend": "kapitalisieren",
    "kapitalisierende": "kapitalisierend",
    "kapitalisierendem": "kapitalisierend",
    "kapitalisierenden": "kapitalisierend",
    "kapitalisierender": "kapitalisierend",
    "kapitalisierendes": "kapitalisierend",
    "kapitalisierest": "kapitalisieren",
    "kapitalisieret": "kapitalisieren",
    "kapitalisierst": "kapitalisieren",
    "kapitalisiert": "kapitalisieren",
    "kapitalisierte": "kapitalisieren",
    "kapitalisiertem": "kapitalisiert",
    "kapitalisierten": "kapitalisieren",
    "kapitalisierter": "kapitalisiert",
    "kapitalisiertes": "kapitalisiert",
    "kapitalisiertest": "kapitalisieren",
    "kapitalisiertet": "kapitalisieren",
    "kapitalistischem": "kapitalistisch",
    "kapitalistischen": "kapitalistisch",
    "kapitalistischer": "kapitalistisch",
    "kapitalistischere": "kapitalistisch",
    "kapitalistischerem": "kapitalistisch",
    "kapitalistischeren": "kapitalistisch",
    "kapitalistischerer": "kapitalistisch",
    "kapitalistischeres": "kapitalistisch",
    "kapitalistisches": "kapitalistisch",
    "kapitalistischste": "kapitalistisch",
    "kapitalistischstem": "kapitalistisch",
    "kapitalistischsten": "kapitalistisch",
    "kapitalistischster": "kapitalistisch",
    "kapitalistischstes": "kapitalistisch",
    "kapitalkräftige": "kapitalkräftig",
    "kapitalkräftigem": "kapitalkräftig",
    "kapitalkräftigen": "kapitalkräftig",
    "kapitalkräftiger": "kapitalkräftig",
    "kapitalkräftigere": "kapitalkräftig",
    "kapitalkräftigerem": "kapitalkräftig",
    "kapitalkräftigeren": "kapitalkräftig",
    "kapitalkräftigerer": "kapitalkräftig",
    "kapitalkräftigeres": "kapitalkräftig",
    "kapitalkräftiges": "kapitalkräftig",
    "kapitalkräftigste": "kapitalkräftig",
    "kapitalkräftigstem": "kapitalkräftig",
    "kapitalkräftigsten": "kapitalkräftig",
    "kapitalkräftigster": "kapitalkräftig",
    "kapitalkräftigstes": "kapitalkräftig",
    "kapitelfestem": "kapitelfest",
    "kapitelfesten": "kapitelfest",
    "kapitelfester": "kapitelfest",
    "kapitelfestere": "kapitelfest",
    "kapitelfesterem": "kapitelfest",
    "kapitelfesteren": "kapitelfest",
    "kapitelfesterer": "kapitelfest",
    "kapitelfesteres": "kapitelfest",
    "kapitelfestes": "kapitelfest",
    "kapitelfesteste": "kapitelfest",
    "kapitelfestestem": "kapitelfest",
    "kapitelfestesten": "kapitelfest",
    "kapitelfestester": "kapitelfest",
    "kapitelfestestes": "kapitelfest",
    "kapituliere": "kapitulieren",
    "kapitulierend": "kapitulieren",
    "kapitulierende": "kapitulierend",
    "kapitulierendem": "kapitulierend",
    "kapitulierenden": "kapitulierend",
    "kapitulierender": "kapitulierend",
    "kapitulierendes": "kapitulierend",
    "kapitulierest": "kapitulieren",
    "kapitulieret": "kapitulieren",
    "kapitulierst": "kapitulieren",
    "kapituliert": "kapitulieren",
    "kapitulierte": "kapitulieren",
    "kapituliertem": "kapituliert",
    "kapitulierten": "kapitulieren",
    "kapitulierter": "kapituliert",
    "kapituliertes": "kapituliert",
    "kapituliertest": "kapitulieren",
    "kapituliertet": "kapitulieren",
    "kappend": "kappen",
    "kappende": "kappend",
    "kappendem": "kappend",
    "kappenden": "kappend",
    "kappender": "kappend",
    "kappendes": "kappend",
    "kappest": "kappen",
    "kappet": "kappen",
    "kappst": "kappen",
    "kappt": "kappen",
    "kappte": "kappen",
    "kappten": "kappen",
    "kapptest": "kappen",
    "kapptet": "kappen",
    "kapriziösem": "kapriziös",
    "kapriziösen": "kapriziös",
    "kapriziöser": "kapriziös",
    "kapriziösere": "kapriziös",
    "kapriziöserem": "kapriziös",
    "kapriziöseren": "kapriziös",
    "kapriziöserer": "kapriziös",
    "kapriziöseres": "kapriziös",
    "kapriziöses": "kapriziös",
    "kapriziöseste": "kapriziös",
    "kapriziösestem": "kapriziös",
    "kapriziösesten": "kapriziös",
    "kapriziösester": "kapriziös",
    "kapriziösestes": "kapriziös",
    "kapsele": "kapseln",
    "kapselnd": "kapseln",
    "kapselnde": "kapselnd",
    "kapselndem": "kapselnd",
    "kapselnden": "kapselnd",
    "kapselnder": "kapselnd",
    "kapselndes": "kapselnd",
    "kapselst": "kapseln",
    "kapselt": "kapseln",
    "kapselte": "kapseln",
    "kapselten": "kapseln",
    "kapseltest": "kapseln",
    "kapseltet": "kapseln",
    "kapsle": "kapseln",
    "kaputte": "kaputt",
    "kaputtem": "kaputt",
    "kaputten": "kaputt",
    "kaputter": "kaputt",
    "kaputtere": "kaputt",
    "kaputterem": "kaputt",
    "kaputteren": "kaputt",
    "kaputterer": "kaputt",
    "kaputteres": "kaputt",
    "kaputtes": "kaputt",
    "kaputteste": "kaputt",
    "kaputtestem": "kaputt",
    "kaputtesten": "kaputt",
    "kaputtester": "kaputt",
    "kaputtestes": "kaputt",
    "kaputtgegangen": "kaputtgehen",
    "kaputtgegangene": "kaputtgegangen",
    "kaputtgegangenem": "kaputtgegangen",
    "kaputtgegangenen": "kaputtgegangen",
    "kaputtgegangener": "kaputtgegangen",
    "kaputtgegangenes": "kaputtgegangen",
    "kaputtgehe": "kaputtgehen",
    "kaputtgehend": "kaputtgehen",
    "kaputtgehende": "kaputtgehend",
    "kaputtgehendem": "kaputtgehend",
    "kaputtgehenden": "kaputtgehend",
    "kaputtgehender": "kaputtgehend",
    "kaputtgehendes": "kaputtgehend",
    "kaputtgehest": "kaputtgehen",
    "kaputtgehet": "kaputtgehen",
    "kaputtgehst": "kaputtgehen",
    "kaputtgeht": "kaputtgehen",
    "kaputtgekriegt": "kaputtkriegen",
    "kaputtgekriegte": "kaputtgekriegt",
    "kaputtgekriegtem": "kaputtgekriegt",
    "kaputtgekriegten": "kaputtgekriegt",
    "kaputtgekriegter": "kaputtgekriegt",
    "kaputtgekriegtes": "kaputtgekriegt",
    "kaputtgelacht": "kaputtlachen",
    "kaputtgelachte": "kaputtgelacht",
    "kaputtgelachtem": "kaputtgelacht",
    "kaputtgelachten": "kaputtgelacht",
    "kaputtgelachter": "kaputtgelacht",
    "kaputtgelachtes": "kaputtgelacht",
    "kaputtging": "kaputtgehen",
    "kaputtginge": "kaputtgehen",
    "kaputtgingen": "kaputtgehen",
    "kaputtgingest": "kaputtgehen",
    "kaputtginget": "kaputtgehen",
    "kaputtgingst": "kaputtgehen",
    "kaputtgingt": "kaputtgehen",
    "kaputtkriege": "kaputtkriegen",
    "kaputtkriegend": "kaputtkriegen",
    "kaputtkriegende": "kaputtkriegend",
    "kaputtkriegendem": "kaputtkriegend",
    "kaputtkriegenden": "kaputtkriegend",
    "kaputtkriegender": "kaputtkriegend",
    "kaputtkriegendes": "kaputtkriegend",
    "kaputtkriegest": "kaputtkriegen",
    "kaputtkrieget": "kaputtkriegen",
    "kaputtkriegst": "kaputtkriegen",
    "kaputtkriegt": "kaputtkriegen",
    "kaputtkriegte": "kaputtkriegen",
    "kaputtkriegten": "kaputtkriegen",
    "kaputtkriegtest": "kaputtkriegen",
    "kaputtkriegtet": "kaputtkriegen",
    "kaputtlache": "kaputtlachen",
    "kaputtlachend": "kaputtlachen",
    "kaputtlachende": "kaputtlachend",
    "kaputtlachendem": "kaputtlachend",
    "kaputtlachenden": "kaputtlachend",
    "kaputtlachender": "kaputtlachend",
    "kaputtlachendere": "kaputtlachend",
    "kaputtlachenderem": "kaputtlachend",
    "kaputtlachenderen": "kaputtlachend",
    "kaputtlachenderer": "kaputtlachend",
    "kaputtlachenderes": "kaputtlachend",
    "kaputtlachendes": "kaputtlachend",
    "kaputtlachendste": "kaputtlachend",
    "kaputtlachendstem": "kaputtlachend",
    "kaputtlachendsten": "kaputtlachend",
    "kaputtlachendster": "kaputtlachend",
    "kaputtlachendstes": "kaputtlachend",
    "kaputtlachest": "kaputtlachen",
    "kaputtlachet": "kaputtlachen",
    "kaputtlachst": "kaputtlachen",
    "kaputtlacht": "kaputtlachen",
    "kaputtlachte": "kaputtlachen",
    "kaputtlachten": "kaputtlachen",
    "kaputtlachtest": "kaputtlachen",
    "kaputtlachtet": "kaputtlachen",
    "kaputtzugehen": "kaputtgehen",
    "kaputtzukriegen": "kaputtkriegen",
    "kaputtzulachen": "kaputtlachen",
    "kardiologischem": "kardiologisch",
    "kardiologischen": "kardiologisch",
    "kardiologischer": "kardiologisch",
    "kardiologisches": "kardiologisch",
    "kargem": "karg",
    "kargen": "karg",
    "karger": "karg",
    "karges": "karg",
    "karibische": "karibisch",
    "karibischem": "karibisch",
    "karibischen": "karibisch",
    "karibischer": "karibisch",
    "karibisches": "karibisch",
    "kariere": "karieren",
    "karierend": "karieren",
    "karierende": "karierend",
    "karierendem": "karierend",
    "karierenden": "karierend",
    "karierender": "karierend",
    "karierendes": "karierend",
    "karierest": "karieren",
    "karieret": "karieren",
    "karierst": "karieren",
    "kariert": "karieren",
    "karierte": "karieren",
    "kariertem": "kariert",
    "karierten": "karieren",
    "karierter": "kariert",
    "kariertes": "kariert",
    "kariertest": "karieren",
    "kariertet": "karieren",
    "karikaturale": "karikatural",
    "karikaturalem": "karikatural",
    "karikaturalen": "karikatural",
    "karikaturaler": "karikatural",
    "karikaturales": "karikatural",
    "karikaturistischem": "karikaturistisch",
    "karikaturistischen": "karikaturistisch",
    "karikaturistischer": "karikaturistisch",
    "karikaturistisches": "karikaturistisch",
    "karikiere": "karikieren",
    "karikierend": "karikieren",
    "karikierende": "karikierend",
    "karikierendem": "karikierend",
    "karikierenden": "karikierend",
    "karikierender": "karikierend",
    "karikierendere": "karikierend",
    "karikierenderem": "karikierend",
    "karikierenderen": "karikierend",
    "karikierenderer": "karikierend",
    "karikierenderes": "karikierend",
    "karikierendes": "karikierend",
    "karikierendste": "karikierend",
    "karikierendstem": "karikierend",
    "karikierendsten": "karikierend",
    "karikierendster": "karikierend",
    "karikierendstes": "karikierend",
    "karikierest": "karikieren",
    "karikieret": "karikieren",
    "karikierst": "karikieren",
    "karikiert": "karikieren",
    "karikierte": "karikieren",
    "karikiertem": "karikiert",
    "karikierten": "karikieren",
    "karikierter": "karikiert",
    "karikiertere": "karikiert",
    "karikierterem": "karikiert",
    "karikierteren": "karikiert",
    "karikierterer": "karikiert",
    "karikierteres": "karikiert",
    "karikiertes": "karikiert",
    "karikiertest": "karikieren",
    "karikierteste": "karikiert",
    "karikiertestem": "karikiert",
    "karikiertesten": "karikiert",
    "karikiertester": "karikiert",
    "karikiertestes": "karikiert",
    "karikiertet": "karikieren",
    "karitative": "karitativ",
    "karitativem": "karitativ",
    "karitativen": "karitativ",
    "karitativer": "karitativ",
    "karitatives": "karitativ",
    "kariösem": "kariös",
    "kariösen": "kariös",
    "kariöser": "kariös",
    "kariöses": "kariös",
    "karrend": "karren",
    "karrende": "karrend",
    "karrendem": "karrend",
    "karrenden": "karrend",
    "karrender": "karrend",
    "karrendes": "karrend",
    "karrest": "karren",
    "karret": "karren",
    "karrst": "karren",
    "karrt": "karren",
    "karrte": "karren",
    "karrten": "karren",
    "karrtest": "karren",
    "karrtet": "karren",
    "kartelliere": "kartellieren",
    "kartellierend": "kartellieren",
    "kartellierende": "kartellierend",
    "kartellierendem": "kartellierend",
    "kartellierenden": "kartellierend",
    "kartellierender": "kartellierend",
    "kartellierendes": "kartellierend",
    "kartellierest": "kartellieren",
    "kartellieret": "kartellieren",
    "kartellierst": "kartellieren",
    "kartelliert": "kartellieren",
    "kartellierte": "kartellieren",
    "kartelliertem": "kartelliert",
    "kartellierten": "kartellieren",
    "kartellierter": "kartelliert",
    "kartelliertes": "kartelliert",
    "kartelliertest": "kartellieren",
    "kartelliertet": "kartellieren",
    "kartend": "karten",
    "kartende": "kartend",
    "kartendem": "kartend",
    "kartenden": "kartend",
    "kartender": "kartend",
    "kartendes": "kartend",
    "kartesischem": "kartesisch",
    "kartesischen": "kartesisch",
    "kartesischer": "kartesisch",
    "kartesisches": "kartesisch",
    "kartest": "karten",
    "kartet": "karten",
    "kartete": "karten",
    "karteten": "karten",
    "kartetest": "karten",
    "kartetet": "karten",
    "kartographiere": "kartographieren",
    "kartographierend": "kartographieren",
    "kartographierende": "kartographierend",
    "kartographierendem": "kartographierend",
    "kartographierenden": "kartographierend",
    "kartographierender": "kartographierend",
    "kartographierendes": "kartographierend",
    "kartographierest": "kartographieren",
    "kartographieret": "kartographieren",
    "kartographierst": "kartographieren",
    "kartographiert": "kartographieren",
    "kartographierte": "kartographieren",
    "kartographiertem": "kartographiert",
    "kartographierten": "kartographieren",
    "kartographierter": "kartographiert",
    "kartographiertes": "kartographiert",
    "kartographiertest": "kartographieren",
    "kartographiertet": "kartographieren",
    "kartographische": "kartographisch",
    "kartographischem": "kartographisch",
    "kartographischen": "kartographisch",
    "kartographischer": "kartographisch",
    "kartographisches": "kartographisch",
    "kartoniere": "kartonieren",
    "kartonierend": "kartonieren",
    "kartonierende": "kartonierend",
    "kartonierendem": "kartonierend",
    "kartonierenden": "kartonierend",
    "kartonierender": "kartonierend",
    "kartonierendes": "kartonierend",
    "kartonierest": "kartonieren",
    "kartonieret": "kartonieren",
    "kartonierst": "kartonieren",
    "kartoniert": "kartonieren",
    "kartonierte": "kartonieren",
    "kartoniertem": "kartoniert",
    "kartonierten": "kartonieren",
    "kartonierter": "kartoniert",
    "kartoniertes": "kartoniert",
    "kartoniertest": "kartonieren",
    "kartoniertet": "kartonieren",
    "kaschiere": "kaschieren",
    "kaschierend": "kaschieren",
    "kaschierende": "kaschierend",
    "kaschierendem": "kaschierend",
    "kaschierenden": "kaschierend",
    "kaschierender": "kaschierend",
    "kaschierendere": "kaschierend",
    "kaschierenderem": "kaschierend",
    "kaschierenderen": "kaschierend",
    "kaschierenderer": "kaschierend",
    "kaschierenderes": "kaschierend",
    "kaschierendes": "kaschierend",
    "kaschierendste": "kaschierend",
    "kaschierendstem": "kaschierend",
    "kaschierendsten": "kaschierend",
    "kaschierendster": "kaschierend",
    "kaschierendstes": "kaschierend",
    "kaschierest": "kaschieren",
    "kaschieret": "kaschieren",
    "kaschierst": "kaschieren",
    "kaschiert": "kaschieren",
    "kaschierte": "kaschieren",
    "kaschiertem": "kaschiert",
    "kaschierten": "kaschieren",
    "kaschierter": "kaschiert",
    "kaschiertere": "kaschiert",
    "kaschierterem": "kaschiert",
    "kaschierteren": "kaschiert",
    "kaschierterer": "kaschiert",
    "kaschierteres": "kaschiert",
    "kaschiertes": "kaschiert",
    "kaschiertest": "kaschieren",
    "kaschierteste": "kaschiert",
    "kaschiertestem": "kaschiert",
    "kaschiertesten": "kaschiert",
    "kaschiertester": "kaschiert",
    "kaschiertestes": "kaschiert",
    "kaschiertet": "kaschieren",
    "kaserniere": "kasernieren",
    "kasernierend": "kasernieren",
    "kasernierende": "kasernierend",
    "kasernierendem": "kasernierend",
    "kasernierenden": "kasernierend",
    "kasernierender": "kasernierend",
    "kasernierendere": "kasernierend",
    "kasernierenderem": "kasernierend",
    "kasernierenderen": "kasernierend",
    "kasernierenderer": "kasernierend",
    "kasernierenderes": "kasernierend",
    "kasernierendes": "kasernierend",
    "kasernierendste": "kasernierend",
    "kasernierendstem": "kasernierend",
    "kasernierendsten": "kasernierend",
    "kasernierendster": "kasernierend",
    "kasernierendstes": "kasernierend",
    "kasernierest": "kasernieren",
    "kasernieret": "kasernieren",
    "kasernierst": "kasernieren",
    "kaserniert": "kasernieren",
    "kasernierte": "kasernieren",
    "kaserniertem": "kaserniert",
    "kasernierten": "kasernieren",
    "kasernierter": "kaserniert",
    "kaserniertere": "kaserniert",
    "kasernierterem": "kaserniert",
    "kasernierteren": "kaserniert",
    "kasernierterer": "kaserniert",
    "kasernierteres": "kaserniert",
    "kaserniertes": "kaserniert",
    "kaserniertest": "kasernieren",
    "kasernierteste": "kaserniert",
    "kaserniertestem": "kaserniert",
    "kaserniertesten": "kaserniert",
    "kaserniertester": "kaserniert",
    "kaserniertestes": "kaserniert",
    "kaserniertet": "kasernieren",
    "kaspere": "kaspern",
    "kaspernd": "kaspern",
    "kaspernde": "kaspernd",
    "kasperndem": "kaspernd",
    "kaspernden": "kaspernd",
    "kaspernder": "kaspernd",
    "kasperndere": "kaspernd",
    "kaspernderem": "kaspernd",
    "kaspernderen": "kaspernd",
    "kaspernderer": "kaspernd",
    "kaspernderes": "kaspernd",
    "kasperndes": "kaspernd",
    "kasperndste": "kaspernd",
    "kasperndstem": "kaspernd",
    "kasperndsten": "kaspernd",
    "kasperndster": "kaspernd",
    "kasperndstes": "kaspernd",
    "kasperst": "kaspern",
    "kaspert": "kaspern",
    "kasperte": "kaspern",
    "kasperten": "kaspern",
    "kaspertest": "kaspern",
    "kaspertet": "kaspern",
    "kassiere": "kassieren",
    "kassierend": "kassieren",
    "kassierende": "kassierend",
    "kassierendem": "kassierend",
    "kassierenden": "kassierend",
    "kassierender": "kassierend",
    "kassierendes": "kassierend",
    "kassierest": "kassieren",
    "kassieret": "kassieren",
    "kassierst": "kassieren",
    "kassiert": "kassieren",
    "kassierte": "kassieren",
    "kassiertem": "kassiert",
    "kassierten": "kassieren",
    "kassierter": "kassiert",
    "kassiertes": "kassiert",
    "kassiertest": "kassieren",
    "kassiertet": "kassieren",
    "katalanischem": "katalanisch",
    "katalanischen": "katalanisch",
    "katalanischer": "katalanisch",
    "katalanisches": "katalanisch",
    "katalogisiere": "katalogisieren",
    "katalogisierend": "katalogisieren",
    "katalogisierende": "katalogisierend",
    "katalogisierendem": "katalogisierend",
    "katalogisierenden": "katalogisierend",
    "katalogisierender": "katalogisierend",
    "katalogisierendes": "katalogisierend",
    "katalogisierest": "katalogisieren",
    "katalogisieret": "katalogisieren",
    "katalogisierst": "katalogisieren",
    "katalogisiert": "katalogisieren",
    "katalogisierte": "katalogisieren",
    "katalogisiertem": "katalogisiert",
    "katalogisierten": "katalogisieren",
    "katalogisierter": "katalogisiert",
    "katalogisiertes": "katalogisiert",
    "katalogisiertest": "katalogisieren",
    "katalogisiertet": "katalogisieren",
    "katalysiere": "katalysieren",
    "katalysierend": "katalysieren",
    "katalysierende": "katalysierend",
    "katalysierendem": "katalysierend",
    "katalysierenden": "katalysierend",
    "katalysierender": "katalysierend",
    "katalysierendes": "katalysierend",
    "katalysierest": "katalysieren",
    "katalysieret": "katalysieren",
    "katalysierst": "katalysieren",
    "katalysiert": "katalysieren",
    "katalysierte": "katalysieren",
    "katalysiertem": "katalysiert",
    "katalysierten": "katalysieren",
    "katalysierter": "katalysiert",
    "katalysiertes": "katalysiert",
    "katalysiertest": "katalysieren",
    "katalysiertet": "katalysieren",
    "katapultiere": "katapultieren",
    "katapultierend": "katapultieren",
    "katapultierende": "katapultierend",
    "katapultierendem": "katapultierend",
    "katapultierenden": "katapultierend",
    "katapultierender": "katapultierend",
    "katapultierendes": "katapultierend",
    "katapultierest": "katapultieren",
    "katapultieret": "katapultieren",
    "katapultierst": "katapultieren",
    "katapultiert": "katapultieren",
    "katapultierte": "katapultieren",
    "katapultiertem": "katapultiert",
    "katapultierten": "katapultieren",
    "katapultierter": "katapultiert",
    "katapultiertes": "katapultiert",
    "katapultiertest": "katapultieren",
    "katapultiertet": "katapultieren",
    "katastrophalem": "katastrophal",
    "katastrophalen": "katastrophal",
    "katastrophaler": "katastrophal",
    "katastrophalere": "katastrophal",
    "katastrophalerem": "katastrophal",
    "katastrophaleren": "katastrophal",
    "katastrophalerer": "katastrophal",
    "katastrophaleres": "katastrophal",
    "katastrophales": "katastrophal",
    "katastrophalste": "katastrophal",
    "katastrophalstem": "katastrophal",
    "katastrophalsten": "katastrophal",
    "katastrophalster": "katastrophal",
    "katastrophalstes": "katastrophal",
    "kategorialem": "kategorial",
    "kategorialen": "kategorial",
    "kategorialer": "kategorial",
    "kategoriales": "kategorial",
    "kategorischem": "kategorisch",
    "kategorischen": "kategorisch",
    "kategorischer": "kategorisch",
    "kategorisches": "kategorisch",
    "kategorisiere": "kategorisieren",
    "kategorisierend": "kategorisieren",
    "kategorisierende": "kategorisierend",
    "kategorisierendem": "kategorisierend",
    "kategorisierenden": "kategorisierend",
    "kategorisierender": "kategorisierend",
    "kategorisierendes": "kategorisierend",
    "kategorisierest": "kategorisieren",
    "kategorisieret": "kategorisieren",
    "kategorisierst": "kategorisieren",
    "kategorisiert": "kategorisieren",
    "kategorisierte": "kategorisieren",
    "kategorisiertem": "kategorisiert",
    "kategorisierten": "kategorisieren",
    "kategorisierter": "kategorisiert",
    "kategorisiertes": "kategorisiert",
    "kategorisiertest": "kategorisieren",
    "kategorisiertet": "kategorisieren",
    "katholischem": "katholisch",
    "katholischen": "katholisch",
    "katholischer": "katholisch",
    "katholischere": "katholisch",
    "katholischerem": "katholisch",
    "katholischeren": "katholisch",
    "katholischerer": "katholisch",
    "katholischeres": "katholisch",
    "katholisches": "katholisch",
    "katholischste": "katholisch",
    "katholischstem": "katholisch",
    "katholischsten": "katholisch",
    "katholischster": "katholisch",
    "katholischstes": "katholisch",
    "katholisiere": "katholisieren",
    "katholisierend": "katholisieren",
    "katholisierende": "katholisierend",
    "katholisierendem": "katholisierend",
    "katholisierenden": "katholisierend",
    "katholisierender": "katholisierend",
    "katholisierendere": "katholisierend",
    "katholisierenderem": "katholisierend",
    "katholisierenderen": "katholisierend",
    "katholisierenderer": "katholisierend",
    "katholisierenderes": "katholisierend",
    "katholisierendes": "katholisierend",
    "katholisierendste": "katholisierend",
    "katholisierendstem": "katholisierend",
    "katholisierendsten": "katholisierend",
    "katholisierendster": "katholisierend",
    "katholisierendstes": "katholisierend",
    "katholisierest": "katholisieren",
    "katholisieret": "katholisieren",
    "katholisierst": "katholisieren",
    "katholisiert": "katholisieren",
    "katholisierte": "katholisieren",
    "katholisiertem": "katholisiert",
    "katholisierten": "katholisieren",
    "katholisierter": "katholisiert",
    "katholisiertere": "katholisiert",
    "katholisierterem": "katholisiert",
    "katholisierteren": "katholisiert",
    "katholisierterer": "katholisiert",
    "katholisierteres": "katholisiert",
    "katholisiertes": "katholisiert",
    "katholisiertest": "katholisieren",
    "katholisierteste": "katholisiert",
    "katholisiertestem": "katholisiert",
    "katholisiertesten": "katholisiert",
    "katholisiertester": "katholisiert",
    "katholisiertestes": "katholisiert",
    "katholisiertet": "katholisieren",
    "katzenfreundlichem": "katzenfreundlich",
    "katzenfreundlichen": "katzenfreundlich",
    "katzenfreundlicher": "katzenfreundlich",
    "katzenfreundlichere": "katzenfreundlich",
    "katzenfreundlicherem": "katzenfreundlich",
    "katzenfreundlicheren": "katzenfreundlich",
    "katzenfreundlicherer": "katzenfreundlich",
    "katzenfreundlicheres": "katzenfreundlich",
    "katzenfreundliches": "katzenfreundlich",
    "katzenfreundlichste": "katzenfreundlich",
    "katzenfreundlichstem": "katzenfreundlich",
    "katzenfreundlichsten": "katzenfreundlich",
    "katzenfreundlichster": "katzenfreundlich",
    "katzenfreundlichstes": "katzenfreundlich",
    "kaue": "kauen",
    "kauend": "kauen",
    "kauende": "kauend",
    "kauendem": "kauend",
    "kauenden": "kauend",
    "kauender": "kauend",
    "kauendes": "kauend",
    "kauere": "kauern",
    "kauernd": "kauern",
    "kauernde": "kauernd",
    "kauerndem": "kauernd",
    "kauernden": "kauernd",
    "kauernder": "kauernd",
    "kauerndere": "kauernd",
    "kauernderem": "kauernd",
    "kauernderen": "kauernd",
    "kauernderer": "kauernd",
    "kauernderes": "kauernd",
    "kauerndes": "kauernd",
    "kauerndste": "kauernd",
    "kauerndstem": "kauernd",
    "kauerndsten": "kauernd",
    "kauerndster": "kauernd",
    "kauerndstes": "kauernd",
    "kauerst": "kauern",
    "kauert": "kauern",
    "kauerte": "kauern",
    "kauerten": "kauern",
    "kauertest": "kauern",
    "kauertet": "kauern",
    "kauest": "kauen",
    "kauet": "kauen",
    "kaufend": "kaufen",
    "kaufende": "kaufend",
    "kaufendem": "kaufend",
    "kaufenden": "kaufend",
    "kaufender": "kaufend",
    "kaufendes": "kaufend",
    "kaufest": "kaufen",
    "kaufet": "kaufen",
    "kaufkräftigem": "kaufkräftig",
    "kaufkräftigen": "kaufkräftig",
    "kaufkräftiger": "kaufkräftig",
    "kaufkräftigere": "kaufkräftig",
    "kaufkräftigerem": "kaufkräftig",
    "kaufkräftigeren": "kaufkräftig",
    "kaufkräftigerer": "kaufkräftig",
    "kaufkräftigeres": "kaufkräftig",
    "kaufkräftiges": "kaufkräftig",
    "kaufkräftigste": "kaufkräftig",
    "kaufkräftigstem": "kaufkräftig",
    "kaufkräftigsten": "kaufkräftig",
    "kaufkräftigster": "kaufkräftig",
    "kaufkräftigstes": "kaufkräftig",
    "kauflustige": "kauflustig",
    "kauflustigem": "kauflustig",
    "kauflustigen": "kauflustig",
    "kauflustiger": "kauflustig",
    "kauflustigere": "kauflustig",
    "kauflustigerem": "kauflustig",
    "kauflustigeren": "kauflustig",
    "kauflustigerer": "kauflustig",
    "kauflustigeres": "kauflustig",
    "kauflustiges": "kauflustig",
    "kauflustigste": "kauflustig",
    "kauflustigstem": "kauflustig",
    "kauflustigsten": "kauflustig",
    "kauflustigster": "kauflustig",
    "kauflustigstes": "kauflustig",
    "kaufmännische": "kaufmännisch",
    "kaufmännischem": "kaufmännisch",
    "kaufmännischen": "kaufmännisch",
    "kaufmännischer": "kaufmännisch",
    "kaufmännisches": "kaufmännisch",
    "kaufst": "kaufen",
    "kauft": "kaufen",
    "kaufte": "kaufen",
    "kauften": "kaufen",
    "kauftest": "kaufen",
    "kauftet": "kaufen",
    "kaukasischem": "kaukasisch",
    "kaukasischen": "kaukasisch",
    "kaukasischer": "kaukasisch",
    "kaukasisches": "kaukasisch",
    "kausalem": "kausal",
    "kausalen": "kausal",
    "kausaler": "kausal",
    "kausales": "kausal",
    "kaust": "kauen",
    "kaut": "kauen",
    "kaute": "kauen",
    "kauten": "kauen",
    "kautest": "kauen",
    "kautet": "kauen",
    "kauzigem": "kauzig",
    "kauzigen": "kauzig",
    "kauziger": "kauzig",
    "kauzigere": "kauzig",
    "kauzigerem": "kauzig",
    "kauzigeren": "kauzig",
    "kauzigerer": "kauzig",
    "kauzigeres": "kauzig",
    "kauziges": "kauzig",
    "kauzigste": "kauzig",
    "kauzigstem": "kauzig",
    "kauzigsten": "kauzig",
    "kauzigster": "kauzig",
    "kauzigstes": "kauzig",
    "keckem": "keck",
    "kecken": "keck",
    "kecker": "keck",
    "keckere": "keck",
    "keckerem": "keck",
    "keckeren": "keck",
    "keckerer": "keck",
    "keckeres": "keck",
    "keckes": "keck",
    "keckste": "keck",
    "keckstem": "keck",
    "kecksten": "keck",
    "keckster": "keck",
    "keckstes": "keck",
    "kegele": "kegeln",
    "kegelnd": "kegeln",
    "kegelnde": "kegelnd",
    "kegelndem": "kegelnd",
    "kegelnden": "kegelnd",
    "kegelnder": "kegelnd",
    "kegelndere": "kegelnd",
    "kegelnderem": "kegelnd",
    "kegelnderen": "kegelnd",
    "kegelnderer": "kegelnd",
    "kegelnderes": "kegelnd",
    "kegelndes": "kegelnd",
    "kegelndste": "kegelnd",
    "kegelndstem": "kegelnd",
    "kegelndsten": "kegelnd",
    "kegelndster": "kegelnd",
    "kegelndstes": "kegelnd",
    "kegelst": "kegeln",
    "kegelt": "kegeln",
    "kegelte": "kegeln",
    "kegelten": "kegeln",
    "kegeltest": "kegeln",
    "kegeltet": "kegeln",
    "kegle": "kegeln",
    "kehre": "kehren",
    "kehrend": "kehren",
    "kehrende": "kehrend",
    "kehrendem": "kehrend",
    "kehrenden": "kehrend",
    "kehrender": "kehrend",
    "kehrendes": "kehrend",
    "kehrest": "kehren",
    "kehret": "kehren",
    "kehrst": "kehren",
    "kehrt": "kehren",
    "kehrte": "kehren",
    "kehrten": "kehren",
    "kehrtest": "kehren",
    "kehrtet": "kehren",
    "keife": "keifen",
    "keifend": "keifen",
    "keifende": "keifend",
    "keifendem": "keifend",
    "keifenden": "keifend",
    "keifender": "keifend",
    "keifendere": "keifend",
    "keifenderem": "keifend",
    "keifenderen": "keifend",
    "keifenderer": "keifend",
    "keifenderes": "keifend",
    "keifendes": "keifend",
    "keifendste": "keifend",
    "keifendstem": "keifend",
    "keifendsten": "keifend",
    "keifendster": "keifend",
    "keifendstes": "keifend",
    "keifest": "keifen",
    "keifet": "keifen",
    "keifst": "keifen",
    "keift": "keifen",
    "keifte": "keifen",
    "keiften": "keifen",
    "keiftest": "keifen",
    "keiftet": "keifen",
    "keilend": "keilen",
    "keilende": "keilend",
    "keilendem": "keilend",
    "keilenden": "keilend",
    "keilender": "keilend",
    "keilendes": "keilend",
    "keilest": "keilen",
    "keilet": "keilen",
    "keilst": "keilen",
    "keilt": "keilen",
    "keilte": "keilen",
    "keilten": "keilen",
    "keiltest": "keilen",
    "keiltet": "keilen",
    "keimend": "keimen",
    "keimende": "keimend",
    "keimendem": "keimend",
    "keimenden": "keimend",
    "keimender": "keimend",
    "keimendere": "keimend",
    "keimenderem": "keimend",
    "keimenderen": "keimend",
    "keimenderer": "keimend",
    "keimenderes": "keimend",
    "keimendes": "keimend",
    "keimendste": "keimend",
    "keimendstem": "keimend",
    "keimendsten": "keimend",
    "keimendster": "keimend",
    "keimendstes": "keimend",
    "keimest": "keimen",
    "keimet": "keimen",
    "keimfreie": "keimfrei",
    "keimfreiem": "keimfrei",
    "keimfreien": "keimfrei",
    "keimfreier": "keimfrei",
    "keimfreiere": "keimfrei",
    "keimfreierem": "keimfrei",
    "keimfreieren": "keimfrei",
    "keimfreierer": "keimfrei",
    "keimfreieres": "keimfrei",
    "keimfreies": "keimfrei",
    "keimfreiste": "keimfrei",
    "keimfreistem": "keimfrei",
    "keimfreisten": "keimfrei",
    "keimfreister": "keimfrei",
    "keimfreistes": "keimfrei",
    "keimfähige": "keimfähig",
    "keimfähigem": "keimfähig",
    "keimfähigen": "keimfähig",
    "keimfähiger": "keimfähig",
    "keimfähigere": "keimfähig",
    "keimfähigerem": "keimfähig",
    "keimfähigeren": "keimfähig",
    "keimfähigerer": "keimfähig",
    "keimfähigeres": "keimfähig",
    "keimfähiges": "keimfähig",
    "keimfähigste": "keimfähig",
    "keimfähigstem": "keimfähig",
    "keimfähigsten": "keimfähig",
    "keimfähigster": "keimfähig",
    "keimfähigstes": "keimfähig",
    "keimst": "keimen",
    "keimt": "keimen",
    "keimte": "keimen",
    "keimten": "keimen",
    "keimtest": "keimen",
    "keimtet": "keimen",
    "keine": "kein",
    "keinem": "kein",
    "keinen": "kein",
    "keiner": "kein",
    "keines": "kein",
    "kellere": "kellern",
    "kellernd": "kellern",
    "kellernde": "kellernd",
    "kellerndem": "kellernd",
    "kellernden": "kellernd",
    "kellernder": "kellernd",
    "kellerndes": "kellernd",
    "kellerst": "kellern",
    "kellert": "kellern",
    "kellerte": "kellern",
    "kellerten": "kellern",
    "kellertest": "kellern",
    "kellertet": "kellern",
    "kellnere": "kellnern",
    "kellnernd": "kellnern",
    "kellnernde": "kellnernd",
    "kellnerndem": "kellnernd",
    "kellnernden": "kellnernd",
    "kellnernder": "kellnernd",
    "kellnerndes": "kellnernd",
    "kellnerst": "kellnern",
    "kellnert": "kellnern",
    "kellnerte": "kellnern",
    "kellnerten": "kellnern",
    "kellnertest": "kellnern",
    "kellnertet": "kellnern",
    "keltere": "keltern",
    "kelternd": "keltern",
    "kelternde": "kelternd",
    "kelterndem": "kelternd",
    "kelternden": "kelternd",
    "kelternder": "kelternd",
    "kelterndes": "kelternd",
    "kelterst": "keltern",
    "keltert": "keltern",
    "kelterte": "keltern",
    "kelterten": "keltern",
    "keltertest": "keltern",
    "keltertet": "keltern",
    "keltische": "keltisch",
    "keltischem": "keltisch",
    "keltischen": "keltisch",
    "keltischer": "keltisch",
    "keltisches": "keltisch",
    "kenne": "kennen",
    "kennend": "kennen",
    "kennende": "kennend",
    "kennendem": "kennend",
    "kennenden": "kennend",
    "kennender": "kennend",
    "kennendes": "kennend",
    "kennengelernt": "kennenlernen",
    "kennengelernte": "kennengelernt",
    "kennengelerntem": "kennengelernt",
    "kennengelernten": "kennengelernt",
    "kennengelernter": "kennengelernt",
    "kennengelerntes": "kennengelernt",
    "kennenlerne": "kennenlernen",
    "kennenlernend": "kennenlernen",
    "kennenlernende": "kennenlernend",
    "kennenlernendem": "kennenlernend",
    "kennenlernenden": "kennenlernend",
    "kennenlernender": "kennenlernend",
    "kennenlernendes": "kennenlernend",
    "kennenlernest": "kennenlernen",
    "kennenlernet": "kennenlernen",
    "kennenlernst": "kennenlernen",
    "kennenlernt": "kennenlernen",
    "kennenlernte": "kennenlernen",
    "kennenlernten": "kennenlernen",
    "kennenlerntest": "kennenlernen",
    "kennenlerntet": "kennenlernen",
    "kennenzulernen": "kennenlernen",
    "kennest": "kennen",
    "kennet": "kennen",
    "kennst": "kennen",
    "kennt": "kennen",
    "kenntliche": "kenntlich",
    "kenntlichem": "kenntlich",
    "kenntlichen": "kenntlich",
    "kenntlicher": "kenntlich",
    "kenntliches": "kenntlich",
    "kennzeichne": "kennzeichnen",
    "kennzeichnend": "kennzeichnen",
    "kennzeichnende": "kennzeichnend",
    "kennzeichnendem": "kennzeichnend",
    "kennzeichnenden": "kennzeichnend",
    "kennzeichnender": "kennzeichnend",
    "kennzeichnendes": "kennzeichnend",
    "kennzeichnest": "kennzeichnen",
    "kennzeichnet": "kennzeichnen",
    "kennzeichnete": "kennzeichnen",
    "kennzeichneten": "kennzeichnen",
    "kennzeichnetest": "kennzeichnen",
    "kennzeichnetet": "kennzeichnen",
    "kentere": "kentern",
    "kenternd": "kentern",
    "kenternde": "kenternd",
    "kenterndem": "kenternd",
    "kenternden": "kenternd",
    "kenternder": "kenternd",
    "kenterndes": "kenternd",
    "kenterst": "kentern",
    "kentert": "kentern",
    "kenterte": "kentern",
    "kenterten": "kentern",
    "kentertest": "kentern",
    "kentertet": "kentern",
    "kerbend": "kerben",
    "kerbende": "kerbend",
    "kerbendem": "kerbend",
    "kerbenden": "kerbend",
    "kerbender": "kerbend",
    "kerbendes": "kerbend",
    "kerbest": "kerben",
    "kerbet": "kerben",
    "kerbst": "kerben",
    "kerbt": "kerben",
    "kerbte": "kerben",
    "kerbten": "kerben",
    "kerbtest": "kerben",
    "kerbtet": "kerben",
    "kerkere": "kerkern",
    "kerkernd": "kerkern",
    "kerkernde": "kerkernd",
    "kerkerndem": "kerkernd",
    "kerkernden": "kerkernd",
    "kerkernder": "kerkernd",
    "kerkerndes": "kerkernd",
    "kerkerst": "kerkern",
    "kerkert": "kerkern",
    "kerkerte": "kerkern",
    "kerkerten": "kerkern",
    "kerkertest": "kerkern",
    "kerkertet": "kerkern",
    "kernend": "kernen",
    "kernende": "kernend",
    "kernendem": "kernend",
    "kernenden": "kernend",
    "kernender": "kernend",
    "kernendes": "kernend",
    "kernest": "kernen",
    "kernet": "kernen",
    "kernigem": "kernig",
    "kernigen": "kernig",
    "kerniger": "kernig",
    "kernigere": "kernig",
    "kernigerem": "kernig",
    "kernigeren": "kernig",
    "kernigerer": "kernig",
    "kernigeres": "kernig",
    "kerniges": "kernig",
    "kernigste": "kernig",
    "kernigstem": "kernig",
    "kernigsten": "kernig",
    "kernigster": "kernig",
    "kernigstes": "kernig",
    "kernlose": "kernlos",
    "kernlosem": "kernlos",
    "kernlosen": "kernlos",
    "kernloser": "kernlos",
    "kernlosere": "kernlos",
    "kernloserem": "kernlos",
    "kernloseren": "kernlos",
    "kernloserer": "kernlos",
    "kernloseres": "kernlos",
    "kernloses": "kernlos",
    "kernloseste": "kernlos",
    "kernlosestem": "kernlos",
    "kernlosesten": "kernlos",
    "kernlosester": "kernlos",
    "kernlosestes": "kernlos",
    "kernphysikalische": "kernphysikalisch",
    "kernphysikalischem": "kernphysikalisch",
    "kernphysikalischen": "kernphysikalisch",
    "kernphysikalischer": "kernphysikalisch",
    "kernphysikalisches": "kernphysikalisch",
    "kernst": "kernen",
    "kernt": "kernen",
    "kernte": "kernen",
    "kernten": "kernen",
    "kerntest": "kernen",
    "kerntet": "kernen",
    "kerzengeradem": "kerzengerade",
    "kerzengeraden": "kerzengerade",
    "kerzengerader": "kerzengerade",
    "kerzengerades": "kerzengerade",
    "kessele": "kesseln",
    "kesselnd": "kesseln",
    "kesselnde": "kesselnd",
    "kesselndem": "kesselnd",
    "kesselnden": "kesselnd",
    "kesselnder": "kesselnd",
    "kesselndes": "kesselnd",
    "kesselst": "kesseln",
    "kesselt": "kesseln",
    "kesselte": "kesseln",
    "kesselten": "kesseln",
    "kesseltest": "kesseln",
    "kesseltet": "kesseln",
    "kessem": "keß",
    "kessen": "keß",
    "kesser": "keß",
    "kessere": "keß",
    "kesserem": "keß",
    "kesseren": "keß",
    "kesserer": "keß",
    "kesseres": "keß",
    "kesses": "keß",
    "kesseste": "keß",
    "kessestem": "keß",
    "kessesten": "keß",
    "kessester": "keß",
    "kessestes": "keß",
    "kessle": "kesseln",
    "kettend": "ketten",
    "kettende": "kettend",
    "kettendem": "kettend",
    "kettenden": "kettend",
    "kettender": "kettend",
    "kettendes": "kettend",
    "kettest": "ketten",
    "kettet": "ketten",
    "kettete": "ketten",
    "ketteten": "ketten",
    "kettetest": "ketten",
    "kettetet": "ketten",
    "ketzerische": "ketzerisch",
    "ketzerischem": "ketzerisch",
    "ketzerischen": "ketzerisch",
    "ketzerischer": "ketzerisch",
    "ketzerischere": "ketzerisch",
    "ketzerischerem": "ketzerisch",
    "ketzerischeren": "ketzerisch",
    "ketzerischerer": "ketzerisch",
    "ketzerischeres": "ketzerisch",
    "ketzerisches": "ketzerisch",
    "ketzerischste": "ketzerisch",
    "ketzerischstem": "ketzerisch",
    "ketzerischsten": "ketzerisch",
    "ketzerischster": "ketzerisch",
    "ketzerischstes": "ketzerisch",
    "keuche": "keuchen",
    "keuchend": "keuchen",
    "keuchende": "keuchend",
    "keuchendem": "keuchend",
    "keuchenden": "keuchend",
    "keuchender": "keuchend",
    "keuchendere": "keuchend",
    "keuchenderem": "keuchend",
    "keuchenderen": "keuchend",
    "keuchenderer": "keuchend",
    "keuchenderes": "keuchend",
    "keuchendes": "keuchend",
    "keuchendste": "keuchend",
    "keuchendstem": "keuchend",
    "keuchendsten": "keuchend",
    "keuchendster": "keuchend",
    "keuchendstes": "keuchend",
    "keuchest": "keuchen",
    "keuchet": "keuchen",
    "keuchst": "keuchen",
    "keucht": "keuchen",
    "keuchte": "keuchen",
    "keuchten": "keuchen",
    "keuchtest": "keuchen",
    "keuchtet": "keuchen",
    "keuschem": "keusch",
    "keuschen": "keusch",
    "keuscher": "keusch",
    "keuschere": "keusch",
    "keuscherem": "keusch",
    "keuscheren": "keusch",
    "keuscherer": "keusch",
    "keuscheres": "keusch",
    "keusches": "keusch",
    "keuschste": "keusch",
    "keuschstem": "keusch",
    "keuschsten": "keusch",
    "keuschster": "keusch",
    "keuschstes": "keusch",
    "kichere": "kichern",
    "kichernd": "kichern",
    "kichernde": "kichernd",
    "kicherndem": "kichernd",
    "kichernden": "kichernd",
    "kichernder": "kichernd",
    "kicherndere": "kichernd",
    "kichernderem": "kichernd",
    "kichernderen": "kichernd",
    "kichernderer": "kichernd",
    "kichernderes": "kichernd",
    "kicherndes": "kichernd",
    "kicherndste": "kichernd",
    "kicherndstem": "kichernd",
    "kicherndsten": "kichernd",
    "kicherndster": "kichernd",
    "kicherndstes": "kichernd",
    "kicherst": "kichern",
    "kichert": "kichern",
    "kicherte": "kichern",
    "kicherten": "kichern",
    "kichertest": "kichern",
    "kichertet": "kichern",
    "kicke": "kicken",
    "kickend": "kicken",
    "kickende": "kickend",
    "kickendem": "kickend",
    "kickenden": "kickend",
    "kickender": "kickend",
    "kickendes": "kickend",
    "kickest": "kicken",
    "kicket": "kicken",
    "kickst": "kicken",
    "kickt": "kicken",
    "kickte": "kicken",
    "kickten": "kicken",
    "kicktest": "kicken",
    "kicktet": "kicken",
    "kieke": "kieken",
    "kiekend": "kieken",
    "kiekende": "kiekend",
    "kiekendem": "kiekend",
    "kiekenden": "kiekend",
    "kiekender": "kiekend",
    "kiekendes": "kiekend",
    "kiekest": "kieken",
    "kieket": "kieken",
    "kiekst": "kieken",
    "kiekt": "kieken",
    "kiekte": "kieken",
    "kiekten": "kieken",
    "kiektest": "kieken",
    "kiektet": "kieken",
    "kiffe": "kiffen",
    "kiffend": "kiffen",
    "kiffende": "kiffend",
    "kiffendem": "kiffend",
    "kiffenden": "kiffend",
    "kiffender": "kiffend",
    "kiffendes": "kiffend",
    "kiffest": "kiffen",
    "kiffet": "kiffen",
    "kiffst": "kiffen",
    "kifft": "kiffen",
    "kiffte": "kiffen",
    "kifften": "kiffen",
    "kifftest": "kiffen",
    "kifftet": "kiffen",
    "kille": "killen",
    "killend": "killen",
    "killende": "killend",
    "killendem": "killend",
    "killenden": "killend",
    "killender": "killend",
    "killendes": "killend",
    "killest": "killen",
    "killet": "killen",
    "killst": "killen",
    "killt": "killen",
    "killte": "killen",
    "killten": "killen",
    "killtest": "killen",
    "killtet": "killen",
    "kilometerlangem": "kilometerlang",
    "kilometerlangen": "kilometerlang",
    "kilometerlanger": "kilometerlang",
    "kilometerlanges": "kilometerlang",
    "kilometerweitem": "kilometerweit",
    "kilometerweiten": "kilometerweit",
    "kilometerweiter": "kilometerweit",
    "kilometerweites": "kilometerweit",
    "kinderfeindlichem": "kinderfeindlich",
    "kinderfeindlichen": "kinderfeindlich",
    "kinderfeindlicher": "kinderfeindlich",
    "kinderfeindlichere": "kinderfeindlich",
    "kinderfeindlicherem": "kinderfeindlich",
    "kinderfeindlicheren": "kinderfeindlich",
    "kinderfeindlicherer": "kinderfeindlich",
    "kinderfeindlicheres": "kinderfeindlich",
    "kinderfeindliches": "kinderfeindlich",
    "kinderfeindlichste": "kinderfeindlich",
    "kinderfeindlichstem": "kinderfeindlich",
    "kinderfeindlichsten": "kinderfeindlich",
    "kinderfeindlichster": "kinderfeindlich",
    "kinderfeindlichstes": "kinderfeindlich",
    "kinderleichtem": "kinderleicht",
    "kinderleichten": "kinderleicht",
    "kinderleichter": "kinderleicht",
    "kinderleichtere": "kinderleicht",
    "kinderleichterem": "kinderleicht",
    "kinderleichteren": "kinderleicht",
    "kinderleichterer": "kinderleicht",
    "kinderleichteres": "kinderleicht",
    "kinderleichtes": "kinderleicht",
    "kinderleichteste": "kinderleicht",
    "kinderleichtestem": "kinderleicht",
    "kinderleichtesten": "kinderleicht",
    "kinderleichtester": "kinderleicht",
    "kinderleichtestes": "kinderleicht",
    "kinderliebe": "kinderlieb",
    "kinderliebem": "kinderlieb",
    "kinderlieben": "kinderlieb",
    "kinderlieber": "kinderlieb",
    "kinderliebere": "kinderlieb",
    "kinderlieberem": "kinderlieb",
    "kinderlieberen": "kinderlieb",
    "kinderlieberer": "kinderlieb",
    "kinderlieberes": "kinderlieb",
    "kinderliebes": "kinderlieb",
    "kinderliebste": "kinderlieb",
    "kinderliebstem": "kinderlieb",
    "kinderliebsten": "kinderlieb",
    "kinderliebster": "kinderlieb",
    "kinderliebstes": "kinderlieb",
    "kinderlose": "kinderlos",
    "kinderlosem": "kinderlos",
    "kinderlosen": "kinderlos",
    "kinderloser": "kinderlos",
    "kinderloses": "kinderlos",
    "kinderreichem": "kinderreich",
    "kinderreichen": "kinderreich",
    "kinderreicher": "kinderreich",
    "kinderreichere": "kinderreich",
    "kinderreicherem": "kinderreich",
    "kinderreicheren": "kinderreich",
    "kinderreicherer": "kinderreich",
    "kinderreicheres": "kinderreich",
    "kinderreiches": "kinderreich",
    "kinderreichste": "kinderreich",
    "kinderreichstem": "kinderreich",
    "kinderreichsten": "kinderreich",
    "kinderreichster": "kinderreich",
    "kinderreichstes": "kinderreich",
    "kindersichere": "kindersicher",
    "kindersicherem": "kindersicher",
    "kindersicheren": "kindersicher",
    "kindersicherer": "kindersicher",
    "kindersicherere": "kindersicher",
    "kindersichererem": "kindersicher",
    "kindersichereren": "kindersicher",
    "kindersichererer": "kindersicher",
    "kindersichereres": "kindersicher",
    "kindersicheres": "kindersicher",
    "kindersicherste": "kindersicher",
    "kindersicherstem": "kindersicher",
    "kindersichersten": "kindersicher",
    "kindersicherster": "kindersicher",
    "kindersicherstes": "kindersicher",
    "kindgemäßem": "kindgemäß",
    "kindgemäßen": "kindgemäß",
    "kindgemäßer": "kindgemäß",
    "kindgemäßes": "kindgemäß",
    "kindhafte": "kindhaft",
    "kindhaftem": "kindhaft",
    "kindhaften": "kindhaft",
    "kindhafter": "kindhaft",
    "kindhaftere": "kindhaft",
    "kindhafterem": "kindhaft",
    "kindhafteren": "kindhaft",
    "kindhafterer": "kindhaft",
    "kindhafteres": "kindhaft",
    "kindhaftes": "kindhaft",
    "kindhafteste": "kindhaft",
    "kindhaftestem": "kindhaft",
    "kindhaftesten": "kindhaft",
    "kindhaftester": "kindhaft",
    "kindhaftestes": "kindhaft",
    "kindischem": "kindisch",
    "kindischen": "kindisch",
    "kindischer": "kindisch",
    "kindischere": "kindisch",
    "kindischerem": "kindisch",
    "kindischeren": "kindisch",
    "kindischerer": "kindisch",
    "kindischeres": "kindisch",
    "kindisches": "kindisch",
    "kindischste": "kindisch",
    "kindischstem": "kindisch",
    "kindischsten": "kindisch",
    "kindischster": "kindisch",
    "kindischstes": "kindisch",
    "kindliche": "kindlich",
    "kindlichem": "kindlich",
    "kindlichen": "kindlich",
    "kindlicher": "kindlich",
    "kindlichere": "kindlich",
    "kindlicherem": "kindlich",
    "kindlicheren": "kindlich",
    "kindlicherer": "kindlich",
    "kindlicheres": "kindlich",
    "kindliches": "kindlich",
    "kindlichste": "kindlich",
    "kindlichstem": "kindlich",
    "kindlichsten": "kindlich",
    "kindlichster": "kindlich",
    "kindlichstes": "kindlich",
    "kinematischem": "kinematisch",
    "kinematischen": "kinematisch",
    "kinematischer": "kinematisch",
    "kinematisches": "kinematisch",
    "kinetische": "kinetisch",
    "kinetischem": "kinetisch",
    "kinetischen": "kinetisch",
    "kinetischer": "kinetisch",
    "kinetisches": "kinetisch",
    "kippend": "kippen",
    "kippende": "kippend",
    "kippendem": "kippend",
    "kippenden": "kippend",
    "kippender": "kippend",
    "kippendes": "kippend",
    "kippest": "kippen",
    "kippet": "kippen",
    "kippst": "kippen",
    "kippt": "kippen",
    "kippte": "kippen",
    "kippten": "kippen",
    "kipptest": "kippen",
    "kipptet": "kippen",
    "kirchenmusikalischem": "kirchenmusikalisch",
    "kirchenmusikalischen": "kirchenmusikalisch",
    "kirchenmusikalischer": "kirchenmusikalisch",
    "kirchenmusikalisches": "kirchenmusikalisch",
    "kirchenpolitische": "kirchenpolitisch",
    "kirchenpolitischem": "kirchenpolitisch",
    "kirchenpolitischen": "kirchenpolitisch",
    "kirchenpolitischer": "kirchenpolitisch",
    "kirchenpolitisches": "kirchenpolitisch",
    "kirchenrechtliche": "kirchenrechtlich",
    "kirchenrechtlichem": "kirchenrechtlich",
    "kirchenrechtlichen": "kirchenrechtlich",
    "kirchenrechtlicher": "kirchenrechtlich",
    "kirchenrechtliches": "kirchenrechtlich",
    "kirchlichem": "kirchlich",
    "kirchlichen": "kirchlich",
    "kirchlicher": "kirchlich",
    "kirchliches": "kirchlich",
    "kitschigem": "kitschig",
    "kitschigen": "kitschig",
    "kitschiger": "kitschig",
    "kitschigere": "kitschig",
    "kitschigerem": "kitschig",
    "kitschigeren": "kitschig",
    "kitschigerer": "kitschig",
    "kitschigeres": "kitschig",
    "kitschiges": "kitschig",
    "kitschigste": "kitschig",
    "kitschigstem": "kitschig",
    "kitschigsten": "kitschig",
    "kitschigster": "kitschig",
    "kitschigstes": "kitschig",
    "kitte": "kitten",
    "kittend": "kitten",
    "kittende": "kittend",
    "kittendem": "kittend",
    "kittenden": "kittend",
    "kittender": "kittend",
    "kittendere": "kittend",
    "kittenderem": "kittend",
    "kittenderen": "kittend",
    "kittenderer": "kittend",
    "kittenderes": "kittend",
    "kittendes": "kittend",
    "kittendste": "kittend",
    "kittendstem": "kittend",
    "kittendsten": "kittend",
    "kittendster": "kittend",
    "kittendstes": "kittend",
    "kittest": "kitten",
    "kittet": "kitten",
    "kittete": "kitten",
    "kitteten": "kitten",
    "kittetest": "kitten",
    "kittetet": "kitten",
    "kitzele": "kitzeln",
    "kitzelige": "kitzelig",
    "kitzeligem": "kitzelig",
    "kitzeligen": "kitzelig",
    "kitzeliger": "kitzelig",
    "kitzeligere": "kitzelig",
    "kitzeligerem": "kitzelig",
    "kitzeligeren": "kitzelig",
    "kitzeligerer": "kitzelig",
    "kitzeligeres": "kitzelig",
    "kitzeliges": "kitzelig",
    "kitzeligste": "kitzelig",
    "kitzeligstem": "kitzelig",
    "kitzeligsten": "kitzelig",
    "kitzeligster": "kitzelig",
    "kitzeligstes": "kitzelig",
    "kitzelnd": "kitzeln",
    "kitzelnde": "kitzelnd",
    "kitzelndem": "kitzelnd",
    "kitzelnden": "kitzelnd",
    "kitzelnder": "kitzelnd",
    "kitzelndere": "kitzelnd",
    "kitzelnderem": "kitzelnd",
    "kitzelnderen": "kitzelnd",
    "kitzelnderer": "kitzelnd",
    "kitzelnderes": "kitzelnd",
    "kitzelndes": "kitzelnd",
    "kitzelndste": "kitzelnd",
    "kitzelndstem": "kitzelnd",
    "kitzelndsten": "kitzelnd",
    "kitzelndster": "kitzelnd",
    "kitzelndstes": "kitzelnd",
    "kitzelst": "kitzeln",
    "kitzelt": "kitzeln",
    "kitzelte": "kitzeln",
    "kitzelten": "kitzeln",
    "kitzeltest": "kitzeln",
    "kitzeltet": "kitzeln",
    "kitzle": "kitzeln",
    "kitzligem": "kitzlig",
    "kitzligen": "kitzlig",
    "kitzliger": "kitzlig",
    "kitzligere": "kitzlig",
    "kitzligerem": "kitzlig",
    "kitzligeren": "kitzlig",
    "kitzligerer": "kitzlig",
    "kitzligeres": "kitzlig",
    "kitzliges": "kitzlig",
    "kitzligste": "kitzlig",
    "kitzligstem": "kitzlig",
    "kitzligsten": "kitzlig",
    "kitzligster": "kitzlig",
    "kitzligstes": "kitzlig",
    "klabastere": "klabastern",
    "klabasternd": "klabastern",
    "klabasternde": "klabasternd",
    "klabasterndem": "klabasternd",
    "klabasternden": "klabasternd",
    "klabasternder": "klabasternd",
    "klabasterndes": "klabasternd",
    "klabasterst": "klabastern",
    "klabastert": "klabastern",
    "klabasterte": "klabastern",
    "klabastertem": "klabastert",
    "klabasterten": "klabastern",
    "klabasterter": "klabastert",
    "klabastertes": "klabastert",
    "klabastertest": "klabastern",
    "klabastertet": "klabastern",
    "klackere": "klackern",
    "klackernd": "klackern",
    "klackernde": "klackernd",
    "klackerndem": "klackernd",
    "klackernden": "klackernd",
    "klackernder": "klackernd",
    "klackerndes": "klackernd",
    "klackerst": "klackern",
    "klackert": "klackern",
    "klackerte": "klackern",
    "klackerten": "klackern",
    "klackertest": "klackern",
    "klackertet": "klackern",
    "klaffe": "klaffen",
    "klaffend": "klaffen",
    "klaffende": "klaffend",
    "klaffendem": "klaffend",
    "klaffenden": "klaffend",
    "klaffender": "klaffend",
    "klaffendere": "klaffend",
    "klaffenderem": "klaffend",
    "klaffenderen": "klaffend",
    "klaffenderer": "klaffend",
    "klaffenderes": "klaffend",
    "klaffendes": "klaffend",
    "klaffendste": "klaffend",
    "klaffendstem": "klaffend",
    "klaffendsten": "klaffend",
    "klaffendster": "klaffend",
    "klaffendstes": "klaffend",
    "klaffest": "klaffen",
    "klaffet": "klaffen",
    "klaffst": "klaffen",
    "klafft": "klaffen",
    "klaffte": "klaffen",
    "klafften": "klaffen",
    "klafftest": "klaffen",
    "klafftet": "klaffen",
    "klagbarem": "klagbar",
    "klagbaren": "klagbar",
    "klagbarer": "klagbar",
    "klagbares": "klagbar",
    "klage": "klagen",
    "klagend": "klagen",
    "klagende": "klagend",
    "klagendem": "klagend",
    "klagenden": "klagend",
    "klagender": "klagend",
    "klagendes": "klagend",
    "klagest": "klagen",
    "klaget": "klagen",
    "klaglose": "klaglos",
    "klaglosem": "klaglos",
    "klaglosen": "klaglos",
    "klagloser": "klaglos",
    "klaglosere": "klaglos",
    "klagloserem": "klaglos",
    "klagloseren": "klaglos",
    "klagloserer": "klaglos",
    "klagloseres": "klaglos",
    "klagloses": "klaglos",
    "klagloseste": "klaglos",
    "klaglosestem": "klaglos",
    "klaglosesten": "klaglos",
    "klaglosester": "klaglos",
    "klaglosestes": "klaglos",
    "klagst": "klagen",
    "klagt": "klagen",
    "klagte": "klagen",
    "klagten": "klagen",
    "klagtest": "klagen",
    "klagtet": "klagen",
    "klammem": "klamm",
    "klammen": "klamm",
    "klammer": "klammern",
    "klammere": "klammern",
    "klammerem": "klamm",
    "klammeren": "klamm",
    "klammerer": "klamm",
    "klammeres": "klamm",
    "klammernd": "klammern",
    "klammernde": "klammernd",
    "klammerndem": "klammernd",
    "klammernden": "klammernd",
    "klammernder": "klammernd",
    "klammerndere": "klammernd",
    "klammernderem": "klammernd",
    "klammernderen": "klammernd",
    "klammernderer": "klammernd",
    "klammernderes": "klammernd",
    "klammerndes": "klammernd",
    "klammerndste": "klammernd",
    "klammerndstem": "klammernd",
    "klammerndsten": "klammernd",
    "klammerndster": "klammernd",
    "klammerndstes": "klammernd",
    "klammerst": "klammern",
    "klammert": "klammern",
    "klammerte": "klammern",
    "klammerten": "klammern",
    "klammertest": "klammern",
    "klammertet": "klammern",
    "klammes": "klamm",
    "klammheimliche": "klammheimlich",
    "klammheimlichem": "klammheimlich",
    "klammheimlichen": "klammheimlich",
    "klammheimlicher": "klammheimlich",
    "klammheimliches": "klammheimlich",
    "klammste": "klamm",
    "klammstem": "klamm",
    "klammsten": "klamm",
    "klammster": "klamm",
    "klammstes": "klamm",
    "klamüsere": "klamüsern",
    "klamüsernd": "klamüsern",
    "klamüsernde": "klamüsernd",
    "klamüserndem": "klamüsernd",
    "klamüsernden": "klamüsernd",
    "klamüsernder": "klamüsernd",
    "klamüserndes": "klamüsernd",
    "klamüserst": "klamüsern",
    "klamüsert": "klamüsern",
    "klamüserte": "klamüsern",
    "klamüsertem": "klamüsert",
    "klamüserten": "klamüsern",
    "klamüserter": "klamüsert",
    "klamüsertes": "klamüsert",
    "klamüsertest": "klamüsern",
    "klamüsertet": "klamüsern",
    "klang": "klingen",
    "klangen": "klingen",
    "klangliche": "klanglich",
    "klanglichem": "klanglich",
    "klanglichen": "klanglich",
    "klanglicher": "klanglich",
    "klangliches": "klanglich",
    "klanglose": "klanglos",
    "klanglosem": "klanglos",
    "klanglosen": "klanglos",
    "klangloser": "klanglos",
    "klanglosere": "klanglos",
    "klangloserem": "klanglos",
    "klangloseren": "klanglos",
    "klangloserer": "klanglos",
    "klangloseres": "klanglos",
    "klangloses": "klanglos",
    "klangloseste": "klanglos",
    "klanglosestem": "klanglos",
    "klanglosesten": "klanglos",
    "klanglosester": "klanglos",
    "klanglosestes": "klanglos",
    "klangst": "klingen",
    "klangt": "klingen",
    "klangvolle": "klangvoll",
    "klangvollem": "klangvoll",
    "klangvollen": "klangvoll",
    "klangvoller": "klangvoll",
    "klangvollere": "klangvoll",
    "klangvollerem": "klangvoll",
    "klangvolleren": "klangvoll",
    "klangvollerer": "klangvoll",
    "klangvolleres": "klangvoll",
    "klangvolles": "klangvoll",
    "klangvollste": "klangvoll",
    "klangvollstem": "klangvoll",
    "klangvollsten": "klangvoll",
    "klangvollster": "klangvoll",
    "klangvollstes": "klangvoll",
    "klappe": "klappen",
    "klappend": "klappen",
    "klappende": "klappend",
    "klappendem": "klappend",
    "klappenden": "klappend",
    "klappender": "klappend",
    "klappendes": "klappend",
    "klappere": "klappern",
    "klapperige": "klapperig",
    "klapperigem": "klapperig",
    "klapperigen": "klapperig",
    "klapperiger": "klapperig",
    "klapperigere": "klapperig",
    "klapperigerem": "klapperig",
    "klapperigeren": "klapperig",
    "klapperigerer": "klapperig",
    "klapperigeres": "klapperig",
    "klapperiges": "klapperig",
    "klapperigste": "klapperig",
    "klapperigstem": "klapperig",
    "klapperigsten": "klapperig",
    "klapperigster": "klapperig",
    "klapperigstes": "klapperig",
    "klappernd": "klappern",
    "klappernde": "klappernd",
    "klapperndem": "klappernd",
    "klappernden": "klappernd",
    "klappernder": "klappernd",
    "klapperndere": "klappernd",
    "klappernderem": "klappernd",
    "klappernderen": "klappernd",
    "klappernderer": "klappernd",
    "klappernderes": "klappernd",
    "klapperndes": "klappernd",
    "klapperndste": "klappernd",
    "klapperndstem": "klappernd",
    "klapperndsten": "klappernd",
    "klapperndster": "klappernd",
    "klapperndstes": "klappernd",
    "klapperst": "klappern",
    "klappert": "klappern",
    "klapperte": "klappern",
    "klapperten": "klappern",
    "klappertest": "klappern",
    "klappertet": "klappern",
    "klappest": "klappen",
    "klappet": "klappen",
    "klapprige": "klapprig",
    "klapprigem": "klapprig",
    "klapprigen": "klapprig",
    "klappriger": "klapprig",
    "klapprigere": "klapprig",
    "klapprigerem": "klapprig",
    "klapprigeren": "klapprig",
    "klapprigerer": "klapprig",
    "klapprigeres": "klapprig",
    "klappriges": "klapprig",
    "klapprigste": "klapprig",
    "klapprigstem": "klapprig",
    "klapprigsten": "klapprig",
    "klapprigster": "klapprig",
    "klapprigstes": "klapprig",
    "klappst": "klappen",
    "klappt": "klappen",
    "klappte": "klappen",
    "klappten": "klappen",
    "klapptest": "klappen",
    "klapptet": "klappen",
    "klar": "klaren",
    "klare": "klaren",
    "klarem": "klar",
    "klaren": "klar",
    "klarend": "klaren",
    "klarende": "klarend",
    "klarendem": "klarend",
    "klarenden": "klarend",
    "klarender": "klarend",
    "klarendes": "klarend",
    "klarer": "klar",
    "klarere": "klar",
    "klarerem": "klar",
    "klareren": "klar",
    "klarerer": "klar",
    "klareres": "klar",
    "klares": "klar",
    "klarest": "klaren",
    "klaret": "klaren",
    "klargekommen": "klarkommen",
    "klargekommene": "klargekommen",
    "klargekommenem": "klargekommen",
    "klargekommenen": "klargekommen",
    "klargekommener": "klargekommen",
    "klargekommenes": "klargekommen",
    "klargekriegt": "klarkriegen",
    "klargekriegte": "klargekriegt",
    "klargekriegtem": "klargekriegt",
    "klargekriegten": "klargekriegt",
    "klargekriegter": "klargekriegt",
    "klargekriegtes": "klargekriegt",
    "klargemacht": "klarmachen",
    "klargemachte": "klargemacht",
    "klargemachtem": "klargemacht",
    "klargemachten": "klargemacht",
    "klargemachter": "klargemacht",
    "klargemachtes": "klargemacht",
    "klargesehen": "klarsehen",
    "klargesehene": "klargesehen",
    "klargesehenem": "klargesehen",
    "klargesehenen": "klargesehen",
    "klargesehener": "klargesehen",
    "klargesehenes": "klargesehen",
    "klargestellt": "klarstellen",
    "klargestellte": "klargestellt",
    "klargestelltem": "klargestellt",
    "klargestellten": "klargestellt",
    "klargestellter": "klargestellt",
    "klargestelltere": "klargestellt",
    "klargestellterem": "klargestellt",
    "klargestellteren": "klargestellt",
    "klargestellterer": "klargestellt",
    "klargestellteres": "klargestellt",
    "klargestelltes": "klargestellt",
    "klargestellteste": "klargestellt",
    "klargestelltestem": "klargestellt",
    "klargestelltesten": "klargestellt",
    "klargestelltester": "klargestellt",
    "klargestelltestes": "klargestellt",
    "klarkam": "klarkommen",
    "klarkamen": "klarkommen",
    "klarkamst": "klarkommen",
    "klarkamt": "klarkommen",
    "klarkomme": "klarkommen",
    "klarkommend": "klarkommen",
    "klarkommende": "klarkommend",
    "klarkommendem": "klarkommend",
    "klarkommenden": "klarkommend",
    "klarkommender": "klarkommend",
    "klarkommendes": "klarkommend",
    "klarkommest": "klarkommen",
    "klarkommet": "klarkommen",
    "klarkommst": "klarkommen",
    "klarkommt": "klarkommen",
    "klarkriege": "klarkriegen",
    "klarkriegend": "klarkriegen",
    "klarkriegende": "klarkriegend",
    "klarkriegendem": "klarkriegend",
    "klarkriegenden": "klarkriegend",
    "klarkriegender": "klarkriegend",
    "klarkriegendes": "klarkriegend",
    "klarkriegest": "klarkriegen",
    "klarkrieget": "klarkriegen",
    "klarkriegst": "klarkriegen",
    "klarkriegt": "klarkriegen",
    "klarkriegte": "klarkriegen",
    "klarkriegten": "klarkriegen",
    "klarkriegtest": "klarkriegen",
    "klarkriegtet": "klarkriegen",
    "klarkäme": "klarkommen",
    "klarkämen": "klarkommen",
    "klarkämest": "klarkommen",
    "klarkämet": "klarkommen",
    "klarmache": "klarmachen",
    "klarmachend": "klarmachen",
    "klarmachende": "klarmachend",
    "klarmachendem": "klarmachend",
    "klarmachenden": "klarmachend",
    "klarmachender": "klarmachend",
    "klarmachendes": "klarmachend",
    "klarmachest": "klarmachen",
    "klarmachet": "klarmachen",
    "klarmachst": "klarmachen",
    "klarmacht": "klarmachen",
    "klarmachte": "klarmachen",
    "klarmachten": "klarmachen",
    "klarmachtest": "klarmachen",
    "klarmachtet": "klarmachen",
    "klarsah": "klarsehen",
    "klarsahen": "klarsehen",
    "klarsahst": "klarsehen",
    "klarsaht": "klarsehen",
    "klarsehe": "klarsehen",
    "klarsehend": "klarsehen",
    "klarsehende": "klarsehend",
    "klarsehendem": "klarsehend",
    "klarsehenden": "klarsehend",
    "klarsehender": "klarsehend",
    "klarsehendere": "klarsehend",
    "klarsehenderem": "klarsehend",
    "klarsehenderen": "klarsehend",
    "klarsehenderer": "klarsehend",
    "klarsehenderes": "klarsehend",
    "klarsehendes": "klarsehend",
    "klarsehendste": "klarsehend",
    "klarsehendstem": "klarsehend",
    "klarsehendsten": "klarsehend",
    "klarsehendster": "klarsehend",
    "klarsehendstes": "klarsehend",
    "klarsehest": "klarsehen",
    "klarsehet": "klarsehen",
    "klarseht": "klarsehen",
    "klarsiehst": "klarsehen",
    "klarsieht": "klarsehen",
    "klarst": "klaren",
    "klarste": "klar",
    "klarstelle": "klarstellen",
    "klarstellend": "klarstellen",
    "klarstellende": "klarstellend",
    "klarstellendem": "klarstellend",
    "klarstellenden": "klarstellend",
    "klarstellender": "klarstellend",
    "klarstellendere": "klarstellend",
    "klarstellenderem": "klarstellend",
    "klarstellenderen": "klarstellend",
    "klarstellenderer": "klarstellend",
    "klarstellenderes": "klarstellend",
    "klarstellendes": "klarstellend",
    "klarstellendste": "klarstellend",
    "klarstellendstem": "klarstellend",
    "klarstellendsten": "klarstellend",
    "klarstellendster": "klarstellend",
    "klarstellendstes": "klarstellend",
    "klarstellest": "klarstellen",
    "klarstellet": "klarstellen",
    "klarstellst": "klarstellen",
    "klarstellt": "klarstellen",
    "klarstellte": "klarstellen",
    "klarstellten": "klarstellen",
    "klarstelltest": "klarstellen",
    "klarstelltet": "klarstellen",
    "klarstem": "klar",
    "klarsten": "klar",
    "klarster": "klar",
    "klarstes": "klar",
    "klarsähe": "klarsehen",
    "klarsähen": "klarsehen",
    "klarsähest": "klarsehen",
    "klarsähet": "klarsehen",
    "klart": "klaren",
    "klarte": "klaren",
    "klarten": "klaren",
    "klartest": "klaren",
    "klartet": "klaren",
    "klarzukommen": "klarkommen",
    "klarzukriegen": "klarkriegen",
    "klarzumachen": "klarmachen",
    "klarzusehen": "klarsehen",
    "klarzustellen": "klarstellen",
    "klassiere": "klassieren",
    "klassierend": "klassieren",
    "klassierende": "klassierend",
    "klassierendem": "klassierend",
    "klassierenden": "klassierend",
    "klassierender": "klassierend",
    "klassierendes": "klassierend",
    "klassierest": "klassieren",
    "klassieret": "klassieren",
    "klassierst": "klassieren",
    "klassiert": "klassieren",
    "klassierte": "klassieren",
    "klassiertem": "klassiert",
    "klassierten": "klassieren",
    "klassierter": "klassiert",
    "klassiertes": "klassiert",
    "klassiertest": "klassieren",
    "klassiertet": "klassieren",
    "klassifiziere": "klassifizieren",
    "klassifizierend": "klassifizieren",
    "klassifizierende": "klassifizierend",
    "klassifizierendem": "klassifizierend",
    "klassifizierenden": "klassifizierend",
    "klassifizierender": "klassifizierend",
    "klassifizierendes": "klassifizierend",
    "klassifizierest": "klassifizieren",
    "klassifizieret": "klassifizieren",
    "klassifizierst": "klassifizieren",
    "klassifiziert": "klassifizieren",
    "klassifizierte": "klassifizieren",
    "klassifiziertem": "klassifiziert",
    "klassifizierten": "klassifizieren",
    "klassifizierter": "klassifiziert",
    "klassifiziertere": "klassifiziert",
    "klassifizierterem": "klassifiziert",
    "klassifizierteren": "klassifiziert",
    "klassifizierterer": "klassifiziert",
    "klassifizierteres": "klassifiziert",
    "klassifiziertes": "klassifiziert",
    "klassifiziertest": "klassifizieren",
    "klassifiziertestem": "klassifiziert",
    "klassifiziertesten": "klassifiziert",
    "klassifiziertester": "klassifiziert",
    "klassifiziertestes": "klassifiziert",
    "klassifiziertet": "klassifizieren",
    "klassischem": "klassisch",
    "klassischen": "klassisch",
    "klassischer": "klassisch",
    "klassischere": "klassisch",
    "klassischerem": "klassisch",
    "klassischeren": "klassisch",
    "klassischerer": "klassisch",
    "klassischeres": "klassisch",
    "klassisches": "klassisch",
    "klassischste": "klassisch",
    "klassischstem": "klassisch",
    "klassischsten": "klassisch",
    "klassischster": "klassisch",
    "klassischstes": "klassisch",
    "klatsche": "klatschen",
    "klatschend": "klatschen",
    "klatschende": "klatschend",
    "klatschendem": "klatschend",
    "klatschenden": "klatschend",
    "klatschender": "klatschend",
    "klatschendere": "klatschend",
    "klatschenderem": "klatschend",
    "klatschenderen": "klatschend",
    "klatschenderer": "klatschend",
    "klatschenderes": "klatschend",
    "klatschendes": "klatschend",
    "klatschendste": "klatschend",
    "klatschendstem": "klatschend",
    "klatschendsten": "klatschend",
    "klatschendster": "klatschend",
    "klatschendstes": "klatschend",
    "klatschest": "klatschen",
    "klatschet": "klatschen",
    "klatschhafte": "klatschhaft",
    "klatschhaftem": "klatschhaft",
    "klatschhaften": "klatschhaft",
    "klatschhafter": "klatschhaft",
    "klatschhaftere": "klatschhaft",
    "klatschhafterem": "klatschhaft",
    "klatschhafteren": "klatschhaft",
    "klatschhafterer": "klatschhaft",
    "klatschhafteres": "klatschhaft",
    "klatschhaftes": "klatschhaft",
    "klatschhafteste": "klatschhaft",
    "klatschhaftestem": "klatschhaft",
    "klatschhaftesten": "klatschhaft",
    "klatschhaftester": "klatschhaft",
    "klatschhaftestes": "klatschhaft",
    "klatschnasse": "klatschnaß",
    "klatschnassem": "klatschnaß",
    "klatschnassen": "klatschnaß",
    "klatschnasser": "klatschnaß",
    "klatschnassere": "klatschnaß",
    "klatschnasserem": "klatschnaß",
    "klatschnasseren": "klatschnaß",
    "klatschnasserer": "klatschnaß",
    "klatschnasseres": "klatschnaß",
    "klatschnasses": "klatschnaß",
    "klatschnasseste": "klatschnaß",
    "klatschnassestem": "klatschnaß",
    "klatschnassesten": "klatschnaß",
    "klatschnassester": "klatschnaß",
    "klatschnassestes": "klatschnaß",
    "klatschst": "klatschen",
    "klatschsüchtige": "klatschsüchtig",
    "klatschsüchtigem": "klatschsüchtig",
    "klatschsüchtigen": "klatschsüchtig",
    "klatschsüchtiger": "klatschsüchtig",
    "klatschsüchtigere": "klatschsüchtig",
    "klatschsüchtigerem": "klatschsüchtig",
    "klatschsüchtigeren": "klatschsüchtig",
    "klatschsüchtigerer": "klatschsüchtig",
    "klatschsüchtigeres": "klatschsüchtig",
    "klatschsüchtiges": "klatschsüchtig",
    "klatschsüchtigste": "klatschsüchtig",
    "klatschsüchtigstem": "klatschsüchtig",
    "klatschsüchtigsten": "klatschsüchtig",
    "klatschsüchtigster": "klatschsüchtig",
    "klatschsüchtigstes": "klatschsüchtig",
    "klatscht": "klatschen",
    "klatschte": "klatschen",
    "klatschten": "klatschen",
    "klatschtest": "klatschen",
    "klatschtet": "klatschen",
    "klaube": "klauben",
    "klaubend": "klauben",
    "klaubende": "klaubend",
    "klaubendem": "klaubend",
    "klaubenden": "klaubend",
    "klaubender": "klaubend",
    "klaubendes": "klaubend",
    "klaubest": "klauben",
    "klaubet": "klauben",
    "klaubst": "klauben",
    "klaubt": "klauben",
    "klaubte": "klauben",
    "klaubten": "klauben",
    "klaubtest": "klauben",
    "klaubtet": "klauben",
    "klaue": "klauen",
    "klauend": "klauen",
    "klauende": "klauend",
    "klauendem": "klauend",
    "klauenden": "klauend",
    "klauender": "klauend",
    "klauendere": "klauend",
    "klauenderem": "klauend",
    "klauenderen": "klauend",
    "klauenderer": "klauend",
    "klauenderes": "klauend",
    "klauendes": "klauend",
    "klauendste": "klauend",
    "klauendstem": "klauend",
    "klauendsten": "klauend",
    "klauendster": "klauend",
    "klauendstes": "klauend",
    "klauest": "klauen",
    "klauet": "klauen",
    "klaust": "klauen",
    "klaut": "klauen",
    "klaute": "klauen",
    "klauten": "klauen",
    "klautest": "klauen",
    "klautet": "klauen",
    "klebe": "kleben",
    "klebenbleibe": "klebenbleiben",
    "klebenbleibend": "klebenbleiben",
    "klebenbleibende": "klebenbleibend",
    "klebenbleibendem": "klebenbleibend",
    "klebenbleibenden": "klebenbleibend",
    "klebenbleibender": "klebenbleibend",
    "klebenbleibendes": "klebenbleibend",
    "klebenbleibest": "klebenbleiben",
    "klebenbleibet": "klebenbleiben",
    "klebenbleibst": "klebenbleiben",
    "klebenbleibt": "klebenbleiben",
    "klebenblieb": "klebenbleiben",
    "klebenbliebe": "klebenbleiben",
    "klebenblieben": "klebenbleiben",
    "klebenbliebest": "klebenbleiben",
    "klebenbliebet": "klebenbleiben",
    "klebenbliebst": "klebenbleiben",
    "klebenbliebt": "klebenbleiben",
    "klebend": "kleben",
    "klebende": "klebend",
    "klebendem": "klebend",
    "klebenden": "klebend",
    "klebender": "klebend",
    "klebendere": "klebend",
    "klebenderem": "klebend",
    "klebenderen": "klebend",
    "klebenderer": "klebend",
    "klebenderes": "klebend",
    "klebendes": "klebend",
    "klebendste": "klebend",
    "klebendstem": "klebend",
    "klebendsten": "klebend",
    "klebendster": "klebend",
    "klebendstes": "klebend",
    "klebengeblieben": "klebenbleiben",
    "klebengebliebene": "klebengeblieben",
    "klebengebliebenem": "klebengeblieben",
    "klebengebliebenen": "klebengeblieben",
    "klebengebliebener": "klebengeblieben",
    "klebengebliebenes": "klebengeblieben",
    "klebenzubleiben": "klebenbleiben",
    "kleberige": "kleberig",
    "kleberigem": "kleberig",
    "kleberigen": "kleberig",
    "kleberiger": "kleberig",
    "kleberigere": "kleberig",
    "kleberigerem": "kleberig",
    "kleberigeren": "kleberig",
    "kleberigerer": "kleberig",
    "kleberigeres": "kleberig",
    "kleberiges": "kleberig",
    "kleberigste": "kleberig",
    "kleberigstem": "kleberig",
    "kleberigsten": "kleberig",
    "kleberigster": "kleberig",
    "kleberigstes": "kleberig",
    "klebest": "kleben",
    "klebet": "kleben",
    "klebrige": "klebrig",
    "klebrigem": "klebrig",
    "klebrigen": "klebrig",
    "klebriger": "klebrig",
    "klebrigere": "klebrig",
    "klebrigerem": "klebrig",
    "klebrigeren": "klebrig",
    "klebrigerer": "klebrig",
    "klebrigeres": "klebrig",
    "klebriges": "klebrig",
    "klebrigste": "klebrig",
    "klebrigstem": "klebrig",
    "klebrigsten": "klebrig",
    "klebrigster": "klebrig",
    "klebrigstes": "klebrig",
    "klebst": "kleben",
    "klebt": "kleben",
    "klebte": "kleben",
    "klebten": "kleben",
    "klebtest": "kleben",
    "klebtet": "kleben",
    "kleckere": "kleckern",
    "kleckernd": "kleckern",
    "kleckernde": "kleckernd",
    "kleckerndem": "kleckernd",
    "kleckernden": "kleckernd",
    "kleckernder": "kleckernd",
    "kleckerndes": "kleckernd",
    "kleckerst": "kleckern",
    "kleckert": "kleckern",
    "kleckerte": "kleckern",
    "kleckerten": "kleckern",
    "kleckertest": "kleckern",
    "kleckertet": "kleckern",
    "kleckse": "klecksen",
    "klecksend": "klecksen",
    "klecksende": "klecksend",
    "klecksendem": "klecksend",
    "klecksenden": "klecksend",
    "klecksender": "klecksend",
    "klecksendes": "klecksend",
    "klecksest": "klecksen",
    "kleckset": "klecksen",
    "kleckst": "klecksen",
    "kleckste": "klecksen",
    "klecksten": "klecksen",
    "kleckstest": "klecksen",
    "kleckstet": "klecksen",
    "kleidend": "kleiden",
    "kleidende": "kleidend",
    "kleidendem": "kleidend",
    "kleidenden": "kleidend",
    "kleidender": "kleidend",
    "kleidendere": "kleidend",
    "kleidenderem": "kleidend",
    "kleidenderen": "kleidend",
    "kleidenderer": "kleidend",
    "kleidenderes": "kleidend",
    "kleidendes": "kleidend",
    "kleidendste": "kleidend",
    "kleidendstem": "kleidend",
    "kleidendsten": "kleidend",
    "kleidendster": "kleidend",
    "kleidendstes": "kleidend",
    "kleidest": "kleiden",
    "kleidet": "kleiden",
    "kleidete": "kleiden",
    "kleideten": "kleiden",
    "kleidetest": "kleiden",
    "kleidetet": "kleiden",
    "kleidsamem": "kleidsam",
    "kleidsamen": "kleidsam",
    "kleidsamer": "kleidsam",
    "kleidsamere": "kleidsam",
    "kleidsamerem": "kleidsam",
    "kleidsameren": "kleidsam",
    "kleidsamerer": "kleidsam",
    "kleidsameres": "kleidsam",
    "kleidsames": "kleidsam",
    "kleidsamste": "kleidsam",
    "kleidsamstem": "kleidsam",
    "kleidsamsten": "kleidsam",
    "kleidsamster": "kleidsam",
    "kleidsamstes": "kleidsam",
    "kleinbürgerlichem": "kleinbürgerlich",
    "kleinbürgerlichen": "kleinbürgerlich",
    "kleinbürgerlicher": "kleinbürgerlich",
    "kleinbürgerlichere": "kleinbürgerlich",
    "kleinbürgerlicherem": "kleinbürgerlich",
    "kleinbürgerlicheren": "kleinbürgerlich",
    "kleinbürgerlicherer": "kleinbürgerlich",
    "kleinbürgerlicheres": "kleinbürgerlich",
    "kleinbürgerliches": "kleinbürgerlich",
    "kleinbürgerlichste": "kleinbürgerlich",
    "kleinbürgerlichstem": "kleinbürgerlich",
    "kleinbürgerlichsten": "kleinbürgerlich",
    "kleinbürgerlichster": "kleinbürgerlich",
    "kleinbürgerlichstes": "kleinbürgerlich",
    "kleinem": "klein",
    "kleinen": "klein",
    "kleiner": "klein",
    "kleinere": "klein",
    "kleinerem": "klein",
    "kleineren": "klein",
    "kleinerer": "klein",
    "kleineres": "klein",
    "kleines": "klein",
    "kleingedrucktem": "kleingedruckt",
    "kleingedruckten": "kleingedruckt",
    "kleingedruckter": "kleingedruckt",
    "kleingedrucktes": "kleingedruckt",
    "kleingekriegt": "kleinkriegen",
    "kleingekriegte": "kleingekriegt",
    "kleingekriegtem": "kleingekriegt",
    "kleingekriegten": "kleingekriegt",
    "kleingekriegter": "kleingekriegt",
    "kleingekriegtes": "kleingekriegt",
    "kleingeschnitten": "kleinschneiden",
    "kleingeschnittene": "kleingeschnitten",
    "kleingeschnittenem": "kleingeschnitten",
    "kleingeschnittenen": "kleingeschnitten",
    "kleingeschnittener": "kleingeschnitten",
    "kleingeschnittenere": "kleingeschnitten",
    "kleingeschnittenerem": "kleingeschnitten",
    "kleingeschnitteneren": "kleingeschnitten",
    "kleingeschnittenerer": "kleingeschnitten",
    "kleingeschnitteneres": "kleingeschnitten",
    "kleingeschnittenes": "kleingeschnitten",
    "kleingeschnittenste": "kleingeschnitten",
    "kleingeschnittenstem": "kleingeschnitten",
    "kleingeschnittensten": "kleingeschnitten",
    "kleingeschnittenster": "kleingeschnitten",
    "kleingeschnittenstes": "kleingeschnitten",
    "kleinkariertem": "kleinkariert",
    "kleinkarierten": "kleinkariert",
    "kleinkarierter": "kleinkariert",
    "kleinkariertere": "kleinkariert",
    "kleinkarierterem": "kleinkariert",
    "kleinkarierteren": "kleinkariert",
    "kleinkarierterer": "kleinkariert",
    "kleinkarierteres": "kleinkariert",
    "kleinkariertes": "kleinkariert",
    "kleinkarierteste": "kleinkariert",
    "kleinkariertestem": "kleinkariert",
    "kleinkariertesten": "kleinkariert",
    "kleinkariertester": "kleinkariert",
    "kleinkariertestes": "kleinkariert",
    "kleinkriege": "kleinkriegen",
    "kleinkriegend": "kleinkriegen",
    "kleinkriegende": "kleinkriegend",
    "kleinkriegendem": "kleinkriegend",
    "kleinkriegenden": "kleinkriegend",
    "kleinkriegender": "kleinkriegend",
    "kleinkriegendes": "kleinkriegend",
    "kleinkriegest": "kleinkriegen",
    "kleinkrieget": "kleinkriegen",
    "kleinkriegst": "kleinkriegen",
    "kleinkriegt": "kleinkriegen",
    "kleinkriegte": "kleinkriegen",
    "kleinkriegten": "kleinkriegen",
    "kleinkriegtest": "kleinkriegen",
    "kleinkriegtet": "kleinkriegen",
    "kleinlaute": "kleinlaut",
    "kleinlautem": "kleinlaut",
    "kleinlauten": "kleinlaut",
    "kleinlauter": "kleinlaut",
    "kleinlautere": "kleinlaut",
    "kleinlauterem": "kleinlaut",
    "kleinlauteren": "kleinlaut",
    "kleinlauterer": "kleinlaut",
    "kleinlauteres": "kleinlaut",
    "kleinlautes": "kleinlaut",
    "kleinlauteste": "kleinlaut",
    "kleinlautestem": "kleinlaut",
    "kleinlautesten": "kleinlaut",
    "kleinlautester": "kleinlaut",
    "kleinlautestes": "kleinlaut",
    "kleinliche": "kleinlich",
    "kleinlichem": "kleinlich",
    "kleinlichen": "kleinlich",
    "kleinlicher": "kleinlich",
    "kleinlichere": "kleinlich",
    "kleinlicherem": "kleinlich",
    "kleinlicheren": "kleinlich",
    "kleinlicherer": "kleinlich",
    "kleinlicheres": "kleinlich",
    "kleinliches": "kleinlich",
    "kleinlichste": "kleinlich",
    "kleinlichstem": "kleinlich",
    "kleinlichsten": "kleinlich",
    "kleinlichster": "kleinlich",
    "kleinlichstes": "kleinlich",
    "kleinschneide": "kleinschneiden",
    "kleinschneidend": "kleinschneiden",
    "kleinschneidende": "kleinschneidend",
    "kleinschneidendem": "kleinschneidend",
    "kleinschneidenden": "kleinschneidend",
    "kleinschneidender": "kleinschneidend",
    "kleinschneidendere": "kleinschneidend",
    "kleinschneidenderem": "kleinschneidend",
    "kleinschneidenderen": "kleinschneidend",
    "kleinschneidenderer": "kleinschneidend",
    "kleinschneidenderes": "kleinschneidend",
    "kleinschneidendes": "kleinschneidend",
    "kleinschneidendste": "kleinschneidend",
    "kleinschneidendstem": "kleinschneidend",
    "kleinschneidendsten": "kleinschneidend",
    "kleinschneidendster": "kleinschneidend",
    "kleinschneidendstes": "kleinschneidend",
    "kleinschneidest": "kleinschneiden",
    "kleinschneidet": "kleinschneiden",
    "kleinschnitt": "kleinschneiden",
    "kleinschnitte": "kleinschneiden",
    "kleinschnitten": "kleinschneiden",
    "kleinschnittest": "kleinschneiden",
    "kleinschnittet": "kleinschneiden",
    "kleinstem": "klein",
    "kleinsten": "klein",
    "kleinster": "klein",
    "kleinstes": "klein",
    "kleinstädtischem": "kleinstädtisch",
    "kleinstädtischen": "kleinstädtisch",
    "kleinstädtischer": "kleinstädtisch",
    "kleinstädtischere": "kleinstädtisch",
    "kleinstädtischerem": "kleinstädtisch",
    "kleinstädtischeren": "kleinstädtisch",
    "kleinstädtischerer": "kleinstädtisch",
    "kleinstädtischeres": "kleinstädtisch",
    "kleinstädtisches": "kleinstädtisch",
    "kleinstädtischste": "kleinstädtisch",
    "kleinstädtischstem": "kleinstädtisch",
    "kleinstädtischsten": "kleinstädtisch",
    "kleinstädtischster": "kleinstädtisch",
    "kleinstädtischstes": "kleinstädtisch",
    "kleinzukriegen": "kleinkriegen",
    "kleinzuschneiden": "kleinschneiden",
    "kleistere": "kleistern",
    "kleisternd": "kleistern",
    "kleisternde": "kleisternd",
    "kleisterndem": "kleisternd",
    "kleisternden": "kleisternd",
    "kleisternder": "kleisternd",
    "kleisterndes": "kleisternd",
    "kleisterst": "kleistern",
    "kleistert": "kleistern",
    "kleisterte": "kleistern",
    "kleisterten": "kleistern",
    "kleistertest": "kleistern",
    "kleistertet": "kleistern",
    "klemmend": "klemmen",
    "klemmende": "klemmend",
    "klemmendem": "klemmend",
    "klemmenden": "klemmend",
    "klemmender": "klemmend",
    "klemmendes": "klemmend",
    "klemmest": "klemmen",
    "klemmet": "klemmen",
    "klemmst": "klemmen",
    "klemmt": "klemmen",
    "klemmte": "klemmen",
    "klemmten": "klemmen",
    "klemmtest": "klemmen",
    "klemmtet": "klemmen",
    "klempnere": "klempnern",
    "klempnernd": "klempnern",
    "klempnernde": "klempnernd",
    "klempnerndem": "klempnernd",
    "klempnernden": "klempnernd",
    "klempnernder": "klempnernd",
    "klempnerndes": "klempnernd",
    "klempnerst": "klempnern",
    "klempnert": "klempnern",
    "klempnerte": "klempnern",
    "klempnerten": "klempnern",
    "klempnertest": "klempnern",
    "klempnertet": "klempnern",
    "klettere": "klettern",
    "kletternd": "klettern",
    "kletternde": "kletternd",
    "kletterndem": "kletternd",
    "kletternden": "kletternd",
    "kletternder": "kletternd",
    "kletterndes": "kletternd",
    "kletterst": "klettern",
    "klettert": "klettern",
    "kletterte": "klettern",
    "kletterten": "klettern",
    "klettertest": "klettern",
    "klettertet": "klettern",
    "klimatischem": "klimatisch",
    "klimatischen": "klimatisch",
    "klimatischer": "klimatisch",
    "klimatisches": "klimatisch",
    "klimatisiere": "klimatisieren",
    "klimatisierend": "klimatisieren",
    "klimatisierende": "klimatisierend",
    "klimatisierendem": "klimatisierend",
    "klimatisierenden": "klimatisierend",
    "klimatisierender": "klimatisierend",
    "klimatisierendes": "klimatisierend",
    "klimatisierest": "klimatisieren",
    "klimatisieret": "klimatisieren",
    "klimatisierst": "klimatisieren",
    "klimatisiert": "klimatisieren",
    "klimatisierte": "klimatisieren",
    "klimatisiertem": "klimatisiert",
    "klimatisierten": "klimatisieren",
    "klimatisierter": "klimatisiert",
    "klimatisiertere": "klimatisiert",
    "klimatisierterem": "klimatisiert",
    "klimatisierteren": "klimatisiert",
    "klimatisierterer": "klimatisiert",
    "klimatisierteres": "klimatisiert",
    "klimatisiertes": "klimatisiert",
    "klimatisiertest": "klimatisieren",
    "klimatisierteste": "klimatisiert",
    "klimatisiertestem": "klimatisiert",
    "klimatisiertesten": "klimatisiert",
    "klimatisiertester": "klimatisiert",
    "klimatisiertestes": "klimatisiert",
    "klimatisiertet": "klimatisieren",
    "klimatologische": "klimatologisch",
    "klimatologischem": "klimatologisch",
    "klimatologischen": "klimatologisch",
    "klimatologischer": "klimatologisch",
    "klimatologisches": "klimatologisch",
    "klimme": "klimmen",
    "klimmend": "klimmen",
    "klimmende": "klimmend",
    "klimmendem": "klimmend",
    "klimmenden": "klimmend",
    "klimmender": "klimmend",
    "klimmendes": "klimmend",
    "klimmest": "klimmen",
    "klimmet": "klimmen",
    "klimmst": "klimmen",
    "klimmt": "klimmen",
    "klimpere": "klimpern",
    "klimpernd": "klimpern",
    "klimpernde": "klimpernd",
    "klimperndem": "klimpernd",
    "klimpernden": "klimpernd",
    "klimpernder": "klimpernd",
    "klimperndere": "klimpernd",
    "klimpernderem": "klimpernd",
    "klimpernderen": "klimpernd",
    "klimpernderer": "klimpernd",
    "klimpernderes": "klimpernd",
    "klimperndes": "klimpernd",
    "klimperndste": "klimpernd",
    "klimperndstem": "klimpernd",
    "klimperndsten": "klimpernd",
    "klimperndster": "klimpernd",
    "klimperndstes": "klimpernd",
    "klimperst": "klimpern",
    "klimpert": "klimpern",
    "klimperte": "klimpern",
    "klimperten": "klimpern",
    "klimpertest": "klimpern",
    "klimpertet": "klimpern",
    "klinge": "klingen",
    "klingele": "klingeln",
    "klingelnd": "klingeln",
    "klingelnde": "klingelnd",
    "klingelndem": "klingelnd",
    "klingelnden": "klingelnd",
    "klingelnder": "klingelnd",
    "klingelndere": "klingelnd",
    "klingelnderem": "klingelnd",
    "klingelnderen": "klingelnd",
    "klingelnderer": "klingelnd",
    "klingelnderes": "klingelnd",
    "klingelndes": "klingelnd",
    "klingelndste": "klingelnd",
    "klingelndstem": "klingelnd",
    "klingelndsten": "klingelnd",
    "klingelndster": "klingelnd",
    "klingelndstes": "klingelnd",
    "klingelst": "klingeln",
    "klingelt": "klingeln",
    "klingelte": "klingeln",
    "klingelten": "klingeln",
    "klingeltest": "klingeln",
    "klingeltet": "klingeln",
    "klingend": "klingen",
    "klingende": "klingend",
    "klingendem": "klingend",
    "klingenden": "klingend",
    "klingender": "klingend",
    "klingendere": "klingend",
    "klingenderem": "klingend",
    "klingenderen": "klingend",
    "klingenderer": "klingend",
    "klingenderes": "klingend",
    "klingendes": "klingend",
    "klingendste": "klingend",
    "klingendstem": "klingend",
    "klingendsten": "klingend",
    "klingendster": "klingend",
    "klingendstes": "klingend",
    "klingest": "klingen",
    "klinget": "klingen",
    "klingle": "klingeln",
    "klingst": "klingen",
    "klingt": "klingen",
    "klinischem": "klinisch",
    "klinischen": "klinisch",
    "klinischer": "klinisch",
    "klinischere": "klinisch",
    "klinischerem": "klinisch",
    "klinischeren": "klinisch",
    "klinischerer": "klinisch",
    "klinischeres": "klinisch",
    "klinisches": "klinisch",
    "klinischste": "klinisch",
    "klinischstem": "klinisch",
    "klinischsten": "klinisch",
    "klinischster": "klinisch",
    "klinischstes": "klinisch",
    "klinke": "klinken",
    "klinkend": "klinken",
    "klinkende": "klinkend",
    "klinkendem": "klinkend",
    "klinkenden": "klinkend",
    "klinkender": "klinkend",
    "klinkendes": "klinkend",
    "klinkest": "klinken",
    "klinket": "klinken",
    "klinkst": "klinken",
    "klinkt": "klinken",
    "klinkte": "klinken",
    "klinkten": "klinken",
    "klinktest": "klinken",
    "klinktet": "klinken",
    "klirre": "klirren",
    "klirrend": "klirren",
    "klirrende": "klirrend",
    "klirrendem": "klirrend",
    "klirrenden": "klirrend",
    "klirrender": "klirrend",
    "klirrendere": "klirrend",
    "klirrenderem": "klirrend",
    "klirrenderen": "klirrend",
    "klirrenderer": "klirrend",
    "klirrenderes": "klirrend",
    "klirrendes": "klirrend",
    "klirrendste": "klirrend",
    "klirrendstem": "klirrend",
    "klirrendsten": "klirrend",
    "klirrendster": "klirrend",
    "klirrendstes": "klirrend",
    "klirrest": "klirren",
    "klirret": "klirren",
    "klirrst": "klirren",
    "klirrt": "klirren",
    "klirrte": "klirren",
    "klirrten": "klirren",
    "klirrtest": "klirren",
    "klirrtet": "klirren",
    "klischeehafte": "klischeehaft",
    "klischeehaftem": "klischeehaft",
    "klischeehaften": "klischeehaft",
    "klischeehafter": "klischeehaft",
    "klischeehaftere": "klischeehaft",
    "klischeehafterem": "klischeehaft",
    "klischeehafteren": "klischeehaft",
    "klischeehafterer": "klischeehaft",
    "klischeehafteres": "klischeehaft",
    "klischeehaftes": "klischeehaft",
    "klischeehafteste": "klischeehaft",
    "klischeehaftestem": "klischeehaft",
    "klischeehaftesten": "klischeehaft",
    "klischeehaftester": "klischeehaft",
    "klischeehaftestes": "klischeehaft",
    "klitschnassem": "klitschnaß",
    "klitschnassen": "klitschnaß",
    "klitschnasser": "klitschnaß",
    "klitschnassere": "klitschnaß",
    "klitschnasserem": "klitschnaß",
    "klitschnasseren": "klitschnaß",
    "klitschnasserer": "klitschnaß",
    "klitschnasseres": "klitschnaß",
    "klitschnasses": "klitschnaß",
    "klitschnasseste": "klitschnaß",
    "klitschnassestem": "klitschnaß",
    "klitschnassesten": "klitschnaß",
    "klitschnassester": "klitschnaß",
    "klitschnassestes": "klitschnaß",
    "klitzekleinem": "klitzeklein",
    "klitzekleinen": "klitzeklein",
    "klitzekleiner": "klitzeklein",
    "klitzekleines": "klitzeklein",
    "klobigem": "klobig",
    "klobigen": "klobig",
    "klobiger": "klobig",
    "klobigere": "klobig",
    "klobigerem": "klobig",
    "klobigeren": "klobig",
    "klobigerer": "klobig",
    "klobigeres": "klobig",
    "klobiges": "klobig",
    "klobigste": "klobig",
    "klobigstem": "klobig",
    "klobigsten": "klobig",
    "klobigster": "klobig",
    "klobigstes": "klobig",
    "klomm": "klimmen",
    "klommen": "klimmen",
    "klommst": "klimmen",
    "klommt": "klimmen",
    "klone": "klonen",
    "klonend": "klonen",
    "klonende": "klonend",
    "klonendem": "klonend",
    "klonenden": "klonend",
    "klonender": "klonend",
    "klonendes": "klonend",
    "klonest": "klonen",
    "klonet": "klonen",
    "klonst": "klonen",
    "klont": "klonen",
    "klonte": "klonen",
    "klonten": "klonen",
    "klontest": "klonen",
    "klontet": "klonen",
    "klopfe": "klopfen",
    "klopfend": "klopfen",
    "klopfende": "klopfend",
    "klopfendem": "klopfend",
    "klopfenden": "klopfend",
    "klopfender": "klopfend",
    "klopfendes": "klopfend",
    "klopfest": "klopfen",
    "klopfet": "klopfen",
    "klopffeste": "klopffest",
    "klopffestem": "klopffest",
    "klopffesten": "klopffest",
    "klopffester": "klopffest",
    "klopffestere": "klopffest",
    "klopffesterem": "klopffest",
    "klopffesteren": "klopffest",
    "klopffesterer": "klopffest",
    "klopffesteres": "klopffest",
    "klopffestes": "klopffest",
    "klopffesteste": "klopffest",
    "klopffestestem": "klopffest",
    "klopffestesten": "klopffest",
    "klopffestester": "klopffest",
    "klopffestestes": "klopffest",
    "klopfst": "klopfen",
    "klopft": "klopfen",
    "klopfte": "klopfen",
    "klopften": "klopfen",
    "klopftest": "klopfen",
    "klopftet": "klopfen",
    "kloppe": "kloppen",
    "kloppend": "kloppen",
    "kloppende": "kloppend",
    "kloppendem": "kloppend",
    "kloppenden": "kloppend",
    "kloppender": "kloppend",
    "kloppendes": "kloppend",
    "kloppest": "kloppen",
    "kloppet": "kloppen",
    "kloppst": "kloppen",
    "kloppt": "kloppen",
    "kloppte": "kloppen",
    "kloppten": "kloppen",
    "klopptest": "kloppen",
    "klopptet": "kloppen",
    "klotzend": "klotzen",
    "klotzende": "klotzend",
    "klotzendem": "klotzend",
    "klotzenden": "klotzend",
    "klotzender": "klotzend",
    "klotzendere": "klotzend",
    "klotzenderem": "klotzend",
    "klotzenderen": "klotzend",
    "klotzenderer": "klotzend",
    "klotzenderes": "klotzend",
    "klotzendes": "klotzend",
    "klotzendste": "klotzend",
    "klotzendstem": "klotzend",
    "klotzendsten": "klotzend",
    "klotzendster": "klotzend",
    "klotzendstes": "klotzend",
    "klotzest": "klotzen",
    "klotzet": "klotzen",
    "klotzige": "klotzig",
    "klotzigem": "klotzig",
    "klotzigen": "klotzig",
    "klotziger": "klotzig",
    "klotzigere": "klotzig",
    "klotzigerem": "klotzig",
    "klotzigeren": "klotzig",
    "klotzigerer": "klotzig",
    "klotzigeres": "klotzig",
    "klotziges": "klotzig",
    "klotzigste": "klotzig",
    "klotzigstem": "klotzig",
    "klotzigsten": "klotzig",
    "klotzigster": "klotzig",
    "klotzigstes": "klotzig",
    "klotzt": "klotzen",
    "klotzte": "klotzen",
    "klotzten": "klotzen",
    "klotztest": "klotzen",
    "klotztet": "klotzen",
    "klugem": "klug",
    "klugen": "klug",
    "kluger": "klug",
    "kluges": "klug",
    "klumpe": "klumpen",
    "klumpend": "klumpen",
    "klumpende": "klumpend",
    "klumpendem": "klumpend",
    "klumpenden": "klumpend",
    "klumpender": "klumpend",
    "klumpendere": "klumpend",
    "klumpenderem": "klumpend",
    "klumpenderen": "klumpend",
    "klumpenderer": "klumpend",
    "klumpenderes": "klumpend",
    "klumpendes": "klumpend",
    "klumpendste": "klumpend",
    "klumpendstem": "klumpend",
    "klumpendsten": "klumpend",
    "klumpendster": "klumpend",
    "klumpendstes": "klumpend",
    "klumpest": "klumpen",
    "klumpet": "klumpen",
    "klumpige": "klumpig",
    "klumpigem": "klumpig",
    "klumpigen": "klumpig",
    "klumpiger": "klumpig",
    "klumpigere": "klumpig",
    "klumpigerem": "klumpig",
    "klumpigeren": "klumpig",
    "klumpigerer": "klumpig",
    "klumpigeres": "klumpig",
    "klumpiges": "klumpig",
    "klumpigste": "klumpig",
    "klumpigstem": "klumpig",
    "klumpigsten": "klumpig",
    "klumpigster": "klumpig",
    "klumpigstes": "klumpig",
    "klumpst": "klumpen",
    "klumpt": "klumpen",
    "klumpte": "klumpen",
    "klumpten": "klumpen",
    "klumptest": "klumpen",
    "klumptet": "klumpen",
    "kläffe": "kläffen",
    "kläffend": "kläffen",
    "kläffendem": "kläffend",
    "kläffender": "kläffend",
    "kläffenderem": "kläffend",
    "kläffenderer": "kläffend",
    "kläffenderes": "kläffend",
    "kläffendes": "kläffend",
    "kläffendstem": "kläffend",
    "kläffendster": "kläffend",
    "kläffendstes": "kläffend",
    "kläffest": "kläffen",
    "kläffet": "kläffen",
    "kläffst": "kläffen",
    "kläfft": "kläffen",
    "kläffte": "kläffen",
    "kläfften": "kläffen",
    "kläfftest": "kläffen",
    "kläfftet": "kläffen",
    "klägliche": "kläglich",
    "kläglichem": "kläglich",
    "kläglichen": "kläglich",
    "kläglicher": "kläglich",
    "kläglichere": "kläglich",
    "kläglicherem": "kläglich",
    "kläglicheren": "kläglich",
    "kläglicherer": "kläglich",
    "kläglicheres": "kläglich",
    "klägliches": "kläglich",
    "kläglichste": "kläglich",
    "kläglichstem": "kläglich",
    "kläglichsten": "kläglich",
    "kläglichster": "kläglich",
    "kläglichstes": "kläglich",
    "klängest": "klingen",
    "klänget": "klingen",
    "kläre": "klären",
    "klärend": "klären",
    "klärendem": "klärend",
    "klärender": "klärend",
    "klärendere": "klärend",
    "klärenderem": "klärend",
    "klärenderen": "klärend",
    "klärenderer": "klärend",
    "klärenderes": "klärend",
    "klärendes": "klärend",
    "klärendste": "klärend",
    "klärendstem": "klärend",
    "klärendsten": "klärend",
    "klärendster": "klärend",
    "klärendstes": "klärend",
    "klärest": "klären",
    "kläret": "klären",
    "klärst": "klären",
    "klärt": "klären",
    "klärte": "klären",
    "klärten": "klären",
    "klärtest": "klären",
    "klärtet": "klären",
    "klöhne": "klöhnen",
    "klöhnend": "klöhnen",
    "klöhnende": "klöhnend",
    "klöhnendem": "klöhnend",
    "klöhnenden": "klöhnend",
    "klöhnender": "klöhnend",
    "klöhnendere": "klöhnend",
    "klöhnenderem": "klöhnend",
    "klöhnenderen": "klöhnend",
    "klöhnenderer": "klöhnend",
    "klöhnenderes": "klöhnend",
    "klöhnendes": "klöhnend",
    "klöhnendste": "klöhnend",
    "klöhnendstem": "klöhnend",
    "klöhnendsten": "klöhnend",
    "klöhnendster": "klöhnend",
    "klöhnendstes": "klöhnend",
    "klöhnest": "klöhnen",
    "klöhnet": "klöhnen",
    "klöhnst": "klöhnen",
    "klöhnt": "klöhnen",
    "klöhnte": "klöhnen",
    "klöhnten": "klöhnen",
    "klöhntest": "klöhnen",
    "klöhntet": "klöhnen",
    "klömme": "klimmen",
    "klömmen": "klimmen",
    "klömmest": "klimmen",
    "klömmet": "klimmen",
    "klöne": "klönen",
    "klönend": "klönen",
    "klönendem": "klönend",
    "klönender": "klönend",
    "klönendere": "klönend",
    "klönenderem": "klönend",
    "klönenderen": "klönend",
    "klönenderer": "klönend",
    "klönenderes": "klönend",
    "klönendes": "klönend",
    "klönendste": "klönend",
    "klönendstem": "klönend",
    "klönendsten": "klönend",
    "klönendster": "klönend",
    "klönendstes": "klönend",
    "klönest": "klönen",
    "klönet": "klönen",
    "klönst": "klönen",
    "klönt": "klönen",
    "klönte": "klönen",
    "klönten": "klönen",
    "klöntest": "klönen",
    "klöntet": "klönen",
    "klösterlichem": "klösterlich",
    "klösterlichen": "klösterlich",
    "klösterlicher": "klösterlich",
    "klösterliches": "klösterlich",
    "klügele": "klügeln",
    "klügelnd": "klügeln",
    "klügelnde": "klügelnd",
    "klügelndem": "klügelnd",
    "klügelnden": "klügelnd",
    "klügelnder": "klügelnd",
    "klügelndes": "klügelnd",
    "klügelst": "klügeln",
    "klügelt": "klügeln",
    "klügelte": "klügeln",
    "klügelten": "klügeln",
    "klügeltest": "klügeln",
    "klügeltet": "klügeln",
    "klüger": "klug",
    "klügere": "klug",
    "klügerem": "klug",
    "klügeren": "klug",
    "klügerer": "klug",
    "klügeres": "klug",
    "klügle": "klügeln",
    "klügstem": "klug",
    "klügsten": "klug",
    "klügster": "klug",
    "klügstes": "klug",
    "klüngele": "klüngeln",
    "klüngelnd": "klüngeln",
    "klüngelnde": "klüngelnd",
    "klüngelndem": "klüngelnd",
    "klüngelnden": "klüngelnd",
    "klüngelnder": "klüngelnd",
    "klüngelndere": "klüngelnd",
    "klüngelnderem": "klüngelnd",
    "klüngelnderen": "klüngelnd",
    "klüngelnderer": "klüngelnd",
    "klüngelnderes": "klüngelnd",
    "klüngelndes": "klüngelnd",
    "klüngelndste": "klüngelnd",
    "klüngelndstem": "klüngelnd",
    "klüngelndsten": "klüngelnd",
    "klüngelndster": "klüngelnd",
    "klüngelndstes": "klüngelnd",
    "klüngelst": "klüngeln",
    "klüngelt": "klüngeln",
    "klüngelte": "klüngeln",
    "klüngelten": "klüngeln",
    "klüngeltest": "klüngeln",
    "klüngeltet": "klüngeln",
    "klüngle": "klüngeln",
    "knabbere": "knabbern",
    "knabbernd": "knabbern",
    "knabbernde": "knabbernd",
    "knabberndem": "knabbernd",
    "knabbernden": "knabbernd",
    "knabbernder": "knabbernd",
    "knabberndes": "knabbernd",
    "knabberst": "knabbern",
    "knabbert": "knabbern",
    "knabberte": "knabbern",
    "knabberten": "knabbern",
    "knabbertest": "knabbern",
    "knabbertet": "knabbern",
    "knabenhaftem": "knabenhaft",
    "knabenhaften": "knabenhaft",
    "knabenhafter": "knabenhaft",
    "knabenhaftere": "knabenhaft",
    "knabenhafterem": "knabenhaft",
    "knabenhafteren": "knabenhaft",
    "knabenhafterer": "knabenhaft",
    "knabenhafteres": "knabenhaft",
    "knabenhaftes": "knabenhaft",
    "knabenhafteste": "knabenhaft",
    "knabenhaftestem": "knabenhaft",
    "knabenhaftesten": "knabenhaft",
    "knabenhaftester": "knabenhaft",
    "knabenhaftestes": "knabenhaft",
    "knacke": "knacken",
    "knackend": "knacken",
    "knackende": "knackend",
    "knackendem": "knackend",
    "knackenden": "knackend",
    "knackender": "knackend",
    "knackendere": "knackend",
    "knackenderem": "knackend",
    "knackenderen": "knackend",
    "knackenderer": "knackend",
    "knackenderes": "knackend",
    "knackendes": "knackend",
    "knackendste": "knackend",
    "knackendstem": "knackend",
    "knackendsten": "knackend",
    "knackendster": "knackend",
    "knackendstes": "knackend",
    "knackest": "knacken",
    "knacket": "knacken",
    "knackse": "knacksen",
    "knacksend": "knacksen",
    "knacksende": "knacksend",
    "knacksendem": "knacksend",
    "knacksenden": "knacksend",
    "knacksender": "knacksend",
    "knacksendere": "knacksend",
    "knacksenderem": "knacksend",
    "knacksenderen": "knacksend",
    "knacksenderer": "knacksend",
    "knacksenderes": "knacksend",
    "knacksendes": "knacksend",
    "knacksendste": "knacksend",
    "knacksendstem": "knacksend",
    "knacksendsten": "knacksend",
    "knacksendster": "knacksend",
    "knacksendstes": "knacksend",
    "knacksest": "knacksen",
    "knackset": "knacksen",
    "knackst": "knacksen",
    "knackste": "knacksen",
    "knacksten": "knacksen",
    "knackstest": "knacksen",
    "knackstet": "knacksen",
    "knackt": "knacken",
    "knackte": "knacken",
    "knackten": "knacken",
    "knacktest": "knacken",
    "knacktet": "knacken",
    "knallend": "knallen",
    "knallende": "knallend",
    "knallendem": "knallend",
    "knallenden": "knallend",
    "knallender": "knallend",
    "knallendere": "knallend",
    "knallenderem": "knallend",
    "knallenderen": "knallend",
    "knallenderer": "knallend",
    "knallenderes": "knallend",
    "knallendes": "knallend",
    "knallendste": "knallend",
    "knallendstem": "knallend",
    "knallendsten": "knallend",
    "knallendster": "knallend",
    "knallendstes": "knallend",
    "knallest": "knallen",
    "knallet": "knallen",
    "knallhartem": "knallhart",
    "knallharten": "knallhart",
    "knallharter": "knallhart",
    "knallhartes": "knallhart",
    "knallige": "knallig",
    "knalligem": "knallig",
    "knalligen": "knallig",
    "knalliger": "knallig",
    "knalligere": "knallig",
    "knalligerem": "knallig",
    "knalligeren": "knallig",
    "knalligerer": "knallig",
    "knalligeres": "knallig",
    "knalliges": "knallig",
    "knalligste": "knallig",
    "knalligstem": "knallig",
    "knalligsten": "knallig",
    "knalligster": "knallig",
    "knalligstes": "knallig",
    "knallst": "knallen",
    "knallt": "knallen",
    "knallte": "knallen",
    "knallten": "knallen",
    "knalltest": "knallen",
    "knalltet": "knallen",
    "knappe": "knapp",
    "knappem": "knapp",
    "knappen": "knapp",
    "knapper": "knapp",
    "knappere": "knapp",
    "knapperem": "knapp",
    "knapperen": "knapp",
    "knapperer": "knapp",
    "knapperes": "knapp",
    "knappes": "knapp",
    "knappgehalten": "knapphalten",
    "knappgehaltene": "knappgehalten",
    "knappgehaltenem": "knappgehalten",
    "knappgehaltenen": "knappgehalten",
    "knappgehaltener": "knappgehalten",
    "knappgehaltenere": "knappgehalten",
    "knappgehaltenerem": "knappgehalten",
    "knappgehalteneren": "knappgehalten",
    "knappgehaltenerer": "knappgehalten",
    "knappgehalteneres": "knappgehalten",
    "knappgehaltenes": "knappgehalten",
    "knappgehaltenste": "knappgehalten",
    "knappgehaltenstem": "knappgehalten",
    "knappgehaltensten": "knappgehalten",
    "knappgehaltenster": "knappgehalten",
    "knappgehaltenstes": "knappgehalten",
    "knapphalte": "knapphalten",
    "knapphaltend": "knapphalten",
    "knapphaltende": "knapphaltend",
    "knapphaltendem": "knapphaltend",
    "knapphaltenden": "knapphaltend",
    "knapphaltender": "knapphaltend",
    "knapphaltendere": "knapphaltend",
    "knapphaltenderem": "knapphaltend",
    "knapphaltenderen": "knapphaltend",
    "knapphaltenderer": "knapphaltend",
    "knapphaltenderes": "knapphaltend",
    "knapphaltendes": "knapphaltend",
    "knapphaltendste": "knapphaltend",
    "knapphaltendstem": "knapphaltend",
    "knapphaltendsten": "knapphaltend",
    "knapphaltendster": "knapphaltend",
    "knapphaltendstes": "knapphaltend",
    "knapphaltest": "knapphalten",
    "knapphaltet": "knapphalten",
    "knapphielt": "knapphalten",
    "knapphielte": "knapphalten",
    "knapphielten": "knapphalten",
    "knapphieltest": "knapphalten",
    "knapphieltet": "knapphalten",
    "knapphält": "knapphalten",
    "knapphältst": "knapphalten",
    "knappstem": "knapp",
    "knappsten": "knapp",
    "knappster": "knapp",
    "knappstes": "knapp",
    "knappzuhalten": "knapphalten",
    "knapse": "knapsen",
    "knapsend": "knapsen",
    "knapsende": "knapsend",
    "knapsendem": "knapsend",
    "knapsenden": "knapsend",
    "knapsender": "knapsend",
    "knapsendere": "knapsend",
    "knapsenderem": "knapsend",
    "knapsenderen": "knapsend",
    "knapsenderer": "knapsend",
    "knapsenderes": "knapsend",
    "knapsendes": "knapsend",
    "knapsendste": "knapsend",
    "knapsendstem": "knapsend",
    "knapsendsten": "knapsend",
    "knapsendster": "knapsend",
    "knapsendstes": "knapsend",
    "knapsest": "knapsen",
    "knapset": "knapsen",
    "knapst": "knapsen",
    "knapste": "knapsen",
    "knapsten": "knapsen",
    "knapstest": "knapsen",
    "knapstet": "knapsen",
    "knarre": "knarren",
    "knarrend": "knarren",
    "knarrende": "knarrend",
    "knarrendem": "knarrend",
    "knarrenden": "knarrend",
    "knarrender": "knarrend",
    "knarrendere": "knarrend",
    "knarrenderem": "knarrend",
    "knarrenderen": "knarrend",
    "knarrenderer": "knarrend",
    "knarrenderes": "knarrend",
    "knarrendes": "knarrend",
    "knarrendste": "knarrend",
    "knarrendstem": "knarrend",
    "knarrendsten": "knarrend",
    "knarrendster": "knarrend",
    "knarrendstes": "knarrend",
    "knarrest": "knarren",
    "knarret": "knarren",
    "knarrst": "knarren",
    "knarrt": "knarren",
    "knarrte": "knarren",
    "knarrten": "knarren",
    "knarrtest": "knarren",
    "knarrtet": "knarren",
    "knarze": "knarzen",
    "knarzend": "knarzen",
    "knarzende": "knarzend",
    "knarzendem": "knarzend",
    "knarzenden": "knarzend",
    "knarzender": "knarzend",
    "knarzendere": "knarzend",
    "knarzenderem": "knarzend",
    "knarzenderen": "knarzend",
    "knarzenderer": "knarzend",
    "knarzenderes": "knarzend",
    "knarzendes": "knarzend",
    "knarzendste": "knarzend",
    "knarzendstem": "knarzend",
    "knarzendsten": "knarzend",
    "knarzendster": "knarzend",
    "knarzendstes": "knarzend",
    "knarzest": "knarzen",
    "knarzet": "knarzen",
    "knarzt": "knarzen",
    "knarzte": "knarzen",
    "knarzten": "knarzen",
    "knarztest": "knarzen",
    "knarztet": "knarzen",
    "knattere": "knattern",
    "knatternd": "knattern",
    "knatternde": "knatternd",
    "knatterndem": "knatternd",
    "knatternden": "knatternd",
    "knatternder": "knatternd",
    "knatterndere": "knatternd",
    "knatternderem": "knatternd",
    "knatternderen": "knatternd",
    "knatternderer": "knatternd",
    "knatternderes": "knatternd",
    "knatterndes": "knatternd",
    "knatterndste": "knatternd",
    "knatterndstem": "knatternd",
    "knatterndsten": "knatternd",
    "knatterndster": "knatternd",
    "knatterndstes": "knatternd",
    "knatterst": "knattern",
    "knattert": "knattern",
    "knatterte": "knattern",
    "knatterten": "knattern",
    "knattertest": "knattern",
    "knattertet": "knattern",
    "knaupeligem": "knaupelig",
    "knaupeligen": "knaupelig",
    "knaupeliger": "knaupelig",
    "knaupeligere": "knaupelig",
    "knaupeligerem": "knaupelig",
    "knaupeligeren": "knaupelig",
    "knaupeligerer": "knaupelig",
    "knaupeligeres": "knaupelig",
    "knaupeliges": "knaupelig",
    "knaupeligste": "knaupelig",
    "knaupeligstem": "knaupelig",
    "knaupeligsten": "knaupelig",
    "knaupeligster": "knaupelig",
    "knaupeligstes": "knaupelig",
    "knausere": "knausern",
    "knauserige": "knauserig",
    "knauserigem": "knauserig",
    "knauserigen": "knauserig",
    "knauseriger": "knauserig",
    "knauserigere": "knauserig",
    "knauserigerem": "knauserig",
    "knauserigeren": "knauserig",
    "knauserigerer": "knauserig",
    "knauserigeres": "knauserig",
    "knauseriges": "knauserig",
    "knauserigste": "knauserig",
    "knauserigstem": "knauserig",
    "knauserigsten": "knauserig",
    "knauserigster": "knauserig",
    "knauserigstes": "knauserig",
    "knausernd": "knausern",
    "knausernde": "knausernd",
    "knauserndem": "knausernd",
    "knausernden": "knausernd",
    "knausernder": "knausernd",
    "knauserndere": "knausernd",
    "knausernderem": "knausernd",
    "knausernderen": "knausernd",
    "knausernderer": "knausernd",
    "knausernderes": "knausernd",
    "knauserndes": "knausernd",
    "knauserndste": "knausernd",
    "knauserndstem": "knausernd",
    "knauserndsten": "knausernd",
    "knauserndster": "knausernd",
    "knauserndstes": "knausernd",
    "knauserst": "knausern",
    "knausert": "knausern",
    "knauserte": "knausern",
    "knauserten": "knausern",
    "knausertest": "knausern",
    "knausertet": "knausern",
    "knautsche": "knautschen",
    "knautschend": "knautschen",
    "knautschende": "knautschend",
    "knautschendem": "knautschend",
    "knautschenden": "knautschend",
    "knautschender": "knautschend",
    "knautschendere": "knautschend",
    "knautschenderem": "knautschend",
    "knautschenderen": "knautschend",
    "knautschenderer": "knautschend",
    "knautschenderes": "knautschend",
    "knautschendes": "knautschend",
    "knautschendste": "knautschend",
    "knautschendstem": "knautschend",
    "knautschendsten": "knautschend",
    "knautschendster": "knautschend",
    "knautschendstes": "knautschend",
    "knautschest": "knautschen",
    "knautschet": "knautschen",
    "knautschige": "knautschig",
    "knautschigem": "knautschig",
    "knautschigen": "knautschig",
    "knautschiger": "knautschig",
    "knautschigere": "knautschig",
    "knautschigerem": "knautschig",
    "knautschigeren": "knautschig",
    "knautschigerer": "knautschig",
    "knautschigeres": "knautschig",
    "knautschiges": "knautschig",
    "knautschigste": "knautschig",
    "knautschigstem": "knautschig",
    "knautschigsten": "knautschig",
    "knautschigster": "knautschig",
    "knautschigstes": "knautschig",
    "knautschst": "knautschen",
    "knautscht": "knautschen",
    "knautschte": "knautschen",
    "knautschten": "knautschen",
    "knautschtest": "knautschen",
    "knautschtet": "knautschen",
    "knebele": "knebeln",
    "knebelnd": "knebeln",
    "knebelnde": "knebelnd",
    "knebelndem": "knebelnd",
    "knebelnden": "knebelnd",
    "knebelnder": "knebelnd",
    "knebelndes": "knebelnd",
    "knebelst": "knebeln",
    "knebelt": "knebeln",
    "knebelte": "knebeln",
    "knebelten": "knebeln",
    "knebeltest": "knebeln",
    "knebeltet": "knebeln",
    "kneble": "knebeln",
    "knechtend": "knechten",
    "knechtende": "knechtend",
    "knechtendem": "knechtend",
    "knechtenden": "knechtend",
    "knechtender": "knechtend",
    "knechtendere": "knechtend",
    "knechtenderem": "knechtend",
    "knechtenderen": "knechtend",
    "knechtenderer": "knechtend",
    "knechtenderes": "knechtend",
    "knechtendes": "knechtend",
    "knechtendste": "knechtend",
    "knechtendstem": "knechtend",
    "knechtendsten": "knechtend",
    "knechtendster": "knechtend",
    "knechtendstes": "knechtend",
    "knechtest": "knechten",
    "knechtet": "knechten",
    "knechtete": "knechten",
    "knechteten": "knechten",
    "knechtetest": "knechten",
    "knechtetet": "knechten",
    "kneife": "kneifen",
    "kneifend": "kneifen",
    "kneifende": "kneifend",
    "kneifendem": "kneifend",
    "kneifenden": "kneifend",
    "kneifender": "kneifend",
    "kneifendes": "kneifend",
    "kneifest": "kneifen",
    "kneifet": "kneifen",
    "kneifst": "kneifen",
    "kneift": "kneifen",
    "knetend": "kneten",
    "knetende": "knetend",
    "knetendem": "knetend",
    "knetenden": "knetend",
    "knetender": "knetend",
    "knetendere": "knetend",
    "knetenderem": "knetend",
    "knetenderen": "knetend",
    "knetenderer": "knetend",
    "knetenderes": "knetend",
    "knetendes": "knetend",
    "knetendste": "knetend",
    "knetendstem": "knetend",
    "knetendsten": "knetend",
    "knetendster": "knetend",
    "knetendstes": "knetend",
    "knetest": "kneten",
    "knetet": "kneten",
    "knetete": "kneten",
    "kneteten": "kneten",
    "knetetest": "kneten",
    "knetetet": "kneten",
    "knickend": "knicken",
    "knickende": "knickend",
    "knickendem": "knickend",
    "knickenden": "knickend",
    "knickender": "knickend",
    "knickendere": "knickend",
    "knickenderem": "knickend",
    "knickenderen": "knickend",
    "knickenderer": "knickend",
    "knickenderes": "knickend",
    "knickendes": "knickend",
    "knickendste": "knickend",
    "knickendstem": "knickend",
    "knickendsten": "knickend",
    "knickendster": "knickend",
    "knickendstes": "knickend",
    "knickest": "knicken",
    "knicket": "knicken",
    "knickrige": "knickrig",
    "knickrigem": "knickrig",
    "knickrigen": "knickrig",
    "knickriger": "knickrig",
    "knickrigere": "knickrig",
    "knickrigerem": "knickrig",
    "knickrigeren": "knickrig",
    "knickrigerer": "knickrig",
    "knickrigeres": "knickrig",
    "knickriges": "knickrig",
    "knickrigste": "knickrig",
    "knickrigstem": "knickrig",
    "knickrigsten": "knickrig",
    "knickrigster": "knickrig",
    "knickrigstes": "knickrig",
    "knickse": "knicksen",
    "knicksend": "knicksen",
    "knicksende": "knicksend",
    "knicksendem": "knicksend",
    "knicksenden": "knicksend",
    "knicksender": "knicksend",
    "knicksendes": "knicksend",
    "knicksest": "knicksen",
    "knickset": "knicksen",
    "knickst": "knicksen",
    "knickste": "knicksen",
    "knicksten": "knicksen",
    "knickstest": "knicksen",
    "knickstet": "knicksen",
    "knickt": "knicken",
    "knickte": "knicken",
    "knickten": "knicken",
    "knicktest": "knicken",
    "knicktet": "knicken",
    "knie": "knien",
    "kniefreiem": "kniefrei",
    "kniefreien": "kniefrei",
    "kniefreier": "kniefrei",
    "kniefreies": "kniefrei",
    "kniend": "knien",
    "kniende": "kniend",
    "kniendem": "kniend",
    "knienden": "kniend",
    "kniender": "kniend",
    "kniendes": "kniend",
    "kniest": "knien",
    "kniet": "knien",
    "kniete": "knien",
    "knieten": "knien",
    "knietest": "knien",
    "knietet": "knien",
    "kniff": "kneifen",
    "kniffeligem": "kniffelig",
    "kniffeligen": "kniffelig",
    "kniffeliger": "kniffelig",
    "kniffeligere": "kniffelig",
    "kniffeligerem": "kniffelig",
    "kniffeligeren": "kniffelig",
    "kniffeligerer": "kniffelig",
    "kniffeligeres": "kniffelig",
    "kniffeliges": "kniffelig",
    "kniffeligste": "kniffelig",
    "kniffeligstem": "kniffelig",
    "kniffeligsten": "kniffelig",
    "kniffeligster": "kniffelig",
    "kniffeligstes": "kniffelig",
    "kniffen": "kneifen",
    "kniffest": "kneifen",
    "kniffet": "kneifen",
    "knifflige": "knifflig",
    "kniffligem": "knifflig",
    "kniffligen": "knifflig",
    "kniffliger": "knifflig",
    "kniffligere": "knifflig",
    "kniffligerem": "knifflig",
    "kniffligeren": "knifflig",
    "kniffligerer": "knifflig",
    "kniffligeres": "knifflig",
    "kniffliges": "knifflig",
    "kniffligste": "knifflig",
    "kniffligstem": "knifflig",
    "kniffligsten": "knifflig",
    "kniffligster": "knifflig",
    "kniffligstes": "knifflig",
    "kniffst": "kneifen",
    "knifft": "kneifen",
    "knipse": "knipsen",
    "knipsend": "knipsen",
    "knipsende": "knipsend",
    "knipsendem": "knipsend",
    "knipsenden": "knipsend",
    "knipsender": "knipsend",
    "knipsendes": "knipsend",
    "knipsest": "knipsen",
    "knipset": "knipsen",
    "knipst": "knipsen",
    "knipste": "knipsen",
    "knipsten": "knipsen",
    "knipstest": "knipsen",
    "knipstet": "knipsen",
    "knirsche": "knirschen",
    "knirschend": "knirschen",
    "knirschende": "knirschend",
    "knirschendem": "knirschend",
    "knirschenden": "knirschend",
    "knirschender": "knirschend",
    "knirschendere": "knirschend",
    "knirschenderem": "knirschend",
    "knirschenderen": "knirschend",
    "knirschenderer": "knirschend",
    "knirschenderes": "knirschend",
    "knirschendes": "knirschend",
    "knirschendste": "knirschend",
    "knirschendstem": "knirschend",
    "knirschendsten": "knirschend",
    "knirschendster": "knirschend",
    "knirschendstes": "knirschend",
    "knirschest": "knirschen",
    "knirschet": "knirschen",
    "knirschst": "knirschen",
    "knirscht": "knirschen",
    "knirschte": "knirschen",
    "knirschten": "knirschen",
    "knirschtest": "knirschen",
    "knirschtet": "knirschen",
    "knistere": "knistern",
    "knisternd": "knistern",
    "knisternde": "knisternd",
    "knisterndem": "knisternd",
    "knisternden": "knisternd",
    "knisternder": "knisternd",
    "knisterndere": "knisternd",
    "knisternderem": "knisternd",
    "knisternderen": "knisternd",
    "knisternderer": "knisternd",
    "knisternderes": "knisternd",
    "knisterndes": "knisternd",
    "knisterndste": "knisternd",
    "knisterndstem": "knisternd",
    "knisterndsten": "knisternd",
    "knisterndster": "knisternd",
    "knisterndstes": "knisternd",
    "knisterst": "knistern",
    "knistert": "knistern",
    "knisterte": "knistern",
    "knisterten": "knistern",
    "knistertest": "knistern",
    "knistertet": "knistern",
    "knittere": "knittern",
    "knitterfreie": "knitterfrei",
    "knitterfreiem": "knitterfrei",
    "knitterfreien": "knitterfrei",
    "knitterfreier": "knitterfrei",
    "knitterfreies": "knitterfrei",
    "knitterige": "knitterig",
    "knitterigem": "knitterig",
    "knitterigen": "knitterig",
    "knitteriger": "knitterig",
    "knitterigere": "knitterig",
    "knitterigerem": "knitterig",
    "knitterigeren": "knitterig",
    "knitterigerer": "knitterig",
    "knitterigeres": "knitterig",
    "knitteriges": "knitterig",
    "knitterigste": "knitterig",
    "knitterigstem": "knitterig",
    "knitterigsten": "knitterig",
    "knitterigster": "knitterig",
    "knitterigstes": "knitterig",
    "knitternd": "knittern",
    "knitternde": "knitternd",
    "knitterndem": "knitternd",
    "knitternden": "knitternd",
    "knitternder": "knitternd",
    "knitterndere": "knitternd",
    "knitternderem": "knitternd",
    "knitternderen": "knitternd",
    "knitternderer": "knitternd",
    "knitternderes": "knitternd",
    "knitterndes": "knitternd",
    "knitterndste": "knitternd",
    "knitterndstem": "knitternd",
    "knitterndsten": "knitternd",
    "knitterndster": "knitternd",
    "knitterndstes": "knitternd",
    "knitterst": "knittern",
    "knittert": "knittern",
    "knitterte": "knittern",
    "knitterten": "knittern",
    "knittertest": "knittern",
    "knittertet": "knittern",
    "knittrige": "knittrig",
    "knittrigem": "knittrig",
    "knittrigen": "knittrig",
    "knittriger": "knittrig",
    "knittrigere": "knittrig",
    "knittrigerem": "knittrig",
    "knittrigeren": "knittrig",
    "knittrigerer": "knittrig",
    "knittrigeres": "knittrig",
    "knittriges": "knittrig",
    "knittrigste": "knittrig",
    "knittrigstem": "knittrig",
    "knittrigsten": "knittrig",
    "knittrigster": "knittrig",
    "knittrigstes": "knittrig",
    "knobele": "knobeln",
    "knobelnd": "knobeln",
    "knobelnde": "knobelnd",
    "knobelndem": "knobelnd",
    "knobelnden": "knobelnd",
    "knobelnder": "knobelnd",
    "knobelndere": "knobelnd",
    "knobelnderem": "knobelnd",
    "knobelnderen": "knobelnd",
    "knobelnderer": "knobelnd",
    "knobelnderes": "knobelnd",
    "knobelndes": "knobelnd",
    "knobelndste": "knobelnd",
    "knobelndstem": "knobelnd",
    "knobelndsten": "knobelnd",
    "knobelndster": "knobelnd",
    "knobelndstes": "knobelnd",
    "knobelst": "knobeln",
    "knobelt": "knobeln",
    "knobelte": "knobeln",
    "knobelten": "knobeln",
    "knobeltest": "knobeln",
    "knobeltet": "knobeln",
    "knoble": "knobeln",
    "knochige": "knochig",
    "knochigem": "knochig",
    "knochigen": "knochig",
    "knochiger": "knochig",
    "knochigere": "knochig",
    "knochigerem": "knochig",
    "knochigeren": "knochig",
    "knochigerer": "knochig",
    "knochigeres": "knochig",
    "knochiges": "knochig",
    "knochigste": "knochig",
    "knochigstem": "knochig",
    "knochigsten": "knochig",
    "knochigster": "knochig",
    "knochigstes": "knochig",
    "knolligem": "knollig",
    "knolligen": "knollig",
    "knolliger": "knollig",
    "knolligere": "knollig",
    "knolligerem": "knollig",
    "knolligeren": "knollig",
    "knolligerer": "knollig",
    "knolligeres": "knollig",
    "knolliges": "knollig",
    "knolligste": "knollig",
    "knolligstem": "knollig",
    "knolligsten": "knollig",
    "knolligster": "knollig",
    "knolligstes": "knollig",
    "knorpelige": "knorpelig",
    "knorpeligem": "knorpelig",
    "knorpeligen": "knorpelig",
    "knorpeliger": "knorpelig",
    "knorpeligere": "knorpelig",
    "knorpeligerem": "knorpelig",
    "knorpeligeren": "knorpelig",
    "knorpeligerer": "knorpelig",
    "knorpeligeres": "knorpelig",
    "knorpeliges": "knorpelig",
    "knorpeligste": "knorpelig",
    "knorpeligstem": "knorpelig",
    "knorpeligsten": "knorpelig",
    "knorpeligster": "knorpelig",
    "knorpeligstes": "knorpelig",
    "knorpligem": "knorplig",
    "knorpligen": "knorplig",
    "knorpliger": "knorplig",
    "knorpligere": "knorplig",
    "knorpligerem": "knorplig",
    "knorpligeren": "knorplig",
    "knorpligerer": "knorplig",
    "knorpligeres": "knorplig",
    "knorpliges": "knorplig",
    "knorpligste": "knorplig",
    "knorpligstem": "knorplig",
    "knorpligsten": "knorplig",
    "knorpligster": "knorplig",
    "knorpligstes": "knorplig",
    "knorrige": "knorrig",
    "knorrigem": "knorrig",
    "knorrigen": "knorrig",
    "knorriger": "knorrig",
    "knorrigere": "knorrig",
    "knorrigerem": "knorrig",
    "knorrigeren": "knorrig",
    "knorrigerer": "knorrig",
    "knorrigeres": "knorrig",
    "knorriges": "knorrig",
    "knorrigste": "knorrig",
    "knorrigstem": "knorrig",
    "knorrigsten": "knorrig",
    "knorrigster": "knorrig",
    "knorrigstes": "knorrig",
    "knote": "knoten",
    "knotend": "knoten",
    "knotende": "knotend",
    "knotendem": "knotend",
    "knotenden": "knotend",
    "knotender": "knotend",
    "knotendes": "knotend",
    "knotest": "knoten",
    "knotet": "knoten",
    "knotete": "knoten",
    "knoteten": "knoten",
    "knotetest": "knoten",
    "knotetet": "knoten",
    "knuffe": "knuffen",
    "knuffend": "knuffen",
    "knuffende": "knuffend",
    "knuffendem": "knuffend",
    "knuffenden": "knuffend",
    "knuffender": "knuffend",
    "knuffendes": "knuffend",
    "knuffest": "knuffen",
    "knuffet": "knuffen",
    "knuffst": "knuffen",
    "knufft": "knuffen",
    "knuffte": "knuffen",
    "knufften": "knuffen",
    "knufftest": "knuffen",
    "knufftet": "knuffen",
    "knurre": "knurren",
    "knurrend": "knurren",
    "knurrende": "knurrend",
    "knurrendem": "knurrend",
    "knurrenden": "knurrend",
    "knurrender": "knurrend",
    "knurrendere": "knurrend",
    "knurrenderem": "knurrend",
    "knurrenderen": "knurrend",
    "knurrenderer": "knurrend",
    "knurrenderes": "knurrend",
    "knurrendes": "knurrend",
    "knurrendste": "knurrend",
    "knurrendstem": "knurrend",
    "knurrendsten": "knurrend",
    "knurrendster": "knurrend",
    "knurrendstes": "knurrend",
    "knurrest": "knurren",
    "knurret": "knurren",
    "knurrst": "knurren",
    "knurrt": "knurren",
    "knurrte": "knurren",
    "knurrten": "knurren",
    "knurrtest": "knurren",
    "knurrtet": "knurren",
    "knuspere": "knuspern",
    "knuspernd": "knuspern",
    "knuspernde": "knuspernd",
    "knusperndem": "knuspernd",
    "knuspernden": "knuspernd",
    "knuspernder": "knuspernd",
    "knusperndere": "knuspernd",
    "knuspernderem": "knuspernd",
    "knuspernderen": "knuspernd",
    "knuspernderer": "knuspernd",
    "knuspernderes": "knuspernd",
    "knusperndes": "knuspernd",
    "knusperndste": "knuspernd",
    "knusperndstem": "knuspernd",
    "knusperndsten": "knuspernd",
    "knusperndster": "knuspernd",
    "knusperndstes": "knuspernd",
    "knusperst": "knuspern",
    "knuspert": "knuspern",
    "knusperte": "knuspern",
    "knusperten": "knuspern",
    "knuspertest": "knuspern",
    "knuspertet": "knuspern",
    "knusprige": "knusprig",
    "knusprigem": "knusprig",
    "knusprigen": "knusprig",
    "knuspriger": "knusprig",
    "knusprigere": "knusprig",
    "knusprigerem": "knusprig",
    "knusprigeren": "knusprig",
    "knusprigerer": "knusprig",
    "knusprigeres": "knusprig",
    "knuspriges": "knusprig",
    "knusprigste": "knusprig",
    "knusprigstem": "knusprig",
    "knusprigsten": "knusprig",
    "knusprigster": "knusprig",
    "knusprigstes": "knusprig",
    "knutsche": "knutschen",
    "knutschend": "knutschen",
    "knutschende": "knutschend",
    "knutschendem": "knutschend",
    "knutschenden": "knutschend",
    "knutschender": "knutschend",
    "knutschendere": "knutschend",
    "knutschenderem": "knutschend",
    "knutschenderen": "knutschend",
    "knutschenderer": "knutschend",
    "knutschenderes": "knutschend",
    "knutschendes": "knutschend",
    "knutschendste": "knutschend",
    "knutschendstem": "knutschend",
    "knutschendsten": "knutschend",
    "knutschendster": "knutschend",
    "knutschendstes": "knutschend",
    "knutschest": "knutschen",
    "knutschet": "knutschen",
    "knutschst": "knutschen",
    "knutscht": "knutschen",
    "knutschte": "knutschen",
    "knutschten": "knutschen",
    "knutschtest": "knutschen",
    "knutschtet": "knutschen",
    "knöcherigem": "knöcherig",
    "knöcherigen": "knöcherig",
    "knöcheriger": "knöcherig",
    "knöcherigere": "knöcherig",
    "knöcherigerem": "knöcherig",
    "knöcherigeren": "knöcherig",
    "knöcherigerer": "knöcherig",
    "knöcherigeres": "knöcherig",
    "knöcheriges": "knöcherig",
    "knöcherigste": "knöcherig",
    "knöcherigstem": "knöcherig",
    "knöcherigsten": "knöcherig",
    "knöcherigster": "knöcherig",
    "knöcherigstes": "knöcherig",
    "knöcherne": "knöchern",
    "knöchernem": "knöchern",
    "knöchernen": "knöchern",
    "knöcherner": "knöchern",
    "knöchernere": "knöchern",
    "knöchernerem": "knöchern",
    "knöcherneren": "knöchern",
    "knöchernerer": "knöchern",
    "knöcherneres": "knöchern",
    "knöchernes": "knöchern",
    "knöcherneste": "knöchern",
    "knöchernestem": "knöchern",
    "knöchernesten": "knöchern",
    "knöchernester": "knöchern",
    "knöchernestes": "knöchern",
    "knöpfend": "knöpfen",
    "knöpfende": "knöpfend",
    "knöpfendem": "knöpfend",
    "knöpfenden": "knöpfend",
    "knöpfender": "knöpfend",
    "knöpfendes": "knöpfend",
    "knöpfest": "knöpfen",
    "knöpfet": "knöpfen",
    "knöpfst": "knöpfen",
    "knöpft": "knöpfen",
    "knöpfte": "knöpfen",
    "knöpften": "knöpfen",
    "knöpftest": "knöpfen",
    "knöpftet": "knöpfen",
    "knülle": "knüllen",
    "knüllend": "knüllen",
    "knüllende": "knüllend",
    "knüllendem": "knüllend",
    "knüllenden": "knüllend",
    "knüllender": "knüllend",
    "knüllendes": "knüllend",
    "knüllest": "knüllen",
    "knüllet": "knüllen",
    "knüllst": "knüllen",
    "knüllt": "knüllen",
    "knüllte": "knüllen",
    "knüllten": "knüllen",
    "knülltest": "knüllen",
    "knülltet": "knüllen",
    "knüpfe": "knüpfen",
    "knüpfend": "knüpfen",
    "knüpfende": "knüpfend",
    "knüpfendem": "knüpfend",
    "knüpfenden": "knüpfend",
    "knüpfender": "knüpfend",
    "knüpfendes": "knüpfend",
    "knüpfest": "knüpfen",
    "knüpfet": "knüpfen",
    "knüpfst": "knüpfen",
    "knüpft": "knüpfen",
    "knüpfte": "knüpfen",
    "knüpften": "knüpfen",
    "knüpftest": "knüpfen",
    "knüpftet": "knüpfen",
    "knüppeldickem": "knüppeldick",
    "knüppeldicken": "knüppeldick",
    "knüppeldicker": "knüppeldick",
    "knüppeldickes": "knüppeldick",
    "knüppele": "knüppeln",
    "knüppelharte": "knüppelhart",
    "knüppelhartem": "knüppelhart",
    "knüppelharten": "knüppelhart",
    "knüppelharter": "knüppelhart",
    "knüppelhartes": "knüppelhart",
    "knüppelnd": "knüppeln",
    "knüppelnde": "knüppelnd",
    "knüppelndem": "knüppelnd",
    "knüppelnden": "knüppelnd",
    "knüppelnder": "knüppelnd",
    "knüppelndere": "knüppelnd",
    "knüppelnderem": "knüppelnd",
    "knüppelnderen": "knüppelnd",
    "knüppelnderer": "knüppelnd",
    "knüppelnderes": "knüppelnd",
    "knüppelndes": "knüppelnd",
    "knüppelndste": "knüppelnd",
    "knüppelndstem": "knüppelnd",
    "knüppelndsten": "knüppelnd",
    "knüppelndster": "knüppelnd",
    "knüppelndstes": "knüppelnd",
    "knüppelst": "knüppeln",
    "knüppelt": "knüppeln",
    "knüppelte": "knüppeln",
    "knüppelten": "knüppeln",
    "knüppeltest": "knüppeln",
    "knüppeltet": "knüppeln",
    "knüpple": "knüppeln",
    "koaxialem": "koaxial",
    "koaxialen": "koaxial",
    "koaxialer": "koaxial",
    "koaxiales": "koaxial",
    "kochechtem": "kochecht",
    "kochechten": "kochecht",
    "kochechter": "kochecht",
    "kochechtes": "kochecht",
    "kochend": "kochen",
    "kochende": "kochend",
    "kochendem": "kochend",
    "kochenden": "kochend",
    "kochender": "kochend",
    "kochendes": "kochend",
    "kochest": "kochen",
    "kochet": "kochen",
    "kochfertige": "kochfertig",
    "kochfertigem": "kochfertig",
    "kochfertigen": "kochfertig",
    "kochfertiger": "kochfertig",
    "kochfertiges": "kochfertig",
    "kochfeste": "kochfest",
    "kochfestem": "kochfest",
    "kochfesten": "kochfest",
    "kochfester": "kochfest",
    "kochfestes": "kochfest",
    "kochst": "kochen",
    "kocht": "kochen",
    "kochte": "kochen",
    "kochten": "kochen",
    "kochtest": "kochen",
    "kochtet": "kochen",
    "kodderige": "kodderig",
    "kodderigem": "kodderig",
    "kodderigen": "kodderig",
    "kodderiger": "kodderig",
    "kodderigere": "kodderig",
    "kodderigerem": "kodderig",
    "kodderigeren": "kodderig",
    "kodderigerer": "kodderig",
    "kodderigeres": "kodderig",
    "kodderiges": "kodderig",
    "kodderigste": "kodderig",
    "kodderigstem": "kodderig",
    "kodderigsten": "kodderig",
    "kodderigster": "kodderig",
    "kodderigstes": "kodderig",
    "koedukative": "koedukativ",
    "koedukativem": "koedukativ",
    "koedukativen": "koedukativ",
    "koedukativer": "koedukativ",
    "koedukatives": "koedukativ",
    "koffeinfreie": "koffeinfrei",
    "koffeinfreiem": "koffeinfrei",
    "koffeinfreien": "koffeinfrei",
    "koffeinfreier": "koffeinfrei",
    "koffeinfreies": "koffeinfrei",
    "kognitivem": "kognitiv",
    "kognitiven": "kognitiv",
    "kognitiver": "kognitiv",
    "kognitivere": "kognitiv",
    "kognitiverem": "kognitiv",
    "kognitiveren": "kognitiv",
    "kognitiverer": "kognitiv",
    "kognitiveres": "kognitiv",
    "kognitives": "kognitiv",
    "kognitivste": "kognitiv",
    "kognitivstem": "kognitiv",
    "kognitivsten": "kognitiv",
    "kognitivster": "kognitiv",
    "kognitivstes": "kognitiv",
    "kohlend": "kohlen",
    "kohlende": "kohlend",
    "kohlendem": "kohlend",
    "kohlenden": "kohlend",
    "kohlender": "kohlend",
    "kohlendes": "kohlend",
    "kohlest": "kohlen",
    "kohlet": "kohlen",
    "kohlst": "kohlen",
    "kohlt": "kohlen",
    "kohlte": "kohlen",
    "kohlten": "kohlen",
    "kohltest": "kohlen",
    "kohltet": "kohlen",
    "kohärente": "kohärent",
    "kohärentem": "kohärent",
    "kohärenten": "kohärent",
    "kohärenter": "kohärent",
    "kohärentes": "kohärent",
    "kokele": "kokeln",
    "kokelnd": "kokeln",
    "kokelnde": "kokelnd",
    "kokelndem": "kokelnd",
    "kokelnden": "kokelnd",
    "kokelnder": "kokelnd",
    "kokelndere": "kokelnd",
    "kokelnderem": "kokelnd",
    "kokelnderen": "kokelnd",
    "kokelnderer": "kokelnd",
    "kokelnderes": "kokelnd",
    "kokelndes": "kokelnd",
    "kokelndste": "kokelnd",
    "kokelndstem": "kokelnd",
    "kokelndsten": "kokelnd",
    "kokelndster": "kokelnd",
    "kokelndstes": "kokelnd",
    "kokelst": "kokeln",
    "kokelt": "kokeln",
    "kokelte": "kokeln",
    "kokelten": "kokeln",
    "kokeltest": "kokeln",
    "kokeltet": "kokeln",
    "kokette": "kokett",
    "kokettem": "kokett",
    "koketten": "kokett",
    "koketter": "kokett",
    "kokettere": "kokett",
    "koketterem": "kokett",
    "koketteren": "kokett",
    "koketterer": "kokett",
    "koketteres": "kokett",
    "kokettes": "kokett",
    "koketteste": "kokett",
    "kokettestem": "kokett",
    "kokettesten": "kokett",
    "kokettester": "kokett",
    "kokettestes": "kokett",
    "kokettiere": "kokettieren",
    "kokettierend": "kokettieren",
    "kokettierende": "kokettierend",
    "kokettierendem": "kokettierend",
    "kokettierenden": "kokettierend",
    "kokettierender": "kokettierend",
    "kokettierendere": "kokettierend",
    "kokettierenderem": "kokettierend",
    "kokettierenderen": "kokettierend",
    "kokettierenderer": "kokettierend",
    "kokettierenderes": "kokettierend",
    "kokettierendes": "kokettierend",
    "kokettierendste": "kokettierend",
    "kokettierendstem": "kokettierend",
    "kokettierendsten": "kokettierend",
    "kokettierendster": "kokettierend",
    "kokettierendstes": "kokettierend",
    "kokettierest": "kokettieren",
    "kokettieret": "kokettieren",
    "kokettierst": "kokettieren",
    "kokettiert": "kokettieren",
    "kokettierte": "kokettieren",
    "kokettiertem": "kokettiert",
    "kokettierten": "kokettieren",
    "kokettierter": "kokettiert",
    "kokettiertere": "kokettiert",
    "kokettierterem": "kokettiert",
    "kokettierteren": "kokettiert",
    "kokettierterer": "kokettiert",
    "kokettierteres": "kokettiert",
    "kokettiertes": "kokettiert",
    "kokettiertest": "kokettieren",
    "kokettierteste": "kokettiert",
    "kokettiertestem": "kokettiert",
    "kokettiertesten": "kokettiert",
    "kokettiertester": "kokettiert",
    "kokettiertestes": "kokettiert",
    "kokettiertet": "kokettieren",
    "kokle": "kokeln",
    "kokse": "koksen",
    "koksend": "koksen",
    "koksende": "koksend",
    "koksendem": "koksend",
    "koksenden": "koksend",
    "koksender": "koksend",
    "koksendes": "koksend",
    "koksest": "koksen",
    "kokset": "koksen",
    "kokst": "koksen",
    "kokste": "koksen",
    "koksten": "koksen",
    "kokstest": "koksen",
    "kokstet": "koksen",
    "kollabiere": "kollabieren",
    "kollabierend": "kollabieren",
    "kollabierende": "kollabierend",
    "kollabierendem": "kollabierend",
    "kollabierenden": "kollabierend",
    "kollabierender": "kollabierend",
    "kollabierendere": "kollabierend",
    "kollabierenderem": "kollabierend",
    "kollabierenderen": "kollabierend",
    "kollabierenderer": "kollabierend",
    "kollabierenderes": "kollabierend",
    "kollabierendes": "kollabierend",
    "kollabierendste": "kollabierend",
    "kollabierendstem": "kollabierend",
    "kollabierendsten": "kollabierend",
    "kollabierendster": "kollabierend",
    "kollabierendstes": "kollabierend",
    "kollabierest": "kollabieren",
    "kollabieret": "kollabieren",
    "kollabierst": "kollabieren",
    "kollabiert": "kollabieren",
    "kollabierte": "kollabieren",
    "kollabiertem": "kollabiert",
    "kollabierten": "kollabieren",
    "kollabierter": "kollabiert",
    "kollabiertes": "kollabiert",
    "kollabiertest": "kollabieren",
    "kollabiertet": "kollabieren",
    "kollaborierend": "kollaborieren",
    "kollaborierende": "kollaborierend",
    "kollaborierendem": "kollaborierend",
    "kollaborierenden": "kollaborierend",
    "kollaborierender": "kollaborierend",
    "kollaborierendere": "kollaborierend",
    "kollaborierenderem": "kollaborierend",
    "kollaborierenderen": "kollaborierend",
    "kollaborierenderer": "kollaborierend",
    "kollaborierenderes": "kollaborierend",
    "kollaborierendes": "kollaborierend",
    "kollaborierendste": "kollaborierend",
    "kollaborierendstem": "kollaborierend",
    "kollaborierendsten": "kollaborierend",
    "kollaborierendster": "kollaborierend",
    "kollaborierendstes": "kollaborierend",
    "kollaborierest": "kollaborieren",
    "kollaborieret": "kollaborieren",
    "kollaborierst": "kollaborieren",
    "kollaboriert": "kollaborieren",
    "kollaborierte": "kollaborieren",
    "kollaboriertem": "kollaboriert",
    "kollaborierten": "kollaborieren",
    "kollaborierter": "kollaboriert",
    "kollaboriertere": "kollaboriert",
    "kollaborierterem": "kollaboriert",
    "kollaborierteren": "kollaboriert",
    "kollaborierterer": "kollaboriert",
    "kollaborierteres": "kollaboriert",
    "kollaboriertes": "kollaboriert",
    "kollaboriertest": "kollaborieren",
    "kollaborierteste": "kollaboriert",
    "kollaboriertestem": "kollaboriert",
    "kollaboriertesten": "kollaboriert",
    "kollaboriertester": "kollaboriert",
    "kollaboriertestes": "kollaboriert",
    "kollaboriertet": "kollaborieren",
    "kollegialem": "kollegial",
    "kollegialen": "kollegial",
    "kollegialer": "kollegial",
    "kollegialere": "kollegial",
    "kollegialerem": "kollegial",
    "kollegialeren": "kollegial",
    "kollegialerer": "kollegial",
    "kollegialeres": "kollegial",
    "kollegiales": "kollegial",
    "kollegialstem": "kollegial",
    "kollegialsten": "kollegial",
    "kollegialster": "kollegial",
    "kollegialstes": "kollegial",
    "kollektivem": "kollektiv",
    "kollektiven": "kollektiv",
    "kollektiver": "kollektiv",
    "kollektives": "kollektiv",
    "kolonialem": "kolonial",
    "kolonialen": "kolonial",
    "kolonialer": "kolonial",
    "koloniales": "kolonial",
    "kolonialisiere": "kolonialisieren",
    "kolonialisierend": "kolonialisieren",
    "kolonialisierende": "kolonialisierend",
    "kolonialisierendem": "kolonialisierend",
    "kolonialisierenden": "kolonialisierend",
    "kolonialisierender": "kolonialisierend",
    "kolonialisierendes": "kolonialisierend",
    "kolonialisierest": "kolonialisieren",
    "kolonialisieret": "kolonialisieren",
    "kolonialisierst": "kolonialisieren",
    "kolonialisiert": "kolonialisieren",
    "kolonialisierte": "kolonialisieren",
    "kolonialisiertem": "kolonialisiert",
    "kolonialisierten": "kolonialisieren",
    "kolonialisierter": "kolonialisiert",
    "kolonialisiertes": "kolonialisiert",
    "kolonialisiertest": "kolonialisieren",
    "kolonialisiertet": "kolonialisieren",
    "kolonialistische": "kolonialistisch",
    "kolonialistischem": "kolonialistisch",
    "kolonialistischen": "kolonialistisch",
    "kolonialistischer": "kolonialistisch",
    "kolonialistisches": "kolonialistisch",
    "kolonisiere": "kolonisieren",
    "kolonisierend": "kolonisieren",
    "kolonisierende": "kolonisierend",
    "kolonisierendem": "kolonisierend",
    "kolonisierenden": "kolonisierend",
    "kolonisierender": "kolonisierend",
    "kolonisierendes": "kolonisierend",
    "kolonisierest": "kolonisieren",
    "kolonisieret": "kolonisieren",
    "kolonisierst": "kolonisieren",
    "kolonisiert": "kolonisieren",
    "kolonisierte": "kolonisieren",
    "kolonisiertem": "kolonisiert",
    "kolonisierten": "kolonisieren",
    "kolonisierter": "kolonisiert",
    "kolonisiertes": "kolonisiert",
    "kolonisiertest": "kolonisieren",
    "kolonisiertet": "kolonisieren",
    "kolossalem": "kolossal",
    "kolossalen": "kolossal",
    "kolossaler": "kolossal",
    "kolossalere": "kolossal",
    "kolossalerem": "kolossal",
    "kolossaleren": "kolossal",
    "kolossalerer": "kolossal",
    "kolossaleres": "kolossal",
    "kolossales": "kolossal",
    "kolossalste": "kolossal",
    "kolossalstem": "kolossal",
    "kolossalsten": "kolossal",
    "kolossalster": "kolossal",
    "kolossalstes": "kolossal",
    "kombinatorischem": "kombinatorisch",
    "kombinatorischen": "kombinatorisch",
    "kombinatorischer": "kombinatorisch",
    "kombinatorisches": "kombinatorisch",
    "kombiniere": "kombinieren",
    "kombinierend": "kombinieren",
    "kombinierende": "kombinierend",
    "kombinierendem": "kombinierend",
    "kombinierenden": "kombinierend",
    "kombinierender": "kombinierend",
    "kombinierendes": "kombinierend",
    "kombinierest": "kombinieren",
    "kombinieret": "kombinieren",
    "kombinierst": "kombinieren",
    "kombiniert": "kombinieren",
    "kombinierte": "kombinieren",
    "kombiniertem": "kombiniert",
    "kombinierten": "kombinieren",
    "kombinierter": "kombiniert",
    "kombiniertes": "kombiniert",
    "kombiniertest": "kombinieren",
    "kombiniertet": "kombinieren",
    "komfortabelstem": "komfortabel",
    "komfortabelsten": "komfortabel",
    "komfortabelster": "komfortabel",
    "komfortabelstes": "komfortabel",
    "komfortable": "komfortabel",
    "komfortablem": "komfortabel",
    "komfortablen": "komfortabel",
    "komfortabler": "komfortabel",
    "komfortablere": "komfortabel",
    "komfortablerem": "komfortabel",
    "komfortableren": "komfortabel",
    "komfortablerer": "komfortabel",
    "komfortableres": "komfortabel",
    "komfortables": "komfortabel",
    "komischem": "komisch",
    "komischen": "komisch",
    "komischer": "komisch",
    "komischere": "komisch",
    "komischerem": "komisch",
    "komischeren": "komisch",
    "komischerer": "komisch",
    "komischeres": "komisch",
    "komisches": "komisch",
    "komischste": "komisch",
    "komischstem": "komisch",
    "komischsten": "komisch",
    "komischster": "komisch",
    "komischstes": "komisch",
    "kommandiere": "kommandieren",
    "kommandierend": "kommandieren",
    "kommandierende": "kommandierend",
    "kommandierendem": "kommandierend",
    "kommandierenden": "kommandierend",
    "kommandierender": "kommandierend",
    "kommandierendes": "kommandierend",
    "kommandierest": "kommandieren",
    "kommandieret": "kommandieren",
    "kommandierst": "kommandieren",
    "kommandiert": "kommandieren",
    "kommandierte": "kommandieren",
    "kommandiertem": "kommandiert",
    "kommandierten": "kommandieren",
    "kommandierter": "kommandiert",
    "kommandiertes": "kommandiert",
    "kommandiertest": "kommandieren",
    "kommandiertet": "kommandieren",
    "komme": "kommen",
    "kommend": "kommen",
    "kommende": "kommend",
    "kommendem": "kommend",
    "kommenden": "kommend",
    "kommender": "kommend",
    "kommendes": "kommend",
    "kommentarlosem": "kommentarlos",
    "kommentarlosen": "kommentarlos",
    "kommentarloser": "kommentarlos",
    "kommentarloses": "kommentarlos",
    "kommentiere": "kommentieren",
    "kommentierend": "kommentieren",
    "kommentierende": "kommentierend",
    "kommentierendem": "kommentierend",
    "kommentierenden": "kommentierend",
    "kommentierender": "kommentierend",
    "kommentierendes": "kommentierend",
    "kommentierest": "kommentieren",
    "kommentieret": "kommentieren",
    "kommentierst": "kommentieren",
    "kommentiert": "kommentieren",
    "kommentierte": "kommentieren",
    "kommentiertem": "kommentiert",
    "kommentierten": "kommentieren",
    "kommentierter": "kommentiert",
    "kommentiertes": "kommentiert",
    "kommentiertest": "kommentieren",
    "kommentiertet": "kommentieren",
    "kommerzialisiere": "kommerzialisieren",
    "kommerzialisierend": "kommerzialisieren",
    "kommerzialisierende": "kommerzialisierend",
    "kommerzialisierendem": "kommerzialisierend",
    "kommerzialisierenden": "kommerzialisierend",
    "kommerzialisierender": "kommerzialisierend",
    "kommerzialisierendere": "kommerzialisierend",
    "kommerzialisierenderem": "kommerzialisierend",
    "kommerzialisierenderen": "kommerzialisierend",
    "kommerzialisierenderer": "kommerzialisierend",
    "kommerzialisierenderes": "kommerzialisierend",
    "kommerzialisierendes": "kommerzialisierend",
    "kommerzialisierendste": "kommerzialisierend",
    "kommerzialisierendstem": "kommerzialisierend",
    "kommerzialisierendsten": "kommerzialisierend",
    "kommerzialisierendster": "kommerzialisierend",
    "kommerzialisierendstes": "kommerzialisierend",
    "kommerzialisierest": "kommerzialisieren",
    "kommerzialisieret": "kommerzialisieren",
    "kommerzialisierst": "kommerzialisieren",
    "kommerzialisiert": "kommerzialisieren",
    "kommerzialisierte": "kommerzialisieren",
    "kommerzialisiertem": "kommerzialisiert",
    "kommerzialisierten": "kommerzialisieren",
    "kommerzialisierter": "kommerzialisiert",
    "kommerzialisiertere": "kommerzialisiert",
    "kommerzialisierterem": "kommerzialisiert",
    "kommerzialisierteren": "kommerzialisiert",
    "kommerzialisierterer": "kommerzialisiert",
    "kommerzialisierteres": "kommerzialisiert",
    "kommerzialisiertes": "kommerzialisiert",
    "kommerzialisiertest": "kommerzialisieren",
    "kommerzialisierteste": "kommerzialisiert",
    "kommerzialisiertestem": "kommerzialisiert",
    "kommerzialisiertesten": "kommerzialisiert",
    "kommerzialisiertester": "kommerzialisiert",
    "kommerzialisiertestes": "kommerzialisiert",
    "kommerzialisiertet": "kommerzialisieren",
    "kommerziellem": "kommerziell",
    "kommerziellen": "kommerziell",
    "kommerzieller": "kommerziell",
    "kommerziellere": "kommerziell",
    "kommerziellerem": "kommerziell",
    "kommerzielleren": "kommerziell",
    "kommerziellerer": "kommerziell",
    "kommerzielleres": "kommerziell",
    "kommerzielles": "kommerziell",
    "kommerziellste": "kommerziell",
    "kommerziellstem": "kommerziell",
    "kommerziellsten": "kommerziell",
    "kommerziellster": "kommerziell",
    "kommerziellstes": "kommerziell",
    "kommest": "kommen",
    "kommet": "kommen",
    "kommissarischem": "kommissarisch",
    "kommissarischen": "kommissarisch",
    "kommissarischer": "kommissarisch",
    "kommissarisches": "kommissarisch",
    "kommst": "kommen",
    "kommt": "kommen",
    "kommunale": "kommunal",
    "kommunalem": "kommunal",
    "kommunalen": "kommunal",
    "kommunaler": "kommunal",
    "kommunales": "kommunal",
    "kommunalisiere": "kommunalisieren",
    "kommunalisierend": "kommunalisieren",
    "kommunalisierende": "kommunalisierend",
    "kommunalisierendem": "kommunalisierend",
    "kommunalisierenden": "kommunalisierend",
    "kommunalisierender": "kommunalisierend",
    "kommunalisierendere": "kommunalisierend",
    "kommunalisierenderem": "kommunalisierend",
    "kommunalisierenderen": "kommunalisierend",
    "kommunalisierenderer": "kommunalisierend",
    "kommunalisierenderes": "kommunalisierend",
    "kommunalisierendes": "kommunalisierend",
    "kommunalisierendste": "kommunalisierend",
    "kommunalisierendstem": "kommunalisierend",
    "kommunalisierendsten": "kommunalisierend",
    "kommunalisierendster": "kommunalisierend",
    "kommunalisierendstes": "kommunalisierend",
    "kommunalisierest": "kommunalisieren",
    "kommunalisieret": "kommunalisieren",
    "kommunalisierst": "kommunalisieren",
    "kommunalisiert": "kommunalisieren",
    "kommunalisierte": "kommunalisieren",
    "kommunalisiertem": "kommunalisiert",
    "kommunalisierten": "kommunalisieren",
    "kommunalisierter": "kommunalisiert",
    "kommunalisiertere": "kommunalisiert",
    "kommunalisierterem": "kommunalisiert",
    "kommunalisierteren": "kommunalisiert",
    "kommunalisierterer": "kommunalisiert",
    "kommunalisierteres": "kommunalisiert",
    "kommunalisiertes": "kommunalisiert",
    "kommunalisiertest": "kommunalisieren",
    "kommunalisierteste": "kommunalisiert",
    "kommunalisiertestem": "kommunalisiert",
    "kommunalisiertesten": "kommunalisiert",
    "kommunalisiertester": "kommunalisiert",
    "kommunalisiertestes": "kommunalisiert",
    "kommunalisiertet": "kommunalisieren",
    "kommunikativem": "kommunikativ",
    "kommunikativen": "kommunikativ",
    "kommunikativer": "kommunikativ",
    "kommunikatives": "kommunikativ",
    "kommunistischem": "kommunistisch",
    "kommunistischen": "kommunistisch",
    "kommunistischer": "kommunistisch",
    "kommunistischere": "kommunistisch",
    "kommunistischerem": "kommunistisch",
    "kommunistischeren": "kommunistisch",
    "kommunistischerer": "kommunistisch",
    "kommunistischeres": "kommunistisch",
    "kommunistisches": "kommunistisch",
    "kommunistischste": "kommunistisch",
    "kommunistischstem": "kommunistisch",
    "kommunistischsten": "kommunistisch",
    "kommunistischster": "kommunistisch",
    "kommunistischstes": "kommunistisch",
    "kommuniziere": "kommunizieren",
    "kommunizierend": "kommunizieren",
    "kommunizierende": "kommunizierend",
    "kommunizierendem": "kommunizierend",
    "kommunizierenden": "kommunizierend",
    "kommunizierender": "kommunizierend",
    "kommunizierendes": "kommunizierend",
    "kommunizierest": "kommunizieren",
    "kommunizieret": "kommunizieren",
    "kommunizierst": "kommunizieren",
    "kommuniziert": "kommunizieren",
    "kommunizierte": "kommunizieren",
    "kommuniziertem": "kommuniziert",
    "kommunizierten": "kommunizieren",
    "kommunizierter": "kommuniziert",
    "kommuniziertes": "kommuniziert",
    "kommuniziertest": "kommunizieren",
    "kommuniziertet": "kommunizieren",
    "kommutative": "kommutativ",
    "kommutativem": "kommutativ",
    "kommutativen": "kommutativ",
    "kommutativer": "kommutativ",
    "kommutatives": "kommutativ",
    "kompaktem": "kompakt",
    "kompakten": "kompakt",
    "kompakter": "kompakt",
    "kompaktere": "kompakt",
    "kompakterem": "kompakt",
    "kompakteren": "kompakt",
    "kompakterer": "kompakt",
    "kompakteres": "kompakt",
    "kompaktes": "kompakt",
    "kompakteste": "kompakt",
    "kompaktestem": "kompakt",
    "kompaktesten": "kompakt",
    "kompaktester": "kompakt",
    "kompaktestes": "kompakt",
    "kompariere": "komparieren",
    "komparierend": "komparieren",
    "komparierende": "komparierend",
    "komparierendem": "komparierend",
    "komparierenden": "komparierend",
    "komparierender": "komparierend",
    "komparierendere": "komparierend",
    "komparierenderem": "komparierend",
    "komparierenderen": "komparierend",
    "komparierenderer": "komparierend",
    "komparierenderes": "komparierend",
    "komparierendes": "komparierend",
    "komparierendste": "komparierend",
    "komparierendstem": "komparierend",
    "komparierendsten": "komparierend",
    "komparierendster": "komparierend",
    "komparierendstes": "komparierend",
    "komparierest": "komparieren",
    "komparieret": "komparieren",
    "komparierst": "komparieren",
    "kompariert": "komparieren",
    "komparierte": "komparieren",
    "kompariertem": "kompariert",
    "komparierten": "komparieren",
    "komparierter": "kompariert",
    "kompariertere": "kompariert",
    "komparierterem": "kompariert",
    "komparierteren": "kompariert",
    "komparierterer": "kompariert",
    "komparierteres": "kompariert",
    "kompariertes": "kompariert",
    "kompariertest": "komparieren",
    "komparierteste": "kompariert",
    "kompariertestem": "kompariert",
    "kompariertesten": "kompariert",
    "kompariertester": "kompariert",
    "kompariertestes": "kompariert",
    "kompariertet": "komparieren",
    "kompatibelste": "kompatibel",
    "kompatibelstem": "kompatibel",
    "kompatibelsten": "kompatibel",
    "kompatibelster": "kompatibel",
    "kompatibelstes": "kompatibel",
    "kompatible": "kompatibel",
    "kompatiblem": "kompatibel",
    "kompatiblen": "kompatibel",
    "kompatibler": "kompatibel",
    "kompatiblere": "kompatibel",
    "kompatiblerem": "kompatibel",
    "kompatibleren": "kompatibel",
    "kompatiblerer": "kompatibel",
    "kompatibleres": "kompatibel",
    "kompatibles": "kompatibel",
    "kompensatorischem": "kompensatorisch",
    "kompensatorischen": "kompensatorisch",
    "kompensatorischer": "kompensatorisch",
    "kompensatorisches": "kompensatorisch",
    "kompensiere": "kompensieren",
    "kompensierend": "kompensieren",
    "kompensierende": "kompensierend",
    "kompensierendem": "kompensierend",
    "kompensierenden": "kompensierend",
    "kompensierender": "kompensierend",
    "kompensierendere": "kompensierend",
    "kompensierenderem": "kompensierend",
    "kompensierenderen": "kompensierend",
    "kompensierenderer": "kompensierend",
    "kompensierenderes": "kompensierend",
    "kompensierendes": "kompensierend",
    "kompensierendste": "kompensierend",
    "kompensierendstem": "kompensierend",
    "kompensierendsten": "kompensierend",
    "kompensierendster": "kompensierend",
    "kompensierendstes": "kompensierend",
    "kompensierest": "kompensieren",
    "kompensieret": "kompensieren",
    "kompensierst": "kompensieren",
    "kompensiert": "kompensieren",
    "kompensierte": "kompensieren",
    "kompensiertem": "kompensiert",
    "kompensierten": "kompensieren",
    "kompensierter": "kompensiert",
    "kompensiertere": "kompensiert",
    "kompensierterem": "kompensiert",
    "kompensierteren": "kompensiert",
    "kompensierterer": "kompensiert",
    "kompensierteres": "kompensiert",
    "kompensiertes": "kompensiert",
    "kompensiertest": "kompensieren",
    "kompensierteste": "kompensiert",
    "kompensiertestem": "kompensiert",
    "kompensiertesten": "kompensiert",
    "kompensiertester": "kompensiert",
    "kompensiertestes": "kompensiert",
    "kompensiertet": "kompensieren",
    "kompetente": "kompetent",
    "kompetentem": "kompetent",
    "kompetenten": "kompetent",
    "kompetenter": "kompetent",
    "kompetentere": "kompetent",
    "kompetenterem": "kompetent",
    "kompetenteren": "kompetent",
    "kompetenterer": "kompetent",
    "kompetenteres": "kompetent",
    "kompetentes": "kompetent",
    "kompetenteste": "kompetent",
    "kompetentestem": "kompetent",
    "kompetentesten": "kompetent",
    "kompetentester": "kompetent",
    "kompetentestes": "kompetent",
    "kompetitivem": "kompetitiv",
    "kompetitiven": "kompetitiv",
    "kompetitiver": "kompetitiv",
    "kompetitives": "kompetitiv",
    "kompiliere": "kompilieren",
    "kompilierend": "kompilieren",
    "kompilierende": "kompilierend",
    "kompilierendem": "kompilierend",
    "kompilierenden": "kompilierend",
    "kompilierender": "kompilierend",
    "kompilierendes": "kompilierend",
    "kompilierest": "kompilieren",
    "kompilieret": "kompilieren",
    "kompilierst": "kompilieren",
    "kompiliert": "kompilieren",
    "kompilierte": "kompilieren",
    "kompiliertem": "kompiliert",
    "kompilierten": "kompilieren",
    "kompilierter": "kompiliert",
    "kompiliertes": "kompiliert",
    "kompiliertest": "kompilieren",
    "kompiliertet": "kompilieren",
    "komplanare": "komplanar",
    "komplanarem": "komplanar",
    "komplanaren": "komplanar",
    "komplanarer": "komplanar",
    "komplanares": "komplanar",
    "komplementiere": "komplementieren",
    "komplementierend": "komplementieren",
    "komplementierende": "komplementierend",
    "komplementierendem": "komplementierend",
    "komplementierenden": "komplementierend",
    "komplementierender": "komplementierend",
    "komplementierendes": "komplementierend",
    "komplementierest": "komplementieren",
    "komplementieret": "komplementieren",
    "komplementierst": "komplementieren",
    "komplementiert": "komplementieren",
    "komplementierte": "komplementieren",
    "komplementiertem": "komplementiert",
    "komplementierten": "komplementieren",
    "komplementierter": "komplementiert",
    "komplementiertere": "komplementiert",
    "komplementierterem": "komplementiert",
    "komplementierteren": "komplementiert",
    "komplementierterer": "komplementiert",
    "komplementierteres": "komplementiert",
    "komplementiertes": "komplementiert",
    "komplementiertest": "komplementieren",
    "komplementierteste": "komplementiert",
    "komplementiertestem": "komplementiert",
    "komplementiertesten": "komplementiert",
    "komplementiertester": "komplementiert",
    "komplementiertestes": "komplementiert",
    "komplementiertet": "komplementieren",
    "komplementäre": "komplementär",
    "komplementärem": "komplementär",
    "komplementären": "komplementär",
    "komplementärer": "komplementär",
    "komplementäres": "komplementär",
    "komplettem": "komplett",
    "kompletten": "komplett",
    "kompletter": "komplett",
    "komplettere": "komplett",
    "kompletterem": "komplett",
    "kompletteren": "komplett",
    "kompletterer": "komplett",
    "kompletteres": "komplett",
    "komplettes": "komplett",
    "kompletteste": "komplett",
    "komplettestem": "komplett",
    "komplettesten": "komplett",
    "komplettester": "komplett",
    "komplettestes": "komplett",
    "komplettiere": "komplettieren",
    "komplettierend": "komplettieren",
    "komplettierende": "komplettierend",
    "komplettierendem": "komplettierend",
    "komplettierenden": "komplettierend",
    "komplettierender": "komplettierend",
    "komplettierendere": "komplettierend",
    "komplettierenderem": "komplettierend",
    "komplettierenderen": "komplettierend",
    "komplettierenderer": "komplettierend",
    "komplettierenderes": "komplettierend",
    "komplettierendes": "komplettierend",
    "komplettierendste": "komplettierend",
    "komplettierendstem": "komplettierend",
    "komplettierendsten": "komplettierend",
    "komplettierendster": "komplettierend",
    "komplettierendstes": "komplettierend",
    "komplettierest": "komplettieren",
    "komplettieret": "komplettieren",
    "komplettierst": "komplettieren",
    "komplettiert": "komplettieren",
    "komplettierte": "komplettieren",
    "komplettiertem": "komplettiert",
    "komplettierten": "komplettieren",
    "komplettierter": "komplettiert",
    "komplettiertere": "komplettiert",
    "komplettierterem": "komplettiert",
    "komplettierteren": "komplettiert",
    "komplettierterer": "komplettiert",
    "komplettierteres": "komplettiert",
    "komplettiertes": "komplettiert",
    "komplettiertest": "komplettieren",
    "komplettierteste": "komplettiert",
    "komplettiertestem": "komplettiert",
    "komplettiertesten": "komplettiert",
    "komplettiertester": "komplettiert",
    "komplettiertestes": "komplettiert",
    "komplettiertet": "komplettieren",
    "komplexe": "komplex",
    "komplexem": "komplex",
    "komplexen": "komplex",
    "komplexer": "komplex",
    "komplexere": "komplex",
    "komplexerem": "komplex",
    "komplexeren": "komplex",
    "komplexerer": "komplex",
    "komplexeres": "komplex",
    "komplexes": "komplex",
    "komplexestem": "komplex",
    "komplexesten": "komplex",
    "komplexester": "komplex",
    "komplexestes": "komplex",
    "komplimentiere": "komplimentieren",
    "komplimentierend": "komplimentieren",
    "komplimentierende": "komplimentierend",
    "komplimentierendem": "komplimentierend",
    "komplimentierenden": "komplimentierend",
    "komplimentierender": "komplimentierend",
    "komplimentierendes": "komplimentierend",
    "komplimentierest": "komplimentieren",
    "komplimentieret": "komplimentieren",
    "komplimentierst": "komplimentieren",
    "komplimentiert": "komplimentieren",
    "komplimentierte": "komplimentieren",
    "komplimentiertem": "komplimentiert",
    "komplimentierten": "komplimentieren",
    "komplimentierter": "komplimentiert",
    "komplimentiertes": "komplimentiert",
    "komplimentiertest": "komplimentieren",
    "komplimentiertet": "komplimentieren",
    "kompliziere": "komplizieren",
    "komplizierend": "komplizieren",
    "komplizierende": "komplizierend",
    "komplizierendem": "komplizierend",
    "komplizierenden": "komplizierend",
    "komplizierender": "komplizierend",
    "komplizierendere": "komplizierend",
    "komplizierenderem": "komplizierend",
    "komplizierenderen": "komplizierend",
    "komplizierenderer": "komplizierend",
    "komplizierenderes": "komplizierend",
    "komplizierendes": "komplizierend",
    "komplizierendste": "komplizierend",
    "komplizierendstem": "komplizierend",
    "komplizierendsten": "komplizierend",
    "komplizierendster": "komplizierend",
    "komplizierendstes": "komplizierend",
    "komplizierest": "komplizieren",
    "komplizieret": "komplizieren",
    "komplizierst": "komplizieren",
    "kompliziert": "komplizieren",
    "komplizierte": "komplizieren",
    "kompliziertem": "kompliziert",
    "komplizierten": "komplizieren",
    "komplizierter": "kompliziert",
    "kompliziertere": "kompliziert",
    "komplizierterem": "kompliziert",
    "komplizierteren": "kompliziert",
    "komplizierterer": "kompliziert",
    "komplizierteres": "kompliziert",
    "kompliziertes": "kompliziert",
    "kompliziertest": "komplizieren",
    "komplizierteste": "kompliziert",
    "kompliziertestem": "kompliziert",
    "kompliziertesten": "kompliziert",
    "kompliziertester": "kompliziert",
    "kompliziertestes": "kompliziert",
    "kompliziertet": "komplizieren",
    "komplottiere": "komplottieren",
    "komplottierend": "komplottieren",
    "komplottierende": "komplottierend",
    "komplottierendem": "komplottierend",
    "komplottierenden": "komplottierend",
    "komplottierender": "komplottierend",
    "komplottierendes": "komplottierend",
    "komplottierest": "komplottieren",
    "komplottieret": "komplottieren",
    "komplottierst": "komplottieren",
    "komplottiert": "komplottieren",
    "komplottierte": "komplottieren",
    "komplottiertem": "komplottiert",
    "komplottierten": "komplottieren",
    "komplottierter": "komplottiert",
    "komplottiertes": "komplottiert",
    "komplottiertest": "komplottieren",
    "komplottiertet": "komplottieren",
    "komponiere": "komponieren",
    "komponierend": "komponieren",
    "komponierende": "komponierend",
    "komponierendem": "komponierend",
    "komponierenden": "komponierend",
    "komponierender": "komponierend",
    "komponierendes": "komponierend",
    "komponierest": "komponieren",
    "komponieret": "komponieren",
    "komponierst": "komponieren",
    "komponiert": "komponieren",
    "komponierte": "komponieren",
    "komponiertem": "komponiert",
    "komponierten": "komponieren",
    "komponierter": "komponiert",
    "komponiertes": "komponiert",
    "komponiertest": "komponieren",
    "komponiertet": "komponieren",
    "kompostiere": "kompostieren",
    "kompostierend": "kompostieren",
    "kompostierende": "kompostierend",
    "kompostierendem": "kompostierend",
    "kompostierenden": "kompostierend",
    "kompostierender": "kompostierend",
    "kompostierendes": "kompostierend",
    "kompostierest": "kompostieren",
    "kompostieret": "kompostieren",
    "kompostierst": "kompostieren",
    "kompostiert": "kompostieren",
    "kompostierte": "kompostieren",
    "kompostiertem": "kompostiert",
    "kompostierten": "kompostieren",
    "kompostierter": "kompostiert",
    "kompostiertes": "kompostiert",
    "kompostiertest": "kompostieren",
    "kompostiertet": "kompostieren",
    "komprimiere": "komprimieren",
    "komprimierend": "komprimieren",
    "komprimierende": "komprimierend",
    "komprimierendem": "komprimierend",
    "komprimierenden": "komprimierend",
    "komprimierender": "komprimierend",
    "komprimierendere": "komprimierend",
    "komprimierenderem": "komprimierend",
    "komprimierenderen": "komprimierend",
    "komprimierenderer": "komprimierend",
    "komprimierenderes": "komprimierend",
    "komprimierendes": "komprimierend",
    "komprimierendste": "komprimierend",
    "komprimierendstem": "komprimierend",
    "komprimierendsten": "komprimierend",
    "komprimierendster": "komprimierend",
    "komprimierendstes": "komprimierend",
    "komprimierest": "komprimieren",
    "komprimieret": "komprimieren",
    "komprimierst": "komprimieren",
    "komprimiert": "komprimieren",
    "komprimierte": "komprimieren",
    "komprimiertem": "komprimiert",
    "komprimierten": "komprimieren",
    "komprimierter": "komprimiert",
    "komprimiertere": "komprimiert",
    "komprimierterem": "komprimiert",
    "komprimierteren": "komprimiert",
    "komprimierterer": "komprimiert",
    "komprimierteres": "komprimiert",
    "komprimiertes": "komprimiert",
    "komprimiertest": "komprimieren",
    "komprimierteste": "komprimiert",
    "komprimiertestem": "komprimiert",
    "komprimiertesten": "komprimiert",
    "komprimiertester": "komprimiert",
    "komprimiertestes": "komprimiert",
    "komprimiertet": "komprimieren",
    "kompromißbereite": "kompromißbereit",
    "kompromißbereitem": "kompromißbereit",
    "kompromißbereiten": "kompromißbereit",
    "kompromißbereiter": "kompromißbereit",
    "kompromißbereitere": "kompromißbereit",
    "kompromißbereiterem": "kompromißbereit",
    "kompromißbereiteren": "kompromißbereit",
    "kompromißbereiterer": "kompromißbereit",
    "kompromißbereiteres": "kompromißbereit",
    "kompromißbereites": "kompromißbereit",
    "kompromißbereiteste": "kompromißbereit",
    "kompromißbereitestem": "kompromißbereit",
    "kompromißbereitesten": "kompromißbereit",
    "kompromißbereitester": "kompromißbereit",
    "kompromißbereitestes": "kompromißbereit",
    "kompromißlosem": "kompromißlos",
    "kompromißlosen": "kompromißlos",
    "kompromißloser": "kompromißlos",
    "kompromißlosere": "kompromißlos",
    "kompromißloserem": "kompromißlos",
    "kompromißloseren": "kompromißlos",
    "kompromißloserer": "kompromißlos",
    "kompromißloseres": "kompromißlos",
    "kompromißloses": "kompromißlos",
    "kompromißloseste": "kompromißlos",
    "kompromißlosestem": "kompromißlos",
    "kompromißlosesten": "kompromißlos",
    "kompromißlosester": "kompromißlos",
    "kompromißlosestes": "kompromißlos",
    "kondensiere": "kondensieren",
    "kondensierend": "kondensieren",
    "kondensierende": "kondensierend",
    "kondensierendem": "kondensierend",
    "kondensierenden": "kondensierend",
    "kondensierender": "kondensierend",
    "kondensierendere": "kondensierend",
    "kondensierenderem": "kondensierend",
    "kondensierenderen": "kondensierend",
    "kondensierenderer": "kondensierend",
    "kondensierenderes": "kondensierend",
    "kondensierendes": "kondensierend",
    "kondensierendste": "kondensierend",
    "kondensierendstem": "kondensierend",
    "kondensierendsten": "kondensierend",
    "kondensierendster": "kondensierend",
    "kondensierendstes": "kondensierend",
    "kondensierest": "kondensieren",
    "kondensieret": "kondensieren",
    "kondensierst": "kondensieren",
    "kondensiert": "kondensieren",
    "kondensierte": "kondensieren",
    "kondensiertem": "kondensiert",
    "kondensierten": "kondensieren",
    "kondensierter": "kondensiert",
    "kondensiertere": "kondensiert",
    "kondensierterem": "kondensiert",
    "kondensierteren": "kondensiert",
    "kondensierterer": "kondensiert",
    "kondensierteres": "kondensiert",
    "kondensiertes": "kondensiert",
    "kondensiertest": "kondensieren",
    "kondensierteste": "kondensiert",
    "kondensiertestem": "kondensiert",
    "kondensiertesten": "kondensiert",
    "kondensiertester": "kondensiert",
    "kondensiertestes": "kondensiert",
    "kondensiertet": "kondensieren",
    "konditionalem": "konditional",
    "konditionalen": "konditional",
    "konditionaler": "konditional",
    "konditionales": "konditional",
    "konditioniere": "konditionieren",
    "konditionierend": "konditionieren",
    "konditionierende": "konditionierend",
    "konditionierendem": "konditionierend",
    "konditionierenden": "konditionierend",
    "konditionierender": "konditionierend",
    "konditionierendere": "konditionierend",
    "konditionierenderem": "konditionierend",
    "konditionierenderen": "konditionierend",
    "konditionierenderer": "konditionierend",
    "konditionierenderes": "konditionierend",
    "konditionierendes": "konditionierend",
    "konditionierendste": "konditionierend",
    "konditionierendstem": "konditionierend",
    "konditionierendsten": "konditionierend",
    "konditionierendster": "konditionierend",
    "konditionierendstes": "konditionierend",
    "konditionierest": "konditionieren",
    "konditionieret": "konditionieren",
    "konditionierst": "konditionieren",
    "konditioniert": "konditionieren",
    "konditionierte": "konditionieren",
    "konditioniertem": "konditioniert",
    "konditionierten": "konditionieren",
    "konditionierter": "konditioniert",
    "konditioniertere": "konditioniert",
    "konditionierterem": "konditioniert",
    "konditionierteren": "konditioniert",
    "konditionierterer": "konditioniert",
    "konditionierteres": "konditioniert",
    "konditioniertes": "konditioniert",
    "konditioniertest": "konditionieren",
    "konditioniertestem": "konditioniert",
    "konditioniertesten": "konditioniert",
    "konditioniertester": "konditioniert",
    "konditioniertestes": "konditioniert",
    "konditioniertet": "konditionieren",
    "konfektioniere": "konfektionieren",
    "konfektionierend": "konfektionieren",
    "konfektionierende": "konfektionierend",
    "konfektionierendem": "konfektionierend",
    "konfektionierenden": "konfektionierend",
    "konfektionierender": "konfektionierend",
    "konfektionierendere": "konfektionierend",
    "konfektionierenderem": "konfektionierend",
    "konfektionierenderen": "konfektionierend",
    "konfektionierenderer": "konfektionierend",
    "konfektionierenderes": "konfektionierend",
    "konfektionierendes": "konfektionierend",
    "konfektionierendste": "konfektionierend",
    "konfektionierendstem": "konfektionierend",
    "konfektionierendsten": "konfektionierend",
    "konfektionierendster": "konfektionierend",
    "konfektionierendstes": "konfektionierend",
    "konfektionierest": "konfektionieren",
    "konfektionieret": "konfektionieren",
    "konfektionierst": "konfektionieren",
    "konfektioniert": "konfektionieren",
    "konfektionierte": "konfektionieren",
    "konfektioniertem": "konfektioniert",
    "konfektionierten": "konfektionieren",
    "konfektionierter": "konfektioniert",
    "konfektioniertere": "konfektioniert",
    "konfektionierterem": "konfektioniert",
    "konfektionierteren": "konfektioniert",
    "konfektionierterer": "konfektioniert",
    "konfektionierteres": "konfektioniert",
    "konfektioniertes": "konfektioniert",
    "konfektioniertest": "konfektionieren",
    "konfektionierteste": "konfektioniert",
    "konfektioniertestem": "konfektioniert",
    "konfektioniertesten": "konfektioniert",
    "konfektioniertester": "konfektioniert",
    "konfektioniertestes": "konfektioniert",
    "konfektioniertet": "konfektionieren",
    "konferiere": "konferieren",
    "konferierend": "konferieren",
    "konferierende": "konferierend",
    "konferierendem": "konferierend",
    "konferierenden": "konferierend",
    "konferierender": "konferierend",
    "konferierendes": "konferierend",
    "konferierest": "konferieren",
    "konferieret": "konferieren",
    "konferierst": "konferieren",
    "konferiert": "konferieren",
    "konferierte": "konferieren",
    "konferiertem": "konferiert",
    "konferierten": "konferieren",
    "konferierter": "konferiert",
    "konferiertes": "konferiert",
    "konferiertest": "konferieren",
    "konferiertet": "konferieren",
    "konfessionslosem": "konfessionslos",
    "konfessionslosen": "konfessionslos",
    "konfessionsloser": "konfessionslos",
    "konfessionsloses": "konfessionslos",
    "konfiguriere": "konfigurieren",
    "konfigurierend": "konfigurieren",
    "konfigurierende": "konfigurierend",
    "konfigurierendem": "konfigurierend",
    "konfigurierenden": "konfigurierend",
    "konfigurierender": "konfigurierend",
    "konfigurierendes": "konfigurierend",
    "konfigurierest": "konfigurieren",
    "konfigurieret": "konfigurieren",
    "konfigurierst": "konfigurieren",
    "konfiguriert": "konfigurieren",
    "konfigurierte": "konfigurieren",
    "konfiguriertem": "konfiguriert",
    "konfigurierten": "konfigurieren",
    "konfigurierter": "konfiguriert",
    "konfiguriertere": "konfiguriert",
    "konfigurierterem": "konfiguriert",
    "konfigurierteren": "konfiguriert",
    "konfigurierterer": "konfiguriert",
    "konfigurierteres": "konfiguriert",
    "konfiguriertes": "konfiguriert",
    "konfiguriertest": "konfigurieren",
    "konfigurierteste": "konfiguriert",
    "konfiguriertestem": "konfiguriert",
    "konfiguriertesten": "konfiguriert",
    "konfiguriertester": "konfiguriert",
    "konfiguriertestes": "konfiguriert",
    "konfiguriertet": "konfigurieren",
    "konfirmiere": "konfirmieren",
    "konfirmierend": "konfirmieren",
    "konfirmierende": "konfirmierend",
    "konfirmierendem": "konfirmierend",
    "konfirmierenden": "konfirmierend",
    "konfirmierender": "konfirmierend",
    "konfirmierendes": "konfirmierend",
    "konfirmierest": "konfirmieren",
    "konfirmieret": "konfirmieren",
    "konfirmierst": "konfirmieren",
    "konfirmiert": "konfirmieren",
    "konfirmierte": "konfirmieren",
    "konfirmiertem": "konfirmiert",
    "konfirmierten": "konfirmieren",
    "konfirmierter": "konfirmiert",
    "konfirmiertere": "konfirmiert",
    "konfirmierterem": "konfirmiert",
    "konfirmierteren": "konfirmiert",
    "konfirmierterer": "konfirmiert",
    "konfirmierteres": "konfirmiert",
    "konfirmiertes": "konfirmiert",
    "konfirmiertest": "konfirmieren",
    "konfirmierteste": "konfirmiert",
    "konfirmiertestem": "konfirmiert",
    "konfirmiertesten": "konfirmiert",
    "konfirmiertester": "konfirmiert",
    "konfirmiertestes": "konfirmiert",
    "konfirmiertet": "konfirmieren",
    "konfisziere": "konfiszieren",
    "konfiszierend": "konfiszieren",
    "konfiszierende": "konfiszierend",
    "konfiszierendem": "konfiszierend",
    "konfiszierenden": "konfiszierend",
    "konfiszierender": "konfiszierend",
    "konfiszierendes": "konfiszierend",
    "konfiszierest": "konfiszieren",
    "konfiszieret": "konfiszieren",
    "konfiszierst": "konfiszieren",
    "konfisziert": "konfiszieren",
    "konfiszierte": "konfiszieren",
    "konfisziertem": "konfisziert",
    "konfiszierten": "konfiszieren",
    "konfiszierter": "konfisziert",
    "konfisziertes": "konfisziert",
    "konfisziertest": "konfiszieren",
    "konfisziertet": "konfiszieren",
    "konfliktfähigem": "konfliktfähig",
    "konfliktfähigen": "konfliktfähig",
    "konfliktfähiger": "konfliktfähig",
    "konfliktfähigere": "konfliktfähig",
    "konfliktfähigerem": "konfliktfähig",
    "konfliktfähigeren": "konfliktfähig",
    "konfliktfähigerer": "konfliktfähig",
    "konfliktfähigeres": "konfliktfähig",
    "konfliktfähiges": "konfliktfähig",
    "konfliktfähigste": "konfliktfähig",
    "konfliktfähigstem": "konfliktfähig",
    "konfliktfähigsten": "konfliktfähig",
    "konfliktfähigster": "konfliktfähig",
    "konfliktfähigstes": "konfliktfähig",
    "konformem": "konform",
    "konformen": "konform",
    "konformer": "konform",
    "konformes": "konform",
    "konfrontiere": "konfrontieren",
    "konfrontierend": "konfrontieren",
    "konfrontierende": "konfrontierend",
    "konfrontierendem": "konfrontierend",
    "konfrontierenden": "konfrontierend",
    "konfrontierender": "konfrontierend",
    "konfrontierendes": "konfrontierend",
    "konfrontierest": "konfrontieren",
    "konfrontieret": "konfrontieren",
    "konfrontierst": "konfrontieren",
    "konfrontiert": "konfrontieren",
    "konfrontierte": "konfrontieren",
    "konfrontiertem": "konfrontiert",
    "konfrontierten": "konfrontieren",
    "konfrontierter": "konfrontiert",
    "konfrontiertes": "konfrontiert",
    "konfrontiertest": "konfrontieren",
    "konfrontiertet": "konfrontieren",
    "konfusem": "konfus",
    "konfusen": "konfus",
    "konfuser": "konfus",
    "konfusere": "konfus",
    "konfuserem": "konfus",
    "konfuseren": "konfus",
    "konfuserer": "konfus",
    "konfuseres": "konfus",
    "konfuses": "konfus",
    "konfuseste": "konfus",
    "konfusestem": "konfus",
    "konfusesten": "konfus",
    "konfusester": "konfus",
    "konfusestes": "konfus",
    "konföderiere": "konföderieren",
    "konföderierend": "konföderieren",
    "konföderierende": "konföderierend",
    "konföderierendem": "konföderierend",
    "konföderierenden": "konföderierend",
    "konföderierender": "konföderierend",
    "konföderierendes": "konföderierend",
    "konföderierest": "konföderieren",
    "konföderieret": "konföderieren",
    "konföderierst": "konföderieren",
    "konföderiert": "konföderieren",
    "konföderierte": "konföderieren",
    "konföderiertem": "konföderiert",
    "konföderierten": "konföderieren",
    "konföderierter": "konföderiert",
    "konföderiertes": "konföderiert",
    "konföderiertest": "konföderieren",
    "konföderiertet": "konföderieren",
    "kongruentem": "kongruent",
    "kongruenten": "kongruent",
    "kongruenter": "kongruent",
    "kongruentes": "kongruent",
    "kongruiere": "kongruieren",
    "kongruierend": "kongruieren",
    "kongruierende": "kongruierend",
    "kongruierendem": "kongruierend",
    "kongruierenden": "kongruierend",
    "kongruierender": "kongruierend",
    "kongruierendes": "kongruierend",
    "kongruierest": "kongruieren",
    "kongruieret": "kongruieren",
    "kongruierst": "kongruieren",
    "kongruiert": "kongruieren",
    "kongruierte": "kongruieren",
    "kongruiertem": "kongruiert",
    "kongruierten": "kongruieren",
    "kongruierter": "kongruiert",
    "kongruiertes": "kongruiert",
    "kongruiertest": "kongruieren",
    "kongruiertet": "kongruieren",
    "konische": "konisch",
    "konischem": "konisch",
    "konischen": "konisch",
    "konischer": "konisch",
    "konischere": "konisch",
    "konischerem": "konisch",
    "konischeren": "konisch",
    "konischerer": "konisch",
    "konischeres": "konisch",
    "konisches": "konisch",
    "konischste": "konisch",
    "konischstem": "konisch",
    "konischsten": "konisch",
    "konischster": "konisch",
    "konischstes": "konisch",
    "konjugiere": "konjugieren",
    "konjugierend": "konjugieren",
    "konjugierende": "konjugierend",
    "konjugierendem": "konjugierend",
    "konjugierenden": "konjugierend",
    "konjugierender": "konjugierend",
    "konjugierendes": "konjugierend",
    "konjugierest": "konjugieren",
    "konjugieret": "konjugieren",
    "konjugierst": "konjugieren",
    "konjugiert": "konjugieren",
    "konjugierte": "konjugieren",
    "konjugiertem": "konjugiert",
    "konjugierten": "konjugieren",
    "konjugierter": "konjugiert",
    "konjugiertes": "konjugiert",
    "konjugiertest": "konjugieren",
    "konjugiertet": "konjugieren",
    "konjunkturelle": "konjunkturell",
    "konjunkturellem": "konjunkturell",
    "konjunkturellen": "konjunkturell",
    "konjunktureller": "konjunkturell",
    "konjunkturelles": "konjunkturell",
    "konkavem": "konkav",
    "konkaven": "konkav",
    "konkaver": "konkav",
    "konkavere": "konkav",
    "konkaverem": "konkav",
    "konkaveren": "konkav",
    "konkaverer": "konkav",
    "konkaveres": "konkav",
    "konkaves": "konkav",
    "konkavste": "konkav",
    "konkavstem": "konkav",
    "konkavsten": "konkav",
    "konkavster": "konkav",
    "konkavstes": "konkav",
    "konkordante": "konkordant",
    "konkordantem": "konkordant",
    "konkordanten": "konkordant",
    "konkordanter": "konkordant",
    "konkordantes": "konkordant",
    "konkretem": "konkret",
    "konkreten": "konkret",
    "konkreter": "konkret",
    "konkretere": "konkret",
    "konkreterem": "konkret",
    "konkreteren": "konkret",
    "konkreterer": "konkret",
    "konkreteres": "konkret",
    "konkretes": "konkret",
    "konkreteste": "konkret",
    "konkretestem": "konkret",
    "konkretesten": "konkret",
    "konkretester": "konkret",
    "konkretestes": "konkret",
    "konkretisiere": "konkretisieren",
    "konkretisierend": "konkretisieren",
    "konkretisierende": "konkretisierend",
    "konkretisierendem": "konkretisierend",
    "konkretisierenden": "konkretisierend",
    "konkretisierender": "konkretisierend",
    "konkretisierendes": "konkretisierend",
    "konkretisierest": "konkretisieren",
    "konkretisieret": "konkretisieren",
    "konkretisierst": "konkretisieren",
    "konkretisiert": "konkretisieren",
    "konkretisierte": "konkretisieren",
    "konkretisiertem": "konkretisiert",
    "konkretisierten": "konkretisieren",
    "konkretisierter": "konkretisiert",
    "konkretisiertes": "konkretisiert",
    "konkretisiertest": "konkretisieren",
    "konkretisiertet": "konkretisieren",
    "konkurrenzfähigem": "konkurrenzfähig",
    "konkurrenzfähigen": "konkurrenzfähig",
    "konkurrenzfähiger": "konkurrenzfähig",
    "konkurrenzfähigere": "konkurrenzfähig",
    "konkurrenzfähigerem": "konkurrenzfähig",
    "konkurrenzfähigeren": "konkurrenzfähig",
    "konkurrenzfähigerer": "konkurrenzfähig",
    "konkurrenzfähigeres": "konkurrenzfähig",
    "konkurrenzfähiges": "konkurrenzfähig",
    "konkurrenzfähigste": "konkurrenzfähig",
    "konkurrenzfähigstem": "konkurrenzfähig",
    "konkurrenzfähigsten": "konkurrenzfähig",
    "konkurrenzfähigster": "konkurrenzfähig",
    "konkurrenzfähigstes": "konkurrenzfähig",
    "konkurrenzlose": "konkurrenzlos",
    "konkurrenzlosem": "konkurrenzlos",
    "konkurrenzlosen": "konkurrenzlos",
    "konkurrenzloser": "konkurrenzlos",
    "konkurrenzlosere": "konkurrenzlos",
    "konkurrenzloserem": "konkurrenzlos",
    "konkurrenzloseren": "konkurrenzlos",
    "konkurrenzloserer": "konkurrenzlos",
    "konkurrenzloseres": "konkurrenzlos",
    "konkurrenzloses": "konkurrenzlos",
    "konkurrenzloseste": "konkurrenzlos",
    "konkurrenzlosestem": "konkurrenzlos",
    "konkurrenzlosesten": "konkurrenzlos",
    "konkurrenzlosester": "konkurrenzlos",
    "konkurrenzlosestes": "konkurrenzlos",
    "konkurriere": "konkurrieren",
    "konkurrierend": "konkurrieren",
    "konkurrierende": "konkurrierend",
    "konkurrierendem": "konkurrierend",
    "konkurrierenden": "konkurrierend",
    "konkurrierender": "konkurrierend",
    "konkurrierendes": "konkurrierend",
    "konkurrierest": "konkurrieren",
    "konkurrieret": "konkurrieren",
    "konkurrierst": "konkurrieren",
    "konkurriert": "konkurrieren",
    "konkurrierte": "konkurrieren",
    "konkurriertem": "konkurriert",
    "konkurrierten": "konkurrieren",
    "konkurrierter": "konkurriert",
    "konkurriertes": "konkurriert",
    "konkurriertest": "konkurrieren",
    "konkurriertet": "konkurrieren",
    "konnte": "können",
    "konnten": "können",
    "konntest": "können",
    "konntet": "können",
    "konsequentem": "konsequent",
    "konsequenten": "konsequent",
    "konsequenter": "konsequent",
    "konsequentere": "konsequent",
    "konsequenterem": "konsequent",
    "konsequenteren": "konsequent",
    "konsequenterer": "konsequent",
    "konsequenteres": "konsequent",
    "konsequentes": "konsequent",
    "konsequenteste": "konsequent",
    "konsequentestem": "konsequent",
    "konsequentesten": "konsequent",
    "konsequentester": "konsequent",
    "konsequentestes": "konsequent",
    "konservativem": "konservativ",
    "konservativen": "konservativ",
    "konservativer": "konservativ",
    "konservativere": "konservativ",
    "konservativerem": "konservativ",
    "konservativeren": "konservativ",
    "konservativerer": "konservativ",
    "konservativeres": "konservativ",
    "konservatives": "konservativ",
    "konservativste": "konservativ",
    "konservativstem": "konservativ",
    "konservativsten": "konservativ",
    "konservativster": "konservativ",
    "konservativstes": "konservativ",
    "konsistentem": "konsistent",
    "konsistenten": "konsistent",
    "konsistenter": "konsistent",
    "konsistentere": "konsistent",
    "konsistenterem": "konsistent",
    "konsistenteren": "konsistent",
    "konsistenterer": "konsistent",
    "konsistenteres": "konsistent",
    "konsistentes": "konsistent",
    "konsistenteste": "konsistent",
    "konsistentestem": "konsistent",
    "konsistentesten": "konsistent",
    "konsistentester": "konsistent",
    "konsistentestes": "konsistent",
    "konsolidiere": "konsolidieren",
    "konsolidierend": "konsolidieren",
    "konsolidierende": "konsolidierend",
    "konsolidierendem": "konsolidierend",
    "konsolidierenden": "konsolidierend",
    "konsolidierender": "konsolidierend",
    "konsolidierendes": "konsolidierend",
    "konsolidierest": "konsolidieren",
    "konsolidieret": "konsolidieren",
    "konsolidierst": "konsolidieren",
    "konsolidiert": "konsolidieren",
    "konsolidierte": "konsolidieren",
    "konsolidiertem": "konsolidiert",
    "konsolidierten": "konsolidieren",
    "konsolidierter": "konsolidiert",
    "konsolidiertere": "konsolidiert",
    "konsolidierterem": "konsolidiert",
    "konsolidierteren": "konsolidiert",
    "konsolidierterer": "konsolidiert",
    "konsolidierteres": "konsolidiert",
    "konsolidiertes": "konsolidiert",
    "konsolidiertest": "konsolidieren",
    "konsolidierteste": "konsolidiert",
    "konsolidiertestem": "konsolidiert",
    "konsolidiertesten": "konsolidiert",
    "konsolidiertester": "konsolidiert",
    "konsolidiertestes": "konsolidiert",
    "konsolidiertet": "konsolidieren",
    "konspirativem": "konspirativ",
    "konspirativen": "konspirativ",
    "konspirativer": "konspirativ",
    "konspirativere": "konspirativ",
    "konspirativerem": "konspirativ",
    "konspirativeren": "konspirativ",
    "konspirativerer": "konspirativ",
    "konspirativeres": "konspirativ",
    "konspiratives": "konspirativ",
    "konspirativste": "konspirativ",
    "konspirativstem": "konspirativ",
    "konspirativsten": "konspirativ",
    "konspirativster": "konspirativ",
    "konspirativstes": "konspirativ",
    "konspiriere": "konspirieren",
    "konspirierend": "konspirieren",
    "konspirierende": "konspirierend",
    "konspirierendem": "konspirierend",
    "konspirierenden": "konspirierend",
    "konspirierender": "konspirierend",
    "konspirierendes": "konspirierend",
    "konspirierest": "konspirieren",
    "konspirieret": "konspirieren",
    "konspirierst": "konspirieren",
    "konspiriert": "konspirieren",
    "konspirierte": "konspirieren",
    "konspiriertem": "konspiriert",
    "konspirierten": "konspirieren",
    "konspirierter": "konspiriert",
    "konspiriertes": "konspiriert",
    "konspiriertest": "konspirieren",
    "konspiriertet": "konspirieren",
    "konstantem": "konstant",
    "konstanten": "konstant",
    "konstanter": "konstant",
    "konstantere": "konstant",
    "konstanterem": "konstant",
    "konstanteren": "konstant",
    "konstanterer": "konstant",
    "konstanteres": "konstant",
    "konstantes": "konstant",
    "konstanteste": "konstant",
    "konstantestem": "konstant",
    "konstantesten": "konstant",
    "konstantester": "konstant",
    "konstantestes": "konstant",
    "konstatiere": "konstatieren",
    "konstatierend": "konstatieren",
    "konstatierende": "konstatierend",
    "konstatierendem": "konstatierend",
    "konstatierenden": "konstatierend",
    "konstatierender": "konstatierend",
    "konstatierendes": "konstatierend",
    "konstatierest": "konstatieren",
    "konstatieret": "konstatieren",
    "konstatierst": "konstatieren",
    "konstatiert": "konstatieren",
    "konstatierte": "konstatieren",
    "konstatiertem": "konstatiert",
    "konstatierten": "konstatieren",
    "konstatierter": "konstatiert",
    "konstatiertes": "konstatiert",
    "konstatiertest": "konstatieren",
    "konstatiertet": "konstatieren",
    "konsternierend": "konsternieren",
    "konsternierende": "konsternierend",
    "konsternierendem": "konsternierend",
    "konsternierenden": "konsternierend",
    "konsternierender": "konsternierend",
    "konsternierendere": "konsternierend",
    "konsternierenderem": "konsternierend",
    "konsternierenderen": "konsternierend",
    "konsternierenderer": "konsternierend",
    "konsternierenderes": "konsternierend",
    "konsternierendes": "konsternierend",
    "konsternierendste": "konsternierend",
    "konsternierendstem": "konsternierend",
    "konsternierendsten": "konsternierend",
    "konsternierendster": "konsternierend",
    "konsternierendstes": "konsternierend",
    "konsternierest": "konsternieren",
    "konsternieret": "konsternieren",
    "konsternierst": "konsternieren",
    "konsterniert": "konsternieren",
    "konsternierte": "konsternieren",
    "konsterniertem": "konsterniert",
    "konsternierten": "konsternieren",
    "konsternierter": "konsterniert",
    "konsterniertere": "konsterniert",
    "konsternierterem": "konsterniert",
    "konsternierteren": "konsterniert",
    "konsternierterer": "konsterniert",
    "konsternierteres": "konsterniert",
    "konsterniertes": "konsterniert",
    "konsterniertest": "konsternieren",
    "konsternierteste": "konsterniert",
    "konsterniertestem": "konsterniert",
    "konsterniertesten": "konsterniert",
    "konsterniertester": "konsterniert",
    "konsterniertestes": "konsterniert",
    "konsterniertet": "konsternieren",
    "konstituiere": "konstituieren",
    "konstituierend": "konstituieren",
    "konstituierende": "konstituierend",
    "konstituierendem": "konstituierend",
    "konstituierenden": "konstituierend",
    "konstituierender": "konstituierend",
    "konstituierendes": "konstituierend",
    "konstituierest": "konstituieren",
    "konstituieret": "konstituieren",
    "konstituierst": "konstituieren",
    "konstituiert": "konstituieren",
    "konstituierte": "konstituieren",
    "konstituiertem": "konstituiert",
    "konstituierten": "konstituieren",
    "konstituierter": "konstituiert",
    "konstituiertes": "konstituiert",
    "konstituiertest": "konstituieren",
    "konstituiertet": "konstituieren",
    "konstitutionelle": "konstitutionell",
    "konstitutionellem": "konstitutionell",
    "konstitutionellen": "konstitutionell",
    "konstitutioneller": "konstitutionell",
    "konstitutionelles": "konstitutionell",
    "konstruiere": "konstruieren",
    "konstruierend": "konstruieren",
    "konstruierende": "konstruierend",
    "konstruierendem": "konstruierend",
    "konstruierenden": "konstruierend",
    "konstruierender": "konstruierend",
    "konstruierendes": "konstruierend",
    "konstruierest": "konstruieren",
    "konstruieret": "konstruieren",
    "konstruierst": "konstruieren",
    "konstruiert": "konstruieren",
    "konstruierte": "konstruieren",
    "konstruiertem": "konstruiert",
    "konstruierten": "konstruieren",
    "konstruierter": "konstruiert",
    "konstruiertes": "konstruiert",
    "konstruiertest": "konstruieren",
    "konstruiertet": "konstruieren",
    "konstruktivem": "konstruktiv",
    "konstruktiven": "konstruktiv",
    "konstruktiver": "konstruktiv",
    "konstruktivere": "konstruktiv",
    "konstruktiverem": "konstruktiv",
    "konstruktiveren": "konstruktiv",
    "konstruktiverer": "konstruktiv",
    "konstruktiveres": "konstruktiv",
    "konstruktives": "konstruktiv",
    "konstruktivste": "konstruktiv",
    "konstruktivstem": "konstruktiv",
    "konstruktivsten": "konstruktiv",
    "konstruktivster": "konstruktiv",
    "konstruktivstes": "konstruktiv",
    "konsultiere": "konsultieren",
    "konsultierend": "konsultieren",
    "konsultierende": "konsultierend",
    "konsultierendem": "konsultierend",
    "konsultierenden": "konsultierend",
    "konsultierender": "konsultierend",
    "konsultierendes": "konsultierend",
    "konsultierest": "konsultieren",
    "konsultieret": "konsultieren",
    "konsultierst": "konsultieren",
    "konsultiert": "konsultieren",
    "konsultierte": "konsultieren",
    "konsultiertem": "konsultiert",
    "konsultierten": "konsultieren",
    "konsultierter": "konsultiert",
    "konsultiertes": "konsultiert",
    "konsultiertest": "konsultieren",
    "konsultiertet": "konsultieren",
    "konsumiere": "konsumieren",
    "konsumierend": "konsumieren",
    "konsumierende": "konsumierend",
    "konsumierendem": "konsumierend",
    "konsumierenden": "konsumierend",
    "konsumierender": "konsumierend",
    "konsumierendere": "konsumierend",
    "konsumierenderem": "konsumierend",
    "konsumierenderen": "konsumierend",
    "konsumierenderer": "konsumierend",
    "konsumierenderes": "konsumierend",
    "konsumierendes": "konsumierend",
    "konsumierendste": "konsumierend",
    "konsumierendstem": "konsumierend",
    "konsumierendsten": "konsumierend",
    "konsumierendster": "konsumierend",
    "konsumierendstes": "konsumierend",
    "konsumierest": "konsumieren",
    "konsumieret": "konsumieren",
    "konsumierst": "konsumieren",
    "konsumiert": "konsumieren",
    "konsumierte": "konsumieren",
    "konsumiertem": "konsumiert",
    "konsumierten": "konsumieren",
    "konsumierter": "konsumiert",
    "konsumiertes": "konsumiert",
    "konsumiertest": "konsumieren",
    "konsumiertet": "konsumieren",
    "kontaktarmem": "kontaktarm",
    "kontaktarmen": "kontaktarm",
    "kontaktarmer": "kontaktarm",
    "kontaktarmes": "kontaktarm",
    "kontaktend": "kontakten",
    "kontaktende": "kontaktend",
    "kontaktendem": "kontaktend",
    "kontaktenden": "kontaktend",
    "kontaktender": "kontaktend",
    "kontaktendes": "kontaktend",
    "kontaktest": "kontakten",
    "kontaktet": "kontakten",
    "kontaktete": "kontakten",
    "kontaktetem": "kontaktet",
    "kontakteten": "kontakten",
    "kontakteter": "kontaktet",
    "kontaktetes": "kontaktet",
    "kontaktetest": "kontakten",
    "kontaktetet": "kontakten",
    "kontaktfreudige": "kontaktfreudig",
    "kontaktfreudigem": "kontaktfreudig",
    "kontaktfreudigen": "kontaktfreudig",
    "kontaktfreudiger": "kontaktfreudig",
    "kontaktfreudigere": "kontaktfreudig",
    "kontaktfreudigerem": "kontaktfreudig",
    "kontaktfreudigeren": "kontaktfreudig",
    "kontaktfreudigerer": "kontaktfreudig",
    "kontaktfreudigeres": "kontaktfreudig",
    "kontaktfreudiges": "kontaktfreudig",
    "kontaktfreudigste": "kontaktfreudig",
    "kontaktfreudigstem": "kontaktfreudig",
    "kontaktfreudigsten": "kontaktfreudig",
    "kontaktfreudigster": "kontaktfreudig",
    "kontaktfreudigstes": "kontaktfreudig",
    "kontaktiere": "kontaktieren",
    "kontaktierend": "kontaktieren",
    "kontaktierende": "kontaktierend",
    "kontaktierendem": "kontaktierend",
    "kontaktierenden": "kontaktierend",
    "kontaktierender": "kontaktierend",
    "kontaktierendes": "kontaktierend",
    "kontaktierest": "kontaktieren",
    "kontaktieret": "kontaktieren",
    "kontaktierst": "kontaktieren",
    "kontaktiert": "kontaktieren",
    "kontaktierte": "kontaktieren",
    "kontaktiertem": "kontaktiert",
    "kontaktierten": "kontaktieren",
    "kontaktierter": "kontaktiert",
    "kontaktiertes": "kontaktiert",
    "kontaktiertest": "kontaktieren",
    "kontaktiertet": "kontaktieren",
    "kontaktscheuem": "kontaktscheu",
    "kontaktscheuen": "kontaktscheu",
    "kontaktscheuer": "kontaktscheu",
    "kontaktscheuere": "kontaktscheu",
    "kontaktscheuerem": "kontaktscheu",
    "kontaktscheueren": "kontaktscheu",
    "kontaktscheuerer": "kontaktscheu",
    "kontaktscheueres": "kontaktscheu",
    "kontaktscheues": "kontaktscheu",
    "kontaktscheuste": "kontaktscheu",
    "kontaktscheustem": "kontaktscheu",
    "kontaktscheusten": "kontaktscheu",
    "kontaktscheuster": "kontaktscheu",
    "kontaktscheustes": "kontaktscheu",
    "kontaktschwache": "kontaktschwach",
    "kontaktschwachem": "kontaktschwach",
    "kontaktschwachen": "kontaktschwach",
    "kontaktschwacher": "kontaktschwach",
    "kontaktschwaches": "kontaktschwach",
    "kontaktschwächer": "kontaktschwach",
    "kontaktschwächere": "kontaktschwach",
    "kontaktschwächerem": "kontaktschwach",
    "kontaktschwächeren": "kontaktschwach",
    "kontaktschwächerer": "kontaktschwach",
    "kontaktschwächeres": "kontaktschwach",
    "kontaktschwächsten": "kontaktschwach",
    "kontaktärmer": "kontaktarm",
    "kontaktärmere": "kontaktarm",
    "kontaktärmerem": "kontaktarm",
    "kontaktärmeren": "kontaktarm",
    "kontaktärmerer": "kontaktarm",
    "kontaktärmeres": "kontaktarm",
    "kontaktärmsten": "kontaktarm",
    "kontaminiere": "kontaminieren",
    "kontaminierend": "kontaminieren",
    "kontaminierende": "kontaminierend",
    "kontaminierendem": "kontaminierend",
    "kontaminierenden": "kontaminierend",
    "kontaminierender": "kontaminierend",
    "kontaminierendes": "kontaminierend",
    "kontaminierest": "kontaminieren",
    "kontaminieret": "kontaminieren",
    "kontaminierst": "kontaminieren",
    "kontaminiert": "kontaminieren",
    "kontaminierte": "kontaminieren",
    "kontaminiertem": "kontaminiert",
    "kontaminierten": "kontaminieren",
    "kontaminierter": "kontaminiert",
    "kontaminiertes": "kontaminiert",
    "kontaminiertest": "kontaminieren",
    "kontaminiertet": "kontaminieren",
    "kontere": "kontern",
    "konternd": "kontern",
    "konternde": "konternd",
    "konterndem": "konternd",
    "konternden": "konternd",
    "konternder": "konternd",
    "konterndere": "konternd",
    "konternderem": "konternd",
    "konternderen": "konternd",
    "konternderer": "konternd",
    "konternderes": "konternd",
    "konterndes": "konternd",
    "konterndste": "konternd",
    "konterndstem": "konternd",
    "konterndsten": "konternd",
    "konterndster": "konternd",
    "konterndstes": "konternd",
    "konterst": "kontern",
    "kontert": "kontern",
    "konterte": "kontern",
    "konterten": "kontern",
    "kontertest": "kontern",
    "kontertet": "kontern",
    "kontinentalem": "kontinental",
    "kontinentalen": "kontinental",
    "kontinentaler": "kontinental",
    "kontinentales": "kontinental",
    "kontinuierlichem": "kontinuierlich",
    "kontinuierlichen": "kontinuierlich",
    "kontinuierlicher": "kontinuierlich",
    "kontinuierlichere": "kontinuierlich",
    "kontinuierlicherem": "kontinuierlich",
    "kontinuierlicheren": "kontinuierlich",
    "kontinuierlicherer": "kontinuierlich",
    "kontinuierlicheres": "kontinuierlich",
    "kontinuierliches": "kontinuierlich",
    "kontinuierlichste": "kontinuierlich",
    "kontinuierlichstem": "kontinuierlich",
    "kontinuierlichsten": "kontinuierlich",
    "kontinuierlichster": "kontinuierlich",
    "kontinuierlichstes": "kontinuierlich",
    "kontradiktorischem": "kontradiktorisch",
    "kontradiktorischen": "kontradiktorisch",
    "kontradiktorischer": "kontradiktorisch",
    "kontradiktorisches": "kontradiktorisch",
    "kontrahiere": "kontrahieren",
    "kontrahierend": "kontrahieren",
    "kontrahierende": "kontrahierend",
    "kontrahierendem": "kontrahierend",
    "kontrahierenden": "kontrahierend",
    "kontrahierender": "kontrahierend",
    "kontrahierendes": "kontrahierend",
    "kontrahierest": "kontrahieren",
    "kontrahieret": "kontrahieren",
    "kontrahierst": "kontrahieren",
    "kontrahiert": "kontrahieren",
    "kontrahierte": "kontrahieren",
    "kontrahiertem": "kontrahiert",
    "kontrahierten": "kontrahieren",
    "kontrahierter": "kontrahiert",
    "kontrahiertes": "kontrahiert",
    "kontrahiertest": "kontrahieren",
    "kontrahiertet": "kontrahieren",
    "kontraproduktivem": "kontraproduktiv",
    "kontraproduktiven": "kontraproduktiv",
    "kontraproduktiver": "kontraproduktiv",
    "kontraproduktivere": "kontraproduktiv",
    "kontraproduktiverem": "kontraproduktiv",
    "kontraproduktiveren": "kontraproduktiv",
    "kontraproduktiverer": "kontraproduktiv",
    "kontraproduktiveres": "kontraproduktiv",
    "kontraproduktives": "kontraproduktiv",
    "kontraproduktivste": "kontraproduktiv",
    "kontraproduktivstem": "kontraproduktiv",
    "kontraproduktivsten": "kontraproduktiv",
    "kontraproduktivster": "kontraproduktiv",
    "kontraproduktivstes": "kontraproduktiv",
    "kontrastierend": "kontrastieren",
    "kontrastierende": "kontrastierend",
    "kontrastierendem": "kontrastierend",
    "kontrastierenden": "kontrastierend",
    "kontrastierender": "kontrastierend",
    "kontrastierendere": "kontrastierend",
    "kontrastierenderem": "kontrastierend",
    "kontrastierenderen": "kontrastierend",
    "kontrastierenderer": "kontrastierend",
    "kontrastierenderes": "kontrastierend",
    "kontrastierendes": "kontrastierend",
    "kontrastierendste": "kontrastierend",
    "kontrastierendstem": "kontrastierend",
    "kontrastierendsten": "kontrastierend",
    "kontrastierendster": "kontrastierend",
    "kontrastierendstes": "kontrastierend",
    "kontrastierest": "kontrastieren",
    "kontrastieret": "kontrastieren",
    "kontrastierst": "kontrastieren",
    "kontrastiert": "kontrastieren",
    "kontrastierte": "kontrastieren",
    "kontrastiertem": "kontrastiert",
    "kontrastierten": "kontrastieren",
    "kontrastierter": "kontrastiert",
    "kontrastiertere": "kontrastiert",
    "kontrastierterem": "kontrastiert",
    "kontrastierteren": "kontrastiert",
    "kontrastierterer": "kontrastiert",
    "kontrastierteres": "kontrastiert",
    "kontrastiertes": "kontrastiert",
    "kontrastiertest": "kontrastieren",
    "kontrastierteste": "kontrastiert",
    "kontrastiertestem": "kontrastiert",
    "kontrastiertesten": "kontrastiert",
    "kontrastiertester": "kontrastiert",
    "kontrastiertestes": "kontrastiert",
    "kontrastiertet": "kontrastieren",
    "kontrastive": "kontrastiv",
    "kontrastivem": "kontrastiv",
    "kontrastiven": "kontrastiv",
    "kontrastiver": "kontrastiv",
    "kontrastivere": "kontrastiv",
    "kontrastiverem": "kontrastiv",
    "kontrastiveren": "kontrastiv",
    "kontrastiverer": "kontrastiv",
    "kontrastiveres": "kontrastiv",
    "kontrastives": "kontrastiv",
    "kontrastivste": "kontrastiv",
    "kontrastivstem": "kontrastiv",
    "kontrastivsten": "kontrastiv",
    "kontrastivster": "kontrastiv",
    "kontrastivstes": "kontrastiv",
    "kontrastreiche": "kontrastreich",
    "kontrastreichem": "kontrastreich",
    "kontrastreichen": "kontrastreich",
    "kontrastreicher": "kontrastreich",
    "kontrastreichere": "kontrastreich",
    "kontrastreicherem": "kontrastreich",
    "kontrastreicheren": "kontrastreich",
    "kontrastreicherer": "kontrastreich",
    "kontrastreicheres": "kontrastreich",
    "kontrastreiches": "kontrastreich",
    "kontrastreichste": "kontrastreich",
    "kontrastreichstem": "kontrastreich",
    "kontrastreichsten": "kontrastreich",
    "kontrastreichster": "kontrastreich",
    "kontrastreichstes": "kontrastreich",
    "kontrolliere": "kontrollieren",
    "kontrollierend": "kontrollieren",
    "kontrollierende": "kontrollierend",
    "kontrollierendem": "kontrollierend",
    "kontrollierenden": "kontrollierend",
    "kontrollierender": "kontrollierend",
    "kontrollierendes": "kontrollierend",
    "kontrollierest": "kontrollieren",
    "kontrollieret": "kontrollieren",
    "kontrollierst": "kontrollieren",
    "kontrolliert": "kontrollieren",
    "kontrollierte": "kontrollieren",
    "kontrolliertem": "kontrolliert",
    "kontrollierten": "kontrollieren",
    "kontrollierter": "kontrolliert",
    "kontrolliertere": "kontrolliert",
    "kontrollierterem": "kontrolliert",
    "kontrollierteren": "kontrolliert",
    "kontrollierterer": "kontrolliert",
    "kontrollierteres": "kontrolliert",
    "kontrolliertes": "kontrolliert",
    "kontrolliertest": "kontrollieren",
    "kontrollierteste": "kontrolliert",
    "kontrolliertestem": "kontrolliert",
    "kontrolliertesten": "kontrolliert",
    "kontrolliertester": "kontrolliert",
    "kontrolliertestes": "kontrolliert",
    "kontrolliertet": "kontrollieren",
    "kontroversem": "kontrovers",
    "kontroversen": "kontrovers",
    "kontroverser": "kontrovers",
    "kontroversere": "kontrovers",
    "kontroverserem": "kontrovers",
    "kontroverseren": "kontrovers",
    "kontroverserer": "kontrovers",
    "kontroverseres": "kontrovers",
    "kontroverses": "kontrovers",
    "kontroverseste": "kontrovers",
    "kontroversestem": "kontrovers",
    "kontroversesten": "kontrovers",
    "kontroversester": "kontrovers",
    "kontroversestes": "kontrovers",
    "konträre": "konträr",
    "konträrem": "konträr",
    "konträren": "konträr",
    "konträrer": "konträr",
    "konträrere": "konträr",
    "konträrerem": "konträr",
    "konträreren": "konträr",
    "konträrerer": "konträr",
    "konträreres": "konträr",
    "konträres": "konträr",
    "konträrste": "konträr",
    "konträrstem": "konträr",
    "konträrsten": "konträr",
    "konträrster": "konträr",
    "konträrstes": "konträr",
    "konventionellem": "konventionell",
    "konventionellen": "konventionell",
    "konventioneller": "konventionell",
    "konventionellere": "konventionell",
    "konventionellerem": "konventionell",
    "konventionelleren": "konventionell",
    "konventionellerer": "konventionell",
    "konventionelleres": "konventionell",
    "konventionelles": "konventionell",
    "konventionellste": "konventionell",
    "konventionellstem": "konventionell",
    "konventionellsten": "konventionell",
    "konventionellster": "konventionell",
    "konventionellstes": "konventionell",
    "konvertiere": "konvertieren",
    "konvertierend": "konvertieren",
    "konvertierende": "konvertierend",
    "konvertierendem": "konvertierend",
    "konvertierenden": "konvertierend",
    "konvertierender": "konvertierend",
    "konvertierendes": "konvertierend",
    "konvertierest": "konvertieren",
    "konvertieret": "konvertieren",
    "konvertierst": "konvertieren",
    "konvertiert": "konvertieren",
    "konvertierte": "konvertieren",
    "konvertiertem": "konvertiert",
    "konvertierten": "konvertieren",
    "konvertierter": "konvertiert",
    "konvertiertes": "konvertiert",
    "konvertiertest": "konvertieren",
    "konvertiertet": "konvertieren",
    "konzentrierend": "konzentrieren",
    "konzentrierende": "konzentrierend",
    "konzentrierendem": "konzentrierend",
    "konzentrierenden": "konzentrierend",
    "konzentrierender": "konzentrierend",
    "konzentrierendere": "konzentrierend",
    "konzentrierenderem": "konzentrierend",
    "konzentrierenderen": "konzentrierend",
    "konzentrierenderer": "konzentrierend",
    "konzentrierenderes": "konzentrierend",
    "konzentrierendes": "konzentrierend",
    "konzentrierendste": "konzentrierend",
    "konzentrierendstem": "konzentrierend",
    "konzentrierendsten": "konzentrierend",
    "konzentrierendster": "konzentrierend",
    "konzentrierendstes": "konzentrierend",
    "konzentrierest": "konzentrieren",
    "konzentrieret": "konzentrieren",
    "konzentrierst": "konzentrieren",
    "konzentriert": "konzentrieren",
    "konzentrierte": "konzentrieren",
    "konzentriertem": "konzentriert",
    "konzentrierten": "konzentrieren",
    "konzentrierter": "konzentriert",
    "konzentriertere": "konzentriert",
    "konzentrierterem": "konzentriert",
    "konzentrierteren": "konzentriert",
    "konzentrierterer": "konzentriert",
    "konzentrierteres": "konzentriert",
    "konzentriertes": "konzentriert",
    "konzentriertest": "konzentrieren",
    "konzentrierteste": "konzentriert",
    "konzentriertestem": "konzentriert",
    "konzentriertesten": "konzentriert",
    "konzentriertester": "konzentriert",
    "konzentriertestes": "konzentriert",
    "konzentriertet": "konzentrieren",
    "konzeptionellem": "konzeptionell",
    "konzeptionellen": "konzeptionell",
    "konzeptioneller": "konzeptionell",
    "konzeptionelles": "konzeptionell",
    "konzertiertem": "konzertiert",
    "konzertierten": "konzertiert",
    "konzertierter": "konzertiert",
    "konzertiertes": "konzertiert",
    "konzertreifem": "konzertreif",
    "konzertreifen": "konzertreif",
    "konzertreifer": "konzertreif",
    "konzertreifes": "konzertreif",
    "konzessivem": "konzessiv",
    "konzessiven": "konzessiv",
    "konzessiver": "konzessiv",
    "konzessives": "konzessiv",
    "konzipiere": "konzipieren",
    "konzipierend": "konzipieren",
    "konzipierende": "konzipierend",
    "konzipierendem": "konzipierend",
    "konzipierenden": "konzipierend",
    "konzipierender": "konzipierend",
    "konzipierendes": "konzipierend",
    "konzipierest": "konzipieren",
    "konzipieret": "konzipieren",
    "konzipierst": "konzipieren",
    "konzipiert": "konzipieren",
    "konzipierte": "konzipieren",
    "konzipiertem": "konzipiert",
    "konzipierten": "konzipieren",
    "konzipierter": "konzipiert",
    "konzipiertes": "konzipiert",
    "konzipiertest": "konzipieren",
    "konzipiertet": "konzipieren",
    "kooperativem": "kooperativ",
    "kooperativen": "kooperativ",
    "kooperativer": "kooperativ",
    "kooperatives": "kooperativ",
    "kooperiere": "kooperieren",
    "kooperierend": "kooperieren",
    "kooperierende": "kooperierend",
    "kooperierendem": "kooperierend",
    "kooperierenden": "kooperierend",
    "kooperierender": "kooperierend",
    "kooperierendere": "kooperierend",
    "kooperierenderem": "kooperierend",
    "kooperierenderen": "kooperierend",
    "kooperierenderer": "kooperierend",
    "kooperierenderes": "kooperierend",
    "kooperierendes": "kooperierend",
    "kooperierendste": "kooperierend",
    "kooperierendstem": "kooperierend",
    "kooperierendsten": "kooperierend",
    "kooperierendster": "kooperierend",
    "kooperierendstes": "kooperierend",
    "kooperierest": "kooperieren",
    "kooperieret": "kooperieren",
    "kooperierst": "kooperieren",
    "kooperiert": "kooperieren",
    "kooperierte": "kooperieren",
    "kooperiertem": "kooperiert",
    "kooperierten": "kooperieren",
    "kooperierter": "kooperiert",
    "kooperiertere": "kooperiert",
    "kooperierterem": "kooperiert",
    "kooperierteren": "kooperiert",
    "kooperierterer": "kooperiert",
    "kooperierteres": "kooperiert",
    "kooperiertes": "kooperiert",
    "kooperiertest": "kooperieren",
    "kooperierteste": "kooperiert",
    "kooperiertestem": "kooperiert",
    "kooperiertesten": "kooperiert",
    "kooperiertester": "kooperiert",
    "kooperiertestes": "kooperiert",
    "kooperiertet": "kooperieren",
    "koordiniere": "koordinieren",
    "koordinierend": "koordinieren",
    "koordinierende": "koordinierend",
    "koordinierendem": "koordinierend",
    "koordinierenden": "koordinierend",
    "koordinierender": "koordinierend",
    "koordinierendes": "koordinierend",
    "koordinierest": "koordinieren",
    "koordinieret": "koordinieren",
    "koordinierst": "koordinieren",
    "koordiniert": "koordinieren",
    "koordinierte": "koordinieren",
    "koordiniertem": "koordiniert",
    "koordinierten": "koordinieren",
    "koordinierter": "koordiniert",
    "koordiniertes": "koordiniert",
    "koordiniertest": "koordinieren",
    "koordiniertet": "koordinieren",
    "kopfgesteuerte": "kopfgesteuert",
    "kopfgesteuertem": "kopfgesteuert",
    "kopfgesteuerten": "kopfgesteuert",
    "kopfgesteuerter": "kopfgesteuert",
    "kopfgesteuertes": "kopfgesteuert",
    "kopflastige": "kopflastig",
    "kopflastigem": "kopflastig",
    "kopflastigen": "kopflastig",
    "kopflastiger": "kopflastig",
    "kopflastigere": "kopflastig",
    "kopflastigerem": "kopflastig",
    "kopflastigeren": "kopflastig",
    "kopflastigerer": "kopflastig",
    "kopflastigeres": "kopflastig",
    "kopflastiges": "kopflastig",
    "kopflastigste": "kopflastig",
    "kopflastigstem": "kopflastig",
    "kopflastigsten": "kopflastig",
    "kopflastigster": "kopflastig",
    "kopflastigstes": "kopflastig",
    "kopflose": "kopflos",
    "kopflosem": "kopflos",
    "kopflosen": "kopflos",
    "kopfloser": "kopflos",
    "kopflosere": "kopflos",
    "kopfloserem": "kopflos",
    "kopfloseren": "kopflos",
    "kopfloserer": "kopflos",
    "kopfloseres": "kopflos",
    "kopfloses": "kopflos",
    "kopfloseste": "kopflos",
    "kopflosestem": "kopflos",
    "kopflosesten": "kopflos",
    "kopflosester": "kopflos",
    "kopflosestes": "kopflos",
    "kopfschüttelndem": "kopfschüttelnd",
    "kopfschüttelnden": "kopfschüttelnd",
    "kopfschüttelnder": "kopfschüttelnd",
    "kopfschüttelndes": "kopfschüttelnd",
    "kopiere": "kopieren",
    "kopierend": "kopieren",
    "kopierende": "kopierend",
    "kopierendem": "kopierend",
    "kopierenden": "kopierend",
    "kopierender": "kopierend",
    "kopierendes": "kopierend",
    "kopierest": "kopieren",
    "kopieret": "kopieren",
    "kopierst": "kopieren",
    "kopiert": "kopieren",
    "kopierte": "kopieren",
    "kopiertem": "kopiert",
    "kopierten": "kopieren",
    "kopierter": "kopiert",
    "kopiertes": "kopiert",
    "kopiertest": "kopieren",
    "kopiertet": "kopieren",
    "koppele": "koppeln",
    "koppelnd": "koppeln",
    "koppelnde": "koppelnd",
    "koppelndem": "koppelnd",
    "koppelnden": "koppelnd",
    "koppelnder": "koppelnd",
    "koppelndes": "koppelnd",
    "koppelst": "koppeln",
    "koppelt": "koppeln",
    "koppelte": "koppeln",
    "koppelten": "koppeln",
    "koppeltest": "koppeln",
    "koppeltet": "koppeln",
    "kopple": "koppeln",
    "korkend": "korken",
    "korkende": "korkend",
    "korkendem": "korkend",
    "korkenden": "korkend",
    "korkender": "korkend",
    "korkendes": "korkend",
    "korkest": "korken",
    "korket": "korken",
    "korkige": "korkig",
    "korkigem": "korkig",
    "korkigen": "korkig",
    "korkiger": "korkig",
    "korkigere": "korkig",
    "korkigerem": "korkig",
    "korkigeren": "korkig",
    "korkigerer": "korkig",
    "korkigeres": "korkig",
    "korkiges": "korkig",
    "korkigste": "korkig",
    "korkigstem": "korkig",
    "korkigsten": "korkig",
    "korkigster": "korkig",
    "korkigstes": "korkig",
    "korkst": "korken",
    "korkt": "korken",
    "korkte": "korken",
    "korkten": "korken",
    "korktest": "korken",
    "korktet": "korken",
    "korpulentem": "korpulent",
    "korpulenten": "korpulent",
    "korpulenter": "korpulent",
    "korpulentere": "korpulent",
    "korpulenterem": "korpulent",
    "korpulenteren": "korpulent",
    "korpulenterer": "korpulent",
    "korpulenteres": "korpulent",
    "korpulentes": "korpulent",
    "korpulenteste": "korpulent",
    "korpulentestem": "korpulent",
    "korpulentesten": "korpulent",
    "korpulentester": "korpulent",
    "korpulentestes": "korpulent",
    "korrekte": "korrekt",
    "korrektem": "korrekt",
    "korrekten": "korrekt",
    "korrekter": "korrekt",
    "korrektere": "korrekt",
    "korrekterem": "korrekt",
    "korrekteren": "korrekt",
    "korrekterer": "korrekt",
    "korrekteres": "korrekt",
    "korrektes": "korrekt",
    "korrekteste": "korrekt",
    "korrektestem": "korrekt",
    "korrektesten": "korrekt",
    "korrektester": "korrekt",
    "korrektestes": "korrekt",
    "korreliere": "korrelieren",
    "korrelierend": "korrelieren",
    "korrelierende": "korrelierend",
    "korrelierendem": "korrelierend",
    "korrelierenden": "korrelierend",
    "korrelierender": "korrelierend",
    "korrelierendere": "korrelierend",
    "korrelierenderem": "korrelierend",
    "korrelierenderen": "korrelierend",
    "korrelierenderer": "korrelierend",
    "korrelierenderes": "korrelierend",
    "korrelierendes": "korrelierend",
    "korrelierendste": "korrelierend",
    "korrelierendstem": "korrelierend",
    "korrelierendsten": "korrelierend",
    "korrelierendster": "korrelierend",
    "korrelierendstes": "korrelierend",
    "korrelierest": "korrelieren",
    "korrelieret": "korrelieren",
    "korrelierst": "korrelieren",
    "korreliert": "korrelieren",
    "korrelierte": "korrelieren",
    "korreliertem": "korreliert",
    "korrelierten": "korrelieren",
    "korrelierter": "korreliert",
    "korreliertere": "korreliert",
    "korrelierterem": "korreliert",
    "korrelierteren": "korreliert",
    "korrelierterer": "korreliert",
    "korrelierteres": "korreliert",
    "korreliertes": "korreliert",
    "korreliertest": "korrelieren",
    "korrelierteste": "korreliert",
    "korreliertestem": "korreliert",
    "korreliertesten": "korreliert",
    "korreliertester": "korreliert",
    "korreliertestes": "korreliert",
    "korreliertet": "korrelieren",
    "korrigiere": "korrigieren",
    "korrigierend": "korrigieren",
    "korrigierende": "korrigierend",
    "korrigierendem": "korrigierend",
    "korrigierenden": "korrigierend",
    "korrigierender": "korrigierend",
    "korrigierendes": "korrigierend",
    "korrigierest": "korrigieren",
    "korrigieret": "korrigieren",
    "korrigierst": "korrigieren",
    "korrigiert": "korrigieren",
    "korrigierte": "korrigieren",
    "korrigiertem": "korrigiert",
    "korrigierten": "korrigieren",
    "korrigierter": "korrigiert",
    "korrigiertes": "korrigiert",
    "korrigiertest": "korrigieren",
    "korrigiertet": "korrigieren",
    "korrumpiere": "korrumpieren",
    "korrumpierend": "korrumpieren",
    "korrumpierende": "korrumpierend",
    "korrumpierendem": "korrumpierend",
    "korrumpierenden": "korrumpierend",
    "korrumpierender": "korrumpierend",
    "korrumpierendere": "korrumpierend",
    "korrumpierenderem": "korrumpierend",
    "korrumpierenderen": "korrumpierend",
    "korrumpierenderer": "korrumpierend",
    "korrumpierenderes": "korrumpierend",
    "korrumpierendes": "korrumpierend",
    "korrumpierendste": "korrumpierend",
    "korrumpierendstem": "korrumpierend",
    "korrumpierendsten": "korrumpierend",
    "korrumpierendster": "korrumpierend",
    "korrumpierendstes": "korrumpierend",
    "korrumpierest": "korrumpieren",
    "korrumpieret": "korrumpieren",
    "korrumpierst": "korrumpieren",
    "korrumpiert": "korrumpieren",
    "korrumpierte": "korrumpieren",
    "korrumpiertem": "korrumpiert",
    "korrumpierten": "korrumpieren",
    "korrumpierter": "korrumpiert",
    "korrumpiertere": "korrumpiert",
    "korrumpierterem": "korrumpiert",
    "korrumpierteren": "korrumpiert",
    "korrumpierterer": "korrumpiert",
    "korrumpierteres": "korrumpiert",
    "korrumpiertes": "korrumpiert",
    "korrumpiertest": "korrumpieren",
    "korrumpierteste": "korrumpiert",
    "korrumpiertestem": "korrumpiert",
    "korrumpiertesten": "korrumpiert",
    "korrumpiertester": "korrumpiert",
    "korrumpiertestes": "korrumpiert",
    "korrumpiertet": "korrumpieren",
    "korrupte": "korrupt",
    "korruptem": "korrupt",
    "korrupten": "korrupt",
    "korrupter": "korrupt",
    "korruptere": "korrupt",
    "korrupterem": "korrupt",
    "korrupteren": "korrupt",
    "korrupterer": "korrupt",
    "korrupteres": "korrupt",
    "korruptes": "korrupt",
    "korrupteste": "korrupt",
    "korruptestem": "korrupt",
    "korruptesten": "korrupt",
    "korruptester": "korrupt",
    "korruptestes": "korrupt",
    "korsischem": "korsisch",
    "korsischen": "korsisch",
    "korsischer": "korsisch",
    "korsisches": "korsisch",
    "koscherem": "koscher",
    "koscheren": "koscher",
    "koscherer": "koscher",
    "koscherere": "koscher",
    "koschererem": "koscher",
    "koschereren": "koscher",
    "koschererer": "koscher",
    "koschereres": "koscher",
    "koscheres": "koscher",
    "koscherste": "koscher",
    "koscherstem": "koscher",
    "koschersten": "koscher",
    "koscherster": "koscher",
    "koscherstes": "koscher",
    "kosmetischem": "kosmetisch",
    "kosmetischen": "kosmetisch",
    "kosmetischer": "kosmetisch",
    "kosmetisches": "kosmetisch",
    "kosmische": "kosmisch",
    "kosmischem": "kosmisch",
    "kosmischen": "kosmisch",
    "kosmischer": "kosmisch",
    "kosmisches": "kosmisch",
    "kosmobiologische": "kosmobiologisch",
    "kosmobiologischem": "kosmobiologisch",
    "kosmobiologischen": "kosmobiologisch",
    "kosmobiologischer": "kosmobiologisch",
    "kosmobiologisches": "kosmobiologisch",
    "kosmographische": "kosmographisch",
    "kosmographischem": "kosmographisch",
    "kosmographischen": "kosmographisch",
    "kosmographischer": "kosmographisch",
    "kosmographisches": "kosmographisch",
    "kosmologische": "kosmologisch",
    "kosmologischem": "kosmologisch",
    "kosmologischen": "kosmologisch",
    "kosmologischer": "kosmologisch",
    "kosmologisches": "kosmologisch",
    "kosmopolitischem": "kosmopolitisch",
    "kosmopolitischen": "kosmopolitisch",
    "kosmopolitischer": "kosmopolitisch",
    "kosmopolitisches": "kosmopolitisch",
    "kostbarem": "kostbar",
    "kostbaren": "kostbar",
    "kostbarer": "kostbar",
    "kostbarere": "kostbar",
    "kostbarerem": "kostbar",
    "kostbareren": "kostbar",
    "kostbarerer": "kostbar",
    "kostbareres": "kostbar",
    "kostbares": "kostbar",
    "kostbarstem": "kostbar",
    "kostbarsten": "kostbar",
    "kostbarster": "kostbar",
    "kostbarstes": "kostbar",
    "koste": "kosten",
    "kostenbewußte": "kostenbewußt",
    "kostenbewußtem": "kostenbewußt",
    "kostenbewußten": "kostenbewußt",
    "kostenbewußter": "kostenbewußt",
    "kostenbewußtere": "kostenbewußt",
    "kostenbewußterem": "kostenbewußt",
    "kostenbewußteren": "kostenbewußt",
    "kostenbewußterer": "kostenbewußt",
    "kostenbewußteres": "kostenbewußt",
    "kostenbewußtes": "kostenbewußt",
    "kostenbewußteste": "kostenbewußt",
    "kostenbewußtestem": "kostenbewußt",
    "kostenbewußtesten": "kostenbewußt",
    "kostenbewußtester": "kostenbewußt",
    "kostenbewußtestes": "kostenbewußt",
    "kostend": "kosten",
    "kostende": "kostend",
    "kostendem": "kostend",
    "kostenden": "kostend",
    "kostender": "kostend",
    "kostendes": "kostend",
    "kostenfreie": "kostenfrei",
    "kostenfreiem": "kostenfrei",
    "kostenfreien": "kostenfrei",
    "kostenfreier": "kostenfrei",
    "kostenfreiere": "kostenfrei",
    "kostenfreierem": "kostenfrei",
    "kostenfreieren": "kostenfrei",
    "kostenfreierer": "kostenfrei",
    "kostenfreieres": "kostenfrei",
    "kostenfreies": "kostenfrei",
    "kostenfreieste": "kostenfrei",
    "kostenfreiestem": "kostenfrei",
    "kostenfreiesten": "kostenfrei",
    "kostenfreiester": "kostenfrei",
    "kostenfreiestes": "kostenfrei",
    "kostengünstige": "kostengünstig",
    "kostengünstigem": "kostengünstig",
    "kostengünstigen": "kostengünstig",
    "kostengünstiger": "kostengünstig",
    "kostengünstigere": "kostengünstig",
    "kostengünstigerem": "kostengünstig",
    "kostengünstigeren": "kostengünstig",
    "kostengünstigerer": "kostengünstig",
    "kostengünstigeres": "kostengünstig",
    "kostengünstiges": "kostengünstig",
    "kostengünstigste": "kostengünstig",
    "kostengünstigstem": "kostengünstig",
    "kostengünstigsten": "kostengünstig",
    "kostengünstigster": "kostengünstig",
    "kostengünstigstes": "kostengünstig",
    "kostenintensive": "kostenintensiv",
    "kostenintensivem": "kostenintensiv",
    "kostenintensiven": "kostenintensiv",
    "kostenintensiver": "kostenintensiv",
    "kostenintensives": "kostenintensiv",
    "kostenlose": "kostenlos",
    "kostenlosem": "kostenlos",
    "kostenlosen": "kostenlos",
    "kostenloser": "kostenlos",
    "kostenloses": "kostenlos",
    "kostenpflichtige": "kostenpflichtig",
    "kostenpflichtigem": "kostenpflichtig",
    "kostenpflichtigen": "kostenpflichtig",
    "kostenpflichtiger": "kostenpflichtig",
    "kostenpflichtiges": "kostenpflichtig",
    "kostest": "kosten",
    "kostet": "kosten",
    "kostete": "kosten",
    "kosteten": "kosten",
    "kostetest": "kosten",
    "kostetet": "kosten",
    "kostspielige": "kostspielig",
    "kostspieligem": "kostspielig",
    "kostspieligen": "kostspielig",
    "kostspieliger": "kostspielig",
    "kostspieligere": "kostspielig",
    "kostspieligerem": "kostspielig",
    "kostspieligeren": "kostspielig",
    "kostspieligerer": "kostspielig",
    "kostspieligeres": "kostspielig",
    "kostspieliges": "kostspielig",
    "kostspieligste": "kostspielig",
    "kostspieligstem": "kostspielig",
    "kostspieligsten": "kostspielig",
    "kostspieligster": "kostspielig",
    "kostspieligstes": "kostspielig",
    "kostümiere": "kostümieren",
    "kostümierend": "kostümieren",
    "kostümierende": "kostümierend",
    "kostümierendem": "kostümierend",
    "kostümierenden": "kostümierend",
    "kostümierender": "kostümierend",
    "kostümierendere": "kostümierend",
    "kostümierenderem": "kostümierend",
    "kostümierenderen": "kostümierend",
    "kostümierenderer": "kostümierend",
    "kostümierenderes": "kostümierend",
    "kostümierendes": "kostümierend",
    "kostümierendste": "kostümierend",
    "kostümierendstem": "kostümierend",
    "kostümierendsten": "kostümierend",
    "kostümierendster": "kostümierend",
    "kostümierendstes": "kostümierend",
    "kostümierest": "kostümieren",
    "kostümieret": "kostümieren",
    "kostümierst": "kostümieren",
    "kostümiert": "kostümieren",
    "kostümierte": "kostümieren",
    "kostümiertem": "kostümiert",
    "kostümierten": "kostümieren",
    "kostümierter": "kostümiert",
    "kostümiertere": "kostümiert",
    "kostümierterem": "kostümiert",
    "kostümierteren": "kostümiert",
    "kostümierterer": "kostümiert",
    "kostümierteres": "kostümiert",
    "kostümiertes": "kostümiert",
    "kostümiertest": "kostümieren",
    "kostümierteste": "kostümiert",
    "kostümiertestem": "kostümiert",
    "kostümiertesten": "kostümiert",
    "kostümiertester": "kostümiert",
    "kostümiertestes": "kostümiert",
    "kostümiertet": "kostümieren",
    "kotzend": "kotzen",
    "kotzende": "kotzend",
    "kotzendem": "kotzend",
    "kotzenden": "kotzend",
    "kotzender": "kotzend",
    "kotzendere": "kotzend",
    "kotzenderem": "kotzend",
    "kotzenderen": "kotzend",
    "kotzenderer": "kotzend",
    "kotzenderes": "kotzend",
    "kotzendes": "kotzend",
    "kotzendste": "kotzend",
    "kotzendstem": "kotzend",
    "kotzendsten": "kotzend",
    "kotzendster": "kotzend",
    "kotzendstes": "kotzend",
    "kotzest": "kotzen",
    "kotzet": "kotzen",
    "kotzt": "kotzen",
    "kotzte": "kotzen",
    "kotzten": "kotzen",
    "kotztest": "kotzen",
    "kotztet": "kotzen",
    "kotzüble": "kotzübel",
    "kotzüblem": "kotzübel",
    "kotzüblen": "kotzübel",
    "kotzübler": "kotzübel",
    "kotzübles": "kotzübel",
    "krabbele": "krabbeln",
    "krabbelige": "krabbelig",
    "krabbeligem": "krabbelig",
    "krabbeligen": "krabbelig",
    "krabbeliger": "krabbelig",
    "krabbeligere": "krabbelig",
    "krabbeligerem": "krabbelig",
    "krabbeligeren": "krabbelig",
    "krabbeligerer": "krabbelig",
    "krabbeligeres": "krabbelig",
    "krabbeliges": "krabbelig",
    "krabbeligste": "krabbelig",
    "krabbeligstem": "krabbelig",
    "krabbeligsten": "krabbelig",
    "krabbeligster": "krabbelig",
    "krabbeligstes": "krabbelig",
    "krabbelnd": "krabbeln",
    "krabbelnde": "krabbelnd",
    "krabbelndem": "krabbelnd",
    "krabbelnden": "krabbelnd",
    "krabbelnder": "krabbelnd",
    "krabbelndere": "krabbelnd",
    "krabbelnderem": "krabbelnd",
    "krabbelnderen": "krabbelnd",
    "krabbelnderer": "krabbelnd",
    "krabbelnderes": "krabbelnd",
    "krabbelndes": "krabbelnd",
    "krabbelndste": "krabbelnd",
    "krabbelndstem": "krabbelnd",
    "krabbelndsten": "krabbelnd",
    "krabbelndster": "krabbelnd",
    "krabbelndstes": "krabbelnd",
    "krabbelst": "krabbeln",
    "krabbelt": "krabbeln",
    "krabbelte": "krabbeln",
    "krabbelten": "krabbeln",
    "krabbeltest": "krabbeln",
    "krabbeltet": "krabbeln",
    "krabble": "krabbeln",
    "krache": "krachen",
    "krachend": "krachen",
    "krachende": "krachend",
    "krachendem": "krachend",
    "krachenden": "krachend",
    "krachender": "krachend",
    "krachendere": "krachend",
    "krachenderem": "krachend",
    "krachenderen": "krachend",
    "krachenderer": "krachend",
    "krachenderes": "krachend",
    "krachendes": "krachend",
    "krachendste": "krachend",
    "krachendstem": "krachend",
    "krachendsten": "krachend",
    "krachendster": "krachend",
    "krachendstes": "krachend",
    "krachest": "krachen",
    "krachet": "krachen",
    "krachst": "krachen",
    "kracht": "krachen",
    "krachte": "krachen",
    "krachten": "krachen",
    "krachtest": "krachen",
    "krachtet": "krachen",
    "kraftlosem": "kraftlos",
    "kraftlosen": "kraftlos",
    "kraftloser": "kraftlos",
    "kraftlosere": "kraftlos",
    "kraftloserem": "kraftlos",
    "kraftloseren": "kraftlos",
    "kraftloserer": "kraftlos",
    "kraftloseres": "kraftlos",
    "kraftloses": "kraftlos",
    "kraftloseste": "kraftlos",
    "kraftlosestem": "kraftlos",
    "kraftlosesten": "kraftlos",
    "kraftlosester": "kraftlos",
    "kraftlosestes": "kraftlos",
    "kraftstrotzendem": "kraftstrotzend",
    "kraftstrotzenden": "kraftstrotzend",
    "kraftstrotzender": "kraftstrotzend",
    "kraftstrotzendere": "kraftstrotzend",
    "kraftstrotzenderem": "kraftstrotzend",
    "kraftstrotzenderen": "kraftstrotzend",
    "kraftstrotzenderer": "kraftstrotzend",
    "kraftstrotzenderes": "kraftstrotzend",
    "kraftstrotzendes": "kraftstrotzend",
    "kraftstrotzendste": "kraftstrotzend",
    "kraftstrotzendstem": "kraftstrotzend",
    "kraftstrotzendsten": "kraftstrotzend",
    "kraftstrotzendster": "kraftstrotzend",
    "kraftstrotzendstes": "kraftstrotzend",
    "kraftvolle": "kraftvoll",
    "kraftvollem": "kraftvoll",
    "kraftvollen": "kraftvoll",
    "kraftvoller": "kraftvoll",
    "kraftvollere": "kraftvoll",
    "kraftvollerem": "kraftvoll",
    "kraftvolleren": "kraftvoll",
    "kraftvollerer": "kraftvoll",
    "kraftvolleres": "kraftvoll",
    "kraftvolles": "kraftvoll",
    "kraftvollste": "kraftvoll",
    "kraftvollstem": "kraftvoll",
    "kraftvollsten": "kraftvoll",
    "kraftvollster": "kraftvoll",
    "kraftvollstes": "kraftvoll",
    "krakeele": "krakeelen",
    "krakeelend": "krakeelen",
    "krakeelende": "krakeelend",
    "krakeelendem": "krakeelend",
    "krakeelenden": "krakeelend",
    "krakeelender": "krakeelend",
    "krakeelendere": "krakeelend",
    "krakeelenderem": "krakeelend",
    "krakeelenderen": "krakeelend",
    "krakeelenderer": "krakeelend",
    "krakeelenderes": "krakeelend",
    "krakeelendes": "krakeelend",
    "krakeelendste": "krakeelend",
    "krakeelendstem": "krakeelend",
    "krakeelendsten": "krakeelend",
    "krakeelendster": "krakeelend",
    "krakeelendstes": "krakeelend",
    "krakeelest": "krakeelen",
    "krakeelet": "krakeelen",
    "krakeelst": "krakeelen",
    "krakeelt": "krakeelen",
    "krakeelte": "krakeelen",
    "krakeeltem": "krakeelt",
    "krakeelten": "krakeelen",
    "krakeelter": "krakeelt",
    "krakeeltes": "krakeelt",
    "krakeeltest": "krakeelen",
    "krakeeltet": "krakeelen",
    "krakelige": "krakelig",
    "krakeligem": "krakelig",
    "krakeligen": "krakelig",
    "krakeliger": "krakelig",
    "krakeligere": "krakelig",
    "krakeligerem": "krakelig",
    "krakeligeren": "krakelig",
    "krakeligerer": "krakelig",
    "krakeligeres": "krakelig",
    "krakeliges": "krakelig",
    "krakeligste": "krakelig",
    "krakeligstem": "krakelig",
    "krakeligsten": "krakelig",
    "krakeligster": "krakelig",
    "krakeligstes": "krakelig",
    "krallend": "krallen",
    "krallende": "krallend",
    "krallendem": "krallend",
    "krallenden": "krallend",
    "krallender": "krallend",
    "krallendere": "krallend",
    "krallenderem": "krallend",
    "krallenderen": "krallend",
    "krallenderer": "krallend",
    "krallenderes": "krallend",
    "krallendes": "krallend",
    "krallendste": "krallend",
    "krallendstem": "krallend",
    "krallendsten": "krallend",
    "krallendster": "krallend",
    "krallendstes": "krallend",
    "krallest": "krallen",
    "krallet": "krallen",
    "krallst": "krallen",
    "krallt": "krallen",
    "krallte": "krallen",
    "krallten": "krallen",
    "kralltest": "krallen",
    "kralltet": "krallen",
    "krame": "kramen",
    "kramend": "kramen",
    "kramende": "kramend",
    "kramendem": "kramend",
    "kramenden": "kramend",
    "kramender": "kramend",
    "kramendere": "kramend",
    "kramenderem": "kramend",
    "kramenderen": "kramend",
    "kramenderer": "kramend",
    "kramenderes": "kramend",
    "kramendes": "kramend",
    "kramendste": "kramend",
    "kramendstem": "kramend",
    "kramendsten": "kramend",
    "kramendster": "kramend",
    "kramendstes": "kramend",
    "kramest": "kramen",
    "kramet": "kramen",
    "krampfartigem": "krampfartig",
    "krampfartigen": "krampfartig",
    "krampfartiger": "krampfartig",
    "krampfartiges": "krampfartig",
    "krampfend": "krampfen",
    "krampfende": "krampfend",
    "krampfendem": "krampfend",
    "krampfenden": "krampfend",
    "krampfender": "krampfend",
    "krampfendes": "krampfend",
    "krampfest": "krampfen",
    "krampfet": "krampfen",
    "krampfhafte": "krampfhaft",
    "krampfhaftem": "krampfhaft",
    "krampfhaften": "krampfhaft",
    "krampfhafter": "krampfhaft",
    "krampfhaftes": "krampfhaft",
    "krampflösende": "krampflösend",
    "krampflösendem": "krampflösend",
    "krampflösenden": "krampflösend",
    "krampflösender": "krampflösend",
    "krampflösendere": "krampflösend",
    "krampflösenderem": "krampflösend",
    "krampflösenderen": "krampflösend",
    "krampflösenderer": "krampflösend",
    "krampflösenderes": "krampflösend",
    "krampflösendes": "krampflösend",
    "krampflösendste": "krampflösend",
    "krampflösendstem": "krampflösend",
    "krampflösendsten": "krampflösend",
    "krampflösendster": "krampflösend",
    "krampflösendstes": "krampflösend",
    "krampfst": "krampfen",
    "krampft": "krampfen",
    "krampfte": "krampfen",
    "krampften": "krampfen",
    "krampftest": "krampfen",
    "krampftet": "krampfen",
    "kramst": "kramen",
    "kramt": "kramen",
    "kramte": "kramen",
    "kramten": "kramen",
    "kramtest": "kramen",
    "kramtet": "kramen",
    "krank": "kranken",
    "kranke": "krank",
    "krankem": "krank",
    "kranken": "krank",
    "krankend": "kranken",
    "krankende": "krankend",
    "krankendem": "krankend",
    "krankenden": "krankend",
    "krankender": "krankend",
    "krankendes": "krankend",
    "krankenhausreifem": "krankenhausreif",
    "krankenhausreifen": "krankenhausreif",
    "krankenhausreifer": "krankenhausreif",
    "krankenhausreifes": "krankenhausreif",
    "kranker": "krank",
    "krankes": "krank",
    "krankest": "kranken",
    "kranket": "kranken",
    "krankfeiere": "krankfeiern",
    "krankfeiernd": "krankfeiern",
    "krankfeiernde": "krankfeiernd",
    "krankfeierndem": "krankfeiernd",
    "krankfeiernden": "krankfeiernd",
    "krankfeiernder": "krankfeiernd",
    "krankfeierndere": "krankfeiernd",
    "krankfeiernderem": "krankfeiernd",
    "krankfeiernderen": "krankfeiernd",
    "krankfeiernderer": "krankfeiernd",
    "krankfeiernderes": "krankfeiernd",
    "krankfeierndes": "krankfeiernd",
    "krankfeierndste": "krankfeiernd",
    "krankfeierndstem": "krankfeiernd",
    "krankfeierndsten": "krankfeiernd",
    "krankfeierndster": "krankfeiernd",
    "krankfeierndstes": "krankfeiernd",
    "krankfeierst": "krankfeiern",
    "krankfeiert": "krankfeiern",
    "krankfeierte": "krankfeiern",
    "krankfeierten": "krankfeiern",
    "krankfeiertest": "krankfeiern",
    "krankfeiertet": "krankfeiern",
    "krankgefeiert": "krankfeiern",
    "krankgefeierte": "krankgefeiert",
    "krankgefeiertem": "krankgefeiert",
    "krankgefeierten": "krankgefeiert",
    "krankgefeierter": "krankgefeiert",
    "krankgefeiertere": "krankgefeiert",
    "krankgefeierterem": "krankgefeiert",
    "krankgefeierteren": "krankgefeiert",
    "krankgefeierterer": "krankgefeiert",
    "krankgefeierteres": "krankgefeiert",
    "krankgefeiertes": "krankgefeiert",
    "krankgefeierteste": "krankgefeiert",
    "krankgefeiertestem": "krankgefeiert",
    "krankgefeiertesten": "krankgefeiert",
    "krankgefeiertester": "krankgefeiert",
    "krankgefeiertestes": "krankgefeiert",
    "krankgelacht": "kranklachen",
    "krankgelachte": "krankgelacht",
    "krankgelachtem": "krankgelacht",
    "krankgelachten": "krankgelacht",
    "krankgelachter": "krankgelacht",
    "krankgelachtes": "krankgelacht",
    "krankgeschrieben": "krankschreiben",
    "krankgeschriebene": "krankgeschrieben",
    "krankgeschriebenem": "krankgeschrieben",
    "krankgeschriebenen": "krankgeschrieben",
    "krankgeschriebener": "krankgeschrieben",
    "krankgeschriebenes": "krankgeschrieben",
    "krankhafte": "krankhaft",
    "krankhaftem": "krankhaft",
    "krankhaften": "krankhaft",
    "krankhafter": "krankhaft",
    "krankhaftere": "krankhaft",
    "krankhafterem": "krankhaft",
    "krankhafteren": "krankhaft",
    "krankhafterer": "krankhaft",
    "krankhafteres": "krankhaft",
    "krankhaftes": "krankhaft",
    "krankhafteste": "krankhaft",
    "krankhaftestem": "krankhaft",
    "krankhaftesten": "krankhaft",
    "krankhaftester": "krankhaft",
    "krankhaftestes": "krankhaft",
    "kranklache": "kranklachen",
    "kranklachend": "kranklachen",
    "kranklachende": "kranklachend",
    "kranklachendem": "kranklachend",
    "kranklachenden": "kranklachend",
    "kranklachender": "kranklachend",
    "kranklachendere": "kranklachend",
    "kranklachenderem": "kranklachend",
    "kranklachenderen": "kranklachend",
    "kranklachenderer": "kranklachend",
    "kranklachenderes": "kranklachend",
    "kranklachendes": "kranklachend",
    "kranklachendste": "kranklachend",
    "kranklachendstem": "kranklachend",
    "kranklachendsten": "kranklachend",
    "kranklachendster": "kranklachend",
    "kranklachendstes": "kranklachend",
    "kranklachest": "kranklachen",
    "kranklachet": "kranklachen",
    "kranklachst": "kranklachen",
    "kranklacht": "kranklachen",
    "kranklachte": "kranklachen",
    "kranklachten": "kranklachen",
    "kranklachtest": "kranklachen",
    "kranklachtet": "kranklachen",
    "krankschreibe": "krankschreiben",
    "krankschreibend": "krankschreiben",
    "krankschreibende": "krankschreibend",
    "krankschreibendem": "krankschreibend",
    "krankschreibenden": "krankschreibend",
    "krankschreibender": "krankschreibend",
    "krankschreibendes": "krankschreibend",
    "krankschreibest": "krankschreiben",
    "krankschreibet": "krankschreiben",
    "krankschreibst": "krankschreiben",
    "krankschreibt": "krankschreiben",
    "krankschrieb": "krankschreiben",
    "krankschriebe": "krankschreiben",
    "krankschrieben": "krankschreiben",
    "krankschriebest": "krankschreiben",
    "krankschriebet": "krankschreiben",
    "krankschriebst": "krankschreiben",
    "krankschriebt": "krankschreiben",
    "krankst": "kranken",
    "krankt": "kranken",
    "krankte": "kranken",
    "krankten": "kranken",
    "kranktest": "kranken",
    "kranktet": "kranken",
    "krankzufeiern": "krankfeiern",
    "krankzulachen": "kranklachen",
    "krankzuschreiben": "krankschreiben",
    "krassem": "kraß",
    "krassen": "kraß",
    "krasser": "kraß",
    "krassere": "kraß",
    "krasserem": "kraß",
    "krasseren": "kraß",
    "krasserer": "kraß",
    "krasseres": "kraß",
    "krasses": "kraß",
    "krasseste": "kraß",
    "krassestem": "kraß",
    "krassesten": "kraß",
    "krassester": "kraß",
    "krassestes": "kraß",
    "kratzbürstigem": "kratzbürstig",
    "kratzbürstigen": "kratzbürstig",
    "kratzbürstiger": "kratzbürstig",
    "kratzbürstigere": "kratzbürstig",
    "kratzbürstigerem": "kratzbürstig",
    "kratzbürstigeren": "kratzbürstig",
    "kratzbürstigerer": "kratzbürstig",
    "kratzbürstigeres": "kratzbürstig",
    "kratzbürstiges": "kratzbürstig",
    "kratzbürstigste": "kratzbürstig",
    "kratzbürstigstem": "kratzbürstig",
    "kratzbürstigsten": "kratzbürstig",
    "kratzbürstigster": "kratzbürstig",
    "kratzbürstigstes": "kratzbürstig",
    "kratze": "kratzen",
    "kratzend": "kratzen",
    "kratzende": "kratzend",
    "kratzendem": "kratzend",
    "kratzenden": "kratzend",
    "kratzender": "kratzend",
    "kratzendere": "kratzend",
    "kratzenderem": "kratzend",
    "kratzenderen": "kratzend",
    "kratzenderer": "kratzend",
    "kratzenderes": "kratzend",
    "kratzendes": "kratzend",
    "kratzendste": "kratzend",
    "kratzendstem": "kratzend",
    "kratzendsten": "kratzend",
    "kratzendster": "kratzend",
    "kratzendstes": "kratzend",
    "kratzest": "kratzen",
    "kratzet": "kratzen",
    "kratzige": "kratzig",
    "kratzigem": "kratzig",
    "kratzigen": "kratzig",
    "kratziger": "kratzig",
    "kratzigere": "kratzig",
    "kratzigerem": "kratzig",
    "kratzigeren": "kratzig",
    "kratzigerer": "kratzig",
    "kratzigeres": "kratzig",
    "kratziges": "kratzig",
    "kratzigste": "kratzig",
    "kratzigstem": "kratzig",
    "kratzigsten": "kratzig",
    "kratzigster": "kratzig",
    "kratzigstes": "kratzig",
    "kratzt": "kratzen",
    "kratzte": "kratzen",
    "kratzten": "kratzen",
    "kratztest": "kratzen",
    "kratztet": "kratzen",
    "kraule": "kraulen",
    "kraulend": "kraulen",
    "kraulende": "kraulend",
    "kraulendem": "kraulend",
    "kraulenden": "kraulend",
    "kraulender": "kraulend",
    "kraulendes": "kraulend",
    "kraulest": "kraulen",
    "kraulet": "kraulen",
    "kraulst": "kraulen",
    "krault": "kraulen",
    "kraulte": "kraulen",
    "kraulten": "kraulen",
    "kraultest": "kraulen",
    "kraultet": "kraulen",
    "krause": "krausen",
    "krausend": "krausen",
    "krausende": "krausend",
    "krausendem": "krausend",
    "krausenden": "krausend",
    "krausender": "krausend",
    "krausendere": "krausend",
    "krausenderem": "krausend",
    "krausenderen": "krausend",
    "krausenderer": "krausend",
    "krausenderes": "krausend",
    "krausendes": "krausend",
    "krausendste": "krausend",
    "krausendstem": "krausend",
    "krausendsten": "krausend",
    "krausendster": "krausend",
    "krausendstes": "krausend",
    "krausest": "krausen",
    "krauset": "krausen",
    "krausköpfige": "krausköpfig",
    "krausköpfigem": "krausköpfig",
    "krausköpfigen": "krausköpfig",
    "krausköpfiger": "krausköpfig",
    "krausköpfiges": "krausköpfig",
    "kraust": "krausen",
    "krauste": "krausen",
    "krausten": "krausen",
    "kraustest": "krausen",
    "kraustet": "krausen",
    "kreativem": "kreativ",
    "kreativen": "kreativ",
    "kreativer": "kreativ",
    "kreativere": "kreativ",
    "kreativerem": "kreativ",
    "kreativeren": "kreativ",
    "kreativerer": "kreativ",
    "kreativeres": "kreativ",
    "kreatives": "kreativ",
    "kreativste": "kreativ",
    "kreativstem": "kreativ",
    "kreativsten": "kreativ",
    "kreativster": "kreativ",
    "kreativstes": "kreativ",
    "krebskrankem": "krebskrank",
    "krebskranken": "krebskrank",
    "krebskranker": "krebskrank",
    "krebskrankes": "krebskrank",
    "kredenze": "kredenzen",
    "kredenzend": "kredenzen",
    "kredenzende": "kredenzend",
    "kredenzendem": "kredenzend",
    "kredenzenden": "kredenzend",
    "kredenzender": "kredenzend",
    "kredenzendere": "kredenzend",
    "kredenzenderem": "kredenzend",
    "kredenzenderen": "kredenzend",
    "kredenzenderer": "kredenzend",
    "kredenzenderes": "kredenzend",
    "kredenzendes": "kredenzend",
    "kredenzendste": "kredenzend",
    "kredenzendstem": "kredenzend",
    "kredenzendsten": "kredenzend",
    "kredenzendster": "kredenzend",
    "kredenzendstes": "kredenzend",
    "kredenzest": "kredenzen",
    "kredenzet": "kredenzen",
    "kredenzt": "kredenzen",
    "kredenzte": "kredenzen",
    "kredenztem": "kredenzt",
    "kredenzten": "kredenzen",
    "kredenzter": "kredenzt",
    "kredenztere": "kredenzt",
    "kredenzterem": "kredenzt",
    "kredenzteren": "kredenzt",
    "kredenzterer": "kredenzt",
    "kredenzteres": "kredenzt",
    "kredenztes": "kredenzt",
    "kredenztest": "kredenzen",
    "kredenzteste": "kredenzt",
    "kredenztestem": "kredenzt",
    "kredenztesten": "kredenzt",
    "kredenztester": "kredenzt",
    "kredenztestes": "kredenzt",
    "kredenztet": "kredenzen",
    "kreditfähigem": "kreditfähig",
    "kreditfähigen": "kreditfähig",
    "kreditfähiger": "kreditfähig",
    "kreditfähiges": "kreditfähig",
    "kreditunwürdigem": "kreditunwürdig",
    "kreditunwürdigen": "kreditunwürdig",
    "kreditunwürdiger": "kreditunwürdig",
    "kreditunwürdiges": "kreditunwürdig",
    "kreditwürdige": "kreditwürdig",
    "kreditwürdigem": "kreditwürdig",
    "kreditwürdigen": "kreditwürdig",
    "kreditwürdiger": "kreditwürdig",
    "kreditwürdigere": "kreditwürdig",
    "kreditwürdigerem": "kreditwürdig",
    "kreditwürdigeren": "kreditwürdig",
    "kreditwürdigerer": "kreditwürdig",
    "kreditwürdigeres": "kreditwürdig",
    "kreditwürdiges": "kreditwürdig",
    "kreditwürdigste": "kreditwürdig",
    "kreditwürdigstem": "kreditwürdig",
    "kreditwürdigsten": "kreditwürdig",
    "kreditwürdigster": "kreditwürdig",
    "kreditwürdigstes": "kreditwürdig",
    "kreidebleiche": "kreidebleich",
    "kreidebleichem": "kreidebleich",
    "kreidebleichen": "kreidebleich",
    "kreidebleicher": "kreidebleich",
    "kreidebleichere": "kreidebleich",
    "kreidebleicherem": "kreidebleich",
    "kreidebleicheren": "kreidebleich",
    "kreidebleicherer": "kreidebleich",
    "kreidebleicheres": "kreidebleich",
    "kreidebleiches": "kreidebleich",
    "kreidebleichste": "kreidebleich",
    "kreidebleichstem": "kreidebleich",
    "kreidebleichsten": "kreidebleich",
    "kreidebleichster": "kreidebleich",
    "kreidebleichstes": "kreidebleich",
    "kreidend": "kreiden",
    "kreidende": "kreidend",
    "kreidendem": "kreidend",
    "kreidenden": "kreidend",
    "kreidender": "kreidend",
    "kreidendes": "kreidend",
    "kreidest": "kreiden",
    "kreidet": "kreiden",
    "kreidete": "kreiden",
    "kreideten": "kreiden",
    "kreidetest": "kreiden",
    "kreidetet": "kreiden",
    "kreische": "kreischen",
    "kreischend": "kreischen",
    "kreischende": "kreischend",
    "kreischendem": "kreischend",
    "kreischenden": "kreischend",
    "kreischender": "kreischend",
    "kreischendere": "kreischend",
    "kreischenderem": "kreischend",
    "kreischenderen": "kreischend",
    "kreischenderer": "kreischend",
    "kreischenderes": "kreischend",
    "kreischendes": "kreischend",
    "kreischendste": "kreischend",
    "kreischendstem": "kreischend",
    "kreischendsten": "kreischend",
    "kreischendster": "kreischend",
    "kreischendstes": "kreischend",
    "kreischest": "kreischen",
    "kreischet": "kreischen",
    "kreischst": "kreischen",
    "kreischt": "kreischen",
    "kreischte": "kreischen",
    "kreischten": "kreischen",
    "kreischtest": "kreischen",
    "kreischtet": "kreischen",
    "kreisend": "kreisen",
    "kreisende": "kreisend",
    "kreisendem": "kreisend",
    "kreisenden": "kreisend",
    "kreisender": "kreisend",
    "kreisendes": "kreisend",
    "kreisest": "kreisen",
    "kreiset": "kreisen",
    "kreisfreie": "kreisfrei",
    "kreisfreiem": "kreisfrei",
    "kreisfreien": "kreisfrei",
    "kreisfreier": "kreisfrei",
    "kreisfreies": "kreisfrei",
    "kreisförmige": "kreisförmig",
    "kreisförmigem": "kreisförmig",
    "kreisförmigen": "kreisförmig",
    "kreisförmiger": "kreisförmig",
    "kreisförmiges": "kreisförmig",
    "kreisrundem": "kreisrund",
    "kreisrunden": "kreisrund",
    "kreisrunder": "kreisrund",
    "kreisrundes": "kreisrund",
    "kreist": "kreisen",
    "kreiste": "kreisen",
    "kreisten": "kreisen",
    "kreistest": "kreisen",
    "kreistet": "kreisen",
    "kremige": "kremig",
    "kremigem": "kremig",
    "kremigen": "kremig",
    "kremiger": "kremig",
    "kremigere": "kremig",
    "kremigerem": "kremig",
    "kremigeren": "kremig",
    "kremigerer": "kremig",
    "kremigeres": "kremig",
    "kremiges": "kremig",
    "kremigste": "kremig",
    "kremigstem": "kremig",
    "kremigsten": "kremig",
    "kremigster": "kremig",
    "kremigstes": "kremig",
    "krempele": "krempeln",
    "krempelnd": "krempeln",
    "krempelnde": "krempelnd",
    "krempelndem": "krempelnd",
    "krempelnden": "krempelnd",
    "krempelnder": "krempelnd",
    "krempelndes": "krempelnd",
    "krempelst": "krempeln",
    "krempelt": "krempeln",
    "krempelte": "krempeln",
    "krempelten": "krempeln",
    "krempeltest": "krempeln",
    "krempeltet": "krempeln",
    "kremple": "krempeln",
    "krepiere": "krepieren",
    "krepierend": "krepieren",
    "krepierende": "krepierend",
    "krepierendem": "krepierend",
    "krepierenden": "krepierend",
    "krepierender": "krepierend",
    "krepierendere": "krepierend",
    "krepierenderem": "krepierend",
    "krepierenderen": "krepierend",
    "krepierenderer": "krepierend",
    "krepierenderes": "krepierend",
    "krepierendes": "krepierend",
    "krepierendste": "krepierend",
    "krepierendstem": "krepierend",
    "krepierendsten": "krepierend",
    "krepierendster": "krepierend",
    "krepierendstes": "krepierend",
    "krepierest": "krepieren",
    "krepieret": "krepieren",
    "krepierst": "krepieren",
    "krepiert": "krepieren",
    "krepierte": "krepieren",
    "krepiertem": "krepiert",
    "krepierten": "krepieren",
    "krepierter": "krepiert",
    "krepiertere": "krepiert",
    "krepierterem": "krepiert",
    "krepierteren": "krepiert",
    "krepierterer": "krepiert",
    "krepierteres": "krepiert",
    "krepiertes": "krepiert",
    "krepiertest": "krepieren",
    "krepierteste": "krepiert",
    "krepiertestem": "krepiert",
    "krepiertesten": "krepiert",
    "krepiertester": "krepiert",
    "krepiertestes": "krepiert",
    "krepiertet": "krepieren",
    "kreuzend": "kreuzen",
    "kreuzende": "kreuzend",
    "kreuzendem": "kreuzend",
    "kreuzenden": "kreuzend",
    "kreuzender": "kreuzend",
    "kreuzendes": "kreuzend",
    "kreuzest": "kreuzen",
    "kreuzet": "kreuzen",
    "kreuzige": "kreuzigen",
    "kreuzigend": "kreuzigen",
    "kreuzigende": "kreuzigend",
    "kreuzigendem": "kreuzigend",
    "kreuzigenden": "kreuzigend",
    "kreuzigender": "kreuzigend",
    "kreuzigendes": "kreuzigend",
    "kreuzigest": "kreuzigen",
    "kreuziget": "kreuzigen",
    "kreuzigst": "kreuzigen",
    "kreuzigt": "kreuzigen",
    "kreuzigte": "kreuzigen",
    "kreuzigten": "kreuzigen",
    "kreuzigtest": "kreuzigen",
    "kreuzigtet": "kreuzigen",
    "kreuzt": "kreuzen",
    "kreuzte": "kreuzen",
    "kreuzten": "kreuzen",
    "kreuztest": "kreuzen",
    "kreuztet": "kreuzen",
    "kreuzungsfreiem": "kreuzungsfrei",
    "kreuzungsfreien": "kreuzungsfrei",
    "kreuzungsfreier": "kreuzungsfrei",
    "kreuzungsfreies": "kreuzungsfrei",
    "kribbele": "kribbeln",
    "kribbelige": "kribbelig",
    "kribbeligem": "kribbelig",
    "kribbeligen": "kribbelig",
    "kribbeliger": "kribbelig",
    "kribbeligere": "kribbelig",
    "kribbeligerem": "kribbelig",
    "kribbeligeren": "kribbelig",
    "kribbeligerer": "kribbelig",
    "kribbeligeres": "kribbelig",
    "kribbeliges": "kribbelig",
    "kribbeligste": "kribbelig",
    "kribbeligstem": "kribbelig",
    "kribbeligsten": "kribbelig",
    "kribbeligster": "kribbelig",
    "kribbeligstes": "kribbelig",
    "kribbelnd": "kribbeln",
    "kribbelnde": "kribbelnd",
    "kribbelndem": "kribbelnd",
    "kribbelnden": "kribbelnd",
    "kribbelnder": "kribbelnd",
    "kribbelndere": "kribbelnd",
    "kribbelnderem": "kribbelnd",
    "kribbelnderen": "kribbelnd",
    "kribbelnderer": "kribbelnd",
    "kribbelnderes": "kribbelnd",
    "kribbelndes": "kribbelnd",
    "kribbelndste": "kribbelnd",
    "kribbelndstem": "kribbelnd",
    "kribbelndsten": "kribbelnd",
    "kribbelndster": "kribbelnd",
    "kribbelndstes": "kribbelnd",
    "kribbelst": "kribbeln",
    "kribbelt": "kribbeln",
    "kribbelte": "kribbeln",
    "kribbelten": "kribbeln",
    "kribbeltest": "kribbeln",
    "kribbeltet": "kribbeln",
    "kribble": "kribbeln",
    "krieche": "kriechen",
    "kriechend": "kriechen",
    "kriechende": "kriechend",
    "kriechendem": "kriechend",
    "kriechenden": "kriechend",
    "kriechender": "kriechend",
    "kriechendes": "kriechend",
    "kriechest": "kriechen",
    "kriechet": "kriechen",
    "kriechst": "kriechen",
    "kriecht": "kriechen",
    "kriegend": "kriegen",
    "kriegende": "kriegend",
    "kriegendem": "kriegend",
    "kriegenden": "kriegend",
    "kriegender": "kriegend",
    "kriegendes": "kriegend",
    "kriegerischem": "kriegerisch",
    "kriegerischen": "kriegerisch",
    "kriegerischer": "kriegerisch",
    "kriegerischere": "kriegerisch",
    "kriegerischerem": "kriegerisch",
    "kriegerischeren": "kriegerisch",
    "kriegerischerer": "kriegerisch",
    "kriegerischeres": "kriegerisch",
    "kriegerisches": "kriegerisch",
    "kriegerischste": "kriegerisch",
    "kriegerischstem": "kriegerisch",
    "kriegerischsten": "kriegerisch",
    "kriegerischster": "kriegerisch",
    "kriegerischstes": "kriegerisch",
    "kriegest": "kriegen",
    "krieget": "kriegen",
    "kriegführende": "kriegführend",
    "kriegführendem": "kriegführend",
    "kriegführenden": "kriegführend",
    "kriegführender": "kriegführend",
    "kriegführendes": "kriegführend",
    "kriegst": "kriegen",
    "kriegt": "kriegen",
    "kriegte": "kriegen",
    "kriegten": "kriegen",
    "kriegtest": "kriegen",
    "kriegtet": "kriegen",
    "kriminalem": "kriminal",
    "kriminalen": "kriminal",
    "kriminaler": "kriminal",
    "kriminales": "kriminal",
    "kriminalisiere": "kriminalisieren",
    "kriminalisierend": "kriminalisieren",
    "kriminalisierende": "kriminalisierend",
    "kriminalisierendem": "kriminalisierend",
    "kriminalisierenden": "kriminalisierend",
    "kriminalisierender": "kriminalisierend",
    "kriminalisierendere": "kriminalisierend",
    "kriminalisierenderem": "kriminalisierend",
    "kriminalisierenderen": "kriminalisierend",
    "kriminalisierenderer": "kriminalisierend",
    "kriminalisierenderes": "kriminalisierend",
    "kriminalisierendes": "kriminalisierend",
    "kriminalisierendste": "kriminalisierend",
    "kriminalisierendstem": "kriminalisierend",
    "kriminalisierendsten": "kriminalisierend",
    "kriminalisierendster": "kriminalisierend",
    "kriminalisierendstes": "kriminalisierend",
    "kriminalisierest": "kriminalisieren",
    "kriminalisieret": "kriminalisieren",
    "kriminalisierst": "kriminalisieren",
    "kriminalisiert": "kriminalisieren",
    "kriminalisierte": "kriminalisieren",
    "kriminalisiertem": "kriminalisiert",
    "kriminalisierten": "kriminalisieren",
    "kriminalisierter": "kriminalisiert",
    "kriminalisiertere": "kriminalisiert",
    "kriminalisierterem": "kriminalisiert",
    "kriminalisierteren": "kriminalisiert",
    "kriminalisierterer": "kriminalisiert",
    "kriminalisierteres": "kriminalisiert",
    "kriminalisiertes": "kriminalisiert",
    "kriminalisiertest": "kriminalisieren",
    "kriminalisierteste": "kriminalisiert",
    "kriminalisiertestem": "kriminalisiert",
    "kriminalisiertesten": "kriminalisiert",
    "kriminalisiertester": "kriminalisiert",
    "kriminalisiertestes": "kriminalisiert",
    "kriminalisiertet": "kriminalisieren",
    "kriminalistische": "kriminalistisch",
    "kriminalistischem": "kriminalistisch",
    "kriminalistischen": "kriminalistisch",
    "kriminalistischer": "kriminalistisch",
    "kriminalistisches": "kriminalistisch",
    "kriminellem": "kriminell",
    "kriminellen": "kriminell",
    "krimineller": "kriminell",
    "kriminellere": "kriminell",
    "kriminellerem": "kriminell",
    "kriminelleren": "kriminell",
    "kriminellerer": "kriminell",
    "kriminelleres": "kriminell",
    "kriminelles": "kriminell",
    "kriminellste": "kriminell",
    "kriminellstem": "kriminell",
    "kriminellsten": "kriminell",
    "kriminellster": "kriminell",
    "kriminellstes": "kriminell",
    "kriminologische": "kriminologisch",
    "kriminologischem": "kriminologisch",
    "kriminologischen": "kriminologisch",
    "kriminologischer": "kriminologisch",
    "kriminologisches": "kriminologisch",
    "kringele": "kringeln",
    "kringelnd": "kringeln",
    "kringelnde": "kringelnd",
    "kringelndem": "kringelnd",
    "kringelnden": "kringelnd",
    "kringelnder": "kringelnd",
    "kringelndere": "kringelnd",
    "kringelnderem": "kringelnd",
    "kringelnderen": "kringelnd",
    "kringelnderer": "kringelnd",
    "kringelnderes": "kringelnd",
    "kringelndes": "kringelnd",
    "kringelndste": "kringelnd",
    "kringelndstem": "kringelnd",
    "kringelndsten": "kringelnd",
    "kringelndster": "kringelnd",
    "kringelndstes": "kringelnd",
    "kringelst": "kringeln",
    "kringelt": "kringeln",
    "kringelte": "kringeln",
    "kringelten": "kringeln",
    "kringeltest": "kringeln",
    "kringeltet": "kringeln",
    "kringle": "kringeln",
    "krisele": "kriseln",
    "kriselnd": "kriseln",
    "kriselnde": "kriselnd",
    "kriselndem": "kriselnd",
    "kriselnden": "kriselnd",
    "kriselnder": "kriselnd",
    "kriselndere": "kriselnd",
    "kriselnderem": "kriselnd",
    "kriselnderen": "kriselnd",
    "kriselnderer": "kriselnd",
    "kriselnderes": "kriselnd",
    "kriselndes": "kriselnd",
    "kriselndste": "kriselnd",
    "kriselndstem": "kriselnd",
    "kriselndsten": "kriselnd",
    "kriselndster": "kriselnd",
    "kriselndstes": "kriselnd",
    "kriselst": "kriseln",
    "kriselt": "kriseln",
    "kriselte": "kriseln",
    "kriselten": "kriseln",
    "kriseltest": "kriseln",
    "kriseltet": "kriseln",
    "krisenanfälligem": "krisenanfällig",
    "krisenanfälligen": "krisenanfällig",
    "krisenanfälliger": "krisenanfällig",
    "krisenanfälligere": "krisenanfällig",
    "krisenanfälligerem": "krisenanfällig",
    "krisenanfälligeren": "krisenanfällig",
    "krisenanfälligerer": "krisenanfällig",
    "krisenanfälligeres": "krisenanfällig",
    "krisenanfälliges": "krisenanfällig",
    "krisenanfälligste": "krisenanfällig",
    "krisenanfälligstem": "krisenanfällig",
    "krisenanfälligsten": "krisenanfällig",
    "krisenanfälligster": "krisenanfällig",
    "krisenanfälligstes": "krisenanfällig",
    "krisenfeste": "krisenfest",
    "krisenfestem": "krisenfest",
    "krisenfesten": "krisenfest",
    "krisenfester": "krisenfest",
    "krisenfestere": "krisenfest",
    "krisenfesterem": "krisenfest",
    "krisenfesteren": "krisenfest",
    "krisenfesterer": "krisenfest",
    "krisenfesteres": "krisenfest",
    "krisenfestes": "krisenfest",
    "krisenfesteste": "krisenfest",
    "krisenfestestem": "krisenfest",
    "krisenfestesten": "krisenfest",
    "krisenfestester": "krisenfest",
    "krisenfestestes": "krisenfest",
    "krisengeschüttelte": "krisengeschüttelt",
    "krisengeschütteltem": "krisengeschüttelt",
    "krisengeschüttelten": "krisengeschüttelt",
    "krisengeschüttelter": "krisengeschüttelt",
    "krisengeschütteltere": "krisengeschüttelt",
    "krisengeschüttelterem": "krisengeschüttelt",
    "krisengeschüttelteren": "krisengeschüttelt",
    "krisengeschüttelterer": "krisengeschüttelt",
    "krisengeschüttelteres": "krisengeschüttelt",
    "krisengeschütteltes": "krisengeschüttelt",
    "krisengeschüttelteste": "krisengeschüttelt",
    "krisengeschütteltestem": "krisengeschüttelt",
    "krisengeschütteltesten": "krisengeschüttelt",
    "krisengeschütteltester": "krisengeschüttelt",
    "krisengeschütteltestes": "krisengeschüttelt",
    "krisle": "kriseln",
    "kristallisiere": "kristallisieren",
    "kristallisierend": "kristallisieren",
    "kristallisierende": "kristallisierend",
    "kristallisierendem": "kristallisierend",
    "kristallisierenden": "kristallisierend",
    "kristallisierender": "kristallisierend",
    "kristallisierendes": "kristallisierend",
    "kristallisierest": "kristallisieren",
    "kristallisieret": "kristallisieren",
    "kristallisierst": "kristallisieren",
    "kristallisiert": "kristallisieren",
    "kristallisierte": "kristallisieren",
    "kristallisiertem": "kristallisiert",
    "kristallisierten": "kristallisieren",
    "kristallisierter": "kristallisiert",
    "kristallisiertes": "kristallisiert",
    "kristallisiertest": "kristallisieren",
    "kristallisiertet": "kristallisieren",
    "kritiklosem": "kritiklos",
    "kritiklosen": "kritiklos",
    "kritikloser": "kritiklos",
    "kritiklosere": "kritiklos",
    "kritikloserem": "kritiklos",
    "kritikloseren": "kritiklos",
    "kritikloserer": "kritiklos",
    "kritikloseres": "kritiklos",
    "kritikloses": "kritiklos",
    "kritikloseste": "kritiklos",
    "kritiklosestem": "kritiklos",
    "kritiklosesten": "kritiklos",
    "kritiklosester": "kritiklos",
    "kritiklosestes": "kritiklos",
    "kritische": "kritisch",
    "kritischem": "kritisch",
    "kritischen": "kritisch",
    "kritischer": "kritisch",
    "kritischere": "kritisch",
    "kritischerem": "kritisch",
    "kritischeren": "kritisch",
    "kritischerer": "kritisch",
    "kritischeres": "kritisch",
    "kritisches": "kritisch",
    "kritischste": "kritisch",
    "kritischstem": "kritisch",
    "kritischsten": "kritisch",
    "kritischster": "kritisch",
    "kritischstes": "kritisch",
    "kritisiere": "kritisieren",
    "kritisierend": "kritisieren",
    "kritisierende": "kritisierend",
    "kritisierendem": "kritisierend",
    "kritisierenden": "kritisierend",
    "kritisierender": "kritisierend",
    "kritisierendere": "kritisierend",
    "kritisierenderem": "kritisierend",
    "kritisierenderen": "kritisierend",
    "kritisierenderer": "kritisierend",
    "kritisierenderes": "kritisierend",
    "kritisierendes": "kritisierend",
    "kritisierendste": "kritisierend",
    "kritisierendstem": "kritisierend",
    "kritisierendsten": "kritisierend",
    "kritisierendster": "kritisierend",
    "kritisierendstes": "kritisierend",
    "kritisierest": "kritisieren",
    "kritisieret": "kritisieren",
    "kritisierst": "kritisieren",
    "kritisiert": "kritisieren",
    "kritisierte": "kritisieren",
    "kritisiertem": "kritisiert",
    "kritisierten": "kritisieren",
    "kritisierter": "kritisiert",
    "kritisiertere": "kritisiert",
    "kritisierterem": "kritisiert",
    "kritisierteren": "kritisiert",
    "kritisierterer": "kritisiert",
    "kritisierteres": "kritisiert",
    "kritisiertes": "kritisiert",
    "kritisiertest": "kritisieren",
    "kritisierteste": "kritisiert",
    "kritisiertestem": "kritisiert",
    "kritisiertesten": "kritisiert",
    "kritisiertester": "kritisiert",
    "kritisiertestes": "kritisiert",
    "kritisiertet": "kritisieren",
    "kritzele": "kritzeln",
    "kritzeligem": "kritzelig",
    "kritzeligen": "kritzelig",
    "kritzeliger": "kritzelig",
    "kritzeligere": "kritzelig",
    "kritzeligerem": "kritzelig",
    "kritzeligeren": "kritzelig",
    "kritzeligerer": "kritzelig",
    "kritzeligeres": "kritzelig",
    "kritzeliges": "kritzelig",
    "kritzeligste": "kritzelig",
    "kritzeligstem": "kritzelig",
    "kritzeligsten": "kritzelig",
    "kritzeligster": "kritzelig",
    "kritzeligstes": "kritzelig",
    "kritzelnd": "kritzeln",
    "kritzelnde": "kritzelnd",
    "kritzelndem": "kritzelnd",
    "kritzelnden": "kritzelnd",
    "kritzelnder": "kritzelnd",
    "kritzelndes": "kritzelnd",
    "kritzelst": "kritzeln",
    "kritzelt": "kritzeln",
    "kritzelte": "kritzeln",
    "kritzelten": "kritzeln",
    "kritzeltest": "kritzeln",
    "kritzeltet": "kritzeln",
    "kritzle": "kritzeln",
    "kroatischem": "kroatisch",
    "kroatischen": "kroatisch",
    "kroatischer": "kroatisch",
    "kroatisches": "kroatisch",
    "kroch": "kriechen",
    "krochen": "kriechen",
    "krochst": "kriechen",
    "krocht": "kriechen",
    "krummbiege": "krummbiegen",
    "krummbiegend": "krummbiegen",
    "krummbiegende": "krummbiegend",
    "krummbiegendem": "krummbiegend",
    "krummbiegenden": "krummbiegend",
    "krummbiegender": "krummbiegend",
    "krummbiegendes": "krummbiegend",
    "krummbiegest": "krummbiegen",
    "krummbieget": "krummbiegen",
    "krummbiegst": "krummbiegen",
    "krummbiegt": "krummbiegen",
    "krummbog": "krummbiegen",
    "krummbogen": "krummbiegen",
    "krummbogst": "krummbiegen",
    "krummbogt": "krummbiegen",
    "krummböge": "krummbiegen",
    "krummbögen": "krummbiegen",
    "krummbögest": "krummbiegen",
    "krummböget": "krummbiegen",
    "krummgebogen": "krummbiegen",
    "krummgebogene": "krummgebogen",
    "krummgebogenem": "krummgebogen",
    "krummgebogenen": "krummgebogen",
    "krummgebogener": "krummgebogen",
    "krummgebogenere": "krummgebogen",
    "krummgebogenerem": "krummgebogen",
    "krummgebogeneren": "krummgebogen",
    "krummgebogenerer": "krummgebogen",
    "krummgebogeneres": "krummgebogen",
    "krummgebogenes": "krummgebogen",
    "krummgebogenste": "krummgebogen",
    "krummgebogenstem": "krummgebogen",
    "krummgebogensten": "krummgebogen",
    "krummgebogenster": "krummgebogen",
    "krummgebogenstes": "krummgebogen",
    "krummgelacht": "krummlachen",
    "krummgelachte": "krummgelacht",
    "krummgelachtem": "krummgelacht",
    "krummgelachten": "krummgelacht",
    "krummgelachter": "krummgelacht",
    "krummgelachtes": "krummgelacht",
    "krummgelegt": "krummlegen",
    "krummgelegte": "krummgelegt",
    "krummgelegtem": "krummgelegt",
    "krummgelegten": "krummgelegt",
    "krummgelegter": "krummgelegt",
    "krummgelegtere": "krummgelegt",
    "krummgelegterem": "krummgelegt",
    "krummgelegteren": "krummgelegt",
    "krummgelegterer": "krummgelegt",
    "krummgelegteres": "krummgelegt",
    "krummgelegtes": "krummgelegt",
    "krummgelegteste": "krummgelegt",
    "krummgelegtestem": "krummgelegt",
    "krummgelegtesten": "krummgelegt",
    "krummgelegtester": "krummgelegt",
    "krummgelegtestes": "krummgelegt",
    "krummgenommen": "krummnehmen",
    "krummgenommene": "krummgenommen",
    "krummgenommenem": "krummgenommen",
    "krummgenommenen": "krummgenommen",
    "krummgenommener": "krummgenommen",
    "krummgenommenes": "krummgenommen",
    "krummlache": "krummlachen",
    "krummlachend": "krummlachen",
    "krummlachende": "krummlachend",
    "krummlachendem": "krummlachend",
    "krummlachenden": "krummlachend",
    "krummlachender": "krummlachend",
    "krummlachendere": "krummlachend",
    "krummlachenderem": "krummlachend",
    "krummlachenderen": "krummlachend",
    "krummlachenderer": "krummlachend",
    "krummlachenderes": "krummlachend",
    "krummlachendes": "krummlachend",
    "krummlachendste": "krummlachend",
    "krummlachendstem": "krummlachend",
    "krummlachendsten": "krummlachend",
    "krummlachendster": "krummlachend",
    "krummlachendstes": "krummlachend",
    "krummlachest": "krummlachen",
    "krummlachet": "krummlachen",
    "krummlachst": "krummlachen",
    "krummlacht": "krummlachen",
    "krummlachte": "krummlachen",
    "krummlachten": "krummlachen",
    "krummlachtest": "krummlachen",
    "krummlachtet": "krummlachen",
    "krummlege": "krummlegen",
    "krummlegend": "krummlegen",
    "krummlegende": "krummlegend",
    "krummlegendem": "krummlegend",
    "krummlegenden": "krummlegend",
    "krummlegender": "krummlegend",
    "krummlegendere": "krummlegend",
    "krummlegenderem": "krummlegend",
    "krummlegenderen": "krummlegend",
    "krummlegenderer": "krummlegend",
    "krummlegenderes": "krummlegend",
    "krummlegendes": "krummlegend",
    "krummlegendste": "krummlegend",
    "krummlegendstem": "krummlegend",
    "krummlegendsten": "krummlegend",
    "krummlegendster": "krummlegend",
    "krummlegendstes": "krummlegend",
    "krummlegest": "krummlegen",
    "krummleget": "krummlegen",
    "krummlegst": "krummlegen",
    "krummlegt": "krummlegen",
    "krummlegte": "krummlegen",
    "krummlegten": "krummlegen",
    "krummlegtest": "krummlegen",
    "krummlegtet": "krummlegen",
    "krummnahm": "krummnehmen",
    "krummnahmen": "krummnehmen",
    "krummnahmst": "krummnehmen",
    "krummnahmt": "krummnehmen",
    "krummnehme": "krummnehmen",
    "krummnehmend": "krummnehmen",
    "krummnehmende": "krummnehmend",
    "krummnehmendem": "krummnehmend",
    "krummnehmenden": "krummnehmend",
    "krummnehmender": "krummnehmend",
    "krummnehmendes": "krummnehmend",
    "krummnehmest": "krummnehmen",
    "krummnehmet": "krummnehmen",
    "krummnehmt": "krummnehmen",
    "krummnimmst": "krummnehmen",
    "krummnimmt": "krummnehmen",
    "krummnähme": "krummnehmen",
    "krummnähmen": "krummnehmen",
    "krummnähmest": "krummnehmen",
    "krummnähmet": "krummnehmen",
    "krummzubiegen": "krummbiegen",
    "krummzulachen": "krummlachen",
    "krummzulegen": "krummlegen",
    "krummzunehmen": "krummnehmen",
    "kryptischem": "kryptisch",
    "kryptischen": "kryptisch",
    "kryptischer": "kryptisch",
    "kryptischere": "kryptisch",
    "kryptischerem": "kryptisch",
    "kryptischeren": "kryptisch",
    "kryptischerer": "kryptisch",
    "kryptischeres": "kryptisch",
    "kryptisches": "kryptisch",
    "kryptischste": "kryptisch",
    "kryptischstem": "kryptisch",
    "kryptischsten": "kryptisch",
    "kryptischster": "kryptisch",
    "kryptischstes": "kryptisch",
    "krächze": "krächzen",
    "krächzend": "krächzen",
    "krächzende": "krächzend",
    "krächzendem": "krächzend",
    "krächzenden": "krächzend",
    "krächzender": "krächzend",
    "krächzendere": "krächzend",
    "krächzenderem": "krächzend",
    "krächzenderen": "krächzend",
    "krächzenderer": "krächzend",
    "krächzenderes": "krächzend",
    "krächzendes": "krächzend",
    "krächzendste": "krächzend",
    "krächzendstem": "krächzend",
    "krächzendsten": "krächzend",
    "krächzendster": "krächzend",
    "krächzendstes": "krächzend",
    "krächzest": "krächzen",
    "krächzet": "krächzen",
    "krächzt": "krächzen",
    "krächzte": "krächzen",
    "krächzten": "krächzen",
    "krächztest": "krächzen",
    "krächztet": "krächzen",
    "kräftig": "kräftigen",
    "kräftige": "kräftig",
    "kräftigem": "kräftig",
    "kräftigen": "kräftig",
    "kräftigend": "kräftigen",
    "kräftigende": "kräftigend",
    "kräftigendem": "kräftigend",
    "kräftigenden": "kräftigend",
    "kräftigender": "kräftigend",
    "kräftigendes": "kräftigend",
    "kräftiger": "kräftig",
    "kräftigere": "kräftig",
    "kräftigerem": "kräftig",
    "kräftigeren": "kräftig",
    "kräftigerer": "kräftig",
    "kräftigeres": "kräftig",
    "kräftiges": "kräftig",
    "kräftigest": "kräftigen",
    "kräftiget": "kräftigen",
    "kräftigst": "kräftigen",
    "kräftigste": "kräftig",
    "kräftigstem": "kräftig",
    "kräftigsten": "kräftig",
    "kräftigster": "kräftig",
    "kräftigstes": "kräftig",
    "kräftigt": "kräftigen",
    "kräftigte": "kräftigen",
    "kräftigten": "kräftigen",
    "kräftigtest": "kräftigen",
    "kräftigtet": "kräftigen",
    "krähe": "krähen",
    "krähend": "krähen",
    "krähende": "krähend",
    "krähendem": "krähend",
    "krähenden": "krähend",
    "krähender": "krähend",
    "krähendes": "krähend",
    "krähest": "krähen",
    "krähet": "krähen",
    "krähst": "krähen",
    "kräht": "krähen",
    "krähte": "krähen",
    "krähten": "krähen",
    "krähtest": "krähen",
    "krähtet": "krähen",
    "kränkliche": "kränklich",
    "kränklichem": "kränklich",
    "kränklichen": "kränklich",
    "kränklicher": "kränklich",
    "kränklichere": "kränklich",
    "kränklicherem": "kränklich",
    "kränklicheren": "kränklich",
    "kränklicherer": "kränklich",
    "kränklicheres": "kränklich",
    "kränkliches": "kränklich",
    "kränklichste": "kränklich",
    "kränklichstem": "kränklich",
    "kränklichsten": "kränklich",
    "kränklichster": "kränklich",
    "kränklichstes": "kränklich",
    "kränzend": "kränzen",
    "kränzende": "kränzend",
    "kränzendem": "kränzend",
    "kränzenden": "kränzend",
    "kränzender": "kränzend",
    "kränzendes": "kränzend",
    "kränzest": "kränzen",
    "kränzet": "kränzen",
    "kränzt": "kränzen",
    "kränzte": "kränzen",
    "kränzten": "kränzen",
    "kränztest": "kränzen",
    "kränztet": "kränzen",
    "kräusele": "kräuseln",
    "kräuselnd": "kräuseln",
    "kräuselnde": "kräuselnd",
    "kräuselndem": "kräuselnd",
    "kräuselnden": "kräuselnd",
    "kräuselnder": "kräuselnd",
    "kräuselndere": "kräuselnd",
    "kräuselnderem": "kräuselnd",
    "kräuselnderen": "kräuselnd",
    "kräuselnderer": "kräuselnd",
    "kräuselnderes": "kräuselnd",
    "kräuselndes": "kräuselnd",
    "kräuselndste": "kräuselnd",
    "kräuselndstem": "kräuselnd",
    "kräuselndsten": "kräuselnd",
    "kräuselndster": "kräuselnd",
    "kräuselndstes": "kräuselnd",
    "kräuselst": "kräuseln",
    "kräuselt": "kräuseln",
    "kräuselte": "kräuseln",
    "kräuselten": "kräuseln",
    "kräuseltest": "kräuseln",
    "kräuseltet": "kräuseln",
    "kräusle": "kräuseln",
    "kröche": "kriechen",
    "kröchen": "kriechen",
    "kröchest": "kriechen",
    "kröchet": "kriechen",
    "kröne": "krönen",
    "krönend": "krönen",
    "krönende": "krönend",
    "krönendem": "krönend",
    "krönenden": "krönend",
    "krönender": "krönend",
    "krönendes": "krönend",
    "krönest": "krönen",
    "krönet": "krönen",
    "krönst": "krönen",
    "krönt": "krönen",
    "krönte": "krönen",
    "krönten": "krönen",
    "kröntest": "krönen",
    "kröntet": "krönen",
    "krümele": "krümeln",
    "krümelige": "krümelig",
    "krümeligem": "krümelig",
    "krümeligen": "krümelig",
    "krümeliger": "krümelig",
    "krümeligere": "krümelig",
    "krümeligerem": "krümelig",
    "krümeligeren": "krümelig",
    "krümeligerer": "krümelig",
    "krümeligeres": "krümelig",
    "krümeliges": "krümelig",
    "krümeligste": "krümelig",
    "krümeligstem": "krümelig",
    "krümeligsten": "krümelig",
    "krümeligster": "krümelig",
    "krümeligstes": "krümelig",
    "krümelnd": "krümeln",
    "krümelnde": "krümelnd",
    "krümelndem": "krümelnd",
    "krümelnden": "krümelnd",
    "krümelnder": "krümelnd",
    "krümelndere": "krümelnd",
    "krümelnderem": "krümelnd",
    "krümelnderen": "krümelnd",
    "krümelnderer": "krümelnd",
    "krümelnderes": "krümelnd",
    "krümelndes": "krümelnd",
    "krümelndste": "krümelnd",
    "krümelndstem": "krümelnd",
    "krümelndsten": "krümelnd",
    "krümelndster": "krümelnd",
    "krümelndstes": "krümelnd",
    "krümelst": "krümeln",
    "krümelt": "krümeln",
    "krümelte": "krümeln",
    "krümelten": "krümeln",
    "krümeltest": "krümeln",
    "krümeltet": "krümeln",
    "krümle": "krümeln",
    "krümme": "krümmen",
    "krümmend": "krümmen",
    "krümmende": "krümmend",
    "krümmendem": "krümmend",
    "krümmenden": "krümmend",
    "krümmender": "krümmend",
    "krümmendere": "krümmend",
    "krümmenderem": "krümmend",
    "krümmenderen": "krümmend",
    "krümmenderer": "krümmend",
    "krümmenderes": "krümmend",
    "krümmendes": "krümmend",
    "krümmendste": "krümmend",
    "krümmendstem": "krümmend",
    "krümmendsten": "krümmend",
    "krümmendster": "krümmend",
    "krümmendstes": "krümmend",
    "krümmest": "krümmen",
    "krümmet": "krümmen",
    "krümmst": "krümmen",
    "krümmt": "krümmen",
    "krümmte": "krümmen",
    "krümmten": "krümmen",
    "krümmtest": "krümmen",
    "krümmtet": "krümmen",
    "kubanischem": "kubanisch",
    "kubanischen": "kubanisch",
    "kubanischer": "kubanisch",
    "kubanisches": "kubanisch",
    "kubischem": "kubisch",
    "kubischen": "kubisch",
    "kubischer": "kubisch",
    "kubisches": "kubisch",
    "kugele": "kugeln",
    "kugelfeste": "kugelfest",
    "kugelfestem": "kugelfest",
    "kugelfesten": "kugelfest",
    "kugelfester": "kugelfest",
    "kugelfestere": "kugelfest",
    "kugelfesterem": "kugelfest",
    "kugelfesteren": "kugelfest",
    "kugelfesterer": "kugelfest",
    "kugelfesteres": "kugelfest",
    "kugelfestes": "kugelfest",
    "kugelfesteste": "kugelfest",
    "kugelfestestem": "kugelfest",
    "kugelfestesten": "kugelfest",
    "kugelfestester": "kugelfest",
    "kugelfestestes": "kugelfest",
    "kugelige": "kugelig",
    "kugeligem": "kugelig",
    "kugeligen": "kugelig",
    "kugeliger": "kugelig",
    "kugeliges": "kugelig",
    "kugelnd": "kugeln",
    "kugelnde": "kugelnd",
    "kugelndem": "kugelnd",
    "kugelnden": "kugelnd",
    "kugelnder": "kugelnd",
    "kugelndes": "kugelnd",
    "kugelrundem": "kugelrund",
    "kugelrunden": "kugelrund",
    "kugelrunder": "kugelrund",
    "kugelrundes": "kugelrund",
    "kugelsicherem": "kugelsicher",
    "kugelsicheren": "kugelsicher",
    "kugelsicherer": "kugelsicher",
    "kugelsicherere": "kugelsicher",
    "kugelsichererem": "kugelsicher",
    "kugelsichereren": "kugelsicher",
    "kugelsichererer": "kugelsicher",
    "kugelsichereres": "kugelsicher",
    "kugelsicheres": "kugelsicher",
    "kugelsicherste": "kugelsicher",
    "kugelsicherstem": "kugelsicher",
    "kugelsichersten": "kugelsicher",
    "kugelsicherster": "kugelsicher",
    "kugelsicherstes": "kugelsicher",
    "kugelst": "kugeln",
    "kugelt": "kugeln",
    "kugelte": "kugeln",
    "kugelten": "kugeln",
    "kugeltest": "kugeln",
    "kugeltet": "kugeln",
    "kugle": "kugeln",
    "kulantem": "kulant",
    "kulanten": "kulant",
    "kulanter": "kulant",
    "kulantere": "kulant",
    "kulanterem": "kulant",
    "kulanteren": "kulant",
    "kulanterer": "kulant",
    "kulanteres": "kulant",
    "kulantes": "kulant",
    "kulanteste": "kulant",
    "kulantestem": "kulant",
    "kulantesten": "kulant",
    "kulantester": "kulant",
    "kulantestes": "kulant",
    "kulinarische": "kulinarisch",
    "kulinarischem": "kulinarisch",
    "kulinarischen": "kulinarisch",
    "kulinarischer": "kulinarisch",
    "kulinarischere": "kulinarisch",
    "kulinarischerem": "kulinarisch",
    "kulinarischeren": "kulinarisch",
    "kulinarischerer": "kulinarisch",
    "kulinarischeres": "kulinarisch",
    "kulinarisches": "kulinarisch",
    "kulinarischste": "kulinarisch",
    "kulinarischstem": "kulinarisch",
    "kulinarischsten": "kulinarisch",
    "kulinarischster": "kulinarisch",
    "kulinarischstes": "kulinarisch",
    "kultiviere": "kultivieren",
    "kultivierend": "kultivieren",
    "kultivierende": "kultivierend",
    "kultivierendem": "kultivierend",
    "kultivierenden": "kultivierend",
    "kultivierender": "kultivierend",
    "kultivierendere": "kultivierend",
    "kultivierenderem": "kultivierend",
    "kultivierenderen": "kultivierend",
    "kultivierenderer": "kultivierend",
    "kultivierenderes": "kultivierend",
    "kultivierendes": "kultivierend",
    "kultivierendste": "kultivierend",
    "kultivierendstem": "kultivierend",
    "kultivierendsten": "kultivierend",
    "kultivierendster": "kultivierend",
    "kultivierendstes": "kultivierend",
    "kultivierest": "kultivieren",
    "kultivieret": "kultivieren",
    "kultivierst": "kultivieren",
    "kultiviert": "kultivieren",
    "kultivierte": "kultivieren",
    "kultiviertem": "kultiviert",
    "kultivierten": "kultivieren",
    "kultivierter": "kultiviert",
    "kultiviertere": "kultiviert",
    "kultivierterem": "kultiviert",
    "kultivierteren": "kultiviert",
    "kultivierterer": "kultiviert",
    "kultivierteres": "kultiviert",
    "kultiviertes": "kultiviert",
    "kultiviertest": "kultivieren",
    "kultivierteste": "kultiviert",
    "kultiviertestem": "kultiviert",
    "kultiviertesten": "kultiviert",
    "kultiviertester": "kultiviert",
    "kultiviertestes": "kultiviert",
    "kultiviertet": "kultivieren",
    "kulturellem": "kulturell",
    "kulturellen": "kulturell",
    "kultureller": "kulturell",
    "kulturelles": "kulturell",
    "kulturhistorischem": "kulturhistorisch",
    "kulturhistorischen": "kulturhistorisch",
    "kulturhistorischer": "kulturhistorisch",
    "kulturhistorisches": "kulturhistorisch",
    "kumuliere": "kumulieren",
    "kumulierend": "kumulieren",
    "kumulierende": "kumulierend",
    "kumulierendem": "kumulierend",
    "kumulierenden": "kumulierend",
    "kumulierender": "kumulierend",
    "kumulierendes": "kumulierend",
    "kumulierest": "kumulieren",
    "kumulieret": "kumulieren",
    "kumulierst": "kumulieren",
    "kumuliert": "kumulieren",
    "kumulierte": "kumulieren",
    "kumuliertem": "kumuliert",
    "kumulierten": "kumulieren",
    "kumulierter": "kumuliert",
    "kumuliertes": "kumuliert",
    "kumuliertest": "kumulieren",
    "kumuliertet": "kumulieren",
    "kundgab": "kundgeben",
    "kundgaben": "kundgeben",
    "kundgabst": "kundgeben",
    "kundgabt": "kundgeben",
    "kundgebe": "kundgeben",
    "kundgebend": "kundgeben",
    "kundgebende": "kundgebend",
    "kundgebendem": "kundgebend",
    "kundgebenden": "kundgebend",
    "kundgebender": "kundgebend",
    "kundgebendes": "kundgebend",
    "kundgebest": "kundgeben",
    "kundgebet": "kundgeben",
    "kundgebt": "kundgeben",
    "kundgegeben": "kundgeben",
    "kundgegebene": "kundgegeben",
    "kundgegebenem": "kundgegeben",
    "kundgegebenen": "kundgegeben",
    "kundgegebener": "kundgegeben",
    "kundgegebenes": "kundgegeben",
    "kundgibst": "kundgeben",
    "kundgibt": "kundgeben",
    "kundgäbe": "kundgeben",
    "kundgäben": "kundgeben",
    "kundgäbest": "kundgeben",
    "kundgäbet": "kundgeben",
    "kundige": "kundig",
    "kundigem": "kundig",
    "kundigen": "kundig",
    "kundiger": "kundig",
    "kundigere": "kundig",
    "kundigerem": "kundig",
    "kundigeren": "kundig",
    "kundigerer": "kundig",
    "kundigeres": "kundig",
    "kundiges": "kundig",
    "kundigste": "kundig",
    "kundigstem": "kundig",
    "kundigsten": "kundig",
    "kundigster": "kundig",
    "kundigstes": "kundig",
    "kundschafte": "kundschaften",
    "kundschaftend": "kundschaften",
    "kundschaftende": "kundschaftend",
    "kundschaftendem": "kundschaftend",
    "kundschaftenden": "kundschaftend",
    "kundschaftender": "kundschaftend",
    "kundschaftendes": "kundschaftend",
    "kundschaftest": "kundschaften",
    "kundschaftet": "kundschaften",
    "kundschaftete": "kundschaften",
    "kundschafteten": "kundschaften",
    "kundschaftetest": "kundschaften",
    "kundschaftetet": "kundschaften",
    "kundzugeben": "kundgeben",
    "kungele": "kungeln",
    "kungelnd": "kungeln",
    "kungelnde": "kungelnd",
    "kungelndem": "kungelnd",
    "kungelnden": "kungelnd",
    "kungelnder": "kungelnd",
    "kungelndere": "kungelnd",
    "kungelnderem": "kungelnd",
    "kungelnderen": "kungelnd",
    "kungelnderer": "kungelnd",
    "kungelnderes": "kungelnd",
    "kungelndes": "kungelnd",
    "kungelndste": "kungelnd",
    "kungelndstem": "kungelnd",
    "kungelndsten": "kungelnd",
    "kungelndster": "kungelnd",
    "kungelndstes": "kungelnd",
    "kungelst": "kungeln",
    "kungelt": "kungeln",
    "kungelte": "kungeln",
    "kungelten": "kungeln",
    "kungeltest": "kungeln",
    "kungeltet": "kungeln",
    "kungle": "kungeln",
    "kunstgerechtem": "kunstgerecht",
    "kunstgerechten": "kunstgerecht",
    "kunstgerechter": "kunstgerecht",
    "kunstgerechtes": "kunstgerecht",
    "kunstvollem": "kunstvoll",
    "kunstvollen": "kunstvoll",
    "kunstvoller": "kunstvoll",
    "kunstvollere": "kunstvoll",
    "kunstvollerem": "kunstvoll",
    "kunstvolleren": "kunstvoll",
    "kunstvollerer": "kunstvoll",
    "kunstvolleres": "kunstvoll",
    "kunstvolles": "kunstvoll",
    "kunstvollste": "kunstvoll",
    "kunstvollstem": "kunstvoll",
    "kunstvollsten": "kunstvoll",
    "kunstvollster": "kunstvoll",
    "kunstvollstes": "kunstvoll",
    "kuppele": "kuppeln",
    "kuppelnd": "kuppeln",
    "kuppelnde": "kuppelnd",
    "kuppelndem": "kuppelnd",
    "kuppelnden": "kuppelnd",
    "kuppelnder": "kuppelnd",
    "kuppelndes": "kuppelnd",
    "kuppelst": "kuppeln",
    "kuppelt": "kuppeln",
    "kuppelte": "kuppeln",
    "kuppelten": "kuppeln",
    "kuppeltest": "kuppeln",
    "kuppeltet": "kuppeln",
    "kupple": "kuppeln",
    "kupplerische": "kupplerisch",
    "kupplerischem": "kupplerisch",
    "kupplerischen": "kupplerisch",
    "kupplerischer": "kupplerisch",
    "kupplerisches": "kupplerisch",
    "kurbele": "kurbeln",
    "kurbelnd": "kurbeln",
    "kurbelnde": "kurbelnd",
    "kurbelndem": "kurbelnd",
    "kurbelnden": "kurbelnd",
    "kurbelnder": "kurbelnd",
    "kurbelndere": "kurbelnd",
    "kurbelnderem": "kurbelnd",
    "kurbelnderen": "kurbelnd",
    "kurbelnderer": "kurbelnd",
    "kurbelnderes": "kurbelnd",
    "kurbelndes": "kurbelnd",
    "kurbelndste": "kurbelnd",
    "kurbelndstem": "kurbelnd",
    "kurbelndsten": "kurbelnd",
    "kurbelndster": "kurbelnd",
    "kurbelndstes": "kurbelnd",
    "kurbelst": "kurbeln",
    "kurbelt": "kurbeln",
    "kurbelte": "kurbeln",
    "kurbelten": "kurbeln",
    "kurbeltest": "kurbeln",
    "kurbeltet": "kurbeln",
    "kurble": "kurbeln",
    "kurdischem": "kurdisch",
    "kurdischen": "kurdisch",
    "kurdischer": "kurdisch",
    "kurdisches": "kurdisch",
    "kurfürstlichem": "kurfürstlich",
    "kurfürstlichen": "kurfürstlich",
    "kurfürstlicher": "kurfürstlich",
    "kurfürstliches": "kurfürstlich",
    "kurierend": "kurieren",
    "kurierende": "kurierend",
    "kurierendem": "kurierend",
    "kurierenden": "kurierend",
    "kurierender": "kurierend",
    "kurierendes": "kurierend",
    "kurierest": "kurieren",
    "kurieret": "kurieren",
    "kurierst": "kurieren",
    "kuriert": "kurieren",
    "kurierte": "kurieren",
    "kuriertem": "kuriert",
    "kurierten": "kurieren",
    "kurierter": "kuriert",
    "kuriertes": "kuriert",
    "kuriertest": "kurieren",
    "kuriertet": "kurieren",
    "kuriose": "kurios",
    "kuriosem": "kurios",
    "kuriosen": "kurios",
    "kurioser": "kurios",
    "kuriosere": "kurios",
    "kurioserem": "kurios",
    "kurioseren": "kurios",
    "kurioserer": "kurios",
    "kurioseres": "kurios",
    "kurioses": "kurios",
    "kurioseste": "kurios",
    "kuriosestem": "kurios",
    "kuriosesten": "kurios",
    "kuriosester": "kurios",
    "kuriosestes": "kurios",
    "kursiere": "kursieren",
    "kursierend": "kursieren",
    "kursierende": "kursierend",
    "kursierendem": "kursierend",
    "kursierenden": "kursierend",
    "kursierender": "kursierend",
    "kursierendere": "kursierend",
    "kursierenderem": "kursierend",
    "kursierenderen": "kursierend",
    "kursierenderer": "kursierend",
    "kursierenderes": "kursierend",
    "kursierendes": "kursierend",
    "kursierendste": "kursierend",
    "kursierendstem": "kursierend",
    "kursierendsten": "kursierend",
    "kursierendster": "kursierend",
    "kursierendstes": "kursierend",
    "kursierest": "kursieren",
    "kursieret": "kursieren",
    "kursierst": "kursieren",
    "kursiert": "kursieren",
    "kursierte": "kursieren",
    "kursiertem": "kursiert",
    "kursierten": "kursieren",
    "kursierter": "kursiert",
    "kursiertes": "kursiert",
    "kursiertest": "kursieren",
    "kursiertet": "kursieren",
    "kursive": "kursiv",
    "kursivem": "kursiv",
    "kursiven": "kursiv",
    "kursiver": "kursiv",
    "kursives": "kursiv",
    "kursorische": "kursorisch",
    "kursorischem": "kursorisch",
    "kursorischen": "kursorisch",
    "kursorischer": "kursorisch",
    "kursorisches": "kursorisch",
    "kurvend": "kurven",
    "kurvende": "kurvend",
    "kurvendem": "kurvend",
    "kurvenden": "kurvend",
    "kurvender": "kurvend",
    "kurvendes": "kurvend",
    "kurvest": "kurven",
    "kurvet": "kurven",
    "kurvige": "kurvig",
    "kurvigem": "kurvig",
    "kurvigen": "kurvig",
    "kurviger": "kurvig",
    "kurvigere": "kurvig",
    "kurvigerem": "kurvig",
    "kurvigeren": "kurvig",
    "kurvigerer": "kurvig",
    "kurvigeres": "kurvig",
    "kurviges": "kurvig",
    "kurvigste": "kurvig",
    "kurvigstem": "kurvig",
    "kurvigsten": "kurvig",
    "kurvigster": "kurvig",
    "kurvigstes": "kurvig",
    "kurvst": "kurven",
    "kurvt": "kurven",
    "kurvte": "kurven",
    "kurvten": "kurven",
    "kurvtest": "kurven",
    "kurvtet": "kurven",
    "kurzarbeite": "kurzarbeiten",
    "kurzarbeitend": "kurzarbeiten",
    "kurzarbeitende": "kurzarbeitend",
    "kurzarbeitendem": "kurzarbeitend",
    "kurzarbeitenden": "kurzarbeitend",
    "kurzarbeitender": "kurzarbeitend",
    "kurzarbeitendes": "kurzarbeitend",
    "kurzarbeitest": "kurzarbeiten",
    "kurzarbeitet": "kurzarbeiten",
    "kurzarbeitete": "kurzarbeiten",
    "kurzarbeiteten": "kurzarbeiten",
    "kurzarbeitetest": "kurzarbeiten",
    "kurzarbeitetet": "kurzarbeiten",
    "kurzatmige": "kurzatmig",
    "kurzatmigem": "kurzatmig",
    "kurzatmigen": "kurzatmig",
    "kurzatmiger": "kurzatmig",
    "kurzatmiges": "kurzatmig",
    "kurzem": "kurz",
    "kurzen": "kurz",
    "kurzer": "kurz",
    "kurzes": "kurz",
    "kurzfristige": "kurzfristig",
    "kurzfristigem": "kurzfristig",
    "kurzfristigen": "kurzfristig",
    "kurzfristiger": "kurzfristig",
    "kurzfristigere": "kurzfristig",
    "kurzfristigerem": "kurzfristig",
    "kurzfristigeren": "kurzfristig",
    "kurzfristigerer": "kurzfristig",
    "kurzfristigeres": "kurzfristig",
    "kurzfristiges": "kurzfristig",
    "kurzfristigste": "kurzfristig",
    "kurzfristigstem": "kurzfristig",
    "kurzfristigsten": "kurzfristig",
    "kurzfristigster": "kurzfristig",
    "kurzfristigstes": "kurzfristig",
    "kurzgearbeitet": "kurzarbeiten",
    "kurzgearbeitete": "kurzgearbeitet",
    "kurzgearbeitetem": "kurzgearbeitet",
    "kurzgearbeiteten": "kurzgearbeitet",
    "kurzgearbeiteter": "kurzgearbeitet",
    "kurzgearbeitetes": "kurzgearbeitet",
    "kurzgehalten": "kurzhalten",
    "kurzgehaltene": "kurzgehalten",
    "kurzgehaltenem": "kurzgehalten",
    "kurzgehaltenen": "kurzgehalten",
    "kurzgehaltener": "kurzgehalten",
    "kurzgehaltenere": "kurzgehalten",
    "kurzgehaltenerem": "kurzgehalten",
    "kurzgehalteneren": "kurzgehalten",
    "kurzgehaltenerer": "kurzgehalten",
    "kurzgehalteneres": "kurzgehalten",
    "kurzgehaltenes": "kurzgehalten",
    "kurzgehaltenste": "kurzgehalten",
    "kurzgehaltenstem": "kurzgehalten",
    "kurzgehaltensten": "kurzgehalten",
    "kurzgehaltenster": "kurzgehalten",
    "kurzgehaltenstes": "kurzgehalten",
    "kurzgeschlossen": "kurzschließen",
    "kurzgeschlossene": "kurzgeschlossen",
    "kurzgeschlossenem": "kurzgeschlossen",
    "kurzgeschlossenen": "kurzgeschlossen",
    "kurzgeschlossener": "kurzgeschlossen",
    "kurzgeschlossenes": "kurzgeschlossen",
    "kurzhalte": "kurzhalten",
    "kurzhaltend": "kurzhalten",
    "kurzhaltende": "kurzhaltend",
    "kurzhaltendem": "kurzhaltend",
    "kurzhaltenden": "kurzhaltend",
    "kurzhaltender": "kurzhaltend",
    "kurzhaltendere": "kurzhaltend",
    "kurzhaltenderem": "kurzhaltend",
    "kurzhaltenderen": "kurzhaltend",
    "kurzhaltenderer": "kurzhaltend",
    "kurzhaltenderes": "kurzhaltend",
    "kurzhaltendes": "kurzhaltend",
    "kurzhaltendste": "kurzhaltend",
    "kurzhaltendstem": "kurzhaltend",
    "kurzhaltendsten": "kurzhaltend",
    "kurzhaltendster": "kurzhaltend",
    "kurzhaltendstes": "kurzhaltend",
    "kurzhaltest": "kurzhalten",
    "kurzhaltet": "kurzhalten",
    "kurzhielt": "kurzhalten",
    "kurzhielte": "kurzhalten",
    "kurzhielten": "kurzhalten",
    "kurzhieltest": "kurzhalten",
    "kurzhieltet": "kurzhalten",
    "kurzhält": "kurzhalten",
    "kurzhältst": "kurzhalten",
    "kurzlebige": "kurzlebig",
    "kurzlebigem": "kurzlebig",
    "kurzlebigen": "kurzlebig",
    "kurzlebiger": "kurzlebig",
    "kurzlebigere": "kurzlebig",
    "kurzlebigerem": "kurzlebig",
    "kurzlebigeren": "kurzlebig",
    "kurzlebigerer": "kurzlebig",
    "kurzlebigeres": "kurzlebig",
    "kurzlebiges": "kurzlebig",
    "kurzlebigste": "kurzlebig",
    "kurzlebigstem": "kurzlebig",
    "kurzlebigsten": "kurzlebig",
    "kurzlebigster": "kurzlebig",
    "kurzlebigstes": "kurzlebig",
    "kurzschließe": "kurzschließen",
    "kurzschließend": "kurzschließen",
    "kurzschließende": "kurzschließend",
    "kurzschließendem": "kurzschließend",
    "kurzschließenden": "kurzschließend",
    "kurzschließender": "kurzschließend",
    "kurzschließendes": "kurzschließend",
    "kurzschließest": "kurzschließen",
    "kurzschließet": "kurzschließen",
    "kurzschließt": "kurzschließen",
    "kurzschlossen": "kurzschließen",
    "kurzschloß": "kurzschließen",
    "kurzschloßt": "kurzschließen",
    "kurzschlösse": "kurzschließen",
    "kurzschlössen": "kurzschließen",
    "kurzschlössest": "kurzschließen",
    "kurzschlösset": "kurzschließen",
    "kurzsichtige": "kurzsichtig",
    "kurzsichtigem": "kurzsichtig",
    "kurzsichtigen": "kurzsichtig",
    "kurzsichtiger": "kurzsichtig",
    "kurzsichtigere": "kurzsichtig",
    "kurzsichtigerem": "kurzsichtig",
    "kurzsichtigeren": "kurzsichtig",
    "kurzsichtigerer": "kurzsichtig",
    "kurzsichtigeres": "kurzsichtig",
    "kurzsichtiges": "kurzsichtig",
    "kurzsichtigste": "kurzsichtig",
    "kurzsichtigstem": "kurzsichtig",
    "kurzsichtigsten": "kurzsichtig",
    "kurzsichtigster": "kurzsichtig",
    "kurzsichtigstes": "kurzsichtig",
    "kurzweiligem": "kurzweilig",
    "kurzweiligen": "kurzweilig",
    "kurzweiliger": "kurzweilig",
    "kurzweiligere": "kurzweilig",
    "kurzweiligerem": "kurzweilig",
    "kurzweiligeren": "kurzweilig",
    "kurzweiligerer": "kurzweilig",
    "kurzweiligeres": "kurzweilig",
    "kurzweiliges": "kurzweilig",
    "kurzweiligste": "kurzweilig",
    "kurzweiligstem": "kurzweilig",
    "kurzweiligsten": "kurzweilig",
    "kurzweiligster": "kurzweilig",
    "kurzweiligstes": "kurzweilig",
    "kurzzeitigem": "kurzzeitig",
    "kurzzeitigen": "kurzzeitig",
    "kurzzeitiger": "kurzzeitig",
    "kurzzeitiges": "kurzzeitig",
    "kurzzuarbeiten": "kurzarbeiten",
    "kurzzuhalten": "kurzhalten",
    "kurzzuschließen": "kurzschließen",
    "kurzärmlige": "kurzärmlig",
    "kurzärmligem": "kurzärmlig",
    "kurzärmligen": "kurzärmlig",
    "kurzärmliger": "kurzärmlig",
    "kurzärmliges": "kurzärmlig",
    "kusche": "kuschen",
    "kuschele": "kuscheln",
    "kuschelnd": "kuscheln",
    "kuschelnde": "kuschelnd",
    "kuschelndem": "kuschelnd",
    "kuschelnden": "kuschelnd",
    "kuschelnder": "kuschelnd",
    "kuschelndere": "kuschelnd",
    "kuschelnderem": "kuschelnd",
    "kuschelnderen": "kuschelnd",
    "kuschelnderer": "kuschelnd",
    "kuschelnderes": "kuschelnd",
    "kuschelndes": "kuschelnd",
    "kuschelndste": "kuschelnd",
    "kuschelndstem": "kuschelnd",
    "kuschelndsten": "kuschelnd",
    "kuschelndster": "kuschelnd",
    "kuschelndstes": "kuschelnd",
    "kuschelst": "kuscheln",
    "kuschelt": "kuscheln",
    "kuschelte": "kuscheln",
    "kuschelten": "kuscheln",
    "kuscheltest": "kuscheln",
    "kuscheltet": "kuscheln",
    "kuschend": "kuschen",
    "kuschende": "kuschend",
    "kuschendem": "kuschend",
    "kuschenden": "kuschend",
    "kuschender": "kuschend",
    "kuschendes": "kuschend",
    "kuschest": "kuschen",
    "kuschet": "kuschen",
    "kuschle": "kuscheln",
    "kuschst": "kuschen",
    "kuscht": "kuschen",
    "kuschte": "kuschen",
    "kuschten": "kuschen",
    "kuschtest": "kuschen",
    "kuschtet": "kuschen",
    "kutschiere": "kutschieren",
    "kutschierend": "kutschieren",
    "kutschierende": "kutschierend",
    "kutschierendem": "kutschierend",
    "kutschierenden": "kutschierend",
    "kutschierender": "kutschierend",
    "kutschierendes": "kutschierend",
    "kutschierest": "kutschieren",
    "kutschieret": "kutschieren",
    "kutschierst": "kutschieren",
    "kutschiert": "kutschieren",
    "kutschierte": "kutschieren",
    "kutschiertem": "kutschiert",
    "kutschierten": "kutschieren",
    "kutschierter": "kutschiert",
    "kutschiertes": "kutschiert",
    "kutschiertest": "kutschieren",
    "kutschiertet": "kutschieren",
    "kußechte": "kußecht",
    "kußechtem": "kußecht",
    "kußechten": "kußecht",
    "kußechter": "kußecht",
    "kußechtes": "kußecht",
    "kußfeste": "kußfest",
    "kußfestem": "kußfest",
    "kußfesten": "kußfest",
    "kußfester": "kußfest",
    "kußfestes": "kußfest",
    "kybernetischem": "kybernetisch",
    "kybernetischen": "kybernetisch",
    "kybernetischer": "kybernetisch",
    "kybernetisches": "kybernetisch",
    "kyrillische": "kyrillisch",
    "kyrillischem": "kyrillisch",
    "kyrillischen": "kyrillisch",
    "kyrillischer": "kyrillisch",
    "kyrillisches": "kyrillisch",
    "kälter": "kalt",
    "kältere": "kalt",
    "kälterem": "kalt",
    "kälteren": "kalt",
    "kälterer": "kalt",
    "kälteres": "kalt",
    "kälteste": "kalt",
    "kältestem": "kalt",
    "kältesten": "kalt",
    "kältester": "kalt",
    "kältestes": "kalt",
    "käme": "kommen",
    "kämen": "kommen",
    "kämest": "kommen",
    "kämet": "kommen",
    "kämmend": "kämmen",
    "kämmende": "kämmend",
    "kämmendem": "kämmend",
    "kämmenden": "kämmend",
    "kämmender": "kämmend",
    "kämmendes": "kämmend",
    "kämmest": "kämmen",
    "kämmet": "kämmen",
    "kämmst": "kämmen",
    "kämmt": "kämmen",
    "kämmte": "kämmen",
    "kämmten": "kämmen",
    "kämmtest": "kämmen",
    "kämmtet": "kämmen",
    "kämpfend": "kämpfen",
    "kämpfende": "kämpfend",
    "kämpfendem": "kämpfend",
    "kämpfenden": "kämpfend",
    "kämpfender": "kämpfend",
    "kämpfendere": "kämpfend",
    "kämpfenderem": "kämpfend",
    "kämpfenderen": "kämpfend",
    "kämpfenderer": "kämpfend",
    "kämpfenderes": "kämpfend",
    "kämpfendes": "kämpfend",
    "kämpfendste": "kämpfend",
    "kämpfendstem": "kämpfend",
    "kämpfendsten": "kämpfend",
    "kämpfendster": "kämpfend",
    "kämpfendstes": "kämpfend",
    "kämpferischem": "kämpferisch",
    "kämpferischen": "kämpferisch",
    "kämpferischer": "kämpferisch",
    "kämpferischere": "kämpferisch",
    "kämpferischerem": "kämpferisch",
    "kämpferischeren": "kämpferisch",
    "kämpferischerer": "kämpferisch",
    "kämpferischeres": "kämpferisch",
    "kämpferisches": "kämpferisch",
    "kämpferischste": "kämpferisch",
    "kämpferischstem": "kämpferisch",
    "kämpferischsten": "kämpferisch",
    "kämpferischster": "kämpferisch",
    "kämpferischstes": "kämpferisch",
    "kämpfest": "kämpfen",
    "kämpfet": "kämpfen",
    "kämpfst": "kämpfen",
    "kämpft": "kämpfen",
    "kämpfte": "kämpfen",
    "kämpften": "kämpfen",
    "kämpftest": "kämpfen",
    "kämpftet": "kämpfen",
    "kärger": "karg",
    "kärgere": "karg",
    "kärgerem": "karg",
    "kärgeren": "karg",
    "kärgerer": "karg",
    "kärgeres": "karg",
    "kärgliche": "kärglich",
    "kärglichem": "kärglich",
    "kärglichen": "kärglich",
    "kärglicher": "kärglich",
    "kärglichere": "kärglich",
    "kärglicherem": "kärglich",
    "kärglicheren": "kärglich",
    "kärglicherer": "kärglich",
    "kärglicheres": "kärglich",
    "kärgliches": "kärglich",
    "kärglichste": "kärglich",
    "kärglichstem": "kärglich",
    "kärglichsten": "kärglich",
    "kärglichster": "kärglich",
    "kärglichstes": "kärglich",
    "kärgste": "karg",
    "kärgstem": "karg",
    "kärgsten": "karg",
    "kärgster": "karg",
    "kärgstes": "karg",
    "käsigem": "käsig",
    "käsigen": "käsig",
    "käsiger": "käsig",
    "käsigere": "käsig",
    "käsigerem": "käsig",
    "käsigeren": "käsig",
    "käsigerer": "käsig",
    "käsigeres": "käsig",
    "käsiges": "käsig",
    "käsigste": "käsig",
    "käsigstem": "käsig",
    "käsigsten": "käsig",
    "käsigster": "käsig",
    "käsigstes": "käsig",
    "käue": "käuen",
    "käuend": "käuen",
    "käuendem": "käuend",
    "käuender": "käuend",
    "käuendes": "käuend",
    "käuest": "käuen",
    "käuet": "käuen",
    "käufliche": "käuflich",
    "käuflichem": "käuflich",
    "käuflichen": "käuflich",
    "käuflicher": "käuflich",
    "käuflichere": "käuflich",
    "käuflicherem": "käuflich",
    "käuflicheren": "käuflich",
    "käuflicherer": "käuflich",
    "käuflicheres": "käuflich",
    "käufliches": "käuflich",
    "käuflichste": "käuflich",
    "käuflichstem": "käuflich",
    "käuflichsten": "käuflich",
    "käuflichster": "käuflich",
    "käuflichstes": "käuflich",
    "käust": "käuen",
    "käut": "käuen",
    "käute": "käuen",
    "käuten": "käuen",
    "käutest": "käuen",
    "käutet": "käuen",
    "ködere": "ködern",
    "ködernd": "ködern",
    "ködernde": "ködernd",
    "köderndem": "ködernd",
    "ködernden": "ködernd",
    "ködernder": "ködernd",
    "köderndes": "ködernd",
    "köderst": "ködern",
    "ködert": "ködern",
    "köderte": "ködern",
    "köderten": "ködern",
    "ködertest": "ködern",
    "ködertet": "ködern",
    "kölnischem": "kölnisch",
    "kölnischen": "kölnisch",
    "kölnischer": "kölnisch",
    "kölnisches": "kölnisch",
    "kölschem": "kölsch",
    "kölschen": "kölsch",
    "kölscher": "kölsch",
    "kölschere": "kölsch",
    "kölscherem": "kölsch",
    "kölscheren": "kölsch",
    "kölscherer": "kölsch",
    "kölscheres": "kölsch",
    "kölsches": "kölsch",
    "kölscheste": "kölsch",
    "kölschestem": "kölsch",
    "kölschesten": "kölsch",
    "kölschester": "kölsch",
    "kölschestes": "kölsch",
    "königlichem": "königlich",
    "königlichen": "königlich",
    "königlicher": "königlich",
    "königlichere": "königlich",
    "königlicherem": "königlich",
    "königlicheren": "königlich",
    "königlicherer": "königlich",
    "königlicheres": "königlich",
    "königliches": "königlich",
    "königlichste": "königlich",
    "königlichstem": "königlich",
    "königlichsten": "königlich",
    "königlichster": "königlich",
    "königlichstes": "königlich",
    "königstreuem": "königstreu",
    "königstreuen": "königstreu",
    "königstreuer": "königstreu",
    "königstreuere": "königstreu",
    "königstreuerem": "königstreu",
    "königstreueren": "königstreu",
    "königstreuerer": "königstreu",
    "königstreueres": "königstreu",
    "königstreues": "königstreu",
    "königstreueste": "königstreu",
    "königstreuestem": "königstreu",
    "königstreuesten": "königstreu",
    "königstreuester": "königstreu",
    "königstreuestes": "königstreu",
    "könne": "können",
    "könnest": "können",
    "könnet": "können",
    "könnt": "können",
    "könnte": "können",
    "könnten": "können",
    "könntest": "können",
    "könntet": "können",
    "köpfend": "köpfen",
    "köpfende": "köpfend",
    "köpfendem": "köpfend",
    "köpfenden": "köpfend",
    "köpfender": "köpfend",
    "köpfendes": "köpfend",
    "köpfest": "köpfen",
    "köpfet": "köpfen",
    "köpfst": "köpfen",
    "köpft": "köpfen",
    "köpfte": "köpfen",
    "köpften": "köpfen",
    "köpftest": "köpfen",
    "köpftet": "köpfen",
    "körnigem": "körnig",
    "körnigen": "körnig",
    "körniger": "körnig",
    "körnigere": "körnig",
    "körnigerem": "körnig",
    "körnigeren": "körnig",
    "körnigerer": "körnig",
    "körnigeres": "körnig",
    "körniges": "körnig",
    "körnigste": "körnig",
    "körnigstem": "körnig",
    "körnigsten": "körnig",
    "körnigster": "körnig",
    "körnigstes": "körnig",
    "körpereigenem": "körpereigen",
    "körpereigenen": "körpereigen",
    "körpereigener": "körpereigen",
    "körpereigenes": "körpereigen",
    "körperliche": "körperlich",
    "körperlichem": "körperlich",
    "körperlichen": "körperlich",
    "körperlicher": "körperlich",
    "körperliches": "körperlich",
    "köstlichem": "köstlich",
    "köstlichen": "köstlich",
    "köstlicher": "köstlich",
    "köstlichere": "köstlich",
    "köstlicherem": "köstlich",
    "köstlicheren": "köstlich",
    "köstlicherer": "köstlich",
    "köstlicheres": "köstlich",
    "köstliches": "köstlich",
    "köstlichstem": "köstlich",
    "köstlichsten": "köstlich",
    "köstlichster": "köstlich",
    "köstlichstes": "köstlich",
    "kübele": "kübeln",
    "kübelnd": "kübeln",
    "kübelnde": "kübelnd",
    "kübelndem": "kübelnd",
    "kübelnden": "kübelnd",
    "kübelnder": "kübelnd",
    "kübelndere": "kübelnd",
    "kübelnderem": "kübelnd",
    "kübelnderen": "kübelnd",
    "kübelnderer": "kübelnd",
    "kübelnderes": "kübelnd",
    "kübelndes": "kübelnd",
    "kübelndste": "kübelnd",
    "kübelndstem": "kübelnd",
    "kübelndsten": "kübelnd",
    "kübelndster": "kübelnd",
    "kübelndstes": "kübelnd",
    "kübelst": "kübeln",
    "kübelt": "kübeln",
    "kübelte": "kübeln",
    "kübelten": "kübeln",
    "kübeltest": "kübeln",
    "kübeltet": "kübeln",
    "küble": "kübeln",
    "kühl": "kühlen",
    "kühle": "kühl",
    "kühlem": "kühl",
    "kühlend": "kühlen",
    "kühlende": "kühlend",
    "kühlendem": "kühlend",
    "kühlenden": "kühlend",
    "kühlender": "kühlend",
    "kühlendere": "kühlend",
    "kühlenderem": "kühlend",
    "kühlenderen": "kühlend",
    "kühlenderer": "kühlend",
    "kühlenderes": "kühlend",
    "kühlendes": "kühlend",
    "kühlendste": "kühlend",
    "kühlendstem": "kühlend",
    "kühlendsten": "kühlend",
    "kühlendster": "kühlend",
    "kühlendstes": "kühlend",
    "kühler": "kühl",
    "kühlere": "kühl",
    "kühlerem": "kühl",
    "kühleren": "kühl",
    "kühlerer": "kühl",
    "kühleres": "kühl",
    "kühles": "kühl",
    "kühlest": "kühlen",
    "kühlet": "kühlen",
    "kühlst": "kühlen",
    "kühlste": "kühl",
    "kühlstem": "kühl",
    "kühlsten": "kühl",
    "kühlster": "kühl",
    "kühlstes": "kühl",
    "kühlt": "kühlen",
    "kühlte": "kühlen",
    "kühlten": "kühlen",
    "kühltest": "kühlen",
    "kühltet": "kühlen",
    "kühnem": "kühn",
    "kühnen": "kühn",
    "kühner": "kühn",
    "kühnere": "kühn",
    "kühnerem": "kühn",
    "kühneren": "kühn",
    "kühnerer": "kühn",
    "kühneres": "kühn",
    "kühnes": "kühn",
    "kühnste": "kühn",
    "kühnstem": "kühn",
    "kühnsten": "kühn",
    "kühnster": "kühn",
    "kühnstes": "kühn",
    "kümmere": "kümmern",
    "kümmerliche": "kümmerlich",
    "kümmerlichem": "kümmerlich",
    "kümmerlichen": "kümmerlich",
    "kümmerlicher": "kümmerlich",
    "kümmerlichere": "kümmerlich",
    "kümmerlicherem": "kümmerlich",
    "kümmerlicheren": "kümmerlich",
    "kümmerlicherer": "kümmerlich",
    "kümmerlicheres": "kümmerlich",
    "kümmerliches": "kümmerlich",
    "kümmerlichste": "kümmerlich",
    "kümmerlichstem": "kümmerlich",
    "kümmerlichsten": "kümmerlich",
    "kümmerlichster": "kümmerlich",
    "kümmerlichstes": "kümmerlich",
    "kümmernd": "kümmern",
    "kümmernde": "kümmernd",
    "kümmerndem": "kümmernd",
    "kümmernden": "kümmernd",
    "kümmernder": "kümmernd",
    "kümmerndes": "kümmernd",
    "kümmerst": "kümmern",
    "kümmert": "kümmern",
    "kümmerte": "kümmern",
    "kümmerten": "kümmern",
    "kümmertest": "kümmern",
    "kümmertet": "kümmern",
    "kündbare": "kündbar",
    "kündbarem": "kündbar",
    "kündbaren": "kündbar",
    "kündbarer": "kündbar",
    "kündbares": "kündbar",
    "kündige": "kündigen",
    "kündigend": "kündigen",
    "kündigende": "kündigend",
    "kündigendem": "kündigend",
    "kündigenden": "kündigend",
    "kündigender": "kündigend",
    "kündigendes": "kündigend",
    "kündigest": "kündigen",
    "kündiget": "kündigen",
    "kündigst": "kündigen",
    "kündigt": "kündigen",
    "kündigte": "kündigen",
    "kündigten": "kündigen",
    "kündigtest": "kündigen",
    "kündigtet": "kündigen",
    "künftige": "künftig",
    "künftigem": "künftig",
    "künftigen": "künftig",
    "künftiger": "künftig",
    "künftiges": "künftig",
    "künstlerischem": "künstlerisch",
    "künstlerischen": "künstlerisch",
    "künstlerischer": "künstlerisch",
    "künstlerisches": "künstlerisch",
    "künstlichem": "künstlich",
    "künstlichen": "künstlich",
    "künstlicher": "künstlich",
    "künstlichere": "künstlich",
    "künstlicherem": "künstlich",
    "künstlicheren": "künstlich",
    "künstlicherer": "künstlich",
    "künstlicheres": "künstlich",
    "künstliches": "künstlich",
    "künstlichste": "künstlich",
    "künstlichstem": "künstlich",
    "künstlichsten": "künstlich",
    "künstlichster": "künstlich",
    "künstlichstes": "künstlich",
    "küre": "küren",
    "kürend": "küren",
    "kürende": "kürend",
    "kürendem": "kürend",
    "kürenden": "kürend",
    "kürender": "kürend",
    "kürendes": "kürend",
    "kürest": "küren",
    "küret": "küren",
    "kürst": "küren",
    "kürt": "küren",
    "kürte": "küren",
    "kürten": "küren",
    "kürtest": "küren",
    "kürtet": "küren",
    "kürze": "kürzen",
    "kürzend": "kürzen",
    "kürzende": "kürzend",
    "kürzendem": "kürzend",
    "kürzenden": "kürzend",
    "kürzender": "kürzend",
    "kürzendes": "kürzend",
    "kürzer": "kurz",
    "kürzere": "kurz",
    "kürzerem": "kurz",
    "kürzeren": "kurz",
    "kürzerer": "kurz",
    "kürzeres": "kurz",
    "kürzest": "kürzen",
    "kürzeste": "kurz",
    "kürzestem": "kurz",
    "kürzesten": "kurz",
    "kürzester": "kurz",
    "kürzestes": "kurz",
    "kürzet": "kürzen",
    "kürzliche": "kürzlich",
    "kürzlichem": "kürzlich",
    "kürzlichen": "kürzlich",
    "kürzlicher": "kürzlich",
    "kürzliches": "kürzlich",
    "kürzt": "kürzen",
    "kürzte": "kürzen",
    "kürzten": "kürzen",
    "kürztest": "kürzen",
    "kürztet": "kürzen",
    "küssend": "küssen",
    "küssende": "küssend",
    "küssendem": "küssend",
    "küssenden": "küssend",
    "küssender": "küssend",
    "küssendes": "küssend",
    "küssest": "küssen",
    "küsset": "küssen",
    "küßt": "küssen",
    "küßte": "küssen",
    "küßten": "küssen",
    "küßtest": "küssen",
    "küßtet": "küssen",
    "labbere": "labbern",
    "labberige": "labberig",
    "labberigem": "labberig",
    "labberigen": "labberig",
    "labberiger": "labberig",
    "labberigere": "labberig",
    "labberigerem": "labberig",
    "labberigeren": "labberig",
    "labberigerer": "labberig",
    "labberigeres": "labberig",
    "labberiges": "labberig",
    "labberigste": "labberig",
    "labberigstem": "labberig",
    "labberigsten": "labberig",
    "labberigster": "labberig",
    "labberigstes": "labberig",
    "labbernd": "labbern",
    "labbernde": "labbernd",
    "labberndem": "labbernd",
    "labbernden": "labbernd",
    "labbernder": "labbernd",
    "labberndere": "labbernd",
    "labbernderem": "labbernd",
    "labbernderen": "labbernd",
    "labbernderer": "labbernd",
    "labbernderes": "labbernd",
    "labberndes": "labbernd",
    "labberndste": "labbernd",
    "labberndstem": "labbernd",
    "labberndsten": "labbernd",
    "labberndster": "labbernd",
    "labberndstes": "labbernd",
    "labberst": "labbern",
    "labbert": "labbern",
    "labberte": "labbern",
    "labberten": "labbern",
    "labbertest": "labbern",
    "labbertet": "labbern",
    "labe": "laben",
    "labend": "laben",
    "labende": "labend",
    "labendem": "labend",
    "labenden": "labend",
    "labender": "labend",
    "labendere": "labend",
    "labenderem": "labend",
    "labenderen": "labend",
    "labenderer": "labend",
    "labenderes": "labend",
    "labendes": "labend",
    "labendste": "labend",
    "labendstem": "labend",
    "labendsten": "labend",
    "labendster": "labend",
    "labendstes": "labend",
    "labere": "labern",
    "labernd": "labern",
    "labernde": "labernd",
    "laberndem": "labernd",
    "labernden": "labernd",
    "labernder": "labernd",
    "laberndere": "labernd",
    "labernderem": "labernd",
    "labernderen": "labernd",
    "labernderer": "labernd",
    "labernderes": "labernd",
    "laberndes": "labernd",
    "laberndste": "labernd",
    "laberndstem": "labernd",
    "laberndsten": "labernd",
    "laberndster": "labernd",
    "laberndstes": "labernd",
    "laberst": "labern",
    "labert": "labern",
    "laberte": "labern",
    "laberten": "labern",
    "labertest": "labern",
    "labertet": "labern",
    "labest": "laben",
    "labet": "laben",
    "labile": "labil",
    "labilem": "labil",
    "labilen": "labil",
    "labiler": "labil",
    "labilere": "labil",
    "labilerem": "labil",
    "labileren": "labil",
    "labilerer": "labil",
    "labileres": "labil",
    "labiles": "labil",
    "labilste": "labil",
    "labilstem": "labil",
    "labilsten": "labil",
    "labilster": "labil",
    "labilstes": "labil",
    "laboriere": "laborieren",
    "laborierend": "laborieren",
    "laborierende": "laborierend",
    "laborierendem": "laborierend",
    "laborierenden": "laborierend",
    "laborierender": "laborierend",
    "laborierendere": "laborierend",
    "laborierenderem": "laborierend",
    "laborierenderen": "laborierend",
    "laborierenderer": "laborierend",
    "laborierenderes": "laborierend",
    "laborierendes": "laborierend",
    "laborierendste": "laborierend",
    "laborierendstem": "laborierend",
    "laborierendsten": "laborierend",
    "laborierendster": "laborierend",
    "laborierendstes": "laborierend",
    "laborierest": "laborieren",
    "laborieret": "laborieren",
    "laborierst": "laborieren",
    "laboriert": "laborieren",
    "laborierte": "laborieren",
    "laboriertem": "laboriert",
    "laborierten": "laborieren",
    "laborierter": "laboriert",
    "laboriertere": "laboriert",
    "laborierterem": "laboriert",
    "laborierteren": "laboriert",
    "laborierterer": "laboriert",
    "laborierteres": "laboriert",
    "laboriertes": "laboriert",
    "laboriertest": "laborieren",
    "laborierteste": "laboriert",
    "laboriertestem": "laboriert",
    "laboriertesten": "laboriert",
    "laboriertester": "laboriert",
    "laboriertestes": "laboriert",
    "laboriertet": "laborieren",
    "labst": "laben",
    "labt": "laben",
    "labte": "laben",
    "labten": "laben",
    "labtest": "laben",
    "labtet": "laben",
    "lachend": "lachen",
    "lachende": "lachend",
    "lachendem": "lachend",
    "lachenden": "lachend",
    "lachender": "lachend",
    "lachendere": "lachend",
    "lachenderem": "lachend",
    "lachenderen": "lachend",
    "lachenderer": "lachend",
    "lachenderes": "lachend",
    "lachendes": "lachend",
    "lachendste": "lachend",
    "lachendstem": "lachend",
    "lachendsten": "lachend",
    "lachendster": "lachend",
    "lachendstes": "lachend",
    "lachest": "lachen",
    "lachet": "lachen",
    "lachhafte": "lachhaft",
    "lachhaftem": "lachhaft",
    "lachhaften": "lachhaft",
    "lachhafter": "lachhaft",
    "lachhaftere": "lachhaft",
    "lachhafterem": "lachhaft",
    "lachhafteren": "lachhaft",
    "lachhafterer": "lachhaft",
    "lachhafteres": "lachhaft",
    "lachhaftes": "lachhaft",
    "lachhafteste": "lachhaft",
    "lachhaftestem": "lachhaft",
    "lachhaftesten": "lachhaft",
    "lachhaftester": "lachhaft",
    "lachhaftestes": "lachhaft",
    "lachst": "lachen",
    "lacht": "lachen",
    "lachte": "lachen",
    "lachten": "lachen",
    "lachtest": "lachen",
    "lachtet": "lachen",
    "lackiere": "lackieren",
    "lackierend": "lackieren",
    "lackierende": "lackierend",
    "lackierendem": "lackierend",
    "lackierenden": "lackierend",
    "lackierender": "lackierend",
    "lackierendes": "lackierend",
    "lackierest": "lackieren",
    "lackieret": "lackieren",
    "lackierst": "lackieren",
    "lackiert": "lackieren",
    "lackierte": "lackieren",
    "lackiertem": "lackiert",
    "lackierten": "lackieren",
    "lackierter": "lackiert",
    "lackiertes": "lackiert",
    "lackiertest": "lackieren",
    "lackiertet": "lackieren",
    "ladend": "laden",
    "ladende": "ladend",
    "ladendem": "ladend",
    "ladenden": "ladend",
    "ladender": "ladend",
    "ladendes": "ladend",
    "ladest": "laden",
    "ladet": "laden",
    "lag": "liegen",
    "lagere": "lagern",
    "lagernd": "lagern",
    "lagernde": "lagernd",
    "lagerndem": "lagernd",
    "lagernden": "lagernd",
    "lagernder": "lagernd",
    "lagerndes": "lagernd",
    "lagerst": "lagern",
    "lagert": "lagern",
    "lagerte": "lagern",
    "lagerten": "lagern",
    "lagertest": "lagern",
    "lagertet": "lagern",
    "lagst": "liegen",
    "lagt": "liegen",
    "lahme": "lahmen",
    "lahmend": "lahmen",
    "lahmende": "lahmend",
    "lahmendem": "lahmend",
    "lahmenden": "lahmend",
    "lahmender": "lahmend",
    "lahmendere": "lahmend",
    "lahmenderem": "lahmend",
    "lahmenderen": "lahmend",
    "lahmenderer": "lahmend",
    "lahmenderes": "lahmend",
    "lahmendes": "lahmend",
    "lahmendste": "lahmend",
    "lahmendstem": "lahmend",
    "lahmendsten": "lahmend",
    "lahmendster": "lahmend",
    "lahmendstes": "lahmend",
    "lahmest": "lahmen",
    "lahmet": "lahmen",
    "lahmgelegt": "lahmlegen",
    "lahmgelegte": "lahmgelegt",
    "lahmgelegtem": "lahmgelegt",
    "lahmgelegten": "lahmgelegt",
    "lahmgelegter": "lahmgelegt",
    "lahmgelegtere": "lahmgelegt",
    "lahmgelegterem": "lahmgelegt",
    "lahmgelegteren": "lahmgelegt",
    "lahmgelegterer": "lahmgelegt",
    "lahmgelegteres": "lahmgelegt",
    "lahmgelegtes": "lahmgelegt",
    "lahmgelegteste": "lahmgelegt",
    "lahmgelegtestem": "lahmgelegt",
    "lahmgelegtesten": "lahmgelegt",
    "lahmgelegtester": "lahmgelegt",
    "lahmgelegtestes": "lahmgelegt",
    "lahmlege": "lahmlegen",
    "lahmlegend": "lahmlegen",
    "lahmlegende": "lahmlegend",
    "lahmlegendem": "lahmlegend",
    "lahmlegenden": "lahmlegend",
    "lahmlegender": "lahmlegend",
    "lahmlegendere": "lahmlegend",
    "lahmlegenderem": "lahmlegend",
    "lahmlegenderen": "lahmlegend",
    "lahmlegenderer": "lahmlegend",
    "lahmlegenderes": "lahmlegend",
    "lahmlegendes": "lahmlegend",
    "lahmlegendste": "lahmlegend",
    "lahmlegendstem": "lahmlegend",
    "lahmlegendsten": "lahmlegend",
    "lahmlegendster": "lahmlegend",
    "lahmlegendstes": "lahmlegend",
    "lahmlegest": "lahmlegen",
    "lahmleget": "lahmlegen",
    "lahmlegst": "lahmlegen",
    "lahmlegt": "lahmlegen",
    "lahmlegte": "lahmlegen",
    "lahmlegten": "lahmlegen",
    "lahmlegtest": "lahmlegen",
    "lahmlegtet": "lahmlegen",
    "lahmst": "lahmen",
    "lahmt": "lahmen",
    "lahmte": "lahmen",
    "lahmten": "lahmen",
    "lahmtest": "lahmen",
    "lahmtet": "lahmen",
    "lahmzulegen": "lahmlegen",
    "laienhaftem": "laienhaft",
    "laienhaften": "laienhaft",
    "laienhafter": "laienhaft",
    "laienhaftere": "laienhaft",
    "laienhafterem": "laienhaft",
    "laienhafteren": "laienhaft",
    "laienhafterer": "laienhaft",
    "laienhafteres": "laienhaft",
    "laienhaftes": "laienhaft",
    "laienhafteste": "laienhaft",
    "laienhaftestem": "laienhaft",
    "laienhaftesten": "laienhaft",
    "laienhaftester": "laienhaft",
    "laienhaftestes": "laienhaft",
    "laizistische": "laizistisch",
    "laizistischem": "laizistisch",
    "laizistischen": "laizistisch",
    "laizistischer": "laizistisch",
    "laizistischere": "laizistisch",
    "laizistischerem": "laizistisch",
    "laizistischeren": "laizistisch",
    "laizistischerer": "laizistisch",
    "laizistischeres": "laizistisch",
    "laizistisches": "laizistisch",
    "laizistischste": "laizistisch",
    "laizistischstem": "laizistisch",
    "laizistischsten": "laizistisch",
    "laizistischster": "laizistisch",
    "laizistischstes": "laizistisch",
    "lakonischem": "lakonisch",
    "lakonischen": "lakonisch",
    "lakonischer": "lakonisch",
    "lakonischere": "lakonisch",
    "lakonischerem": "lakonisch",
    "lakonischeren": "lakonisch",
    "lakonischerer": "lakonisch",
    "lakonischeres": "lakonisch",
    "lakonisches": "lakonisch",
    "lakonischste": "lakonisch",
    "lakonischstem": "lakonisch",
    "lakonischsten": "lakonisch",
    "lakonischster": "lakonisch",
    "lakonischstes": "lakonisch",
    "laktiere": "laktieren",
    "laktierend": "laktieren",
    "laktierende": "laktierend",
    "laktierendem": "laktierend",
    "laktierenden": "laktierend",
    "laktierender": "laktierend",
    "laktierendere": "laktierend",
    "laktierenderem": "laktierend",
    "laktierenderen": "laktierend",
    "laktierenderer": "laktierend",
    "laktierenderes": "laktierend",
    "laktierendes": "laktierend",
    "laktierendste": "laktierend",
    "laktierendstem": "laktierend",
    "laktierendsten": "laktierend",
    "laktierendster": "laktierend",
    "laktierendstes": "laktierend",
    "laktierest": "laktieren",
    "laktieret": "laktieren",
    "laktierst": "laktieren",
    "laktiert": "laktieren",
    "laktierte": "laktieren",
    "laktiertem": "laktiert",
    "laktierten": "laktieren",
    "laktierter": "laktiert",
    "laktiertere": "laktiert",
    "laktierterem": "laktiert",
    "laktierteren": "laktiert",
    "laktierterer": "laktiert",
    "laktierteres": "laktiert",
    "laktiertes": "laktiert",
    "laktiertest": "laktieren",
    "laktierteste": "laktiert",
    "laktiertestem": "laktiert",
    "laktiertesten": "laktiert",
    "laktiertester": "laktiert",
    "laktiertestes": "laktiert",
    "laktiertet": "laktieren",
    "lalle": "lallen",
    "lallend": "lallen",
    "lallende": "lallend",
    "lallendem": "lallend",
    "lallenden": "lallend",
    "lallender": "lallend",
    "lallendere": "lallend",
    "lallenderem": "lallend",
    "lallenderen": "lallend",
    "lallenderer": "lallend",
    "lallenderes": "lallend",
    "lallendes": "lallend",
    "lallendste": "lallend",
    "lallendstem": "lallend",
    "lallendsten": "lallend",
    "lallendster": "lallend",
    "lallendstes": "lallend",
    "lallest": "lallen",
    "lallet": "lallen",
    "lallst": "lallen",
    "lallt": "lallen",
    "lallte": "lallen",
    "lallten": "lallen",
    "lalltest": "lallen",
    "lalltet": "lallen",
    "lamentiere": "lamentieren",
    "lamentierend": "lamentieren",
    "lamentierende": "lamentierend",
    "lamentierendem": "lamentierend",
    "lamentierenden": "lamentierend",
    "lamentierender": "lamentierend",
    "lamentierendere": "lamentierend",
    "lamentierenderem": "lamentierend",
    "lamentierenderen": "lamentierend",
    "lamentierenderer": "lamentierend",
    "lamentierenderes": "lamentierend",
    "lamentierendes": "lamentierend",
    "lamentierendste": "lamentierend",
    "lamentierendstem": "lamentierend",
    "lamentierendsten": "lamentierend",
    "lamentierendster": "lamentierend",
    "lamentierendstes": "lamentierend",
    "lamentierest": "lamentieren",
    "lamentieret": "lamentieren",
    "lamentierst": "lamentieren",
    "lamentiert": "lamentieren",
    "lamentierte": "lamentieren",
    "lamentiertem": "lamentiert",
    "lamentierten": "lamentieren",
    "lamentierter": "lamentiert",
    "lamentiertes": "lamentiert",
    "lamentiertest": "lamentieren",
    "lamentiertet": "lamentieren",
    "laminiere": "laminieren",
    "laminierend": "laminieren",
    "laminierende": "laminierend",
    "laminierendem": "laminierend",
    "laminierenden": "laminierend",
    "laminierender": "laminierend",
    "laminierendes": "laminierend",
    "laminierest": "laminieren",
    "laminieret": "laminieren",
    "laminierst": "laminieren",
    "laminiert": "laminieren",
    "laminierte": "laminieren",
    "laminiertem": "laminiert",
    "laminierten": "laminieren",
    "laminierter": "laminiert",
    "laminiertes": "laminiert",
    "laminiertest": "laminieren",
    "laminiertet": "laminieren",
    "lammfrommem": "lammfromm",
    "lammfrommen": "lammfromm",
    "lammfrommer": "lammfromm",
    "lammfrommere": "lammfromm",
    "lammfrommerem": "lammfromm",
    "lammfrommeren": "lammfromm",
    "lammfrommerer": "lammfromm",
    "lammfrommeres": "lammfromm",
    "lammfrommes": "lammfromm",
    "lammfrommste": "lammfromm",
    "lammfrommstem": "lammfromm",
    "lammfrommsten": "lammfromm",
    "lammfrommster": "lammfromm",
    "lammfrommstes": "lammfromm",
    "landend": "landen",
    "landende": "landend",
    "landendem": "landend",
    "landenden": "landend",
    "landender": "landend",
    "landendes": "landend",
    "landest": "landen",
    "landesübliche": "landesüblich",
    "landesüblichem": "landesüblich",
    "landesüblichen": "landesüblich",
    "landesüblicher": "landesüblich",
    "landesübliches": "landesüblich",
    "landet": "landen",
    "landete": "landen",
    "landeten": "landen",
    "landetest": "landen",
    "landetet": "landen",
    "landfremde": "landfremd",
    "landfremdem": "landfremd",
    "landfremden": "landfremd",
    "landfremder": "landfremd",
    "landfremdere": "landfremd",
    "landfremderem": "landfremd",
    "landfremderen": "landfremd",
    "landfremderer": "landfremd",
    "landfremderes": "landfremd",
    "landfremdes": "landfremd",
    "landfremdeste": "landfremd",
    "landfremdestem": "landfremd",
    "landfremdesten": "landfremd",
    "landfremdester": "landfremd",
    "landfremdestes": "landfremd",
    "landläufige": "landläufig",
    "landläufigem": "landläufig",
    "landläufigen": "landläufig",
    "landläufiger": "landläufig",
    "landläufiges": "landläufig",
    "landschaftlichem": "landschaftlich",
    "landschaftlichen": "landschaftlich",
    "landschaftlicher": "landschaftlich",
    "landschaftliches": "landschaftlich",
    "landwirtschaftlichem": "landwirtschaftlich",
    "landwirtschaftlichen": "landwirtschaftlich",
    "landwirtschaftlicher": "landwirtschaftlich",
    "landwirtschaftlichere": "landwirtschaftlich",
    "landwirtschaftlicherem": "landwirtschaftlich",
    "landwirtschaftlicheren": "landwirtschaftlich",
    "landwirtschaftlicherer": "landwirtschaftlich",
    "landwirtschaftlicheres": "landwirtschaftlich",
    "landwirtschaftliches": "landwirtschaftlich",
    "landwirtschaftlichste": "landwirtschaftlich",
    "landwirtschaftlichstem": "landwirtschaftlich",
    "landwirtschaftlichsten": "landwirtschaftlich",
    "landwirtschaftlichster": "landwirtschaftlich",
    "landwirtschaftlichstes": "landwirtschaftlich",
    "lang": "langen",
    "langatmige": "langatmig",
    "langatmigem": "langatmig",
    "langatmigen": "langatmig",
    "langatmiger": "langatmig",
    "langatmigere": "langatmig",
    "langatmigerem": "langatmig",
    "langatmigeren": "langatmig",
    "langatmigerer": "langatmig",
    "langatmigeres": "langatmig",
    "langatmiges": "langatmig",
    "langatmigste": "langatmig",
    "langatmigstem": "langatmig",
    "langatmigsten": "langatmig",
    "langatmigster": "langatmig",
    "langatmigstes": "langatmig",
    "langdrehe": "langdrehen",
    "langdrehend": "langdrehen",
    "langdrehende": "langdrehend",
    "langdrehendem": "langdrehend",
    "langdrehenden": "langdrehend",
    "langdrehender": "langdrehend",
    "langdrehendes": "langdrehend",
    "langdrehest": "langdrehen",
    "langdrehet": "langdrehen",
    "langdrehst": "langdrehen",
    "langdreht": "langdrehen",
    "langdrehte": "langdrehen",
    "langdrehten": "langdrehen",
    "langdrehtest": "langdrehen",
    "langdrehtet": "langdrehen",
    "lange": "lang",
    "langem": "lang",
    "langen": "lang",
    "langend": "langen",
    "langende": "langend",
    "langendem": "langend",
    "langenden": "langend",
    "langender": "langend",
    "langendes": "langend",
    "langer": "lang",
    "langes": "lang",
    "langest": "langen",
    "langet": "langen",
    "langfristige": "langfristig",
    "langfristigem": "langfristig",
    "langfristigen": "langfristig",
    "langfristiger": "langfristig",
    "langfristigere": "langfristig",
    "langfristigerem": "langfristig",
    "langfristigeren": "langfristig",
    "langfristigerer": "langfristig",
    "langfristigeres": "langfristig",
    "langfristiges": "langfristig",
    "langfristigste": "langfristig",
    "langfristigstem": "langfristig",
    "langfristigsten": "langfristig",
    "langfristigster": "langfristig",
    "langfristigstes": "langfristig",
    "langgedreht": "langdrehen",
    "langgedrehte": "langgedreht",
    "langgedrehtem": "langgedreht",
    "langgedrehten": "langgedreht",
    "langgedrehter": "langgedreht",
    "langgedrehtes": "langgedreht",
    "langhaarige": "langhaarig",
    "langhaarigem": "langhaarig",
    "langhaarigen": "langhaarig",
    "langhaariger": "langhaarig",
    "langhaariges": "langhaarig",
    "langjährige": "langjährig",
    "langjährigem": "langjährig",
    "langjährigen": "langjährig",
    "langjähriger": "langjährig",
    "langjähriges": "langjährig",
    "langlebige": "langlebig",
    "langlebigem": "langlebig",
    "langlebigen": "langlebig",
    "langlebiger": "langlebig",
    "langlebigere": "langlebig",
    "langlebigerem": "langlebig",
    "langlebigeren": "langlebig",
    "langlebigerer": "langlebig",
    "langlebigeres": "langlebig",
    "langlebiges": "langlebig",
    "langlebigste": "langlebig",
    "langlebigstem": "langlebig",
    "langlebigsten": "langlebig",
    "langlebigster": "langlebig",
    "langlebigstes": "langlebig",
    "langmütige": "langmütig",
    "langmütigem": "langmütig",
    "langmütigen": "langmütig",
    "langmütiger": "langmütig",
    "langmütigere": "langmütig",
    "langmütigerem": "langmütig",
    "langmütigeren": "langmütig",
    "langmütigerer": "langmütig",
    "langmütigeres": "langmütig",
    "langmütiges": "langmütig",
    "langmütigste": "langmütig",
    "langmütigstem": "langmütig",
    "langmütigsten": "langmütig",
    "langmütigster": "langmütig",
    "langmütigstes": "langmütig",
    "langsame": "langsam",
    "langsamem": "langsam",
    "langsamen": "langsam",
    "langsamer": "langsam",
    "langsamere": "langsam",
    "langsamerem": "langsam",
    "langsameren": "langsam",
    "langsamerer": "langsam",
    "langsameres": "langsam",
    "langsames": "langsam",
    "langsamste": "langsam",
    "langsamstem": "langsam",
    "langsamsten": "langsam",
    "langsamster": "langsam",
    "langsamstes": "langsam",
    "langst": "langen",
    "langstielige": "langstielig",
    "langstieligem": "langstielig",
    "langstieligen": "langstielig",
    "langstieliger": "langstielig",
    "langstieligere": "langstielig",
    "langstieligerem": "langstielig",
    "langstieligeren": "langstielig",
    "langstieligerer": "langstielig",
    "langstieligeres": "langstielig",
    "langstieliges": "langstielig",
    "langstieligste": "langstielig",
    "langstieligstem": "langstielig",
    "langstieligsten": "langstielig",
    "langstieligster": "langstielig",
    "langstieligstes": "langstielig",
    "langt": "langen",
    "langte": "langen",
    "langten": "langen",
    "langtest": "langen",
    "langtet": "langen",
    "langweile": "langweilen",
    "langweilend": "langweilen",
    "langweilende": "langweilend",
    "langweilendem": "langweilend",
    "langweilenden": "langweilend",
    "langweilender": "langweilend",
    "langweilendere": "langweilend",
    "langweilenderem": "langweilend",
    "langweilenderen": "langweilend",
    "langweilenderer": "langweilend",
    "langweilenderes": "langweilend",
    "langweilendes": "langweilend",
    "langweilendste": "langweilend",
    "langweilendstem": "langweilend",
    "langweilendsten": "langweilend",
    "langweilendster": "langweilend",
    "langweilendstes": "langweilend",
    "langweilest": "langweilen",
    "langweilet": "langweilen",
    "langweilige": "langweilig",
    "langweiligem": "langweilig",
    "langweiligen": "langweilig",
    "langweiliger": "langweilig",
    "langweiligere": "langweilig",
    "langweiligerem": "langweilig",
    "langweiligeren": "langweilig",
    "langweiligerer": "langweilig",
    "langweiligeres": "langweilig",
    "langweiliges": "langweilig",
    "langweiligste": "langweilig",
    "langweiligstem": "langweilig",
    "langweiligsten": "langweilig",
    "langweiligster": "langweilig",
    "langweiligstes": "langweilig",
    "langweilst": "langweilen",
    "langweilt": "langweilen",
    "langweilte": "langweilen",
    "langweilten": "langweilen",
    "langweiltest": "langweilen",
    "langweiltet": "langweilen",
    "langwierigem": "langwierig",
    "langwierigen": "langwierig",
    "langwieriger": "langwierig",
    "langwierigere": "langwierig",
    "langwierigerem": "langwierig",
    "langwierigeren": "langwierig",
    "langwierigerer": "langwierig",
    "langwierigeres": "langwierig",
    "langwieriges": "langwierig",
    "langwierigste": "langwierig",
    "langwierigstem": "langwierig",
    "langwierigsten": "langwierig",
    "langwierigster": "langwierig",
    "langwierigstes": "langwierig",
    "langzudrehen": "langdrehen",
    "langärmelige": "langärmelig",
    "langärmeligem": "langärmelig",
    "langärmeligen": "langärmelig",
    "langärmeliger": "langärmelig",
    "langärmeliges": "langärmelig",
    "lapidarem": "lapidar",
    "lapidaren": "lapidar",
    "lapidarer": "lapidar",
    "lapidares": "lapidar",
    "lappend": "lappen",
    "lappende": "lappend",
    "lappendem": "lappend",
    "lappenden": "lappend",
    "lappender": "lappend",
    "lappendes": "lappend",
    "lappest": "lappen",
    "lappet": "lappen",
    "lappige": "lappig",
    "lappigem": "lappig",
    "lappigen": "lappig",
    "lappiger": "lappig",
    "lappigere": "lappig",
    "lappigerem": "lappig",
    "lappigeren": "lappig",
    "lappigerer": "lappig",
    "lappigeres": "lappig",
    "lappiges": "lappig",
    "lappigste": "lappig",
    "lappigstem": "lappig",
    "lappigsten": "lappig",
    "lappigster": "lappig",
    "lappigstes": "lappig",
    "lappst": "lappen",
    "lappt": "lappen",
    "lappte": "lappen",
    "lappten": "lappen",
    "lapptest": "lappen",
    "lapptet": "lappen",
    "las": "lesen",
    "lasche": "lasch",
    "laschem": "lasch",
    "laschen": "lasch",
    "lascher": "lasch",
    "laschere": "lasch",
    "lascherem": "lasch",
    "lascheren": "lasch",
    "lascherer": "lasch",
    "lascheres": "lasch",
    "lasches": "lasch",
    "laschste": "lasch",
    "laschstem": "lasch",
    "laschsten": "lasch",
    "laschster": "lasch",
    "laschstes": "lasch",
    "lasen": "lesen",
    "lasse": "lassen",
    "lassend": "lassen",
    "lassende": "lassend",
    "lassendem": "lassend",
    "lassenden": "lassend",
    "lassender": "lassend",
    "lassendes": "lassend",
    "lassest": "lassen",
    "lasset": "lassen",
    "last": "lesen",
    "laste": "lasten",
    "lastend": "lasten",
    "lastende": "lastend",
    "lastendem": "lastend",
    "lastenden": "lastend",
    "lastender": "lastend",
    "lastendes": "lastend",
    "lasterhaftem": "lasterhaft",
    "lasterhaften": "lasterhaft",
    "lasterhafter": "lasterhaft",
    "lasterhaftere": "lasterhaft",
    "lasterhafterem": "lasterhaft",
    "lasterhafteren": "lasterhaft",
    "lasterhafterer": "lasterhaft",
    "lasterhafteres": "lasterhaft",
    "lasterhaftes": "lasterhaft",
    "lasterhafteste": "lasterhaft",
    "lasterhaftestem": "lasterhaft",
    "lasterhaftesten": "lasterhaft",
    "lasterhaftester": "lasterhaft",
    "lasterhaftestes": "lasterhaft",
    "lastest": "lasten",
    "lastet": "lasten",
    "lastete": "lasten",
    "lasteten": "lasten",
    "lastetest": "lasten",
    "lastetet": "lasten",
    "lateinamerikanischem": "lateinamerikanisch",
    "lateinamerikanischen": "lateinamerikanisch",
    "lateinamerikanischer": "lateinamerikanisch",
    "lateinamerikanisches": "lateinamerikanisch",
    "lateinischem": "lateinisch",
    "lateinischen": "lateinisch",
    "lateinischer": "lateinisch",
    "lateinisches": "lateinisch",
    "latentem": "latent",
    "latenten": "latent",
    "latenter": "latent",
    "latentere": "latent",
    "latenterem": "latent",
    "latenteren": "latent",
    "latenterer": "latent",
    "latenteres": "latent",
    "latentes": "latent",
    "latenteste": "latent",
    "latentestem": "latent",
    "latentesten": "latent",
    "latentester": "latent",
    "latentestes": "latent",
    "laterale": "lateral",
    "lateralem": "lateral",
    "lateralen": "lateral",
    "lateraler": "lateral",
    "laterales": "lateral",
    "latsche": "latschen",
    "latschend": "latschen",
    "latschende": "latschend",
    "latschendem": "latschend",
    "latschenden": "latschend",
    "latschender": "latschend",
    "latschendes": "latschend",
    "latschest": "latschen",
    "latschet": "latschen",
    "latschst": "latschen",
    "latscht": "latschen",
    "latschte": "latschen",
    "latschten": "latschen",
    "latschtest": "latschen",
    "latschtet": "latschen",
    "lauem": "lau",
    "lauen": "lau",
    "lauer": "lauern",
    "lauere": "lau",
    "lauerem": "lau",
    "laueren": "lau",
    "lauerer": "lau",
    "laueres": "lau",
    "lauernd": "lauern",
    "lauernde": "lauernd",
    "lauerndem": "lauernd",
    "lauernden": "lauernd",
    "lauernder": "lauernd",
    "lauerndere": "lauernd",
    "lauernderem": "lauernd",
    "lauernderen": "lauernd",
    "lauernderer": "lauernd",
    "lauernderes": "lauernd",
    "lauerndes": "lauernd",
    "lauerndste": "lauernd",
    "lauerndstem": "lauernd",
    "lauerndsten": "lauernd",
    "lauerndster": "lauernd",
    "lauerndstes": "lauernd",
    "lauerst": "lauern",
    "lauert": "lauern",
    "lauerte": "lauern",
    "lauerten": "lauern",
    "lauertest": "lauern",
    "lauertet": "lauern",
    "laues": "lau",
    "laueste": "lau",
    "lauestem": "lau",
    "lauesten": "lau",
    "lauester": "lau",
    "lauestes": "lau",
    "laufend": "laufen",
    "laufende": "laufend",
    "laufendem": "laufend",
    "laufenden": "laufend",
    "laufender": "laufend",
    "laufendes": "laufend",
    "laufest": "laufen",
    "laufet": "laufen",
    "lauffähige": "lauffähig",
    "lauffähigem": "lauffähig",
    "lauffähigen": "lauffähig",
    "lauffähiger": "lauffähig",
    "lauffähigere": "lauffähig",
    "lauffähigerem": "lauffähig",
    "lauffähigeren": "lauffähig",
    "lauffähigerer": "lauffähig",
    "lauffähigeres": "lauffähig",
    "lauffähiges": "lauffähig",
    "lauffähigste": "lauffähig",
    "lauffähigstem": "lauffähig",
    "lauffähigsten": "lauffähig",
    "lauffähigster": "lauffähig",
    "lauffähigstes": "lauffähig",
    "lauft": "laufen",
    "laugend": "laugen",
    "laugende": "laugend",
    "laugendem": "laugend",
    "laugenden": "laugend",
    "laugender": "laugend",
    "laugendes": "laugend",
    "laugest": "laugen",
    "lauget": "laugen",
    "laugst": "laugen",
    "laugt": "laugen",
    "laugte": "laugen",
    "laugten": "laugen",
    "laugtest": "laugen",
    "laugtet": "laugen",
    "launenhaftem": "launenhaft",
    "launenhaften": "launenhaft",
    "launenhafter": "launenhaft",
    "launenhaftere": "launenhaft",
    "launenhafterem": "launenhaft",
    "launenhafteren": "launenhaft",
    "launenhafterer": "launenhaft",
    "launenhafteres": "launenhaft",
    "launenhaftes": "launenhaft",
    "launenhafteste": "launenhaft",
    "launenhaftestem": "launenhaft",
    "launenhaftesten": "launenhaft",
    "launenhaftester": "launenhaft",
    "launenhaftestes": "launenhaft",
    "launige": "launig",
    "launigem": "launig",
    "launigen": "launig",
    "launiger": "launig",
    "launigere": "launig",
    "launigerem": "launig",
    "launigeren": "launig",
    "launigerer": "launig",
    "launigeres": "launig",
    "launiges": "launig",
    "launigste": "launig",
    "launigstem": "launig",
    "launigsten": "launig",
    "launigster": "launig",
    "launigstes": "launig",
    "launische": "launisch",
    "launischem": "launisch",
    "launischen": "launisch",
    "launischer": "launisch",
    "launischere": "launisch",
    "launischerem": "launisch",
    "launischeren": "launisch",
    "launischerer": "launisch",
    "launischeres": "launisch",
    "launisches": "launisch",
    "launischste": "launisch",
    "launischstem": "launisch",
    "launischsten": "launisch",
    "launischster": "launisch",
    "launischstes": "launisch",
    "lausche": "lauschen",
    "lauschend": "lauschen",
    "lauschende": "lauschend",
    "lauschendem": "lauschend",
    "lauschenden": "lauschend",
    "lauschender": "lauschend",
    "lauschendere": "lauschend",
    "lauschenderem": "lauschend",
    "lauschenderen": "lauschend",
    "lauschenderer": "lauschend",
    "lauschenderes": "lauschend",
    "lauschendes": "lauschend",
    "lauschendste": "lauschend",
    "lauschendstem": "lauschend",
    "lauschendsten": "lauschend",
    "lauschendster": "lauschend",
    "lauschendstes": "lauschend",
    "lauschest": "lauschen",
    "lauschet": "lauschen",
    "lauschige": "lauschig",
    "lauschigem": "lauschig",
    "lauschigen": "lauschig",
    "lauschiger": "lauschig",
    "lauschigere": "lauschig",
    "lauschigerem": "lauschig",
    "lauschigeren": "lauschig",
    "lauschigerer": "lauschig",
    "lauschigeres": "lauschig",
    "lauschiges": "lauschig",
    "lauschigste": "lauschig",
    "lauschigstem": "lauschig",
    "lauschigsten": "lauschig",
    "lauschigster": "lauschig",
    "lauschigstes": "lauschig",
    "lauschst": "lauschen",
    "lauscht": "lauschen",
    "lauschte": "lauschen",
    "lauschten": "lauschen",
    "lauschtest": "lauschen",
    "lauschtet": "lauschen",
    "lause": "lausen",
    "lausend": "lausen",
    "lausende": "lausend",
    "lausendem": "lausend",
    "lausenden": "lausend",
    "lausender": "lausend",
    "lausendere": "lausend",
    "lausenderem": "lausend",
    "lausenderen": "lausend",
    "lausenderer": "lausend",
    "lausenderes": "lausend",
    "lausendes": "lausend",
    "lausendste": "lausend",
    "lausendstem": "lausend",
    "lausendsten": "lausend",
    "lausendster": "lausend",
    "lausendstes": "lausend",
    "lausest": "lausen",
    "lauset": "lausen",
    "lausige": "lausig",
    "lausigem": "lausig",
    "lausigen": "lausig",
    "lausiger": "lausig",
    "lausigere": "lausig",
    "lausigerem": "lausig",
    "lausigeren": "lausig",
    "lausigerer": "lausig",
    "lausigeres": "lausig",
    "lausiges": "lausig",
    "lausigste": "lausig",
    "lausigstem": "lausig",
    "lausigsten": "lausig",
    "lausigster": "lausig",
    "lausigstes": "lausig",
    "laust": "lausen",
    "lauste": "lausen",
    "lausten": "lausen",
    "laustest": "lausen",
    "laustet": "lausen",
    "laute": "laut",
    "lautem": "laut",
    "lauten": "laut",
    "lautend": "lauten",
    "lautende": "lautend",
    "lautendem": "lautend",
    "lautenden": "lautend",
    "lautender": "lautend",
    "lautendes": "lautend",
    "lauter": "laut",
    "lautere": "laut",
    "lauterem": "laut",
    "lauteren": "laut",
    "lauterer": "laut",
    "lauteres": "laut",
    "lautes": "laut",
    "lautest": "lauten",
    "lauteste": "laut",
    "lautestem": "laut",
    "lautesten": "laut",
    "lautester": "laut",
    "lautestes": "laut",
    "lautet": "lauten",
    "lautete": "lauten",
    "lauteten": "lauten",
    "lautetest": "lauten",
    "lautetet": "lauten",
    "lautlose": "lautlos",
    "lautlosem": "lautlos",
    "lautlosen": "lautlos",
    "lautloser": "lautlos",
    "lautlosere": "lautlos",
    "lautloserem": "lautlos",
    "lautloseren": "lautlos",
    "lautloserer": "lautlos",
    "lautloseres": "lautlos",
    "lautloses": "lautlos",
    "lautloseste": "lautlos",
    "lautlosestem": "lautlos",
    "lautlosesten": "lautlos",
    "lautlosester": "lautlos",
    "lautlosestes": "lautlos",
    "lautstarkem": "lautstark",
    "lautstarken": "lautstark",
    "lautstarker": "lautstark",
    "lautstarkes": "lautstark",
    "lauwarme": "lauwarm",
    "lauwarmem": "lauwarm",
    "lauwarmen": "lauwarm",
    "lauwarmer": "lauwarm",
    "lauwarmes": "lauwarm",
    "laxem": "lax",
    "laxen": "lax",
    "laxer": "lax",
    "laxere": "lax",
    "laxerem": "lax",
    "laxeren": "lax",
    "laxerer": "lax",
    "laxeres": "lax",
    "laxes": "lax",
    "laxeste": "lax",
    "laxestem": "lax",
    "laxesten": "lax",
    "laxester": "lax",
    "laxestes": "lax",
    "laß": "lassen",
    "laßt": "lassen",
    "lebe": "leben",
    "lebend": "leben",
    "lebende": "lebend",
    "lebendem": "lebend",
    "lebenden": "lebend",
    "lebender": "lebend",
    "lebendes": "lebend",
    "lebendige": "lebendig",
    "lebendigem": "lebendig",
    "lebendigen": "lebendig",
    "lebendiger": "lebendig",
    "lebendigere": "lebendig",
    "lebendigerem": "lebendig",
    "lebendigeren": "lebendig",
    "lebendigerer": "lebendig",
    "lebendigeres": "lebendig",
    "lebendiges": "lebendig",
    "lebendigste": "lebendig",
    "lebendigstem": "lebendig",
    "lebendigsten": "lebendig",
    "lebendigster": "lebendig",
    "lebendigstes": "lebendig",
    "lebensbedrohlichem": "lebensbedrohlich",
    "lebensbedrohlichen": "lebensbedrohlich",
    "lebensbedrohlicher": "lebensbedrohlich",
    "lebensbedrohlichere": "lebensbedrohlich",
    "lebensbedrohlicherem": "lebensbedrohlich",
    "lebensbedrohlicheren": "lebensbedrohlich",
    "lebensbedrohlicherer": "lebensbedrohlich",
    "lebensbedrohlicheres": "lebensbedrohlich",
    "lebensbedrohliches": "lebensbedrohlich",
    "lebensbedrohlichste": "lebensbedrohlich",
    "lebensbedrohlichstem": "lebensbedrohlich",
    "lebensbedrohlichsten": "lebensbedrohlich",
    "lebensbedrohlichster": "lebensbedrohlich",
    "lebensbedrohlichstes": "lebensbedrohlich",
    "lebensechte": "lebensecht",
    "lebensechtem": "lebensecht",
    "lebensechten": "lebensecht",
    "lebensechter": "lebensecht",
    "lebensechtes": "lebensecht",
    "lebensfreudige": "lebensfreudig",
    "lebensfreudigem": "lebensfreudig",
    "lebensfreudigen": "lebensfreudig",
    "lebensfreudiger": "lebensfreudig",
    "lebensfreudigere": "lebensfreudig",
    "lebensfreudigerem": "lebensfreudig",
    "lebensfreudigeren": "lebensfreudig",
    "lebensfreudigerer": "lebensfreudig",
    "lebensfreudigeres": "lebensfreudig",
    "lebensfreudiges": "lebensfreudig",
    "lebensfreudigste": "lebensfreudig",
    "lebensfreudigstem": "lebensfreudig",
    "lebensfreudigsten": "lebensfreudig",
    "lebensfreudigster": "lebensfreudig",
    "lebensfreudigstes": "lebensfreudig",
    "lebensfrohe": "lebensfroh",
    "lebensfrohem": "lebensfroh",
    "lebensfrohen": "lebensfroh",
    "lebensfroher": "lebensfroh",
    "lebensfrohere": "lebensfroh",
    "lebensfroherem": "lebensfroh",
    "lebensfroheren": "lebensfroh",
    "lebensfroherer": "lebensfroh",
    "lebensfroheres": "lebensfroh",
    "lebensfrohes": "lebensfroh",
    "lebensfroheste": "lebensfroh",
    "lebensfrohestem": "lebensfroh",
    "lebensfrohesten": "lebensfroh",
    "lebensfrohester": "lebensfroh",
    "lebensfrohestes": "lebensfroh",
    "lebensfähige": "lebensfähig",
    "lebensfähigem": "lebensfähig",
    "lebensfähigen": "lebensfähig",
    "lebensfähiger": "lebensfähig",
    "lebensfähigere": "lebensfähig",
    "lebensfähigerem": "lebensfähig",
    "lebensfähigeren": "lebensfähig",
    "lebensfähigerer": "lebensfähig",
    "lebensfähigeres": "lebensfähig",
    "lebensfähiges": "lebensfähig",
    "lebensfähigste": "lebensfähig",
    "lebensfähigstem": "lebensfähig",
    "lebensfähigsten": "lebensfähig",
    "lebensfähigster": "lebensfähig",
    "lebensfähigstes": "lebensfähig",
    "lebensgefährliche": "lebensgefährlich",
    "lebensgefährlichem": "lebensgefährlich",
    "lebensgefährlichen": "lebensgefährlich",
    "lebensgefährlicher": "lebensgefährlich",
    "lebensgefährlichere": "lebensgefährlich",
    "lebensgefährlicherem": "lebensgefährlich",
    "lebensgefährlicheren": "lebensgefährlich",
    "lebensgefährlicherer": "lebensgefährlich",
    "lebensgefährlicheres": "lebensgefährlich",
    "lebensgefährliches": "lebensgefährlich",
    "lebensgefährlichste": "lebensgefährlich",
    "lebensgefährlichstem": "lebensgefährlich",
    "lebensgefährlichsten": "lebensgefährlich",
    "lebensgefährlichster": "lebensgefährlich",
    "lebensgefährlichstes": "lebensgefährlich",
    "lebensgroße": "lebensgroß",
    "lebensgroßem": "lebensgroß",
    "lebensgroßen": "lebensgroß",
    "lebensgroßer": "lebensgroß",
    "lebensgroßes": "lebensgroß",
    "lebenslange": "lebenslang",
    "lebenslangem": "lebenslang",
    "lebenslangen": "lebenslang",
    "lebenslanger": "lebenslang",
    "lebenslanges": "lebenslang",
    "lebenslustige": "lebenslustig",
    "lebenslustigem": "lebenslustig",
    "lebenslustigen": "lebenslustig",
    "lebenslustiger": "lebenslustig",
    "lebenslustigere": "lebenslustig",
    "lebenslustigerem": "lebenslustig",
    "lebenslustigeren": "lebenslustig",
    "lebenslustigerer": "lebenslustig",
    "lebenslustigeres": "lebenslustig",
    "lebenslustiges": "lebenslustig",
    "lebenslustigste": "lebenslustig",
    "lebenslustigstem": "lebenslustig",
    "lebenslustigsten": "lebenslustig",
    "lebenslustigster": "lebenslustig",
    "lebenslustigstes": "lebenslustig",
    "lebenslängliche": "lebenslänglich",
    "lebenslänglichem": "lebenslänglich",
    "lebenslänglichen": "lebenslänglich",
    "lebenslänglicher": "lebenslänglich",
    "lebenslängliches": "lebenslänglich",
    "lebensmüdem": "lebensmüde",
    "lebensmüden": "lebensmüde",
    "lebensmüder": "lebensmüde",
    "lebensmüdere": "lebensmüde",
    "lebensmüderem": "lebensmüde",
    "lebensmüderen": "lebensmüde",
    "lebensmüderer": "lebensmüde",
    "lebensmüderes": "lebensmüde",
    "lebensmüdes": "lebensmüde",
    "lebensmüdeste": "lebensmüde",
    "lebensmüdestem": "lebensmüde",
    "lebensmüdesten": "lebensmüde",
    "lebensmüdester": "lebensmüde",
    "lebensmüdestes": "lebensmüde",
    "lebensnotwendige": "lebensnotwendig",
    "lebensnotwendigem": "lebensnotwendig",
    "lebensnotwendigen": "lebensnotwendig",
    "lebensnotwendiger": "lebensnotwendig",
    "lebensnotwendigere": "lebensnotwendig",
    "lebensnotwendigerem": "lebensnotwendig",
    "lebensnotwendigeren": "lebensnotwendig",
    "lebensnotwendigerer": "lebensnotwendig",
    "lebensnotwendigeres": "lebensnotwendig",
    "lebensnotwendiges": "lebensnotwendig",
    "lebensnotwendigste": "lebensnotwendig",
    "lebensnotwendigstem": "lebensnotwendig",
    "lebensnotwendigsten": "lebensnotwendig",
    "lebensnotwendigster": "lebensnotwendig",
    "lebensnotwendigstes": "lebensnotwendig",
    "lebenswichtige": "lebenswichtig",
    "lebenswichtigem": "lebenswichtig",
    "lebenswichtigen": "lebenswichtig",
    "lebenswichtiger": "lebenswichtig",
    "lebenswichtiges": "lebenswichtig",
    "lebest": "leben",
    "lebet": "leben",
    "lebhaftem": "lebhaft",
    "lebhaften": "lebhaft",
    "lebhafter": "lebhaft",
    "lebhaftere": "lebhaft",
    "lebhafterem": "lebhaft",
    "lebhafteren": "lebhaft",
    "lebhafterer": "lebhaft",
    "lebhafteres": "lebhaft",
    "lebhaftes": "lebhaft",
    "lebhafteste": "lebhaft",
    "lebhaftestem": "lebhaft",
    "lebhaftesten": "lebhaft",
    "lebhaftester": "lebhaft",
    "lebhaftestes": "lebhaft",
    "leblosem": "leblos",
    "leblosen": "leblos",
    "lebloser": "leblos",
    "leblosere": "leblos",
    "lebloserem": "leblos",
    "lebloseren": "leblos",
    "lebloserer": "leblos",
    "lebloseres": "leblos",
    "lebloses": "leblos",
    "lebloseste": "leblos",
    "leblosestem": "leblos",
    "leblosesten": "leblos",
    "leblosester": "leblos",
    "leblosestes": "leblos",
    "lebst": "leben",
    "lebt": "leben",
    "lebte": "leben",
    "lebten": "leben",
    "lebtest": "leben",
    "lebtet": "leben",
    "leckerem": "lecker",
    "leckeren": "lecker",
    "leckerer": "lecker",
    "leckerere": "lecker",
    "leckererem": "lecker",
    "leckereren": "lecker",
    "leckererer": "lecker",
    "leckereres": "lecker",
    "leckeres": "lecker",
    "leckerste": "lecker",
    "leckerstem": "lecker",
    "leckersten": "lecker",
    "leckerster": "lecker",
    "leckerstes": "lecker",
    "leckgeschlagen": "leckschlagen",
    "leckgeschlagene": "leckgeschlagen",
    "leckgeschlagenem": "leckgeschlagen",
    "leckgeschlagenen": "leckgeschlagen",
    "leckgeschlagener": "leckgeschlagen",
    "leckgeschlagenes": "leckgeschlagen",
    "leckschlage": "leckschlagen",
    "leckschlagend": "leckschlagen",
    "leckschlagende": "leckschlagend",
    "leckschlagendem": "leckschlagend",
    "leckschlagenden": "leckschlagend",
    "leckschlagender": "leckschlagend",
    "leckschlagendes": "leckschlagend",
    "leckschlagest": "leckschlagen",
    "leckschlaget": "leckschlagen",
    "leckschlagt": "leckschlagen",
    "leckschlug": "leckschlagen",
    "leckschlugen": "leckschlagen",
    "leckschlugst": "leckschlagen",
    "leckschlugt": "leckschlagen",
    "leckschlägst": "leckschlagen",
    "leckschlägt": "leckschlagen",
    "leckschlüge": "leckschlagen",
    "leckschlügen": "leckschlagen",
    "leckschlügest": "leckschlagen",
    "leckschlüget": "leckschlagen",
    "leckzuschlagen": "leckschlagen",
    "ledere": "ledern",
    "ledernd": "ledern",
    "ledernde": "ledernd",
    "lederndem": "ledernd",
    "ledernden": "ledernd",
    "ledernder": "ledernd",
    "lederndes": "ledernd",
    "lederst": "ledern",
    "ledert": "ledern",
    "lederte": "ledern",
    "lederten": "ledern",
    "ledertest": "ledern",
    "ledertet": "ledern",
    "ledige": "ledig",
    "ledigem": "ledig",
    "ledigen": "ledig",
    "lediger": "ledig",
    "lediges": "ledig",
    "leer": "leeren",
    "leere": "leer",
    "leerem": "leer",
    "leeren": "leer",
    "leerend": "leeren",
    "leerende": "leerend",
    "leerendem": "leerend",
    "leerenden": "leerend",
    "leerender": "leerend",
    "leerendes": "leerend",
    "leerer": "leer",
    "leerere": "leer",
    "leererem": "leer",
    "leereren": "leer",
    "leererer": "leer",
    "leereres": "leer",
    "leeres": "leer",
    "leerest": "leeren",
    "leeret": "leeren",
    "leergestanden": "leerstehen",
    "leergestandene": "leergestanden",
    "leergestandenem": "leergestanden",
    "leergestandenen": "leergestanden",
    "leergestandener": "leergestanden",
    "leergestandenes": "leergestanden",
    "leerst": "leeren",
    "leerstand": "leerstehen",
    "leerstanden": "leerstehen",
    "leerstandest": "leerstehen",
    "leerstandet": "leerstehen",
    "leerste": "leer",
    "leerstehe": "leerstehen",
    "leerstehend": "leerstehen",
    "leerstehende": "leerstehend",
    "leerstehendem": "leerstehend",
    "leerstehenden": "leerstehend",
    "leerstehender": "leerstehend",
    "leerstehendes": "leerstehend",
    "leerstehest": "leerstehen",
    "leerstehet": "leerstehen",
    "leerstehst": "leerstehen",
    "leersteht": "leerstehen",
    "leerstem": "leer",
    "leersten": "leer",
    "leerster": "leer",
    "leerstes": "leer",
    "leerstünde": "leerstehen",
    "leerstünden": "leerstehen",
    "leerstündest": "leerstehen",
    "leerstündet": "leerstehen",
    "leert": "leeren",
    "leerte": "leeren",
    "leerten": "leeren",
    "leertest": "leeren",
    "leertet": "leeren",
    "leerzustehen": "leerstehen",
    "legalem": "legal",
    "legalen": "legal",
    "legaler": "legal",
    "legales": "legal",
    "legalisiere": "legalisieren",
    "legalisierend": "legalisieren",
    "legalisierende": "legalisierend",
    "legalisierendem": "legalisierend",
    "legalisierenden": "legalisierend",
    "legalisierender": "legalisierend",
    "legalisierendes": "legalisierend",
    "legalisierest": "legalisieren",
    "legalisieret": "legalisieren",
    "legalisierst": "legalisieren",
    "legalisiert": "legalisieren",
    "legalisierte": "legalisieren",
    "legalisiertem": "legalisiert",
    "legalisierten": "legalisieren",
    "legalisierter": "legalisiert",
    "legalisiertes": "legalisiert",
    "legalisiertest": "legalisieren",
    "legalisiertet": "legalisieren",
    "lege": "legen",
    "legend": "legen",
    "legende": "legend",
    "legendem": "legend",
    "legenden": "legend",
    "legender": "legend",
    "legendes": "legend",
    "legendäre": "legendär",
    "legendärem": "legendär",
    "legendären": "legendär",
    "legendärer": "legendär",
    "legendärere": "legendär",
    "legendärerem": "legendär",
    "legendäreren": "legendär",
    "legendärerer": "legendär",
    "legendäreres": "legendär",
    "legendäres": "legendär",
    "legendärste": "legendär",
    "legendärstem": "legendär",
    "legendärsten": "legendär",
    "legendärster": "legendär",
    "legendärstes": "legendär",
    "legest": "legen",
    "leget": "legen",
    "legislativem": "legislativ",
    "legislativen": "legislativ",
    "legislativer": "legislativ",
    "legislatives": "legislativ",
    "legislatorische": "legislatorisch",
    "legislatorischem": "legislatorisch",
    "legislatorischen": "legislatorisch",
    "legislatorischer": "legislatorisch",
    "legislatorisches": "legislatorisch",
    "legitimem": "legitim",
    "legitimen": "legitim",
    "legitimer": "legitim",
    "legitimere": "legitim",
    "legitimerem": "legitim",
    "legitimeren": "legitim",
    "legitimerer": "legitim",
    "legitimeres": "legitim",
    "legitimes": "legitim",
    "legitimiere": "legitimieren",
    "legitimierend": "legitimieren",
    "legitimierende": "legitimierend",
    "legitimierendem": "legitimierend",
    "legitimierenden": "legitimierend",
    "legitimierender": "legitimierend",
    "legitimierendes": "legitimierend",
    "legitimierest": "legitimieren",
    "legitimieret": "legitimieren",
    "legitimierst": "legitimieren",
    "legitimiert": "legitimieren",
    "legitimierte": "legitimieren",
    "legitimiertem": "legitimiert",
    "legitimierten": "legitimieren",
    "legitimierter": "legitimiert",
    "legitimiertes": "legitimiert",
    "legitimiertest": "legitimieren",
    "legitimiertet": "legitimieren",
    "legitimistischem": "legitimistisch",
    "legitimistischen": "legitimistisch",
    "legitimistischer": "legitimistisch",
    "legitimistisches": "legitimistisch",
    "legitimste": "legitim",
    "legitimstem": "legitim",
    "legitimsten": "legitim",
    "legitimster": "legitim",
    "legitimstes": "legitim",
    "legst": "legen",
    "legt": "legen",
    "legte": "legen",
    "legten": "legen",
    "legtest": "legen",
    "legtet": "legen",
    "lehmigem": "lehmig",
    "lehmigen": "lehmig",
    "lehmiger": "lehmig",
    "lehmigere": "lehmig",
    "lehmigerem": "lehmig",
    "lehmigeren": "lehmig",
    "lehmigerer": "lehmig",
    "lehmigeres": "lehmig",
    "lehmiges": "lehmig",
    "lehmigste": "lehmig",
    "lehmigstem": "lehmig",
    "lehmigsten": "lehmig",
    "lehmigster": "lehmig",
    "lehmigstes": "lehmig",
    "lehnend": "lehnen",
    "lehnende": "lehnend",
    "lehnendem": "lehnend",
    "lehnenden": "lehnend",
    "lehnender": "lehnend",
    "lehnendes": "lehnend",
    "lehnest": "lehnen",
    "lehnet": "lehnen",
    "lehnst": "lehnen",
    "lehnt": "lehnen",
    "lehnte": "lehnen",
    "lehnten": "lehnen",
    "lehntest": "lehnen",
    "lehntet": "lehnen",
    "lehrend": "lehren",
    "lehrende": "lehrend",
    "lehrendem": "lehrend",
    "lehrenden": "lehrend",
    "lehrender": "lehrend",
    "lehrendes": "lehrend",
    "lehrest": "lehren",
    "lehret": "lehren",
    "lehrhaftem": "lehrhaft",
    "lehrhaften": "lehrhaft",
    "lehrhafter": "lehrhaft",
    "lehrhaftere": "lehrhaft",
    "lehrhafterem": "lehrhaft",
    "lehrhafteren": "lehrhaft",
    "lehrhafterer": "lehrhaft",
    "lehrhafteres": "lehrhaft",
    "lehrhaftes": "lehrhaft",
    "lehrhafteste": "lehrhaft",
    "lehrhaftestem": "lehrhaft",
    "lehrhaftesten": "lehrhaft",
    "lehrhaftester": "lehrhaft",
    "lehrhaftestes": "lehrhaft",
    "lehrreichem": "lehrreich",
    "lehrreichen": "lehrreich",
    "lehrreicher": "lehrreich",
    "lehrreichere": "lehrreich",
    "lehrreicherem": "lehrreich",
    "lehrreicheren": "lehrreich",
    "lehrreicherer": "lehrreich",
    "lehrreicheres": "lehrreich",
    "lehrreiches": "lehrreich",
    "lehrreichste": "lehrreich",
    "lehrreichstem": "lehrreich",
    "lehrreichsten": "lehrreich",
    "lehrreichster": "lehrreich",
    "lehrreichstes": "lehrreich",
    "lehrst": "lehren",
    "lehrt": "lehren",
    "lehrte": "lehren",
    "lehrten": "lehren",
    "lehrtest": "lehren",
    "lehrtet": "lehren",
    "leibend": "leiben",
    "leibende": "leibend",
    "leibendem": "leibend",
    "leibenden": "leibend",
    "leibender": "leibend",
    "leibendes": "leibend",
    "leibest": "leiben",
    "leibet": "leiben",
    "leiblichem": "leiblich",
    "leiblichen": "leiblich",
    "leiblicher": "leiblich",
    "leibliches": "leiblich",
    "leibst": "leiben",
    "leibt": "leiben",
    "leibte": "leiben",
    "leibten": "leiben",
    "leibtest": "leiben",
    "leibtet": "leiben",
    "leichenblassem": "leichenblaß",
    "leichenblassen": "leichenblaß",
    "leichenblasser": "leichenblaß",
    "leichenblassere": "leichenblaß",
    "leichenblasserem": "leichenblaß",
    "leichenblasseren": "leichenblaß",
    "leichenblasserer": "leichenblaß",
    "leichenblasseres": "leichenblaß",
    "leichenblasses": "leichenblaß",
    "leichenblasseste": "leichenblaß",
    "leichenblassestem": "leichenblaß",
    "leichenblassesten": "leichenblaß",
    "leichenblassester": "leichenblaß",
    "leichenblassestes": "leichenblaß",
    "leichtem": "leicht",
    "leichten": "leicht",
    "leichter": "leicht",
    "leichtere": "leicht",
    "leichterem": "leicht",
    "leichteren": "leicht",
    "leichterer": "leicht",
    "leichteres": "leicht",
    "leichtes": "leicht",
    "leichteste": "leicht",
    "leichtestem": "leicht",
    "leichtesten": "leicht",
    "leichtester": "leicht",
    "leichtestes": "leicht",
    "leichtfertige": "leichtfertig",
    "leichtfertigem": "leichtfertig",
    "leichtfertigen": "leichtfertig",
    "leichtfertiger": "leichtfertig",
    "leichtfertigere": "leichtfertig",
    "leichtfertigerem": "leichtfertig",
    "leichtfertigeren": "leichtfertig",
    "leichtfertigerer": "leichtfertig",
    "leichtfertigeres": "leichtfertig",
    "leichtfertiges": "leichtfertig",
    "leichtfertigste": "leichtfertig",
    "leichtfertigstem": "leichtfertig",
    "leichtfertigsten": "leichtfertig",
    "leichtfertigster": "leichtfertig",
    "leichtfertigstes": "leichtfertig",
    "leichtfüßige": "leichtfüßig",
    "leichtfüßigem": "leichtfüßig",
    "leichtfüßigen": "leichtfüßig",
    "leichtfüßiger": "leichtfüßig",
    "leichtfüßiges": "leichtfüßig",
    "leichtgläubige": "leichtgläubig",
    "leichtgläubigem": "leichtgläubig",
    "leichtgläubigen": "leichtgläubig",
    "leichtgläubiger": "leichtgläubig",
    "leichtgläubigere": "leichtgläubig",
    "leichtgläubigerem": "leichtgläubig",
    "leichtgläubigeren": "leichtgläubig",
    "leichtgläubigerer": "leichtgläubig",
    "leichtgläubigeres": "leichtgläubig",
    "leichtgläubiges": "leichtgläubig",
    "leichtgläubigste": "leichtgläubig",
    "leichtgläubigstem": "leichtgläubig",
    "leichtgläubigsten": "leichtgläubig",
    "leichtgläubigster": "leichtgläubig",
    "leichtgläubigstes": "leichtgläubig",
    "leichtsinnigem": "leichtsinnig",
    "leichtsinnigen": "leichtsinnig",
    "leichtsinniger": "leichtsinnig",
    "leichtsinnigere": "leichtsinnig",
    "leichtsinnigerem": "leichtsinnig",
    "leichtsinnigeren": "leichtsinnig",
    "leichtsinnigerer": "leichtsinnig",
    "leichtsinnigeres": "leichtsinnig",
    "leichtsinniges": "leichtsinnig",
    "leichtsinnigste": "leichtsinnig",
    "leichtsinnigstem": "leichtsinnig",
    "leichtsinnigsten": "leichtsinnig",
    "leichtsinnigster": "leichtsinnig",
    "leichtsinnigstes": "leichtsinnig",
    "leide": "leiden",
    "leidend": "leiden",
    "leidende": "leidend",
    "leidendem": "leidend",
    "leidenden": "leidend",
    "leidender": "leidend",
    "leidendes": "leidend",
    "leidenschaftlichem": "leidenschaftlich",
    "leidenschaftlichen": "leidenschaftlich",
    "leidenschaftlicher": "leidenschaftlich",
    "leidenschaftlichere": "leidenschaftlich",
    "leidenschaftlicherem": "leidenschaftlich",
    "leidenschaftlicheren": "leidenschaftlich",
    "leidenschaftlicherer": "leidenschaftlich",
    "leidenschaftlicheres": "leidenschaftlich",
    "leidenschaftliches": "leidenschaftlich",
    "leidenschaftlichste": "leidenschaftlich",
    "leidenschaftlichstem": "leidenschaftlich",
    "leidenschaftlichsten": "leidenschaftlich",
    "leidenschaftlichster": "leidenschaftlich",
    "leidenschaftlichstes": "leidenschaftlich",
    "leidest": "leiden",
    "leidet": "leiden",
    "leidige": "leidig",
    "leidigem": "leidig",
    "leidigen": "leidig",
    "leidiger": "leidig",
    "leidiges": "leidig",
    "leidliche": "leidlich",
    "leidlichem": "leidlich",
    "leidlichen": "leidlich",
    "leidlicher": "leidlich",
    "leidliches": "leidlich",
    "leidtragende": "leidtragend",
    "leidtragendem": "leidtragend",
    "leidtragenden": "leidtragend",
    "leidtragender": "leidtragend",
    "leidtragendes": "leidtragend",
    "leidvolle": "leidvoll",
    "leidvollem": "leidvoll",
    "leidvollen": "leidvoll",
    "leidvoller": "leidvoll",
    "leidvollere": "leidvoll",
    "leidvollerem": "leidvoll",
    "leidvolleren": "leidvoll",
    "leidvollerer": "leidvoll",
    "leidvolleres": "leidvoll",
    "leidvolles": "leidvoll",
    "leidvollste": "leidvoll",
    "leidvollstem": "leidvoll",
    "leidvollsten": "leidvoll",
    "leidvollster": "leidvoll",
    "leidvollstes": "leidvoll",
    "leiere": "leiern",
    "leiernd": "leiern",
    "leiernde": "leiernd",
    "leierndem": "leiernd",
    "leiernden": "leiernd",
    "leiernder": "leiernd",
    "leierndere": "leiernd",
    "leiernderem": "leiernd",
    "leiernderen": "leiernd",
    "leiernderer": "leiernd",
    "leiernderes": "leiernd",
    "leierndes": "leiernd",
    "leierndste": "leiernd",
    "leierndstem": "leiernd",
    "leierndsten": "leiernd",
    "leierndster": "leiernd",
    "leierndstes": "leiernd",
    "leierst": "leiern",
    "leiert": "leiern",
    "leierte": "leiern",
    "leierten": "leiern",
    "leiertest": "leiern",
    "leiertet": "leiern",
    "leihe": "leihen",
    "leihend": "leihen",
    "leihende": "leihend",
    "leihendem": "leihend",
    "leihenden": "leihend",
    "leihender": "leihend",
    "leihendes": "leihend",
    "leihest": "leihen",
    "leihet": "leihen",
    "leihst": "leihen",
    "leiht": "leihen",
    "leime": "leimen",
    "leimend": "leimen",
    "leimende": "leimend",
    "leimendem": "leimend",
    "leimenden": "leimend",
    "leimender": "leimend",
    "leimendes": "leimend",
    "leimest": "leimen",
    "leimet": "leimen",
    "leimst": "leimen",
    "leimt": "leimen",
    "leimte": "leimen",
    "leimten": "leimen",
    "leimtest": "leimen",
    "leimtet": "leimen",
    "leine": "leinen",
    "leinend": "leinen",
    "leinende": "leinend",
    "leinendem": "leinend",
    "leinenden": "leinend",
    "leinender": "leinend",
    "leinendes": "leinend",
    "leinest": "leinen",
    "leinet": "leinen",
    "leinst": "leinen",
    "leint": "leinen",
    "leinte": "leinen",
    "leinten": "leinen",
    "leintest": "leinen",
    "leintet": "leinen",
    "leisem": "leise",
    "leisen": "leise",
    "leiser": "leise",
    "leisere": "leise",
    "leiserem": "leise",
    "leiseren": "leise",
    "leiserer": "leise",
    "leiseres": "leise",
    "leises": "leise",
    "leiseste": "leise",
    "leisestem": "leise",
    "leisesten": "leise",
    "leisester": "leise",
    "leisestes": "leise",
    "leiste": "leisten",
    "leistend": "leisten",
    "leistende": "leistend",
    "leistendem": "leistend",
    "leistenden": "leistend",
    "leistender": "leistend",
    "leistendere": "leistend",
    "leistenderem": "leistend",
    "leistenderen": "leistend",
    "leistenderer": "leistend",
    "leistenderes": "leistend",
    "leistendes": "leistend",
    "leistendste": "leistend",
    "leistendstem": "leistend",
    "leistendsten": "leistend",
    "leistendster": "leistend",
    "leistendstes": "leistend",
    "leistest": "leisten",
    "leistet": "leisten",
    "leistete": "leisten",
    "leisteten": "leisten",
    "leistetest": "leisten",
    "leistetet": "leisten",
    "leistungsfähigem": "leistungsfähig",
    "leistungsfähigen": "leistungsfähig",
    "leistungsfähiger": "leistungsfähig",
    "leistungsfähigere": "leistungsfähig",
    "leistungsfähigerem": "leistungsfähig",
    "leistungsfähigeren": "leistungsfähig",
    "leistungsfähigerer": "leistungsfähig",
    "leistungsfähigeres": "leistungsfähig",
    "leistungsfähiges": "leistungsfähig",
    "leistungsfähigste": "leistungsfähig",
    "leistungsfähigstem": "leistungsfähig",
    "leistungsfähigsten": "leistungsfähig",
    "leistungsfähigster": "leistungsfähig",
    "leistungsfähigstes": "leistungsfähig",
    "leistungsorientierte": "leistungsorientiert",
    "leistungsorientiertem": "leistungsorientiert",
    "leistungsorientierten": "leistungsorientiert",
    "leistungsorientierter": "leistungsorientiert",
    "leistungsorientiertes": "leistungsorientiert",
    "leistungsstarke": "leistungsstark",
    "leistungsstarkem": "leistungsstark",
    "leistungsstarken": "leistungsstark",
    "leistungsstarker": "leistungsstark",
    "leistungsstarkes": "leistungsstark",
    "leistungsstärker": "leistungsstark",
    "leistungsstärkere": "leistungsstark",
    "leistungsstärkerem": "leistungsstark",
    "leistungsstärkeren": "leistungsstark",
    "leistungsstärkerer": "leistungsstark",
    "leistungsstärkeres": "leistungsstark",
    "leistungsstärksten": "leistungsstark",
    "leite": "leiten",
    "leitend": "leiten",
    "leitende": "leitend",
    "leitendem": "leitend",
    "leitenden": "leitend",
    "leitender": "leitend",
    "leitendere": "leitend",
    "leitenderem": "leitend",
    "leitenderen": "leitend",
    "leitenderer": "leitend",
    "leitenderes": "leitend",
    "leitendes": "leitend",
    "leitendste": "leitend",
    "leitendstem": "leitend",
    "leitendsten": "leitend",
    "leitendster": "leitend",
    "leitendstes": "leitend",
    "leitest": "leiten",
    "leitet": "leiten",
    "leitete": "leiten",
    "leiteten": "leiten",
    "leitetest": "leiten",
    "leitetet": "leiten",
    "lemmatisiere": "lemmatisieren",
    "lemmatisierend": "lemmatisieren",
    "lemmatisierende": "lemmatisierend",
    "lemmatisierendem": "lemmatisierend",
    "lemmatisierenden": "lemmatisierend",
    "lemmatisierender": "lemmatisierend",
    "lemmatisierendes": "lemmatisierend",
    "lemmatisierest": "lemmatisieren",
    "lemmatisieret": "lemmatisieren",
    "lemmatisierst": "lemmatisieren",
    "lemmatisiert": "lemmatisieren",
    "lemmatisierte": "lemmatisieren",
    "lemmatisiertem": "lemmatisiert",
    "lemmatisierten": "lemmatisieren",
    "lemmatisierter": "lemmatisiert",
    "lemmatisiertes": "lemmatisiert",
    "lemmatisiertest": "lemmatisieren",
    "lemmatisiertet": "lemmatisieren",
    "lenkbarem": "lenkbar",
    "lenkbaren": "lenkbar",
    "lenkbarer": "lenkbar",
    "lenkbares": "lenkbar",
    "lenke": "lenken",
    "lenkend": "lenken",
    "lenkende": "lenkend",
    "lenkendem": "lenkend",
    "lenkenden": "lenkend",
    "lenkender": "lenkend",
    "lenkendes": "lenkend",
    "lenkest": "lenken",
    "lenket": "lenken",
    "lenkst": "lenken",
    "lenkt": "lenken",
    "lenkte": "lenken",
    "lenkten": "lenken",
    "lenktest": "lenken",
    "lenktet": "lenken",
    "lernbarem": "lernbar",
    "lernbaren": "lernbar",
    "lernbarer": "lernbar",
    "lernbares": "lernbar",
    "lernbegierige": "lernbegierig",
    "lernbegierigem": "lernbegierig",
    "lernbegierigen": "lernbegierig",
    "lernbegieriger": "lernbegierig",
    "lernbegierigere": "lernbegierig",
    "lernbegierigerem": "lernbegierig",
    "lernbegierigeren": "lernbegierig",
    "lernbegierigerer": "lernbegierig",
    "lernbegierigeres": "lernbegierig",
    "lernbegieriges": "lernbegierig",
    "lernbegierigste": "lernbegierig",
    "lernbegierigstem": "lernbegierig",
    "lernbegierigsten": "lernbegierig",
    "lernbegierigster": "lernbegierig",
    "lernbegierigstes": "lernbegierig",
    "lernbehinderte": "lernbehindert",
    "lernbehindertem": "lernbehindert",
    "lernbehinderten": "lernbehindert",
    "lernbehinderter": "lernbehindert",
    "lernbehindertes": "lernbehindert",
    "lerne": "lernen",
    "lerneifrige": "lerneifrig",
    "lerneifrigem": "lerneifrig",
    "lerneifrigen": "lerneifrig",
    "lerneifriger": "lerneifrig",
    "lerneifrigere": "lerneifrig",
    "lerneifrigerem": "lerneifrig",
    "lerneifrigeren": "lerneifrig",
    "lerneifrigerer": "lerneifrig",
    "lerneifrigeres": "lerneifrig",
    "lerneifriges": "lerneifrig",
    "lerneifrigste": "lerneifrig",
    "lerneifrigstem": "lerneifrig",
    "lerneifrigsten": "lerneifrig",
    "lerneifrigster": "lerneifrig",
    "lerneifrigstes": "lerneifrig",
    "lernend": "lernen",
    "lernende": "lernend",
    "lernendem": "lernend",
    "lernenden": "lernend",
    "lernender": "lernend",
    "lernendes": "lernend",
    "lernest": "lernen",
    "lernet": "lernen",
    "lernst": "lernen",
    "lernt": "lernen",
    "lernte": "lernen",
    "lernten": "lernen",
    "lerntest": "lernen",
    "lerntet": "lernen",
    "lesbischem": "lesbisch",
    "lesbischen": "lesbisch",
    "lesbischer": "lesbisch",
    "lesbisches": "lesbisch",
    "lese": "lesen",
    "lesefreudigem": "lesefreudig",
    "lesefreudigen": "lesefreudig",
    "lesefreudiger": "lesefreudig",
    "lesefreudigere": "lesefreudig",
    "lesefreudigerem": "lesefreudig",
    "lesefreudigeren": "lesefreudig",
    "lesefreudigerer": "lesefreudig",
    "lesefreudigeres": "lesefreudig",
    "lesefreudiges": "lesefreudig",
    "lesefreudigste": "lesefreudig",
    "lesefreudigstem": "lesefreudig",
    "lesefreudigsten": "lesefreudig",
    "lesefreudigster": "lesefreudig",
    "lesefreudigstes": "lesefreudig",
    "lesend": "lesen",
    "lesende": "lesend",
    "lesendem": "lesend",
    "lesenden": "lesend",
    "lesender": "lesend",
    "lesendes": "lesend",
    "lesenswertem": "lesenswert",
    "lesenswerten": "lesenswert",
    "lesenswerter": "lesenswert",
    "lesenswertere": "lesenswert",
    "lesenswerterem": "lesenswert",
    "lesenswerteren": "lesenswert",
    "lesenswerterer": "lesenswert",
    "lesenswerteres": "lesenswert",
    "lesenswertes": "lesenswert",
    "lesenswerteste": "lesenswert",
    "lesenswertestem": "lesenswert",
    "lesenswertesten": "lesenswert",
    "lesenswertester": "lesenswert",
    "lesenswertestes": "lesenswert",
    "leserlichem": "leserlich",
    "leserlichen": "leserlich",
    "leserlicher": "leserlich",
    "leserlichere": "leserlich",
    "leserlicherem": "leserlich",
    "leserlicheren": "leserlich",
    "leserlicherer": "leserlich",
    "leserlicheres": "leserlich",
    "leserliches": "leserlich",
    "leserlichste": "leserlich",
    "leserlichstem": "leserlich",
    "leserlichsten": "leserlich",
    "leserlichster": "leserlich",
    "leserlichstes": "leserlich",
    "lesest": "lesen",
    "leset": "lesen",
    "lest": "lesen",
    "lethargischem": "lethargisch",
    "lethargischen": "lethargisch",
    "lethargischer": "lethargisch",
    "lethargisches": "lethargisch",
    "lettische": "lettisch",
    "lettischem": "lettisch",
    "lettischen": "lettisch",
    "lettischer": "lettisch",
    "lettisches": "lettisch",
    "letztem": "letzt",
    "letzten": "letzt",
    "letzter": "letzt",
    "letztere": "letzter",
    "letzterem": "letzter",
    "letzteren": "letzter",
    "letzterer": "letzter",
    "letzteres": "letzter",
    "letztes": "letzt",
    "letztgenannte": "letztgenannt",
    "letztgenanntem": "letztgenannt",
    "letztgenannten": "letztgenannt",
    "letztgenannter": "letztgenannt",
    "letztgenanntes": "letztgenannt",
    "letztjährige": "letztjährig",
    "letztjährigem": "letztjährig",
    "letztjährigen": "letztjährig",
    "letztjähriger": "letztjährig",
    "letztjähriges": "letztjährig",
    "letztliche": "letztlich",
    "letztlichem": "letztlich",
    "letztlichen": "letztlich",
    "letztlicher": "letztlich",
    "letztliches": "letztlich",
    "letztmalige": "letztmalig",
    "letztmaligem": "letztmalig",
    "letztmaligen": "letztmalig",
    "letztmaliger": "letztmalig",
    "letztmaliges": "letztmalig",
    "leuchtend": "leuchten",
    "leuchtende": "leuchtend",
    "leuchtendem": "leuchtend",
    "leuchtenden": "leuchtend",
    "leuchtender": "leuchtend",
    "leuchtendere": "leuchtend",
    "leuchtenderem": "leuchtend",
    "leuchtenderen": "leuchtend",
    "leuchtenderer": "leuchtend",
    "leuchtenderes": "leuchtend",
    "leuchtendes": "leuchtend",
    "leuchtendste": "leuchtend",
    "leuchtendstem": "leuchtend",
    "leuchtendsten": "leuchtend",
    "leuchtendster": "leuchtend",
    "leuchtendstes": "leuchtend",
    "leuchtest": "leuchten",
    "leuchtet": "leuchten",
    "leuchtete": "leuchten",
    "leuchteten": "leuchten",
    "leuchtetest": "leuchten",
    "leuchtetet": "leuchten",
    "leugne": "leugnen",
    "leugnend": "leugnen",
    "leugnende": "leugnend",
    "leugnendem": "leugnend",
    "leugnenden": "leugnend",
    "leugnender": "leugnend",
    "leugnendes": "leugnend",
    "leugnest": "leugnen",
    "leugnet": "leugnen",
    "leugnete": "leugnen",
    "leugneten": "leugnen",
    "leugnetest": "leugnen",
    "leugnetet": "leugnen",
    "lexigraphischem": "lexigraphisch",
    "lexigraphischen": "lexigraphisch",
    "lexigraphischer": "lexigraphisch",
    "lexigraphisches": "lexigraphisch",
    "lexikalischem": "lexikalisch",
    "lexikalischen": "lexikalisch",
    "lexikalischer": "lexikalisch",
    "lexikalisches": "lexikalisch",
    "lexikalisiere": "lexikalisieren",
    "lexikalisierend": "lexikalisieren",
    "lexikalisierende": "lexikalisierend",
    "lexikalisierendem": "lexikalisierend",
    "lexikalisierenden": "lexikalisierend",
    "lexikalisierender": "lexikalisierend",
    "lexikalisierendes": "lexikalisierend",
    "lexikalisierest": "lexikalisieren",
    "lexikalisieret": "lexikalisieren",
    "lexikalisierst": "lexikalisieren",
    "lexikalisiert": "lexikalisieren",
    "lexikalisierte": "lexikalisieren",
    "lexikalisiertem": "lexikalisiert",
    "lexikalisierten": "lexikalisieren",
    "lexikalisierter": "lexikalisiert",
    "lexikalisiertes": "lexikalisiert",
    "lexikalisiertest": "lexikalisieren",
    "lexikalisiertet": "lexikalisieren",
    "lexikographischem": "lexikographisch",
    "lexikographischen": "lexikographisch",
    "lexikographischer": "lexikographisch",
    "lexikographisches": "lexikographisch",
    "libanesischem": "libanesisch",
    "libanesischen": "libanesisch",
    "libanesischer": "libanesisch",
    "libanesisches": "libanesisch",
    "liberalem": "liberal",
    "liberalen": "liberal",
    "liberaler": "liberal",
    "liberalere": "liberal",
    "liberalerem": "liberal",
    "liberaleren": "liberal",
    "liberalerer": "liberal",
    "liberaleres": "liberal",
    "liberales": "liberal",
    "liberalisiere": "liberalisieren",
    "liberalisierend": "liberalisieren",
    "liberalisierende": "liberalisierend",
    "liberalisierendem": "liberalisierend",
    "liberalisierenden": "liberalisierend",
    "liberalisierender": "liberalisierend",
    "liberalisierendes": "liberalisierend",
    "liberalisierest": "liberalisieren",
    "liberalisieret": "liberalisieren",
    "liberalisierst": "liberalisieren",
    "liberalisiert": "liberalisieren",
    "liberalisierte": "liberalisieren",
    "liberalisiertem": "liberalisiert",
    "liberalisierten": "liberalisieren",
    "liberalisierter": "liberalisiert",
    "liberalisiertere": "liberalisiert",
    "liberalisierterem": "liberalisiert",
    "liberalisierteren": "liberalisiert",
    "liberalisierterer": "liberalisiert",
    "liberalisierteres": "liberalisiert",
    "liberalisiertes": "liberalisiert",
    "liberalisiertest": "liberalisieren",
    "liberalisiertestem": "liberalisiert",
    "liberalisiertesten": "liberalisiert",
    "liberalisiertester": "liberalisiert",
    "liberalisiertestes": "liberalisiert",
    "liberalisiertet": "liberalisieren",
    "liberalstem": "liberal",
    "liberalsten": "liberal",
    "liberalster": "liberal",
    "liberalstes": "liberal",
    "lichtbeständigem": "lichtbeständig",
    "lichtbeständigen": "lichtbeständig",
    "lichtbeständiger": "lichtbeständig",
    "lichtbeständigere": "lichtbeständig",
    "lichtbeständigerem": "lichtbeständig",
    "lichtbeständigeren": "lichtbeständig",
    "lichtbeständigerer": "lichtbeständig",
    "lichtbeständigeres": "lichtbeständig",
    "lichtbeständiges": "lichtbeständig",
    "lichtbeständigste": "lichtbeständig",
    "lichtbeständigstem": "lichtbeständig",
    "lichtbeständigsten": "lichtbeständig",
    "lichtbeständigster": "lichtbeständig",
    "lichtbeständigstes": "lichtbeständig",
    "lichtdurchlässige": "lichtdurchlässig",
    "lichtdurchlässigem": "lichtdurchlässig",
    "lichtdurchlässigen": "lichtdurchlässig",
    "lichtdurchlässiger": "lichtdurchlässig",
    "lichtdurchlässigere": "lichtdurchlässig",
    "lichtdurchlässigerem": "lichtdurchlässig",
    "lichtdurchlässigeren": "lichtdurchlässig",
    "lichtdurchlässigerer": "lichtdurchlässig",
    "lichtdurchlässigeres": "lichtdurchlässig",
    "lichtdurchlässiges": "lichtdurchlässig",
    "lichtdurchlässigste": "lichtdurchlässig",
    "lichtdurchlässigstem": "lichtdurchlässig",
    "lichtdurchlässigsten": "lichtdurchlässig",
    "lichtdurchlässigster": "lichtdurchlässig",
    "lichtdurchlässigstes": "lichtdurchlässig",
    "lichtempfindliche": "lichtempfindlich",
    "lichtempfindlichem": "lichtempfindlich",
    "lichtempfindlichen": "lichtempfindlich",
    "lichtempfindlicher": "lichtempfindlich",
    "lichtempfindlichere": "lichtempfindlich",
    "lichtempfindlicherem": "lichtempfindlich",
    "lichtempfindlicheren": "lichtempfindlich",
    "lichtempfindlicherer": "lichtempfindlich",
    "lichtempfindlicheres": "lichtempfindlich",
    "lichtempfindliches": "lichtempfindlich",
    "lichtempfindlichste": "lichtempfindlich",
    "lichtempfindlichstem": "lichtempfindlich",
    "lichtempfindlichsten": "lichtempfindlich",
    "lichtempfindlichster": "lichtempfindlich",
    "lichtempfindlichstes": "lichtempfindlich",
    "lichtend": "lichten",
    "lichtende": "lichtend",
    "lichtendem": "lichtend",
    "lichtenden": "lichtend",
    "lichtender": "lichtend",
    "lichtendes": "lichtend",
    "lichtest": "lichten",
    "lichtet": "lichten",
    "lichtete": "lichten",
    "lichteten": "lichten",
    "lichtetest": "lichten",
    "lichtetet": "lichten",
    "lichtscheuem": "lichtscheu",
    "lichtscheuen": "lichtscheu",
    "lichtscheuer": "lichtscheu",
    "lichtscheuere": "lichtscheu",
    "lichtscheuerem": "lichtscheu",
    "lichtscheueren": "lichtscheu",
    "lichtscheuerer": "lichtscheu",
    "lichtscheueres": "lichtscheu",
    "lichtscheues": "lichtscheu",
    "lichtscheuste": "lichtscheu",
    "lichtscheustem": "lichtscheu",
    "lichtscheusten": "lichtscheu",
    "lichtscheuster": "lichtscheu",
    "lichtscheustes": "lichtscheu",
    "lichtschwache": "lichtschwach",
    "lichtschwachem": "lichtschwach",
    "lichtschwachen": "lichtschwach",
    "lichtschwacher": "lichtschwach",
    "lichtschwaches": "lichtschwach",
    "lichtschwächer": "lichtschwach",
    "lichtschwächere": "lichtschwach",
    "lichtschwächerem": "lichtschwach",
    "lichtschwächeren": "lichtschwach",
    "lichtschwächerer": "lichtschwach",
    "lichtschwächeres": "lichtschwach",
    "lichtschwächste": "lichtschwach",
    "lichtschwächstem": "lichtschwach",
    "lichtschwächsten": "lichtschwach",
    "lichtschwächster": "lichtschwach",
    "lichtschwächstes": "lichtschwach",
    "lichtstarke": "lichtstark",
    "lichtstarkem": "lichtstark",
    "lichtstarken": "lichtstark",
    "lichtstarker": "lichtstark",
    "lichtstarkes": "lichtstark",
    "lichtstärker": "lichtstark",
    "lichtstärkere": "lichtstark",
    "lichtstärkerem": "lichtstark",
    "lichtstärkeren": "lichtstark",
    "lichtstärkerer": "lichtstark",
    "lichtstärkeres": "lichtstark",
    "lichtstärkste": "lichtstark",
    "lichtstärkstem": "lichtstark",
    "lichtstärksten": "lichtstark",
    "lichtstärkster": "lichtstark",
    "lichtstärkstes": "lichtstark",
    "lieb": "lieben",
    "liebbehalte": "liebbehalten",
    "liebbehaltend": "liebbehalten",
    "liebbehaltende": "liebbehaltend",
    "liebbehaltendem": "liebbehaltend",
    "liebbehaltenden": "liebbehaltend",
    "liebbehaltender": "liebbehaltend",
    "liebbehaltendes": "liebbehaltend",
    "liebbehaltene": "liebbehalten",
    "liebbehaltenem": "liebbehalten",
    "liebbehaltenen": "liebbehalten",
    "liebbehaltener": "liebbehalten",
    "liebbehaltenes": "liebbehalten",
    "liebbehaltest": "liebbehalten",
    "liebbehaltet": "liebbehalten",
    "liebbehielt": "liebbehalten",
    "liebbehielte": "liebbehalten",
    "liebbehielten": "liebbehalten",
    "liebbehieltest": "liebbehalten",
    "liebbehieltet": "liebbehalten",
    "liebbehält": "liebbehalten",
    "liebbehältst": "liebbehalten",
    "liebe": "lieb",
    "liebebedürftige": "liebebedürftig",
    "liebebedürftigem": "liebebedürftig",
    "liebebedürftigen": "liebebedürftig",
    "liebebedürftiger": "liebebedürftig",
    "liebebedürftigere": "liebebedürftig",
    "liebebedürftigerem": "liebebedürftig",
    "liebebedürftigeren": "liebebedürftig",
    "liebebedürftigerer": "liebebedürftig",
    "liebebedürftigeres": "liebebedürftig",
    "liebebedürftiges": "liebebedürftig",
    "liebebedürftigste": "liebebedürftig",
    "liebebedürftigstem": "liebebedürftig",
    "liebebedürftigsten": "liebebedürftig",
    "liebebedürftigster": "liebebedürftig",
    "liebebedürftigstes": "liebebedürftig",
    "liebem": "lieb",
    "lieben": "lieb",
    "liebend": "lieben",
    "liebende": "liebend",
    "liebendem": "liebend",
    "liebenden": "liebend",
    "liebender": "liebend",
    "liebendere": "liebend",
    "liebenderem": "liebend",
    "liebenderen": "liebend",
    "liebenderer": "liebend",
    "liebenderes": "liebend",
    "liebendes": "liebend",
    "liebendste": "liebend",
    "liebendstem": "liebend",
    "liebendsten": "liebend",
    "liebendster": "liebend",
    "liebendstes": "liebend",
    "liebenswertem": "liebenswert",
    "liebenswerten": "liebenswert",
    "liebenswerter": "liebenswert",
    "liebenswertere": "liebenswert",
    "liebenswerterem": "liebenswert",
    "liebenswerteren": "liebenswert",
    "liebenswerterer": "liebenswert",
    "liebenswerteres": "liebenswert",
    "liebenswertes": "liebenswert",
    "liebenswerteste": "liebenswert",
    "liebenswertestem": "liebenswert",
    "liebenswertesten": "liebenswert",
    "liebenswertester": "liebenswert",
    "liebenswertestes": "liebenswert",
    "liebenswürdige": "liebenswürdig",
    "liebenswürdigem": "liebenswürdig",
    "liebenswürdigen": "liebenswürdig",
    "liebenswürdiger": "liebenswürdig",
    "liebenswürdigere": "liebenswürdig",
    "liebenswürdigerem": "liebenswürdig",
    "liebenswürdigeren": "liebenswürdig",
    "liebenswürdigerer": "liebenswürdig",
    "liebenswürdigeres": "liebenswürdig",
    "liebenswürdiges": "liebenswürdig",
    "liebenswürdigste": "liebenswürdig",
    "liebenswürdigstem": "liebenswürdig",
    "liebenswürdigsten": "liebenswürdig",
    "liebenswürdigster": "liebenswürdig",
    "liebenswürdigstes": "liebenswürdig",
    "lieber": "lieb",
    "liebere": "lieb",
    "lieberem": "lieb",
    "lieberen": "lieb",
    "lieberer": "lieb",
    "lieberes": "lieb",
    "liebes": "lieb",
    "liebest": "lieben",
    "liebet": "lieben",
    "liebevolle": "liebevoll",
    "liebevollem": "liebevoll",
    "liebevollen": "liebevoll",
    "liebevoller": "liebevoll",
    "liebevollere": "liebevoll",
    "liebevollerem": "liebevoll",
    "liebevolleren": "liebevoll",
    "liebevollerer": "liebevoll",
    "liebevolleres": "liebevoll",
    "liebevolles": "liebevoll",
    "liebevollste": "liebevoll",
    "liebevollstem": "liebevoll",
    "liebevollsten": "liebevoll",
    "liebevollster": "liebevoll",
    "liebevollstes": "liebevoll",
    "liebgewann": "liebgewinnen",
    "liebgewannen": "liebgewinnen",
    "liebgewannst": "liebgewinnen",
    "liebgewannt": "liebgewinnen",
    "liebgewinne": "liebgewinnen",
    "liebgewinnend": "liebgewinnen",
    "liebgewinnende": "liebgewinnend",
    "liebgewinnendem": "liebgewinnend",
    "liebgewinnenden": "liebgewinnend",
    "liebgewinnender": "liebgewinnend",
    "liebgewinnendere": "liebgewinnend",
    "liebgewinnenderem": "liebgewinnend",
    "liebgewinnenderen": "liebgewinnend",
    "liebgewinnenderer": "liebgewinnend",
    "liebgewinnenderes": "liebgewinnend",
    "liebgewinnendes": "liebgewinnend",
    "liebgewinnendste": "liebgewinnend",
    "liebgewinnendstem": "liebgewinnend",
    "liebgewinnendsten": "liebgewinnend",
    "liebgewinnendster": "liebgewinnend",
    "liebgewinnendstes": "liebgewinnend",
    "liebgewinnest": "liebgewinnen",
    "liebgewinnet": "liebgewinnen",
    "liebgewinnst": "liebgewinnen",
    "liebgewinnt": "liebgewinnen",
    "liebgewonnen": "liebgewinnen",
    "liebgewonnene": "liebgewonnen",
    "liebgewonnenem": "liebgewonnen",
    "liebgewonnenen": "liebgewonnen",
    "liebgewonnener": "liebgewonnen",
    "liebgewonnenere": "liebgewonnen",
    "liebgewonnenerem": "liebgewonnen",
    "liebgewonneneren": "liebgewonnen",
    "liebgewonnenerer": "liebgewonnen",
    "liebgewonneneres": "liebgewonnen",
    "liebgewonnenes": "liebgewonnen",
    "liebgewonnenste": "liebgewonnen",
    "liebgewonnenstem": "liebgewonnen",
    "liebgewonnensten": "liebgewonnen",
    "liebgewonnenster": "liebgewonnen",
    "liebgewonnenstes": "liebgewonnen",
    "liebgewänne": "liebgewinnen",
    "liebgewännen": "liebgewinnen",
    "liebgewännest": "liebgewinnen",
    "liebgewännet": "liebgewinnen",
    "liebkose": "liebkosen",
    "liebkosend": "liebkosen",
    "liebkosende": "liebkosend",
    "liebkosendem": "liebkosend",
    "liebkosenden": "liebkosend",
    "liebkosender": "liebkosend",
    "liebkosendere": "liebkosend",
    "liebkosenderem": "liebkosend",
    "liebkosenderen": "liebkosend",
    "liebkosenderer": "liebkosend",
    "liebkosenderes": "liebkosend",
    "liebkosendes": "liebkosend",
    "liebkosendste": "liebkosend",
    "liebkosendstem": "liebkosend",
    "liebkosendsten": "liebkosend",
    "liebkosendster": "liebkosend",
    "liebkosendstes": "liebkosend",
    "liebkosest": "liebkosen",
    "liebkoset": "liebkosen",
    "liebkost": "liebkosen",
    "liebkoste": "liebkosen",
    "liebkostem": "liebkost",
    "liebkosten": "liebkosen",
    "liebkoster": "liebkost",
    "liebkostes": "liebkost",
    "liebkostest": "liebkosen",
    "liebkostet": "liebkosen",
    "lieblichem": "lieblich",
    "lieblichen": "lieblich",
    "lieblicher": "lieblich",
    "lieblichere": "lieblich",
    "lieblicherem": "lieblich",
    "lieblicheren": "lieblich",
    "lieblicherer": "lieblich",
    "lieblicheres": "lieblich",
    "liebliches": "lieblich",
    "lieblichste": "lieblich",
    "lieblichstem": "lieblich",
    "lieblichsten": "lieblich",
    "lieblichster": "lieblich",
    "lieblichstes": "lieblich",
    "lieblosem": "lieblos",
    "lieblosen": "lieblos",
    "liebloser": "lieblos",
    "lieblosere": "lieblos",
    "liebloserem": "lieblos",
    "liebloseren": "lieblos",
    "liebloserer": "lieblos",
    "liebloseres": "lieblos",
    "liebloses": "lieblos",
    "liebloseste": "lieblos",
    "lieblosestem": "lieblos",
    "lieblosesten": "lieblos",
    "lieblosester": "lieblos",
    "lieblosestes": "lieblos",
    "liebreizendem": "liebreizend",
    "liebreizenden": "liebreizend",
    "liebreizender": "liebreizend",
    "liebreizendere": "liebreizend",
    "liebreizenderem": "liebreizend",
    "liebreizenderen": "liebreizend",
    "liebreizenderer": "liebreizend",
    "liebreizenderes": "liebreizend",
    "liebreizendes": "liebreizend",
    "liebreizendste": "liebreizend",
    "liebreizendstem": "liebreizend",
    "liebreizendsten": "liebreizend",
    "liebreizendster": "liebreizend",
    "liebreizendstes": "liebreizend",
    "liebst": "lieben",
    "liebste": "lieb",
    "liebstem": "lieb",
    "liebsten": "lieb",
    "liebster": "lieb",
    "liebstes": "lieb",
    "liebt": "lieben",
    "liebte": "lieben",
    "liebten": "lieben",
    "liebtest": "lieben",
    "liebtet": "lieben",
    "liebzubehalten": "liebbehalten",
    "liebzugewinnen": "liebgewinnen",
    "liebäugele": "liebäugeln",
    "liebäugelnd": "liebäugeln",
    "liebäugelnde": "liebäugelnd",
    "liebäugelndem": "liebäugelnd",
    "liebäugelnden": "liebäugelnd",
    "liebäugelnder": "liebäugelnd",
    "liebäugelndere": "liebäugelnd",
    "liebäugelnderem": "liebäugelnd",
    "liebäugelnderen": "liebäugelnd",
    "liebäugelnderer": "liebäugelnd",
    "liebäugelnderes": "liebäugelnd",
    "liebäugelndes": "liebäugelnd",
    "liebäugelndste": "liebäugelnd",
    "liebäugelndstem": "liebäugelnd",
    "liebäugelndsten": "liebäugelnd",
    "liebäugelndster": "liebäugelnd",
    "liebäugelndstes": "liebäugelnd",
    "liebäugelst": "liebäugeln",
    "liebäugelt": "liebäugeln",
    "liebäugelte": "liebäugeln",
    "liebäugelten": "liebäugeln",
    "liebäugeltest": "liebäugeln",
    "liebäugeltet": "liebäugeln",
    "liebäugle": "liebäugeln",
    "liederlichem": "liederlich",
    "liederlichen": "liederlich",
    "liederlicher": "liederlich",
    "liederlichere": "liederlich",
    "liederlicherem": "liederlich",
    "liederlicheren": "liederlich",
    "liederlicherer": "liederlich",
    "liederlicheres": "liederlich",
    "liederliches": "liederlich",
    "liederlichste": "liederlich",
    "liederlichstem": "liederlich",
    "liederlichsten": "liederlich",
    "liederlichster": "liederlich",
    "liederlichstes": "liederlich",
    "lief": "laufen",
    "liefe": "laufen",
    "liefen": "laufen",
    "lieferbarem": "lieferbar",
    "lieferbaren": "lieferbar",
    "lieferbarer": "lieferbar",
    "lieferbares": "lieferbar",
    "liefere": "liefern",
    "liefernd": "liefern",
    "liefernde": "liefernd",
    "lieferndem": "liefernd",
    "liefernden": "liefernd",
    "liefernder": "liefernd",
    "lieferndes": "liefernd",
    "lieferst": "liefern",
    "liefert": "liefern",
    "lieferte": "liefern",
    "lieferten": "liefern",
    "liefertest": "liefern",
    "liefertet": "liefern",
    "liefest": "laufen",
    "liefet": "laufen",
    "liefst": "laufen",
    "lieft": "laufen",
    "liege": "liegen",
    "liegenbleibe": "liegenbleiben",
    "liegenbleibend": "liegenbleiben",
    "liegenbleibende": "liegenbleibend",
    "liegenbleibendem": "liegenbleibend",
    "liegenbleibenden": "liegenbleibend",
    "liegenbleibender": "liegenbleibend",
    "liegenbleibendes": "liegenbleibend",
    "liegenbleibest": "liegenbleiben",
    "liegenbleibet": "liegenbleiben",
    "liegenbleibst": "liegenbleiben",
    "liegenbleibt": "liegenbleiben",
    "liegenblieb": "liegenbleiben",
    "liegenbliebe": "liegenbleiben",
    "liegenblieben": "liegenbleiben",
    "liegenbliebest": "liegenbleiben",
    "liegenbliebet": "liegenbleiben",
    "liegenbliebst": "liegenbleiben",
    "liegenbliebt": "liegenbleiben",
    "liegend": "liegen",
    "liegende": "liegend",
    "liegendem": "liegend",
    "liegenden": "liegend",
    "liegender": "liegend",
    "liegendes": "liegend",
    "liegengeblieben": "liegenbleiben",
    "liegengebliebene": "liegengeblieben",
    "liegengebliebenem": "liegengeblieben",
    "liegengebliebenen": "liegengeblieben",
    "liegengebliebener": "liegengeblieben",
    "liegengebliebenes": "liegengeblieben",
    "liegenzubleiben": "liegenbleiben",
    "liegest": "liegen",
    "lieget": "liegen",
    "liegst": "liegen",
    "liegt": "liegen",
    "lieh": "leihen",
    "liehe": "leihen",
    "liehen": "leihen",
    "liehest": "leihen",
    "liehet": "leihen",
    "liehst": "leihen",
    "lieht": "leihen",
    "lies": "lesen",
    "liest": "lesen",
    "ließ": "lassen",
    "ließe": "lassen",
    "ließen": "lassen",
    "ließest": "lassen",
    "ließet": "lassen",
    "ließt": "lassen",
    "liftend": "liften",
    "liftende": "liftend",
    "liftendem": "liftend",
    "liftenden": "liftend",
    "liftender": "liftend",
    "liftendes": "liftend",
    "liftest": "liften",
    "liftet": "liften",
    "liftete": "liften",
    "lifteten": "liften",
    "liftetest": "liften",
    "liftetet": "liften",
    "limitiere": "limitieren",
    "limitierend": "limitieren",
    "limitierende": "limitierend",
    "limitierendem": "limitierend",
    "limitierenden": "limitierend",
    "limitierender": "limitierend",
    "limitierendere": "limitierend",
    "limitierenderem": "limitierend",
    "limitierenderen": "limitierend",
    "limitierenderer": "limitierend",
    "limitierenderes": "limitierend",
    "limitierendes": "limitierend",
    "limitierendste": "limitierend",
    "limitierendstem": "limitierend",
    "limitierendsten": "limitierend",
    "limitierendster": "limitierend",
    "limitierendstes": "limitierend",
    "limitierest": "limitieren",
    "limitieret": "limitieren",
    "limitierst": "limitieren",
    "limitiert": "limitieren",
    "limitierte": "limitieren",
    "limitiertem": "limitiert",
    "limitierten": "limitieren",
    "limitierter": "limitiert",
    "limitiertere": "limitiert",
    "limitierterem": "limitiert",
    "limitierteren": "limitiert",
    "limitierterer": "limitiert",
    "limitierteres": "limitiert",
    "limitiertes": "limitiert",
    "limitiertest": "limitieren",
    "limitierteste": "limitiert",
    "limitiertestem": "limitiert",
    "limitiertesten": "limitiert",
    "limitiertester": "limitiert",
    "limitiertestes": "limitiert",
    "limitiertet": "limitieren",
    "lindere": "lindern",
    "lindernd": "lindern",
    "lindernde": "lindernd",
    "linderndem": "lindernd",
    "lindernden": "lindernd",
    "lindernder": "lindernd",
    "linderndere": "lindernd",
    "lindernderem": "lindernd",
    "lindernderen": "lindernd",
    "lindernderer": "lindernd",
    "lindernderes": "lindernd",
    "linderndes": "lindernd",
    "linderndste": "lindernd",
    "linderndstem": "lindernd",
    "linderndsten": "lindernd",
    "linderndster": "lindernd",
    "linderndstes": "lindernd",
    "linderst": "lindern",
    "lindert": "lindern",
    "linderte": "lindern",
    "linderten": "lindern",
    "lindertest": "lindern",
    "lindertet": "lindern",
    "linearem": "linear",
    "linearen": "linear",
    "linearer": "linear",
    "lineares": "linear",
    "lingualem": "lingual",
    "lingualen": "lingual",
    "lingualer": "lingual",
    "linguales": "lingual",
    "liniere": "linieren",
    "linierend": "linieren",
    "linierende": "linierend",
    "linierendem": "linierend",
    "linierenden": "linierend",
    "linierender": "linierend",
    "linierendes": "linierend",
    "linierest": "linieren",
    "linieret": "linieren",
    "linierst": "linieren",
    "liniert": "linieren",
    "linierte": "linieren",
    "liniertem": "liniert",
    "linierten": "linieren",
    "linierter": "liniert",
    "liniertes": "liniert",
    "liniertest": "linieren",
    "liniertet": "linieren",
    "linke": "link",
    "linkem": "link",
    "linken": "link",
    "linker": "link",
    "linkere": "link",
    "linkerem": "link",
    "linkeren": "link",
    "linkerer": "link",
    "linkeres": "link",
    "linkes": "link",
    "linkeste": "link",
    "linkestem": "link",
    "linkesten": "link",
    "linkester": "link",
    "linkestes": "link",
    "linksdrehendem": "linksdrehend",
    "linksdrehenden": "linksdrehend",
    "linksdrehender": "linksdrehend",
    "linksdrehendes": "linksdrehend",
    "linkshändigem": "linkshändig",
    "linkshändigen": "linkshändig",
    "linkshändiger": "linkshändig",
    "linkshändiges": "linkshändig",
    "linkslastigem": "linkslastig",
    "linkslastigen": "linkslastig",
    "linkslastiger": "linkslastig",
    "linkslastiges": "linkslastig",
    "linksliberale": "linksliberal",
    "linksliberalem": "linksliberal",
    "linksliberalen": "linksliberal",
    "linksliberaler": "linksliberal",
    "linksliberalere": "linksliberal",
    "linksliberalerem": "linksliberal",
    "linksliberaleren": "linksliberal",
    "linksliberalerer": "linksliberal",
    "linksliberaleres": "linksliberal",
    "linksliberales": "linksliberal",
    "linksliberalste": "linksliberal",
    "linksliberalstem": "linksliberal",
    "linksliberalsten": "linksliberal",
    "linksliberalster": "linksliberal",
    "linksliberalstes": "linksliberal",
    "linksläufige": "linksläufig",
    "linksläufigem": "linksläufig",
    "linksläufigen": "linksläufig",
    "linksläufiger": "linksläufig",
    "linksläufiges": "linksläufig",
    "linksseitigem": "linksseitig",
    "linksseitigen": "linksseitig",
    "linksseitiger": "linksseitig",
    "linksseitiges": "linksseitig",
    "liquidiere": "liquidieren",
    "liquidierend": "liquidieren",
    "liquidierende": "liquidierend",
    "liquidierendem": "liquidierend",
    "liquidierenden": "liquidierend",
    "liquidierender": "liquidierend",
    "liquidierendes": "liquidierend",
    "liquidierest": "liquidieren",
    "liquidieret": "liquidieren",
    "liquidierst": "liquidieren",
    "liquidiert": "liquidieren",
    "liquidierte": "liquidieren",
    "liquidiertem": "liquidiert",
    "liquidierten": "liquidieren",
    "liquidierter": "liquidiert",
    "liquidiertes": "liquidiert",
    "liquidiertest": "liquidieren",
    "liquidiertet": "liquidieren",
    "lisch": "löschen",
    "lischst": "löschen",
    "lischt": "löschen",
    "lispele": "lispeln",
    "lispelnd": "lispeln",
    "lispelnde": "lispelnd",
    "lispelndem": "lispelnd",
    "lispelnden": "lispelnd",
    "lispelnder": "lispelnd",
    "lispelndere": "lispelnd",
    "lispelnderem": "lispelnd",
    "lispelnderen": "lispelnd",
    "lispelnderer": "lispelnd",
    "lispelnderes": "lispelnd",
    "lispelndes": "lispelnd",
    "lispelndste": "lispelnd",
    "lispelndstem": "lispelnd",
    "lispelndsten": "lispelnd",
    "lispelndster": "lispelnd",
    "lispelndstes": "lispelnd",
    "lispelst": "lispeln",
    "lispelt": "lispeln",
    "lispelte": "lispeln",
    "lispelten": "lispeln",
    "lispeltest": "lispeln",
    "lispeltet": "lispeln",
    "lisple": "lispeln",
    "listend": "listen",
    "listende": "listend",
    "listendem": "listend",
    "listenden": "listend",
    "listender": "listend",
    "listendes": "listend",
    "listest": "listen",
    "listet": "listen",
    "listete": "listen",
    "listeten": "listen",
    "listetest": "listen",
    "listetet": "listen",
    "listige": "listig",
    "listigem": "listig",
    "listigen": "listig",
    "listiger": "listig",
    "listigere": "listig",
    "listigerem": "listig",
    "listigeren": "listig",
    "listigerer": "listig",
    "listigeres": "listig",
    "listiges": "listig",
    "listigste": "listig",
    "listigstem": "listig",
    "listigsten": "listig",
    "listigster": "listig",
    "listigstes": "listig",
    "litauischem": "litauisch",
    "litauischen": "litauisch",
    "litauischer": "litauisch",
    "litauisches": "litauisch",
    "literalisiere": "literalisieren",
    "literalisierend": "literalisieren",
    "literalisierende": "literalisierend",
    "literalisierendem": "literalisierend",
    "literalisierenden": "literalisierend",
    "literalisierender": "literalisierend",
    "literalisierendes": "literalisierend",
    "literalisierest": "literalisieren",
    "literalisieret": "literalisieren",
    "literalisierst": "literalisieren",
    "literalisiert": "literalisieren",
    "literalisierte": "literalisieren",
    "literalisiertem": "literalisiert",
    "literalisierten": "literalisieren",
    "literalisierter": "literalisiert",
    "literalisiertes": "literalisiert",
    "literalisiertest": "literalisieren",
    "literalisiertet": "literalisieren",
    "literarische": "literarisch",
    "literarischem": "literarisch",
    "literarischen": "literarisch",
    "literarischer": "literarisch",
    "literarisches": "literarisch",
    "literarisiere": "literarisieren",
    "literarisierend": "literarisieren",
    "literarisierende": "literarisierend",
    "literarisierendem": "literarisierend",
    "literarisierenden": "literarisierend",
    "literarisierender": "literarisierend",
    "literarisierendes": "literarisierend",
    "literarisierest": "literarisieren",
    "literarisieret": "literarisieren",
    "literarisierst": "literarisieren",
    "literarisiert": "literarisieren",
    "literarisierte": "literarisieren",
    "literarisiertem": "literarisiert",
    "literarisierten": "literarisieren",
    "literarisierter": "literarisiert",
    "literarisiertes": "literarisiert",
    "literarisiertest": "literarisieren",
    "literarisiertet": "literarisieren",
    "litt": "leiden",
    "litte": "leiden",
    "litten": "leiden",
    "littest": "leiden",
    "littet": "leiden",
    "liturgischem": "liturgisch",
    "liturgischen": "liturgisch",
    "liturgischer": "liturgisch",
    "liturgisches": "liturgisch",
    "lobend": "loben",
    "lobende": "lobend",
    "lobendem": "lobend",
    "lobenden": "lobend",
    "lobender": "lobend",
    "lobendere": "lobend",
    "lobenderem": "lobend",
    "lobenderen": "lobend",
    "lobenderer": "lobend",
    "lobenderes": "lobend",
    "lobendes": "lobend",
    "lobendste": "lobend",
    "lobendstem": "lobend",
    "lobendsten": "lobend",
    "lobendster": "lobend",
    "lobendstes": "lobend",
    "lobenswertem": "lobenswert",
    "lobenswerten": "lobenswert",
    "lobenswerter": "lobenswert",
    "lobenswertere": "lobenswert",
    "lobenswerterem": "lobenswert",
    "lobenswerteren": "lobenswert",
    "lobenswerterer": "lobenswert",
    "lobenswerteres": "lobenswert",
    "lobenswertes": "lobenswert",
    "lobenswerteste": "lobenswert",
    "lobenswertestem": "lobenswert",
    "lobenswertesten": "lobenswert",
    "lobenswertester": "lobenswert",
    "lobenswertestes": "lobenswert",
    "lobest": "loben",
    "lobet": "loben",
    "lobst": "loben",
    "lobt": "loben",
    "lobte": "loben",
    "lobten": "loben",
    "lobtest": "loben",
    "lobtet": "loben",
    "lochend": "lochen",
    "lochende": "lochend",
    "lochendem": "lochend",
    "lochenden": "lochend",
    "lochender": "lochend",
    "lochendes": "lochend",
    "lochest": "lochen",
    "lochet": "lochen",
    "lochst": "lochen",
    "locht": "lochen",
    "lochte": "lochen",
    "lochten": "lochen",
    "lochtest": "lochen",
    "lochtet": "lochen",
    "lockend": "locken",
    "lockende": "lockend",
    "lockendem": "lockend",
    "lockenden": "lockend",
    "lockender": "lockend",
    "lockendere": "lockend",
    "lockenderem": "lockend",
    "lockenderen": "lockend",
    "lockenderer": "lockend",
    "lockenderes": "lockend",
    "lockendes": "lockend",
    "lockendste": "lockend",
    "lockendstem": "lockend",
    "lockendsten": "lockend",
    "lockendster": "lockend",
    "lockendstes": "lockend",
    "locker": "lockern",
    "lockere": "locker",
    "lockerem": "locker",
    "lockeren": "locker",
    "lockerer": "locker",
    "lockerere": "locker",
    "lockererem": "locker",
    "lockereren": "locker",
    "lockererer": "locker",
    "lockereres": "locker",
    "lockeres": "locker",
    "lockernd": "lockern",
    "lockernde": "lockernd",
    "lockerndem": "lockernd",
    "lockernden": "lockernd",
    "lockernder": "lockernd",
    "lockerndes": "lockernd",
    "lockerst": "lockern",
    "lockerste": "locker",
    "lockerstem": "locker",
    "lockersten": "locker",
    "lockerster": "locker",
    "lockerstes": "locker",
    "lockert": "lockern",
    "lockerte": "lockern",
    "lockerten": "lockern",
    "lockertest": "lockern",
    "lockertet": "lockern",
    "lockest": "locken",
    "locket": "locken",
    "lockst": "locken",
    "lockt": "locken",
    "lockte": "locken",
    "lockten": "locken",
    "locktest": "locken",
    "locktet": "locken",
    "lodere": "lodern",
    "lodernd": "lodern",
    "lodernde": "lodernd",
    "loderndem": "lodernd",
    "lodernden": "lodernd",
    "lodernder": "lodernd",
    "loderndere": "lodernd",
    "lodernderem": "lodernd",
    "lodernderen": "lodernd",
    "lodernderer": "lodernd",
    "lodernderes": "lodernd",
    "loderndes": "lodernd",
    "loderndste": "lodernd",
    "loderndstem": "lodernd",
    "loderndsten": "lodernd",
    "loderndster": "lodernd",
    "loderndstes": "lodernd",
    "loderst": "lodern",
    "lodert": "lodern",
    "loderte": "lodern",
    "loderten": "lodern",
    "lodertest": "lodern",
    "lodertet": "lodern",
    "log": "lügen",
    "logen": "lügen",
    "logge": "loggen",
    "loggend": "loggen",
    "loggende": "loggend",
    "loggendem": "loggend",
    "loggenden": "loggend",
    "loggender": "loggend",
    "loggendes": "loggend",
    "loggest": "loggen",
    "logget": "loggen",
    "loggst": "loggen",
    "loggt": "loggen",
    "loggte": "loggen",
    "loggten": "loggen",
    "loggtest": "loggen",
    "loggtet": "loggen",
    "logischem": "logisch",
    "logischen": "logisch",
    "logischer": "logisch",
    "logischere": "logisch",
    "logischerem": "logisch",
    "logischeren": "logisch",
    "logischerer": "logisch",
    "logischeres": "logisch",
    "logisches": "logisch",
    "logischste": "logisch",
    "logischstem": "logisch",
    "logischsten": "logisch",
    "logischster": "logisch",
    "logischstes": "logisch",
    "logistische": "logistisch",
    "logistischem": "logistisch",
    "logistischen": "logistisch",
    "logistischer": "logistisch",
    "logistisches": "logistisch",
    "logst": "lügen",
    "logt": "lügen",
    "lohne": "lohnen",
    "lohnend": "lohnen",
    "lohnende": "lohnend",
    "lohnendem": "lohnend",
    "lohnenden": "lohnend",
    "lohnender": "lohnend",
    "lohnendere": "lohnend",
    "lohnenderem": "lohnend",
    "lohnenderen": "lohnend",
    "lohnenderer": "lohnend",
    "lohnenderes": "lohnend",
    "lohnendes": "lohnend",
    "lohnendste": "lohnend",
    "lohnendstem": "lohnend",
    "lohnendsten": "lohnend",
    "lohnendster": "lohnend",
    "lohnendstes": "lohnend",
    "lohnest": "lohnen",
    "lohnet": "lohnen",
    "lohnst": "lohnen",
    "lohnt": "lohnen",
    "lohnte": "lohnen",
    "lohnten": "lohnen",
    "lohntest": "lohnen",
    "lohntet": "lohnen",
    "lokalem": "lokal",
    "lokalen": "lokal",
    "lokaler": "lokal",
    "lokales": "lokal",
    "lokalisiere": "lokalisieren",
    "lokalisierend": "lokalisieren",
    "lokalisierende": "lokalisierend",
    "lokalisierendem": "lokalisierend",
    "lokalisierenden": "lokalisierend",
    "lokalisierender": "lokalisierend",
    "lokalisierendes": "lokalisierend",
    "lokalisierest": "lokalisieren",
    "lokalisieret": "lokalisieren",
    "lokalisierst": "lokalisieren",
    "lokalisiert": "lokalisieren",
    "lokalisierte": "lokalisieren",
    "lokalisiertem": "lokalisiert",
    "lokalisierten": "lokalisieren",
    "lokalisierter": "lokalisiert",
    "lokalisiertes": "lokalisiert",
    "lokalisiertest": "lokalisieren",
    "lokalisiertet": "lokalisieren",
    "lombardiere": "lombardieren",
    "lombardierend": "lombardieren",
    "lombardierende": "lombardierend",
    "lombardierendem": "lombardierend",
    "lombardierenden": "lombardierend",
    "lombardierender": "lombardierend",
    "lombardierendes": "lombardierend",
    "lombardierest": "lombardieren",
    "lombardieret": "lombardieren",
    "lombardierst": "lombardieren",
    "lombardiert": "lombardieren",
    "lombardierte": "lombardieren",
    "lombardiertem": "lombardiert",
    "lombardierten": "lombardieren",
    "lombardierter": "lombardiert",
    "lombardiertes": "lombardiert",
    "lombardiertest": "lombardieren",
    "lombardiertet": "lombardieren",
    "lombardische": "lombardisch",
    "lombardischem": "lombardisch",
    "lombardischen": "lombardisch",
    "lombardischer": "lombardisch",
    "lombardisches": "lombardisch",
    "losarbeite": "losarbeiten",
    "losarbeitend": "losarbeiten",
    "losarbeitende": "losarbeitend",
    "losarbeitendem": "losarbeitend",
    "losarbeitenden": "losarbeitend",
    "losarbeitender": "losarbeitend",
    "losarbeitendes": "losarbeitend",
    "losarbeitest": "losarbeiten",
    "losarbeitet": "losarbeiten",
    "losarbeitete": "losarbeiten",
    "losarbeiteten": "losarbeiten",
    "losarbeitetest": "losarbeiten",
    "losarbeitetet": "losarbeiten",
    "losband": "losbinden",
    "losbanden": "losbinden",
    "losbandest": "losbinden",
    "losbandet": "losbinden",
    "losbekam": "losbekommen",
    "losbekamen": "losbekommen",
    "losbekamst": "losbekommen",
    "losbekamt": "losbekommen",
    "losbekomme": "losbekommen",
    "losbekommend": "losbekommen",
    "losbekommende": "losbekommend",
    "losbekommendem": "losbekommend",
    "losbekommenden": "losbekommend",
    "losbekommender": "losbekommend",
    "losbekommendes": "losbekommend",
    "losbekommene": "losbekommen",
    "losbekommenem": "losbekommen",
    "losbekommenen": "losbekommen",
    "losbekommener": "losbekommen",
    "losbekommenes": "losbekommen",
    "losbekommest": "losbekommen",
    "losbekommet": "losbekommen",
    "losbekommst": "losbekommen",
    "losbekommt": "losbekommen",
    "losbekäme": "losbekommen",
    "losbekämen": "losbekommen",
    "losbekämest": "losbekommen",
    "losbekämet": "losbekommen",
    "losbinde": "losbinden",
    "losbindend": "losbinden",
    "losbindende": "losbindend",
    "losbindendem": "losbindend",
    "losbindenden": "losbindend",
    "losbindender": "losbindend",
    "losbindendes": "losbindend",
    "losbindest": "losbinden",
    "losbindet": "losbinden",
    "losbrach": "losbrechen",
    "losbrachen": "losbrechen",
    "losbrachst": "losbrechen",
    "losbracht": "losbrechen",
    "losbrachte": "losbringen",
    "losbrachten": "losbringen",
    "losbrachtest": "losbringen",
    "losbrachtet": "losbringen",
    "losbrause": "losbrausen",
    "losbrausend": "losbrausen",
    "losbrausende": "losbrausend",
    "losbrausendem": "losbrausend",
    "losbrausenden": "losbrausend",
    "losbrausender": "losbrausend",
    "losbrausendes": "losbrausend",
    "losbrausest": "losbrausen",
    "losbrauset": "losbrausen",
    "losbraust": "losbrausen",
    "losbrauste": "losbrausen",
    "losbrausten": "losbrausen",
    "losbraustest": "losbrausen",
    "losbraustet": "losbrausen",
    "losbreche": "losbrechen",
    "losbrechend": "losbrechen",
    "losbrechende": "losbrechend",
    "losbrechendem": "losbrechend",
    "losbrechenden": "losbrechend",
    "losbrechender": "losbrechend",
    "losbrechendes": "losbrechend",
    "losbrechest": "losbrechen",
    "losbrechet": "losbrechen",
    "losbrecht": "losbrechen",
    "losbrichst": "losbrechen",
    "losbricht": "losbrechen",
    "losbringe": "losbringen",
    "losbringend": "losbringen",
    "losbringende": "losbringend",
    "losbringendem": "losbringend",
    "losbringenden": "losbringend",
    "losbringender": "losbringend",
    "losbringendes": "losbringend",
    "losbringest": "losbringen",
    "losbringet": "losbringen",
    "losbringst": "losbringen",
    "losbringt": "losbringen",
    "losbräche": "losbrechen",
    "losbrächen": "losbrechen",
    "losbrächest": "losbrechen",
    "losbrächet": "losbrechen",
    "losbrächte": "losbringen",
    "losbrächten": "losbringen",
    "losbrächtest": "losbringen",
    "losbrächtet": "losbringen",
    "losbände": "losbinden",
    "losbänden": "losbinden",
    "losbändest": "losbinden",
    "losbändet": "losbinden",
    "losch": "löschen",
    "loschen": "löschen",
    "loschst": "löschen",
    "loscht": "löschen",
    "losdonnere": "losdonnern",
    "losdonnernd": "losdonnern",
    "losdonnernde": "losdonnernd",
    "losdonnerndem": "losdonnernd",
    "losdonnernden": "losdonnernd",
    "losdonnernder": "losdonnernd",
    "losdonnerndes": "losdonnernd",
    "losdonnerst": "losdonnern",
    "losdonnert": "losdonnern",
    "losdonnerte": "losdonnern",
    "losdonnerten": "losdonnern",
    "losdonnertest": "losdonnern",
    "losdonnertet": "losdonnern",
    "loseise": "loseisen",
    "loseisend": "loseisen",
    "loseisende": "loseisend",
    "loseisendem": "loseisend",
    "loseisenden": "loseisend",
    "loseisender": "loseisend",
    "loseisendes": "loseisend",
    "loseisest": "loseisen",
    "loseiset": "loseisen",
    "loseist": "loseisen",
    "loseiste": "loseisen",
    "loseisten": "loseisen",
    "loseistest": "loseisen",
    "loseistet": "loseisen",
    "losem": "lose",
    "losend": "losen",
    "losende": "losend",
    "losendem": "losend",
    "losenden": "losend",
    "losender": "losend",
    "losendes": "losend",
    "loser": "lose",
    "losere": "lose",
    "loserem": "lose",
    "loseren": "lose",
    "loserer": "lose",
    "loseres": "lose",
    "losest": "losen",
    "loseste": "lose",
    "losestem": "lose",
    "losesten": "lose",
    "losester": "lose",
    "losestes": "lose",
    "loset": "losen",
    "losgab": "losgeben",
    "losgaben": "losgeben",
    "losgabst": "losgeben",
    "losgabt": "losgeben",
    "losgearbeitet": "losarbeiten",
    "losgearbeitete": "losgearbeitet",
    "losgearbeitetem": "losgearbeitet",
    "losgearbeiteten": "losgearbeitet",
    "losgearbeiteter": "losgearbeitet",
    "losgearbeitetes": "losgearbeitet",
    "losgebe": "losgeben",
    "losgebend": "losgeben",
    "losgebende": "losgebend",
    "losgebendem": "losgebend",
    "losgebenden": "losgebend",
    "losgebender": "losgebend",
    "losgebendes": "losgebend",
    "losgebest": "losgeben",
    "losgebet": "losgeben",
    "losgebracht": "losbringen",
    "losgebrachte": "losgebracht",
    "losgebrachtem": "losgebracht",
    "losgebrachten": "losgebracht",
    "losgebrachter": "losgebracht",
    "losgebrachtes": "losgebracht",
    "losgebraust": "losbrausen",
    "losgebrauste": "losgebraust",
    "losgebraustem": "losgebraust",
    "losgebrausten": "losgebraust",
    "losgebrauster": "losgebraust",
    "losgebraustes": "losgebraust",
    "losgebrochen": "losbrechen",
    "losgebrochene": "losgebrochen",
    "losgebrochenem": "losgebrochen",
    "losgebrochenen": "losgebrochen",
    "losgebrochener": "losgebrochen",
    "losgebrochenes": "losgebrochen",
    "losgebt": "losgeben",
    "losgebunden": "losbinden",
    "losgebundene": "losgebunden",
    "losgebundenem": "losgebunden",
    "losgebundenen": "losgebunden",
    "losgebundener": "losgebunden",
    "losgebundenes": "losgebunden",
    "losgedonnert": "losdonnern",
    "losgedonnerte": "losgedonnert",
    "losgedonnertem": "losgedonnert",
    "losgedonnerten": "losgedonnert",
    "losgedonnerter": "losgedonnert",
    "losgedonnertes": "losgedonnert",
    "losgeeist": "loseisen",
    "losgeeiste": "losgeeist",
    "losgeeistem": "losgeeist",
    "losgeeisten": "losgeeist",
    "losgeeister": "losgeeist",
    "losgeeistes": "losgeeist",
    "losgegangen": "losgehen",
    "losgegangene": "losgegangen",
    "losgegangenem": "losgegangen",
    "losgegangenen": "losgegangen",
    "losgegangener": "losgegangen",
    "losgegangenes": "losgegangen",
    "losgegeben": "losgeben",
    "losgegebene": "losgegeben",
    "losgegebenem": "losgegeben",
    "losgegebenen": "losgegeben",
    "losgegebener": "losgegeben",
    "losgegebenes": "losgegeben",
    "losgehaucht": "loshauchen",
    "losgehauchte": "losgehaucht",
    "losgehauchtem": "losgehaucht",
    "losgehauchten": "losgehaucht",
    "losgehauchter": "losgehaucht",
    "losgehauchtes": "losgehaucht",
    "losgehauen": "loshauen",
    "losgehauene": "losgehauen",
    "losgehauenem": "losgehauen",
    "losgehauenen": "losgehauen",
    "losgehauener": "losgehauen",
    "losgehauenes": "losgehauen",
    "losgehe": "losgehen",
    "losgehend": "losgehen",
    "losgehende": "losgehend",
    "losgehendem": "losgehend",
    "losgehenden": "losgehend",
    "losgehender": "losgehend",
    "losgehendes": "losgehend",
    "losgehest": "losgehen",
    "losgehet": "losgehen",
    "losgehst": "losgehen",
    "losgeht": "losgehen",
    "losgekauft": "loskaufen",
    "losgekaufte": "losgekauft",
    "losgekauftem": "losgekauft",
    "losgekauften": "losgekauft",
    "losgekaufter": "losgekauft",
    "losgekauftes": "losgekauft",
    "losgekettet": "losketten",
    "losgekettete": "losgekettet",
    "losgekettetem": "losgekettet",
    "losgeketteten": "losgekettet",
    "losgeketteter": "losgekettet",
    "losgekettetes": "losgekettet",
    "losgekommen": "loskommen",
    "losgekommene": "losgekommen",
    "losgekommenem": "losgekommen",
    "losgekommenen": "losgekommen",
    "losgekommener": "losgekommen",
    "losgekommenes": "losgekommen",
    "losgekoppelt": "loskoppeln",
    "losgekoppelte": "losgekoppelt",
    "losgekoppeltem": "losgekoppelt",
    "losgekoppelten": "losgekoppelt",
    "losgekoppelter": "losgekoppelt",
    "losgekoppeltes": "losgekoppelt",
    "losgelacht": "loslachen",
    "losgelachte": "losgelacht",
    "losgelachtem": "losgelacht",
    "losgelachten": "losgelacht",
    "losgelachter": "losgelacht",
    "losgelachtes": "losgelacht",
    "losgelassen": "loslassen",
    "losgelassene": "losgelassen",
    "losgelassenem": "losgelassen",
    "losgelassenen": "losgelassen",
    "losgelassener": "losgelassen",
    "losgelassenere": "losgelassen",
    "losgelassenerem": "losgelassen",
    "losgelasseneren": "losgelassen",
    "losgelassenerer": "losgelassen",
    "losgelasseneres": "losgelassen",
    "losgelassenes": "losgelassen",
    "losgelassenste": "losgelassen",
    "losgelassenstem": "losgelassen",
    "losgelassensten": "losgelassen",
    "losgelassenster": "losgelassen",
    "losgelassenstes": "losgelassen",
    "losgelaufen": "loslaufen",
    "losgelaufene": "losgelaufen",
    "losgelaufenem": "losgelaufen",
    "losgelaufenen": "losgelaufen",
    "losgelaufener": "losgelaufen",
    "losgelaufenes": "losgelaufen",
    "losgelöst": "loslösen",
    "losgelöste": "losgelöst",
    "losgelöstem": "losgelöst",
    "losgelösten": "losgelöst",
    "losgelöster": "losgelöst",
    "losgelöstere": "losgelöst",
    "losgelösterem": "losgelöst",
    "losgelösteren": "losgelöst",
    "losgelösterer": "losgelöst",
    "losgelösteres": "losgelöst",
    "losgelöstes": "losgelöst",
    "losgelösteste": "losgelöst",
    "losgelöstestem": "losgelöst",
    "losgelöstesten": "losgelöst",
    "losgelöstester": "losgelöst",
    "losgelöstestes": "losgelöst",
    "losgemacht": "losmachen",
    "losgemachte": "losgemacht",
    "losgemachtem": "losgemacht",
    "losgemachten": "losgemacht",
    "losgemachter": "losgemacht",
    "losgemachtes": "losgemacht",
    "losgeplatzt": "losplatzen",
    "losgeplatzte": "losgeplatzt",
    "losgeplatztem": "losgeplatzt",
    "losgeplatzten": "losgeplatzt",
    "losgeplatzter": "losgeplatzt",
    "losgeplatztere": "losgeplatzt",
    "losgeplatzterem": "losgeplatzt",
    "losgeplatzteren": "losgeplatzt",
    "losgeplatzterer": "losgeplatzt",
    "losgeplatzteres": "losgeplatzt",
    "losgeplatztes": "losgeplatzt",
    "losgeplatzteste": "losgeplatzt",
    "losgeplatztestem": "losgeplatzt",
    "losgeplatztesten": "losgeplatzt",
    "losgeplatztester": "losgeplatzt",
    "losgeplatztestes": "losgeplatzt",
    "losgerannt": "losrennen",
    "losgerannte": "losgerannt",
    "losgeranntem": "losgerannt",
    "losgerannten": "losgerannt",
    "losgerannter": "losgerannt",
    "losgeranntes": "losgerannt",
    "losgerast": "losrasen",
    "losgeraste": "losgerast",
    "losgerastem": "losgerast",
    "losgerasten": "losgerast",
    "losgeraster": "losgerast",
    "losgerastes": "losgerast",
    "losgerissen": "losreißen",
    "losgerissene": "losgerissen",
    "losgerissenem": "losgerissen",
    "losgerissenen": "losgerissen",
    "losgerissener": "losgerissen",
    "losgerissenes": "losgerissen",
    "losgesagt": "lossagen",
    "losgesagte": "losgesagt",
    "losgesagtem": "losgesagt",
    "losgesagten": "losgesagt",
    "losgesagter": "losgesagt",
    "losgesagtes": "losgesagt",
    "losgeschlagen": "losschlagen",
    "losgeschlagene": "losgeschlagen",
    "losgeschlagenem": "losgeschlagen",
    "losgeschlagenen": "losgeschlagen",
    "losgeschlagener": "losgeschlagen",
    "losgeschlagenes": "losgeschlagen",
    "losgeschossen": "losschießen",
    "losgeschossene": "losgeschossen",
    "losgeschossenem": "losgeschossen",
    "losgeschossenen": "losgeschossen",
    "losgeschossener": "losgeschossen",
    "losgeschossenes": "losgeschossen",
    "losgeschraubt": "losschrauben",
    "losgeschraubte": "losgeschraubt",
    "losgeschraubtem": "losgeschraubt",
    "losgeschraubten": "losgeschraubt",
    "losgeschraubter": "losgeschraubt",
    "losgeschraubtes": "losgeschraubt",
    "losgesprochen": "lossprechen",
    "losgesprochene": "losgesprochen",
    "losgesprochenem": "losgesprochen",
    "losgesprochenen": "losgesprochen",
    "losgesprochener": "losgesprochen",
    "losgesprochenes": "losgesprochen",
    "losgesprungen": "losspringen",
    "losgesprungene": "losgesprungen",
    "losgesprungenem": "losgesprungen",
    "losgesprungenen": "losgesprungen",
    "losgesprungener": "losgesprungen",
    "losgesprungenes": "losgesprungen",
    "losgesteuert": "lossteuern",
    "losgesteuerte": "losgesteuert",
    "losgesteuertem": "losgesteuert",
    "losgesteuerten": "losgesteuert",
    "losgesteuerter": "losgesteuert",
    "losgesteuertes": "losgesteuert",
    "losgestürmt": "losstürmen",
    "losgestürmte": "losgestürmt",
    "losgestürmtem": "losgestürmt",
    "losgestürmten": "losgestürmt",
    "losgestürmter": "losgestürmt",
    "losgestürmtes": "losgestürmt",
    "losgetrennt": "lostrennen",
    "losgetrennte": "losgetrennt",
    "losgetrenntem": "losgetrennt",
    "losgetrennten": "losgetrennt",
    "losgetrennter": "losgetrennt",
    "losgetrenntes": "losgetrennt",
    "losgetreten": "lostreten",
    "losgetretene": "losgetreten",
    "losgetretenem": "losgetreten",
    "losgetretenen": "losgetreten",
    "losgetretener": "losgetreten",
    "losgetretenes": "losgetreten",
    "losgezogen": "losziehen",
    "losgezogene": "losgezogen",
    "losgezogenem": "losgezogen",
    "losgezogenen": "losgezogen",
    "losgezogener": "losgezogen",
    "losgezogenes": "losgezogen",
    "losgibst": "losgeben",
    "losgibt": "losgeben",
    "losging": "losgehen",
    "losginge": "losgehen",
    "losgingen": "losgehen",
    "losgingest": "losgehen",
    "losginget": "losgehen",
    "losgingst": "losgehen",
    "losgingt": "losgehen",
    "losgäbe": "losgeben",
    "losgäben": "losgeben",
    "losgäbest": "losgeben",
    "losgäbet": "losgeben",
    "loshauche": "loshauchen",
    "loshauchend": "loshauchen",
    "loshauchende": "loshauchend",
    "loshauchendem": "loshauchend",
    "loshauchenden": "loshauchend",
    "loshauchender": "loshauchend",
    "loshauchendes": "loshauchend",
    "loshauchest": "loshauchen",
    "loshauchet": "loshauchen",
    "loshauchst": "loshauchen",
    "loshaucht": "loshauchen",
    "loshauchte": "loshauchen",
    "loshauchten": "loshauchen",
    "loshauchtest": "loshauchen",
    "loshauchtet": "loshauchen",
    "loshaue": "loshauen",
    "loshauend": "loshauen",
    "loshauende": "loshauend",
    "loshauendem": "loshauend",
    "loshauenden": "loshauend",
    "loshauender": "loshauend",
    "loshauendes": "loshauend",
    "loshauest": "loshauen",
    "loshauet": "loshauen",
    "loshaust": "loshauen",
    "loshaut": "loshauen",
    "loshaute": "loshauen",
    "loshauten": "loshauen",
    "loshautest": "loshauen",
    "loshautet": "loshauen",
    "loskam": "loskommen",
    "loskamen": "loskommen",
    "loskamst": "loskommen",
    "loskamt": "loskommen",
    "loskaufend": "loskaufen",
    "loskaufende": "loskaufend",
    "loskaufendem": "loskaufend",
    "loskaufenden": "loskaufend",
    "loskaufender": "loskaufend",
    "loskaufendes": "loskaufend",
    "loskaufest": "loskaufen",
    "loskaufet": "loskaufen",
    "loskaufst": "loskaufen",
    "loskauft": "loskaufen",
    "loskaufte": "loskaufen",
    "loskauften": "loskaufen",
    "loskauftest": "loskaufen",
    "loskauftet": "loskaufen",
    "loskette": "losketten",
    "loskettend": "losketten",
    "loskettende": "loskettend",
    "loskettendem": "loskettend",
    "loskettenden": "loskettend",
    "loskettender": "loskettend",
    "loskettendes": "loskettend",
    "loskettest": "losketten",
    "loskettet": "losketten",
    "loskettete": "losketten",
    "losketteten": "losketten",
    "loskettetest": "losketten",
    "loskettetet": "losketten",
    "loskomme": "loskommen",
    "loskommend": "loskommen",
    "loskommende": "loskommend",
    "loskommendem": "loskommend",
    "loskommenden": "loskommend",
    "loskommender": "loskommend",
    "loskommendes": "loskommend",
    "loskommest": "loskommen",
    "loskommet": "loskommen",
    "loskommst": "loskommen",
    "loskommt": "loskommen",
    "loskoppele": "loskoppeln",
    "loskoppelnd": "loskoppeln",
    "loskoppelnde": "loskoppelnd",
    "loskoppelndem": "loskoppelnd",
    "loskoppelnden": "loskoppelnd",
    "loskoppelnder": "loskoppelnd",
    "loskoppelndes": "loskoppelnd",
    "loskoppelst": "loskoppeln",
    "loskoppelt": "loskoppeln",
    "loskoppelte": "loskoppeln",
    "loskoppelten": "loskoppeln",
    "loskoppeltest": "loskoppeln",
    "loskoppeltet": "loskoppeln",
    "loskopple": "loskoppeln",
    "loskäme": "loskommen",
    "loskämen": "loskommen",
    "loskämest": "loskommen",
    "loskämet": "loskommen",
    "loslache": "loslachen",
    "loslachend": "loslachen",
    "loslachende": "loslachend",
    "loslachendem": "loslachend",
    "loslachenden": "loslachend",
    "loslachender": "loslachend",
    "loslachendere": "loslachend",
    "loslachenderem": "loslachend",
    "loslachenderen": "loslachend",
    "loslachenderer": "loslachend",
    "loslachenderes": "loslachend",
    "loslachendes": "loslachend",
    "loslachendste": "loslachend",
    "loslachendstem": "loslachend",
    "loslachendsten": "loslachend",
    "loslachendster": "loslachend",
    "loslachendstes": "loslachend",
    "loslachest": "loslachen",
    "loslachet": "loslachen",
    "loslachst": "loslachen",
    "loslacht": "loslachen",
    "loslachte": "loslachen",
    "loslachten": "loslachen",
    "loslachtest": "loslachen",
    "loslachtet": "loslachen",
    "loslasse": "loslassen",
    "loslassend": "loslassen",
    "loslassende": "loslassend",
    "loslassendem": "loslassend",
    "loslassenden": "loslassend",
    "loslassender": "loslassend",
    "loslassendere": "loslassend",
    "loslassenderem": "loslassend",
    "loslassenderen": "loslassend",
    "loslassenderer": "loslassend",
    "loslassenderes": "loslassend",
    "loslassendes": "loslassend",
    "loslassendste": "loslassend",
    "loslassendstem": "loslassend",
    "loslassendsten": "loslassend",
    "loslassendster": "loslassend",
    "loslassendstes": "loslassend",
    "loslassest": "loslassen",
    "loslasset": "loslassen",
    "loslaufe": "loslaufen",
    "loslaufend": "loslaufen",
    "loslaufende": "loslaufend",
    "loslaufendem": "loslaufend",
    "loslaufenden": "loslaufend",
    "loslaufender": "loslaufend",
    "loslaufendes": "loslaufend",
    "loslaufest": "loslaufen",
    "loslaufet": "loslaufen",
    "loslauft": "loslaufen",
    "loslaßt": "loslassen",
    "loslief": "loslaufen",
    "losliefe": "loslaufen",
    "losliefen": "loslaufen",
    "losliefest": "loslaufen",
    "losliefet": "loslaufen",
    "losliefst": "loslaufen",
    "loslieft": "loslaufen",
    "losließ": "loslassen",
    "losließe": "loslassen",
    "losließen": "loslassen",
    "losließest": "loslassen",
    "losließet": "loslassen",
    "losließt": "loslassen",
    "losläufst": "loslaufen",
    "losläuft": "loslaufen",
    "losläßt": "loslassen",
    "loslöse": "loslösen",
    "loslösend": "loslösen",
    "loslösende": "loslösend",
    "loslösendem": "loslösend",
    "loslösenden": "loslösend",
    "loslösender": "loslösend",
    "loslösendere": "loslösend",
    "loslösenderem": "loslösend",
    "loslösenderen": "loslösend",
    "loslösenderer": "loslösend",
    "loslösenderes": "loslösend",
    "loslösendes": "loslösend",
    "loslösendste": "loslösend",
    "loslösendstem": "loslösend",
    "loslösendsten": "loslösend",
    "loslösendster": "loslösend",
    "loslösendstes": "loslösend",
    "loslösest": "loslösen",
    "loslöset": "loslösen",
    "loslöst": "loslösen",
    "loslöste": "loslösen",
    "loslösten": "loslösen",
    "loslöstest": "loslösen",
    "loslöstet": "loslösen",
    "losmache": "losmachen",
    "losmachend": "losmachen",
    "losmachende": "losmachend",
    "losmachendem": "losmachend",
    "losmachenden": "losmachend",
    "losmachender": "losmachend",
    "losmachendes": "losmachend",
    "losmachest": "losmachen",
    "losmachet": "losmachen",
    "losmachst": "losmachen",
    "losmacht": "losmachen",
    "losmachte": "losmachen",
    "losmachten": "losmachen",
    "losmachtest": "losmachen",
    "losmachtet": "losmachen",
    "losmarschiere": "losmarschieren",
    "losmarschierend": "losmarschieren",
    "losmarschierende": "losmarschierend",
    "losmarschierendem": "losmarschierend",
    "losmarschierenden": "losmarschierend",
    "losmarschierender": "losmarschierend",
    "losmarschierendes": "losmarschierend",
    "losmarschierest": "losmarschieren",
    "losmarschieret": "losmarschieren",
    "losmarschierst": "losmarschieren",
    "losmarschiert": "losmarschieren",
    "losmarschierte": "losmarschieren",
    "losmarschiertem": "losmarschiert",
    "losmarschierten": "losmarschieren",
    "losmarschierter": "losmarschiert",
    "losmarschiertes": "losmarschiert",
    "losmarschiertest": "losmarschieren",
    "losmarschiertet": "losmarschieren",
    "losplatze": "losplatzen",
    "losplatzend": "losplatzen",
    "losplatzende": "losplatzend",
    "losplatzendem": "losplatzend",
    "losplatzenden": "losplatzend",
    "losplatzender": "losplatzend",
    "losplatzendere": "losplatzend",
    "losplatzenderem": "losplatzend",
    "losplatzenderen": "losplatzend",
    "losplatzenderer": "losplatzend",
    "losplatzenderes": "losplatzend",
    "losplatzendes": "losplatzend",
    "losplatzendste": "losplatzend",
    "losplatzendstem": "losplatzend",
    "losplatzendsten": "losplatzend",
    "losplatzendster": "losplatzend",
    "losplatzendstes": "losplatzend",
    "losplatzest": "losplatzen",
    "losplatzet": "losplatzen",
    "losplatzt": "losplatzen",
    "losplatzte": "losplatzen",
    "losplatzten": "losplatzen",
    "losplatztest": "losplatzen",
    "losplatztet": "losplatzen",
    "losrannte": "losrennen",
    "losrannten": "losrennen",
    "losranntest": "losrennen",
    "losranntet": "losrennen",
    "losrase": "losrasen",
    "losrasend": "losrasen",
    "losrasende": "losrasend",
    "losrasendem": "losrasend",
    "losrasenden": "losrasend",
    "losrasender": "losrasend",
    "losrasendes": "losrasend",
    "losrasest": "losrasen",
    "losraset": "losrasen",
    "losrast": "losrasen",
    "losraste": "losrasen",
    "losrasten": "losrasen",
    "losrastest": "losrasen",
    "losrastet": "losrasen",
    "losreiße": "losreißen",
    "losreißend": "losreißen",
    "losreißende": "losreißend",
    "losreißendem": "losreißend",
    "losreißenden": "losreißend",
    "losreißender": "losreißend",
    "losreißendes": "losreißend",
    "losreißest": "losreißen",
    "losreißet": "losreißen",
    "losreißt": "losreißen",
    "losrenne": "losrennen",
    "losrennend": "losrennen",
    "losrennende": "losrennend",
    "losrennendem": "losrennend",
    "losrennenden": "losrennend",
    "losrennender": "losrennend",
    "losrennendes": "losrennend",
    "losrennest": "losrennen",
    "losrennet": "losrennen",
    "losrennst": "losrennen",
    "losrennt": "losrennen",
    "losrisse": "losreißen",
    "losrissen": "losreißen",
    "losrissest": "losreißen",
    "losrisset": "losreißen",
    "losriß": "losreißen",
    "losrißt": "losreißen",
    "lossage": "lossagen",
    "lossagend": "lossagen",
    "lossagende": "lossagend",
    "lossagendem": "lossagend",
    "lossagenden": "lossagend",
    "lossagender": "lossagend",
    "lossagendes": "lossagend",
    "lossagest": "lossagen",
    "lossaget": "lossagen",
    "lossagst": "lossagen",
    "lossagt": "lossagen",
    "lossagte": "lossagen",
    "lossagten": "lossagen",
    "lossagtest": "lossagen",
    "lossagtet": "lossagen",
    "losschieße": "losschießen",
    "losschießend": "losschießen",
    "losschießende": "losschießend",
    "losschießendem": "losschießend",
    "losschießenden": "losschießend",
    "losschießender": "losschießend",
    "losschießendes": "losschießend",
    "losschießest": "losschießen",
    "losschießet": "losschießen",
    "losschießt": "losschießen",
    "losschlage": "losschlagen",
    "losschlagend": "losschlagen",
    "losschlagende": "losschlagend",
    "losschlagendem": "losschlagend",
    "losschlagenden": "losschlagend",
    "losschlagender": "losschlagend",
    "losschlagendes": "losschlagend",
    "losschlagest": "losschlagen",
    "losschlaget": "losschlagen",
    "losschlagt": "losschlagen",
    "losschlug": "losschlagen",
    "losschlugen": "losschlagen",
    "losschlugst": "losschlagen",
    "losschlugt": "losschlagen",
    "losschlägst": "losschlagen",
    "losschlägt": "losschlagen",
    "losschlüge": "losschlagen",
    "losschlügen": "losschlagen",
    "losschlügest": "losschlagen",
    "losschlüget": "losschlagen",
    "losschossen": "losschießen",
    "losschoß": "losschießen",
    "losschoßt": "losschießen",
    "losschraube": "losschrauben",
    "losschraubend": "losschrauben",
    "losschraubende": "losschraubend",
    "losschraubendem": "losschraubend",
    "losschraubenden": "losschraubend",
    "losschraubender": "losschraubend",
    "losschraubendes": "losschraubend",
    "losschraubest": "losschrauben",
    "losschraubet": "losschrauben",
    "losschraubst": "losschrauben",
    "losschraubt": "losschrauben",
    "losschraubte": "losschrauben",
    "losschraubten": "losschrauben",
    "losschraubtest": "losschrauben",
    "losschraubtet": "losschrauben",
    "losschösse": "losschießen",
    "losschössen": "losschießen",
    "losschössest": "losschießen",
    "losschösset": "losschießen",
    "lossprach": "lossprechen",
    "lossprachen": "lossprechen",
    "lossprachst": "lossprechen",
    "losspracht": "lossprechen",
    "lossprang": "losspringen",
    "lossprangen": "losspringen",
    "lossprangst": "losspringen",
    "lossprangt": "losspringen",
    "losspreche": "lossprechen",
    "lossprechend": "lossprechen",
    "lossprechende": "lossprechend",
    "lossprechendem": "lossprechend",
    "lossprechenden": "lossprechend",
    "lossprechender": "lossprechend",
    "lossprechendes": "lossprechend",
    "lossprechest": "lossprechen",
    "lossprechet": "lossprechen",
    "lossprecht": "lossprechen",
    "lossprichst": "lossprechen",
    "losspricht": "lossprechen",
    "losspringe": "losspringen",
    "losspringend": "losspringen",
    "losspringende": "losspringend",
    "losspringendem": "losspringend",
    "losspringenden": "losspringend",
    "losspringender": "losspringend",
    "losspringendes": "losspringend",
    "losspringest": "losspringen",
    "losspringet": "losspringen",
    "losspringst": "losspringen",
    "losspringt": "losspringen",
    "losspräche": "lossprechen",
    "lossprächen": "lossprechen",
    "lossprächest": "lossprechen",
    "lossprächet": "lossprechen",
    "losspränge": "losspringen",
    "lossprängen": "losspringen",
    "lossprängest": "losspringen",
    "losspränget": "losspringen",
    "lossteuere": "lossteuern",
    "lossteuernd": "lossteuern",
    "lossteuernde": "lossteuernd",
    "lossteuerndem": "lossteuernd",
    "lossteuernden": "lossteuernd",
    "lossteuernder": "lossteuernd",
    "lossteuerndes": "lossteuernd",
    "lossteuerst": "lossteuern",
    "lossteuert": "lossteuern",
    "lossteuerte": "lossteuern",
    "lossteuerten": "lossteuern",
    "lossteuertest": "lossteuern",
    "lossteuertet": "lossteuern",
    "losstürme": "losstürmen",
    "losstürmend": "losstürmen",
    "losstürmende": "losstürmend",
    "losstürmendem": "losstürmend",
    "losstürmenden": "losstürmend",
    "losstürmender": "losstürmend",
    "losstürmendes": "losstürmend",
    "losstürmest": "losstürmen",
    "losstürmet": "losstürmen",
    "losstürmst": "losstürmen",
    "losstürmt": "losstürmen",
    "losstürmte": "losstürmen",
    "losstürmten": "losstürmen",
    "losstürmtest": "losstürmen",
    "losstürmtet": "losstürmen",
    "lost": "losen",
    "loste": "losen",
    "losten": "losen",
    "lostest": "losen",
    "lostet": "losen",
    "lostrat": "lostreten",
    "lostraten": "lostreten",
    "lostratest": "lostreten",
    "lostratet": "lostreten",
    "lostrenne": "lostrennen",
    "lostrennend": "lostrennen",
    "lostrennende": "lostrennend",
    "lostrennendem": "lostrennend",
    "lostrennenden": "lostrennend",
    "lostrennender": "lostrennend",
    "lostrennendes": "lostrennend",
    "lostrennest": "lostrennen",
    "lostrennet": "lostrennen",
    "lostrennst": "lostrennen",
    "lostrennt": "lostrennen",
    "lostrennte": "lostrennen",
    "lostrennten": "lostrennen",
    "lostrenntest": "lostrennen",
    "lostrenntet": "lostrennen",
    "lostrete": "lostreten",
    "lostretend": "lostreten",
    "lostretende": "lostretend",
    "lostretendem": "lostretend",
    "lostretenden": "lostretend",
    "lostretender": "lostretend",
    "lostretendes": "lostretend",
    "lostretest": "lostreten",
    "lostretet": "lostreten",
    "lostritt": "lostreten",
    "lostrittst": "lostreten",
    "losträte": "lostreten",
    "losträten": "lostreten",
    "losträtest": "lostreten",
    "losträtet": "lostreten",
    "losziehe": "losziehen",
    "losziehend": "losziehen",
    "losziehende": "losziehend",
    "losziehendem": "losziehend",
    "losziehenden": "losziehend",
    "losziehender": "losziehend",
    "losziehendes": "losziehend",
    "losziehest": "losziehen",
    "losziehet": "losziehen",
    "losziehst": "losziehen",
    "loszieht": "losziehen",
    "loszog": "losziehen",
    "loszogen": "losziehen",
    "loszogst": "losziehen",
    "loszogt": "losziehen",
    "loszuarbeiten": "losarbeiten",
    "loszubekommen": "losbekommen",
    "loszubinden": "losbinden",
    "loszubrausen": "losbrausen",
    "loszubrechen": "losbrechen",
    "loszubringen": "losbringen",
    "loszudonnern": "losdonnern",
    "loszueisen": "loseisen",
    "loszugeben": "losgeben",
    "loszugehen": "losgehen",
    "loszuhauchen": "loshauchen",
    "loszuhauen": "loshauen",
    "loszukaufen": "loskaufen",
    "loszuketten": "losketten",
    "loszukommen": "loskommen",
    "loszukoppeln": "loskoppeln",
    "loszulachen": "loslachen",
    "loszulassen": "loslassen",
    "loszulaufen": "loslaufen",
    "loszulösen": "loslösen",
    "loszumachen": "losmachen",
    "loszumarschieren": "losmarschieren",
    "loszuplatzen": "losplatzen",
    "loszurasen": "losrasen",
    "loszureißen": "losreißen",
    "loszurennen": "losrennen",
    "loszusagen": "lossagen",
    "loszuschießen": "losschießen",
    "loszuschlagen": "losschlagen",
    "loszuschrauben": "losschrauben",
    "loszusprechen": "lossprechen",
    "loszuspringen": "losspringen",
    "loszusteuern": "lossteuern",
    "loszustürmen": "losstürmen",
    "loszutrennen": "lostrennen",
    "loszutreten": "lostreten",
    "loszuziehen": "losziehen",
    "loszöge": "losziehen",
    "loszögen": "losziehen",
    "loszögest": "losziehen",
    "loszöget": "losziehen",
    "lote": "loten",
    "lotend": "loten",
    "lotende": "lotend",
    "lotendem": "lotend",
    "lotenden": "lotend",
    "lotender": "lotend",
    "lotendes": "lotend",
    "lotest": "loten",
    "lotet": "loten",
    "lotete": "loten",
    "loteten": "loten",
    "lotetest": "loten",
    "lotetet": "loten",
    "lotrechtem": "lotrecht",
    "lotrechten": "lotrecht",
    "lotrechter": "lotrecht",
    "lotrechtes": "lotrecht",
    "lotse": "lotsen",
    "lotsend": "lotsen",
    "lotsende": "lotsend",
    "lotsendem": "lotsend",
    "lotsenden": "lotsend",
    "lotsender": "lotsend",
    "lotsendes": "lotsend",
    "lotsest": "lotsen",
    "lotset": "lotsen",
    "lotst": "lotsen",
    "lotste": "lotsen",
    "lotsten": "lotsen",
    "lotstest": "lotsen",
    "lotstet": "lotsen",
    "lottere": "lottern",
    "lotterigem": "lotterig",
    "lotterigen": "lotterig",
    "lotteriger": "lotterig",
    "lotterigere": "lotterig",
    "lotterigerem": "lotterig",
    "lotterigeren": "lotterig",
    "lotterigerer": "lotterig",
    "lotterigeres": "lotterig",
    "lotteriges": "lotterig",
    "lotterigste": "lotterig",
    "lotterigstem": "lotterig",
    "lotterigsten": "lotterig",
    "lotterigster": "lotterig",
    "lotterigstes": "lotterig",
    "lotternd": "lottern",
    "lotternde": "lotternd",
    "lotterndem": "lotternd",
    "lotternden": "lotternd",
    "lotternder": "lotternd",
    "lotterndere": "lotternd",
    "lotternderem": "lotternd",
    "lotternderen": "lotternd",
    "lotternderer": "lotternd",
    "lotternderes": "lotternd",
    "lotterndes": "lotternd",
    "lotterndste": "lotternd",
    "lotterndstem": "lotternd",
    "lotterndsten": "lotternd",
    "lotterndster": "lotternd",
    "lotterndstes": "lotternd",
    "lotterst": "lottern",
    "lottert": "lottern",
    "lotterte": "lottern",
    "lotterten": "lottern",
    "lottertest": "lottern",
    "lottertet": "lottern",
    "lud": "laden",
    "luden": "laden",
    "ludest": "laden",
    "ludet": "laden",
    "luftdichtem": "luftdicht",
    "luftdichten": "luftdicht",
    "luftdichter": "luftdicht",
    "luftdichtes": "luftdicht",
    "luftige": "luftig",
    "luftigem": "luftig",
    "luftigen": "luftig",
    "luftiger": "luftig",
    "luftigere": "luftig",
    "luftigerem": "luftig",
    "luftigeren": "luftig",
    "luftigerer": "luftig",
    "luftigeres": "luftig",
    "luftiges": "luftig",
    "luftigste": "luftig",
    "luftigstem": "luftig",
    "luftigsten": "luftig",
    "luftigster": "luftig",
    "luftigstes": "luftig",
    "luftleere": "luftleer",
    "luftleerem": "luftleer",
    "luftleeren": "luftleer",
    "luftleerer": "luftleer",
    "luftleeres": "luftleer",
    "luge": "lugen",
    "lugend": "lugen",
    "lugende": "lugend",
    "lugendem": "lugend",
    "lugenden": "lugend",
    "lugender": "lugend",
    "lugendes": "lugend",
    "lugest": "lugen",
    "luget": "lugen",
    "lugst": "lugen",
    "lugt": "lugen",
    "lugte": "lugen",
    "lugten": "lugen",
    "lugtest": "lugen",
    "lugtet": "lugen",
    "lukrativem": "lukrativ",
    "lukrativen": "lukrativ",
    "lukrativer": "lukrativ",
    "lukrativere": "lukrativ",
    "lukrativerem": "lukrativ",
    "lukrativeren": "lukrativ",
    "lukrativerer": "lukrativ",
    "lukrativeres": "lukrativ",
    "lukratives": "lukrativ",
    "lukrativste": "lukrativ",
    "lukrativstem": "lukrativ",
    "lukrativsten": "lukrativ",
    "lukrativster": "lukrativ",
    "lukrativstes": "lukrativ",
    "lulle": "lullen",
    "lullend": "lullen",
    "lullende": "lullend",
    "lullendem": "lullend",
    "lullenden": "lullend",
    "lullender": "lullend",
    "lullendes": "lullend",
    "lullest": "lullen",
    "lullet": "lullen",
    "lullst": "lullen",
    "lullt": "lullen",
    "lullte": "lullen",
    "lullten": "lullen",
    "lulltest": "lullen",
    "lulltet": "lullen",
    "lumpigem": "lumpig",
    "lumpigen": "lumpig",
    "lumpiger": "lumpig",
    "lumpigere": "lumpig",
    "lumpigerem": "lumpig",
    "lumpigeren": "lumpig",
    "lumpigerer": "lumpig",
    "lumpigeres": "lumpig",
    "lumpiges": "lumpig",
    "lumpigste": "lumpig",
    "lumpigstem": "lumpig",
    "lumpigsten": "lumpig",
    "lumpigster": "lumpig",
    "lumpigstes": "lumpig",
    "lunatischem": "lunatisch",
    "lunatischen": "lunatisch",
    "lunatischer": "lunatisch",
    "lunatisches": "lunatisch",
    "lungenkrankem": "lungenkrank",
    "lungenkranken": "lungenkrank",
    "lungenkranker": "lungenkrank",
    "lungenkrankes": "lungenkrank",
    "lungere": "lungern",
    "lungernd": "lungern",
    "lungernde": "lungernd",
    "lungerndem": "lungernd",
    "lungernden": "lungernd",
    "lungernder": "lungernd",
    "lungerndes": "lungernd",
    "lungerst": "lungern",
    "lungert": "lungern",
    "lungerte": "lungern",
    "lungerten": "lungern",
    "lungertest": "lungern",
    "lungertet": "lungern",
    "lupenreinem": "lupenrein",
    "lupenreinen": "lupenrein",
    "lupenreiner": "lupenrein",
    "lupenreines": "lupenrein",
    "lupfe": "lupfen",
    "lupfend": "lupfen",
    "lupfende": "lupfend",
    "lupfendem": "lupfend",
    "lupfenden": "lupfend",
    "lupfender": "lupfend",
    "lupfendes": "lupfend",
    "lupfest": "lupfen",
    "lupfet": "lupfen",
    "lupfst": "lupfen",
    "lupft": "lupfen",
    "lupfte": "lupfen",
    "lupften": "lupfen",
    "lupftest": "lupfen",
    "lupftet": "lupfen",
    "lustbetontem": "lustbetont",
    "lustbetonten": "lustbetont",
    "lustbetonter": "lustbetont",
    "lustbetontere": "lustbetont",
    "lustbetonterem": "lustbetont",
    "lustbetonteren": "lustbetont",
    "lustbetonterer": "lustbetont",
    "lustbetonteres": "lustbetont",
    "lustbetontes": "lustbetont",
    "lustbetonteste": "lustbetont",
    "lustbetontestem": "lustbetont",
    "lustbetontesten": "lustbetont",
    "lustbetontester": "lustbetont",
    "lustbetontestes": "lustbetont",
    "lustigem": "lustig",
    "lustigen": "lustig",
    "lustiger": "lustig",
    "lustigere": "lustig",
    "lustigerem": "lustig",
    "lustigeren": "lustig",
    "lustigerer": "lustig",
    "lustigeres": "lustig",
    "lustiges": "lustig",
    "lustigste": "lustig",
    "lustigstem": "lustig",
    "lustigsten": "lustig",
    "lustigster": "lustig",
    "lustigstes": "lustig",
    "lustlosem": "lustlos",
    "lustlosen": "lustlos",
    "lustloser": "lustlos",
    "lustlosere": "lustlos",
    "lustloserem": "lustlos",
    "lustloseren": "lustlos",
    "lustloserer": "lustlos",
    "lustloseres": "lustlos",
    "lustloses": "lustlos",
    "lustloseste": "lustlos",
    "lustlosestem": "lustlos",
    "lustlosesten": "lustlos",
    "lustlosester": "lustlos",
    "lustlosestes": "lustlos",
    "lustvollem": "lustvoll",
    "lustvollen": "lustvoll",
    "lustvoller": "lustvoll",
    "lustvollere": "lustvoll",
    "lustvollerem": "lustvoll",
    "lustvolleren": "lustvoll",
    "lustvollerer": "lustvoll",
    "lustvolleres": "lustvoll",
    "lustvolles": "lustvoll",
    "lustvollste": "lustvoll",
    "lustvollstem": "lustvoll",
    "lustvollsten": "lustvoll",
    "lustvollster": "lustvoll",
    "lustvollstes": "lustvoll",
    "lutsche": "lutschen",
    "lutschend": "lutschen",
    "lutschende": "lutschend",
    "lutschendem": "lutschend",
    "lutschenden": "lutschend",
    "lutschender": "lutschend",
    "lutschendes": "lutschend",
    "lutschest": "lutschen",
    "lutschet": "lutschen",
    "lutschst": "lutschen",
    "lutscht": "lutschen",
    "lutschte": "lutschen",
    "lutschten": "lutschen",
    "lutschtest": "lutschen",
    "lutschtet": "lutschen",
    "luxuriösem": "luxuriös",
    "luxuriösen": "luxuriös",
    "luxuriöser": "luxuriös",
    "luxuriösere": "luxuriös",
    "luxuriöserem": "luxuriös",
    "luxuriöseren": "luxuriös",
    "luxuriöserer": "luxuriös",
    "luxuriöseres": "luxuriös",
    "luxuriöses": "luxuriös",
    "luxuriöseste": "luxuriös",
    "luxuriösestem": "luxuriös",
    "luxuriösesten": "luxuriös",
    "luxuriösester": "luxuriös",
    "luxuriösestes": "luxuriös",
    "lyrischem": "lyrisch",
    "lyrischen": "lyrisch",
    "lyrischer": "lyrisch",
    "lyrischere": "lyrisch",
    "lyrischerem": "lyrisch",
    "lyrischeren": "lyrisch",
    "lyrischerer": "lyrisch",
    "lyrischeres": "lyrisch",
    "lyrisches": "lyrisch",
    "lyrischste": "lyrisch",
    "lyrischstem": "lyrisch",
    "lyrischsten": "lyrisch",
    "lyrischster": "lyrisch",
    "lyrischstes": "lyrisch",
    "lächele": "lächeln",
    "lächelnd": "lächeln",
    "lächelnde": "lächelnd",
    "lächelndem": "lächelnd",
    "lächelnden": "lächelnd",
    "lächelnder": "lächelnd",
    "lächelndere": "lächelnd",
    "lächelnderem": "lächelnd",
    "lächelnderen": "lächelnd",
    "lächelnderer": "lächelnd",
    "lächelnderes": "lächelnd",
    "lächelndes": "lächelnd",
    "lächelndste": "lächelnd",
    "lächelndstem": "lächelnd",
    "lächelndsten": "lächelnd",
    "lächelndster": "lächelnd",
    "lächelndstes": "lächelnd",
    "lächelst": "lächeln",
    "lächelt": "lächeln",
    "lächelte": "lächeln",
    "lächelten": "lächeln",
    "lächeltest": "lächeln",
    "lächeltet": "lächeln",
    "lächerlichem": "lächerlich",
    "lächerlichen": "lächerlich",
    "lächerlicher": "lächerlich",
    "lächerlichere": "lächerlich",
    "lächerlicherem": "lächerlich",
    "lächerlicheren": "lächerlich",
    "lächerlicherer": "lächerlich",
    "lächerlicheres": "lächerlich",
    "lächerliches": "lächerlich",
    "lächerlichstem": "lächerlich",
    "lächerlichsten": "lächerlich",
    "lächerlichster": "lächerlich",
    "lächerlichstes": "lächerlich",
    "lächle": "lächeln",
    "lädiere": "lädieren",
    "lädierend": "lädieren",
    "lädierende": "lädierend",
    "lädierendem": "lädierend",
    "lädierenden": "lädierend",
    "lädierender": "lädierend",
    "lädierendere": "lädierend",
    "lädierenderem": "lädierend",
    "lädierenderen": "lädierend",
    "lädierenderer": "lädierend",
    "lädierenderes": "lädierend",
    "lädierendes": "lädierend",
    "lädierendste": "lädierend",
    "lädierendstem": "lädierend",
    "lädierendsten": "lädierend",
    "lädierendster": "lädierend",
    "lädierendstes": "lädierend",
    "lädierest": "lädieren",
    "lädieret": "lädieren",
    "lädierst": "lädieren",
    "lädiert": "lädieren",
    "lädierte": "lädieren",
    "lädiertem": "lädiert",
    "lädierten": "lädieren",
    "lädierter": "lädiert",
    "lädiertere": "lädiert",
    "lädierterem": "lädiert",
    "lädierteren": "lädiert",
    "lädierterer": "lädiert",
    "lädierteres": "lädiert",
    "lädiertes": "lädiert",
    "lädiertest": "lädieren",
    "lädierteste": "lädiert",
    "lädiertestem": "lädiert",
    "lädiertesten": "lädiert",
    "lädiertester": "lädiert",
    "lädiertestes": "lädiert",
    "lädiertet": "lädieren",
    "lädst": "laden",
    "lädt": "laden",
    "läge": "liegen",
    "lägen": "liegen",
    "lägest": "liegen",
    "läget": "liegen",
    "lähme": "lähmen",
    "lähmend": "lähmen",
    "lähmendem": "lähmend",
    "lähmender": "lähmend",
    "lähmenderem": "lähmend",
    "lähmenderer": "lähmend",
    "lähmenderes": "lähmend",
    "lähmendes": "lähmend",
    "lähmendstem": "lähmend",
    "lähmendster": "lähmend",
    "lähmendstes": "lähmend",
    "lähmest": "lähmen",
    "lähmet": "lähmen",
    "lähmst": "lähmen",
    "lähmt": "lähmen",
    "lähmte": "lähmen",
    "lähmten": "lähmen",
    "lähmtest": "lähmen",
    "lähmtet": "lähmen",
    "ländliche": "ländlich",
    "ländlichem": "ländlich",
    "ländlichen": "ländlich",
    "ländlicher": "ländlich",
    "ländlichere": "ländlich",
    "ländlicherem": "ländlich",
    "ländlicheren": "ländlich",
    "ländlicherer": "ländlich",
    "ländlicheres": "ländlich",
    "ländliches": "ländlich",
    "ländlichste": "ländlich",
    "ländlichstem": "ländlich",
    "ländlichsten": "ländlich",
    "ländlichster": "ländlich",
    "ländlichstes": "ländlich",
    "länger": "lang",
    "längere": "lang",
    "längerem": "lang",
    "längeren": "lang",
    "längerer": "lang",
    "längeres": "lang",
    "längerfristige": "längerfristig",
    "längerfristigem": "längerfristig",
    "längerfristigen": "längerfristig",
    "längerfristiger": "längerfristig",
    "längerfristiges": "längerfristig",
    "längliche": "länglich",
    "länglichem": "länglich",
    "länglichen": "länglich",
    "länglicher": "länglich",
    "länglichere": "länglich",
    "länglicherem": "länglich",
    "länglicheren": "länglich",
    "länglicherer": "länglich",
    "länglicheres": "länglich",
    "längliches": "länglich",
    "länglichste": "länglich",
    "länglichstem": "länglich",
    "länglichsten": "länglich",
    "länglichster": "länglich",
    "länglichstes": "länglich",
    "längstem": "lang",
    "längsten": "lang",
    "längster": "lang",
    "längstes": "lang",
    "läppere": "läppern",
    "läppernd": "läppern",
    "läppernde": "läppernd",
    "läpperndem": "läppernd",
    "läppernden": "läppernd",
    "läppernder": "läppernd",
    "läpperndes": "läppernd",
    "läpperst": "läppern",
    "läppert": "läppern",
    "läpperte": "läppern",
    "läpperten": "läppern",
    "läppertest": "läppern",
    "läppertet": "läppern",
    "lärme": "lärmen",
    "lärmend": "lärmen",
    "lärmende": "lärmend",
    "lärmendem": "lärmend",
    "lärmenden": "lärmend",
    "lärmender": "lärmend",
    "lärmendere": "lärmend",
    "lärmenderem": "lärmend",
    "lärmenderen": "lärmend",
    "lärmenderer": "lärmend",
    "lärmenderes": "lärmend",
    "lärmendes": "lärmend",
    "lärmendste": "lärmend",
    "lärmendstem": "lärmend",
    "lärmendsten": "lärmend",
    "lärmendster": "lärmend",
    "lärmendstes": "lärmend",
    "lärmest": "lärmen",
    "lärmet": "lärmen",
    "lärmst": "lärmen",
    "lärmt": "lärmen",
    "lärmte": "lärmen",
    "lärmten": "lärmen",
    "lärmtest": "lärmen",
    "lärmtet": "lärmen",
    "läse": "lesen",
    "läsen": "lesen",
    "läsest": "lesen",
    "läset": "lesen",
    "lässige": "lässig",
    "lässigem": "lässig",
    "lässigen": "lässig",
    "lässiger": "lässig",
    "lässigere": "lässig",
    "lässigerem": "lässig",
    "lässigeren": "lässig",
    "lässigerer": "lässig",
    "lässigeres": "lässig",
    "lässiges": "lässig",
    "lässigstem": "lässig",
    "lässigsten": "lässig",
    "lässigster": "lässig",
    "lässigstes": "lässig",
    "lästere": "lästern",
    "lästernd": "lästern",
    "lästernde": "lästernd",
    "lästerndem": "lästernd",
    "lästernden": "lästernd",
    "lästernder": "lästernd",
    "lästerndere": "lästernd",
    "lästernderem": "lästernd",
    "lästernderen": "lästernd",
    "lästernderer": "lästernd",
    "lästernderes": "lästernd",
    "lästerndes": "lästernd",
    "lästerndste": "lästernd",
    "lästerndstem": "lästernd",
    "lästerndsten": "lästernd",
    "lästerndster": "lästernd",
    "lästerndstes": "lästernd",
    "lästerst": "lästern",
    "lästert": "lästern",
    "lästerte": "lästern",
    "lästerten": "lästern",
    "lästertest": "lästern",
    "lästertet": "lästern",
    "lästige": "lästig",
    "lästigem": "lästig",
    "lästigen": "lästig",
    "lästiger": "lästig",
    "lästigere": "lästig",
    "lästigerem": "lästig",
    "lästigeren": "lästig",
    "lästigerer": "lästig",
    "lästigeres": "lästig",
    "lästiges": "lästig",
    "lästigste": "lästig",
    "lästigstem": "lästig",
    "lästigsten": "lästig",
    "lästigster": "lästig",
    "lästigstes": "lästig",
    "läufige": "läufig",
    "läufigem": "läufig",
    "läufigen": "läufig",
    "läufiger": "läufig",
    "läufigere": "läufig",
    "läufigerem": "läufig",
    "läufigeren": "läufig",
    "läufigerer": "läufig",
    "läufigeres": "läufig",
    "läufiges": "läufig",
    "läufigste": "läufig",
    "läufigstem": "läufig",
    "läufigsten": "läufig",
    "läufigster": "läufig",
    "läufigstes": "läufig",
    "läufst": "laufen",
    "läuft": "laufen",
    "läute": "läuten",
    "läutend": "läuten",
    "läutendem": "läutend",
    "läutender": "läutend",
    "läutendes": "läutend",
    "läutest": "läuten",
    "läutet": "läuten",
    "läutete": "läuten",
    "läuteten": "läuten",
    "läutetest": "läuten",
    "läutetet": "läuten",
    "läßt": "lassen",
    "löblichem": "löblich",
    "löblichen": "löblich",
    "löblicher": "löblich",
    "löbliches": "löblich",
    "löchere": "löchern",
    "löcherige": "löcherig",
    "löcherigem": "löcherig",
    "löcherigen": "löcherig",
    "löcheriger": "löcherig",
    "löcherigere": "löcherig",
    "löcherigerem": "löcherig",
    "löcherigeren": "löcherig",
    "löcherigerer": "löcherig",
    "löcherigeres": "löcherig",
    "löcheriges": "löcherig",
    "löcherigste": "löcherig",
    "löcherigstem": "löcherig",
    "löcherigsten": "löcherig",
    "löcherigster": "löcherig",
    "löcherigstes": "löcherig",
    "löchernd": "löchern",
    "löchernde": "löchernd",
    "löcherndem": "löchernd",
    "löchernden": "löchernd",
    "löchernder": "löchernd",
    "löcherndes": "löchernd",
    "löcherst": "löchern",
    "löchert": "löchern",
    "löcherte": "löchern",
    "löcherten": "löchern",
    "löchertest": "löchern",
    "löchertet": "löchern",
    "löchrigem": "löchrig",
    "löchrigen": "löchrig",
    "löchriger": "löchrig",
    "löchrigere": "löchrig",
    "löchrigerem": "löchrig",
    "löchrigeren": "löchrig",
    "löchrigerer": "löchrig",
    "löchrigeres": "löchrig",
    "löchriges": "löchrig",
    "löchrigste": "löchrig",
    "löchrigstem": "löchrig",
    "löchrigsten": "löchrig",
    "löchrigster": "löchrig",
    "löchrigstes": "löchrig",
    "löffele": "löffeln",
    "löffelnd": "löffeln",
    "löffelnde": "löffelnd",
    "löffelndem": "löffelnd",
    "löffelnden": "löffelnd",
    "löffelnder": "löffelnd",
    "löffelndes": "löffelnd",
    "löffelst": "löffeln",
    "löffelt": "löffeln",
    "löffelte": "löffeln",
    "löffelten": "löffeln",
    "löffeltest": "löffeln",
    "löffeltet": "löffeln",
    "löffle": "löffeln",
    "löge": "lügen",
    "lögen": "lügen",
    "lögest": "lügen",
    "löget": "lügen",
    "löhne": "löhnen",
    "löhnend": "löhnen",
    "löhnendem": "löhnend",
    "löhnender": "löhnend",
    "löhnendes": "löhnend",
    "löhnest": "löhnen",
    "löhnet": "löhnen",
    "löhnst": "löhnen",
    "löhnt": "löhnen",
    "löhnte": "löhnen",
    "löhnten": "löhnen",
    "löhntest": "löhnen",
    "löhntet": "löhnen",
    "lösbare": "lösbar",
    "lösbarem": "lösbar",
    "lösbaren": "lösbar",
    "lösbarer": "lösbar",
    "lösbares": "lösbar",
    "lösche": "löschen",
    "löschend": "löschen",
    "löschende": "löschend",
    "löschendem": "löschend",
    "löschenden": "löschend",
    "löschender": "löschend",
    "löschendes": "löschend",
    "löschest": "löschen",
    "löschet": "löschen",
    "löschst": "löschen",
    "löscht": "löschen",
    "löschte": "löschen",
    "löschten": "löschen",
    "löschtest": "löschen",
    "löschtet": "löschen",
    "löse": "lösen",
    "lösend": "lösen",
    "lösendem": "lösend",
    "lösender": "lösend",
    "lösendes": "lösend",
    "lösest": "lösen",
    "löset": "lösen",
    "lösliche": "löslich",
    "löslichem": "löslich",
    "löslichen": "löslich",
    "löslicher": "löslich",
    "löslichere": "löslich",
    "löslicherem": "löslich",
    "löslicheren": "löslich",
    "löslicherer": "löslich",
    "löslicheres": "löslich",
    "lösliches": "löslich",
    "löslichste": "löslich",
    "löslichstem": "löslich",
    "löslichsten": "löslich",
    "löslichster": "löslich",
    "löslichstes": "löslich",
    "löst": "lösen",
    "löste": "lösen",
    "lösten": "lösen",
    "löstest": "lösen",
    "löstet": "lösen",
    "löte": "löten",
    "lötend": "löten",
    "lötendem": "lötend",
    "lötender": "lötend",
    "lötendes": "lötend",
    "lötest": "löten",
    "lötet": "löten",
    "lötete": "löten",
    "löteten": "löten",
    "lötetest": "löten",
    "lötetet": "löten",
    "löwenstarkem": "löwenstark",
    "löwenstarken": "löwenstark",
    "löwenstarker": "löwenstark",
    "löwenstarkes": "löwenstark",
    "lüde": "laden",
    "lüden": "laden",
    "lüdest": "laden",
    "lüdet": "laden",
    "lüftend": "lüften",
    "lüftende": "lüftend",
    "lüftendem": "lüftend",
    "lüftenden": "lüftend",
    "lüftender": "lüftend",
    "lüftendes": "lüftend",
    "lüftest": "lüften",
    "lüftet": "lüften",
    "lüftete": "lüften",
    "lüfteten": "lüften",
    "lüftetest": "lüften",
    "lüftetet": "lüften",
    "lüge": "lügen",
    "lügend": "lügen",
    "lügendem": "lügend",
    "lügender": "lügend",
    "lügendes": "lügend",
    "lügenhafte": "lügenhaft",
    "lügenhaftem": "lügenhaft",
    "lügenhaften": "lügenhaft",
    "lügenhafter": "lügenhaft",
    "lügenhaftes": "lügenhaft",
    "lügest": "lügen",
    "lüget": "lügen",
    "lügnerische": "lügnerisch",
    "lügnerischem": "lügnerisch",
    "lügnerischen": "lügnerisch",
    "lügnerischer": "lügnerisch",
    "lügnerischere": "lügnerisch",
    "lügnerischerem": "lügnerisch",
    "lügnerischeren": "lügnerisch",
    "lügnerischerer": "lügnerisch",
    "lügnerischeres": "lügnerisch",
    "lügnerisches": "lügnerisch",
    "lügnerischste": "lügnerisch",
    "lügnerischstem": "lügnerisch",
    "lügnerischsten": "lügnerisch",
    "lügnerischster": "lügnerisch",
    "lügnerischstes": "lügnerisch",
    "lügst": "lügen",
    "lügt": "lügen",
    "lümmele": "lümmeln",
    "lümmelnd": "lümmeln",
    "lümmelnde": "lümmelnd",
    "lümmelndem": "lümmelnd",
    "lümmelnden": "lümmelnd",
    "lümmelnder": "lümmelnd",
    "lümmelndes": "lümmelnd",
    "lümmelst": "lümmeln",
    "lümmelt": "lümmeln",
    "lümmelte": "lümmeln",
    "lümmelten": "lümmeln",
    "lümmeltest": "lümmeln",
    "lümmeltet": "lümmeln",
    "lümmle": "lümmeln",
    "lüsternem": "lüstern",
    "lüsternen": "lüstern",
    "lüsterner": "lüstern",
    "lüsternere": "lüstern",
    "lüsternerem": "lüstern",
    "lüsterneren": "lüstern",
    "lüsternerer": "lüstern",
    "lüsterneres": "lüstern",
    "lüsternes": "lüstern",
    "lüsternste": "lüstern",
    "lüsternstem": "lüstern",
    "lüsternsten": "lüstern",
    "lüsternster": "lüstern",
    "lüsternstes": "lüstern",
    "lütte": "lütt",
    "lüttem": "lütt",
    "lütten": "lütt",
    "lütter": "lütt",
    "lüttere": "lütt",
    "lütterem": "lütt",
    "lütteren": "lütt",
    "lütterer": "lütt",
    "lütteres": "lütt",
    "lüttes": "lütt",
    "lütteste": "lütt",
    "lüttestem": "lütt",
    "lüttesten": "lütt",
    "lüttester": "lütt",
    "lüttestes": "lütt",
    "machbarem": "machbar",
    "machbaren": "machbar",
    "machbarer": "machbar",
    "machbarere": "machbar",
    "machbarerem": "machbar",
    "machbareren": "machbar",
    "machbarerer": "machbar",
    "machbareres": "machbar",
    "machbares": "machbar",
    "machbarste": "machbar",
    "machbarstem": "machbar",
    "machbarsten": "machbar",
    "machbarster": "machbar",
    "machbarstes": "machbar",
    "mache": "machen",
    "machend": "machen",
    "machende": "machend",
    "machendem": "machend",
    "machenden": "machend",
    "machender": "machend",
    "machendes": "machend",
    "machest": "machen",
    "machet": "machen",
    "machst": "machen",
    "macht": "machen",
    "machte": "machen",
    "machten": "machen",
    "machtest": "machen",
    "machtet": "machen",
    "machtlose": "machtlos",
    "machtlosem": "machtlos",
    "machtlosen": "machtlos",
    "machtloser": "machtlos",
    "machtlosere": "machtlos",
    "machtloserem": "machtlos",
    "machtloseren": "machtlos",
    "machtloserer": "machtlos",
    "machtloseres": "machtlos",
    "machtloses": "machtlos",
    "machtloseste": "machtlos",
    "machtlosestem": "machtlos",
    "machtlosesten": "machtlos",
    "machtlosester": "machtlos",
    "machtlosestes": "machtlos",
    "madigem": "madig",
    "madigen": "madig",
    "madiger": "madig",
    "madigere": "madig",
    "madigerem": "madig",
    "madigeren": "madig",
    "madigerer": "madig",
    "madigeres": "madig",
    "madiges": "madig",
    "madigste": "madig",
    "madigstem": "madig",
    "madigsten": "madig",
    "madigster": "madig",
    "madigstes": "madig",
    "mag": "mögen",
    "mager": "magern",
    "magere": "mager",
    "magerem": "mager",
    "mageren": "mager",
    "magerer": "mager",
    "magerere": "mager",
    "magererem": "mager",
    "magereren": "mager",
    "magererer": "mager",
    "magereres": "mager",
    "mageres": "mager",
    "magernd": "magern",
    "magernde": "magernd",
    "magerndem": "magernd",
    "magernden": "magernd",
    "magernder": "magernd",
    "magerndes": "magernd",
    "magerst": "magern",
    "magerste": "mager",
    "magerstem": "mager",
    "magersten": "mager",
    "magerster": "mager",
    "magerstes": "mager",
    "magersüchtige": "magersüchtig",
    "magersüchtigem": "magersüchtig",
    "magersüchtigen": "magersüchtig",
    "magersüchtiger": "magersüchtig",
    "magersüchtigere": "magersüchtig",
    "magersüchtigerem": "magersüchtig",
    "magersüchtigeren": "magersüchtig",
    "magersüchtigerer": "magersüchtig",
    "magersüchtigeres": "magersüchtig",
    "magersüchtiges": "magersüchtig",
    "magersüchtigste": "magersüchtig",
    "magersüchtigstem": "magersüchtig",
    "magersüchtigsten": "magersüchtig",
    "magersüchtigster": "magersüchtig",
    "magersüchtigstes": "magersüchtig",
    "magert": "magern",
    "magerte": "magern",
    "magerten": "magern",
    "magertest": "magern",
    "magertet": "magern",
    "magischem": "magisch",
    "magischen": "magisch",
    "magischer": "magisch",
    "magischere": "magisch",
    "magischerem": "magisch",
    "magischeren": "magisch",
    "magischerer": "magisch",
    "magischeres": "magisch",
    "magisches": "magisch",
    "magischste": "magisch",
    "magischstem": "magisch",
    "magischsten": "magisch",
    "magischster": "magisch",
    "magischstes": "magisch",
    "magst": "mögen",
    "mahlend": "mahlen",
    "mahlende": "mahlend",
    "mahlendem": "mahlend",
    "mahlenden": "mahlend",
    "mahlender": "mahlend",
    "mahlendes": "mahlend",
    "mahlest": "mahlen",
    "mahlet": "mahlen",
    "mahlst": "mahlen",
    "mahlt": "mahlen",
    "mahlte": "mahlen",
    "mahlten": "mahlen",
    "mahltest": "mahlen",
    "mahltet": "mahlen",
    "mahne": "mahnen",
    "mahnend": "mahnen",
    "mahnende": "mahnend",
    "mahnendem": "mahnend",
    "mahnenden": "mahnend",
    "mahnender": "mahnend",
    "mahnendere": "mahnend",
    "mahnenderem": "mahnend",
    "mahnenderen": "mahnend",
    "mahnenderer": "mahnend",
    "mahnenderes": "mahnend",
    "mahnendes": "mahnend",
    "mahnendste": "mahnend",
    "mahnendstem": "mahnend",
    "mahnendsten": "mahnend",
    "mahnendster": "mahnend",
    "mahnendstes": "mahnend",
    "mahnest": "mahnen",
    "mahnet": "mahnen",
    "mahnst": "mahnen",
    "mahnt": "mahnen",
    "mahnte": "mahnen",
    "mahnten": "mahnen",
    "mahntest": "mahnen",
    "mahntet": "mahnen",
    "majestätischem": "majestätisch",
    "majestätischen": "majestätisch",
    "majestätischer": "majestätisch",
    "majestätisches": "majestätisch",
    "makaberem": "makaber",
    "makaberen": "makaber",
    "makaberer": "makaber",
    "makaberere": "makaber",
    "makabererem": "makaber",
    "makabereren": "makaber",
    "makabererer": "makaber",
    "makabereres": "makaber",
    "makaberes": "makaber",
    "makaberste": "makaber",
    "makaberstem": "makaber",
    "makabersten": "makaber",
    "makaberster": "makaber",
    "makaberstes": "makaber",
    "makellose": "makellos",
    "makellosem": "makellos",
    "makellosen": "makellos",
    "makelloser": "makellos",
    "makellosere": "makellos",
    "makelloserem": "makellos",
    "makelloseren": "makellos",
    "makelloserer": "makellos",
    "makelloseres": "makellos",
    "makelloses": "makellos",
    "makelloseste": "makellos",
    "makellosestem": "makellos",
    "makellosesten": "makellos",
    "makellosester": "makellos",
    "makellosestes": "makellos",
    "malend": "malen",
    "malende": "malend",
    "malendem": "malend",
    "malenden": "malend",
    "malender": "malend",
    "malendes": "malend",
    "malerischem": "malerisch",
    "malerischen": "malerisch",
    "malerischer": "malerisch",
    "malerischere": "malerisch",
    "malerischerem": "malerisch",
    "malerischeren": "malerisch",
    "malerischerer": "malerisch",
    "malerischeres": "malerisch",
    "malerisches": "malerisch",
    "malerischste": "malerisch",
    "malerischstem": "malerisch",
    "malerischsten": "malerisch",
    "malerischster": "malerisch",
    "malerischstes": "malerisch",
    "malest": "malen",
    "malet": "malen",
    "malgenommen": "malnehmen",
    "malgenommene": "malgenommen",
    "malgenommenem": "malgenommen",
    "malgenommenen": "malgenommen",
    "malgenommener": "malgenommen",
    "malgenommenes": "malgenommen",
    "malnahm": "malnehmen",
    "malnahmen": "malnehmen",
    "malnahmst": "malnehmen",
    "malnahmt": "malnehmen",
    "malnehme": "malnehmen",
    "malnehmend": "malnehmen",
    "malnehmende": "malnehmend",
    "malnehmendem": "malnehmend",
    "malnehmenden": "malnehmend",
    "malnehmender": "malnehmend",
    "malnehmendes": "malnehmend",
    "malnehmest": "malnehmen",
    "malnehmet": "malnehmen",
    "malnehmt": "malnehmen",
    "malnimmst": "malnehmen",
    "malnimmt": "malnehmen",
    "malnähme": "malnehmen",
    "malnähmen": "malnehmen",
    "malnähmest": "malnehmen",
    "malnähmet": "malnehmen",
    "malst": "malen",
    "malt": "malen",
    "malte": "malen",
    "malten": "malen",
    "maltest": "malen",
    "maltet": "malen",
    "malzunehmen": "malnehmen",
    "mampfe": "mampfen",
    "mampfend": "mampfen",
    "mampfende": "mampfend",
    "mampfendem": "mampfend",
    "mampfenden": "mampfend",
    "mampfender": "mampfend",
    "mampfendere": "mampfend",
    "mampfenderem": "mampfend",
    "mampfenderen": "mampfend",
    "mampfenderer": "mampfend",
    "mampfenderes": "mampfend",
    "mampfendes": "mampfend",
    "mampfendste": "mampfend",
    "mampfendstem": "mampfend",
    "mampfendsten": "mampfend",
    "mampfendster": "mampfend",
    "mampfendstes": "mampfend",
    "mampfest": "mampfen",
    "mampfet": "mampfen",
    "mampfst": "mampfen",
    "mampft": "mampfen",
    "mampfte": "mampfen",
    "mampften": "mampfen",
    "mampftest": "mampfen",
    "mampftet": "mampfen",
    "manage": "managen",
    "managend": "managen",
    "managende": "managend",
    "managendem": "managend",
    "managenden": "managend",
    "managender": "managend",
    "managendes": "managend",
    "managest": "managen",
    "managet": "managen",
    "managst": "managen",
    "managt": "managen",
    "managte": "managen",
    "managten": "managen",
    "managtest": "managen",
    "managtet": "managen",
    "manche": "manch",
    "manchem": "manch",
    "manchen": "manch",
    "mancher": "manch",
    "manches": "manch",
    "mangele": "mangeln",
    "mangelhafte": "mangelhaft",
    "mangelhaftem": "mangelhaft",
    "mangelhaften": "mangelhaft",
    "mangelhafter": "mangelhaft",
    "mangelhaftere": "mangelhaft",
    "mangelhafterem": "mangelhaft",
    "mangelhafteren": "mangelhaft",
    "mangelhafterer": "mangelhaft",
    "mangelhafteres": "mangelhaft",
    "mangelhaftes": "mangelhaft",
    "mangelhafteste": "mangelhaft",
    "mangelhaftestem": "mangelhaft",
    "mangelhaftesten": "mangelhaft",
    "mangelhaftester": "mangelhaft",
    "mangelhaftestes": "mangelhaft",
    "mangelnd": "mangeln",
    "mangelnde": "mangelnd",
    "mangelndem": "mangelnd",
    "mangelnden": "mangelnd",
    "mangelnder": "mangelnd",
    "mangelndes": "mangelnd",
    "mangelst": "mangeln",
    "mangelt": "mangeln",
    "mangelte": "mangeln",
    "mangelten": "mangeln",
    "mangeltest": "mangeln",
    "mangeltet": "mangeln",
    "mangle": "mangeln",
    "manierlichem": "manierlich",
    "manierlichen": "manierlich",
    "manierlicher": "manierlich",
    "manierlichere": "manierlich",
    "manierlicherem": "manierlich",
    "manierlicheren": "manierlich",
    "manierlicherer": "manierlich",
    "manierlicheres": "manierlich",
    "manierliches": "manierlich",
    "manierlichste": "manierlich",
    "manierlichstem": "manierlich",
    "manierlichsten": "manierlich",
    "manierlichster": "manierlich",
    "manierlichstes": "manierlich",
    "manifestierend": "manifestieren",
    "manifestierende": "manifestierend",
    "manifestierendem": "manifestierend",
    "manifestierenden": "manifestierend",
    "manifestierender": "manifestierend",
    "manifestierendere": "manifestierend",
    "manifestierenderem": "manifestierend",
    "manifestierenderen": "manifestierend",
    "manifestierenderer": "manifestierend",
    "manifestierenderes": "manifestierend",
    "manifestierendes": "manifestierend",
    "manifestierendste": "manifestierend",
    "manifestierendstem": "manifestierend",
    "manifestierendsten": "manifestierend",
    "manifestierendster": "manifestierend",
    "manifestierendstes": "manifestierend",
    "manifestierest": "manifestieren",
    "manifestieret": "manifestieren",
    "manifestierst": "manifestieren",
    "manifestiert": "manifestieren",
    "manifestierte": "manifestieren",
    "manifestiertem": "manifestiert",
    "manifestierten": "manifestieren",
    "manifestierter": "manifestiert",
    "manifestiertere": "manifestiert",
    "manifestierterem": "manifestiert",
    "manifestierteren": "manifestiert",
    "manifestierterer": "manifestiert",
    "manifestierteres": "manifestiert",
    "manifestiertes": "manifestiert",
    "manifestiertest": "manifestieren",
    "manifestierteste": "manifestiert",
    "manifestiertestem": "manifestiert",
    "manifestiertesten": "manifestiert",
    "manifestiertester": "manifestiert",
    "manifestiertestes": "manifestiert",
    "manifestiertet": "manifestieren",
    "manipulierbarem": "manipulierbar",
    "manipulierbaren": "manipulierbar",
    "manipulierbarer": "manipulierbar",
    "manipulierbarere": "manipulierbar",
    "manipulierbarerem": "manipulierbar",
    "manipulierbareren": "manipulierbar",
    "manipulierbarerer": "manipulierbar",
    "manipulierbareres": "manipulierbar",
    "manipulierbares": "manipulierbar",
    "manipulierbarste": "manipulierbar",
    "manipulierbarstem": "manipulierbar",
    "manipulierbarsten": "manipulierbar",
    "manipulierbarster": "manipulierbar",
    "manipulierbarstes": "manipulierbar",
    "manipuliere": "manipulieren",
    "manipulierend": "manipulieren",
    "manipulierende": "manipulierend",
    "manipulierendem": "manipulierend",
    "manipulierenden": "manipulierend",
    "manipulierender": "manipulierend",
    "manipulierendes": "manipulierend",
    "manipulierest": "manipulieren",
    "manipulieret": "manipulieren",
    "manipulierst": "manipulieren",
    "manipuliert": "manipulieren",
    "manipulierte": "manipulieren",
    "manipuliertem": "manipuliert",
    "manipulierten": "manipulieren",
    "manipulierter": "manipuliert",
    "manipuliertere": "manipuliert",
    "manipulierterem": "manipuliert",
    "manipulierteren": "manipuliert",
    "manipulierterer": "manipuliert",
    "manipulierteres": "manipuliert",
    "manipuliertes": "manipuliert",
    "manipuliertest": "manipulieren",
    "manipulierteste": "manipuliert",
    "manipuliertestem": "manipuliert",
    "manipuliertesten": "manipuliert",
    "manipuliertester": "manipuliert",
    "manipuliertestes": "manipuliert",
    "manipuliertet": "manipulieren",
    "manische": "manisch",
    "manischem": "manisch",
    "manischen": "manisch",
    "manischer": "manisch",
    "manischere": "manisch",
    "manischerem": "manisch",
    "manischeren": "manisch",
    "manischerer": "manisch",
    "manischeres": "manisch",
    "manisches": "manisch",
    "manischste": "manisch",
    "manischstem": "manisch",
    "manischsten": "manisch",
    "manischster": "manisch",
    "manischstes": "manisch",
    "mannhaftem": "mannhaft",
    "mannhaften": "mannhaft",
    "mannhafter": "mannhaft",
    "mannhaftere": "mannhaft",
    "mannhafterem": "mannhaft",
    "mannhafteren": "mannhaft",
    "mannhafterer": "mannhaft",
    "mannhafteres": "mannhaft",
    "mannhaftes": "mannhaft",
    "mannhafteste": "mannhaft",
    "mannhaftestem": "mannhaft",
    "mannhaftesten": "mannhaft",
    "mannhaftester": "mannhaft",
    "mannhaftestes": "mannhaft",
    "mannigfachem": "mannigfach",
    "mannigfachen": "mannigfach",
    "mannigfacher": "mannigfach",
    "mannigfaches": "mannigfach",
    "mannigfaltige": "mannigfaltig",
    "mannigfaltigem": "mannigfaltig",
    "mannigfaltigen": "mannigfaltig",
    "mannigfaltiger": "mannigfaltig",
    "mannigfaltigere": "mannigfaltig",
    "mannigfaltigerem": "mannigfaltig",
    "mannigfaltigeren": "mannigfaltig",
    "mannigfaltigerer": "mannigfaltig",
    "mannigfaltigeres": "mannigfaltig",
    "mannigfaltiges": "mannigfaltig",
    "mannigfaltigste": "mannigfaltig",
    "mannigfaltigstem": "mannigfaltig",
    "mannigfaltigsten": "mannigfaltig",
    "mannigfaltigster": "mannigfaltig",
    "mannigfaltigstes": "mannigfaltig",
    "manuellem": "manuell",
    "manuellen": "manuell",
    "manueller": "manuell",
    "manuellere": "manuell",
    "manuellerem": "manuell",
    "manuelleren": "manuell",
    "manuellerer": "manuell",
    "manuelleres": "manuell",
    "manuelles": "manuell",
    "manuellste": "manuell",
    "manuellstem": "manuell",
    "manuellsten": "manuell",
    "manuellster": "manuell",
    "manuellstes": "manuell",
    "marginalem": "marginal",
    "marginalen": "marginal",
    "marginaler": "marginal",
    "marginales": "marginal",
    "mariniere": "marinieren",
    "marinierend": "marinieren",
    "marinierende": "marinierend",
    "marinierendem": "marinierend",
    "marinierenden": "marinierend",
    "marinierender": "marinierend",
    "marinierendes": "marinierend",
    "marinierest": "marinieren",
    "marinieret": "marinieren",
    "marinierst": "marinieren",
    "mariniert": "marinieren",
    "marinierte": "marinieren",
    "mariniertem": "mariniert",
    "marinierten": "marinieren",
    "marinierter": "mariniert",
    "mariniertes": "mariniert",
    "mariniertest": "marinieren",
    "mariniertet": "marinieren",
    "maritimem": "maritim",
    "maritimen": "maritim",
    "maritimer": "maritim",
    "maritimes": "maritim",
    "markante": "markant",
    "markantem": "markant",
    "markanten": "markant",
    "markanter": "markant",
    "markantere": "markant",
    "markanterem": "markant",
    "markanteren": "markant",
    "markanterer": "markant",
    "markanteres": "markant",
    "markantes": "markant",
    "markanteste": "markant",
    "markantestem": "markant",
    "markantesten": "markant",
    "markantester": "markant",
    "markantestes": "markant",
    "markiere": "markieren",
    "markierend": "markieren",
    "markierende": "markierend",
    "markierendem": "markierend",
    "markierenden": "markierend",
    "markierender": "markierend",
    "markierendes": "markierend",
    "markierest": "markieren",
    "markieret": "markieren",
    "markierst": "markieren",
    "markiert": "markieren",
    "markierte": "markieren",
    "markiertem": "markiert",
    "markierten": "markieren",
    "markierter": "markiert",
    "markiertere": "markiert",
    "markierterem": "markiert",
    "markierteren": "markiert",
    "markierterer": "markiert",
    "markierteres": "markiert",
    "markiertes": "markiert",
    "markiertest": "markieren",
    "markierteste": "markiert",
    "markiertestem": "markiert",
    "markiertesten": "markiert",
    "markiertester": "markiert",
    "markiertestes": "markiert",
    "markiertet": "markieren",
    "markigem": "markig",
    "markigen": "markig",
    "markiger": "markig",
    "markigere": "markig",
    "markigerem": "markig",
    "markigeren": "markig",
    "markigerer": "markig",
    "markigeres": "markig",
    "markiges": "markig",
    "markigste": "markig",
    "markigstem": "markig",
    "markigsten": "markig",
    "markigster": "markig",
    "markigstes": "markig",
    "marktbeherrschendem": "marktbeherrschend",
    "marktbeherrschenden": "marktbeherrschend",
    "marktbeherrschender": "marktbeherrschend",
    "marktbeherrschendes": "marktbeherrschend",
    "marktfähigem": "marktfähig",
    "marktfähigen": "marktfähig",
    "marktfähiger": "marktfähig",
    "marktfähiges": "marktfähig",
    "marktgerechte": "marktgerecht",
    "marktgerechtem": "marktgerecht",
    "marktgerechten": "marktgerecht",
    "marktgerechter": "marktgerecht",
    "marktgerechtere": "marktgerecht",
    "marktgerechterem": "marktgerecht",
    "marktgerechteren": "marktgerecht",
    "marktgerechterer": "marktgerecht",
    "marktgerechteres": "marktgerecht",
    "marktgerechtes": "marktgerecht",
    "marktgerechteste": "marktgerecht",
    "marktgerechtestem": "marktgerecht",
    "marktgerechtesten": "marktgerecht",
    "marktgerechtester": "marktgerecht",
    "marktgerechtestes": "marktgerecht",
    "marktliche": "marktlich",
    "marktlichem": "marktlich",
    "marktlichen": "marktlich",
    "marktlicher": "marktlich",
    "marktliches": "marktlich",
    "marmoriere": "marmorieren",
    "marmorierend": "marmorieren",
    "marmorierende": "marmorierend",
    "marmorierendem": "marmorierend",
    "marmorierenden": "marmorierend",
    "marmorierender": "marmorierend",
    "marmorierendere": "marmorierend",
    "marmorierenderem": "marmorierend",
    "marmorierenderen": "marmorierend",
    "marmorierenderer": "marmorierend",
    "marmorierenderes": "marmorierend",
    "marmorierendes": "marmorierend",
    "marmorierendste": "marmorierend",
    "marmorierendstem": "marmorierend",
    "marmorierendsten": "marmorierend",
    "marmorierendster": "marmorierend",
    "marmorierendstes": "marmorierend",
    "marmorierest": "marmorieren",
    "marmorieret": "marmorieren",
    "marmorierst": "marmorieren",
    "marmoriert": "marmorieren",
    "marmorierte": "marmorieren",
    "marmoriertem": "marmoriert",
    "marmorierten": "marmorieren",
    "marmorierter": "marmoriert",
    "marmoriertere": "marmoriert",
    "marmorierterem": "marmoriert",
    "marmorierteren": "marmoriert",
    "marmorierterer": "marmoriert",
    "marmorierteres": "marmoriert",
    "marmoriertes": "marmoriert",
    "marmoriertest": "marmorieren",
    "marmorierteste": "marmoriert",
    "marmoriertestem": "marmoriert",
    "marmoriertesten": "marmoriert",
    "marmoriertester": "marmoriert",
    "marmoriertestes": "marmoriert",
    "marmoriertet": "marmorieren",
    "marodem": "marode",
    "maroden": "marode",
    "maroder": "marode",
    "marodere": "marode",
    "maroderem": "marode",
    "maroderen": "marode",
    "maroderer": "marode",
    "maroderes": "marode",
    "marodes": "marode",
    "marodeste": "marode",
    "marodestem": "marode",
    "marodesten": "marode",
    "marodester": "marode",
    "marodestes": "marode",
    "marokkanische": "marokkanisch",
    "marokkanischem": "marokkanisch",
    "marokkanischen": "marokkanisch",
    "marokkanischer": "marokkanisch",
    "marokkanisches": "marokkanisch",
    "marschiere": "marschieren",
    "marschierend": "marschieren",
    "marschierende": "marschierend",
    "marschierendem": "marschierend",
    "marschierenden": "marschierend",
    "marschierender": "marschierend",
    "marschierendes": "marschierend",
    "marschierest": "marschieren",
    "marschieret": "marschieren",
    "marschierst": "marschieren",
    "marschiert": "marschieren",
    "marschierte": "marschieren",
    "marschiertem": "marschiert",
    "marschierten": "marschieren",
    "marschierter": "marschiert",
    "marschiertes": "marschiert",
    "marschiertest": "marschieren",
    "marschiertet": "marschieren",
    "martere": "martern",
    "marternd": "martern",
    "marternde": "marternd",
    "marterndem": "marternd",
    "marternden": "marternd",
    "marternder": "marternd",
    "marterndere": "marternd",
    "marternderem": "marternd",
    "marternderen": "marternd",
    "marternderer": "marternd",
    "marternderes": "marternd",
    "marterndes": "marternd",
    "marterndste": "marternd",
    "marterndstem": "marternd",
    "marterndsten": "marternd",
    "marterndster": "marternd",
    "marterndstes": "marternd",
    "marterst": "martern",
    "martert": "martern",
    "marterte": "martern",
    "marterten": "martern",
    "martertest": "martern",
    "martertet": "martern",
    "marxistischem": "marxistisch",
    "marxistischen": "marxistisch",
    "marxistischer": "marxistisch",
    "marxistischere": "marxistisch",
    "marxistischerem": "marxistisch",
    "marxistischeren": "marxistisch",
    "marxistischerer": "marxistisch",
    "marxistischeres": "marxistisch",
    "marxistisches": "marxistisch",
    "marxistischste": "marxistisch",
    "marxistischstem": "marxistisch",
    "marxistischsten": "marxistisch",
    "marxistischster": "marxistisch",
    "marxistischstes": "marxistisch",
    "maschinellem": "maschinell",
    "maschinellen": "maschinell",
    "maschineller": "maschinell",
    "maschinellere": "maschinell",
    "maschinellerem": "maschinell",
    "maschinelleren": "maschinell",
    "maschinellerer": "maschinell",
    "maschinelleres": "maschinell",
    "maschinelles": "maschinell",
    "maschinellste": "maschinell",
    "maschinellstem": "maschinell",
    "maschinellsten": "maschinell",
    "maschinellster": "maschinell",
    "maschinellstes": "maschinell",
    "maschinenlesbarem": "maschinenlesbar",
    "maschinenlesbaren": "maschinenlesbar",
    "maschinenlesbarer": "maschinenlesbar",
    "maschinenlesbares": "maschinenlesbar",
    "masere": "masern",
    "masernd": "masern",
    "masernde": "masernd",
    "maserndem": "masernd",
    "masernden": "masernd",
    "masernder": "masernd",
    "maserndes": "masernd",
    "maserst": "masern",
    "masert": "masern",
    "maserte": "masern",
    "maserten": "masern",
    "masertest": "masern",
    "masertet": "masern",
    "maskenhaftem": "maskenhaft",
    "maskenhaften": "maskenhaft",
    "maskenhafter": "maskenhaft",
    "maskenhaftere": "maskenhaft",
    "maskenhafterem": "maskenhaft",
    "maskenhafteren": "maskenhaft",
    "maskenhafterer": "maskenhaft",
    "maskenhafteres": "maskenhaft",
    "maskenhaftes": "maskenhaft",
    "maskenhafteste": "maskenhaft",
    "maskenhaftestem": "maskenhaft",
    "maskenhaftesten": "maskenhaft",
    "maskenhaftester": "maskenhaft",
    "maskenhaftestes": "maskenhaft",
    "maskiere": "maskieren",
    "maskierend": "maskieren",
    "maskierende": "maskierend",
    "maskierendem": "maskierend",
    "maskierenden": "maskierend",
    "maskierender": "maskierend",
    "maskierendes": "maskierend",
    "maskierest": "maskieren",
    "maskieret": "maskieren",
    "maskierst": "maskieren",
    "maskiert": "maskieren",
    "maskierte": "maskieren",
    "maskiertem": "maskiert",
    "maskierten": "maskieren",
    "maskierter": "maskiert",
    "maskiertes": "maskiert",
    "maskiertest": "maskieren",
    "maskiertet": "maskieren",
    "massenhafte": "massenhaft",
    "massenhaftem": "massenhaft",
    "massenhaften": "massenhaft",
    "massenhafter": "massenhaft",
    "massenhaftes": "massenhaft",
    "massiere": "massieren",
    "massierend": "massieren",
    "massierende": "massierend",
    "massierendem": "massierend",
    "massierenden": "massierend",
    "massierender": "massierend",
    "massierendes": "massierend",
    "massierest": "massieren",
    "massieret": "massieren",
    "massierst": "massieren",
    "massiert": "massieren",
    "massierte": "massieren",
    "massiertem": "massiert",
    "massierten": "massieren",
    "massierter": "massiert",
    "massiertere": "massiert",
    "massierterem": "massiert",
    "massierteren": "massiert",
    "massierterer": "massiert",
    "massierteres": "massiert",
    "massiertes": "massiert",
    "massiertest": "massieren",
    "massierteste": "massiert",
    "massiertestem": "massiert",
    "massiertesten": "massiert",
    "massiertester": "massiert",
    "massiertestes": "massiert",
    "massiertet": "massieren",
    "massige": "massig",
    "massigem": "massig",
    "massigen": "massig",
    "massiger": "massig",
    "massiges": "massig",
    "massive": "massiv",
    "massivem": "massiv",
    "massiven": "massiv",
    "massiver": "massiv",
    "massivere": "massiv",
    "massiverem": "massiv",
    "massiveren": "massiv",
    "massiverer": "massiv",
    "massiveres": "massiv",
    "massives": "massiv",
    "massivste": "massiv",
    "massivstem": "massiv",
    "massivsten": "massiv",
    "massivster": "massiv",
    "massivstes": "massiv",
    "masturbiere": "masturbieren",
    "masturbierend": "masturbieren",
    "masturbierende": "masturbierend",
    "masturbierendem": "masturbierend",
    "masturbierenden": "masturbierend",
    "masturbierender": "masturbierend",
    "masturbierendere": "masturbierend",
    "masturbierenderem": "masturbierend",
    "masturbierenderen": "masturbierend",
    "masturbierenderer": "masturbierend",
    "masturbierenderes": "masturbierend",
    "masturbierendes": "masturbierend",
    "masturbierendste": "masturbierend",
    "masturbierendstem": "masturbierend",
    "masturbierendsten": "masturbierend",
    "masturbierendster": "masturbierend",
    "masturbierendstes": "masturbierend",
    "masturbierest": "masturbieren",
    "masturbieret": "masturbieren",
    "masturbierst": "masturbieren",
    "masturbiert": "masturbieren",
    "masturbierte": "masturbieren",
    "masturbiertem": "masturbiert",
    "masturbierten": "masturbieren",
    "masturbierter": "masturbiert",
    "masturbiertes": "masturbiert",
    "masturbiertest": "masturbieren",
    "masturbiertet": "masturbieren",
    "materialisiere": "materialisieren",
    "materialisierend": "materialisieren",
    "materialisierende": "materialisierend",
    "materialisierendem": "materialisierend",
    "materialisierenden": "materialisierend",
    "materialisierender": "materialisierend",
    "materialisierendere": "materialisierend",
    "materialisierenderem": "materialisierend",
    "materialisierenderen": "materialisierend",
    "materialisierenderer": "materialisierend",
    "materialisierenderes": "materialisierend",
    "materialisierendes": "materialisierend",
    "materialisierendste": "materialisierend",
    "materialisierendstem": "materialisierend",
    "materialisierendsten": "materialisierend",
    "materialisierendster": "materialisierend",
    "materialisierendstes": "materialisierend",
    "materialisierest": "materialisieren",
    "materialisieret": "materialisieren",
    "materialisierst": "materialisieren",
    "materialisiert": "materialisieren",
    "materialisierte": "materialisieren",
    "materialisiertem": "materialisiert",
    "materialisierten": "materialisieren",
    "materialisierter": "materialisiert",
    "materialisiertere": "materialisiert",
    "materialisierterem": "materialisiert",
    "materialisierteren": "materialisiert",
    "materialisierterer": "materialisiert",
    "materialisierteres": "materialisiert",
    "materialisiertes": "materialisiert",
    "materialisiertest": "materialisieren",
    "materialisierteste": "materialisiert",
    "materialisiertestem": "materialisiert",
    "materialisiertesten": "materialisiert",
    "materialisiertester": "materialisiert",
    "materialisiertestes": "materialisiert",
    "materialisiertet": "materialisieren",
    "materialistische": "materialistisch",
    "materialistischem": "materialistisch",
    "materialistischen": "materialistisch",
    "materialistischer": "materialistisch",
    "materialistischere": "materialistisch",
    "materialistischerem": "materialistisch",
    "materialistischeren": "materialistisch",
    "materialistischerer": "materialistisch",
    "materialistischeres": "materialistisch",
    "materialistisches": "materialistisch",
    "materialistischste": "materialistisch",
    "materialistischstem": "materialistisch",
    "materialistischsten": "materialistisch",
    "materialistischster": "materialistisch",
    "materialistischstes": "materialistisch",
    "materiellem": "materiell",
    "materiellen": "materiell",
    "materieller": "materiell",
    "materiellere": "materiell",
    "materiellerem": "materiell",
    "materielleren": "materiell",
    "materiellerer": "materiell",
    "materielleres": "materiell",
    "materielles": "materiell",
    "materiellste": "materiell",
    "materiellstem": "materiell",
    "materiellsten": "materiell",
    "materiellster": "materiell",
    "materiellstes": "materiell",
    "mathematische": "mathematisch",
    "mathematischem": "mathematisch",
    "mathematischen": "mathematisch",
    "mathematischer": "mathematisch",
    "mathematischere": "mathematisch",
    "mathematischerem": "mathematisch",
    "mathematischeren": "mathematisch",
    "mathematischerer": "mathematisch",
    "mathematischeres": "mathematisch",
    "mathematisches": "mathematisch",
    "mathematischste": "mathematisch",
    "mathematischstem": "mathematisch",
    "mathematischsten": "mathematisch",
    "mathematischster": "mathematisch",
    "mathematischstes": "mathematisch",
    "mathematisiere": "mathematisieren",
    "mathematisierend": "mathematisieren",
    "mathematisierende": "mathematisierend",
    "mathematisierendem": "mathematisierend",
    "mathematisierenden": "mathematisierend",
    "mathematisierender": "mathematisierend",
    "mathematisierendes": "mathematisierend",
    "mathematisierest": "mathematisieren",
    "mathematisieret": "mathematisieren",
    "mathematisierst": "mathematisieren",
    "mathematisiert": "mathematisieren",
    "mathematisierte": "mathematisieren",
    "mathematisiertem": "mathematisiert",
    "mathematisierten": "mathematisieren",
    "mathematisierter": "mathematisiert",
    "mathematisiertes": "mathematisiert",
    "mathematisiertest": "mathematisieren",
    "mathematisiertet": "mathematisieren",
    "matschigem": "matschig",
    "matschigen": "matschig",
    "matschiger": "matschig",
    "matschigere": "matschig",
    "matschigerem": "matschig",
    "matschigeren": "matschig",
    "matschigerer": "matschig",
    "matschigeres": "matschig",
    "matschiges": "matschig",
    "matschigste": "matschig",
    "matschigstem": "matschig",
    "matschigsten": "matschig",
    "matschigster": "matschig",
    "matschigstes": "matschig",
    "matte": "matt",
    "mattem": "matt",
    "matten": "matt",
    "matter": "matt",
    "mattere": "matt",
    "matterem": "matt",
    "matteren": "matt",
    "matterer": "matt",
    "matteres": "matt",
    "mattes": "matt",
    "matteste": "matt",
    "mattestem": "matt",
    "mattesten": "matt",
    "mattester": "matt",
    "mattestes": "matt",
    "mauere": "mauern",
    "mauernd": "mauern",
    "mauernde": "mauernd",
    "mauerndem": "mauernd",
    "mauernden": "mauernd",
    "mauernder": "mauernd",
    "mauerndes": "mauernd",
    "mauerst": "mauern",
    "mauert": "mauern",
    "mauerte": "mauern",
    "mauerten": "mauern",
    "mauertest": "mauern",
    "mauertet": "mauern",
    "maulend": "maulen",
    "maulende": "maulend",
    "maulendem": "maulend",
    "maulenden": "maulend",
    "maulender": "maulend",
    "maulendere": "maulend",
    "maulenderem": "maulend",
    "maulenderen": "maulend",
    "maulenderer": "maulend",
    "maulenderes": "maulend",
    "maulendes": "maulend",
    "maulendste": "maulend",
    "maulendstem": "maulend",
    "maulendsten": "maulend",
    "maulendster": "maulend",
    "maulendstes": "maulend",
    "maulest": "maulen",
    "maulet": "maulen",
    "maulst": "maulen",
    "mault": "maulen",
    "maulte": "maulen",
    "maulten": "maulen",
    "maultest": "maulen",
    "maultet": "maulen",
    "mauschele": "mauscheln",
    "mauschelnd": "mauscheln",
    "mauschelnde": "mauschelnd",
    "mauschelndem": "mauschelnd",
    "mauschelnden": "mauschelnd",
    "mauschelnder": "mauschelnd",
    "mauschelndere": "mauschelnd",
    "mauschelnderem": "mauschelnd",
    "mauschelnderen": "mauschelnd",
    "mauschelnderer": "mauschelnd",
    "mauschelnderes": "mauschelnd",
    "mauschelndes": "mauschelnd",
    "mauschelndste": "mauschelnd",
    "mauschelndstem": "mauschelnd",
    "mauschelndsten": "mauschelnd",
    "mauschelndster": "mauschelnd",
    "mauschelndstes": "mauschelnd",
    "mauschelst": "mauscheln",
    "mauschelt": "mauscheln",
    "mauschelte": "mauscheln",
    "mauschelten": "mauscheln",
    "mauscheltest": "mauscheln",
    "mauscheltet": "mauscheln",
    "mauschle": "mauscheln",
    "mausere": "mausern",
    "mausernd": "mausern",
    "mausernde": "mausernd",
    "mauserndem": "mausernd",
    "mausernden": "mausernd",
    "mausernder": "mausernd",
    "mauserndere": "mausernd",
    "mausernderem": "mausernd",
    "mausernderen": "mausernd",
    "mausernderer": "mausernd",
    "mausernderes": "mausernd",
    "mauserndes": "mausernd",
    "mauserndste": "mausernd",
    "mauserndstem": "mausernd",
    "mauserndsten": "mausernd",
    "mauserndster": "mausernd",
    "mauserndstes": "mausernd",
    "mauserst": "mausern",
    "mausert": "mausern",
    "mauserte": "mausern",
    "mauserten": "mausern",
    "mausertest": "mausern",
    "mausertet": "mausern",
    "maximalem": "maximal",
    "maximalen": "maximal",
    "maximaler": "maximal",
    "maximales": "maximal",
    "maximiere": "maximieren",
    "maximierend": "maximieren",
    "maximierende": "maximierend",
    "maximierendem": "maximierend",
    "maximierenden": "maximierend",
    "maximierender": "maximierend",
    "maximierendere": "maximierend",
    "maximierenderem": "maximierend",
    "maximierenderen": "maximierend",
    "maximierenderer": "maximierend",
    "maximierenderes": "maximierend",
    "maximierendes": "maximierend",
    "maximierendste": "maximierend",
    "maximierendstem": "maximierend",
    "maximierendsten": "maximierend",
    "maximierendster": "maximierend",
    "maximierendstes": "maximierend",
    "maximierest": "maximieren",
    "maximieret": "maximieren",
    "maximierst": "maximieren",
    "maximiert": "maximieren",
    "maximierte": "maximieren",
    "maximiertem": "maximiert",
    "maximierten": "maximieren",
    "maximierter": "maximiert",
    "maximiertere": "maximiert",
    "maximierterem": "maximiert",
    "maximierteren": "maximiert",
    "maximierterer": "maximiert",
    "maximierteres": "maximiert",
    "maximiertes": "maximiert",
    "maximiertest": "maximieren",
    "maximierteste": "maximiert",
    "maximiertestem": "maximiert",
    "maximiertesten": "maximiert",
    "maximiertester": "maximiert",
    "maximiertestes": "maximiert",
    "maximiertet": "maximieren",
    "mazedonischem": "mazedonisch",
    "mazedonischen": "mazedonisch",
    "mazedonischer": "mazedonisch",
    "mazedonisches": "mazedonisch",
    "maß": "messen",
    "maßend": "maßen",
    "maßende": "maßend",
    "maßendem": "maßend",
    "maßenden": "maßend",
    "maßender": "maßend",
    "maßendere": "maßend",
    "maßenderem": "maßend",
    "maßenderen": "maßend",
    "maßenderer": "maßend",
    "maßenderes": "maßend",
    "maßendes": "maßend",
    "maßendste": "maßend",
    "maßendstem": "maßend",
    "maßendsten": "maßend",
    "maßendster": "maßend",
    "maßendstes": "maßend",
    "maßest": "maßen",
    "maßet": "maßen",
    "maßgebliche": "maßgeblich",
    "maßgeblichem": "maßgeblich",
    "maßgeblichen": "maßgeblich",
    "maßgeblicher": "maßgeblich",
    "maßgebliches": "maßgeblich",
    "maßgehalten": "maßhalten",
    "maßgehaltene": "maßgehalten",
    "maßgehaltenem": "maßgehalten",
    "maßgehaltenen": "maßgehalten",
    "maßgehaltener": "maßgehalten",
    "maßgehaltenes": "maßgehalten",
    "maßgeschneiderte": "maßgeschneidert",
    "maßgeschneidertem": "maßgeschneidert",
    "maßgeschneiderten": "maßgeschneidert",
    "maßgeschneiderter": "maßgeschneidert",
    "maßgeschneidertes": "maßgeschneidert",
    "maßhalte": "maßhalten",
    "maßhaltend": "maßhalten",
    "maßhaltende": "maßhaltend",
    "maßhaltendem": "maßhaltend",
    "maßhaltenden": "maßhaltend",
    "maßhaltender": "maßhaltend",
    "maßhaltendes": "maßhaltend",
    "maßhaltest": "maßhalten",
    "maßhaltet": "maßhalten",
    "maßhielt": "maßhalten",
    "maßhielte": "maßhalten",
    "maßhielten": "maßhalten",
    "maßhieltest": "maßhalten",
    "maßhieltet": "maßhalten",
    "maßhält": "maßhalten",
    "maßhältst": "maßhalten",
    "maßlose": "maßlos",
    "maßlosem": "maßlos",
    "maßlosen": "maßlos",
    "maßloser": "maßlos",
    "maßlosere": "maßlos",
    "maßloserem": "maßlos",
    "maßloseren": "maßlos",
    "maßloserer": "maßlos",
    "maßloseres": "maßlos",
    "maßloses": "maßlos",
    "maßloseste": "maßlos",
    "maßlosestem": "maßlos",
    "maßlosesten": "maßlos",
    "maßlosester": "maßlos",
    "maßlosestes": "maßlos",
    "maßstabgetreuem": "maßstabgetreu",
    "maßstabgetreuen": "maßstabgetreu",
    "maßstabgetreuer": "maßstabgetreu",
    "maßstabgetreuere": "maßstabgetreu",
    "maßstabgetreuerem": "maßstabgetreu",
    "maßstabgetreueren": "maßstabgetreu",
    "maßstabgetreuerer": "maßstabgetreu",
    "maßstabgetreueres": "maßstabgetreu",
    "maßstabgetreues": "maßstabgetreu",
    "maßstabgetreuste": "maßstabgetreu",
    "maßstabgetreustem": "maßstabgetreu",
    "maßstabgetreusten": "maßstabgetreu",
    "maßstabgetreuster": "maßstabgetreu",
    "maßstabgetreustes": "maßstabgetreu",
    "maßt": "messen",
    "maßte": "maßen",
    "maßten": "maßen",
    "maßtest": "maßen",
    "maßtet": "maßen",
    "maßvolle": "maßvoll",
    "maßvollem": "maßvoll",
    "maßvollen": "maßvoll",
    "maßvoller": "maßvoll",
    "maßvollere": "maßvoll",
    "maßvollerem": "maßvoll",
    "maßvolleren": "maßvoll",
    "maßvollerer": "maßvoll",
    "maßvolleres": "maßvoll",
    "maßvolles": "maßvoll",
    "maßvollste": "maßvoll",
    "maßvollstem": "maßvoll",
    "maßvollsten": "maßvoll",
    "maßvollster": "maßvoll",
    "maßvollstes": "maßvoll",
    "maßzuhalten": "maßhalten",
    "mechanischem": "mechanisch",
    "mechanischen": "mechanisch",
    "mechanischer": "mechanisch",
    "mechanisches": "mechanisch",
    "meckere": "meckern",
    "meckernd": "meckern",
    "meckernde": "meckernd",
    "meckerndem": "meckernd",
    "meckernden": "meckernd",
    "meckernder": "meckernd",
    "meckerndere": "meckernd",
    "meckernderem": "meckernd",
    "meckernderen": "meckernd",
    "meckernderer": "meckernd",
    "meckernderes": "meckernd",
    "meckerndes": "meckernd",
    "meckerndste": "meckernd",
    "meckerndstem": "meckernd",
    "meckerndsten": "meckernd",
    "meckerndster": "meckernd",
    "meckerndstes": "meckernd",
    "meckerst": "meckern",
    "meckert": "meckern",
    "meckerte": "meckern",
    "meckerten": "meckern",
    "meckertest": "meckern",
    "meckertet": "meckern",
    "medialem": "medial",
    "medialen": "medial",
    "medialer": "medial",
    "mediales": "medial",
    "medikamentösem": "medikamentös",
    "medikamentösen": "medikamentös",
    "medikamentöser": "medikamentös",
    "medikamentöses": "medikamentös",
    "meditativem": "meditativ",
    "meditativen": "meditativ",
    "meditativer": "meditativ",
    "meditatives": "meditativ",
    "mediterrane": "mediterran",
    "mediterranem": "mediterran",
    "mediterranen": "mediterran",
    "mediterraner": "mediterran",
    "mediterranes": "mediterran",
    "meditiere": "meditieren",
    "meditierend": "meditieren",
    "meditierende": "meditierend",
    "meditierendem": "meditierend",
    "meditierenden": "meditierend",
    "meditierender": "meditierend",
    "meditierendes": "meditierend",
    "meditierest": "meditieren",
    "meditieret": "meditieren",
    "meditierst": "meditieren",
    "meditiert": "meditieren",
    "meditierte": "meditieren",
    "meditiertem": "meditiert",
    "meditierten": "meditieren",
    "meditierter": "meditiert",
    "meditiertes": "meditiert",
    "meditiertest": "meditieren",
    "meditiertet": "meditieren",
    "medizinischem": "medizinisch",
    "medizinischen": "medizinisch",
    "medizinischer": "medizinisch",
    "medizinisches": "medizinisch",
    "mehrdeutigem": "mehrdeutig",
    "mehrdeutigen": "mehrdeutig",
    "mehrdeutiger": "mehrdeutig",
    "mehrdeutiges": "mehrdeutig",
    "mehrdimensionale": "mehrdimensional",
    "mehrdimensionalem": "mehrdimensional",
    "mehrdimensionalen": "mehrdimensional",
    "mehrdimensionaler": "mehrdimensional",
    "mehrdimensionales": "mehrdimensional",
    "mehre": "mehren",
    "mehrend": "mehren",
    "mehrende": "mehrend",
    "mehrendem": "mehrend",
    "mehrenden": "mehrend",
    "mehrender": "mehrend",
    "mehrendes": "mehrend",
    "mehrere": "mehrer",
    "mehreren": "mehrer",
    "mehrerer": "mehrer",
    "mehrest": "mehren",
    "mehret": "mehren",
    "mehrfache": "mehrfach",
    "mehrfachem": "mehrfach",
    "mehrfachen": "mehrfach",
    "mehrfacher": "mehrfach",
    "mehrfaches": "mehrfach",
    "mehrfarbigem": "mehrfarbig",
    "mehrfarbigen": "mehrfarbig",
    "mehrfarbiger": "mehrfarbig",
    "mehrfarbiges": "mehrfarbig",
    "mehrheitlichem": "mehrheitlich",
    "mehrheitlichen": "mehrheitlich",
    "mehrheitlicher": "mehrheitlich",
    "mehrheitliches": "mehrheitlich",
    "mehrjährige": "mehrjährig",
    "mehrjährigem": "mehrjährig",
    "mehrjährigen": "mehrjährig",
    "mehrjähriger": "mehrjährig",
    "mehrjähriges": "mehrjährig",
    "mehrmaligem": "mehrmalig",
    "mehrmaligen": "mehrmalig",
    "mehrmaliger": "mehrmalig",
    "mehrmaliges": "mehrmalig",
    "mehrsilbige": "mehrsilbig",
    "mehrsilbigem": "mehrsilbig",
    "mehrsilbigen": "mehrsilbig",
    "mehrsilbiger": "mehrsilbig",
    "mehrsilbiges": "mehrsilbig",
    "mehrsprachige": "mehrsprachig",
    "mehrsprachigem": "mehrsprachig",
    "mehrsprachigen": "mehrsprachig",
    "mehrsprachiger": "mehrsprachig",
    "mehrsprachiges": "mehrsprachig",
    "mehrspurige": "mehrspurig",
    "mehrspurigem": "mehrspurig",
    "mehrspurigen": "mehrspurig",
    "mehrspuriger": "mehrspurig",
    "mehrspuriges": "mehrspurig",
    "mehrst": "mehren",
    "mehrstimmige": "mehrstimmig",
    "mehrstimmigem": "mehrstimmig",
    "mehrstimmigen": "mehrstimmig",
    "mehrstimmiger": "mehrstimmig",
    "mehrstimmiges": "mehrstimmig",
    "mehrt": "mehren",
    "mehrte": "mehren",
    "mehrteilige": "mehrteilig",
    "mehrteiligem": "mehrteilig",
    "mehrteiligen": "mehrteilig",
    "mehrteiliger": "mehrteilig",
    "mehrteiliges": "mehrteilig",
    "mehrten": "mehren",
    "mehrtest": "mehren",
    "mehrtet": "mehren",
    "mehrtägige": "mehrtägig",
    "mehrtägigem": "mehrtägig",
    "mehrtägigen": "mehrtägig",
    "mehrtägiger": "mehrtägig",
    "mehrtägiges": "mehrtägig",
    "mehrzelligem": "mehrzellig",
    "mehrzelligen": "mehrzellig",
    "mehrzelliger": "mehrzellig",
    "mehrzelliges": "mehrzellig",
    "meide": "meiden",
    "meidend": "meiden",
    "meidende": "meidend",
    "meidendem": "meidend",
    "meidenden": "meidend",
    "meidender": "meidend",
    "meidendes": "meidend",
    "meidest": "meiden",
    "meidet": "meiden",
    "meilenlangem": "meilenlang",
    "meilenlangen": "meilenlang",
    "meilenlanger": "meilenlang",
    "meilenlanges": "meilenlang",
    "meilenweite": "meilenweit",
    "meilenweitem": "meilenweit",
    "meilenweiten": "meilenweit",
    "meilenweiter": "meilenweit",
    "meilenweites": "meilenweit",
    "mein": "meinen",
    "meine": "meinen",
    "meinem": "mein",
    "meinen": "mein",
    "meinend": "meinen",
    "meinende": "meinend",
    "meinendem": "meinend",
    "meinenden": "meinend",
    "meinender": "meinend",
    "meinendes": "meinend",
    "meiner": "sich",
    "meines": "mein",
    "meinest": "meinen",
    "meinet": "meinen",
    "meinst": "meinen",
    "meint": "meinen",
    "meinte": "meinen",
    "meinten": "meinen",
    "meintest": "meinen",
    "meintet": "meinen",
    "meistbietende": "meistbietend",
    "meistbietendem": "meistbietend",
    "meistbietenden": "meistbietend",
    "meistbietender": "meistbietend",
    "meistbietendere": "meistbietend",
    "meistbietenderem": "meistbietend",
    "meistbietenderen": "meistbietend",
    "meistbietenderer": "meistbietend",
    "meistbietenderes": "meistbietend",
    "meistbietendes": "meistbietend",
    "meistbietendste": "meistbietend",
    "meistbietendstem": "meistbietend",
    "meistbietendsten": "meistbietend",
    "meistbietendster": "meistbietend",
    "meistbietendstes": "meistbietend",
    "meiste": "meist",
    "meistem": "meist",
    "meisten": "meist",
    "meister": "meistern",
    "meistere": "meistern",
    "meisterhafte": "meisterhaft",
    "meisterhaftem": "meisterhaft",
    "meisterhaften": "meisterhaft",
    "meisterhafter": "meisterhaft",
    "meisterhaftere": "meisterhaft",
    "meisterhafterem": "meisterhaft",
    "meisterhafteren": "meisterhaft",
    "meisterhafterer": "meisterhaft",
    "meisterhafteres": "meisterhaft",
    "meisterhaftes": "meisterhaft",
    "meisterhafteste": "meisterhaft",
    "meisterhaftestem": "meisterhaft",
    "meisterhaftesten": "meisterhaft",
    "meisterhaftester": "meisterhaft",
    "meisterhaftestes": "meisterhaft",
    "meisterliche": "meisterlich",
    "meisterlichem": "meisterlich",
    "meisterlichen": "meisterlich",
    "meisterlicher": "meisterlich",
    "meisterlichere": "meisterlich",
    "meisterlicherem": "meisterlich",
    "meisterlicheren": "meisterlich",
    "meisterlicherer": "meisterlich",
    "meisterlicheres": "meisterlich",
    "meisterliches": "meisterlich",
    "meisterlichste": "meisterlich",
    "meisterlichstem": "meisterlich",
    "meisterlichsten": "meisterlich",
    "meisterlichster": "meisterlich",
    "meisterlichstes": "meisterlich",
    "meisternd": "meistern",
    "meisternde": "meisternd",
    "meisterndem": "meisternd",
    "meisternden": "meisternd",
    "meisternder": "meisternd",
    "meisterndere": "meisternd",
    "meisternderem": "meisternd",
    "meisternderen": "meisternd",
    "meisternderer": "meisternd",
    "meisternderes": "meisternd",
    "meisterndes": "meisternd",
    "meisterndste": "meisternd",
    "meisterndstem": "meisternd",
    "meisterndsten": "meisternd",
    "meisterndster": "meisternd",
    "meisterndstes": "meisternd",
    "meisterst": "meistern",
    "meistert": "meistern",
    "meisterte": "meistern",
    "meisterten": "meistern",
    "meistertest": "meistern",
    "meistertet": "meistern",
    "meistes": "meist",
    "meistgebräuchliche": "meistgebräuchlich",
    "meistgebräuchlichem": "meistgebräuchlich",
    "meistgebräuchlichen": "meistgebräuchlich",
    "meistgebräuchlicher": "meistgebräuchlich",
    "meistgebräuchlichere": "meistgebräuchlich",
    "meistgebräuchlicherem": "meistgebräuchlich",
    "meistgebräuchlicheren": "meistgebräuchlich",
    "meistgebräuchlicherer": "meistgebräuchlich",
    "meistgebräuchlicheres": "meistgebräuchlich",
    "meistgebräuchliches": "meistgebräuchlich",
    "meistgebräuchlichste": "meistgebräuchlich",
    "meistgebräuchlichstem": "meistgebräuchlich",
    "meistgebräuchlichsten": "meistgebräuchlich",
    "meistgebräuchlichster": "meistgebräuchlich",
    "meistgebräuchlichstes": "meistgebräuchlich",
    "meistgeflogene": "meistgeflogen",
    "meistgeflogenem": "meistgeflogen",
    "meistgeflogenen": "meistgeflogen",
    "meistgeflogener": "meistgeflogen",
    "meistgeflogenere": "meistgeflogen",
    "meistgeflogenerem": "meistgeflogen",
    "meistgeflogeneren": "meistgeflogen",
    "meistgeflogenerer": "meistgeflogen",
    "meistgeflogeneres": "meistgeflogen",
    "meistgeflogenes": "meistgeflogen",
    "meistgeflogenste": "meistgeflogen",
    "meistgeflogenstem": "meistgeflogen",
    "meistgeflogensten": "meistgeflogen",
    "meistgeflogenster": "meistgeflogen",
    "meistgeflogenstes": "meistgeflogen",
    "meistgenannte": "meistgenannt",
    "meistgenanntem": "meistgenannt",
    "meistgenannten": "meistgenannt",
    "meistgenannter": "meistgenannt",
    "meistgenanntes": "meistgenannt",
    "meißele": "meißeln",
    "meißelnd": "meißeln",
    "meißelnde": "meißelnd",
    "meißelndem": "meißelnd",
    "meißelnden": "meißelnd",
    "meißelnder": "meißelnd",
    "meißelndes": "meißelnd",
    "meißelst": "meißeln",
    "meißelt": "meißeln",
    "meißelte": "meißeln",
    "meißelten": "meißeln",
    "meißeltest": "meißeln",
    "meißeltet": "meißeln",
    "meißle": "meißeln",
    "melde": "melden",
    "meldend": "melden",
    "meldende": "meldend",
    "meldendem": "meldend",
    "meldenden": "meldend",
    "meldender": "meldend",
    "meldendes": "meldend",
    "meldepflichtigem": "meldepflichtig",
    "meldepflichtigen": "meldepflichtig",
    "meldepflichtiger": "meldepflichtig",
    "meldepflichtiges": "meldepflichtig",
    "meldest": "melden",
    "meldet": "melden",
    "meldete": "melden",
    "meldeten": "melden",
    "meldetest": "melden",
    "meldetet": "melden",
    "melke": "melken",
    "melkend": "melken",
    "melkende": "melkend",
    "melkendem": "melkend",
    "melkenden": "melkend",
    "melkender": "melkend",
    "melkendes": "melkend",
    "melkest": "melken",
    "melket": "melken",
    "melkst": "melken",
    "melkt": "melken",
    "melkte": "melken",
    "melkten": "melken",
    "melktest": "melken",
    "melktet": "melken",
    "melodische": "melodisch",
    "melodischem": "melodisch",
    "melodischen": "melodisch",
    "melodischer": "melodisch",
    "melodischere": "melodisch",
    "melodischerem": "melodisch",
    "melodischeren": "melodisch",
    "melodischerer": "melodisch",
    "melodischeres": "melodisch",
    "melodisches": "melodisch",
    "melodischste": "melodisch",
    "melodischstem": "melodisch",
    "melodischsten": "melodisch",
    "melodischster": "melodisch",
    "melodischstes": "melodisch",
    "melodiösem": "melodiös",
    "melodiösen": "melodiös",
    "melodiöser": "melodiös",
    "melodiösere": "melodiös",
    "melodiöserem": "melodiös",
    "melodiöseren": "melodiös",
    "melodiöserer": "melodiös",
    "melodiöseres": "melodiös",
    "melodiöses": "melodiös",
    "melodiöseste": "melodiös",
    "melodiösestem": "melodiös",
    "melodiösesten": "melodiös",
    "melodiösester": "melodiös",
    "melodiösestes": "melodiös",
    "melodramatische": "melodramatisch",
    "melodramatischem": "melodramatisch",
    "melodramatischen": "melodramatisch",
    "melodramatischer": "melodramatisch",
    "melodramatisches": "melodramatisch",
    "memoriere": "memorieren",
    "memorierend": "memorieren",
    "memorierende": "memorierend",
    "memorierendem": "memorierend",
    "memorierenden": "memorierend",
    "memorierender": "memorierend",
    "memorierendes": "memorierend",
    "memorierest": "memorieren",
    "memorieret": "memorieren",
    "memorierst": "memorieren",
    "memoriert": "memorieren",
    "memorierte": "memorieren",
    "memoriertem": "memoriert",
    "memorierten": "memorieren",
    "memorierter": "memoriert",
    "memoriertes": "memoriert",
    "memoriertest": "memorieren",
    "memoriertet": "memorieren",
    "mengend": "mengen",
    "mengende": "mengend",
    "mengendem": "mengend",
    "mengenden": "mengend",
    "mengender": "mengend",
    "mengendes": "mengend",
    "mengest": "mengen",
    "menget": "mengen",
    "mengst": "mengen",
    "mengt": "mengen",
    "mengte": "mengen",
    "mengten": "mengen",
    "mengtest": "mengen",
    "mengtet": "mengen",
    "menschenfeindlichem": "menschenfeindlich",
    "menschenfeindlichen": "menschenfeindlich",
    "menschenfeindlicher": "menschenfeindlich",
    "menschenfeindlichere": "menschenfeindlich",
    "menschenfeindlicherem": "menschenfeindlich",
    "menschenfeindlicheren": "menschenfeindlich",
    "menschenfeindlicherer": "menschenfeindlich",
    "menschenfeindlicheres": "menschenfeindlich",
    "menschenfeindliches": "menschenfeindlich",
    "menschenfeindlichste": "menschenfeindlich",
    "menschenfeindlichstem": "menschenfeindlich",
    "menschenfeindlichsten": "menschenfeindlich",
    "menschenfeindlichster": "menschenfeindlich",
    "menschenfeindlichstes": "menschenfeindlich",
    "menschenfreundliche": "menschenfreundlich",
    "menschenfreundlichem": "menschenfreundlich",
    "menschenfreundlichen": "menschenfreundlich",
    "menschenfreundlicher": "menschenfreundlich",
    "menschenfreundlichere": "menschenfreundlich",
    "menschenfreundlicherem": "menschenfreundlich",
    "menschenfreundlicheren": "menschenfreundlich",
    "menschenfreundlicherer": "menschenfreundlich",
    "menschenfreundlicheres": "menschenfreundlich",
    "menschenfreundliches": "menschenfreundlich",
    "menschenfreundlichste": "menschenfreundlich",
    "menschenfreundlichstem": "menschenfreundlich",
    "menschenfreundlichsten": "menschenfreundlich",
    "menschenfreundlichster": "menschenfreundlich",
    "menschenfreundlichstes": "menschenfreundlich",
    "menschenscheue": "menschenscheu",
    "menschenscheuem": "menschenscheu",
    "menschenscheuen": "menschenscheu",
    "menschenscheuer": "menschenscheu",
    "menschenscheuere": "menschenscheu",
    "menschenscheuerem": "menschenscheu",
    "menschenscheueren": "menschenscheu",
    "menschenscheuerer": "menschenscheu",
    "menschenscheueres": "menschenscheu",
    "menschenscheues": "menschenscheu",
    "menschenscheuste": "menschenscheu",
    "menschenscheustem": "menschenscheu",
    "menschenscheusten": "menschenscheu",
    "menschenscheuster": "menschenscheu",
    "menschenscheustes": "menschenscheu",
    "menschenunwürdige": "menschenunwürdig",
    "menschenunwürdigem": "menschenunwürdig",
    "menschenunwürdigen": "menschenunwürdig",
    "menschenunwürdiger": "menschenunwürdig",
    "menschenunwürdigere": "menschenunwürdig",
    "menschenunwürdigerem": "menschenunwürdig",
    "menschenunwürdigeren": "menschenunwürdig",
    "menschenunwürdigerer": "menschenunwürdig",
    "menschenunwürdigeres": "menschenunwürdig",
    "menschenunwürdiges": "menschenunwürdig",
    "menschenunwürdigste": "menschenunwürdig",
    "menschenunwürdigstem": "menschenunwürdig",
    "menschenunwürdigsten": "menschenunwürdig",
    "menschenunwürdigster": "menschenunwürdig",
    "menschenunwürdigstes": "menschenunwürdig",
    "menschlichem": "menschlich",
    "menschlichen": "menschlich",
    "menschlicher": "menschlich",
    "menschlichere": "menschlich",
    "menschlicherem": "menschlich",
    "menschlicheren": "menschlich",
    "menschlicherer": "menschlich",
    "menschlicheres": "menschlich",
    "menschliches": "menschlich",
    "menschlichste": "menschlich",
    "menschlichstem": "menschlich",
    "menschlichsten": "menschlich",
    "menschlichster": "menschlich",
    "menschlichstes": "menschlich",
    "mentale": "mental",
    "mentalem": "mental",
    "mentalen": "mental",
    "mentaler": "mental",
    "mentales": "mental",
    "merkbarem": "merkbar",
    "merkbaren": "merkbar",
    "merkbarer": "merkbar",
    "merkbares": "merkbar",
    "merke": "merken",
    "merkend": "merken",
    "merkende": "merkend",
    "merkendem": "merkend",
    "merkenden": "merkend",
    "merkender": "merkend",
    "merkendes": "merkend",
    "merkest": "merken",
    "merket": "merken",
    "merkliche": "merklich",
    "merklichem": "merklich",
    "merklichen": "merklich",
    "merklicher": "merklich",
    "merkliches": "merklich",
    "merkst": "merken",
    "merkt": "merken",
    "merkte": "merken",
    "merkten": "merken",
    "merktest": "merken",
    "merktet": "merken",
    "merkwürdige": "merkwürdig",
    "merkwürdigem": "merkwürdig",
    "merkwürdigen": "merkwürdig",
    "merkwürdiger": "merkwürdig",
    "merkwürdigere": "merkwürdig",
    "merkwürdigerem": "merkwürdig",
    "merkwürdigeren": "merkwürdig",
    "merkwürdigerer": "merkwürdig",
    "merkwürdigeres": "merkwürdig",
    "merkwürdiges": "merkwürdig",
    "merkwürdigstem": "merkwürdig",
    "merkwürdigsten": "merkwürdig",
    "merkwürdigster": "merkwürdig",
    "merkwürdigstes": "merkwürdig",
    "merze": "merzen",
    "merzend": "merzen",
    "merzende": "merzend",
    "merzendem": "merzend",
    "merzenden": "merzend",
    "merzender": "merzend",
    "merzendes": "merzend",
    "merzest": "merzen",
    "merzet": "merzen",
    "merzt": "merzen",
    "merzte": "merzen",
    "merzten": "merzen",
    "merztest": "merzen",
    "merztet": "merzen",
    "messend": "messen",
    "messende": "messend",
    "messendem": "messend",
    "messenden": "messend",
    "messender": "messend",
    "messendes": "messend",
    "messerscharfem": "messerscharf",
    "messerscharfen": "messerscharf",
    "messerscharfer": "messerscharf",
    "messerscharfes": "messerscharf",
    "messest": "messen",
    "messet": "messen",
    "metallischem": "metallisch",
    "metallischen": "metallisch",
    "metallischer": "metallisch",
    "metallisches": "metallisch",
    "metallisiere": "metallisieren",
    "metallisierend": "metallisieren",
    "metallisierende": "metallisierend",
    "metallisierendem": "metallisierend",
    "metallisierenden": "metallisierend",
    "metallisierender": "metallisierend",
    "metallisierendere": "metallisierend",
    "metallisierenderem": "metallisierend",
    "metallisierenderen": "metallisierend",
    "metallisierenderer": "metallisierend",
    "metallisierenderes": "metallisierend",
    "metallisierendes": "metallisierend",
    "metallisierendste": "metallisierend",
    "metallisierendstem": "metallisierend",
    "metallisierendsten": "metallisierend",
    "metallisierendster": "metallisierend",
    "metallisierendstes": "metallisierend",
    "metallisierest": "metallisieren",
    "metallisieret": "metallisieren",
    "metallisierst": "metallisieren",
    "metallisiert": "metallisieren",
    "metallisierte": "metallisieren",
    "metallisiertem": "metallisiert",
    "metallisierten": "metallisieren",
    "metallisierter": "metallisiert",
    "metallisiertere": "metallisiert",
    "metallisierterem": "metallisiert",
    "metallisierteren": "metallisiert",
    "metallisierterer": "metallisiert",
    "metallisierteres": "metallisiert",
    "metallisiertes": "metallisiert",
    "metallisiertest": "metallisieren",
    "metallisierteste": "metallisiert",
    "metallisiertestem": "metallisiert",
    "metallisiertesten": "metallisiert",
    "metallisiertester": "metallisiert",
    "metallisiertestes": "metallisiert",
    "metallisiertet": "metallisieren",
    "metaphysischem": "metaphysisch",
    "metaphysischen": "metaphysisch",
    "metaphysischer": "metaphysisch",
    "metaphysisches": "metaphysisch",
    "meteorologischem": "meteorologisch",
    "meteorologischen": "meteorologisch",
    "meteorologischer": "meteorologisch",
    "meteorologisches": "meteorologisch",
    "meterlangem": "meterlang",
    "meterlangen": "meterlang",
    "meterlanger": "meterlang",
    "meterlanges": "meterlang",
    "methodischem": "methodisch",
    "methodischen": "methodisch",
    "methodischer": "methodisch",
    "methodisches": "methodisch",
    "methodisiere": "methodisieren",
    "methodisierend": "methodisieren",
    "methodisierende": "methodisierend",
    "methodisierendem": "methodisierend",
    "methodisierenden": "methodisierend",
    "methodisierender": "methodisierend",
    "methodisierendes": "methodisierend",
    "methodisierest": "methodisieren",
    "methodisieret": "methodisieren",
    "methodisierst": "methodisieren",
    "methodisiert": "methodisieren",
    "methodisierte": "methodisieren",
    "methodisiertem": "methodisiert",
    "methodisierten": "methodisieren",
    "methodisierter": "methodisiert",
    "methodisiertere": "methodisiert",
    "methodisierterem": "methodisiert",
    "methodisierteren": "methodisiert",
    "methodisierterer": "methodisiert",
    "methodisierteres": "methodisiert",
    "methodisiertes": "methodisiert",
    "methodisiertest": "methodisieren",
    "methodisierteste": "methodisiert",
    "methodisiertestem": "methodisiert",
    "methodisiertesten": "methodisiert",
    "methodisiertester": "methodisiert",
    "methodisiertestes": "methodisiert",
    "methodisiertet": "methodisieren",
    "metrischem": "metrisch",
    "metrischen": "metrisch",
    "metrischer": "metrisch",
    "metrisches": "metrisch",
    "metzele": "metzeln",
    "metzelnd": "metzeln",
    "metzelnde": "metzelnd",
    "metzelndem": "metzelnd",
    "metzelnden": "metzelnd",
    "metzelnder": "metzelnd",
    "metzelndere": "metzelnd",
    "metzelnderem": "metzelnd",
    "metzelnderen": "metzelnd",
    "metzelnderer": "metzelnd",
    "metzelnderes": "metzelnd",
    "metzelndes": "metzelnd",
    "metzelndste": "metzelnd",
    "metzelndstem": "metzelnd",
    "metzelndsten": "metzelnd",
    "metzelndster": "metzelnd",
    "metzelndstes": "metzelnd",
    "metzelst": "metzeln",
    "metzelt": "metzeln",
    "metzelte": "metzeln",
    "metzelten": "metzeln",
    "metzeltest": "metzeln",
    "metzeltet": "metzeln",
    "metzle": "metzeln",
    "meutere": "meutern",
    "meuternd": "meutern",
    "meuternde": "meuternd",
    "meuterndem": "meuternd",
    "meuternden": "meuternd",
    "meuternder": "meuternd",
    "meuterndere": "meuternd",
    "meuternderem": "meuternd",
    "meuternderen": "meuternd",
    "meuternderer": "meuternd",
    "meuternderes": "meuternd",
    "meuterndes": "meuternd",
    "meuterndste": "meuternd",
    "meuterndstem": "meuternd",
    "meuterndsten": "meuternd",
    "meuterndster": "meuternd",
    "meuterndstes": "meuternd",
    "meuterst": "meutern",
    "meutert": "meutern",
    "meuterte": "meutern",
    "meuterten": "meutern",
    "meutertest": "meutern",
    "meutertet": "meutern",
    "mexikanische": "mexikanisch",
    "mexikanischem": "mexikanisch",
    "mexikanischen": "mexikanisch",
    "mexikanischer": "mexikanisch",
    "mexikanischere": "mexikanisch",
    "mexikanischerem": "mexikanisch",
    "mexikanischeren": "mexikanisch",
    "mexikanischerer": "mexikanisch",
    "mexikanischeres": "mexikanisch",
    "mexikanisches": "mexikanisch",
    "mexikanischste": "mexikanisch",
    "mexikanischstem": "mexikanisch",
    "mexikanischsten": "mexikanisch",
    "mexikanischster": "mexikanisch",
    "mexikanischstes": "mexikanisch",
    "meßbarem": "meßbar",
    "meßbaren": "meßbar",
    "meßbarer": "meßbar",
    "meßbares": "meßbar",
    "meßt": "messen",
    "mich": "sich",
    "mied": "meiden",
    "miede": "meiden",
    "mieden": "meiden",
    "miedest": "meiden",
    "miedet": "meiden",
    "miefe": "miefen",
    "miefend": "miefen",
    "miefende": "miefend",
    "miefendem": "miefend",
    "miefenden": "miefend",
    "miefender": "miefend",
    "miefendere": "miefend",
    "miefenderem": "miefend",
    "miefenderen": "miefend",
    "miefenderer": "miefend",
    "miefenderes": "miefend",
    "miefendes": "miefend",
    "miefendste": "miefend",
    "miefendstem": "miefend",
    "miefendsten": "miefend",
    "miefendster": "miefend",
    "miefendstes": "miefend",
    "miefest": "miefen",
    "miefet": "miefen",
    "miefst": "miefen",
    "mieft": "miefen",
    "miefte": "miefen",
    "mieften": "miefen",
    "mieftest": "miefen",
    "mieftet": "miefen",
    "miesem": "mies",
    "miesen": "mies",
    "mieser": "mies",
    "miesere": "mies",
    "mieserem": "mies",
    "mieseren": "mies",
    "mieserer": "mies",
    "mieseres": "mies",
    "mieses": "mies",
    "mieseste": "mies",
    "miesestem": "mies",
    "miesesten": "mies",
    "miesester": "mies",
    "miesestes": "mies",
    "mietend": "mieten",
    "mietende": "mietend",
    "mietendem": "mietend",
    "mietenden": "mietend",
    "mietender": "mietend",
    "mietendes": "mietend",
    "mietest": "mieten",
    "mietet": "mieten",
    "mietete": "mieten",
    "mieteten": "mieten",
    "mietetest": "mieten",
    "mietetet": "mieten",
    "mietfreie": "mietfrei",
    "mietfreiem": "mietfrei",
    "mietfreien": "mietfrei",
    "mietfreier": "mietfrei",
    "mietfreies": "mietfrei",
    "milchigem": "milchig",
    "milchigen": "milchig",
    "milchiger": "milchig",
    "milchigere": "milchig",
    "milchigerem": "milchig",
    "milchigeren": "milchig",
    "milchigerer": "milchig",
    "milchigeres": "milchig",
    "milchiges": "milchig",
    "milchigste": "milchig",
    "milchigstem": "milchig",
    "milchigsten": "milchig",
    "milchigster": "milchig",
    "milchigstes": "milchig",
    "milde": "mild",
    "mildem": "mild",
    "milden": "mild",
    "milder": "mildern",
    "mildere": "mild",
    "milderem": "mild",
    "milderen": "mild",
    "milderer": "mild",
    "milderes": "mild",
    "mildernd": "mildern",
    "mildernde": "mildernd",
    "milderndem": "mildernd",
    "mildernden": "mildernd",
    "mildernder": "mildernd",
    "milderndere": "mildernd",
    "mildernderem": "mildernd",
    "mildernderen": "mildernd",
    "mildernderer": "mildernd",
    "mildernderes": "mildernd",
    "milderndes": "mildernd",
    "milderndste": "mildernd",
    "milderndstem": "mildernd",
    "milderndsten": "mildernd",
    "milderndster": "mildernd",
    "milderndstes": "mildernd",
    "milderst": "mildern",
    "mildert": "mildern",
    "milderte": "mildern",
    "milderten": "mildern",
    "mildertest": "mildern",
    "mildertet": "mildern",
    "mildes": "mild",
    "mildeste": "mild",
    "mildestem": "mild",
    "mildesten": "mild",
    "mildester": "mild",
    "mildestes": "mild",
    "mildtätige": "mildtätig",
    "mildtätigem": "mildtätig",
    "mildtätigen": "mildtätig",
    "mildtätiger": "mildtätig",
    "mildtätigere": "mildtätig",
    "mildtätigerem": "mildtätig",
    "mildtätigeren": "mildtätig",
    "mildtätigerer": "mildtätig",
    "mildtätigeres": "mildtätig",
    "mildtätiges": "mildtätig",
    "mildtätigste": "mildtätig",
    "mildtätigstem": "mildtätig",
    "mildtätigsten": "mildtätig",
    "mildtätigster": "mildtätig",
    "mildtätigstes": "mildtätig",
    "militantem": "militant",
    "militanten": "militant",
    "militanter": "militant",
    "militantere": "militant",
    "militanterem": "militant",
    "militanteren": "militant",
    "militanterer": "militant",
    "militanteres": "militant",
    "militantes": "militant",
    "militanteste": "militant",
    "militantestem": "militant",
    "militantesten": "militant",
    "militantester": "militant",
    "militantestes": "militant",
    "militarisiere": "militarisieren",
    "militarisierend": "militarisieren",
    "militarisierende": "militarisierend",
    "militarisierendem": "militarisierend",
    "militarisierenden": "militarisierend",
    "militarisierender": "militarisierend",
    "militarisierendere": "militarisierend",
    "militarisierenderem": "militarisierend",
    "militarisierenderen": "militarisierend",
    "militarisierenderer": "militarisierend",
    "militarisierenderes": "militarisierend",
    "militarisierendes": "militarisierend",
    "militarisierendste": "militarisierend",
    "militarisierendstem": "militarisierend",
    "militarisierendsten": "militarisierend",
    "militarisierendster": "militarisierend",
    "militarisierendstes": "militarisierend",
    "militarisierest": "militarisieren",
    "militarisieret": "militarisieren",
    "militarisierst": "militarisieren",
    "militarisiert": "militarisieren",
    "militarisierte": "militarisieren",
    "militarisiertem": "militarisiert",
    "militarisierten": "militarisieren",
    "militarisierter": "militarisiert",
    "militarisiertere": "militarisiert",
    "militarisierterem": "militarisiert",
    "militarisierteren": "militarisiert",
    "militarisierterer": "militarisiert",
    "militarisierteres": "militarisiert",
    "militarisiertes": "militarisiert",
    "militarisiertest": "militarisieren",
    "militarisiertestem": "militarisiert",
    "militarisiertesten": "militarisiert",
    "militarisiertester": "militarisiert",
    "militarisiertestes": "militarisiert",
    "militarisiertet": "militarisieren",
    "militärische": "militärisch",
    "militärischem": "militärisch",
    "militärischen": "militärisch",
    "militärischer": "militärisch",
    "militärischere": "militärisch",
    "militärischerem": "militärisch",
    "militärischeren": "militärisch",
    "militärischerer": "militärisch",
    "militärischeres": "militärisch",
    "militärisches": "militärisch",
    "militärischste": "militärisch",
    "militärischstem": "militärisch",
    "militärischsten": "militärisch",
    "militärischster": "militärisch",
    "militärischstes": "militärisch",
    "milk": "melken",
    "milkst": "melken",
    "milkt": "melken",
    "millimetergroßem": "millimetergroß",
    "millimetergroßen": "millimetergroß",
    "millimetergroßer": "millimetergroß",
    "millimetergroßes": "millimetergroß",
    "mime": "mimen",
    "mimend": "mimen",
    "mimende": "mimend",
    "mimendem": "mimend",
    "mimenden": "mimend",
    "mimender": "mimend",
    "mimendes": "mimend",
    "mimest": "mimen",
    "mimet": "mimen",
    "mimische": "mimisch",
    "mimischem": "mimisch",
    "mimischen": "mimisch",
    "mimischer": "mimisch",
    "mimisches": "mimisch",
    "mimosenhaftem": "mimosenhaft",
    "mimosenhaften": "mimosenhaft",
    "mimosenhafter": "mimosenhaft",
    "mimosenhaftere": "mimosenhaft",
    "mimosenhafterem": "mimosenhaft",
    "mimosenhafteren": "mimosenhaft",
    "mimosenhafterer": "mimosenhaft",
    "mimosenhafteres": "mimosenhaft",
    "mimosenhaftes": "mimosenhaft",
    "mimosenhafteste": "mimosenhaft",
    "mimosenhaftestem": "mimosenhaft",
    "mimosenhaftesten": "mimosenhaft",
    "mimosenhaftester": "mimosenhaft",
    "mimosenhaftestes": "mimosenhaft",
    "mimst": "mimen",
    "mimt": "mimen",
    "mimte": "mimen",
    "mimten": "mimen",
    "mimtest": "mimen",
    "mimtet": "mimen",
    "minder": "mindern",
    "minderbegabte": "minderbegabt",
    "minderbegabtem": "minderbegabt",
    "minderbegabten": "minderbegabt",
    "minderbegabter": "minderbegabt",
    "minderbegabtes": "minderbegabt",
    "mindere": "mindern",
    "minderjährigem": "minderjährig",
    "minderjährigen": "minderjährig",
    "minderjähriger": "minderjährig",
    "minderjähriges": "minderjährig",
    "mindernd": "mindern",
    "mindernde": "mindernd",
    "minderndem": "mindernd",
    "mindernden": "mindernd",
    "mindernder": "mindernd",
    "minderndes": "mindernd",
    "minderst": "mindern",
    "mindert": "mindern",
    "minderte": "mindern",
    "minderten": "mindern",
    "mindertest": "mindern",
    "mindertet": "mindern",
    "minderwertigem": "minderwertig",
    "minderwertigen": "minderwertig",
    "minderwertiger": "minderwertig",
    "minderwertigere": "minderwertig",
    "minderwertigerem": "minderwertig",
    "minderwertigeren": "minderwertig",
    "minderwertigerer": "minderwertig",
    "minderwertigeres": "minderwertig",
    "minderwertiges": "minderwertig",
    "minderwertigstem": "minderwertig",
    "minderwertigsten": "minderwertig",
    "minderwertigster": "minderwertig",
    "minderwertigstes": "minderwertig",
    "mineralischem": "mineralisch",
    "mineralischen": "mineralisch",
    "mineralischer": "mineralisch",
    "mineralisches": "mineralisch",
    "miniaturisiere": "miniaturisieren",
    "miniaturisierend": "miniaturisieren",
    "miniaturisierende": "miniaturisierend",
    "miniaturisierendem": "miniaturisierend",
    "miniaturisierenden": "miniaturisierend",
    "miniaturisierender": "miniaturisierend",
    "miniaturisierendes": "miniaturisierend",
    "miniaturisierest": "miniaturisieren",
    "miniaturisieret": "miniaturisieren",
    "miniaturisierst": "miniaturisieren",
    "miniaturisiert": "miniaturisieren",
    "miniaturisierte": "miniaturisieren",
    "miniaturisiertem": "miniaturisiert",
    "miniaturisierten": "miniaturisieren",
    "miniaturisierter": "miniaturisiert",
    "miniaturisiertes": "miniaturisiert",
    "miniaturisiertest": "miniaturisieren",
    "miniaturisiertet": "miniaturisieren",
    "minimalem": "minimal",
    "minimalen": "minimal",
    "minimaler": "minimal",
    "minimales": "minimal",
    "minimalisiere": "minimalisieren",
    "minimalisierend": "minimalisieren",
    "minimalisierende": "minimalisierend",
    "minimalisierendem": "minimalisierend",
    "minimalisierenden": "minimalisierend",
    "minimalisierender": "minimalisierend",
    "minimalisierendes": "minimalisierend",
    "minimalisierest": "minimalisieren",
    "minimalisieret": "minimalisieren",
    "minimalisierst": "minimalisieren",
    "minimalisiert": "minimalisieren",
    "minimalisierte": "minimalisieren",
    "minimalisiertem": "minimalisiert",
    "minimalisierten": "minimalisieren",
    "minimalisierter": "minimalisiert",
    "minimalisiertes": "minimalisiert",
    "minimalisiertest": "minimalisieren",
    "minimalisiertet": "minimalisieren",
    "minimiere": "minimieren",
    "minimierend": "minimieren",
    "minimierende": "minimierend",
    "minimierendem": "minimierend",
    "minimierenden": "minimierend",
    "minimierender": "minimierend",
    "minimierendere": "minimierend",
    "minimierenderem": "minimierend",
    "minimierenderen": "minimierend",
    "minimierenderer": "minimierend",
    "minimierenderes": "minimierend",
    "minimierendes": "minimierend",
    "minimierendste": "minimierend",
    "minimierendstem": "minimierend",
    "minimierendsten": "minimierend",
    "minimierendster": "minimierend",
    "minimierendstes": "minimierend",
    "minimierest": "minimieren",
    "minimieret": "minimieren",
    "minimierst": "minimieren",
    "minimiert": "minimieren",
    "minimierte": "minimieren",
    "minimiertem": "minimiert",
    "minimierten": "minimieren",
    "minimierter": "minimiert",
    "minimiertere": "minimiert",
    "minimierterem": "minimiert",
    "minimierteren": "minimiert",
    "minimierterer": "minimiert",
    "minimierteres": "minimiert",
    "minimiertes": "minimiert",
    "minimiertest": "minimieren",
    "minimierteste": "minimiert",
    "minimiertestem": "minimiert",
    "minimiertesten": "minimiert",
    "minimiertester": "minimiert",
    "minimiertestes": "minimiert",
    "minimiertet": "minimieren",
    "ministerialem": "ministerial",
    "ministerialen": "ministerial",
    "ministerialer": "ministerial",
    "ministeriales": "ministerial",
    "ministerielle": "ministeriell",
    "ministeriellem": "ministeriell",
    "ministeriellen": "ministeriell",
    "ministerieller": "ministeriell",
    "ministerielles": "ministeriell",
    "minutenlangem": "minutenlang",
    "minutenlangen": "minutenlang",
    "minutenlanger": "minutenlang",
    "minutenlanges": "minutenlang",
    "minutiöse": "minutiös",
    "minutiösem": "minutiös",
    "minutiösen": "minutiös",
    "minutiöser": "minutiös",
    "minutiöses": "minutiös",
    "mir": "sich",
    "mische": "mischen",
    "mischend": "mischen",
    "mischende": "mischend",
    "mischendem": "mischend",
    "mischenden": "mischend",
    "mischender": "mischend",
    "mischendes": "mischend",
    "mischest": "mischen",
    "mischet": "mischen",
    "mischst": "mischen",
    "mischt": "mischen",
    "mischte": "mischen",
    "mischten": "mischen",
    "mischtest": "mischen",
    "mischtet": "mischen",
    "miserabelstem": "miserabel",
    "miserabelsten": "miserabel",
    "miserabelster": "miserabel",
    "miserabelstes": "miserabel",
    "miserable": "miserabel",
    "miserablem": "miserabel",
    "miserablen": "miserabel",
    "miserabler": "miserabel",
    "miserablere": "miserabel",
    "miserablerem": "miserabel",
    "miserableren": "miserabel",
    "miserablerer": "miserabel",
    "miserableres": "miserabel",
    "miserables": "miserabel",
    "misse": "missen",
    "missend": "missen",
    "missende": "missend",
    "missendem": "missend",
    "missenden": "missend",
    "missender": "missend",
    "missendes": "missend",
    "missest": "missen",
    "misset": "missen",
    "missionarischem": "missionarisch",
    "missionarischen": "missionarisch",
    "missionarischer": "missionarisch",
    "missionarisches": "missionarisch",
    "missioniere": "missionieren",
    "missionierend": "missionieren",
    "missionierende": "missionierend",
    "missionierendem": "missionierend",
    "missionierenden": "missionierend",
    "missionierender": "missionierend",
    "missionierendere": "missionierend",
    "missionierenderem": "missionierend",
    "missionierenderen": "missionierend",
    "missionierenderer": "missionierend",
    "missionierenderes": "missionierend",
    "missionierendes": "missionierend",
    "missionierendste": "missionierend",
    "missionierendstem": "missionierend",
    "missionierendsten": "missionierend",
    "missionierendster": "missionierend",
    "missionierendstes": "missionierend",
    "missionierest": "missionieren",
    "missionieret": "missionieren",
    "missionierst": "missionieren",
    "missioniert": "missionieren",
    "missionierte": "missionieren",
    "missioniertem": "missioniert",
    "missionierten": "missionieren",
    "missionierter": "missioniert",
    "missioniertere": "missioniert",
    "missionierterem": "missioniert",
    "missionierteren": "missioniert",
    "missionierterer": "missioniert",
    "missionierteres": "missioniert",
    "missioniertes": "missioniert",
    "missioniertest": "missionieren",
    "missionierteste": "missioniert",
    "missioniertestem": "missioniert",
    "missioniertesten": "missioniert",
    "missioniertester": "missioniert",
    "missioniertestes": "missioniert",
    "missioniertet": "missionieren",
    "miste": "misten",
    "mistend": "misten",
    "mistende": "mistend",
    "mistendem": "mistend",
    "mistenden": "mistend",
    "mistender": "mistend",
    "mistendes": "mistend",
    "mistest": "misten",
    "mistet": "misten",
    "mistete": "misten",
    "misteten": "misten",
    "mistetest": "misten",
    "mistetet": "misten",
    "mitarbeite": "mitarbeiten",
    "mitarbeitend": "mitarbeiten",
    "mitarbeitende": "mitarbeitend",
    "mitarbeitendem": "mitarbeitend",
    "mitarbeitenden": "mitarbeitend",
    "mitarbeitender": "mitarbeitend",
    "mitarbeitendes": "mitarbeitend",
    "mitarbeitest": "mitarbeiten",
    "mitarbeitet": "mitarbeiten",
    "mitarbeitete": "mitarbeiten",
    "mitarbeiteten": "mitarbeiten",
    "mitarbeitetest": "mitarbeiten",
    "mitarbeitetet": "mitarbeiten",
    "mitaß": "mitessen",
    "mitaßen": "mitessen",
    "mitaßt": "mitessen",
    "mitbekam": "mitbekommen",
    "mitbekamen": "mitbekommen",
    "mitbekamst": "mitbekommen",
    "mitbekamt": "mitbekommen",
    "mitbekomme": "mitbekommen",
    "mitbekommend": "mitbekommen",
    "mitbekommende": "mitbekommend",
    "mitbekommendem": "mitbekommend",
    "mitbekommenden": "mitbekommend",
    "mitbekommender": "mitbekommend",
    "mitbekommendes": "mitbekommend",
    "mitbekommene": "mitbekommen",
    "mitbekommenem": "mitbekommen",
    "mitbekommenen": "mitbekommen",
    "mitbekommener": "mitbekommen",
    "mitbekommenes": "mitbekommen",
    "mitbekommest": "mitbekommen",
    "mitbekommet": "mitbekommen",
    "mitbekommst": "mitbekommen",
    "mitbekommt": "mitbekommen",
    "mitbekäme": "mitbekommen",
    "mitbekämen": "mitbekommen",
    "mitbekämest": "mitbekommen",
    "mitbekämet": "mitbekommen",
    "mitbenutze": "mitbenutzen",
    "mitbenutzend": "mitbenutzen",
    "mitbenutzende": "mitbenutzend",
    "mitbenutzendem": "mitbenutzend",
    "mitbenutzenden": "mitbenutzend",
    "mitbenutzender": "mitbenutzend",
    "mitbenutzendes": "mitbenutzend",
    "mitbenutzest": "mitbenutzen",
    "mitbenutzet": "mitbenutzen",
    "mitbenutzt": "mitbenutzen",
    "mitbenutzte": "mitbenutzen",
    "mitbenutztem": "mitbenutzt",
    "mitbenutzten": "mitbenutzen",
    "mitbenutzter": "mitbenutzt",
    "mitbenutztes": "mitbenutzt",
    "mitbenutztest": "mitbenutzen",
    "mitbenutztet": "mitbenutzen",
    "mitbestimme": "mitbestimmen",
    "mitbestimmend": "mitbestimmen",
    "mitbestimmende": "mitbestimmend",
    "mitbestimmendem": "mitbestimmend",
    "mitbestimmenden": "mitbestimmend",
    "mitbestimmender": "mitbestimmend",
    "mitbestimmendere": "mitbestimmend",
    "mitbestimmenderem": "mitbestimmend",
    "mitbestimmenderen": "mitbestimmend",
    "mitbestimmenderer": "mitbestimmend",
    "mitbestimmenderes": "mitbestimmend",
    "mitbestimmendes": "mitbestimmend",
    "mitbestimmendste": "mitbestimmend",
    "mitbestimmendstem": "mitbestimmend",
    "mitbestimmendsten": "mitbestimmend",
    "mitbestimmendster": "mitbestimmend",
    "mitbestimmendstes": "mitbestimmend",
    "mitbestimmest": "mitbestimmen",
    "mitbestimmet": "mitbestimmen",
    "mitbestimmst": "mitbestimmen",
    "mitbestimmt": "mitbestimmen",
    "mitbestimmte": "mitbestimmen",
    "mitbestimmtem": "mitbestimmt",
    "mitbestimmten": "mitbestimmen",
    "mitbestimmter": "mitbestimmt",
    "mitbestimmtere": "mitbestimmt",
    "mitbestimmterem": "mitbestimmt",
    "mitbestimmteren": "mitbestimmt",
    "mitbestimmterer": "mitbestimmt",
    "mitbestimmteres": "mitbestimmt",
    "mitbestimmtes": "mitbestimmt",
    "mitbestimmtest": "mitbestimmen",
    "mitbestimmteste": "mitbestimmt",
    "mitbestimmtestem": "mitbestimmt",
    "mitbestimmtesten": "mitbestimmt",
    "mitbestimmtester": "mitbestimmt",
    "mitbestimmtestes": "mitbestimmt",
    "mitbestimmtet": "mitbestimmen",
    "mitbewarb": "mitbewerben",
    "mitbewarben": "mitbewerben",
    "mitbewarbst": "mitbewerben",
    "mitbewarbt": "mitbewerben",
    "mitbewerbe": "mitbewerben",
    "mitbewerbend": "mitbewerben",
    "mitbewerbende": "mitbewerbend",
    "mitbewerbendem": "mitbewerbend",
    "mitbewerbenden": "mitbewerbend",
    "mitbewerbender": "mitbewerbend",
    "mitbewerbendes": "mitbewerbend",
    "mitbewerbest": "mitbewerben",
    "mitbewerbet": "mitbewerben",
    "mitbewerbt": "mitbewerben",
    "mitbewirbst": "mitbewerben",
    "mitbewirbt": "mitbewerben",
    "mitbeworben": "mitbewerben",
    "mitbeworbene": "mitbeworben",
    "mitbeworbenem": "mitbeworben",
    "mitbeworbenen": "mitbeworben",
    "mitbeworbener": "mitbeworben",
    "mitbeworbenes": "mitbeworben",
    "mitbewärbe": "mitbewerben",
    "mitbewärben": "mitbewerben",
    "mitbewärbest": "mitbewerben",
    "mitbewärbet": "mitbewerben",
    "mitbrachte": "mitbringen",
    "mitbrachten": "mitbringen",
    "mitbrachtest": "mitbringen",
    "mitbrachtet": "mitbringen",
    "mitbringe": "mitbringen",
    "mitbringend": "mitbringen",
    "mitbringende": "mitbringend",
    "mitbringendem": "mitbringend",
    "mitbringenden": "mitbringend",
    "mitbringender": "mitbringend",
    "mitbringendes": "mitbringend",
    "mitbringest": "mitbringen",
    "mitbringet": "mitbringen",
    "mitbringst": "mitbringen",
    "mitbringt": "mitbringen",
    "mitbrächte": "mitbringen",
    "mitbrächten": "mitbringen",
    "mitbrächtest": "mitbringen",
    "mitbrächtet": "mitbringen",
    "mitempfand": "mitempfinden",
    "mitempfanden": "mitempfinden",
    "mitempfandest": "mitempfinden",
    "mitempfandet": "mitempfinden",
    "mitempfinde": "mitempfinden",
    "mitempfindend": "mitempfinden",
    "mitempfindende": "mitempfindend",
    "mitempfindendem": "mitempfindend",
    "mitempfindenden": "mitempfindend",
    "mitempfindender": "mitempfindend",
    "mitempfindendes": "mitempfindend",
    "mitempfindest": "mitempfinden",
    "mitempfindet": "mitempfinden",
    "mitempfunden": "mitempfinden",
    "mitempfundene": "mitempfunden",
    "mitempfundenem": "mitempfunden",
    "mitempfundenen": "mitempfunden",
    "mitempfundener": "mitempfunden",
    "mitempfundenes": "mitempfunden",
    "mitempfände": "mitempfinden",
    "mitempfänden": "mitempfinden",
    "mitempfändest": "mitempfinden",
    "mitempfändet": "mitempfinden",
    "miterlebe": "miterleben",
    "miterlebend": "miterleben",
    "miterlebende": "miterlebend",
    "miterlebendem": "miterlebend",
    "miterlebenden": "miterlebend",
    "miterlebender": "miterlebend",
    "miterlebendes": "miterlebend",
    "miterlebest": "miterleben",
    "miterlebet": "miterleben",
    "miterlebst": "miterleben",
    "miterlebt": "miterleben",
    "miterlebte": "miterleben",
    "miterlebtem": "miterlebt",
    "miterlebten": "miterleben",
    "miterlebter": "miterlebt",
    "miterlebtes": "miterlebt",
    "miterlebtest": "miterleben",
    "miterlebtet": "miterleben",
    "mitesse": "mitessen",
    "mitessend": "mitessen",
    "mitessende": "mitessend",
    "mitessendem": "mitessend",
    "mitessenden": "mitessend",
    "mitessender": "mitessend",
    "mitessendes": "mitessend",
    "mitessest": "mitessen",
    "mitesset": "mitessen",
    "miteßt": "mitessen",
    "mitfahre": "mitfahren",
    "mitfahrend": "mitfahren",
    "mitfahrende": "mitfahrend",
    "mitfahrendem": "mitfahrend",
    "mitfahrenden": "mitfahrend",
    "mitfahrender": "mitfahrend",
    "mitfahrendes": "mitfahrend",
    "mitfahrest": "mitfahren",
    "mitfahret": "mitfahren",
    "mitfahrt": "mitfahren",
    "mitfliege": "mitfliegen",
    "mitfliegend": "mitfliegen",
    "mitfliegende": "mitfliegend",
    "mitfliegendem": "mitfliegend",
    "mitfliegenden": "mitfliegend",
    "mitfliegender": "mitfliegend",
    "mitfliegendes": "mitfliegend",
    "mitfliegest": "mitfliegen",
    "mitflieget": "mitfliegen",
    "mitfliegst": "mitfliegen",
    "mitfliegt": "mitfliegen",
    "mitflog": "mitfliegen",
    "mitflogen": "mitfliegen",
    "mitflogst": "mitfliegen",
    "mitflogt": "mitfliegen",
    "mitflöge": "mitfliegen",
    "mitflögen": "mitfliegen",
    "mitflögest": "mitfliegen",
    "mitflöget": "mitfliegen",
    "mitfreue": "mitfreuen",
    "mitfreuend": "mitfreuen",
    "mitfreuende": "mitfreuend",
    "mitfreuendem": "mitfreuend",
    "mitfreuenden": "mitfreuend",
    "mitfreuender": "mitfreuend",
    "mitfreuendes": "mitfreuend",
    "mitfreuest": "mitfreuen",
    "mitfreuet": "mitfreuen",
    "mitfreust": "mitfreuen",
    "mitfreut": "mitfreuen",
    "mitfreute": "mitfreuen",
    "mitfreuten": "mitfreuen",
    "mitfreutest": "mitfreuen",
    "mitfreutet": "mitfreuen",
    "mitfuhr": "mitfahren",
    "mitfuhren": "mitfahren",
    "mitfuhrst": "mitfahren",
    "mitfuhrt": "mitfahren",
    "mitfährst": "mitfahren",
    "mitfährt": "mitfahren",
    "mitfühle": "mitfühlen",
    "mitfühlend": "mitfühlen",
    "mitfühlende": "mitfühlend",
    "mitfühlendem": "mitfühlend",
    "mitfühlenden": "mitfühlend",
    "mitfühlender": "mitfühlend",
    "mitfühlendere": "mitfühlend",
    "mitfühlenderem": "mitfühlend",
    "mitfühlenderen": "mitfühlend",
    "mitfühlenderer": "mitfühlend",
    "mitfühlenderes": "mitfühlend",
    "mitfühlendes": "mitfühlend",
    "mitfühlendste": "mitfühlend",
    "mitfühlendstem": "mitfühlend",
    "mitfühlendsten": "mitfühlend",
    "mitfühlendster": "mitfühlend",
    "mitfühlendstes": "mitfühlend",
    "mitfühlest": "mitfühlen",
    "mitfühlet": "mitfühlen",
    "mitfühlst": "mitfühlen",
    "mitfühlt": "mitfühlen",
    "mitfühlte": "mitfühlen",
    "mitfühlten": "mitfühlen",
    "mitfühltest": "mitfühlen",
    "mitfühltet": "mitfühlen",
    "mitführe": "mitfahren",
    "mitführen": "mitfahren",
    "mitführest": "mitfahren",
    "mitführet": "mitfahren",
    "mitgab": "mitgeben",
    "mitgaben": "mitgeben",
    "mitgabst": "mitgeben",
    "mitgabt": "mitgeben",
    "mitgearbeitet": "mitarbeiten",
    "mitgearbeitete": "mitgearbeitet",
    "mitgearbeitetem": "mitgearbeitet",
    "mitgearbeiteten": "mitgearbeitet",
    "mitgearbeiteter": "mitgearbeitet",
    "mitgearbeitetes": "mitgearbeitet",
    "mitgebe": "mitgeben",
    "mitgebend": "mitgeben",
    "mitgebende": "mitgebend",
    "mitgebendem": "mitgebend",
    "mitgebenden": "mitgebend",
    "mitgebender": "mitgebend",
    "mitgebendes": "mitgebend",
    "mitgebest": "mitgeben",
    "mitgebet": "mitgeben",
    "mitgebracht": "mitbringen",
    "mitgebrachte": "mitgebracht",
    "mitgebrachtem": "mitgebracht",
    "mitgebrachten": "mitgebracht",
    "mitgebrachter": "mitgebracht",
    "mitgebrachtes": "mitgebracht",
    "mitgebt": "mitgeben",
    "mitgefahren": "mitfahren",
    "mitgefahrene": "mitgefahren",
    "mitgefahrenem": "mitgefahren",
    "mitgefahrenen": "mitgefahren",
    "mitgefahrener": "mitgefahren",
    "mitgefahrenes": "mitgefahren",
    "mitgeflogen": "mitfliegen",
    "mitgeflogene": "mitgeflogen",
    "mitgeflogenem": "mitgeflogen",
    "mitgeflogenen": "mitgeflogen",
    "mitgeflogener": "mitgeflogen",
    "mitgeflogenes": "mitgeflogen",
    "mitgefreut": "mitfreuen",
    "mitgefreute": "mitgefreut",
    "mitgefreutem": "mitgefreut",
    "mitgefreuten": "mitgefreut",
    "mitgefreuter": "mitgefreut",
    "mitgefreutes": "mitgefreut",
    "mitgefühlt": "mitfühlen",
    "mitgefühlte": "mitgefühlt",
    "mitgefühltem": "mitgefühlt",
    "mitgefühlten": "mitgefühlt",
    "mitgefühlter": "mitgefühlt",
    "mitgefühltes": "mitgefühlt",
    "mitgegeben": "mitgeben",
    "mitgegebene": "mitgegeben",
    "mitgegebenem": "mitgegeben",
    "mitgegebenen": "mitgegeben",
    "mitgegebener": "mitgegeben",
    "mitgegebenes": "mitgegeben",
    "mitgegessen": "mitessen",
    "mitgegessene": "mitgegessen",
    "mitgegessenem": "mitgegessen",
    "mitgegessenen": "mitgegessen",
    "mitgegessener": "mitgegessen",
    "mitgegessenes": "mitgegessen",
    "mitgehalten": "mithalten",
    "mitgehaltene": "mitgehalten",
    "mitgehaltenem": "mitgehalten",
    "mitgehaltenen": "mitgehalten",
    "mitgehaltener": "mitgehalten",
    "mitgehaltenes": "mitgehalten",
    "mitgeholfen": "mithelfen",
    "mitgeholfene": "mitgeholfen",
    "mitgeholfenem": "mitgeholfen",
    "mitgeholfenen": "mitgeholfen",
    "mitgeholfener": "mitgeholfen",
    "mitgeholfenes": "mitgeholfen",
    "mitgehört": "mithören",
    "mitgehörte": "mitgehört",
    "mitgehörtem": "mitgehört",
    "mitgehörten": "mitgehört",
    "mitgehörter": "mitgehört",
    "mitgehörtes": "mitgehört",
    "mitgekriegt": "mitkriegen",
    "mitgekriegte": "mitgekriegt",
    "mitgekriegtem": "mitgekriegt",
    "mitgekriegten": "mitgekriegt",
    "mitgekriegter": "mitgekriegt",
    "mitgekriegtes": "mitgekriegt",
    "mitgekämpft": "mitkämpfen",
    "mitgekämpfte": "mitgekämpft",
    "mitgekämpftem": "mitgekämpft",
    "mitgekämpften": "mitgekämpft",
    "mitgekämpfter": "mitgekämpft",
    "mitgekämpftes": "mitgekämpft",
    "mitgelassen": "mitlassen",
    "mitgelassene": "mitgelassen",
    "mitgelassenem": "mitgelassen",
    "mitgelassenen": "mitgelassen",
    "mitgelassener": "mitgelassen",
    "mitgelassenes": "mitgelassen",
    "mitgelaufen": "mitlaufen",
    "mitgelaufene": "mitgelaufen",
    "mitgelaufenem": "mitgelaufen",
    "mitgelaufenen": "mitgelaufen",
    "mitgelaufener": "mitgelaufen",
    "mitgelaufenes": "mitgelaufen",
    "mitgelernt": "mitlernen",
    "mitgelernte": "mitgelernt",
    "mitgelerntem": "mitgelernt",
    "mitgelernten": "mitgelernt",
    "mitgelernter": "mitgelernt",
    "mitgelerntes": "mitgelernt",
    "mitgelitten": "mitleiden",
    "mitgelittene": "mitgelitten",
    "mitgelittenem": "mitgelitten",
    "mitgelittenen": "mitgelitten",
    "mitgelittener": "mitgelitten",
    "mitgelittenes": "mitgelitten",
    "mitgemacht": "mitmachen",
    "mitgemachte": "mitgemacht",
    "mitgemachtem": "mitgemacht",
    "mitgemachten": "mitgemacht",
    "mitgemachter": "mitgemacht",
    "mitgemachtes": "mitgemacht",
    "mitgemischt": "mitmischen",
    "mitgemischte": "mitgemischt",
    "mitgemischtem": "mitgemischt",
    "mitgemischten": "mitgemischt",
    "mitgemischter": "mitgemischt",
    "mitgemischtes": "mitgemischt",
    "mitgenommen": "mitnehmen",
    "mitgenommene": "mitgenommen",
    "mitgenommenem": "mitgenommen",
    "mitgenommenen": "mitgenommen",
    "mitgenommener": "mitgenommen",
    "mitgenommenere": "mitgenommen",
    "mitgenommenerem": "mitgenommen",
    "mitgenommeneren": "mitgenommen",
    "mitgenommenerer": "mitgenommen",
    "mitgenommeneres": "mitgenommen",
    "mitgenommenes": "mitgenommen",
    "mitgenommenste": "mitgenommen",
    "mitgenommenstem": "mitgenommen",
    "mitgenommensten": "mitgenommen",
    "mitgenommenster": "mitgenommen",
    "mitgenommenstes": "mitgenommen",
    "mitgerechnet": "mitrechnen",
    "mitgerechnete": "mitgerechnet",
    "mitgerechnetem": "mitgerechnet",
    "mitgerechneten": "mitgerechnet",
    "mitgerechneter": "mitgerechnet",
    "mitgerechnetes": "mitgerechnet",
    "mitgeredet": "mitreden",
    "mitgeredete": "mitgeredet",
    "mitgeredetem": "mitgeredet",
    "mitgeredeten": "mitgeredet",
    "mitgeredeter": "mitgeredet",
    "mitgeredetes": "mitgeredet",
    "mitgereist": "mitreisen",
    "mitgereiste": "mitgereist",
    "mitgereistem": "mitgereist",
    "mitgereisten": "mitgereist",
    "mitgereister": "mitgereist",
    "mitgereistes": "mitgereist",
    "mitgerissen": "mitreißen",
    "mitgerissene": "mitgerissen",
    "mitgerissenem": "mitgerissen",
    "mitgerissenen": "mitgerissen",
    "mitgerissener": "mitgerissen",
    "mitgerissenes": "mitgerissen",
    "mitgeschleift": "mitschleifen",
    "mitgeschleifte": "mitgeschleift",
    "mitgeschleiftem": "mitgeschleift",
    "mitgeschleiften": "mitgeschleift",
    "mitgeschleifter": "mitgeschleift",
    "mitgeschleiftes": "mitgeschleift",
    "mitgeschleppt": "mitschleppen",
    "mitgeschleppte": "mitgeschleppt",
    "mitgeschlepptem": "mitgeschleppt",
    "mitgeschleppten": "mitgeschleppt",
    "mitgeschleppter": "mitgeschleppt",
    "mitgeschlepptes": "mitgeschleppt",
    "mitgeschliffen": "mitschleifen",
    "mitgeschliffene": "mitgeschliffen",
    "mitgeschliffenem": "mitgeschliffen",
    "mitgeschliffenen": "mitgeschliffen",
    "mitgeschliffener": "mitgeschliffen",
    "mitgeschliffenes": "mitgeschliffen",
    "mitgeschnitten": "mitschneiden",
    "mitgeschnittene": "mitgeschnitten",
    "mitgeschnittenem": "mitgeschnitten",
    "mitgeschnittenen": "mitgeschnitten",
    "mitgeschnittener": "mitgeschnitten",
    "mitgeschnittenes": "mitgeschnitten",
    "mitgeschrieben": "mitschreiben",
    "mitgeschriebene": "mitgeschrieben",
    "mitgeschriebenem": "mitgeschrieben",
    "mitgeschriebenen": "mitgeschrieben",
    "mitgeschriebener": "mitgeschrieben",
    "mitgeschriebenere": "mitgeschrieben",
    "mitgeschriebenerem": "mitgeschrieben",
    "mitgeschriebeneren": "mitgeschrieben",
    "mitgeschriebenerer": "mitgeschrieben",
    "mitgeschriebeneres": "mitgeschrieben",
    "mitgeschriebenes": "mitgeschrieben",
    "mitgeschriebenste": "mitgeschrieben",
    "mitgeschriebenstem": "mitgeschrieben",
    "mitgeschriebensten": "mitgeschrieben",
    "mitgeschriebenster": "mitgeschrieben",
    "mitgeschriebenstes": "mitgeschrieben",
    "mitgeschwungen": "mitschwingen",
    "mitgeschwungene": "mitgeschwungen",
    "mitgeschwungenem": "mitgeschwungen",
    "mitgeschwungenen": "mitgeschwungen",
    "mitgeschwungener": "mitgeschwungen",
    "mitgeschwungenes": "mitgeschwungen",
    "mitgesoffen": "mitsaufen",
    "mitgesoffene": "mitgesoffen",
    "mitgesoffenem": "mitgesoffen",
    "mitgesoffenen": "mitgesoffen",
    "mitgesoffener": "mitgesoffen",
    "mitgesoffenes": "mitgesoffen",
    "mitgespielt": "mitspielen",
    "mitgespielte": "mitgespielt",
    "mitgespieltem": "mitgespielt",
    "mitgespielten": "mitgespielt",
    "mitgespielter": "mitgespielt",
    "mitgespieltes": "mitgespielt",
    "mitgesprochen": "mitsprechen",
    "mitgesprochene": "mitgesprochen",
    "mitgesprochenem": "mitgesprochen",
    "mitgesprochenen": "mitgesprochen",
    "mitgesprochener": "mitgesprochen",
    "mitgesprochenes": "mitgesprochen",
    "mitgestalte": "mitgestalten",
    "mitgestaltend": "mitgestalten",
    "mitgestaltende": "mitgestaltend",
    "mitgestaltendem": "mitgestaltend",
    "mitgestaltenden": "mitgestaltend",
    "mitgestaltender": "mitgestaltend",
    "mitgestaltendere": "mitgestaltend",
    "mitgestaltenderem": "mitgestaltend",
    "mitgestaltenderen": "mitgestaltend",
    "mitgestaltenderer": "mitgestaltend",
    "mitgestaltenderes": "mitgestaltend",
    "mitgestaltendes": "mitgestaltend",
    "mitgestaltendste": "mitgestaltend",
    "mitgestaltendstem": "mitgestaltend",
    "mitgestaltendsten": "mitgestaltend",
    "mitgestaltendster": "mitgestaltend",
    "mitgestaltendstes": "mitgestaltend",
    "mitgestaltest": "mitgestalten",
    "mitgestaltet": "mitgestalten",
    "mitgestaltete": "mitgestalten",
    "mitgestaltetem": "mitgestaltet",
    "mitgestalteten": "mitgestalten",
    "mitgestalteter": "mitgestaltet",
    "mitgestaltetes": "mitgestaltet",
    "mitgestaltetest": "mitgestalten",
    "mitgestaltetet": "mitgestalten",
    "mitgesungen": "mitsingen",
    "mitgesungene": "mitgesungen",
    "mitgesungenem": "mitgesungen",
    "mitgesungenen": "mitgesungen",
    "mitgesungener": "mitgesungen",
    "mitgesungenes": "mitgesungen",
    "mitgetanzt": "mittanzen",
    "mitgetanzte": "mitgetanzt",
    "mitgetanztem": "mitgetanzt",
    "mitgetanzten": "mitgetanzt",
    "mitgetanzter": "mitgetanzt",
    "mitgetanztes": "mitgetanzt",
    "mitgeteilt": "mitteilen",
    "mitgeteilte": "mitgeteilt",
    "mitgeteiltem": "mitgeteilt",
    "mitgeteilten": "mitgeteilt",
    "mitgeteilter": "mitgeteilt",
    "mitgeteiltes": "mitgeteilt",
    "mitgetragen": "mittragen",
    "mitgetragene": "mitgetragen",
    "mitgetragenem": "mitgetragen",
    "mitgetragenen": "mitgetragen",
    "mitgetragener": "mitgetragen",
    "mitgetragenes": "mitgetragen",
    "mitgetrunken": "mittrinken",
    "mitgetrunkene": "mitgetrunken",
    "mitgetrunkenem": "mitgetrunken",
    "mitgetrunkenen": "mitgetrunken",
    "mitgetrunkener": "mitgetrunken",
    "mitgetrunkenes": "mitgetrunken",
    "mitgewirkt": "mitwirken",
    "mitgewirkte": "mitgewirkt",
    "mitgewirktem": "mitgewirkt",
    "mitgewirkten": "mitgewirkt",
    "mitgewirkter": "mitgewirkt",
    "mitgewirktes": "mitgewirkt",
    "mitgezogen": "mitziehen",
    "mitgezogene": "mitgezogen",
    "mitgezogenem": "mitgezogen",
    "mitgezogenen": "mitgezogen",
    "mitgezogener": "mitgezogen",
    "mitgezogenes": "mitgezogen",
    "mitgezählt": "mitzählen",
    "mitgezählte": "mitgezählt",
    "mitgezähltem": "mitgezählt",
    "mitgezählten": "mitgezählt",
    "mitgezählter": "mitgezählt",
    "mitgezähltes": "mitgezählt",
    "mitgibst": "mitgeben",
    "mitgibt": "mitgeben",
    "mitgliederstarkem": "mitgliederstark",
    "mitgliederstarken": "mitgliederstark",
    "mitgliederstarker": "mitgliederstark",
    "mitgliederstarkes": "mitgliederstark",
    "mitgliederstärker": "mitgliederstark",
    "mitgliederstärkere": "mitgliederstark",
    "mitgliederstärkerem": "mitgliederstark",
    "mitgliederstärkeren": "mitgliederstark",
    "mitgliederstärkerer": "mitgliederstark",
    "mitgliederstärkeres": "mitgliederstark",
    "mitgliederstärkste": "mitgliederstark",
    "mitgliederstärkstem": "mitgliederstark",
    "mitgliederstärksten": "mitgliederstark",
    "mitgliederstärkster": "mitgliederstark",
    "mitgliederstärkstes": "mitgliederstark",
    "mitgäbe": "mitgeben",
    "mitgäben": "mitgeben",
    "mitgäbest": "mitgeben",
    "mitgäbet": "mitgeben",
    "mithalf": "mithelfen",
    "mithalfen": "mithelfen",
    "mithalfst": "mithelfen",
    "mithalft": "mithelfen",
    "mithalte": "mithalten",
    "mithaltend": "mithalten",
    "mithaltende": "mithaltend",
    "mithaltendem": "mithaltend",
    "mithaltenden": "mithaltend",
    "mithaltender": "mithaltend",
    "mithaltendes": "mithaltend",
    "mithaltest": "mithalten",
    "mithaltet": "mithalten",
    "mithelfe": "mithelfen",
    "mithelfend": "mithelfen",
    "mithelfende": "mithelfend",
    "mithelfendem": "mithelfend",
    "mithelfenden": "mithelfend",
    "mithelfender": "mithelfend",
    "mithelfendes": "mithelfend",
    "mithelfest": "mithelfen",
    "mithelfet": "mithelfen",
    "mithelft": "mithelfen",
    "mithielt": "mithalten",
    "mithielte": "mithalten",
    "mithielten": "mithalten",
    "mithieltest": "mithalten",
    "mithieltet": "mithalten",
    "mithilfst": "mithelfen",
    "mithilft": "mithelfen",
    "mithälfe": "mithelfen",
    "mithälfen": "mithelfen",
    "mithälfest": "mithelfen",
    "mithälfet": "mithelfen",
    "mithält": "mithalten",
    "mithältst": "mithalten",
    "mithöre": "mithören",
    "mithörend": "mithören",
    "mithörende": "mithörend",
    "mithörendem": "mithörend",
    "mithörenden": "mithörend",
    "mithörender": "mithörend",
    "mithörendes": "mithörend",
    "mithörest": "mithören",
    "mithöret": "mithören",
    "mithörst": "mithören",
    "mithört": "mithören",
    "mithörte": "mithören",
    "mithörten": "mithören",
    "mithörtest": "mithören",
    "mithörtet": "mithören",
    "mitißt": "mitessen",
    "mitkriege": "mitkriegen",
    "mitkriegend": "mitkriegen",
    "mitkriegende": "mitkriegend",
    "mitkriegendem": "mitkriegend",
    "mitkriegenden": "mitkriegend",
    "mitkriegender": "mitkriegend",
    "mitkriegendes": "mitkriegend",
    "mitkriegest": "mitkriegen",
    "mitkrieget": "mitkriegen",
    "mitkriegst": "mitkriegen",
    "mitkriegt": "mitkriegen",
    "mitkriegte": "mitkriegen",
    "mitkriegten": "mitkriegen",
    "mitkriegtest": "mitkriegen",
    "mitkriegtet": "mitkriegen",
    "mitkämpfe": "mitkämpfen",
    "mitkämpfend": "mitkämpfen",
    "mitkämpfende": "mitkämpfend",
    "mitkämpfendem": "mitkämpfend",
    "mitkämpfenden": "mitkämpfend",
    "mitkämpfender": "mitkämpfend",
    "mitkämpfendes": "mitkämpfend",
    "mitkämpfest": "mitkämpfen",
    "mitkämpfet": "mitkämpfen",
    "mitkämpfst": "mitkämpfen",
    "mitkämpft": "mitkämpfen",
    "mitkämpfte": "mitkämpfen",
    "mitkämpften": "mitkämpfen",
    "mitkämpftest": "mitkämpfen",
    "mitkämpftet": "mitkämpfen",
    "mitlasse": "mitlassen",
    "mitlassend": "mitlassen",
    "mitlassende": "mitlassend",
    "mitlassendem": "mitlassend",
    "mitlassenden": "mitlassend",
    "mitlassender": "mitlassend",
    "mitlassendes": "mitlassend",
    "mitlassest": "mitlassen",
    "mitlasset": "mitlassen",
    "mitlaufe": "mitlaufen",
    "mitlaufend": "mitlaufen",
    "mitlaufende": "mitlaufend",
    "mitlaufendem": "mitlaufend",
    "mitlaufenden": "mitlaufend",
    "mitlaufender": "mitlaufend",
    "mitlaufendes": "mitlaufend",
    "mitlaufest": "mitlaufen",
    "mitlaufet": "mitlaufen",
    "mitlauft": "mitlaufen",
    "mitlaßt": "mitlassen",
    "mitleide": "mitleiden",
    "mitleidend": "mitleiden",
    "mitleidende": "mitleidend",
    "mitleidendem": "mitleidend",
    "mitleidenden": "mitleidend",
    "mitleidender": "mitleidend",
    "mitleidendes": "mitleidend",
    "mitleidest": "mitleiden",
    "mitleidet": "mitleiden",
    "mitleidige": "mitleidig",
    "mitleidigem": "mitleidig",
    "mitleidigen": "mitleidig",
    "mitleidiger": "mitleidig",
    "mitleidigere": "mitleidig",
    "mitleidigerem": "mitleidig",
    "mitleidigeren": "mitleidig",
    "mitleidigerer": "mitleidig",
    "mitleidigeres": "mitleidig",
    "mitleidiges": "mitleidig",
    "mitleidigste": "mitleidig",
    "mitleidigstem": "mitleidig",
    "mitleidigsten": "mitleidig",
    "mitleidigster": "mitleidig",
    "mitleidigstes": "mitleidig",
    "mitlerne": "mitlernen",
    "mitlernend": "mitlernen",
    "mitlernende": "mitlernend",
    "mitlernendem": "mitlernend",
    "mitlernenden": "mitlernend",
    "mitlernender": "mitlernend",
    "mitlernendes": "mitlernend",
    "mitlernest": "mitlernen",
    "mitlernet": "mitlernen",
    "mitlernst": "mitlernen",
    "mitlernt": "mitlernen",
    "mitlernte": "mitlernen",
    "mitlernten": "mitlernen",
    "mitlerntest": "mitlernen",
    "mitlerntet": "mitlernen",
    "mitlief": "mitlaufen",
    "mitliefe": "mitlaufen",
    "mitliefen": "mitlaufen",
    "mitliefest": "mitlaufen",
    "mitliefet": "mitlaufen",
    "mitliefst": "mitlaufen",
    "mitlieft": "mitlaufen",
    "mitließ": "mitlassen",
    "mitließe": "mitlassen",
    "mitließen": "mitlassen",
    "mitließest": "mitlassen",
    "mitließet": "mitlassen",
    "mitließt": "mitlassen",
    "mitlitt": "mitleiden",
    "mitlitte": "mitleiden",
    "mitlitten": "mitleiden",
    "mitlittest": "mitleiden",
    "mitlittet": "mitleiden",
    "mitläufst": "mitlaufen",
    "mitläuft": "mitlaufen",
    "mitläßt": "mitlassen",
    "mitmache": "mitmachen",
    "mitmachend": "mitmachen",
    "mitmachende": "mitmachend",
    "mitmachendem": "mitmachend",
    "mitmachenden": "mitmachend",
    "mitmachender": "mitmachend",
    "mitmachendes": "mitmachend",
    "mitmachest": "mitmachen",
    "mitmachet": "mitmachen",
    "mitmachst": "mitmachen",
    "mitmacht": "mitmachen",
    "mitmachte": "mitmachen",
    "mitmachten": "mitmachen",
    "mitmachtest": "mitmachen",
    "mitmachtet": "mitmachen",
    "mitmische": "mitmischen",
    "mitmischend": "mitmischen",
    "mitmischende": "mitmischend",
    "mitmischendem": "mitmischend",
    "mitmischenden": "mitmischend",
    "mitmischender": "mitmischend",
    "mitmischendes": "mitmischend",
    "mitmischest": "mitmischen",
    "mitmischet": "mitmischen",
    "mitmischst": "mitmischen",
    "mitmischt": "mitmischen",
    "mitmischte": "mitmischen",
    "mitmischten": "mitmischen",
    "mitmischtest": "mitmischen",
    "mitmischtet": "mitmischen",
    "mitnahm": "mitnehmen",
    "mitnahmen": "mitnehmen",
    "mitnahmst": "mitnehmen",
    "mitnahmt": "mitnehmen",
    "mitnehme": "mitnehmen",
    "mitnehmend": "mitnehmen",
    "mitnehmende": "mitnehmend",
    "mitnehmendem": "mitnehmend",
    "mitnehmenden": "mitnehmend",
    "mitnehmender": "mitnehmend",
    "mitnehmendes": "mitnehmend",
    "mitnehmest": "mitnehmen",
    "mitnehmet": "mitnehmen",
    "mitnehmt": "mitnehmen",
    "mitnimmst": "mitnehmen",
    "mitnimmt": "mitnehmen",
    "mitnähme": "mitnehmen",
    "mitnähmen": "mitnehmen",
    "mitnähmest": "mitnehmen",
    "mitnähmet": "mitnehmen",
    "mitrechne": "mitrechnen",
    "mitrechnend": "mitrechnen",
    "mitrechnende": "mitrechnend",
    "mitrechnendem": "mitrechnend",
    "mitrechnenden": "mitrechnend",
    "mitrechnender": "mitrechnend",
    "mitrechnendes": "mitrechnend",
    "mitrechnest": "mitrechnen",
    "mitrechnet": "mitrechnen",
    "mitrechnete": "mitrechnen",
    "mitrechneten": "mitrechnen",
    "mitrechnetest": "mitrechnen",
    "mitrechnetet": "mitrechnen",
    "mitrede": "mitreden",
    "mitredend": "mitreden",
    "mitredende": "mitredend",
    "mitredendem": "mitredend",
    "mitredenden": "mitredend",
    "mitredender": "mitredend",
    "mitredendes": "mitredend",
    "mitredest": "mitreden",
    "mitredet": "mitreden",
    "mitredete": "mitreden",
    "mitredeten": "mitreden",
    "mitredetest": "mitreden",
    "mitredetet": "mitreden",
    "mitreise": "mitreisen",
    "mitreisend": "mitreisen",
    "mitreisende": "mitreisend",
    "mitreisendem": "mitreisend",
    "mitreisenden": "mitreisend",
    "mitreisender": "mitreisend",
    "mitreisendes": "mitreisend",
    "mitreisest": "mitreisen",
    "mitreiset": "mitreisen",
    "mitreist": "mitreisen",
    "mitreiste": "mitreisen",
    "mitreisten": "mitreisen",
    "mitreistest": "mitreisen",
    "mitreistet": "mitreisen",
    "mitreiße": "mitreißen",
    "mitreißend": "mitreißen",
    "mitreißende": "mitreißend",
    "mitreißendem": "mitreißend",
    "mitreißenden": "mitreißend",
    "mitreißender": "mitreißend",
    "mitreißendere": "mitreißend",
    "mitreißenderem": "mitreißend",
    "mitreißenderen": "mitreißend",
    "mitreißenderer": "mitreißend",
    "mitreißenderes": "mitreißend",
    "mitreißendes": "mitreißend",
    "mitreißendste": "mitreißend",
    "mitreißendstem": "mitreißend",
    "mitreißendsten": "mitreißend",
    "mitreißendster": "mitreißend",
    "mitreißendstes": "mitreißend",
    "mitreißest": "mitreißen",
    "mitreißet": "mitreißen",
    "mitreißt": "mitreißen",
    "mitrisse": "mitreißen",
    "mitrissen": "mitreißen",
    "mitrissest": "mitreißen",
    "mitrisset": "mitreißen",
    "mitriß": "mitreißen",
    "mitrißt": "mitreißen",
    "mitsang": "mitsingen",
    "mitsangen": "mitsingen",
    "mitsangst": "mitsingen",
    "mitsangt": "mitsingen",
    "mitsaufe": "mitsaufen",
    "mitsaufend": "mitsaufen",
    "mitsaufende": "mitsaufend",
    "mitsaufendem": "mitsaufend",
    "mitsaufenden": "mitsaufend",
    "mitsaufender": "mitsaufend",
    "mitsaufendes": "mitsaufend",
    "mitsaufest": "mitsaufen",
    "mitsaufet": "mitsaufen",
    "mitsauft": "mitsaufen",
    "mitschleife": "mitschleifen",
    "mitschleifend": "mitschleifen",
    "mitschleifende": "mitschleifend",
    "mitschleifendem": "mitschleifend",
    "mitschleifenden": "mitschleifend",
    "mitschleifender": "mitschleifend",
    "mitschleifendes": "mitschleifend",
    "mitschleifest": "mitschleifen",
    "mitschleifet": "mitschleifen",
    "mitschleifst": "mitschleifen",
    "mitschleift": "mitschleifen",
    "mitschleifte": "mitschleifen",
    "mitschleiften": "mitschleifen",
    "mitschleiftest": "mitschleifen",
    "mitschleiftet": "mitschleifen",
    "mitschleppe": "mitschleppen",
    "mitschleppend": "mitschleppen",
    "mitschleppende": "mitschleppend",
    "mitschleppendem": "mitschleppend",
    "mitschleppenden": "mitschleppend",
    "mitschleppender": "mitschleppend",
    "mitschleppendes": "mitschleppend",
    "mitschleppest": "mitschleppen",
    "mitschleppet": "mitschleppen",
    "mitschleppst": "mitschleppen",
    "mitschleppt": "mitschleppen",
    "mitschleppte": "mitschleppen",
    "mitschleppten": "mitschleppen",
    "mitschlepptest": "mitschleppen",
    "mitschlepptet": "mitschleppen",
    "mitschliff": "mitschleifen",
    "mitschliffe": "mitschleifen",
    "mitschliffen": "mitschleifen",
    "mitschliffest": "mitschleifen",
    "mitschliffet": "mitschleifen",
    "mitschliffst": "mitschleifen",
    "mitschlifft": "mitschleifen",
    "mitschneide": "mitschneiden",
    "mitschneidend": "mitschneiden",
    "mitschneidende": "mitschneidend",
    "mitschneidendem": "mitschneidend",
    "mitschneidenden": "mitschneidend",
    "mitschneidender": "mitschneidend",
    "mitschneidendes": "mitschneidend",
    "mitschneidest": "mitschneiden",
    "mitschneidet": "mitschneiden",
    "mitschnitt": "mitschneiden",
    "mitschnittest": "mitschneiden",
    "mitschnittet": "mitschneiden",
    "mitschreibe": "mitschreiben",
    "mitschreibend": "mitschreiben",
    "mitschreibende": "mitschreibend",
    "mitschreibendem": "mitschreibend",
    "mitschreibenden": "mitschreibend",
    "mitschreibender": "mitschreibend",
    "mitschreibendes": "mitschreibend",
    "mitschreibest": "mitschreiben",
    "mitschreibet": "mitschreiben",
    "mitschreibst": "mitschreiben",
    "mitschreibt": "mitschreiben",
    "mitschrieb": "mitschreiben",
    "mitschriebe": "mitschreiben",
    "mitschrieben": "mitschreiben",
    "mitschriebest": "mitschreiben",
    "mitschriebet": "mitschreiben",
    "mitschriebst": "mitschreiben",
    "mitschriebt": "mitschreiben",
    "mitschwang": "mitschwingen",
    "mitschwangen": "mitschwingen",
    "mitschwangst": "mitschwingen",
    "mitschwangt": "mitschwingen",
    "mitschwinge": "mitschwingen",
    "mitschwingend": "mitschwingen",
    "mitschwingende": "mitschwingend",
    "mitschwingendem": "mitschwingend",
    "mitschwingenden": "mitschwingend",
    "mitschwingender": "mitschwingend",
    "mitschwingendes": "mitschwingend",
    "mitschwingest": "mitschwingen",
    "mitschwinget": "mitschwingen",
    "mitschwingst": "mitschwingen",
    "mitschwingt": "mitschwingen",
    "mitschwänge": "mitschwingen",
    "mitschwängen": "mitschwingen",
    "mitschwängest": "mitschwingen",
    "mitschwänget": "mitschwingen",
    "mitsinge": "mitsingen",
    "mitsingend": "mitsingen",
    "mitsingende": "mitsingend",
    "mitsingendem": "mitsingend",
    "mitsingenden": "mitsingend",
    "mitsingender": "mitsingend",
    "mitsingendes": "mitsingend",
    "mitsingest": "mitsingen",
    "mitsinget": "mitsingen",
    "mitsingst": "mitsingen",
    "mitsingt": "mitsingen",
    "mitsoff": "mitsaufen",
    "mitsoffen": "mitsaufen",
    "mitsoffst": "mitsaufen",
    "mitsofft": "mitsaufen",
    "mitspiele": "mitspielen",
    "mitspielend": "mitspielen",
    "mitspielende": "mitspielend",
    "mitspielendem": "mitspielend",
    "mitspielenden": "mitspielend",
    "mitspielender": "mitspielend",
    "mitspielendes": "mitspielend",
    "mitspielest": "mitspielen",
    "mitspielet": "mitspielen",
    "mitspielst": "mitspielen",
    "mitspielt": "mitspielen",
    "mitspielte": "mitspielen",
    "mitspielten": "mitspielen",
    "mitspieltest": "mitspielen",
    "mitspieltet": "mitspielen",
    "mitsprach": "mitsprechen",
    "mitsprachen": "mitsprechen",
    "mitsprachst": "mitsprechen",
    "mitspracht": "mitsprechen",
    "mitspreche": "mitsprechen",
    "mitsprechend": "mitsprechen",
    "mitsprechende": "mitsprechend",
    "mitsprechendem": "mitsprechend",
    "mitsprechenden": "mitsprechend",
    "mitsprechender": "mitsprechend",
    "mitsprechendes": "mitsprechend",
    "mitsprechest": "mitsprechen",
    "mitsprechet": "mitsprechen",
    "mitsprecht": "mitsprechen",
    "mitsprichst": "mitsprechen",
    "mitspricht": "mitsprechen",
    "mitspräche": "mitsprechen",
    "mitsprächen": "mitsprechen",
    "mitsprächest": "mitsprechen",
    "mitsprächet": "mitsprechen",
    "mitsänge": "mitsingen",
    "mitsängen": "mitsingen",
    "mitsängest": "mitsingen",
    "mitsänget": "mitsingen",
    "mitsäufst": "mitsaufen",
    "mitsäuft": "mitsaufen",
    "mitsöffe": "mitsaufen",
    "mitsöffen": "mitsaufen",
    "mitsöffest": "mitsaufen",
    "mitsöffet": "mitsaufen",
    "mittanze": "mittanzen",
    "mittanzend": "mittanzen",
    "mittanzende": "mittanzend",
    "mittanzendem": "mittanzend",
    "mittanzenden": "mittanzend",
    "mittanzender": "mittanzend",
    "mittanzendes": "mittanzend",
    "mittanzest": "mittanzen",
    "mittanzet": "mittanzen",
    "mittanzt": "mittanzen",
    "mittanzte": "mittanzen",
    "mittanzten": "mittanzen",
    "mittanztest": "mittanzen",
    "mittanztet": "mittanzen",
    "mitteile": "mitteilen",
    "mitteilend": "mitteilen",
    "mitteilende": "mitteilend",
    "mitteilendem": "mitteilend",
    "mitteilenden": "mitteilend",
    "mitteilender": "mitteilend",
    "mitteilendere": "mitteilend",
    "mitteilenderem": "mitteilend",
    "mitteilenderen": "mitteilend",
    "mitteilenderer": "mitteilend",
    "mitteilenderes": "mitteilend",
    "mitteilendes": "mitteilend",
    "mitteilendste": "mitteilend",
    "mitteilendstem": "mitteilend",
    "mitteilendsten": "mitteilend",
    "mitteilendster": "mitteilend",
    "mitteilendstes": "mitteilend",
    "mitteilest": "mitteilen",
    "mitteilet": "mitteilen",
    "mitteilsame": "mitteilsam",
    "mitteilsamem": "mitteilsam",
    "mitteilsamen": "mitteilsam",
    "mitteilsamer": "mitteilsam",
    "mitteilsamere": "mitteilsam",
    "mitteilsamerem": "mitteilsam",
    "mitteilsameren": "mitteilsam",
    "mitteilsamerer": "mitteilsam",
    "mitteilsameres": "mitteilsam",
    "mitteilsames": "mitteilsam",
    "mitteilsamste": "mitteilsam",
    "mitteilsamstem": "mitteilsam",
    "mitteilsamsten": "mitteilsam",
    "mitteilsamster": "mitteilsam",
    "mitteilsamstes": "mitteilsam",
    "mitteilst": "mitteilen",
    "mitteilt": "mitteilen",
    "mitteilte": "mitteilen",
    "mitteilten": "mitteilen",
    "mitteiltest": "mitteilen",
    "mitteiltet": "mitteilen",
    "mittelalterliche": "mittelalterlich",
    "mittelalterlichem": "mittelalterlich",
    "mittelalterlichen": "mittelalterlich",
    "mittelalterlicher": "mittelalterlich",
    "mittelalterlichere": "mittelalterlich",
    "mittelalterlicherem": "mittelalterlich",
    "mittelalterlicheren": "mittelalterlich",
    "mittelalterlicherer": "mittelalterlich",
    "mittelalterlicheres": "mittelalterlich",
    "mittelalterliches": "mittelalterlich",
    "mittelalterlichste": "mittelalterlich",
    "mittelalterlichstem": "mittelalterlich",
    "mittelalterlichsten": "mittelalterlich",
    "mittelalterlichster": "mittelalterlich",
    "mittelalterlichstes": "mittelalterlich",
    "mittelbarem": "mittelbar",
    "mittelbaren": "mittelbar",
    "mittelbarer": "mittelbar",
    "mittelbares": "mittelbar",
    "mittele": "mitteln",
    "mitteleuropäische": "mitteleuropäisch",
    "mitteleuropäischem": "mitteleuropäisch",
    "mitteleuropäischen": "mitteleuropäisch",
    "mitteleuropäischer": "mitteleuropäisch",
    "mitteleuropäisches": "mitteleuropäisch",
    "mittelfristige": "mittelfristig",
    "mittelfristigem": "mittelfristig",
    "mittelfristigen": "mittelfristig",
    "mittelfristiger": "mittelfristig",
    "mittelfristiges": "mittelfristig",
    "mittelgroßem": "mittelgroß",
    "mittelgroßen": "mittelgroß",
    "mittelgroßer": "mittelgroß",
    "mittelgroßes": "mittelgroß",
    "mittelhochdeutsche": "mittelhochdeutsch",
    "mittelhochdeutschem": "mittelhochdeutsch",
    "mittelhochdeutschen": "mittelhochdeutsch",
    "mittelhochdeutscher": "mittelhochdeutsch",
    "mittelhochdeutsches": "mittelhochdeutsch",
    "mittellose": "mittellos",
    "mittellosem": "mittellos",
    "mittellosen": "mittellos",
    "mittelloser": "mittellos",
    "mittellosere": "mittellos",
    "mittelloserem": "mittellos",
    "mittelloseren": "mittellos",
    "mittelloserer": "mittellos",
    "mittelloseres": "mittellos",
    "mittelloses": "mittellos",
    "mittelloseste": "mittellos",
    "mittellosestem": "mittellos",
    "mittellosesten": "mittellos",
    "mittellosester": "mittellos",
    "mittellosestes": "mittellos",
    "mittelmäßige": "mittelmäßig",
    "mittelmäßigem": "mittelmäßig",
    "mittelmäßigen": "mittelmäßig",
    "mittelmäßiger": "mittelmäßig",
    "mittelmäßigere": "mittelmäßig",
    "mittelmäßigerem": "mittelmäßig",
    "mittelmäßigeren": "mittelmäßig",
    "mittelmäßigerer": "mittelmäßig",
    "mittelmäßigeres": "mittelmäßig",
    "mittelmäßiges": "mittelmäßig",
    "mittelmäßigste": "mittelmäßig",
    "mittelmäßigstem": "mittelmäßig",
    "mittelmäßigsten": "mittelmäßig",
    "mittelmäßigster": "mittelmäßig",
    "mittelmäßigstes": "mittelmäßig",
    "mittelnd": "mitteln",
    "mittelnde": "mittelnd",
    "mittelndem": "mittelnd",
    "mittelnden": "mittelnd",
    "mittelnder": "mittelnd",
    "mittelndes": "mittelnd",
    "mittelprächtigem": "mittelprächtig",
    "mittelprächtigen": "mittelprächtig",
    "mittelprächtiger": "mittelprächtig",
    "mittelprächtiges": "mittelprächtig",
    "mittelst": "mitteln",
    "mittelständige": "mittelständig",
    "mittelständigem": "mittelständig",
    "mittelständigen": "mittelständig",
    "mittelständiger": "mittelständig",
    "mittelständiges": "mittelständig",
    "mittelständische": "mittelständisch",
    "mittelständischem": "mittelständisch",
    "mittelständischen": "mittelständisch",
    "mittelständischer": "mittelständisch",
    "mittelständisches": "mittelständisch",
    "mittelt": "mitteln",
    "mittelte": "mitteln",
    "mittelten": "mitteln",
    "mitteltest": "mitteln",
    "mitteltet": "mitteln",
    "mittigem": "mittig",
    "mittigen": "mittig",
    "mittiger": "mittig",
    "mittigere": "mittig",
    "mittigerem": "mittig",
    "mittigeren": "mittig",
    "mittigerer": "mittig",
    "mittigeres": "mittig",
    "mittiges": "mittig",
    "mittigste": "mittig",
    "mittigstem": "mittig",
    "mittigsten": "mittig",
    "mittigster": "mittig",
    "mittigstes": "mittig",
    "mittle": "mittel",
    "mittlem": "mittel",
    "mittlen": "mittel",
    "mittler": "mittel",
    "mittlere": "mittler",
    "mittlerem": "mittler",
    "mittleren": "mittler",
    "mittlerer": "mittler",
    "mittleres": "mittler",
    "mittles": "mittel",
    "mittrage": "mittragen",
    "mittragend": "mittragen",
    "mittragende": "mittragend",
    "mittragendem": "mittragend",
    "mittragenden": "mittragend",
    "mittragender": "mittragend",
    "mittragendes": "mittragend",
    "mittragest": "mittragen",
    "mittraget": "mittragen",
    "mittragt": "mittragen",
    "mittrank": "mittrinken",
    "mittranken": "mittrinken",
    "mittrankst": "mittrinken",
    "mittrankt": "mittrinken",
    "mittrinke": "mittrinken",
    "mittrinkend": "mittrinken",
    "mittrinkende": "mittrinkend",
    "mittrinkendem": "mittrinkend",
    "mittrinkenden": "mittrinkend",
    "mittrinkender": "mittrinkend",
    "mittrinkendes": "mittrinkend",
    "mittrinkest": "mittrinken",
    "mittrinket": "mittrinken",
    "mittrinkst": "mittrinken",
    "mittrinkt": "mittrinken",
    "mittrug": "mittragen",
    "mittrugen": "mittragen",
    "mittrugst": "mittragen",
    "mittrugt": "mittragen",
    "mitträgst": "mittragen",
    "mitträgt": "mittragen",
    "mittränke": "mittrinken",
    "mittränken": "mittrinken",
    "mittränkest": "mittrinken",
    "mittränket": "mittrinken",
    "mittrüge": "mittragen",
    "mittrügen": "mittragen",
    "mittrügest": "mittragen",
    "mittrüget": "mittragen",
    "mitverantwortlichem": "mitverantwortlich",
    "mitverantwortlichen": "mitverantwortlich",
    "mitverantwortlicher": "mitverantwortlich",
    "mitverantwortliches": "mitverantwortlich",
    "mitwirke": "mitwirken",
    "mitwirkend": "mitwirken",
    "mitwirkende": "mitwirkend",
    "mitwirkendem": "mitwirkend",
    "mitwirkenden": "mitwirkend",
    "mitwirkender": "mitwirkend",
    "mitwirkendes": "mitwirkend",
    "mitwirkest": "mitwirken",
    "mitwirket": "mitwirken",
    "mitwirkst": "mitwirken",
    "mitwirkt": "mitwirken",
    "mitwirkte": "mitwirken",
    "mitwirkten": "mitwirken",
    "mitwirktest": "mitwirken",
    "mitwirktet": "mitwirken",
    "mitziehe": "mitziehen",
    "mitziehend": "mitziehen",
    "mitziehende": "mitziehend",
    "mitziehendem": "mitziehend",
    "mitziehenden": "mitziehend",
    "mitziehender": "mitziehend",
    "mitziehendes": "mitziehend",
    "mitziehest": "mitziehen",
    "mitziehet": "mitziehen",
    "mitziehst": "mitziehen",
    "mitzieht": "mitziehen",
    "mitzog": "mitziehen",
    "mitzogen": "mitziehen",
    "mitzogst": "mitziehen",
    "mitzogt": "mitziehen",
    "mitzuarbeiten": "mitarbeiten",
    "mitzubekommen": "mitbekommen",
    "mitzubenutzen": "mitbenutzen",
    "mitzubestimmen": "mitbestimmen",
    "mitzubewerben": "mitbewerben",
    "mitzubringen": "mitbringen",
    "mitzuempfinden": "mitempfinden",
    "mitzuerleben": "miterleben",
    "mitzuessen": "mitessen",
    "mitzufahren": "mitfahren",
    "mitzufliegen": "mitfliegen",
    "mitzufreuen": "mitfreuen",
    "mitzufühlen": "mitfühlen",
    "mitzugeben": "mitgeben",
    "mitzugestalten": "mitgestalten",
    "mitzuhalten": "mithalten",
    "mitzuhelfen": "mithelfen",
    "mitzuhören": "mithören",
    "mitzukriegen": "mitkriegen",
    "mitzukämpfen": "mitkämpfen",
    "mitzulassen": "mitlassen",
    "mitzulaufen": "mitlaufen",
    "mitzuleiden": "mitleiden",
    "mitzulernen": "mitlernen",
    "mitzumachen": "mitmachen",
    "mitzumischen": "mitmischen",
    "mitzunehmen": "mitnehmen",
    "mitzurechnen": "mitrechnen",
    "mitzureden": "mitreden",
    "mitzureisen": "mitreisen",
    "mitzureißen": "mitreißen",
    "mitzusaufen": "mitsaufen",
    "mitzuschleifen": "mitschleifen",
    "mitzuschleppen": "mitschleppen",
    "mitzuschneiden": "mitschneiden",
    "mitzuschreiben": "mitschreiben",
    "mitzuschwingen": "mitschwingen",
    "mitzusingen": "mitsingen",
    "mitzuspielen": "mitspielen",
    "mitzusprechen": "mitsprechen",
    "mitzutanzen": "mittanzen",
    "mitzuteilen": "mitteilen",
    "mitzutragen": "mittragen",
    "mitzutrinken": "mittrinken",
    "mitzuwirken": "mitwirken",
    "mitzuziehen": "mitziehen",
    "mitzuzählen": "mitzählen",
    "mitzähle": "mitzählen",
    "mitzählend": "mitzählen",
    "mitzählende": "mitzählend",
    "mitzählendem": "mitzählend",
    "mitzählenden": "mitzählend",
    "mitzählender": "mitzählend",
    "mitzählendere": "mitzählend",
    "mitzählenderem": "mitzählend",
    "mitzählenderen": "mitzählend",
    "mitzählenderer": "mitzählend",
    "mitzählenderes": "mitzählend",
    "mitzählendes": "mitzählend",
    "mitzählendste": "mitzählend",
    "mitzählendstem": "mitzählend",
    "mitzählendsten": "mitzählend",
    "mitzählendster": "mitzählend",
    "mitzählendstes": "mitzählend",
    "mitzählest": "mitzählen",
    "mitzählet": "mitzählen",
    "mitzählst": "mitzählen",
    "mitzählt": "mitzählen",
    "mitzählte": "mitzählen",
    "mitzählten": "mitzählen",
    "mitzähltest": "mitzählen",
    "mitzähltet": "mitzählen",
    "mitzöge": "mitziehen",
    "mitzögen": "mitziehen",
    "mitzögest": "mitziehen",
    "mitzöget": "mitziehen",
    "mitäße": "mitessen",
    "mitäßen": "mitessen",
    "mitäßest": "mitessen",
    "mitäßet": "mitessen",
    "mixe": "mixen",
    "mixend": "mixen",
    "mixende": "mixend",
    "mixendem": "mixend",
    "mixenden": "mixend",
    "mixender": "mixend",
    "mixendes": "mixend",
    "mixest": "mixen",
    "mixet": "mixen",
    "mixt": "mixen",
    "mixte": "mixen",
    "mixten": "mixen",
    "mixtest": "mixen",
    "mixtet": "mixen",
    "miß": "missen",
    "mißachte": "mißachten",
    "mißachtend": "mißachten",
    "mißachtende": "mißachtend",
    "mißachtendem": "mißachtend",
    "mißachtenden": "mißachtend",
    "mißachtender": "mißachtend",
    "mißachtendere": "mißachtend",
    "mißachtenderem": "mißachtend",
    "mißachtenderen": "mißachtend",
    "mißachtenderer": "mißachtend",
    "mißachtenderes": "mißachtend",
    "mißachtendes": "mißachtend",
    "mißachtendste": "mißachtend",
    "mißachtendstem": "mißachtend",
    "mißachtendsten": "mißachtend",
    "mißachtendster": "mißachtend",
    "mißachtendstes": "mißachtend",
    "mißachtest": "mißachten",
    "mißachtet": "mißachten",
    "mißachtete": "mißachten",
    "mißachtetem": "mißachtet",
    "mißachteten": "mißachten",
    "mißachteter": "mißachtet",
    "mißachtetere": "mißachtet",
    "mißachteterem": "mißachtet",
    "mißachteteren": "mißachtet",
    "mißachteterer": "mißachtet",
    "mißachteteres": "mißachtet",
    "mißachtetes": "mißachtet",
    "mißachtetest": "mißachten",
    "mißachteteste": "mißachtet",
    "mißachtetestem": "mißachtet",
    "mißachtetesten": "mißachtet",
    "mißachtetester": "mißachtet",
    "mißachtetestes": "mißachtet",
    "mißachtetet": "mißachten",
    "mißbilde": "mißbilden",
    "mißbildend": "mißbilden",
    "mißbildende": "mißbildend",
    "mißbildendem": "mißbildend",
    "mißbildenden": "mißbildend",
    "mißbildender": "mißbildend",
    "mißbildendere": "mißbildend",
    "mißbildenderem": "mißbildend",
    "mißbildenderen": "mißbildend",
    "mißbildenderer": "mißbildend",
    "mißbildenderes": "mißbildend",
    "mißbildendes": "mißbildend",
    "mißbildendste": "mißbildend",
    "mißbildendstem": "mißbildend",
    "mißbildendsten": "mißbildend",
    "mißbildendster": "mißbildend",
    "mißbildendstes": "mißbildend",
    "mißbildest": "mißbilden",
    "mißbildet": "mißbilden",
    "mißbildete": "mißbilden",
    "mißbildetem": "mißbildet",
    "mißbildeten": "mißbilden",
    "mißbildeter": "mißbildet",
    "mißbildetere": "mißbildet",
    "mißbildeterem": "mißbildet",
    "mißbildeteren": "mißbildet",
    "mißbildeterer": "mißbildet",
    "mißbildeteres": "mißbildet",
    "mißbildetes": "mißbildet",
    "mißbildetest": "mißbilden",
    "mißbildeteste": "mißbildet",
    "mißbildetestem": "mißbildet",
    "mißbildetesten": "mißbildet",
    "mißbildetester": "mißbildet",
    "mißbildetestes": "mißbildet",
    "mißbildetet": "mißbilden",
    "mißbillige": "mißbilligen",
    "mißbilligend": "mißbilligen",
    "mißbilligende": "mißbilligend",
    "mißbilligendem": "mißbilligend",
    "mißbilligenden": "mißbilligend",
    "mißbilligender": "mißbilligend",
    "mißbilligendes": "mißbilligend",
    "mißbilligest": "mißbilligen",
    "mißbilliget": "mißbilligen",
    "mißbilligst": "mißbilligen",
    "mißbilligt": "mißbilligen",
    "mißbilligte": "mißbilligen",
    "mißbilligtem": "mißbilligt",
    "mißbilligten": "mißbilligen",
    "mißbilligter": "mißbilligt",
    "mißbilligtes": "mißbilligt",
    "mißbilligtest": "mißbilligen",
    "mißbilligtet": "mißbilligen",
    "mißbrauchend": "mißbrauchen",
    "mißbrauchende": "mißbrauchend",
    "mißbrauchendem": "mißbrauchend",
    "mißbrauchenden": "mißbrauchend",
    "mißbrauchender": "mißbrauchend",
    "mißbrauchendes": "mißbrauchend",
    "mißbrauchest": "mißbrauchen",
    "mißbrauchet": "mißbrauchen",
    "mißbrauchst": "mißbrauchen",
    "mißbraucht": "mißbrauchen",
    "mißbrauchte": "mißbrauchen",
    "mißbrauchtem": "mißbraucht",
    "mißbrauchten": "mißbrauchen",
    "mißbrauchter": "mißbraucht",
    "mißbrauchtere": "mißbraucht",
    "mißbrauchterem": "mißbraucht",
    "mißbrauchteren": "mißbraucht",
    "mißbrauchterer": "mißbraucht",
    "mißbrauchteres": "mißbraucht",
    "mißbrauchtes": "mißbraucht",
    "mißbrauchtest": "mißbrauchen",
    "mißbrauchteste": "mißbraucht",
    "mißbrauchtestem": "mißbraucht",
    "mißbrauchtesten": "mißbraucht",
    "mißbrauchtester": "mißbraucht",
    "mißbrauchtestes": "mißbraucht",
    "mißbrauchtet": "mißbrauchen",
    "mißbräuchliche": "mißbräuchlich",
    "mißbräuchlichem": "mißbräuchlich",
    "mißbräuchlichen": "mißbräuchlich",
    "mißbräuchlicher": "mißbräuchlich",
    "mißbräuchliches": "mißbräuchlich",
    "mißfalle": "mißfallen",
    "mißfallend": "mißfallen",
    "mißfallende": "mißfallend",
    "mißfallendem": "mißfallend",
    "mißfallenden": "mißfallend",
    "mißfallender": "mißfallend",
    "mißfallendes": "mißfallend",
    "mißfallene": "mißfallen",
    "mißfallenem": "mißfallen",
    "mißfallenen": "mißfallen",
    "mißfallener": "mißfallen",
    "mißfallenere": "mißfallen",
    "mißfallenerem": "mißfallen",
    "mißfalleneren": "mißfallen",
    "mißfallenerer": "mißfallen",
    "mißfalleneres": "mißfallen",
    "mißfallenes": "mißfallen",
    "mißfallenstem": "mißfallen",
    "mißfallensten": "mißfallen",
    "mißfallenster": "mißfallen",
    "mißfallenstes": "mißfallen",
    "mißfallest": "mißfallen",
    "mißfallet": "mißfallen",
    "mißfallt": "mißfallen",
    "mißfiel": "mißfallen",
    "mißfiele": "mißfallen",
    "mißfielen": "mißfallen",
    "mißfielest": "mißfallen",
    "mißfielet": "mißfallen",
    "mißfielst": "mißfallen",
    "mißfielt": "mißfallen",
    "mißfällst": "mißfallen",
    "mißfällt": "mißfallen",
    "mißgebildetem": "mißgebildet",
    "mißgebildeten": "mißgebildet",
    "mißgebildeter": "mißgebildet",
    "mißgebildetes": "mißgebildet",
    "mißgefallen": "mißfallen",
    "mißgestimmtem": "mißgestimmt",
    "mißgestimmten": "mißgestimmt",
    "mißgestimmter": "mißgestimmt",
    "mißgestimmtere": "mißgestimmt",
    "mißgestimmterem": "mißgestimmt",
    "mißgestimmteren": "mißgestimmt",
    "mißgestimmterer": "mißgestimmt",
    "mißgestimmteres": "mißgestimmt",
    "mißgestimmtes": "mißgestimmt",
    "mißgestimmteste": "mißgestimmt",
    "mißgestimmtestem": "mißgestimmt",
    "mißgestimmtesten": "mißgestimmt",
    "mißgestimmtester": "mißgestimmt",
    "mißgestimmtestes": "mißgestimmt",
    "mißglücke": "mißglücken",
    "mißglückend": "mißglücken",
    "mißglückende": "mißglückend",
    "mißglückendem": "mißglückend",
    "mißglückenden": "mißglückend",
    "mißglückender": "mißglückend",
    "mißglückendere": "mißglückend",
    "mißglückenderem": "mißglückend",
    "mißglückenderen": "mißglückend",
    "mißglückenderer": "mißglückend",
    "mißglückenderes": "mißglückend",
    "mißglückendes": "mißglückend",
    "mißglückendste": "mißglückend",
    "mißglückendstem": "mißglückend",
    "mißglückendsten": "mißglückend",
    "mißglückendster": "mißglückend",
    "mißglückendstes": "mißglückend",
    "mißglückest": "mißglücken",
    "mißglücket": "mißglücken",
    "mißglückst": "mißglücken",
    "mißglückt": "mißglücken",
    "mißglückte": "mißglücken",
    "mißglücktem": "mißglückt",
    "mißglückten": "mißglücken",
    "mißglückter": "mißglückt",
    "mißglücktere": "mißglückt",
    "mißglückterem": "mißglückt",
    "mißglückteren": "mißglückt",
    "mißglückterer": "mißglückt",
    "mißglückteres": "mißglückt",
    "mißglücktes": "mißglückt",
    "mißglücktest": "mißglücken",
    "mißglückteste": "mißglückt",
    "mißglücktestem": "mißglückt",
    "mißglücktesten": "mißglückt",
    "mißglücktester": "mißglückt",
    "mißglücktestes": "mißglückt",
    "mißglücktet": "mißglücken",
    "mißhandele": "mißhandeln",
    "mißhandelnd": "mißhandeln",
    "mißhandelnde": "mißhandelnd",
    "mißhandelndem": "mißhandelnd",
    "mißhandelnden": "mißhandelnd",
    "mißhandelnder": "mißhandelnd",
    "mißhandelndes": "mißhandelnd",
    "mißhandelst": "mißhandeln",
    "mißhandelt": "mißhandeln",
    "mißhandelte": "mißhandeln",
    "mißhandeltem": "mißhandelt",
    "mißhandelten": "mißhandeln",
    "mißhandelter": "mißhandelt",
    "mißhandeltere": "mißhandelt",
    "mißhandelterem": "mißhandelt",
    "mißhandelteren": "mißhandelt",
    "mißhandelterer": "mißhandelt",
    "mißhandelteres": "mißhandelt",
    "mißhandeltes": "mißhandelt",
    "mißhandeltest": "mißhandeln",
    "mißhandelteste": "mißhandelt",
    "mißhandeltestem": "mißhandelt",
    "mißhandeltesten": "mißhandelt",
    "mißhandeltester": "mißhandelt",
    "mißhandeltestes": "mißhandelt",
    "mißhandeltet": "mißhandeln",
    "mißhandle": "mißhandeln",
    "mißinterpretiere": "mißinterpretieren",
    "mißinterpretierend": "mißinterpretieren",
    "mißinterpretierende": "mißinterpretierend",
    "mißinterpretierendem": "mißinterpretierend",
    "mißinterpretierenden": "mißinterpretierend",
    "mißinterpretierender": "mißinterpretierend",
    "mißinterpretierendes": "mißinterpretierend",
    "mißinterpretierest": "mißinterpretieren",
    "mißinterpretieret": "mißinterpretieren",
    "mißinterpretierst": "mißinterpretieren",
    "mißinterpretiert": "mißinterpretieren",
    "mißinterpretierte": "mißinterpretieren",
    "mißinterpretiertem": "mißinterpretiert",
    "mißinterpretierten": "mißinterpretieren",
    "mißinterpretierter": "mißinterpretiert",
    "mißinterpretiertes": "mißinterpretiert",
    "mißinterpretiertest": "mißinterpretieren",
    "mißinterpretiertet": "mißinterpretieren",
    "mißlang": "mißlingen",
    "mißlangen": "mißlingen",
    "mißlangst": "mißlingen",
    "mißlangt": "mißlingen",
    "mißliche": "mißlich",
    "mißlichem": "mißlich",
    "mißlichen": "mißlich",
    "mißlicher": "mißlich",
    "mißliches": "mißlich",
    "mißlinge": "mißlingen",
    "mißlingend": "mißlingen",
    "mißlingende": "mißlingend",
    "mißlingendem": "mißlingend",
    "mißlingenden": "mißlingend",
    "mißlingender": "mißlingend",
    "mißlingendes": "mißlingend",
    "mißlingest": "mißlingen",
    "mißlinget": "mißlingen",
    "mißlingst": "mißlingen",
    "mißlingt": "mißlingen",
    "mißlungen": "mißlingen",
    "mißlungene": "mißlungen",
    "mißlungenem": "mißlungen",
    "mißlungenen": "mißlungen",
    "mißlungener": "mißlungen",
    "mißlungenere": "mißlungen",
    "mißlungenerem": "mißlungen",
    "mißlungeneren": "mißlungen",
    "mißlungenerer": "mißlungen",
    "mißlungeneres": "mißlungen",
    "mißlungenes": "mißlungen",
    "mißlungenste": "mißlungen",
    "mißlungenstem": "mißlungen",
    "mißlungensten": "mißlungen",
    "mißlungenster": "mißlungen",
    "mißlungenstes": "mißlungen",
    "mißlänge": "mißlingen",
    "mißlängen": "mißlingen",
    "mißlängest": "mißlingen",
    "mißlänget": "mißlingen",
    "mißmutige": "mißmutig",
    "mißmutigem": "mißmutig",
    "mißmutigen": "mißmutig",
    "mißmutiger": "mißmutig",
    "mißmutigere": "mißmutig",
    "mißmutigerem": "mißmutig",
    "mißmutigeren": "mißmutig",
    "mißmutigerer": "mißmutig",
    "mißmutigeres": "mißmutig",
    "mißmutiges": "mißmutig",
    "mißmutigste": "mißmutig",
    "mißmutigstem": "mißmutig",
    "mißmutigsten": "mißmutig",
    "mißmutigster": "mißmutig",
    "mißmutigstes": "mißmutig",
    "mißrate": "mißraten",
    "mißratend": "mißraten",
    "mißratende": "mißratend",
    "mißratendem": "mißratend",
    "mißratenden": "mißratend",
    "mißratender": "mißratend",
    "mißratendes": "mißratend",
    "mißratene": "mißraten",
    "mißratenem": "mißraten",
    "mißratenen": "mißraten",
    "mißratener": "mißraten",
    "mißratenere": "mißraten",
    "mißratenerem": "mißraten",
    "mißrateneren": "mißraten",
    "mißratenerer": "mißraten",
    "mißrateneres": "mißraten",
    "mißratenes": "mißraten",
    "mißratenstem": "mißraten",
    "mißratensten": "mißraten",
    "mißratenster": "mißraten",
    "mißratenstes": "mißraten",
    "mißratest": "mißraten",
    "mißratet": "mißraten",
    "mißriet": "mißraten",
    "mißriete": "mißraten",
    "mißrieten": "mißraten",
    "mißrietest": "mißraten",
    "mißrietet": "mißraten",
    "mißrät": "mißraten",
    "mißrätst": "mißraten",
    "mißt": "missen",
    "mißte": "missen",
    "mißten": "missen",
    "mißtest": "missen",
    "mißtet": "missen",
    "mißtraue": "mißtrauen",
    "mißtrauend": "mißtrauen",
    "mißtrauende": "mißtrauend",
    "mißtrauendem": "mißtrauend",
    "mißtrauenden": "mißtrauend",
    "mißtrauender": "mißtrauend",
    "mißtrauendere": "mißtrauend",
    "mißtrauenderem": "mißtrauend",
    "mißtrauenderen": "mißtrauend",
    "mißtrauenderer": "mißtrauend",
    "mißtrauenderes": "mißtrauend",
    "mißtrauendes": "mißtrauend",
    "mißtrauendste": "mißtrauend",
    "mißtrauendstem": "mißtrauend",
    "mißtrauendsten": "mißtrauend",
    "mißtrauendster": "mißtrauend",
    "mißtrauendstes": "mißtrauend",
    "mißtrauest": "mißtrauen",
    "mißtrauet": "mißtrauen",
    "mißtrauische": "mißtrauisch",
    "mißtrauischem": "mißtrauisch",
    "mißtrauischen": "mißtrauisch",
    "mißtrauischer": "mißtrauisch",
    "mißtrauischere": "mißtrauisch",
    "mißtrauischerem": "mißtrauisch",
    "mißtrauischeren": "mißtrauisch",
    "mißtrauischerer": "mißtrauisch",
    "mißtrauischeres": "mißtrauisch",
    "mißtrauisches": "mißtrauisch",
    "mißtrauischste": "mißtrauisch",
    "mißtrauischstem": "mißtrauisch",
    "mißtrauischsten": "mißtrauisch",
    "mißtrauischster": "mißtrauisch",
    "mißtrauischstes": "mißtrauisch",
    "mißtraust": "mißtrauen",
    "mißtraut": "mißtrauen",
    "mißtraute": "mißtrauen",
    "mißtrautem": "mißtraut",
    "mißtrauten": "mißtrauen",
    "mißtrauter": "mißtraut",
    "mißtrautes": "mißtraut",
    "mißtrautest": "mißtrauen",
    "mißtrautet": "mißtrauen",
    "mißverstand": "mißverstehen",
    "mißverstanden": "mißverstehen",
    "mißverstandene": "mißverstanden",
    "mißverstandenem": "mißverstanden",
    "mißverstandenen": "mißverstanden",
    "mißverstandener": "mißverstanden",
    "mißverstandenere": "mißverstanden",
    "mißverstandenerem": "mißverstanden",
    "mißverstandeneren": "mißverstanden",
    "mißverstandenerer": "mißverstanden",
    "mißverstandeneres": "mißverstanden",
    "mißverstandenes": "mißverstanden",
    "mißverstandenste": "mißverstanden",
    "mißverstandenstem": "mißverstanden",
    "mißverstandensten": "mißverstanden",
    "mißverstandenster": "mißverstanden",
    "mißverstandenstes": "mißverstanden",
    "mißverstandest": "mißverstehen",
    "mißverstandet": "mißverstehen",
    "mißverstehe": "mißverstehen",
    "mißverstehend": "mißverstehen",
    "mißverstehende": "mißverstehend",
    "mißverstehendem": "mißverstehend",
    "mißverstehenden": "mißverstehend",
    "mißverstehender": "mißverstehend",
    "mißverstehendes": "mißverstehend",
    "mißverstehest": "mißverstehen",
    "mißverstehet": "mißverstehen",
    "mißverstehst": "mißverstehen",
    "mißversteht": "mißverstehen",
    "mißverstände": "mißverstehen",
    "mißverständen": "mißverstehen",
    "mißverständest": "mißverstehen",
    "mißverständet": "mißverstehen",
    "mißverständliche": "mißverständlich",
    "mißverständlichem": "mißverständlich",
    "mißverständlichen": "mißverständlich",
    "mißverständlicher": "mißverständlich",
    "mißverständliches": "mißverständlich",
    "mißwirtschafte": "mißwirtschaften",
    "mißwirtschaftend": "mißwirtschaften",
    "mißwirtschaftende": "mißwirtschaftend",
    "mißwirtschaftendem": "mißwirtschaftend",
    "mißwirtschaftenden": "mißwirtschaftend",
    "mißwirtschaftender": "mißwirtschaftend",
    "mißwirtschaftendes": "mißwirtschaftend",
    "mißwirtschaftest": "mißwirtschaften",
    "mißwirtschaftet": "mißwirtschaften",
    "mißwirtschaftete": "mißwirtschaften",
    "mißwirtschaftetem": "mißwirtschaftet",
    "mißwirtschafteten": "mißwirtschaften",
    "mißwirtschafteter": "mißwirtschaftet",
    "mißwirtschaftetes": "mißwirtschaftet",
    "mißwirtschaftetest": "mißwirtschaften",
    "mißwirtschaftetet": "mißwirtschaften",
    "mnemotechnische": "mnemotechnisch",
    "mnemotechnischem": "mnemotechnisch",
    "mnemotechnischen": "mnemotechnisch",
    "mnemotechnischer": "mnemotechnisch",
    "mnemotechnisches": "mnemotechnisch",
    "mobile": "mobil",
    "mobilem": "mobil",
    "mobilen": "mobil",
    "mobiler": "mobil",
    "mobilere": "mobil",
    "mobilerem": "mobil",
    "mobileren": "mobil",
    "mobilerer": "mobil",
    "mobileres": "mobil",
    "mobiles": "mobil",
    "mobilisiere": "mobilisieren",
    "mobilisierend": "mobilisieren",
    "mobilisierende": "mobilisierend",
    "mobilisierendem": "mobilisierend",
    "mobilisierenden": "mobilisierend",
    "mobilisierender": "mobilisierend",
    "mobilisierendere": "mobilisierend",
    "mobilisierenderem": "mobilisierend",
    "mobilisierenderen": "mobilisierend",
    "mobilisierenderer": "mobilisierend",
    "mobilisierenderes": "mobilisierend",
    "mobilisierendes": "mobilisierend",
    "mobilisierendste": "mobilisierend",
    "mobilisierendstem": "mobilisierend",
    "mobilisierendsten": "mobilisierend",
    "mobilisierendster": "mobilisierend",
    "mobilisierendstes": "mobilisierend",
    "mobilisierest": "mobilisieren",
    "mobilisieret": "mobilisieren",
    "mobilisierst": "mobilisieren",
    "mobilisiert": "mobilisieren",
    "mobilisierte": "mobilisieren",
    "mobilisiertem": "mobilisiert",
    "mobilisierten": "mobilisieren",
    "mobilisierter": "mobilisiert",
    "mobilisiertere": "mobilisiert",
    "mobilisierterem": "mobilisiert",
    "mobilisierteren": "mobilisiert",
    "mobilisierterer": "mobilisiert",
    "mobilisierteres": "mobilisiert",
    "mobilisiertes": "mobilisiert",
    "mobilisiertest": "mobilisieren",
    "mobilisierteste": "mobilisiert",
    "mobilisiertestem": "mobilisiert",
    "mobilisiertesten": "mobilisiert",
    "mobilisiertester": "mobilisiert",
    "mobilisiertestes": "mobilisiert",
    "mobilisiertet": "mobilisieren",
    "mobilstem": "mobil",
    "mobilsten": "mobil",
    "mobilster": "mobil",
    "mobilstes": "mobil",
    "mochte": "mögen",
    "mochten": "mögen",
    "mochtest": "mögen",
    "mochtet": "mögen",
    "modalem": "modal",
    "modalen": "modal",
    "modaler": "modal",
    "modales": "modal",
    "modebewußtem": "modebewußt",
    "modebewußten": "modebewußt",
    "modebewußter": "modebewußt",
    "modebewußtere": "modebewußt",
    "modebewußterem": "modebewußt",
    "modebewußteren": "modebewußt",
    "modebewußterer": "modebewußt",
    "modebewußteres": "modebewußt",
    "modebewußtes": "modebewußt",
    "modebewußteste": "modebewußt",
    "modebewußtestem": "modebewußt",
    "modebewußtesten": "modebewußt",
    "modebewußtester": "modebewußt",
    "modebewußtestes": "modebewußt",
    "modele": "modeln",
    "modelliere": "modellieren",
    "modellierend": "modellieren",
    "modellierende": "modellierend",
    "modellierendem": "modellierend",
    "modellierenden": "modellierend",
    "modellierender": "modellierend",
    "modellierendere": "modellierend",
    "modellierenderem": "modellierend",
    "modellierenderen": "modellierend",
    "modellierenderer": "modellierend",
    "modellierenderes": "modellierend",
    "modellierendes": "modellierend",
    "modellierendste": "modellierend",
    "modellierendstem": "modellierend",
    "modellierendsten": "modellierend",
    "modellierendster": "modellierend",
    "modellierendstes": "modellierend",
    "modellierest": "modellieren",
    "modellieret": "modellieren",
    "modellierst": "modellieren",
    "modelliert": "modellieren",
    "modellierte": "modellieren",
    "modelliertem": "modelliert",
    "modellierten": "modellieren",
    "modellierter": "modelliert",
    "modelliertes": "modelliert",
    "modelliertest": "modellieren",
    "modelliertet": "modellieren",
    "modelnd": "modeln",
    "modelnde": "modelnd",
    "modelndem": "modelnd",
    "modelnden": "modelnd",
    "modelnder": "modelnd",
    "modelndes": "modelnd",
    "modelst": "modeln",
    "modelt": "modeln",
    "modelte": "modeln",
    "modelten": "modeln",
    "modeltest": "modeln",
    "modeltet": "modeln",
    "moderatem": "moderat",
    "moderaten": "moderat",
    "moderater": "moderat",
    "moderatere": "moderat",
    "moderaterem": "moderat",
    "moderateren": "moderat",
    "moderaterer": "moderat",
    "moderateres": "moderat",
    "moderates": "moderat",
    "moderateste": "moderat",
    "moderatestem": "moderat",
    "moderatesten": "moderat",
    "moderatester": "moderat",
    "moderatestes": "moderat",
    "moderiere": "moderieren",
    "moderierend": "moderieren",
    "moderierende": "moderierend",
    "moderierendem": "moderierend",
    "moderierenden": "moderierend",
    "moderierender": "moderierend",
    "moderierendes": "moderierend",
    "moderierest": "moderieren",
    "moderieret": "moderieren",
    "moderierst": "moderieren",
    "moderiert": "moderieren",
    "moderierte": "moderieren",
    "moderiertem": "moderiert",
    "moderierten": "moderieren",
    "moderierter": "moderiert",
    "moderiertes": "moderiert",
    "moderiertest": "moderieren",
    "moderiertet": "moderieren",
    "moderige": "moderig",
    "moderigem": "moderig",
    "moderigen": "moderig",
    "moderiger": "moderig",
    "moderigere": "moderig",
    "moderigerem": "moderig",
    "moderigeren": "moderig",
    "moderigerer": "moderig",
    "moderigeres": "moderig",
    "moderiges": "moderig",
    "moderigste": "moderig",
    "moderigstem": "moderig",
    "moderigsten": "moderig",
    "moderigster": "moderig",
    "moderigstes": "moderig",
    "moderne": "modern",
    "modernem": "modern",
    "modernen": "modern",
    "moderner": "modern",
    "modernere": "modern",
    "modernerem": "modern",
    "moderneren": "modern",
    "modernerer": "modern",
    "moderneres": "modern",
    "modernes": "modern",
    "modernisiere": "modernisieren",
    "modernisierend": "modernisieren",
    "modernisierende": "modernisierend",
    "modernisierendem": "modernisierend",
    "modernisierenden": "modernisierend",
    "modernisierender": "modernisierend",
    "modernisierendes": "modernisierend",
    "modernisierest": "modernisieren",
    "modernisieret": "modernisieren",
    "modernisierst": "modernisieren",
    "modernisiert": "modernisieren",
    "modernisierte": "modernisieren",
    "modernisiertem": "modernisiert",
    "modernisierten": "modernisieren",
    "modernisierter": "modernisiert",
    "modernisiertere": "modernisiert",
    "modernisierterem": "modernisiert",
    "modernisierteren": "modernisiert",
    "modernisierterer": "modernisiert",
    "modernisierteres": "modernisiert",
    "modernisiertes": "modernisiert",
    "modernisiertest": "modernisieren",
    "modernisierteste": "modernisiert",
    "modernisiertestem": "modernisiert",
    "modernisiertesten": "modernisiert",
    "modernisiertester": "modernisiert",
    "modernisiertestes": "modernisiert",
    "modernisiertet": "modernisieren",
    "modernstem": "modern",
    "modernsten": "modern",
    "modernster": "modern",
    "modernstes": "modern",
    "modifiziere": "modifizieren",
    "modifizierend": "modifizieren",
    "modifizierende": "modifizierend",
    "modifizierendem": "modifizierend",
    "modifizierenden": "modifizierend",
    "modifizierender": "modifizierend",
    "modifizierendes": "modifizierend",
    "modifizierest": "modifizieren",
    "modifizieret": "modifizieren",
    "modifizierst": "modifizieren",
    "modifiziert": "modifizieren",
    "modifizierte": "modifizieren",
    "modifiziertem": "modifiziert",
    "modifizierten": "modifizieren",
    "modifizierter": "modifiziert",
    "modifiziertere": "modifiziert",
    "modifizierterem": "modifiziert",
    "modifizierteren": "modifiziert",
    "modifizierterer": "modifiziert",
    "modifizierteres": "modifiziert",
    "modifiziertes": "modifiziert",
    "modifiziertest": "modifizieren",
    "modifizierteste": "modifiziert",
    "modifiziertestem": "modifiziert",
    "modifiziertesten": "modifiziert",
    "modifiziertester": "modifiziert",
    "modifiziertestes": "modifiziert",
    "modifiziertet": "modifizieren",
    "modische": "modisch",
    "modischem": "modisch",
    "modischen": "modisch",
    "modischer": "modisch",
    "modischere": "modisch",
    "modischerem": "modisch",
    "modischeren": "modisch",
    "modischerer": "modisch",
    "modischeres": "modisch",
    "modisches": "modisch",
    "modischste": "modisch",
    "modischstem": "modisch",
    "modischsten": "modisch",
    "modischster": "modisch",
    "modischstes": "modisch",
    "modle": "modeln",
    "modularem": "modular",
    "modularen": "modular",
    "modularer": "modular",
    "modulares": "modular",
    "modulationsfähige": "modulationsfähig",
    "modulationsfähigem": "modulationsfähig",
    "modulationsfähigen": "modulationsfähig",
    "modulationsfähiger": "modulationsfähig",
    "modulationsfähiges": "modulationsfähig",
    "moduliere": "modulieren",
    "modulierend": "modulieren",
    "modulierende": "modulierend",
    "modulierendem": "modulierend",
    "modulierenden": "modulierend",
    "modulierender": "modulierend",
    "modulierendes": "modulierend",
    "modulierest": "modulieren",
    "modulieret": "modulieren",
    "modulierst": "modulieren",
    "moduliert": "modulieren",
    "modulierte": "modulieren",
    "moduliertem": "moduliert",
    "modulierten": "modulieren",
    "modulierter": "moduliert",
    "moduliertes": "moduliert",
    "moduliertest": "modulieren",
    "moduliertet": "modulieren",
    "mogele": "mogeln",
    "mogelnd": "mogeln",
    "mogelnde": "mogelnd",
    "mogelndem": "mogelnd",
    "mogelnden": "mogelnd",
    "mogelnder": "mogelnd",
    "mogelndes": "mogelnd",
    "mogelst": "mogeln",
    "mogelt": "mogeln",
    "mogelte": "mogeln",
    "mogelten": "mogeln",
    "mogeltest": "mogeln",
    "mogeltet": "mogeln",
    "mogle": "mogeln",
    "mohammedanischem": "mohammedanisch",
    "mohammedanischen": "mohammedanisch",
    "mohammedanischer": "mohammedanisch",
    "mohammedanisches": "mohammedanisch",
    "molekularem": "molekular",
    "molekularen": "molekular",
    "molekularer": "molekular",
    "molekulares": "molekular",
    "molk": "melken",
    "molken": "melken",
    "molkst": "melken",
    "molkt": "melken",
    "molligem": "mollig",
    "molligen": "mollig",
    "molliger": "mollig",
    "molligere": "mollig",
    "molligerem": "mollig",
    "molligeren": "mollig",
    "molligerer": "mollig",
    "molligeres": "mollig",
    "molliges": "mollig",
    "molligste": "mollig",
    "molligstem": "mollig",
    "molligsten": "mollig",
    "molligster": "mollig",
    "molligstes": "mollig",
    "momentanem": "momentan",
    "momentanen": "momentan",
    "momentaner": "momentan",
    "momentanes": "momentan",
    "monatlichem": "monatlich",
    "monatlichen": "monatlich",
    "monatlicher": "monatlich",
    "monatliches": "monatlich",
    "mondsüchtigem": "mondsüchtig",
    "mondsüchtigen": "mondsüchtig",
    "mondsüchtiger": "mondsüchtig",
    "mondsüchtiges": "mondsüchtig",
    "monegassischem": "monegassisch",
    "monegassischen": "monegassisch",
    "monegassischer": "monegassisch",
    "monegassisches": "monegassisch",
    "moniere": "monieren",
    "monierend": "monieren",
    "monierende": "monierend",
    "monierendem": "monierend",
    "monierenden": "monierend",
    "monierender": "monierend",
    "monierendes": "monierend",
    "monierest": "monieren",
    "monieret": "monieren",
    "monierst": "monieren",
    "moniert": "monieren",
    "monierte": "monieren",
    "moniertem": "moniert",
    "monierten": "monieren",
    "monierter": "moniert",
    "moniertes": "moniert",
    "moniertest": "monieren",
    "moniertet": "monieren",
    "monographischem": "monographisch",
    "monographischen": "monographisch",
    "monographischer": "monographisch",
    "monographisches": "monographisch",
    "monokausale": "monokausal",
    "monokausalem": "monokausal",
    "monokausalen": "monokausal",
    "monokausaler": "monokausal",
    "monokausales": "monokausal",
    "monopolisiere": "monopolisieren",
    "monopolisierend": "monopolisieren",
    "monopolisierende": "monopolisierend",
    "monopolisierendem": "monopolisierend",
    "monopolisierenden": "monopolisierend",
    "monopolisierender": "monopolisierend",
    "monopolisierendere": "monopolisierend",
    "monopolisierenderem": "monopolisierend",
    "monopolisierenderen": "monopolisierend",
    "monopolisierenderer": "monopolisierend",
    "monopolisierenderes": "monopolisierend",
    "monopolisierendes": "monopolisierend",
    "monopolisierendste": "monopolisierend",
    "monopolisierendstem": "monopolisierend",
    "monopolisierendsten": "monopolisierend",
    "monopolisierendster": "monopolisierend",
    "monopolisierendstes": "monopolisierend",
    "monopolisierest": "monopolisieren",
    "monopolisieret": "monopolisieren",
    "monopolisierst": "monopolisieren",
    "monopolisiert": "monopolisieren",
    "monopolisierte": "monopolisieren",
    "monopolisiertem": "monopolisiert",
    "monopolisierten": "monopolisieren",
    "monopolisierter": "monopolisiert",
    "monopolisiertere": "monopolisiert",
    "monopolisierterem": "monopolisiert",
    "monopolisierteren": "monopolisiert",
    "monopolisierterer": "monopolisiert",
    "monopolisierteres": "monopolisiert",
    "monopolisiertes": "monopolisiert",
    "monopolisiertest": "monopolisieren",
    "monopolisiertestem": "monopolisiert",
    "monopolisiertesten": "monopolisiert",
    "monopolisiertester": "monopolisiert",
    "monopolisiertestes": "monopolisiert",
    "monopolisiertet": "monopolisieren",
    "monopolistischem": "monopolistisch",
    "monopolistischen": "monopolistisch",
    "monopolistischer": "monopolistisch",
    "monopolistisches": "monopolistisch",
    "monotonem": "monoton",
    "monotonen": "monoton",
    "monotoner": "monoton",
    "monotonere": "monoton",
    "monotonerem": "monoton",
    "monotoneren": "monoton",
    "monotonerer": "monoton",
    "monotoneres": "monoton",
    "monotones": "monoton",
    "monotonste": "monoton",
    "monotonstem": "monoton",
    "monotonsten": "monoton",
    "monotonster": "monoton",
    "monotonstes": "monoton",
    "montanem": "montan",
    "montanen": "montan",
    "montaner": "montan",
    "montanes": "montan",
    "montiere": "montieren",
    "montierend": "montieren",
    "montierende": "montierend",
    "montierendem": "montierend",
    "montierenden": "montierend",
    "montierender": "montierend",
    "montierendes": "montierend",
    "montierest": "montieren",
    "montieret": "montieren",
    "montierst": "montieren",
    "montiert": "montieren",
    "montierte": "montieren",
    "montiertem": "montiert",
    "montierten": "montieren",
    "montierter": "montiert",
    "montiertes": "montiert",
    "montiertest": "montieren",
    "montiertet": "montieren",
    "monumentalem": "monumental",
    "monumentalen": "monumental",
    "monumentaler": "monumental",
    "monumentales": "monumental",
    "mopse": "mopsen",
    "mopsend": "mopsen",
    "mopsende": "mopsend",
    "mopsendem": "mopsend",
    "mopsenden": "mopsend",
    "mopsender": "mopsend",
    "mopsendere": "mopsend",
    "mopsenderem": "mopsend",
    "mopsenderen": "mopsend",
    "mopsenderer": "mopsend",
    "mopsenderes": "mopsend",
    "mopsendes": "mopsend",
    "mopsendste": "mopsend",
    "mopsendstem": "mopsend",
    "mopsendsten": "mopsend",
    "mopsendster": "mopsend",
    "mopsendstes": "mopsend",
    "mopsest": "mopsen",
    "mopset": "mopsen",
    "mopsige": "mopsig",
    "mopsigem": "mopsig",
    "mopsigen": "mopsig",
    "mopsiger": "mopsig",
    "mopsigere": "mopsig",
    "mopsigerem": "mopsig",
    "mopsigeren": "mopsig",
    "mopsigerer": "mopsig",
    "mopsigeres": "mopsig",
    "mopsiges": "mopsig",
    "mopsigste": "mopsig",
    "mopsigstem": "mopsig",
    "mopsigsten": "mopsig",
    "mopsigster": "mopsig",
    "mopsigstes": "mopsig",
    "mopst": "mopsen",
    "mopste": "mopsen",
    "mopsten": "mopsen",
    "mopstest": "mopsen",
    "mopstet": "mopsen",
    "moralische": "moralisch",
    "moralischem": "moralisch",
    "moralischen": "moralisch",
    "moralischer": "moralisch",
    "moralisches": "moralisch",
    "moralisiere": "moralisieren",
    "moralisierend": "moralisieren",
    "moralisierende": "moralisierend",
    "moralisierendem": "moralisierend",
    "moralisierenden": "moralisierend",
    "moralisierender": "moralisierend",
    "moralisierendere": "moralisierend",
    "moralisierenderem": "moralisierend",
    "moralisierenderen": "moralisierend",
    "moralisierenderer": "moralisierend",
    "moralisierenderes": "moralisierend",
    "moralisierendes": "moralisierend",
    "moralisierendste": "moralisierend",
    "moralisierendstem": "moralisierend",
    "moralisierendsten": "moralisierend",
    "moralisierendster": "moralisierend",
    "moralisierendstes": "moralisierend",
    "moralisierest": "moralisieren",
    "moralisieret": "moralisieren",
    "moralisierst": "moralisieren",
    "moralisiert": "moralisieren",
    "moralisierte": "moralisieren",
    "moralisiertem": "moralisiert",
    "moralisierten": "moralisieren",
    "moralisierter": "moralisiert",
    "moralisiertere": "moralisiert",
    "moralisierterem": "moralisiert",
    "moralisierteren": "moralisiert",
    "moralisierterer": "moralisiert",
    "moralisierteres": "moralisiert",
    "moralisiertes": "moralisiert",
    "moralisiertest": "moralisieren",
    "moralisierteste": "moralisiert",
    "moralisiertestem": "moralisiert",
    "moralisiertesten": "moralisiert",
    "moralisiertester": "moralisiert",
    "moralisiertestes": "moralisiert",
    "moralisiertet": "moralisieren",
    "morastigem": "morastig",
    "morastigen": "morastig",
    "morastiger": "morastig",
    "morastigere": "morastig",
    "morastigerem": "morastig",
    "morastigeren": "morastig",
    "morastigerer": "morastig",
    "morastigeres": "morastig",
    "morastiges": "morastig",
    "morastigste": "morastig",
    "morastigstem": "morastig",
    "morastigsten": "morastig",
    "morastigster": "morastig",
    "morastigstes": "morastig",
    "morbidem": "morbid",
    "morbiden": "morbid",
    "morbider": "morbid",
    "morbides": "morbid",
    "mordend": "morden",
    "mordende": "mordend",
    "mordendem": "mordend",
    "mordenden": "mordend",
    "mordender": "mordend",
    "mordendes": "mordend",
    "mordest": "morden",
    "mordet": "morden",
    "mordete": "morden",
    "mordeten": "morden",
    "mordetest": "morden",
    "mordetet": "morden",
    "mordsmäßigem": "mordsmäßig",
    "mordsmäßigen": "mordsmäßig",
    "mordsmäßiger": "mordsmäßig",
    "mordsmäßiges": "mordsmäßig",
    "morgendlichem": "morgendlich",
    "morgendlichen": "morgendlich",
    "morgendlicher": "morgendlich",
    "morgendliches": "morgendlich",
    "morgenländische": "morgenländisch",
    "morgenländischem": "morgenländisch",
    "morgenländischen": "morgenländisch",
    "morgenländischer": "morgenländisch",
    "morgenländisches": "morgenländisch",
    "morgigem": "morgig",
    "morgigen": "morgig",
    "morgiger": "morgig",
    "morgiges": "morgig",
    "morphologischem": "morphologisch",
    "morphologischen": "morphologisch",
    "morphologischer": "morphologisch",
    "morphologisches": "morphologisch",
    "morschem": "morsch",
    "morschen": "morsch",
    "morscher": "morsch",
    "morschere": "morsch",
    "morscherem": "morsch",
    "morscheren": "morsch",
    "morscherer": "morsch",
    "morscheres": "morsch",
    "morsches": "morsch",
    "morscheste": "morsch",
    "morschestem": "morsch",
    "morschesten": "morsch",
    "morschester": "morsch",
    "morschestes": "morsch",
    "morse": "morsen",
    "morsend": "morsen",
    "morsende": "morsend",
    "morsendem": "morsend",
    "morsenden": "morsend",
    "morsender": "morsend",
    "morsendes": "morsend",
    "morsest": "morsen",
    "morset": "morsen",
    "morst": "morsen",
    "morste": "morsen",
    "morsten": "morsen",
    "morstest": "morsen",
    "morstet": "morsen",
    "mortifiziere": "mortifizieren",
    "mortifizierend": "mortifizieren",
    "mortifizierende": "mortifizierend",
    "mortifizierendem": "mortifizierend",
    "mortifizierenden": "mortifizierend",
    "mortifizierender": "mortifizierend",
    "mortifizierendes": "mortifizierend",
    "mortifizierest": "mortifizieren",
    "mortifizieret": "mortifizieren",
    "mortifizierst": "mortifizieren",
    "mortifiziert": "mortifizieren",
    "mortifizierte": "mortifizieren",
    "mortifiziertem": "mortifiziert",
    "mortifizierten": "mortifizieren",
    "mortifizierter": "mortifiziert",
    "mortifiziertes": "mortifiziert",
    "mortifiziertest": "mortifizieren",
    "mortifiziertet": "mortifizieren",
    "mosere": "mosern",
    "mosernd": "mosern",
    "mosernde": "mosernd",
    "moserndem": "mosernd",
    "mosernden": "mosernd",
    "mosernder": "mosernd",
    "moserndere": "mosernd",
    "mosernderem": "mosernd",
    "mosernderen": "mosernd",
    "mosernderer": "mosernd",
    "mosernderes": "mosernd",
    "moserndes": "mosernd",
    "moserndste": "mosernd",
    "moserndstem": "mosernd",
    "moserndsten": "mosernd",
    "moserndster": "mosernd",
    "moserndstes": "mosernd",
    "moserst": "mosern",
    "mosert": "mosern",
    "moserte": "mosern",
    "moserten": "mosern",
    "mosertest": "mosern",
    "mosertet": "mosern",
    "moskauhörigem": "moskauhörig",
    "moskauhörigen": "moskauhörig",
    "moskauhöriger": "moskauhörig",
    "moskauhörigere": "moskauhörig",
    "moskauhörigerem": "moskauhörig",
    "moskauhörigeren": "moskauhörig",
    "moskauhörigerer": "moskauhörig",
    "moskauhörigeres": "moskauhörig",
    "moskauhöriges": "moskauhörig",
    "moskauhörigste": "moskauhörig",
    "moskauhörigstem": "moskauhörig",
    "moskauhörigsten": "moskauhörig",
    "moskauhörigster": "moskauhörig",
    "moskauhörigstes": "moskauhörig",
    "moslemischem": "moslemisch",
    "moslemischen": "moslemisch",
    "moslemischer": "moslemisch",
    "moslemisches": "moslemisch",
    "motiviere": "motivieren",
    "motivierend": "motivieren",
    "motivierende": "motivierend",
    "motivierendem": "motivierend",
    "motivierenden": "motivierend",
    "motivierender": "motivierend",
    "motivierendere": "motivierend",
    "motivierenderem": "motivierend",
    "motivierenderen": "motivierend",
    "motivierenderer": "motivierend",
    "motivierenderes": "motivierend",
    "motivierendes": "motivierend",
    "motivierendste": "motivierend",
    "motivierendstem": "motivierend",
    "motivierendsten": "motivierend",
    "motivierendster": "motivierend",
    "motivierendstes": "motivierend",
    "motivierest": "motivieren",
    "motivieret": "motivieren",
    "motivierst": "motivieren",
    "motiviert": "motivieren",
    "motivierte": "motivieren",
    "motiviertem": "motiviert",
    "motivierten": "motivieren",
    "motivierter": "motiviert",
    "motiviertere": "motiviert",
    "motivierterem": "motiviert",
    "motivierteren": "motiviert",
    "motivierterer": "motiviert",
    "motivierteres": "motiviert",
    "motiviertes": "motiviert",
    "motiviertest": "motivieren",
    "motivierteste": "motiviert",
    "motiviertestem": "motiviert",
    "motiviertesten": "motiviert",
    "motiviertester": "motiviert",
    "motiviertestes": "motiviert",
    "motiviertet": "motivieren",
    "motorischem": "motorisch",
    "motorischen": "motorisch",
    "motorischer": "motorisch",
    "motorisches": "motorisch",
    "motorisiere": "motorisieren",
    "motorisierend": "motorisieren",
    "motorisierende": "motorisierend",
    "motorisierendem": "motorisierend",
    "motorisierenden": "motorisierend",
    "motorisierender": "motorisierend",
    "motorisierendes": "motorisierend",
    "motorisierest": "motorisieren",
    "motorisieret": "motorisieren",
    "motorisierst": "motorisieren",
    "motorisiert": "motorisieren",
    "motorisierte": "motorisieren",
    "motorisiertem": "motorisiert",
    "motorisierten": "motorisieren",
    "motorisierter": "motorisiert",
    "motorisiertere": "motorisiert",
    "motorisierterem": "motorisiert",
    "motorisierteren": "motorisiert",
    "motorisierterer": "motorisiert",
    "motorisierteres": "motorisiert",
    "motorisiertes": "motorisiert",
    "motorisiertest": "motorisieren",
    "motorisierteste": "motorisiert",
    "motorisiertestem": "motorisiert",
    "motorisiertesten": "motorisiert",
    "motorisiertester": "motorisiert",
    "motorisiertestes": "motorisiert",
    "motorisiertet": "motorisieren",
    "mottend": "motten",
    "mottende": "mottend",
    "mottendem": "mottend",
    "mottenden": "mottend",
    "mottender": "mottend",
    "mottendes": "mottend",
    "mottest": "motten",
    "mottet": "motten",
    "mottete": "motten",
    "motteten": "motten",
    "mottetest": "motten",
    "mottetet": "motten",
    "motze": "motzen",
    "motzend": "motzen",
    "motzende": "motzend",
    "motzendem": "motzend",
    "motzenden": "motzend",
    "motzender": "motzend",
    "motzendere": "motzend",
    "motzenderem": "motzend",
    "motzenderen": "motzend",
    "motzenderer": "motzend",
    "motzenderes": "motzend",
    "motzendes": "motzend",
    "motzendste": "motzend",
    "motzendstem": "motzend",
    "motzendsten": "motzend",
    "motzendster": "motzend",
    "motzendstes": "motzend",
    "motzest": "motzen",
    "motzet": "motzen",
    "motzige": "motzig",
    "motzigem": "motzig",
    "motzigen": "motzig",
    "motziger": "motzig",
    "motzigere": "motzig",
    "motzigerem": "motzig",
    "motzigeren": "motzig",
    "motzigerer": "motzig",
    "motzigeres": "motzig",
    "motziges": "motzig",
    "motzigste": "motzig",
    "motzigstem": "motzig",
    "motzigsten": "motzig",
    "motzigster": "motzig",
    "motzigstes": "motzig",
    "motzt": "motzen",
    "motzte": "motzen",
    "motzten": "motzen",
    "motztest": "motzen",
    "motztet": "motzen",
    "muckse": "mucksen",
    "mucksend": "mucksen",
    "mucksende": "mucksend",
    "mucksendem": "mucksend",
    "mucksenden": "mucksend",
    "mucksender": "mucksend",
    "mucksendere": "mucksend",
    "mucksenderem": "mucksend",
    "mucksenderen": "mucksend",
    "mucksenderer": "mucksend",
    "mucksenderes": "mucksend",
    "mucksendes": "mucksend",
    "mucksendste": "mucksend",
    "mucksendstem": "mucksend",
    "mucksendsten": "mucksend",
    "mucksendster": "mucksend",
    "mucksendstes": "mucksend",
    "mucksest": "mucksen",
    "muckset": "mucksen",
    "muckst": "mucksen",
    "muckste": "mucksen",
    "mucksten": "mucksen",
    "muckstest": "mucksen",
    "muckstet": "mucksen",
    "muffele": "muffeln",
    "muffelige": "muffelig",
    "muffeligem": "muffelig",
    "muffeligen": "muffelig",
    "muffeliger": "muffelig",
    "muffeligere": "muffelig",
    "muffeligerem": "muffelig",
    "muffeligeren": "muffelig",
    "muffeligerer": "muffelig",
    "muffeligeres": "muffelig",
    "muffeliges": "muffelig",
    "muffeligste": "muffelig",
    "muffeligstem": "muffelig",
    "muffeligsten": "muffelig",
    "muffeligster": "muffelig",
    "muffeligstes": "muffelig",
    "muffelnd": "muffeln",
    "muffelnde": "muffelnd",
    "muffelndem": "muffelnd",
    "muffelnden": "muffelnd",
    "muffelnder": "muffelnd",
    "muffelndere": "muffelnd",
    "muffelnderem": "muffelnd",
    "muffelnderen": "muffelnd",
    "muffelnderer": "muffelnd",
    "muffelnderes": "muffelnd",
    "muffelndes": "muffelnd",
    "muffelndste": "muffelnd",
    "muffelndstem": "muffelnd",
    "muffelndsten": "muffelnd",
    "muffelndster": "muffelnd",
    "muffelndstes": "muffelnd",
    "muffelst": "muffeln",
    "muffelt": "muffeln",
    "muffelte": "muffeln",
    "muffelten": "muffeln",
    "muffeltest": "muffeln",
    "muffeltet": "muffeln",
    "muffend": "muffen",
    "muffende": "muffend",
    "muffendem": "muffend",
    "muffenden": "muffend",
    "muffender": "muffend",
    "muffendere": "muffend",
    "muffenderem": "muffend",
    "muffenderen": "muffend",
    "muffenderer": "muffend",
    "muffenderes": "muffend",
    "muffendes": "muffend",
    "muffendste": "muffend",
    "muffendstem": "muffend",
    "muffendsten": "muffend",
    "muffendster": "muffend",
    "muffendstes": "muffend",
    "muffest": "muffen",
    "muffet": "muffen",
    "muffige": "muffig",
    "muffigem": "muffig",
    "muffigen": "muffig",
    "muffiger": "muffig",
    "muffigere": "muffig",
    "muffigerem": "muffig",
    "muffigeren": "muffig",
    "muffigerer": "muffig",
    "muffigeres": "muffig",
    "muffiges": "muffig",
    "muffigste": "muffig",
    "muffigstem": "muffig",
    "muffigsten": "muffig",
    "muffigster": "muffig",
    "muffigstes": "muffig",
    "muffle": "muffeln",
    "muffst": "muffen",
    "mufft": "muffen",
    "muffte": "muffen",
    "mufften": "muffen",
    "mufftest": "muffen",
    "mufftet": "muffen",
    "mulmigem": "mulmig",
    "mulmigen": "mulmig",
    "mulmiger": "mulmig",
    "mulmigere": "mulmig",
    "mulmigerem": "mulmig",
    "mulmigeren": "mulmig",
    "mulmigerer": "mulmig",
    "mulmigeres": "mulmig",
    "mulmiges": "mulmig",
    "mulmigste": "mulmig",
    "mulmigstem": "mulmig",
    "mulmigsten": "mulmig",
    "mulmigster": "mulmig",
    "mulmigstes": "mulmig",
    "multidisziplinäre": "multidisziplinär",
    "multidisziplinärem": "multidisziplinär",
    "multidisziplinären": "multidisziplinär",
    "multidisziplinärer": "multidisziplinär",
    "multidisziplinärere": "multidisziplinär",
    "multidisziplinärerem": "multidisziplinär",
    "multidisziplinäreren": "multidisziplinär",
    "multidisziplinärerer": "multidisziplinär",
    "multidisziplinäreres": "multidisziplinär",
    "multidisziplinäres": "multidisziplinär",
    "multidisziplinärste": "multidisziplinär",
    "multidisziplinärstem": "multidisziplinär",
    "multidisziplinärsten": "multidisziplinär",
    "multidisziplinärster": "multidisziplinär",
    "multidisziplinärstes": "multidisziplinär",
    "multifunktionale": "multifunktional",
    "multifunktionalem": "multifunktional",
    "multifunktionalen": "multifunktional",
    "multifunktionaler": "multifunktional",
    "multifunktionales": "multifunktional",
    "multikulturellem": "multikulturell",
    "multikulturellen": "multikulturell",
    "multikultureller": "multikulturell",
    "multikulturellere": "multikulturell",
    "multikulturellerem": "multikulturell",
    "multikulturelleren": "multikulturell",
    "multikulturellerer": "multikulturell",
    "multikulturelleres": "multikulturell",
    "multikulturelles": "multikulturell",
    "multikulturellste": "multikulturell",
    "multikulturellstem": "multikulturell",
    "multikulturellsten": "multikulturell",
    "multikulturellster": "multikulturell",
    "multikulturellstes": "multikulturell",
    "multilinguale": "multilingual",
    "multilingualem": "multilingual",
    "multilingualen": "multilingual",
    "multilingualer": "multilingual",
    "multilinguales": "multilingual",
    "multimediale": "multimedial",
    "multimedialem": "multimedial",
    "multimedialen": "multimedial",
    "multimedialer": "multimedial",
    "multimediales": "multimedial",
    "mumifiziere": "mumifizieren",
    "mumifizierend": "mumifizieren",
    "mumifizierende": "mumifizierend",
    "mumifizierendem": "mumifizierend",
    "mumifizierenden": "mumifizierend",
    "mumifizierender": "mumifizierend",
    "mumifizierendes": "mumifizierend",
    "mumifizierest": "mumifizieren",
    "mumifizieret": "mumifizieren",
    "mumifizierst": "mumifizieren",
    "mumifiziert": "mumifizieren",
    "mumifizierte": "mumifizieren",
    "mumifiziertem": "mumifiziert",
    "mumifizierten": "mumifizieren",
    "mumifizierter": "mumifiziert",
    "mumifiziertes": "mumifiziert",
    "mumifiziertest": "mumifizieren",
    "mumifiziertet": "mumifizieren",
    "mundend": "munden",
    "mundende": "mundend",
    "mundendem": "mundend",
    "mundenden": "mundend",
    "mundender": "mundend",
    "mundendere": "mundend",
    "mundenderem": "mundend",
    "mundenderen": "mundend",
    "mundenderer": "mundend",
    "mundenderes": "mundend",
    "mundendes": "mundend",
    "mundendste": "mundend",
    "mundendstem": "mundend",
    "mundendsten": "mundend",
    "mundendster": "mundend",
    "mundendstes": "mundend",
    "mundest": "munden",
    "mundet": "munden",
    "mundete": "munden",
    "mundeten": "munden",
    "mundetest": "munden",
    "mundetet": "munden",
    "mundgerechte": "mundgerecht",
    "mundgerechtem": "mundgerecht",
    "mundgerechten": "mundgerecht",
    "mundgerechter": "mundgerecht",
    "mundgerechtere": "mundgerecht",
    "mundgerechterem": "mundgerecht",
    "mundgerechteren": "mundgerecht",
    "mundgerechterer": "mundgerecht",
    "mundgerechteres": "mundgerecht",
    "mundgerechtes": "mundgerecht",
    "mundgerechteste": "mundgerecht",
    "mundgerechtestem": "mundgerecht",
    "mundgerechtesten": "mundgerecht",
    "mundgerechtester": "mundgerecht",
    "mundgerechtestes": "mundgerecht",
    "munkele": "munkeln",
    "munkelnd": "munkeln",
    "munkelnde": "munkelnd",
    "munkelndem": "munkelnd",
    "munkelnden": "munkelnd",
    "munkelnder": "munkelnd",
    "munkelndere": "munkelnd",
    "munkelnderem": "munkelnd",
    "munkelnderen": "munkelnd",
    "munkelnderer": "munkelnd",
    "munkelnderes": "munkelnd",
    "munkelndes": "munkelnd",
    "munkelndste": "munkelnd",
    "munkelndstem": "munkelnd",
    "munkelndsten": "munkelnd",
    "munkelndster": "munkelnd",
    "munkelndstes": "munkelnd",
    "munkelst": "munkeln",
    "munkelt": "munkeln",
    "munkelte": "munkeln",
    "munkelten": "munkeln",
    "munkeltest": "munkeln",
    "munkeltet": "munkeln",
    "munkle": "munkeln",
    "muntere": "muntern",
    "munternd": "muntern",
    "munternde": "munternd",
    "munterndem": "munternd",
    "munternden": "munternd",
    "munternder": "munternd",
    "munterndes": "munternd",
    "munterst": "muntern",
    "muntert": "muntern",
    "munterte": "muntern",
    "munterten": "muntern",
    "muntertest": "muntern",
    "muntertet": "muntern",
    "murkse": "murksen",
    "murksend": "murksen",
    "murksende": "murksend",
    "murksendem": "murksend",
    "murksenden": "murksend",
    "murksender": "murksend",
    "murksendes": "murksend",
    "murksest": "murksen",
    "murkset": "murksen",
    "murkst": "murksen",
    "murkste": "murksen",
    "murksten": "murksen",
    "murkstest": "murksen",
    "murkstet": "murksen",
    "murmele": "murmeln",
    "murmelnd": "murmeln",
    "murmelnde": "murmelnd",
    "murmelndem": "murmelnd",
    "murmelnden": "murmelnd",
    "murmelnder": "murmelnd",
    "murmelndes": "murmelnd",
    "murmelst": "murmeln",
    "murmelt": "murmeln",
    "murmelte": "murmeln",
    "murmelten": "murmeln",
    "murmeltest": "murmeln",
    "murmeltet": "murmeln",
    "murmle": "murmeln",
    "murre": "murren",
    "murrend": "murren",
    "murrende": "murrend",
    "murrendem": "murrend",
    "murrenden": "murrend",
    "murrender": "murrend",
    "murrendere": "murrend",
    "murrenderem": "murrend",
    "murrenderen": "murrend",
    "murrenderer": "murrend",
    "murrenderes": "murrend",
    "murrendes": "murrend",
    "murrendste": "murrend",
    "murrendstem": "murrend",
    "murrendsten": "murrend",
    "murrendster": "murrend",
    "murrendstes": "murrend",
    "murrest": "murren",
    "murret": "murren",
    "murrst": "murren",
    "murrt": "murren",
    "murrte": "murren",
    "murrten": "murren",
    "murrtest": "murren",
    "murrtet": "murren",
    "musikalischem": "musikalisch",
    "musikalischen": "musikalisch",
    "musikalischer": "musikalisch",
    "musikalischere": "musikalisch",
    "musikalischerem": "musikalisch",
    "musikalischeren": "musikalisch",
    "musikalischerer": "musikalisch",
    "musikalischeres": "musikalisch",
    "musikalisches": "musikalisch",
    "musikalischste": "musikalisch",
    "musikalischstem": "musikalisch",
    "musikalischsten": "musikalisch",
    "musikalischster": "musikalisch",
    "musikalischstes": "musikalisch",
    "musischem": "musisch",
    "musischen": "musisch",
    "musischer": "musisch",
    "musischere": "musisch",
    "musischerem": "musisch",
    "musischeren": "musisch",
    "musischerer": "musisch",
    "musischeres": "musisch",
    "musisches": "musisch",
    "musischste": "musisch",
    "musischstem": "musisch",
    "musischsten": "musisch",
    "musischster": "musisch",
    "musischstes": "musisch",
    "musiziere": "musizieren",
    "musizierend": "musizieren",
    "musizierende": "musizierend",
    "musizierendem": "musizierend",
    "musizierenden": "musizierend",
    "musizierender": "musizierend",
    "musizierendes": "musizierend",
    "musizierest": "musizieren",
    "musizieret": "musizieren",
    "musizierst": "musizieren",
    "musiziert": "musizieren",
    "musizierte": "musizieren",
    "musiziertem": "musiziert",
    "musizierten": "musizieren",
    "musizierter": "musiziert",
    "musiziertes": "musiziert",
    "musiziertest": "musizieren",
    "musiziertet": "musizieren",
    "muskulärem": "muskulär",
    "muskulären": "muskulär",
    "muskulärer": "muskulär",
    "muskulärere": "muskulär",
    "muskulärerem": "muskulär",
    "muskuläreren": "muskulär",
    "muskulärerer": "muskulär",
    "muskuläreres": "muskulär",
    "muskuläres": "muskulär",
    "muskulärste": "muskulär",
    "muskulärstem": "muskulär",
    "muskulärsten": "muskulär",
    "muskulärster": "muskulär",
    "muskulärstes": "muskulär",
    "muskulöse": "muskulös",
    "muskulösem": "muskulös",
    "muskulösen": "muskulös",
    "muskulöser": "muskulös",
    "muskulösere": "muskulös",
    "muskulöserem": "muskulös",
    "muskulöseren": "muskulös",
    "muskulöserer": "muskulös",
    "muskulöseres": "muskulös",
    "muskulöses": "muskulös",
    "muskulöseste": "muskulös",
    "muskulösestem": "muskulös",
    "muskulösesten": "muskulös",
    "muskulösester": "muskulös",
    "muskulösestes": "muskulös",
    "muslimischem": "muslimisch",
    "muslimischen": "muslimisch",
    "muslimischer": "muslimisch",
    "muslimisches": "muslimisch",
    "mustere": "mustern",
    "mustergültige": "mustergültig",
    "mustergültigem": "mustergültig",
    "mustergültigen": "mustergültig",
    "mustergültiger": "mustergültig",
    "mustergültigere": "mustergültig",
    "mustergültigerem": "mustergültig",
    "mustergültigeren": "mustergültig",
    "mustergültigerer": "mustergültig",
    "mustergültigeres": "mustergültig",
    "mustergültiges": "mustergültig",
    "mustergültigste": "mustergültig",
    "mustergültigstem": "mustergültig",
    "mustergültigsten": "mustergültig",
    "mustergültigster": "mustergültig",
    "mustergültigstes": "mustergültig",
    "musternd": "mustern",
    "musternde": "musternd",
    "musterndem": "musternd",
    "musternden": "musternd",
    "musternder": "musternd",
    "musterndere": "musternd",
    "musternderem": "musternd",
    "musternderen": "musternd",
    "musternderer": "musternd",
    "musternderes": "musternd",
    "musterndes": "musternd",
    "musterndste": "musternd",
    "musterndstem": "musternd",
    "musterndsten": "musternd",
    "musterndster": "musternd",
    "musterndstes": "musternd",
    "musterst": "mustern",
    "mustert": "mustern",
    "musterte": "mustern",
    "musterten": "mustern",
    "mustertest": "mustern",
    "mustertet": "mustern",
    "mutend": "muten",
    "mutende": "mutend",
    "mutendem": "mutend",
    "mutenden": "mutend",
    "mutender": "mutend",
    "mutendes": "mutend",
    "mutest": "muten",
    "mutet": "muten",
    "mutete": "muten",
    "muteten": "muten",
    "mutetest": "muten",
    "mutetet": "muten",
    "mutiere": "mutieren",
    "mutierend": "mutieren",
    "mutierende": "mutierend",
    "mutierendem": "mutierend",
    "mutierenden": "mutierend",
    "mutierender": "mutierend",
    "mutierendere": "mutierend",
    "mutierenderem": "mutierend",
    "mutierenderen": "mutierend",
    "mutierenderer": "mutierend",
    "mutierenderes": "mutierend",
    "mutierendes": "mutierend",
    "mutierendste": "mutierend",
    "mutierendstem": "mutierend",
    "mutierendsten": "mutierend",
    "mutierendster": "mutierend",
    "mutierendstes": "mutierend",
    "mutierest": "mutieren",
    "mutieret": "mutieren",
    "mutierst": "mutieren",
    "mutiert": "mutieren",
    "mutierte": "mutieren",
    "mutiertem": "mutiert",
    "mutierten": "mutieren",
    "mutierter": "mutiert",
    "mutiertere": "mutiert",
    "mutierterem": "mutiert",
    "mutierteren": "mutiert",
    "mutierterer": "mutiert",
    "mutierteres": "mutiert",
    "mutiertes": "mutiert",
    "mutiertest": "mutieren",
    "mutierteste": "mutiert",
    "mutiertestem": "mutiert",
    "mutiertesten": "mutiert",
    "mutiertester": "mutiert",
    "mutiertestes": "mutiert",
    "mutiertet": "mutieren",
    "mutige": "mutig",
    "mutigem": "mutig",
    "mutigen": "mutig",
    "mutiger": "mutig",
    "mutigere": "mutig",
    "mutigerem": "mutig",
    "mutigeren": "mutig",
    "mutigerer": "mutig",
    "mutigeres": "mutig",
    "mutiges": "mutig",
    "mutigste": "mutig",
    "mutigstem": "mutig",
    "mutigsten": "mutig",
    "mutigster": "mutig",
    "mutigstes": "mutig",
    "mutlose": "mutlos",
    "mutlosem": "mutlos",
    "mutlosen": "mutlos",
    "mutloser": "mutlos",
    "mutlosere": "mutlos",
    "mutloserem": "mutlos",
    "mutloseren": "mutlos",
    "mutloserer": "mutlos",
    "mutloseres": "mutlos",
    "mutloses": "mutlos",
    "mutloseste": "mutlos",
    "mutlosestem": "mutlos",
    "mutlosesten": "mutlos",
    "mutlosester": "mutlos",
    "mutlosestes": "mutlos",
    "mutmaße": "mutmaßen",
    "mutmaßend": "mutmaßen",
    "mutmaßende": "mutmaßend",
    "mutmaßendem": "mutmaßend",
    "mutmaßenden": "mutmaßend",
    "mutmaßender": "mutmaßend",
    "mutmaßendere": "mutmaßend",
    "mutmaßenderem": "mutmaßend",
    "mutmaßenderen": "mutmaßend",
    "mutmaßenderer": "mutmaßend",
    "mutmaßenderes": "mutmaßend",
    "mutmaßendes": "mutmaßend",
    "mutmaßendste": "mutmaßend",
    "mutmaßendstem": "mutmaßend",
    "mutmaßendsten": "mutmaßend",
    "mutmaßendster": "mutmaßend",
    "mutmaßendstes": "mutmaßend",
    "mutmaßest": "mutmaßen",
    "mutmaßet": "mutmaßen",
    "mutmaßliche": "mutmaßlich",
    "mutmaßlichem": "mutmaßlich",
    "mutmaßlichen": "mutmaßlich",
    "mutmaßlicher": "mutmaßlich",
    "mutmaßliches": "mutmaßlich",
    "mutmaßt": "mutmaßen",
    "mutmaßte": "mutmaßen",
    "mutmaßten": "mutmaßen",
    "mutmaßtest": "mutmaßen",
    "mutmaßtet": "mutmaßen",
    "mutwilligem": "mutwillig",
    "mutwilligen": "mutwillig",
    "mutwilliger": "mutwillig",
    "mutwilliges": "mutwillig",
    "mußt": "müssen",
    "mußte": "müssen",
    "mußten": "müssen",
    "mußtet": "müssen",
    "mysteriösem": "mysteriös",
    "mysteriösen": "mysteriös",
    "mysteriöser": "mysteriös",
    "mysteriösere": "mysteriös",
    "mysteriöserem": "mysteriös",
    "mysteriöseren": "mysteriös",
    "mysteriöserer": "mysteriös",
    "mysteriöseres": "mysteriös",
    "mysteriöses": "mysteriös",
    "mysteriöseste": "mysteriös",
    "mysteriösestem": "mysteriös",
    "mysteriösesten": "mysteriös",
    "mysteriösester": "mysteriös",
    "mysteriösestes": "mysteriös",
    "mystifizierend": "mystifizieren",
    "mystifizierende": "mystifizierend",
    "mystifizierendem": "mystifizierend",
    "mystifizierenden": "mystifizierend",
    "mystifizierender": "mystifizierend",
    "mystifizierendere": "mystifizierend",
    "mystifizierenderem": "mystifizierend",
    "mystifizierenderen": "mystifizierend",
    "mystifizierenderer": "mystifizierend",
    "mystifizierenderes": "mystifizierend",
    "mystifizierendes": "mystifizierend",
    "mystifizierendste": "mystifizierend",
    "mystifizierendstem": "mystifizierend",
    "mystifizierendsten": "mystifizierend",
    "mystifizierendster": "mystifizierend",
    "mystifizierendstes": "mystifizierend",
    "mystifizierest": "mystifizieren",
    "mystifizieret": "mystifizieren",
    "mystifizierst": "mystifizieren",
    "mystifiziert": "mystifizieren",
    "mystifizierte": "mystifizieren",
    "mystifiziertem": "mystifiziert",
    "mystifizierten": "mystifizieren",
    "mystifizierter": "mystifiziert",
    "mystifiziertere": "mystifiziert",
    "mystifizierterem": "mystifiziert",
    "mystifizierteren": "mystifiziert",
    "mystifizierterer": "mystifiziert",
    "mystifizierteres": "mystifiziert",
    "mystifiziertes": "mystifiziert",
    "mystifiziertest": "mystifizieren",
    "mystifizierteste": "mystifiziert",
    "mystifiziertestem": "mystifiziert",
    "mystifiziertesten": "mystifiziert",
    "mystifiziertester": "mystifiziert",
    "mystifiziertestes": "mystifiziert",
    "mystifiziertet": "mystifizieren",
    "mystischem": "mystisch",
    "mystischen": "mystisch",
    "mystischer": "mystisch",
    "mystischere": "mystisch",
    "mystischerem": "mystisch",
    "mystischeren": "mystisch",
    "mystischerer": "mystisch",
    "mystischeres": "mystisch",
    "mystisches": "mystisch",
    "mystischste": "mystisch",
    "mystischstem": "mystisch",
    "mystischsten": "mystisch",
    "mystischster": "mystisch",
    "mystischstes": "mystisch",
    "mächtigem": "mächtig",
    "mächtigen": "mächtig",
    "mächtiger": "mächtig",
    "mächtigere": "mächtig",
    "mächtigerem": "mächtig",
    "mächtigeren": "mächtig",
    "mächtigerer": "mächtig",
    "mächtigeres": "mächtig",
    "mächtiges": "mächtig",
    "mächtigste": "mächtig",
    "mächtigstem": "mächtig",
    "mächtigsten": "mächtig",
    "mächtigster": "mächtig",
    "mächtigstes": "mächtig",
    "mähdresche": "mähdreschen",
    "mähdreschend": "mähdreschen",
    "mähdreschende": "mähdreschend",
    "mähdreschendem": "mähdreschend",
    "mähdreschenden": "mähdreschend",
    "mähdreschender": "mähdreschend",
    "mähdreschendes": "mähdreschend",
    "mähdreschest": "mähdreschen",
    "mähdreschet": "mähdreschen",
    "mähdreschst": "mähdreschen",
    "mähdrescht": "mähdreschen",
    "mähdreschte": "mähdreschen",
    "mähdreschten": "mähdreschen",
    "mähdreschtest": "mähdreschen",
    "mähdreschtet": "mähdreschen",
    "mähe": "mähen",
    "mähend": "mähen",
    "mähende": "mähend",
    "mähendem": "mähend",
    "mähenden": "mähend",
    "mähender": "mähend",
    "mähendes": "mähend",
    "mähest": "mähen",
    "mähet": "mähen",
    "mähst": "mähen",
    "mäht": "mähen",
    "mähte": "mähen",
    "mähten": "mähen",
    "mähtest": "mähen",
    "mähtet": "mähen",
    "mäkele": "mäkeln",
    "mäkelnd": "mäkeln",
    "mäkelnde": "mäkelnd",
    "mäkelndem": "mäkelnd",
    "mäkelnden": "mäkelnd",
    "mäkelnder": "mäkelnd",
    "mäkelndere": "mäkelnd",
    "mäkelnderem": "mäkelnd",
    "mäkelnderen": "mäkelnd",
    "mäkelnderer": "mäkelnd",
    "mäkelnderes": "mäkelnd",
    "mäkelndes": "mäkelnd",
    "mäkelndste": "mäkelnd",
    "mäkelndstem": "mäkelnd",
    "mäkelndsten": "mäkelnd",
    "mäkelndster": "mäkelnd",
    "mäkelndstes": "mäkelnd",
    "mäkelst": "mäkeln",
    "mäkelt": "mäkeln",
    "mäkelte": "mäkeln",
    "mäkelten": "mäkeln",
    "mäkeltest": "mäkeln",
    "mäkeltet": "mäkeln",
    "mäkle": "mäkeln",
    "männlichem": "männlich",
    "männlichen": "männlich",
    "männlicher": "männlich",
    "männlichere": "männlich",
    "männlicherem": "männlich",
    "männlicheren": "männlich",
    "männlicherer": "männlich",
    "männlicheres": "männlich",
    "männliches": "männlich",
    "männlichstem": "männlich",
    "männlichsten": "männlich",
    "männlichster": "männlich",
    "männlichstes": "männlich",
    "märchenhaftem": "märchenhaft",
    "märchenhaften": "märchenhaft",
    "märchenhafter": "märchenhaft",
    "märchenhaftere": "märchenhaft",
    "märchenhafterem": "märchenhaft",
    "märchenhafteren": "märchenhaft",
    "märchenhafterer": "märchenhaft",
    "märchenhafteres": "märchenhaft",
    "märchenhaftes": "märchenhaft",
    "märchenhafteste": "märchenhaft",
    "märchenhaftestem": "märchenhaft",
    "märchenhaftesten": "märchenhaft",
    "märchenhaftester": "märchenhaft",
    "märchenhaftestes": "märchenhaft",
    "märkische": "märkisch",
    "märkischem": "märkisch",
    "märkischen": "märkisch",
    "märkischer": "märkisch",
    "märkisches": "märkisch",
    "mäste": "mästen",
    "mästend": "mästen",
    "mästende": "mästend",
    "mästendem": "mästend",
    "mästenden": "mästend",
    "mästender": "mästend",
    "mästendere": "mästend",
    "mästenderem": "mästend",
    "mästenderen": "mästend",
    "mästenderer": "mästend",
    "mästenderes": "mästend",
    "mästendes": "mästend",
    "mästendste": "mästend",
    "mästendstem": "mästend",
    "mästendsten": "mästend",
    "mästendster": "mästend",
    "mästendstes": "mästend",
    "mästest": "mästen",
    "mästet": "mästen",
    "mästete": "mästen",
    "mästeten": "mästen",
    "mästetest": "mästen",
    "mästetet": "mästen",
    "mäße": "messen",
    "mäßen": "messen",
    "mäßest": "messen",
    "mäßet": "messen",
    "mäßig": "mäßigen",
    "mäßige": "mäßigen",
    "mäßigem": "mäßig",
    "mäßigend": "mäßigen",
    "mäßigende": "mäßigend",
    "mäßigendem": "mäßigend",
    "mäßigenden": "mäßigend",
    "mäßigender": "mäßigend",
    "mäßigendes": "mäßigend",
    "mäßiger": "mäßig",
    "mäßigere": "mäßig",
    "mäßigerem": "mäßig",
    "mäßigeren": "mäßig",
    "mäßigerer": "mäßig",
    "mäßigeres": "mäßig",
    "mäßiges": "mäßig",
    "mäßigest": "mäßigen",
    "mäßiget": "mäßigen",
    "mäßigst": "mäßigen",
    "mäßigste": "mäßig",
    "mäßigstem": "mäßig",
    "mäßigsten": "mäßig",
    "mäßigster": "mäßig",
    "mäßigstes": "mäßig",
    "mäßigt": "mäßigen",
    "mäßigte": "mäßigen",
    "mäßigten": "mäßigen",
    "mäßigtest": "mäßigen",
    "mäßigtet": "mäßigen",
    "möbele": "möbeln",
    "möbelnd": "möbeln",
    "möbelnde": "möbelnd",
    "möbelndem": "möbelnd",
    "möbelnden": "möbelnd",
    "möbelnder": "möbelnd",
    "möbelndes": "möbelnd",
    "möbelst": "möbeln",
    "möbelt": "möbeln",
    "möbelte": "möbeln",
    "möbelten": "möbeln",
    "möbeltest": "möbeln",
    "möbeltet": "möbeln",
    "möble": "möbeln",
    "möbliere": "möblieren",
    "möblierend": "möblieren",
    "möblierende": "möblierend",
    "möblierendem": "möblierend",
    "möblierenden": "möblierend",
    "möblierender": "möblierend",
    "möblierendes": "möblierend",
    "möblierest": "möblieren",
    "möblieret": "möblieren",
    "möblierst": "möblieren",
    "möbliert": "möblieren",
    "möblierte": "möblieren",
    "möbliertem": "möbliert",
    "möblierten": "möblieren",
    "möblierter": "möbliert",
    "möbliertes": "möbliert",
    "möbliertest": "möblieren",
    "möbliertet": "möblieren",
    "möchte": "mögen",
    "möchten": "mögen",
    "möchtest": "mögen",
    "möchtet": "mögen",
    "möge": "mögen",
    "mögest": "mögen",
    "möget": "mögen",
    "mögliche": "möglich",
    "möglichem": "möglich",
    "möglichen": "möglich",
    "möglicher": "möglich",
    "möglichere": "möglich",
    "möglicherem": "möglich",
    "möglicheren": "möglich",
    "möglicherer": "möglich",
    "möglicheres": "möglich",
    "mögliches": "möglich",
    "möglichstem": "möglich",
    "möglichsten": "möglich",
    "möglichster": "möglich",
    "möglichstes": "möglich",
    "mögt": "mögen",
    "mölke": "melken",
    "mölken": "melken",
    "mölkest": "melken",
    "mölket": "melken",
    "mörderischem": "mörderisch",
    "mörderischen": "mörderisch",
    "mörderischer": "mörderisch",
    "mörderischere": "mörderisch",
    "mörderischerem": "mörderisch",
    "mörderischeren": "mörderisch",
    "mörderischerer": "mörderisch",
    "mörderischeres": "mörderisch",
    "mörderisches": "mörderisch",
    "mörderischste": "mörderisch",
    "mörderischstem": "mörderisch",
    "mörderischsten": "mörderisch",
    "mörderischster": "mörderisch",
    "mörderischstes": "mörderisch",
    "mörtele": "mörteln",
    "mörtelnd": "mörteln",
    "mörtelnde": "mörtelnd",
    "mörtelndem": "mörtelnd",
    "mörtelnden": "mörtelnd",
    "mörtelnder": "mörtelnd",
    "mörtelndes": "mörtelnd",
    "mörtelst": "mörteln",
    "mörtelt": "mörteln",
    "mörtelte": "mörteln",
    "mörtelten": "mörteln",
    "mörteltest": "mörteln",
    "mörteltet": "mörteln",
    "mörtle": "mörteln",
    "müdem": "müde",
    "müden": "müde",
    "müder": "müde",
    "müdere": "müde",
    "müderem": "müde",
    "müderen": "müde",
    "müderer": "müde",
    "müderes": "müde",
    "müdes": "müde",
    "müdeste": "müde",
    "müdestem": "müde",
    "müdesten": "müde",
    "müdester": "müde",
    "müdestes": "müde",
    "mühe": "mühen",
    "mühelosem": "mühelos",
    "mühelosen": "mühelos",
    "müheloser": "mühelos",
    "mühelosere": "mühelos",
    "müheloserem": "mühelos",
    "müheloseren": "mühelos",
    "müheloserer": "mühelos",
    "müheloseres": "mühelos",
    "müheloses": "mühelos",
    "müheloseste": "mühelos",
    "mühelosestem": "mühelos",
    "mühelosesten": "mühelos",
    "mühelosester": "mühelos",
    "mühelosestes": "mühelos",
    "mühend": "mühen",
    "mühende": "mühend",
    "mühendem": "mühend",
    "mühenden": "mühend",
    "mühender": "mühend",
    "mühendes": "mühend",
    "mühest": "mühen",
    "mühet": "mühen",
    "mühevolle": "mühevoll",
    "mühevollem": "mühevoll",
    "mühevollen": "mühevoll",
    "mühevoller": "mühevoll",
    "mühevollere": "mühevoll",
    "mühevollerem": "mühevoll",
    "mühevolleren": "mühevoll",
    "mühevollerer": "mühevoll",
    "mühevolleres": "mühevoll",
    "mühevolles": "mühevoll",
    "mühevollste": "mühevoll",
    "mühevollstem": "mühevoll",
    "mühevollsten": "mühevoll",
    "mühevollster": "mühevoll",
    "mühevollstes": "mühevoll",
    "mühsamem": "mühsam",
    "mühsamen": "mühsam",
    "mühsamer": "mühsam",
    "mühsamere": "mühsam",
    "mühsamerem": "mühsam",
    "mühsameren": "mühsam",
    "mühsamerer": "mühsam",
    "mühsameres": "mühsam",
    "mühsames": "mühsam",
    "mühsamste": "mühsam",
    "mühsamstem": "mühsam",
    "mühsamsten": "mühsam",
    "mühsamster": "mühsam",
    "mühsamstes": "mühsam",
    "mühselige": "mühselig",
    "mühseligem": "mühselig",
    "mühseligen": "mühselig",
    "mühseliger": "mühselig",
    "mühseligere": "mühselig",
    "mühseligerem": "mühselig",
    "mühseligeren": "mühselig",
    "mühseligerer": "mühselig",
    "mühseligeres": "mühselig",
    "mühseliges": "mühselig",
    "mühseligste": "mühselig",
    "mühseligstem": "mühselig",
    "mühseligsten": "mühselig",
    "mühseligster": "mühselig",
    "mühseligstes": "mühselig",
    "mühst": "mühen",
    "müht": "mühen",
    "mühte": "mühen",
    "mühten": "mühen",
    "mühtest": "mühen",
    "mühtet": "mühen",
    "mümmele": "mümmeln",
    "mümmelnd": "mümmeln",
    "mümmelnde": "mümmelnd",
    "mümmelndem": "mümmelnd",
    "mümmelnden": "mümmelnd",
    "mümmelnder": "mümmelnd",
    "mümmelndere": "mümmelnd",
    "mümmelnderem": "mümmelnd",
    "mümmelnderen": "mümmelnd",
    "mümmelnderer": "mümmelnd",
    "mümmelnderes": "mümmelnd",
    "mümmelndes": "mümmelnd",
    "mümmelndste": "mümmelnd",
    "mümmelndstem": "mümmelnd",
    "mümmelndsten": "mümmelnd",
    "mümmelndster": "mümmelnd",
    "mümmelndstes": "mümmelnd",
    "mümmelst": "mümmeln",
    "mümmelt": "mümmeln",
    "mümmelte": "mümmeln",
    "mümmelten": "mümmeln",
    "mümmeltest": "mümmeln",
    "mümmeltet": "mümmeln",
    "mümmle": "mümmeln",
    "münde": "münden",
    "mündend": "münden",
    "mündendem": "mündend",
    "mündender": "mündend",
    "mündendes": "mündend",
    "mündest": "münden",
    "mündet": "münden",
    "mündete": "münden",
    "mündeten": "münden",
    "mündetest": "münden",
    "mündetet": "münden",
    "mündigem": "mündig",
    "mündigen": "mündig",
    "mündiger": "mündig",
    "mündigere": "mündig",
    "mündigerem": "mündig",
    "mündigeren": "mündig",
    "mündigerer": "mündig",
    "mündigeres": "mündig",
    "mündiges": "mündig",
    "mündigste": "mündig",
    "mündigstem": "mündig",
    "mündigsten": "mündig",
    "mündigster": "mündig",
    "mündigstes": "mündig",
    "mündliche": "mündlich",
    "mündlichem": "mündlich",
    "mündlichen": "mündlich",
    "mündlicher": "mündlich",
    "mündliches": "mündlich",
    "münze": "münzen",
    "münzend": "münzen",
    "münzende": "münzend",
    "münzendem": "münzend",
    "münzenden": "münzend",
    "münzender": "münzend",
    "münzendes": "münzend",
    "münzest": "münzen",
    "münzet": "münzen",
    "münzt": "münzen",
    "münzte": "münzen",
    "münzten": "münzen",
    "münztest": "münzen",
    "münztet": "münzen",
    "mürbem": "mürbe",
    "mürben": "mürbe",
    "mürber": "mürbe",
    "mürbere": "mürbe",
    "mürberem": "mürbe",
    "mürberen": "mürbe",
    "mürberer": "mürbe",
    "mürberes": "mürbe",
    "mürbes": "mürbe",
    "mürbeste": "mürbe",
    "mürbestem": "mürbe",
    "mürbesten": "mürbe",
    "mürbester": "mürbe",
    "mürbestes": "mürbe",
    "mürrische": "mürrisch",
    "mürrischem": "mürrisch",
    "mürrischen": "mürrisch",
    "mürrischer": "mürrisch",
    "mürrischere": "mürrisch",
    "mürrischerem": "mürrisch",
    "mürrischeren": "mürrisch",
    "mürrischerer": "mürrisch",
    "mürrischeres": "mürrisch",
    "mürrisches": "mürrisch",
    "mürrischste": "mürrisch",
    "mürrischstem": "mürrisch",
    "mürrischsten": "mürrisch",
    "mürrischster": "mürrisch",
    "mürrischstes": "mürrisch",
    "müsse": "müssen",
    "müssest": "müssen",
    "müsset": "müssen",
    "mütterlichem": "mütterlich",
    "mütterlichen": "mütterlich",
    "mütterlicher": "mütterlich",
    "mütterliches": "mütterlich",
    "müßige": "müßig",
    "müßigem": "müßig",
    "müßigen": "müßig",
    "müßiger": "müßig",
    "müßigere": "müßig",
    "müßigerem": "müßig",
    "müßigeren": "müßig",
    "müßigerer": "müßig",
    "müßigeres": "müßig",
    "müßiges": "müßig",
    "müßigste": "müßig",
    "müßigstem": "müßig",
    "müßigsten": "müßig",
    "müßigster": "müßig",
    "müßigstes": "müßig",
    "müßt": "müssen",
    "müßte": "müssen",
    "müßten": "müssen",
    "müßtest": "müssen",
    "müßtet": "müssen",
    "nabele": "nabeln",
    "nabelnd": "nabeln",
    "nabelnde": "nabelnd",
    "nabelndem": "nabelnd",
    "nabelnden": "nabelnd",
    "nabelnder": "nabelnd",
    "nabelndes": "nabelnd",
    "nabelst": "nabeln",
    "nabelt": "nabeln",
    "nabelte": "nabeln",
    "nabelten": "nabeln",
    "nabeltest": "nabeln",
    "nabeltet": "nabeln",
    "nable": "nabeln",
    "nachahme": "nachahmen",
    "nachahmend": "nachahmen",
    "nachahmende": "nachahmend",
    "nachahmendem": "nachahmend",
    "nachahmenden": "nachahmend",
    "nachahmender": "nachahmend",
    "nachahmendere": "nachahmend",
    "nachahmenderem": "nachahmend",
    "nachahmenderen": "nachahmend",
    "nachahmenderer": "nachahmend",
    "nachahmenderes": "nachahmend",
    "nachahmendes": "nachahmend",
    "nachahmendste": "nachahmend",
    "nachahmendstem": "nachahmend",
    "nachahmendsten": "nachahmend",
    "nachahmendster": "nachahmend",
    "nachahmendstes": "nachahmend",
    "nachahmenswertem": "nachahmenswert",
    "nachahmenswerten": "nachahmenswert",
    "nachahmenswerter": "nachahmenswert",
    "nachahmenswertes": "nachahmenswert",
    "nachahmest": "nachahmen",
    "nachahmet": "nachahmen",
    "nachahmst": "nachahmen",
    "nachahmt": "nachahmen",
    "nachahmte": "nachahmen",
    "nachahmten": "nachahmen",
    "nachahmtest": "nachahmen",
    "nachahmtet": "nachahmen",
    "nacharbeite": "nacharbeiten",
    "nacharbeitend": "nacharbeiten",
    "nacharbeitende": "nacharbeitend",
    "nacharbeitendem": "nacharbeitend",
    "nacharbeitenden": "nacharbeitend",
    "nacharbeitender": "nacharbeitend",
    "nacharbeitendes": "nacharbeitend",
    "nacharbeitest": "nacharbeiten",
    "nacharbeitet": "nacharbeiten",
    "nacharbeitete": "nacharbeiten",
    "nacharbeiteten": "nacharbeiten",
    "nacharbeitetest": "nacharbeiten",
    "nacharbeitetet": "nacharbeiten",
    "nachaß": "nachessen",
    "nachaßen": "nachessen",
    "nachaßt": "nachessen",
    "nachbaue": "nachbauen",
    "nachbauend": "nachbauen",
    "nachbauende": "nachbauend",
    "nachbauendem": "nachbauend",
    "nachbauenden": "nachbauend",
    "nachbauender": "nachbauend",
    "nachbauendes": "nachbauend",
    "nachbauest": "nachbauen",
    "nachbauet": "nachbauen",
    "nachbaust": "nachbauen",
    "nachbaut": "nachbauen",
    "nachbaute": "nachbauen",
    "nachbauten": "nachbauen",
    "nachbautest": "nachbauen",
    "nachbautet": "nachbauen",
    "nachberechne": "nachberechnen",
    "nachberechnend": "nachberechnen",
    "nachberechnende": "nachberechnend",
    "nachberechnendem": "nachberechnend",
    "nachberechnenden": "nachberechnend",
    "nachberechnender": "nachberechnend",
    "nachberechnendes": "nachberechnend",
    "nachberechnest": "nachberechnen",
    "nachberechnet": "nachberechnen",
    "nachberechnete": "nachberechnen",
    "nachberechnetem": "nachberechnet",
    "nachberechneten": "nachberechnen",
    "nachberechneter": "nachberechnet",
    "nachberechnetes": "nachberechnet",
    "nachberechnetest": "nachberechnen",
    "nachberechnetet": "nachberechnen",
    "nachbereite": "nachbereiten",
    "nachbereitend": "nachbereiten",
    "nachbereitende": "nachbereitend",
    "nachbereitendem": "nachbereitend",
    "nachbereitenden": "nachbereitend",
    "nachbereitender": "nachbereitend",
    "nachbereitendes": "nachbereitend",
    "nachbereitest": "nachbereiten",
    "nachbereitet": "nachbereiten",
    "nachbereitete": "nachbereiten",
    "nachbereitetem": "nachbereitet",
    "nachbereiteten": "nachbereiten",
    "nachbereiteter": "nachbereitet",
    "nachbereitetere": "nachbereitet",
    "nachbereiteterem": "nachbereitet",
    "nachbereiteteren": "nachbereitet",
    "nachbereiteterer": "nachbereitet",
    "nachbereiteteres": "nachbereitet",
    "nachbereitetes": "nachbereitet",
    "nachbereitetest": "nachbereiten",
    "nachbereiteteste": "nachbereitet",
    "nachbereitetestem": "nachbereitet",
    "nachbereitetesten": "nachbereitet",
    "nachbereitetester": "nachbereitet",
    "nachbereitetestes": "nachbereitet",
    "nachbereitetet": "nachbereiten",
    "nachberitt": "nachbereiten",
    "nachberitte": "nachbereiten",
    "nachberitten": "nachbereiten",
    "nachberittest": "nachbereiten",
    "nachberittet": "nachbereiten",
    "nachbestelle": "nachbestellen",
    "nachbestellend": "nachbestellen",
    "nachbestellende": "nachbestellend",
    "nachbestellendem": "nachbestellend",
    "nachbestellenden": "nachbestellend",
    "nachbestellender": "nachbestellend",
    "nachbestellendes": "nachbestellend",
    "nachbestellest": "nachbestellen",
    "nachbestellet": "nachbestellen",
    "nachbestellst": "nachbestellen",
    "nachbestellt": "nachbestellen",
    "nachbestellte": "nachbestellen",
    "nachbestelltem": "nachbestellt",
    "nachbestellten": "nachbestellen",
    "nachbestellter": "nachbestellt",
    "nachbestelltes": "nachbestellt",
    "nachbestelltest": "nachbestellen",
    "nachbestelltet": "nachbestellen",
    "nachbete": "nachbeten",
    "nachbetend": "nachbeten",
    "nachbetende": "nachbetend",
    "nachbetendem": "nachbetend",
    "nachbetenden": "nachbetend",
    "nachbetender": "nachbetend",
    "nachbetendes": "nachbetend",
    "nachbetest": "nachbeten",
    "nachbetet": "nachbeten",
    "nachbetete": "nachbeten",
    "nachbeteten": "nachbeten",
    "nachbetetest": "nachbeten",
    "nachbetetet": "nachbeten",
    "nachbildend": "nachbilden",
    "nachbildende": "nachbildend",
    "nachbildendem": "nachbildend",
    "nachbildenden": "nachbildend",
    "nachbildender": "nachbildend",
    "nachbildendere": "nachbildend",
    "nachbildenderem": "nachbildend",
    "nachbildenderen": "nachbildend",
    "nachbildenderer": "nachbildend",
    "nachbildenderes": "nachbildend",
    "nachbildendes": "nachbildend",
    "nachbildendste": "nachbildend",
    "nachbildendstem": "nachbildend",
    "nachbildendsten": "nachbildend",
    "nachbildendster": "nachbildend",
    "nachbildendstes": "nachbildend",
    "nachbildest": "nachbilden",
    "nachbildet": "nachbilden",
    "nachbildete": "nachbilden",
    "nachbildeten": "nachbilden",
    "nachbildetest": "nachbilden",
    "nachbildetet": "nachbilden",
    "nachbleibe": "nachbleiben",
    "nachbleibend": "nachbleiben",
    "nachbleibende": "nachbleibend",
    "nachbleibendem": "nachbleibend",
    "nachbleibenden": "nachbleibend",
    "nachbleibender": "nachbleibend",
    "nachbleibendes": "nachbleibend",
    "nachbleibest": "nachbleiben",
    "nachbleibet": "nachbleiben",
    "nachbleibst": "nachbleiben",
    "nachbleibt": "nachbleiben",
    "nachbleiche": "nachbleichen",
    "nachbleichend": "nachbleichen",
    "nachbleichende": "nachbleichend",
    "nachbleichendem": "nachbleichend",
    "nachbleichenden": "nachbleichend",
    "nachbleichender": "nachbleichend",
    "nachbleichendes": "nachbleichend",
    "nachbleichest": "nachbleichen",
    "nachbleichet": "nachbleichen",
    "nachbleichst": "nachbleichen",
    "nachbleicht": "nachbleichen",
    "nachblich": "nachbleichen",
    "nachbliche": "nachbleichen",
    "nachblichen": "nachbleichen",
    "nachblichest": "nachbleichen",
    "nachblichet": "nachbleichen",
    "nachblichst": "nachbleichen",
    "nachblicht": "nachbleichen",
    "nachblicke": "nachblicken",
    "nachblickend": "nachblicken",
    "nachblickende": "nachblickend",
    "nachblickendem": "nachblickend",
    "nachblickenden": "nachblickend",
    "nachblickender": "nachblickend",
    "nachblickendere": "nachblickend",
    "nachblickenderem": "nachblickend",
    "nachblickenderen": "nachblickend",
    "nachblickenderer": "nachblickend",
    "nachblickenderes": "nachblickend",
    "nachblickendes": "nachblickend",
    "nachblickendste": "nachblickend",
    "nachblickendstem": "nachblickend",
    "nachblickendsten": "nachblickend",
    "nachblickendster": "nachblickend",
    "nachblickendstes": "nachblickend",
    "nachblickest": "nachblicken",
    "nachblicket": "nachblicken",
    "nachblickst": "nachblicken",
    "nachblickt": "nachblicken",
    "nachblickte": "nachblicken",
    "nachblickten": "nachblicken",
    "nachblicktest": "nachblicken",
    "nachblicktet": "nachblicken",
    "nachblieb": "nachbleiben",
    "nachbliebe": "nachbleiben",
    "nachblieben": "nachbleiben",
    "nachbliebest": "nachbleiben",
    "nachbliebet": "nachbleiben",
    "nachbliebst": "nachbleiben",
    "nachbliebt": "nachbleiben",
    "nachblute": "nachbluten",
    "nachblutend": "nachbluten",
    "nachblutende": "nachblutend",
    "nachblutendem": "nachblutend",
    "nachblutenden": "nachblutend",
    "nachblutender": "nachblutend",
    "nachblutendes": "nachblutend",
    "nachblutest": "nachbluten",
    "nachblutet": "nachbluten",
    "nachblutete": "nachbluten",
    "nachbluteten": "nachbluten",
    "nachblutetest": "nachbluten",
    "nachblutetet": "nachbluten",
    "nachbohre": "nachbohren",
    "nachbohrend": "nachbohren",
    "nachbohrende": "nachbohrend",
    "nachbohrendem": "nachbohrend",
    "nachbohrenden": "nachbohrend",
    "nachbohrender": "nachbohrend",
    "nachbohrendes": "nachbohrend",
    "nachbohrest": "nachbohren",
    "nachbohret": "nachbohren",
    "nachbohrst": "nachbohren",
    "nachbohrt": "nachbohren",
    "nachbohrte": "nachbohren",
    "nachbohrten": "nachbohren",
    "nachbohrtest": "nachbohren",
    "nachbohrtet": "nachbohren",
    "nachbrachte": "nachbringen",
    "nachbrachten": "nachbringen",
    "nachbrachtest": "nachbringen",
    "nachbrachtet": "nachbringen",
    "nachbringe": "nachbringen",
    "nachbringend": "nachbringen",
    "nachbringende": "nachbringend",
    "nachbringendem": "nachbringend",
    "nachbringenden": "nachbringend",
    "nachbringender": "nachbringend",
    "nachbringendes": "nachbringend",
    "nachbringest": "nachbringen",
    "nachbringet": "nachbringen",
    "nachbringst": "nachbringen",
    "nachbringt": "nachbringen",
    "nachbrächte": "nachbringen",
    "nachbrächten": "nachbringen",
    "nachbrächtest": "nachbringen",
    "nachbrächtet": "nachbringen",
    "nachdachte": "nachdenken",
    "nachdachten": "nachdenken",
    "nachdachtest": "nachdenken",
    "nachdachtet": "nachdenken",
    "nachdatiere": "nachdatieren",
    "nachdatierend": "nachdatieren",
    "nachdatierende": "nachdatierend",
    "nachdatierendem": "nachdatierend",
    "nachdatierenden": "nachdatierend",
    "nachdatierender": "nachdatierend",
    "nachdatierendes": "nachdatierend",
    "nachdatierest": "nachdatieren",
    "nachdatieret": "nachdatieren",
    "nachdatierst": "nachdatieren",
    "nachdatiert": "nachdatieren",
    "nachdatierte": "nachdatieren",
    "nachdatiertem": "nachdatiert",
    "nachdatierten": "nachdatieren",
    "nachdatierter": "nachdatiert",
    "nachdatiertes": "nachdatiert",
    "nachdatiertest": "nachdatieren",
    "nachdatiertet": "nachdatieren",
    "nachdenke": "nachdenken",
    "nachdenkend": "nachdenken",
    "nachdenkende": "nachdenkend",
    "nachdenkendem": "nachdenkend",
    "nachdenkenden": "nachdenkend",
    "nachdenkender": "nachdenkend",
    "nachdenkendere": "nachdenkend",
    "nachdenkenderem": "nachdenkend",
    "nachdenkenderen": "nachdenkend",
    "nachdenkenderer": "nachdenkend",
    "nachdenkenderes": "nachdenkend",
    "nachdenkendes": "nachdenkend",
    "nachdenkendste": "nachdenkend",
    "nachdenkendstem": "nachdenkend",
    "nachdenkendsten": "nachdenkend",
    "nachdenkendster": "nachdenkend",
    "nachdenkendstes": "nachdenkend",
    "nachdenkest": "nachdenken",
    "nachdenket": "nachdenken",
    "nachdenkliche": "nachdenklich",
    "nachdenklichem": "nachdenklich",
    "nachdenklichen": "nachdenklich",
    "nachdenklicher": "nachdenklich",
    "nachdenklichere": "nachdenklich",
    "nachdenklicherem": "nachdenklich",
    "nachdenklicheren": "nachdenklich",
    "nachdenklicherer": "nachdenklich",
    "nachdenklicheres": "nachdenklich",
    "nachdenkliches": "nachdenklich",
    "nachdenklichste": "nachdenklich",
    "nachdenklichstem": "nachdenklich",
    "nachdenklichsten": "nachdenklich",
    "nachdenklichster": "nachdenklich",
    "nachdenklichstes": "nachdenklich",
    "nachdenkst": "nachdenken",
    "nachdenkt": "nachdenken",
    "nachdichte": "nachdichten",
    "nachdichtend": "nachdichten",
    "nachdichtende": "nachdichtend",
    "nachdichtendem": "nachdichtend",
    "nachdichtenden": "nachdichtend",
    "nachdichtender": "nachdichtend",
    "nachdichtendes": "nachdichtend",
    "nachdichtest": "nachdichten",
    "nachdichtet": "nachdichten",
    "nachdichtete": "nachdichten",
    "nachdichteten": "nachdichten",
    "nachdichtetest": "nachdichten",
    "nachdichtetet": "nachdichten",
    "nachdrang": "nachdringen",
    "nachdrangen": "nachdringen",
    "nachdrangst": "nachdringen",
    "nachdrangt": "nachdringen",
    "nachdringe": "nachdringen",
    "nachdringend": "nachdringen",
    "nachdringende": "nachdringend",
    "nachdringendem": "nachdringend",
    "nachdringenden": "nachdringend",
    "nachdringender": "nachdringend",
    "nachdringendes": "nachdringend",
    "nachdringest": "nachdringen",
    "nachdringet": "nachdringen",
    "nachdringst": "nachdringen",
    "nachdringt": "nachdringen",
    "nachdruckend": "nachdrucken",
    "nachdruckende": "nachdruckend",
    "nachdruckendem": "nachdruckend",
    "nachdruckenden": "nachdruckend",
    "nachdruckender": "nachdruckend",
    "nachdruckendes": "nachdruckend",
    "nachdruckest": "nachdrucken",
    "nachdrucket": "nachdrucken",
    "nachdruckst": "nachdrucken",
    "nachdruckt": "nachdrucken",
    "nachdruckte": "nachdrucken",
    "nachdruckten": "nachdrucken",
    "nachdrucktest": "nachdrucken",
    "nachdrucktet": "nachdrucken",
    "nachdränge": "nachdringen",
    "nachdrängen": "nachdringen",
    "nachdrängend": "nachdrängen",
    "nachdrängende": "nachdrängend",
    "nachdrängendem": "nachdrängend",
    "nachdrängenden": "nachdrängend",
    "nachdrängender": "nachdrängend",
    "nachdrängendes": "nachdrängend",
    "nachdrängest": "nachdringen",
    "nachdränget": "nachdringen",
    "nachdrängst": "nachdrängen",
    "nachdrängt": "nachdrängen",
    "nachdrängte": "nachdrängen",
    "nachdrängten": "nachdrängen",
    "nachdrängtest": "nachdrängen",
    "nachdrängtet": "nachdrängen",
    "nachdrückliche": "nachdrücklich",
    "nachdrücklichem": "nachdrücklich",
    "nachdrücklichen": "nachdrücklich",
    "nachdrücklicher": "nachdrücklich",
    "nachdrückliches": "nachdrücklich",
    "nachdunkele": "nachdunkeln",
    "nachdunkelnd": "nachdunkeln",
    "nachdunkelnde": "nachdunkelnd",
    "nachdunkelndem": "nachdunkelnd",
    "nachdunkelnden": "nachdunkelnd",
    "nachdunkelnder": "nachdunkelnd",
    "nachdunkelndere": "nachdunkelnd",
    "nachdunkelnderem": "nachdunkelnd",
    "nachdunkelnderen": "nachdunkelnd",
    "nachdunkelnderer": "nachdunkelnd",
    "nachdunkelnderes": "nachdunkelnd",
    "nachdunkelndes": "nachdunkelnd",
    "nachdunkelndste": "nachdunkelnd",
    "nachdunkelndstem": "nachdunkelnd",
    "nachdunkelndsten": "nachdunkelnd",
    "nachdunkelndster": "nachdunkelnd",
    "nachdunkelndstes": "nachdunkelnd",
    "nachdunkelst": "nachdunkeln",
    "nachdunkelt": "nachdunkeln",
    "nachdunkelte": "nachdunkeln",
    "nachdunkelten": "nachdunkeln",
    "nachdunkeltest": "nachdunkeln",
    "nachdunkeltet": "nachdunkeln",
    "nachdunkle": "nachdunkeln",
    "nachdächte": "nachdenken",
    "nachdächten": "nachdenken",
    "nachdächtest": "nachdenken",
    "nachdächtet": "nachdenken",
    "nacheifere": "nacheifern",
    "nacheifernd": "nacheifern",
    "nacheifernde": "nacheifernd",
    "nacheiferndem": "nacheifernd",
    "nacheifernden": "nacheifernd",
    "nacheifernder": "nacheifernd",
    "nacheiferndes": "nacheifernd",
    "nacheiferst": "nacheifern",
    "nacheifert": "nacheifern",
    "nacheiferte": "nacheifern",
    "nacheiferten": "nacheifern",
    "nacheifertest": "nacheifern",
    "nacheifertet": "nacheifern",
    "nacheile": "nacheilen",
    "nacheilend": "nacheilen",
    "nacheilende": "nacheilend",
    "nacheilendem": "nacheilend",
    "nacheilenden": "nacheilend",
    "nacheilender": "nacheilend",
    "nacheilendes": "nacheilend",
    "nacheilest": "nacheilen",
    "nacheilet": "nacheilen",
    "nacheilst": "nacheilen",
    "nacheilt": "nacheilen",
    "nacheilte": "nacheilen",
    "nacheilten": "nacheilen",
    "nacheiltest": "nacheilen",
    "nacheiltet": "nacheilen",
    "nachempfand": "nachempfinden",
    "nachempfanden": "nachempfinden",
    "nachempfandest": "nachempfinden",
    "nachempfandet": "nachempfinden",
    "nachempfinde": "nachempfinden",
    "nachempfindend": "nachempfinden",
    "nachempfindende": "nachempfindend",
    "nachempfindendem": "nachempfindend",
    "nachempfindenden": "nachempfindend",
    "nachempfindender": "nachempfindend",
    "nachempfindendere": "nachempfindend",
    "nachempfindenderem": "nachempfindend",
    "nachempfindenderen": "nachempfindend",
    "nachempfindenderer": "nachempfindend",
    "nachempfindenderes": "nachempfindend",
    "nachempfindendes": "nachempfindend",
    "nachempfindendste": "nachempfindend",
    "nachempfindendstem": "nachempfindend",
    "nachempfindendsten": "nachempfindend",
    "nachempfindendster": "nachempfindend",
    "nachempfindendstes": "nachempfindend",
    "nachempfindest": "nachempfinden",
    "nachempfindet": "nachempfinden",
    "nachempfunden": "nachempfinden",
    "nachempfundene": "nachempfunden",
    "nachempfundenem": "nachempfunden",
    "nachempfundenen": "nachempfunden",
    "nachempfundener": "nachempfunden",
    "nachempfundenere": "nachempfunden",
    "nachempfundenerem": "nachempfunden",
    "nachempfundeneren": "nachempfunden",
    "nachempfundenerer": "nachempfunden",
    "nachempfundeneres": "nachempfunden",
    "nachempfundenes": "nachempfunden",
    "nachempfundenste": "nachempfunden",
    "nachempfundenstem": "nachempfunden",
    "nachempfundensten": "nachempfunden",
    "nachempfundenster": "nachempfunden",
    "nachempfundenstes": "nachempfunden",
    "nachempfände": "nachempfinden",
    "nachempfänden": "nachempfinden",
    "nachempfändest": "nachempfinden",
    "nachempfändet": "nachempfinden",
    "nacherzähle": "nacherzählen",
    "nacherzählend": "nacherzählen",
    "nacherzählende": "nacherzählend",
    "nacherzählendem": "nacherzählend",
    "nacherzählenden": "nacherzählend",
    "nacherzählender": "nacherzählend",
    "nacherzählendes": "nacherzählend",
    "nacherzählest": "nacherzählen",
    "nacherzählet": "nacherzählen",
    "nacherzählst": "nacherzählen",
    "nacherzählt": "nacherzählen",
    "nacherzählte": "nacherzählen",
    "nacherzähltem": "nacherzählt",
    "nacherzählten": "nacherzählen",
    "nacherzählter": "nacherzählt",
    "nacherzähltes": "nacherzählt",
    "nacherzähltest": "nacherzählen",
    "nacherzähltet": "nacherzählen",
    "nachesse": "nachessen",
    "nachessend": "nachessen",
    "nachessende": "nachessend",
    "nachessendem": "nachessend",
    "nachessenden": "nachessend",
    "nachessender": "nachessend",
    "nachessendes": "nachessend",
    "nachessest": "nachessen",
    "nachesset": "nachessen",
    "nacheßt": "nachessen",
    "nachfahre": "nachfahren",
    "nachfahrend": "nachfahren",
    "nachfahrende": "nachfahrend",
    "nachfahrendem": "nachfahrend",
    "nachfahrenden": "nachfahrend",
    "nachfahrender": "nachfahrend",
    "nachfahrendes": "nachfahrend",
    "nachfahrest": "nachfahren",
    "nachfahret": "nachfahren",
    "nachfahrt": "nachfahren",
    "nachfasse": "nachfassen",
    "nachfassend": "nachfassen",
    "nachfassende": "nachfassend",
    "nachfassendem": "nachfassend",
    "nachfassenden": "nachfassend",
    "nachfassender": "nachfassend",
    "nachfassendes": "nachfassend",
    "nachfassest": "nachfassen",
    "nachfasset": "nachfassen",
    "nachfaßt": "nachfassen",
    "nachfaßte": "nachfassen",
    "nachfaßten": "nachfassen",
    "nachfaßtest": "nachfassen",
    "nachfaßtet": "nachfassen",
    "nachfeiere": "nachfeiern",
    "nachfeiernd": "nachfeiern",
    "nachfeiernde": "nachfeiernd",
    "nachfeierndem": "nachfeiernd",
    "nachfeiernden": "nachfeiernd",
    "nachfeiernder": "nachfeiernd",
    "nachfeierndes": "nachfeiernd",
    "nachfeierst": "nachfeiern",
    "nachfeiert": "nachfeiern",
    "nachfeierte": "nachfeiern",
    "nachfeierten": "nachfeiern",
    "nachfeiertest": "nachfeiern",
    "nachfeiertet": "nachfeiern",
    "nachfilme": "nachfilmen",
    "nachfilmend": "nachfilmen",
    "nachfilmende": "nachfilmend",
    "nachfilmendem": "nachfilmend",
    "nachfilmenden": "nachfilmend",
    "nachfilmender": "nachfilmend",
    "nachfilmendes": "nachfilmend",
    "nachfilmest": "nachfilmen",
    "nachfilmet": "nachfilmen",
    "nachfilmst": "nachfilmen",
    "nachfilmt": "nachfilmen",
    "nachfilmte": "nachfilmen",
    "nachfilmten": "nachfilmen",
    "nachfilmtest": "nachfilmen",
    "nachfilmtet": "nachfilmen",
    "nachfolge": "nachfolgen",
    "nachfolgend": "nachfolgen",
    "nachfolgende": "nachfolgend",
    "nachfolgendem": "nachfolgend",
    "nachfolgenden": "nachfolgend",
    "nachfolgender": "nachfolgend",
    "nachfolgendes": "nachfolgend",
    "nachfolgest": "nachfolgen",
    "nachfolget": "nachfolgen",
    "nachfolgst": "nachfolgen",
    "nachfolgt": "nachfolgen",
    "nachfolgte": "nachfolgen",
    "nachfolgten": "nachfolgen",
    "nachfolgtest": "nachfolgen",
    "nachfolgtet": "nachfolgen",
    "nachfordere": "nachfordern",
    "nachfordernd": "nachfordern",
    "nachfordernde": "nachfordernd",
    "nachforderndem": "nachfordernd",
    "nachfordernden": "nachfordernd",
    "nachfordernder": "nachfordernd",
    "nachforderndes": "nachfordernd",
    "nachforderst": "nachfordern",
    "nachfordert": "nachfordern",
    "nachforderte": "nachfordern",
    "nachforderten": "nachfordern",
    "nachfordertest": "nachfordern",
    "nachfordertet": "nachfordern",
    "nachforsche": "nachforschen",
    "nachforschend": "nachforschen",
    "nachforschende": "nachforschend",
    "nachforschendem": "nachforschend",
    "nachforschenden": "nachforschend",
    "nachforschender": "nachforschend",
    "nachforschendere": "nachforschend",
    "nachforschenderem": "nachforschend",
    "nachforschenderen": "nachforschend",
    "nachforschenderer": "nachforschend",
    "nachforschenderes": "nachforschend",
    "nachforschendes": "nachforschend",
    "nachforschendste": "nachforschend",
    "nachforschendstem": "nachforschend",
    "nachforschendsten": "nachforschend",
    "nachforschendster": "nachforschend",
    "nachforschendstes": "nachforschend",
    "nachforschest": "nachforschen",
    "nachforschet": "nachforschen",
    "nachforschst": "nachforschen",
    "nachforscht": "nachforschen",
    "nachforschte": "nachforschen",
    "nachforschten": "nachforschen",
    "nachforschtest": "nachforschen",
    "nachforschtet": "nachforschen",
    "nachfrage": "nachfragen",
    "nachfragend": "nachfragen",
    "nachfragende": "nachfragend",
    "nachfragendem": "nachfragend",
    "nachfragenden": "nachfragend",
    "nachfragender": "nachfragend",
    "nachfragendes": "nachfragend",
    "nachfragest": "nachfragen",
    "nachfraget": "nachfragen",
    "nachfragst": "nachfragen",
    "nachfragt": "nachfragen",
    "nachfragte": "nachfragen",
    "nachfragten": "nachfragen",
    "nachfragtest": "nachfragen",
    "nachfragtet": "nachfragen",
    "nachfuhr": "nachfahren",
    "nachfuhren": "nachfahren",
    "nachfuhrst": "nachfahren",
    "nachfuhrt": "nachfahren",
    "nachfährst": "nachfahren",
    "nachfährt": "nachfahren",
    "nachfühle": "nachfühlen",
    "nachfühlend": "nachfühlen",
    "nachfühlende": "nachfühlend",
    "nachfühlendem": "nachfühlend",
    "nachfühlenden": "nachfühlend",
    "nachfühlender": "nachfühlend",
    "nachfühlendere": "nachfühlend",
    "nachfühlenderem": "nachfühlend",
    "nachfühlenderen": "nachfühlend",
    "nachfühlenderer": "nachfühlend",
    "nachfühlenderes": "nachfühlend",
    "nachfühlendes": "nachfühlend",
    "nachfühlendste": "nachfühlend",
    "nachfühlendstem": "nachfühlend",
    "nachfühlendsten": "nachfühlend",
    "nachfühlendster": "nachfühlend",
    "nachfühlendstes": "nachfühlend",
    "nachfühlest": "nachfühlen",
    "nachfühlet": "nachfühlen",
    "nachfühlst": "nachfühlen",
    "nachfühlt": "nachfühlen",
    "nachfühlte": "nachfühlen",
    "nachfühlten": "nachfühlen",
    "nachfühltest": "nachfühlen",
    "nachfühltet": "nachfühlen",
    "nachführe": "nachfahren",
    "nachführen": "nachfahren",
    "nachführest": "nachfahren",
    "nachführet": "nachfahren",
    "nachfülle": "nachfüllen",
    "nachfüllend": "nachfüllen",
    "nachfüllende": "nachfüllend",
    "nachfüllendem": "nachfüllend",
    "nachfüllenden": "nachfüllend",
    "nachfüllender": "nachfüllend",
    "nachfüllendes": "nachfüllend",
    "nachfüllest": "nachfüllen",
    "nachfüllet": "nachfüllen",
    "nachfüllst": "nachfüllen",
    "nachfüllt": "nachfüllen",
    "nachfüllte": "nachfüllen",
    "nachfüllten": "nachfüllen",
    "nachfülltest": "nachfüllen",
    "nachfülltet": "nachfüllen",
    "nachgab": "nachgeben",
    "nachgaben": "nachgeben",
    "nachgabst": "nachgeben",
    "nachgabt": "nachgeben",
    "nachgeahmt": "nachahmen",
    "nachgeahmte": "nachgeahmt",
    "nachgeahmtem": "nachgeahmt",
    "nachgeahmten": "nachgeahmt",
    "nachgeahmter": "nachgeahmt",
    "nachgeahmtere": "nachgeahmt",
    "nachgeahmterem": "nachgeahmt",
    "nachgeahmteren": "nachgeahmt",
    "nachgeahmterer": "nachgeahmt",
    "nachgeahmteres": "nachgeahmt",
    "nachgeahmtes": "nachgeahmt",
    "nachgeahmteste": "nachgeahmt",
    "nachgeahmtestem": "nachgeahmt",
    "nachgeahmtesten": "nachgeahmt",
    "nachgeahmtester": "nachgeahmt",
    "nachgeahmtestes": "nachgeahmt",
    "nachgearbeitet": "nacharbeiten",
    "nachgearbeitete": "nachgearbeitet",
    "nachgearbeitetem": "nachgearbeitet",
    "nachgearbeiteten": "nachgearbeitet",
    "nachgearbeiteter": "nachgearbeitet",
    "nachgearbeitetes": "nachgearbeitet",
    "nachgebaut": "nachbauen",
    "nachgebaute": "nachgebaut",
    "nachgebautem": "nachgebaut",
    "nachgebauten": "nachgebaut",
    "nachgebauter": "nachgebaut",
    "nachgebautes": "nachgebaut",
    "nachgebe": "nachgeben",
    "nachgebend": "nachgeben",
    "nachgebende": "nachgebend",
    "nachgebendem": "nachgebend",
    "nachgebenden": "nachgebend",
    "nachgebender": "nachgebend",
    "nachgebendere": "nachgebend",
    "nachgebenderem": "nachgebend",
    "nachgebenderen": "nachgebend",
    "nachgebenderer": "nachgebend",
    "nachgebenderes": "nachgebend",
    "nachgebendes": "nachgebend",
    "nachgebendste": "nachgebend",
    "nachgebendstem": "nachgebend",
    "nachgebendsten": "nachgebend",
    "nachgebendster": "nachgebend",
    "nachgebendstes": "nachgebend",
    "nachgebest": "nachgeben",
    "nachgebet": "nachgeben",
    "nachgebetet": "nachbeten",
    "nachgebetete": "nachgebetet",
    "nachgebetetem": "nachgebetet",
    "nachgebeteten": "nachgebetet",
    "nachgebeteter": "nachgebetet",
    "nachgebetetes": "nachgebetet",
    "nachgebildet": "nachbilden",
    "nachgebildete": "nachgebildet",
    "nachgebildetem": "nachgebildet",
    "nachgebildeten": "nachgebildet",
    "nachgebildeter": "nachgebildet",
    "nachgebildetere": "nachgebildet",
    "nachgebildeterem": "nachgebildet",
    "nachgebildeteren": "nachgebildet",
    "nachgebildeterer": "nachgebildet",
    "nachgebildeteres": "nachgebildet",
    "nachgebildetes": "nachgebildet",
    "nachgebildeteste": "nachgebildet",
    "nachgebildetestem": "nachgebildet",
    "nachgebildetesten": "nachgebildet",
    "nachgebildetester": "nachgebildet",
    "nachgebildetestes": "nachgebildet",
    "nachgeblichen": "nachbleichen",
    "nachgeblichene": "nachgeblichen",
    "nachgeblichenem": "nachgeblichen",
    "nachgeblichenen": "nachgeblichen",
    "nachgeblichener": "nachgeblichen",
    "nachgeblichenere": "nachgeblichen",
    "nachgeblichenerem": "nachgeblichen",
    "nachgeblicheneren": "nachgeblichen",
    "nachgeblichenerer": "nachgeblichen",
    "nachgeblicheneres": "nachgeblichen",
    "nachgeblichenes": "nachgeblichen",
    "nachgeblichenste": "nachgeblichen",
    "nachgeblichenstem": "nachgeblichen",
    "nachgeblichensten": "nachgeblichen",
    "nachgeblichenster": "nachgeblichen",
    "nachgeblichenstes": "nachgeblichen",
    "nachgeblickt": "nachblicken",
    "nachgeblickte": "nachgeblickt",
    "nachgeblicktem": "nachgeblickt",
    "nachgeblickten": "nachgeblickt",
    "nachgeblickter": "nachgeblickt",
    "nachgeblicktere": "nachgeblickt",
    "nachgeblickterem": "nachgeblickt",
    "nachgeblickteren": "nachgeblickt",
    "nachgeblickterer": "nachgeblickt",
    "nachgeblickteres": "nachgeblickt",
    "nachgeblicktes": "nachgeblickt",
    "nachgeblickteste": "nachgeblickt",
    "nachgeblicktestem": "nachgeblickt",
    "nachgeblicktesten": "nachgeblickt",
    "nachgeblicktester": "nachgeblickt",
    "nachgeblicktestes": "nachgeblickt",
    "nachgeblieben": "nachbleiben",
    "nachgebliebene": "nachgeblieben",
    "nachgebliebenem": "nachgeblieben",
    "nachgebliebenen": "nachgeblieben",
    "nachgebliebener": "nachgeblieben",
    "nachgebliebenes": "nachgeblieben",
    "nachgeblutet": "nachbluten",
    "nachgeblutete": "nachgeblutet",
    "nachgeblutetem": "nachgeblutet",
    "nachgebluteten": "nachgeblutet",
    "nachgebluteter": "nachgeblutet",
    "nachgeblutetes": "nachgeblutet",
    "nachgebohrt": "nachbohren",
    "nachgebohrte": "nachgebohrt",
    "nachgebohrtem": "nachgebohrt",
    "nachgebohrten": "nachgebohrt",
    "nachgebohrter": "nachgebohrt",
    "nachgebohrtes": "nachgebohrt",
    "nachgebracht": "nachbringen",
    "nachgebrachte": "nachgebracht",
    "nachgebrachtem": "nachgebracht",
    "nachgebrachten": "nachgebracht",
    "nachgebrachter": "nachgebracht",
    "nachgebrachtes": "nachgebracht",
    "nachgebt": "nachgeben",
    "nachgedacht": "nachdenken",
    "nachgedachte": "nachgedacht",
    "nachgedachtem": "nachgedacht",
    "nachgedachten": "nachgedacht",
    "nachgedachter": "nachgedacht",
    "nachgedachtes": "nachgedacht",
    "nachgedichtet": "nachdichten",
    "nachgedichtete": "nachgedichtet",
    "nachgedichtetem": "nachgedichtet",
    "nachgedichteten": "nachgedichtet",
    "nachgedichteter": "nachgedichtet",
    "nachgedichtetes": "nachgedichtet",
    "nachgedruckt": "nachdrucken",
    "nachgedruckte": "nachgedruckt",
    "nachgedrucktem": "nachgedruckt",
    "nachgedruckten": "nachgedruckt",
    "nachgedruckter": "nachgedruckt",
    "nachgedrucktes": "nachgedruckt",
    "nachgedrungen": "nachdringen",
    "nachgedrungene": "nachgedrungen",
    "nachgedrungenem": "nachgedrungen",
    "nachgedrungenen": "nachgedrungen",
    "nachgedrungener": "nachgedrungen",
    "nachgedrungenes": "nachgedrungen",
    "nachgedrängt": "nachdrängen",
    "nachgedrängte": "nachgedrängt",
    "nachgedrängtem": "nachgedrängt",
    "nachgedrängten": "nachgedrängt",
    "nachgedrängter": "nachgedrängt",
    "nachgedrängtes": "nachgedrängt",
    "nachgedunkelt": "nachdunkeln",
    "nachgedunkelte": "nachgedunkelt",
    "nachgedunkeltem": "nachgedunkelt",
    "nachgedunkelten": "nachgedunkelt",
    "nachgedunkelter": "nachgedunkelt",
    "nachgedunkeltere": "nachgedunkelt",
    "nachgedunkelterem": "nachgedunkelt",
    "nachgedunkelteren": "nachgedunkelt",
    "nachgedunkelterer": "nachgedunkelt",
    "nachgedunkelteres": "nachgedunkelt",
    "nachgedunkeltes": "nachgedunkelt",
    "nachgedunkelteste": "nachgedunkelt",
    "nachgedunkeltestem": "nachgedunkelt",
    "nachgedunkeltesten": "nachgedunkelt",
    "nachgedunkeltester": "nachgedunkelt",
    "nachgedunkeltestes": "nachgedunkelt",
    "nachgeeifert": "nacheifern",
    "nachgeeiferte": "nachgeeifert",
    "nachgeeifertem": "nachgeeifert",
    "nachgeeiferten": "nachgeeifert",
    "nachgeeiferter": "nachgeeifert",
    "nachgeeifertes": "nachgeeifert",
    "nachgeeilt": "nacheilen",
    "nachgeeilte": "nachgeeilt",
    "nachgeeiltem": "nachgeeilt",
    "nachgeeilten": "nachgeeilt",
    "nachgeeilter": "nachgeeilt",
    "nachgeeiltes": "nachgeeilt",
    "nachgefahren": "nachfahren",
    "nachgefahrene": "nachgefahren",
    "nachgefahrenem": "nachgefahren",
    "nachgefahrenen": "nachgefahren",
    "nachgefahrener": "nachgefahren",
    "nachgefahrenes": "nachgefahren",
    "nachgefaßt": "nachfassen",
    "nachgefaßte": "nachgefaßt",
    "nachgefaßtem": "nachgefaßt",
    "nachgefaßten": "nachgefaßt",
    "nachgefaßter": "nachgefaßt",
    "nachgefaßtes": "nachgefaßt",
    "nachgefeiert": "nachfeiern",
    "nachgefeierte": "nachgefeiert",
    "nachgefeiertem": "nachgefeiert",
    "nachgefeierten": "nachgefeiert",
    "nachgefeierter": "nachgefeiert",
    "nachgefeiertes": "nachgefeiert",
    "nachgefilmt": "nachfilmen",
    "nachgefilmte": "nachgefilmt",
    "nachgefilmtem": "nachgefilmt",
    "nachgefilmten": "nachgefilmt",
    "nachgefilmter": "nachgefilmt",
    "nachgefilmtes": "nachgefilmt",
    "nachgefolgt": "nachfolgen",
    "nachgefolgte": "nachgefolgt",
    "nachgefolgtem": "nachgefolgt",
    "nachgefolgten": "nachgefolgt",
    "nachgefolgter": "nachgefolgt",
    "nachgefolgtes": "nachgefolgt",
    "nachgefordert": "nachfordern",
    "nachgeforderte": "nachgefordert",
    "nachgefordertem": "nachgefordert",
    "nachgeforderten": "nachgefordert",
    "nachgeforderter": "nachgefordert",
    "nachgefordertes": "nachgefordert",
    "nachgeforscht": "nachforschen",
    "nachgeforschte": "nachgeforscht",
    "nachgeforschtem": "nachgeforscht",
    "nachgeforschten": "nachgeforscht",
    "nachgeforschter": "nachgeforscht",
    "nachgeforschtes": "nachgeforscht",
    "nachgefragt": "nachfragen",
    "nachgefragte": "nachgefragt",
    "nachgefragtem": "nachgefragt",
    "nachgefragten": "nachgefragt",
    "nachgefragter": "nachgefragt",
    "nachgefragtes": "nachgefragt",
    "nachgefühlt": "nachfühlen",
    "nachgefühlte": "nachgefühlt",
    "nachgefühltem": "nachgefühlt",
    "nachgefühlten": "nachgefühlt",
    "nachgefühlter": "nachgefühlt",
    "nachgefühltere": "nachgefühlt",
    "nachgefühlterem": "nachgefühlt",
    "nachgefühlteren": "nachgefühlt",
    "nachgefühlterer": "nachgefühlt",
    "nachgefühlteres": "nachgefühlt",
    "nachgefühltes": "nachgefühlt",
    "nachgefühlteste": "nachgefühlt",
    "nachgefühltestem": "nachgefühlt",
    "nachgefühltesten": "nachgefühlt",
    "nachgefühltester": "nachgefühlt",
    "nachgefühltestes": "nachgefühlt",
    "nachgefüllt": "nachfüllen",
    "nachgefüllte": "nachgefüllt",
    "nachgefülltem": "nachgefüllt",
    "nachgefüllten": "nachgefüllt",
    "nachgefüllter": "nachgefüllt",
    "nachgefülltes": "nachgefüllt",
    "nachgegangen": "nachgehen",
    "nachgegangene": "nachgegangen",
    "nachgegangenem": "nachgegangen",
    "nachgegangenen": "nachgegangen",
    "nachgegangener": "nachgegangen",
    "nachgegangenes": "nachgegangen",
    "nachgegeben": "nachgeben",
    "nachgegebene": "nachgegeben",
    "nachgegebenem": "nachgegeben",
    "nachgegebenen": "nachgegeben",
    "nachgegebener": "nachgegeben",
    "nachgegebenes": "nachgegeben",
    "nachgegessen": "nachessen",
    "nachgegessene": "nachgegessen",
    "nachgegessenem": "nachgegessen",
    "nachgegessenen": "nachgegessen",
    "nachgegessener": "nachgegessen",
    "nachgegessenes": "nachgegessen",
    "nachgegoren": "nachgären",
    "nachgegorene": "nachgegoren",
    "nachgegorenem": "nachgegoren",
    "nachgegorenen": "nachgegoren",
    "nachgegorener": "nachgegoren",
    "nachgegorenere": "nachgegoren",
    "nachgegorenerem": "nachgegoren",
    "nachgegoreneren": "nachgegoren",
    "nachgegorenerer": "nachgegoren",
    "nachgegoreneres": "nachgegoren",
    "nachgegorenes": "nachgegoren",
    "nachgegorenste": "nachgegoren",
    "nachgegorenstem": "nachgegoren",
    "nachgegorensten": "nachgegoren",
    "nachgegorenster": "nachgegoren",
    "nachgegorenstes": "nachgegoren",
    "nachgegossen": "nachgießen",
    "nachgegossene": "nachgegossen",
    "nachgegossenem": "nachgegossen",
    "nachgegossenen": "nachgegossen",
    "nachgegossener": "nachgegossen",
    "nachgegossenes": "nachgegossen",
    "nachgegrübelt": "nachgrübeln",
    "nachgegrübelte": "nachgegrübelt",
    "nachgegrübeltem": "nachgegrübelt",
    "nachgegrübelten": "nachgegrübelt",
    "nachgegrübelter": "nachgegrübelt",
    "nachgegrübeltes": "nachgegrübelt",
    "nachgehakt": "nachhaken",
    "nachgehakte": "nachgehakt",
    "nachgehaktem": "nachgehakt",
    "nachgehakten": "nachgehakt",
    "nachgehakter": "nachgehakt",
    "nachgehaktes": "nachgehakt",
    "nachgehallt": "nachhallen",
    "nachgehallte": "nachgehallt",
    "nachgehalltem": "nachgehallt",
    "nachgehallten": "nachgehallt",
    "nachgehallter": "nachgehallt",
    "nachgehalltes": "nachgehallt",
    "nachgehangen": "nachhängen",
    "nachgehangene": "nachgehangen",
    "nachgehangenem": "nachgehangen",
    "nachgehangenen": "nachgehangen",
    "nachgehangener": "nachgehangen",
    "nachgehangenes": "nachgehangen",
    "nachgehe": "nachgehen",
    "nachgehend": "nachgehen",
    "nachgehende": "nachgehend",
    "nachgehendem": "nachgehend",
    "nachgehenden": "nachgehend",
    "nachgehender": "nachgehend",
    "nachgehendes": "nachgehend",
    "nachgehest": "nachgehen",
    "nachgehet": "nachgehen",
    "nachgehinkt": "nachhinken",
    "nachgehinkte": "nachgehinkt",
    "nachgehinktem": "nachgehinkt",
    "nachgehinkten": "nachgehinkt",
    "nachgehinkter": "nachgehinkt",
    "nachgehinktere": "nachgehinkt",
    "nachgehinkterem": "nachgehinkt",
    "nachgehinkteren": "nachgehinkt",
    "nachgehinkterer": "nachgehinkt",
    "nachgehinkteres": "nachgehinkt",
    "nachgehinktes": "nachgehinkt",
    "nachgehinkteste": "nachgehinkt",
    "nachgehinktestem": "nachgehinkt",
    "nachgehinktesten": "nachgehinkt",
    "nachgehinktester": "nachgehinkt",
    "nachgehinktestes": "nachgehinkt",
    "nachgeholfen": "nachhelfen",
    "nachgeholfene": "nachgeholfen",
    "nachgeholfenem": "nachgeholfen",
    "nachgeholfenen": "nachgeholfen",
    "nachgeholfener": "nachgeholfen",
    "nachgeholfenes": "nachgeholfen",
    "nachgeholt": "nachholen",
    "nachgeholte": "nachgeholt",
    "nachgeholtem": "nachgeholt",
    "nachgeholten": "nachgeholt",
    "nachgeholter": "nachgeholt",
    "nachgeholtes": "nachgeholt",
    "nachgehst": "nachgehen",
    "nachgeht": "nachgehen",
    "nachgehängt": "nachhängen",
    "nachgehängte": "nachgehängt",
    "nachgehängtem": "nachgehängt",
    "nachgehängten": "nachgehängt",
    "nachgehängter": "nachgehängt",
    "nachgehängtes": "nachgehängt",
    "nachgeimpft": "nachimpfen",
    "nachgeimpfte": "nachgeimpft",
    "nachgeimpftem": "nachgeimpft",
    "nachgeimpften": "nachgeimpft",
    "nachgeimpfter": "nachgeimpft",
    "nachgeimpftes": "nachgeimpft",
    "nachgejagt": "nachjagen",
    "nachgejagte": "nachgejagt",
    "nachgejagtem": "nachgejagt",
    "nachgejagten": "nachgejagt",
    "nachgejagter": "nachgejagt",
    "nachgejagtere": "nachgejagt",
    "nachgejagterem": "nachgejagt",
    "nachgejagteren": "nachgejagt",
    "nachgejagterer": "nachgejagt",
    "nachgejagteres": "nachgejagt",
    "nachgejagtes": "nachgejagt",
    "nachgejagteste": "nachgejagt",
    "nachgejagtestem": "nachgejagt",
    "nachgejagtesten": "nachgejagt",
    "nachgejagtester": "nachgejagt",
    "nachgejagtestes": "nachgejagt",
    "nachgekartet": "nachkarten",
    "nachgekartete": "nachgekartet",
    "nachgekartetem": "nachgekartet",
    "nachgekarteten": "nachgekartet",
    "nachgekarteter": "nachgekartet",
    "nachgekartetere": "nachgekartet",
    "nachgekarteterem": "nachgekartet",
    "nachgekarteteren": "nachgekartet",
    "nachgekarteterer": "nachgekartet",
    "nachgekarteteres": "nachgekartet",
    "nachgekartetes": "nachgekartet",
    "nachgekarteteste": "nachgekartet",
    "nachgekartetestem": "nachgekartet",
    "nachgekartetesten": "nachgekartet",
    "nachgekartetester": "nachgekartet",
    "nachgekartetestes": "nachgekartet",
    "nachgekauft": "nachkaufen",
    "nachgekaufte": "nachgekauft",
    "nachgekauftem": "nachgekauft",
    "nachgekauften": "nachgekauft",
    "nachgekaufter": "nachgekauft",
    "nachgekauftes": "nachgekauft",
    "nachgeklungen": "nachklingen",
    "nachgeklungene": "nachgeklungen",
    "nachgeklungenem": "nachgeklungen",
    "nachgeklungenen": "nachgeklungen",
    "nachgeklungener": "nachgeklungen",
    "nachgeklungenes": "nachgeklungen",
    "nachgekommen": "nachkommen",
    "nachgekommene": "nachgekommen",
    "nachgekommenem": "nachgekommen",
    "nachgekommenen": "nachgekommen",
    "nachgekommener": "nachgekommen",
    "nachgekommenes": "nachgekommen",
    "nachgeladen": "nachladen",
    "nachgeladene": "nachgeladen",
    "nachgeladenem": "nachgeladen",
    "nachgeladenen": "nachgeladen",
    "nachgeladener": "nachgeladen",
    "nachgeladenes": "nachgeladen",
    "nachgelassen": "nachlassen",
    "nachgelassene": "nachgelassen",
    "nachgelassenem": "nachgelassen",
    "nachgelassenen": "nachgelassen",
    "nachgelassener": "nachgelassen",
    "nachgelassenes": "nachgelassen",
    "nachgelaufen": "nachlaufen",
    "nachgelaufene": "nachgelaufen",
    "nachgelaufenem": "nachgelaufen",
    "nachgelaufenen": "nachgelaufen",
    "nachgelaufener": "nachgelaufen",
    "nachgelaufenes": "nachgelaufen",
    "nachgelebt": "nachleben",
    "nachgelebte": "nachgelebt",
    "nachgelebtem": "nachgelebt",
    "nachgelebten": "nachgelebt",
    "nachgelebter": "nachgelebt",
    "nachgelebtes": "nachgelebt",
    "nachgelegt": "nachlegen",
    "nachgelegte": "nachgelegt",
    "nachgelegtem": "nachgelegt",
    "nachgelegten": "nachgelegt",
    "nachgelegter": "nachgelegt",
    "nachgelegtes": "nachgelegt",
    "nachgelernt": "nachlernen",
    "nachgelernte": "nachgelernt",
    "nachgelerntem": "nachgelernt",
    "nachgelernten": "nachgelernt",
    "nachgelernter": "nachgelernt",
    "nachgelerntes": "nachgelernt",
    "nachgelesen": "nachlesen",
    "nachgelesene": "nachgelesen",
    "nachgelesenem": "nachgelesen",
    "nachgelesenen": "nachgelesen",
    "nachgelesener": "nachgelesen",
    "nachgelesenes": "nachgelesen",
    "nachgeliefert": "nachliefern",
    "nachgelieferte": "nachgeliefert",
    "nachgeliefertem": "nachgeliefert",
    "nachgelieferten": "nachgeliefert",
    "nachgelieferter": "nachgeliefert",
    "nachgeliefertes": "nachgeliefert",
    "nachgelöst": "nachlösen",
    "nachgelöste": "nachgelöst",
    "nachgelöstem": "nachgelöst",
    "nachgelösten": "nachgelöst",
    "nachgelöster": "nachgelöst",
    "nachgelöstes": "nachgelöst",
    "nachgemacht": "nachmachen",
    "nachgemachte": "nachgemacht",
    "nachgemachtem": "nachgemacht",
    "nachgemachten": "nachgemacht",
    "nachgemachter": "nachgemacht",
    "nachgemachtere": "nachgemacht",
    "nachgemachterem": "nachgemacht",
    "nachgemachteren": "nachgemacht",
    "nachgemachterer": "nachgemacht",
    "nachgemachteres": "nachgemacht",
    "nachgemachtes": "nachgemacht",
    "nachgemachteste": "nachgemacht",
    "nachgemachtestem": "nachgemacht",
    "nachgemachtesten": "nachgemacht",
    "nachgemachtester": "nachgemacht",
    "nachgemachtestes": "nachgemacht",
    "nachgemalt": "nachmalen",
    "nachgemalte": "nachgemalt",
    "nachgemaltem": "nachgemalt",
    "nachgemalten": "nachgemalt",
    "nachgemalter": "nachgemalt",
    "nachgemaltes": "nachgemalt",
    "nachgemeldet": "nachmelden",
    "nachgemeldete": "nachgemeldet",
    "nachgemeldetem": "nachgemeldet",
    "nachgemeldeten": "nachgemeldet",
    "nachgemeldeter": "nachgemeldet",
    "nachgemeldetes": "nachgemeldet",
    "nachgemessen": "nachmessen",
    "nachgemessene": "nachgemessen",
    "nachgemessenem": "nachgemessen",
    "nachgemessenen": "nachgemessen",
    "nachgemessener": "nachgemessen",
    "nachgemessenes": "nachgemessen",
    "nachgenommen": "nachnehmen",
    "nachgenommene": "nachgenommen",
    "nachgenommenem": "nachgenommen",
    "nachgenommenen": "nachgenommen",
    "nachgenommener": "nachgenommen",
    "nachgenommenes": "nachgenommen",
    "nachgepfiffen": "nachpfeifen",
    "nachgepfiffene": "nachgepfiffen",
    "nachgepfiffenem": "nachgepfiffen",
    "nachgepfiffenen": "nachgepfiffen",
    "nachgepfiffener": "nachgepfiffen",
    "nachgepfiffenes": "nachgepfiffen",
    "nachgeprüft": "nachprüfen",
    "nachgeprüfte": "nachgeprüft",
    "nachgeprüftem": "nachgeprüft",
    "nachgeprüften": "nachgeprüft",
    "nachgeprüfter": "nachgeprüft",
    "nachgeprüftere": "nachgeprüft",
    "nachgeprüfterem": "nachgeprüft",
    "nachgeprüfteren": "nachgeprüft",
    "nachgeprüfterer": "nachgeprüft",
    "nachgeprüfteres": "nachgeprüft",
    "nachgeprüftes": "nachgeprüft",
    "nachgeprüfteste": "nachgeprüft",
    "nachgeprüftestem": "nachgeprüft",
    "nachgeprüftesten": "nachgeprüft",
    "nachgeprüftester": "nachgeprüft",
    "nachgeprüftestes": "nachgeprüft",
    "nachgerannt": "nachrennen",
    "nachgerannte": "nachgerannt",
    "nachgeranntem": "nachgerannt",
    "nachgerannten": "nachgerannt",
    "nachgerannter": "nachgerannt",
    "nachgeranntes": "nachgerannt",
    "nachgerate": "nachgeraten",
    "nachgeratend": "nachgeraten",
    "nachgeratende": "nachgeratend",
    "nachgeratendem": "nachgeratend",
    "nachgeratenden": "nachgeratend",
    "nachgeratender": "nachgeratend",
    "nachgeratendes": "nachgeratend",
    "nachgeratene": "nachgeraten",
    "nachgeratenem": "nachgeraten",
    "nachgeratenen": "nachgeraten",
    "nachgeratener": "nachgeraten",
    "nachgeratenes": "nachgeraten",
    "nachgeratest": "nachgeraten",
    "nachgeratet": "nachgeraten",
    "nachgerechnet": "nachrechnen",
    "nachgerechnete": "nachgerechnet",
    "nachgerechnetem": "nachgerechnet",
    "nachgerechneten": "nachgerechnet",
    "nachgerechneter": "nachgerechnet",
    "nachgerechnetes": "nachgerechnet",
    "nachgeredet": "nachreden",
    "nachgeredete": "nachgeredet",
    "nachgeredetem": "nachgeredet",
    "nachgeredeten": "nachgeredet",
    "nachgeredeter": "nachgeredet",
    "nachgeredetes": "nachgeredet",
    "nachgereicht": "nachreichen",
    "nachgereichte": "nachgereicht",
    "nachgereichtem": "nachgereicht",
    "nachgereichten": "nachgereicht",
    "nachgereichter": "nachgereicht",
    "nachgereichtes": "nachgereicht",
    "nachgereift": "nachreifen",
    "nachgereifte": "nachgereift",
    "nachgereiftem": "nachgereift",
    "nachgereiften": "nachgereift",
    "nachgereifter": "nachgereift",
    "nachgereiftes": "nachgereift",
    "nachgereist": "nachreisen",
    "nachgereiste": "nachgereist",
    "nachgereistem": "nachgereist",
    "nachgereisten": "nachgereist",
    "nachgereister": "nachgereist",
    "nachgereistes": "nachgereist",
    "nachgeriet": "nachgeraten",
    "nachgeriete": "nachgeraten",
    "nachgerieten": "nachgeraten",
    "nachgerietest": "nachgeraten",
    "nachgerietet": "nachgeraten",
    "nachgerufen": "nachrufen",
    "nachgerufene": "nachgerufen",
    "nachgerufenem": "nachgerufen",
    "nachgerufenen": "nachgerufen",
    "nachgerufener": "nachgerufen",
    "nachgerufenes": "nachgerufen",
    "nachgerät": "nachgeraten",
    "nachgerätst": "nachgeraten",
    "nachgerühmt": "nachrühmen",
    "nachgerühmte": "nachgerühmt",
    "nachgerühmtem": "nachgerühmt",
    "nachgerühmten": "nachgerühmt",
    "nachgerühmter": "nachgerühmt",
    "nachgerühmtes": "nachgerühmt",
    "nachgerüstet": "nachrüsten",
    "nachgerüstete": "nachgerüstet",
    "nachgerüstetem": "nachgerüstet",
    "nachgerüsteten": "nachgerüstet",
    "nachgerüsteter": "nachgerüstet",
    "nachgerüstetes": "nachgerüstet",
    "nachgesagt": "nachsagen",
    "nachgesagte": "nachgesagt",
    "nachgesagtem": "nachgesagt",
    "nachgesagten": "nachgesagt",
    "nachgesagter": "nachgesagt",
    "nachgesagtes": "nachgesagt",
    "nachgesandt": "nachsenden",
    "nachgesandte": "nachgesandt",
    "nachgesandtem": "nachgesandt",
    "nachgesandten": "nachgesandt",
    "nachgesandter": "nachgesandt",
    "nachgesandtes": "nachgesandt",
    "nachgeschaffen": "nachschaffen",
    "nachgeschaffene": "nachgeschaffen",
    "nachgeschaffenem": "nachgeschaffen",
    "nachgeschaffenen": "nachgeschaffen",
    "nachgeschaffener": "nachgeschaffen",
    "nachgeschaffenes": "nachgeschaffen",
    "nachgeschafft": "nachschaffen",
    "nachgeschaffte": "nachgeschafft",
    "nachgeschafftem": "nachgeschafft",
    "nachgeschafften": "nachgeschafft",
    "nachgeschaffter": "nachgeschafft",
    "nachgeschafftes": "nachgeschafft",
    "nachgeschaut": "nachschauen",
    "nachgeschaute": "nachgeschaut",
    "nachgeschautem": "nachgeschaut",
    "nachgeschauten": "nachgeschaut",
    "nachgeschauter": "nachgeschaut",
    "nachgeschautes": "nachgeschaut",
    "nachgeschlagen": "nachschlagen",
    "nachgeschlagene": "nachgeschlagen",
    "nachgeschlagenem": "nachgeschlagen",
    "nachgeschlagenen": "nachgeschlagen",
    "nachgeschlagener": "nachgeschlagen",
    "nachgeschlagenes": "nachgeschlagen",
    "nachgeschleppt": "nachschleppen",
    "nachgeschleppte": "nachgeschleppt",
    "nachgeschlepptem": "nachgeschleppt",
    "nachgeschleppten": "nachgeschleppt",
    "nachgeschleppter": "nachgeschleppt",
    "nachgeschlepptes": "nachgeschleppt",
    "nachgeschlichen": "nachschleichen",
    "nachgeschlichene": "nachgeschlichen",
    "nachgeschlichenem": "nachgeschlichen",
    "nachgeschlichenen": "nachgeschlichen",
    "nachgeschlichener": "nachgeschlichen",
    "nachgeschlichenes": "nachgeschlichen",
    "nachgeschmissen": "nachschmeißen",
    "nachgeschmissene": "nachgeschmissen",
    "nachgeschmissenem": "nachgeschmissen",
    "nachgeschmissenen": "nachgeschmissen",
    "nachgeschmissener": "nachgeschmissen",
    "nachgeschmissenere": "nachgeschmissen",
    "nachgeschmissenerem": "nachgeschmissen",
    "nachgeschmisseneren": "nachgeschmissen",
    "nachgeschmissenerer": "nachgeschmissen",
    "nachgeschmisseneres": "nachgeschmissen",
    "nachgeschmissenes": "nachgeschmissen",
    "nachgeschmissenste": "nachgeschmissen",
    "nachgeschmissenstem": "nachgeschmissen",
    "nachgeschmissensten": "nachgeschmissen",
    "nachgeschmissenster": "nachgeschmissen",
    "nachgeschmissenstes": "nachgeschmissen",
    "nachgeschnitten": "nachschneiden",
    "nachgeschnittene": "nachgeschnitten",
    "nachgeschnittenem": "nachgeschnitten",
    "nachgeschnittenen": "nachgeschnitten",
    "nachgeschnittener": "nachgeschnitten",
    "nachgeschnittenes": "nachgeschnitten",
    "nachgeschrieben": "nachschreiben",
    "nachgeschriebene": "nachgeschrieben",
    "nachgeschriebenem": "nachgeschrieben",
    "nachgeschriebenen": "nachgeschrieben",
    "nachgeschriebener": "nachgeschrieben",
    "nachgeschriebenes": "nachgeschrieben",
    "nachgeschwommen": "nachschwimmen",
    "nachgeschwommene": "nachgeschwommen",
    "nachgeschwommenem": "nachgeschwommen",
    "nachgeschwommenen": "nachgeschwommen",
    "nachgeschwommener": "nachgeschwommen",
    "nachgeschwommenes": "nachgeschwommen",
    "nachgeschüttet": "nachschütten",
    "nachgeschüttete": "nachgeschüttet",
    "nachgeschüttetem": "nachgeschüttet",
    "nachgeschütteten": "nachgeschüttet",
    "nachgeschütteter": "nachgeschüttet",
    "nachgeschüttetes": "nachgeschüttet",
    "nachgesehen": "nachsehen",
    "nachgesehene": "nachgesehen",
    "nachgesehenem": "nachgesehen",
    "nachgesehenen": "nachgesehen",
    "nachgesehener": "nachgesehen",
    "nachgesehenes": "nachgesehen",
    "nachgesendet": "nachsenden",
    "nachgesendete": "nachgesendet",
    "nachgesendetem": "nachgesendet",
    "nachgesendeten": "nachgesendet",
    "nachgesendeter": "nachgesendet",
    "nachgesendetes": "nachgesendet",
    "nachgesessen": "nachsitzen",
    "nachgesessene": "nachgesessen",
    "nachgesessenem": "nachgesessen",
    "nachgesessenen": "nachgesessen",
    "nachgesessener": "nachgesessen",
    "nachgesessenes": "nachgesessen",
    "nachgesetzt": "nachsetzen",
    "nachgesetzte": "nachgesetzt",
    "nachgesetztem": "nachgesetzt",
    "nachgesetzten": "nachgesetzt",
    "nachgesetzter": "nachgesetzt",
    "nachgesetztes": "nachgesetzt",
    "nachgesonnen": "nachsinnen",
    "nachgesonnene": "nachgesonnen",
    "nachgesonnenem": "nachgesonnen",
    "nachgesonnenen": "nachgesonnen",
    "nachgesonnener": "nachgesonnen",
    "nachgesonnenes": "nachgesonnen",
    "nachgespielt": "nachspielen",
    "nachgespielte": "nachgespielt",
    "nachgespieltem": "nachgespielt",
    "nachgespielten": "nachgespielt",
    "nachgespielter": "nachgespielt",
    "nachgespieltes": "nachgespielt",
    "nachgesprochen": "nachsprechen",
    "nachgesprochene": "nachgesprochen",
    "nachgesprochenem": "nachgesprochen",
    "nachgesprochenen": "nachgesprochen",
    "nachgesprochener": "nachgesprochen",
    "nachgesprochenere": "nachgesprochen",
    "nachgesprochenerem": "nachgesprochen",
    "nachgesprocheneren": "nachgesprochen",
    "nachgesprochenerer": "nachgesprochen",
    "nachgesprocheneres": "nachgesprochen",
    "nachgesprochenes": "nachgesprochen",
    "nachgesprochenste": "nachgesprochen",
    "nachgesprochenstem": "nachgesprochen",
    "nachgesprochensten": "nachgesprochen",
    "nachgesprochenster": "nachgesprochen",
    "nachgesprochenstes": "nachgesprochen",
    "nachgesprungen": "nachspringen",
    "nachgesprungene": "nachgesprungen",
    "nachgesprungenem": "nachgesprungen",
    "nachgesprungenen": "nachgesprungen",
    "nachgesprungener": "nachgesprungen",
    "nachgesprungenes": "nachgesprungen",
    "nachgespült": "nachspülen",
    "nachgespülte": "nachgespült",
    "nachgespültem": "nachgespült",
    "nachgespülten": "nachgespült",
    "nachgespülter": "nachgespült",
    "nachgespültes": "nachgespült",
    "nachgespürt": "nachspüren",
    "nachgespürte": "nachgespürt",
    "nachgespürtem": "nachgespürt",
    "nachgespürten": "nachgespürt",
    "nachgespürter": "nachgespürt",
    "nachgespürtere": "nachgespürt",
    "nachgespürterem": "nachgespürt",
    "nachgespürteren": "nachgespürt",
    "nachgespürterer": "nachgespürt",
    "nachgespürteres": "nachgespürt",
    "nachgespürtes": "nachgespürt",
    "nachgespürteste": "nachgespürt",
    "nachgespürtestem": "nachgespürt",
    "nachgespürtesten": "nachgespürt",
    "nachgespürtester": "nachgespürt",
    "nachgespürtestes": "nachgespürt",
    "nachgestanden": "nachstehen",
    "nachgestandene": "nachgestanden",
    "nachgestandenem": "nachgestanden",
    "nachgestandenen": "nachgestanden",
    "nachgestandener": "nachgestanden",
    "nachgestandenes": "nachgestanden",
    "nachgestellt": "nachstellen",
    "nachgestellte": "nachgestellt",
    "nachgestelltem": "nachgestellt",
    "nachgestellten": "nachgestellt",
    "nachgestellter": "nachgestellt",
    "nachgestelltes": "nachgestellt",
    "nachgestiegen": "nachsteigen",
    "nachgestiegene": "nachgestiegen",
    "nachgestiegenem": "nachgestiegen",
    "nachgestiegenen": "nachgestiegen",
    "nachgestiegener": "nachgestiegen",
    "nachgestiegenes": "nachgestiegen",
    "nachgestimmt": "nachstimmen",
    "nachgestimmte": "nachgestimmt",
    "nachgestimmtem": "nachgestimmt",
    "nachgestimmten": "nachgestimmt",
    "nachgestimmter": "nachgestimmt",
    "nachgestimmtes": "nachgestimmt",
    "nachgestrebt": "nachstreben",
    "nachgestrebte": "nachgestrebt",
    "nachgestrebtem": "nachgestrebt",
    "nachgestrebten": "nachgestrebt",
    "nachgestrebter": "nachgestrebt",
    "nachgestrebtes": "nachgestrebt",
    "nachgestürzt": "nachstürzen",
    "nachgestürzte": "nachgestürzt",
    "nachgestürztem": "nachgestürzt",
    "nachgestürzten": "nachgestürzt",
    "nachgestürzter": "nachgestürzt",
    "nachgestürztes": "nachgestürzt",
    "nachgesucht": "nachsuchen",
    "nachgesuchte": "nachgesucht",
    "nachgesuchtem": "nachgesucht",
    "nachgesuchten": "nachgesucht",
    "nachgesuchter": "nachgesucht",
    "nachgesuchtes": "nachgesucht",
    "nachgesungen": "nachsingen",
    "nachgesungene": "nachgesungen",
    "nachgesungenem": "nachgesungen",
    "nachgesungenen": "nachgesungen",
    "nachgesungener": "nachgesungen",
    "nachgesungenere": "nachgesungen",
    "nachgesungenerem": "nachgesungen",
    "nachgesungeneren": "nachgesungen",
    "nachgesungenerer": "nachgesungen",
    "nachgesungeneres": "nachgesungen",
    "nachgesungenes": "nachgesungen",
    "nachgesungenste": "nachgesungen",
    "nachgesungenstem": "nachgesungen",
    "nachgesungensten": "nachgesungen",
    "nachgesungenster": "nachgesungen",
    "nachgesungenstes": "nachgesungen",
    "nachgetankt": "nachtanken",
    "nachgetankte": "nachgetankt",
    "nachgetanktem": "nachgetankt",
    "nachgetankten": "nachgetankt",
    "nachgetankter": "nachgetankt",
    "nachgetanktes": "nachgetankt",
    "nachgetragen": "nachtragen",
    "nachgetragene": "nachgetragen",
    "nachgetragenem": "nachgetragen",
    "nachgetragenen": "nachgetragen",
    "nachgetragener": "nachgetragen",
    "nachgetragenes": "nachgetragen",
    "nachgetrauert": "nachtrauern",
    "nachgetrauerte": "nachgetrauert",
    "nachgetrauertem": "nachgetrauert",
    "nachgetrauerten": "nachgetrauert",
    "nachgetrauerter": "nachgetrauert",
    "nachgetrauertes": "nachgetrauert",
    "nachgetönt": "nachtönen",
    "nachgetönte": "nachgetönt",
    "nachgetöntem": "nachgetönt",
    "nachgetönten": "nachgetönt",
    "nachgetönter": "nachgetönt",
    "nachgetöntes": "nachgetönt",
    "nachgewachsen": "nachwachsen",
    "nachgewachsene": "nachgewachsen",
    "nachgewachsenem": "nachgewachsen",
    "nachgewachsenen": "nachgewachsen",
    "nachgewachsener": "nachgewachsen",
    "nachgewachsenes": "nachgewachsen",
    "nachgewachst": "nachwachsen",
    "nachgewachste": "nachgewachst",
    "nachgewachstem": "nachgewachst",
    "nachgewachsten": "nachgewachst",
    "nachgewachster": "nachgewachst",
    "nachgewachstes": "nachgewachst",
    "nachgeweint": "nachweinen",
    "nachgeweinte": "nachgeweint",
    "nachgeweintem": "nachgeweint",
    "nachgeweinten": "nachgeweint",
    "nachgeweinter": "nachgeweint",
    "nachgeweintes": "nachgeweint",
    "nachgewiesen": "nachweisen",
    "nachgewiesene": "nachgewiesen",
    "nachgewiesenem": "nachgewiesen",
    "nachgewiesenen": "nachgewiesen",
    "nachgewiesener": "nachgewiesen",
    "nachgewiesenes": "nachgewiesen",
    "nachgewinkt": "nachwinken",
    "nachgewinkte": "nachgewinkt",
    "nachgewinktem": "nachgewinkt",
    "nachgewinkten": "nachgewinkt",
    "nachgewinkter": "nachgewinkt",
    "nachgewinktes": "nachgewinkt",
    "nachgewirkt": "nachwirken",
    "nachgewirkte": "nachgewirkt",
    "nachgewirktem": "nachgewirkt",
    "nachgewirkten": "nachgewirkt",
    "nachgewirkter": "nachgewirkt",
    "nachgewirktes": "nachgewirkt",
    "nachgewogen": "nachwiegen",
    "nachgewogene": "nachgewogen",
    "nachgewogenem": "nachgewogen",
    "nachgewogenen": "nachgewogen",
    "nachgewogener": "nachgewogen",
    "nachgewogenes": "nachgewogen",
    "nachgeworfen": "nachwerfen",
    "nachgeworfene": "nachgeworfen",
    "nachgeworfenem": "nachgeworfen",
    "nachgeworfenen": "nachgeworfen",
    "nachgeworfener": "nachgeworfen",
    "nachgeworfenere": "nachgeworfen",
    "nachgeworfenerem": "nachgeworfen",
    "nachgeworfeneren": "nachgeworfen",
    "nachgeworfenerer": "nachgeworfen",
    "nachgeworfeneres": "nachgeworfen",
    "nachgeworfenes": "nachgeworfen",
    "nachgeworfenste": "nachgeworfen",
    "nachgeworfenstem": "nachgeworfen",
    "nachgeworfensten": "nachgeworfen",
    "nachgeworfenster": "nachgeworfen",
    "nachgeworfenstes": "nachgeworfen",
    "nachgezahlt": "nachzahlen",
    "nachgezahlte": "nachgezahlt",
    "nachgezahltem": "nachgezahlt",
    "nachgezahlten": "nachgezahlt",
    "nachgezahlter": "nachgezahlt",
    "nachgezahltes": "nachgezahlt",
    "nachgezeichnet": "nachzeichnen",
    "nachgezeichnete": "nachgezeichnet",
    "nachgezeichnetem": "nachgezeichnet",
    "nachgezeichneten": "nachgezeichnet",
    "nachgezeichneter": "nachgezeichnet",
    "nachgezeichnetes": "nachgezeichnet",
    "nachgezogen": "nachziehen",
    "nachgezogene": "nachgezogen",
    "nachgezogenem": "nachgezogen",
    "nachgezogenen": "nachgezogen",
    "nachgezogener": "nachgezogen",
    "nachgezogenes": "nachgezogen",
    "nachgezählt": "nachzählen",
    "nachgezähltem": "nachgezählt",
    "nachgezählter": "nachgezählt",
    "nachgezähltes": "nachgezählt",
    "nachgeäfft": "nachäffen",
    "nachgeäffte": "nachgeäfft",
    "nachgeäfftem": "nachgeäfft",
    "nachgeäfften": "nachgeäfft",
    "nachgeäffter": "nachgeäfft",
    "nachgeäfftere": "nachgeäfft",
    "nachgeäffterem": "nachgeäfft",
    "nachgeäffteren": "nachgeäfft",
    "nachgeäffterer": "nachgeäfft",
    "nachgeäffteres": "nachgeäfft",
    "nachgeäfftes": "nachgeäfft",
    "nachgeäffteste": "nachgeäfft",
    "nachgeäfftestem": "nachgeäfft",
    "nachgeäfftesten": "nachgeäfft",
    "nachgeäfftester": "nachgeäfft",
    "nachgeäfftestes": "nachgeäfft",
    "nachgibst": "nachgeben",
    "nachgibt": "nachgeben",
    "nachgieße": "nachgießen",
    "nachgießend": "nachgießen",
    "nachgießende": "nachgießend",
    "nachgießendem": "nachgießend",
    "nachgießenden": "nachgießend",
    "nachgießender": "nachgießend",
    "nachgießendes": "nachgießend",
    "nachgießest": "nachgießen",
    "nachgießet": "nachgießen",
    "nachgießt": "nachgießen",
    "nachging": "nachgehen",
    "nachginge": "nachgehen",
    "nachgingen": "nachgehen",
    "nachgingest": "nachgehen",
    "nachginget": "nachgehen",
    "nachgingst": "nachgehen",
    "nachgingt": "nachgehen",
    "nachgor": "nachgären",
    "nachgoren": "nachgären",
    "nachgorst": "nachgären",
    "nachgort": "nachgären",
    "nachgossen": "nachgießen",
    "nachgoß": "nachgießen",
    "nachgoßt": "nachgießen",
    "nachgrübele": "nachgrübeln",
    "nachgrübelnd": "nachgrübeln",
    "nachgrübelnde": "nachgrübelnd",
    "nachgrübelndem": "nachgrübelnd",
    "nachgrübelnden": "nachgrübelnd",
    "nachgrübelnder": "nachgrübelnd",
    "nachgrübelndere": "nachgrübelnd",
    "nachgrübelnderem": "nachgrübelnd",
    "nachgrübelnderen": "nachgrübelnd",
    "nachgrübelnderer": "nachgrübelnd",
    "nachgrübelnderes": "nachgrübelnd",
    "nachgrübelndes": "nachgrübelnd",
    "nachgrübelndste": "nachgrübelnd",
    "nachgrübelndstem": "nachgrübelnd",
    "nachgrübelndsten": "nachgrübelnd",
    "nachgrübelndster": "nachgrübelnd",
    "nachgrübelndstes": "nachgrübelnd",
    "nachgrübelst": "nachgrübeln",
    "nachgrübelt": "nachgrübeln",
    "nachgrübelte": "nachgrübeln",
    "nachgrübelten": "nachgrübeln",
    "nachgrübeltest": "nachgrübeln",
    "nachgrübeltet": "nachgrübeln",
    "nachgrüble": "nachgrübeln",
    "nachgäbe": "nachgeben",
    "nachgäben": "nachgeben",
    "nachgäbest": "nachgeben",
    "nachgäbet": "nachgeben",
    "nachgäre": "nachgären",
    "nachgärend": "nachgären",
    "nachgärende": "nachgärend",
    "nachgärendem": "nachgärend",
    "nachgärenden": "nachgärend",
    "nachgärender": "nachgärend",
    "nachgärendere": "nachgärend",
    "nachgärenderem": "nachgärend",
    "nachgärenderen": "nachgärend",
    "nachgärenderer": "nachgärend",
    "nachgärenderes": "nachgärend",
    "nachgärendes": "nachgärend",
    "nachgärendste": "nachgärend",
    "nachgärendstem": "nachgärend",
    "nachgärendsten": "nachgärend",
    "nachgärendster": "nachgärend",
    "nachgärendstes": "nachgärend",
    "nachgärest": "nachgären",
    "nachgäret": "nachgären",
    "nachgärst": "nachgären",
    "nachgärt": "nachgären",
    "nachgöre": "nachgären",
    "nachgören": "nachgären",
    "nachgörest": "nachgären",
    "nachgöret": "nachgären",
    "nachgösse": "nachgießen",
    "nachgössen": "nachgießen",
    "nachgössest": "nachgießen",
    "nachgösset": "nachgießen",
    "nachhake": "nachhaken",
    "nachhakend": "nachhaken",
    "nachhakende": "nachhakend",
    "nachhakendem": "nachhakend",
    "nachhakenden": "nachhakend",
    "nachhakender": "nachhakend",
    "nachhakendere": "nachhakend",
    "nachhakenderem": "nachhakend",
    "nachhakenderen": "nachhakend",
    "nachhakenderer": "nachhakend",
    "nachhakenderes": "nachhakend",
    "nachhakendes": "nachhakend",
    "nachhakendste": "nachhakend",
    "nachhakendstem": "nachhakend",
    "nachhakendsten": "nachhakend",
    "nachhakendster": "nachhakend",
    "nachhakendstes": "nachhakend",
    "nachhakest": "nachhaken",
    "nachhaket": "nachhaken",
    "nachhakst": "nachhaken",
    "nachhakt": "nachhaken",
    "nachhakte": "nachhaken",
    "nachhakten": "nachhaken",
    "nachhaktest": "nachhaken",
    "nachhaktet": "nachhaken",
    "nachhalf": "nachhelfen",
    "nachhalfen": "nachhelfen",
    "nachhalfst": "nachhelfen",
    "nachhalft": "nachhelfen",
    "nachhallend": "nachhallen",
    "nachhallende": "nachhallend",
    "nachhallendem": "nachhallend",
    "nachhallenden": "nachhallend",
    "nachhallender": "nachhallend",
    "nachhallendere": "nachhallend",
    "nachhallenderem": "nachhallend",
    "nachhallenderen": "nachhallend",
    "nachhallenderer": "nachhallend",
    "nachhallenderes": "nachhallend",
    "nachhallendes": "nachhallend",
    "nachhallendste": "nachhallend",
    "nachhallendstem": "nachhallend",
    "nachhallendsten": "nachhallend",
    "nachhallendster": "nachhallend",
    "nachhallendstes": "nachhallend",
    "nachhallest": "nachhallen",
    "nachhallet": "nachhallen",
    "nachhallst": "nachhallen",
    "nachhallt": "nachhallen",
    "nachhallte": "nachhallen",
    "nachhallten": "nachhallen",
    "nachhalltest": "nachhallen",
    "nachhalltet": "nachhallen",
    "nachhaltige": "nachhaltig",
    "nachhaltigem": "nachhaltig",
    "nachhaltigen": "nachhaltig",
    "nachhaltiger": "nachhaltig",
    "nachhaltigere": "nachhaltig",
    "nachhaltigerem": "nachhaltig",
    "nachhaltigeren": "nachhaltig",
    "nachhaltigerer": "nachhaltig",
    "nachhaltigeres": "nachhaltig",
    "nachhaltiges": "nachhaltig",
    "nachhaltigste": "nachhaltig",
    "nachhaltigstem": "nachhaltig",
    "nachhaltigsten": "nachhaltig",
    "nachhaltigster": "nachhaltig",
    "nachhaltigstes": "nachhaltig",
    "nachhelfe": "nachhelfen",
    "nachhelfend": "nachhelfen",
    "nachhelfende": "nachhelfend",
    "nachhelfendem": "nachhelfend",
    "nachhelfenden": "nachhelfend",
    "nachhelfender": "nachhelfend",
    "nachhelfendes": "nachhelfend",
    "nachhelfest": "nachhelfen",
    "nachhelfet": "nachhelfen",
    "nachhelft": "nachhelfen",
    "nachhilfst": "nachhelfen",
    "nachhilft": "nachhelfen",
    "nachhing": "nachhängen",
    "nachhinge": "nachhängen",
    "nachhingen": "nachhängen",
    "nachhingest": "nachhängen",
    "nachhinget": "nachhängen",
    "nachhingst": "nachhängen",
    "nachhingt": "nachhängen",
    "nachhinke": "nachhinken",
    "nachhinkend": "nachhinken",
    "nachhinkende": "nachhinkend",
    "nachhinkendem": "nachhinkend",
    "nachhinkenden": "nachhinkend",
    "nachhinkender": "nachhinkend",
    "nachhinkendere": "nachhinkend",
    "nachhinkenderem": "nachhinkend",
    "nachhinkenderen": "nachhinkend",
    "nachhinkenderer": "nachhinkend",
    "nachhinkenderes": "nachhinkend",
    "nachhinkendes": "nachhinkend",
    "nachhinkendste": "nachhinkend",
    "nachhinkendstem": "nachhinkend",
    "nachhinkendsten": "nachhinkend",
    "nachhinkendster": "nachhinkend",
    "nachhinkendstes": "nachhinkend",
    "nachhinkest": "nachhinken",
    "nachhinket": "nachhinken",
    "nachhinkst": "nachhinken",
    "nachhinkt": "nachhinken",
    "nachhinkte": "nachhinken",
    "nachhinkten": "nachhinken",
    "nachhinktest": "nachhinken",
    "nachhinktet": "nachhinken",
    "nachhole": "nachholen",
    "nachholend": "nachholen",
    "nachholende": "nachholend",
    "nachholendem": "nachholend",
    "nachholenden": "nachholend",
    "nachholender": "nachholend",
    "nachholendes": "nachholend",
    "nachholest": "nachholen",
    "nachholet": "nachholen",
    "nachholst": "nachholen",
    "nachholt": "nachholen",
    "nachholte": "nachholen",
    "nachholten": "nachholen",
    "nachholtest": "nachholen",
    "nachholtet": "nachholen",
    "nachhälfe": "nachhelfen",
    "nachhälfen": "nachhelfen",
    "nachhälfest": "nachhelfen",
    "nachhälfet": "nachhelfen",
    "nachhänge": "nachhängen",
    "nachhängend": "nachhängen",
    "nachhängende": "nachhängend",
    "nachhängendem": "nachhängend",
    "nachhängenden": "nachhängend",
    "nachhängender": "nachhängend",
    "nachhängendes": "nachhängend",
    "nachhängest": "nachhängen",
    "nachhänget": "nachhängen",
    "nachhängst": "nachhängen",
    "nachhängt": "nachhängen",
    "nachhängte": "nachhängen",
    "nachhängten": "nachhängen",
    "nachhängtest": "nachhängen",
    "nachhängtet": "nachhängen",
    "nachimpfe": "nachimpfen",
    "nachimpfend": "nachimpfen",
    "nachimpfende": "nachimpfend",
    "nachimpfendem": "nachimpfend",
    "nachimpfenden": "nachimpfend",
    "nachimpfender": "nachimpfend",
    "nachimpfendes": "nachimpfend",
    "nachimpfest": "nachimpfen",
    "nachimpfet": "nachimpfen",
    "nachimpfst": "nachimpfen",
    "nachimpft": "nachimpfen",
    "nachimpfte": "nachimpfen",
    "nachimpften": "nachimpfen",
    "nachimpftest": "nachimpfen",
    "nachimpftet": "nachimpfen",
    "nachißt": "nachessen",
    "nachjage": "nachjagen",
    "nachjagend": "nachjagen",
    "nachjagende": "nachjagend",
    "nachjagendem": "nachjagend",
    "nachjagenden": "nachjagend",
    "nachjagender": "nachjagend",
    "nachjagendere": "nachjagend",
    "nachjagenderem": "nachjagend",
    "nachjagenderen": "nachjagend",
    "nachjagenderer": "nachjagend",
    "nachjagenderes": "nachjagend",
    "nachjagendes": "nachjagend",
    "nachjagendste": "nachjagend",
    "nachjagendstem": "nachjagend",
    "nachjagendsten": "nachjagend",
    "nachjagendster": "nachjagend",
    "nachjagendstes": "nachjagend",
    "nachjagest": "nachjagen",
    "nachjaget": "nachjagen",
    "nachjagst": "nachjagen",
    "nachjagt": "nachjagen",
    "nachjagte": "nachjagen",
    "nachjagten": "nachjagen",
    "nachjagtest": "nachjagen",
    "nachjagtet": "nachjagen",
    "nachkam": "nachkommen",
    "nachkamen": "nachkommen",
    "nachkamst": "nachkommen",
    "nachkamt": "nachkommen",
    "nachkarte": "nachkarten",
    "nachkartend": "nachkarten",
    "nachkartende": "nachkartend",
    "nachkartendem": "nachkartend",
    "nachkartenden": "nachkartend",
    "nachkartender": "nachkartend",
    "nachkartendere": "nachkartend",
    "nachkartenderem": "nachkartend",
    "nachkartenderen": "nachkartend",
    "nachkartenderer": "nachkartend",
    "nachkartenderes": "nachkartend",
    "nachkartendes": "nachkartend",
    "nachkartendste": "nachkartend",
    "nachkartendstem": "nachkartend",
    "nachkartendsten": "nachkartend",
    "nachkartendster": "nachkartend",
    "nachkartendstes": "nachkartend",
    "nachkartest": "nachkarten",
    "nachkartet": "nachkarten",
    "nachkartete": "nachkarten",
    "nachkarteten": "nachkarten",
    "nachkartetest": "nachkarten",
    "nachkartetet": "nachkarten",
    "nachkaufe": "nachkaufen",
    "nachkaufend": "nachkaufen",
    "nachkaufende": "nachkaufend",
    "nachkaufendem": "nachkaufend",
    "nachkaufenden": "nachkaufend",
    "nachkaufender": "nachkaufend",
    "nachkaufendes": "nachkaufend",
    "nachkaufest": "nachkaufen",
    "nachkaufet": "nachkaufen",
    "nachkaufst": "nachkaufen",
    "nachkauft": "nachkaufen",
    "nachkaufte": "nachkaufen",
    "nachkauften": "nachkaufen",
    "nachkauftest": "nachkaufen",
    "nachkauftet": "nachkaufen",
    "nachklang": "nachklingen",
    "nachklangen": "nachklingen",
    "nachklangst": "nachklingen",
    "nachklangt": "nachklingen",
    "nachklinge": "nachklingen",
    "nachklingend": "nachklingen",
    "nachklingende": "nachklingend",
    "nachklingendem": "nachklingend",
    "nachklingenden": "nachklingend",
    "nachklingender": "nachklingend",
    "nachklingendes": "nachklingend",
    "nachklingest": "nachklingen",
    "nachklinget": "nachklingen",
    "nachklingst": "nachklingen",
    "nachklingt": "nachklingen",
    "nachklängest": "nachklingen",
    "nachklänget": "nachklingen",
    "nachkomme": "nachkommen",
    "nachkommend": "nachkommen",
    "nachkommende": "nachkommend",
    "nachkommendem": "nachkommend",
    "nachkommenden": "nachkommend",
    "nachkommender": "nachkommend",
    "nachkommendes": "nachkommend",
    "nachkommest": "nachkommen",
    "nachkommet": "nachkommen",
    "nachkommst": "nachkommen",
    "nachkommt": "nachkommen",
    "nachkontrolliere": "nachkontrollieren",
    "nachkontrollierend": "nachkontrollieren",
    "nachkontrollierende": "nachkontrollierend",
    "nachkontrollierendem": "nachkontrollierend",
    "nachkontrollierenden": "nachkontrollierend",
    "nachkontrollierender": "nachkontrollierend",
    "nachkontrollierendes": "nachkontrollierend",
    "nachkontrollierest": "nachkontrollieren",
    "nachkontrollieret": "nachkontrollieren",
    "nachkontrollierst": "nachkontrollieren",
    "nachkontrolliert": "nachkontrollieren",
    "nachkontrollierte": "nachkontrollieren",
    "nachkontrolliertem": "nachkontrolliert",
    "nachkontrollierten": "nachkontrollieren",
    "nachkontrollierter": "nachkontrolliert",
    "nachkontrolliertes": "nachkontrolliert",
    "nachkontrolliertest": "nachkontrollieren",
    "nachkontrolliertet": "nachkontrollieren",
    "nachkäme": "nachkommen",
    "nachkämen": "nachkommen",
    "nachkämest": "nachkommen",
    "nachkämet": "nachkommen",
    "nachlade": "nachladen",
    "nachladend": "nachladen",
    "nachladende": "nachladend",
    "nachladendem": "nachladend",
    "nachladenden": "nachladend",
    "nachladender": "nachladend",
    "nachladendes": "nachladend",
    "nachladest": "nachladen",
    "nachladet": "nachladen",
    "nachlas": "nachlesen",
    "nachlasen": "nachlesen",
    "nachlassend": "nachlassen",
    "nachlassende": "nachlassend",
    "nachlassendem": "nachlassend",
    "nachlassenden": "nachlassend",
    "nachlassender": "nachlassend",
    "nachlassendes": "nachlassend",
    "nachlassest": "nachlassen",
    "nachlasset": "nachlassen",
    "nachlast": "nachlesen",
    "nachlaufend": "nachlaufen",
    "nachlaufende": "nachlaufend",
    "nachlaufendem": "nachlaufend",
    "nachlaufenden": "nachlaufend",
    "nachlaufender": "nachlaufend",
    "nachlaufendes": "nachlaufend",
    "nachlaufest": "nachlaufen",
    "nachlaufet": "nachlaufen",
    "nachlauft": "nachlaufen",
    "nachlaßt": "nachlassen",
    "nachlebe": "nachleben",
    "nachlebend": "nachleben",
    "nachlebende": "nachlebend",
    "nachlebendem": "nachlebend",
    "nachlebenden": "nachlebend",
    "nachlebender": "nachlebend",
    "nachlebendes": "nachlebend",
    "nachlebest": "nachleben",
    "nachlebet": "nachleben",
    "nachlebst": "nachleben",
    "nachlebt": "nachleben",
    "nachlebte": "nachleben",
    "nachlebten": "nachleben",
    "nachlebtest": "nachleben",
    "nachlebtet": "nachleben",
    "nachlege": "nachlegen",
    "nachlegend": "nachlegen",
    "nachlegende": "nachlegend",
    "nachlegendem": "nachlegend",
    "nachlegenden": "nachlegend",
    "nachlegender": "nachlegend",
    "nachlegendes": "nachlegend",
    "nachlegest": "nachlegen",
    "nachleget": "nachlegen",
    "nachlegst": "nachlegen",
    "nachlegt": "nachlegen",
    "nachlegte": "nachlegen",
    "nachlegten": "nachlegen",
    "nachlegtest": "nachlegen",
    "nachlegtet": "nachlegen",
    "nachlerne": "nachlernen",
    "nachlernend": "nachlernen",
    "nachlernende": "nachlernend",
    "nachlernendem": "nachlernend",
    "nachlernenden": "nachlernend",
    "nachlernender": "nachlernend",
    "nachlernendes": "nachlernend",
    "nachlernest": "nachlernen",
    "nachlernet": "nachlernen",
    "nachlernst": "nachlernen",
    "nachlernt": "nachlernen",
    "nachlernte": "nachlernen",
    "nachlernten": "nachlernen",
    "nachlerntest": "nachlernen",
    "nachlerntet": "nachlernen",
    "nachlese": "nachlesen",
    "nachlesend": "nachlesen",
    "nachlesende": "nachlesend",
    "nachlesendem": "nachlesend",
    "nachlesenden": "nachlesend",
    "nachlesender": "nachlesend",
    "nachlesendes": "nachlesend",
    "nachlesest": "nachlesen",
    "nachleset": "nachlesen",
    "nachlest": "nachlesen",
    "nachlief": "nachlaufen",
    "nachliefe": "nachlaufen",
    "nachliefen": "nachlaufen",
    "nachliefere": "nachliefern",
    "nachliefernd": "nachliefern",
    "nachliefernde": "nachliefernd",
    "nachlieferndem": "nachliefernd",
    "nachliefernden": "nachliefernd",
    "nachliefernder": "nachliefernd",
    "nachlieferndes": "nachliefernd",
    "nachlieferst": "nachliefern",
    "nachliefert": "nachliefern",
    "nachlieferte": "nachliefern",
    "nachlieferten": "nachliefern",
    "nachliefertest": "nachliefern",
    "nachliefertet": "nachliefern",
    "nachliefest": "nachlaufen",
    "nachliefet": "nachlaufen",
    "nachliefst": "nachlaufen",
    "nachlieft": "nachlaufen",
    "nachliest": "nachlesen",
    "nachließ": "nachlassen",
    "nachließe": "nachlassen",
    "nachließen": "nachlassen",
    "nachließest": "nachlassen",
    "nachließet": "nachlassen",
    "nachließt": "nachlassen",
    "nachlud": "nachladen",
    "nachluden": "nachladen",
    "nachludest": "nachladen",
    "nachludet": "nachladen",
    "nachlädst": "nachladen",
    "nachlädt": "nachladen",
    "nachläse": "nachlesen",
    "nachläsen": "nachlesen",
    "nachläsest": "nachlesen",
    "nachläset": "nachlesen",
    "nachlässige": "nachlässig",
    "nachlässigem": "nachlässig",
    "nachlässigen": "nachlässig",
    "nachlässiger": "nachlässig",
    "nachlässigere": "nachlässig",
    "nachlässigerem": "nachlässig",
    "nachlässigeren": "nachlässig",
    "nachlässigerer": "nachlässig",
    "nachlässigeres": "nachlässig",
    "nachlässiges": "nachlässig",
    "nachlässigstem": "nachlässig",
    "nachlässigsten": "nachlässig",
    "nachlässigster": "nachlässig",
    "nachlässigstes": "nachlässig",
    "nachläufst": "nachlaufen",
    "nachläuft": "nachlaufen",
    "nachläßt": "nachlassen",
    "nachlöse": "nachlösen",
    "nachlösend": "nachlösen",
    "nachlösende": "nachlösend",
    "nachlösendem": "nachlösend",
    "nachlösenden": "nachlösend",
    "nachlösender": "nachlösend",
    "nachlösendes": "nachlösend",
    "nachlösest": "nachlösen",
    "nachlöset": "nachlösen",
    "nachlöst": "nachlösen",
    "nachlöste": "nachlösen",
    "nachlösten": "nachlösen",
    "nachlöstest": "nachlösen",
    "nachlöstet": "nachlösen",
    "nachlüde": "nachladen",
    "nachlüden": "nachladen",
    "nachlüdest": "nachladen",
    "nachlüdet": "nachladen",
    "nachmache": "nachmachen",
    "nachmachend": "nachmachen",
    "nachmachende": "nachmachend",
    "nachmachendem": "nachmachend",
    "nachmachenden": "nachmachend",
    "nachmachender": "nachmachend",
    "nachmachendes": "nachmachend",
    "nachmachest": "nachmachen",
    "nachmachet": "nachmachen",
    "nachmachst": "nachmachen",
    "nachmacht": "nachmachen",
    "nachmachte": "nachmachen",
    "nachmachten": "nachmachen",
    "nachmachtest": "nachmachen",
    "nachmachtet": "nachmachen",
    "nachmale": "nachmalen",
    "nachmalend": "nachmalen",
    "nachmalende": "nachmalend",
    "nachmalendem": "nachmalend",
    "nachmalenden": "nachmalend",
    "nachmalender": "nachmalend",
    "nachmalendes": "nachmalend",
    "nachmalest": "nachmalen",
    "nachmalet": "nachmalen",
    "nachmalst": "nachmalen",
    "nachmalt": "nachmalen",
    "nachmalte": "nachmalen",
    "nachmalten": "nachmalen",
    "nachmaltest": "nachmalen",
    "nachmaltet": "nachmalen",
    "nachmaß": "nachmessen",
    "nachmaßen": "nachmessen",
    "nachmaßt": "nachmessen",
    "nachmelde": "nachmelden",
    "nachmeldend": "nachmelden",
    "nachmeldende": "nachmeldend",
    "nachmeldendem": "nachmeldend",
    "nachmeldenden": "nachmeldend",
    "nachmeldender": "nachmeldend",
    "nachmeldendes": "nachmeldend",
    "nachmeldest": "nachmelden",
    "nachmeldet": "nachmelden",
    "nachmeldete": "nachmelden",
    "nachmeldeten": "nachmelden",
    "nachmeldetest": "nachmelden",
    "nachmeldetet": "nachmelden",
    "nachmesse": "nachmessen",
    "nachmessend": "nachmessen",
    "nachmessende": "nachmessend",
    "nachmessendem": "nachmessend",
    "nachmessenden": "nachmessend",
    "nachmessender": "nachmessend",
    "nachmessendes": "nachmessend",
    "nachmessest": "nachmessen",
    "nachmesset": "nachmessen",
    "nachmeßt": "nachmessen",
    "nachmißt": "nachmessen",
    "nachmäße": "nachmessen",
    "nachmäßen": "nachmessen",
    "nachmäßest": "nachmessen",
    "nachmäßet": "nachmessen",
    "nachnahm": "nachnehmen",
    "nachnahmst": "nachnehmen",
    "nachnahmt": "nachnehmen",
    "nachnehme": "nachnehmen",
    "nachnehmend": "nachnehmen",
    "nachnehmende": "nachnehmend",
    "nachnehmendem": "nachnehmend",
    "nachnehmenden": "nachnehmend",
    "nachnehmender": "nachnehmend",
    "nachnehmendes": "nachnehmend",
    "nachnehmest": "nachnehmen",
    "nachnehmet": "nachnehmen",
    "nachnehmt": "nachnehmen",
    "nachnimmst": "nachnehmen",
    "nachnimmt": "nachnehmen",
    "nachnähme": "nachnehmen",
    "nachnähmen": "nachnehmen",
    "nachnähmest": "nachnehmen",
    "nachnähmet": "nachnehmen",
    "nachpfeife": "nachpfeifen",
    "nachpfeifend": "nachpfeifen",
    "nachpfeifende": "nachpfeifend",
    "nachpfeifendem": "nachpfeifend",
    "nachpfeifenden": "nachpfeifend",
    "nachpfeifender": "nachpfeifend",
    "nachpfeifendere": "nachpfeifend",
    "nachpfeifenderem": "nachpfeifend",
    "nachpfeifenderen": "nachpfeifend",
    "nachpfeifenderer": "nachpfeifend",
    "nachpfeifenderes": "nachpfeifend",
    "nachpfeifendes": "nachpfeifend",
    "nachpfeifendste": "nachpfeifend",
    "nachpfeifendstem": "nachpfeifend",
    "nachpfeifendsten": "nachpfeifend",
    "nachpfeifendster": "nachpfeifend",
    "nachpfeifendstes": "nachpfeifend",
    "nachpfeifest": "nachpfeifen",
    "nachpfeifet": "nachpfeifen",
    "nachpfeifst": "nachpfeifen",
    "nachpfeift": "nachpfeifen",
    "nachpfiff": "nachpfeifen",
    "nachpfiffe": "nachpfeifen",
    "nachpfiffen": "nachpfeifen",
    "nachpfiffest": "nachpfeifen",
    "nachpfiffet": "nachpfeifen",
    "nachpfiffst": "nachpfeifen",
    "nachpfifft": "nachpfeifen",
    "nachprüfbare": "nachprüfbar",
    "nachprüfbarem": "nachprüfbar",
    "nachprüfbaren": "nachprüfbar",
    "nachprüfbarer": "nachprüfbar",
    "nachprüfbares": "nachprüfbar",
    "nachprüfe": "nachprüfen",
    "nachprüfend": "nachprüfen",
    "nachprüfende": "nachprüfend",
    "nachprüfendem": "nachprüfend",
    "nachprüfenden": "nachprüfend",
    "nachprüfender": "nachprüfend",
    "nachprüfendes": "nachprüfend",
    "nachprüfest": "nachprüfen",
    "nachprüfet": "nachprüfen",
    "nachprüfst": "nachprüfen",
    "nachprüft": "nachprüfen",
    "nachprüfte": "nachprüfen",
    "nachprüften": "nachprüfen",
    "nachprüftest": "nachprüfen",
    "nachprüftet": "nachprüfen",
    "nachrannte": "nachrennen",
    "nachrannten": "nachrennen",
    "nachranntest": "nachrennen",
    "nachranntet": "nachrennen",
    "nachrechne": "nachrechnen",
    "nachrechnend": "nachrechnen",
    "nachrechnende": "nachrechnend",
    "nachrechnendem": "nachrechnend",
    "nachrechnenden": "nachrechnend",
    "nachrechnender": "nachrechnend",
    "nachrechnendes": "nachrechnend",
    "nachrechnest": "nachrechnen",
    "nachrechnet": "nachrechnen",
    "nachrechnete": "nachrechnen",
    "nachrechneten": "nachrechnen",
    "nachrechnetest": "nachrechnen",
    "nachrechnetet": "nachrechnen",
    "nachrede": "nachreden",
    "nachredend": "nachreden",
    "nachredende": "nachredend",
    "nachredendem": "nachredend",
    "nachredenden": "nachredend",
    "nachredender": "nachredend",
    "nachredendes": "nachredend",
    "nachredest": "nachreden",
    "nachredet": "nachreden",
    "nachredete": "nachreden",
    "nachredeten": "nachreden",
    "nachredetest": "nachreden",
    "nachredetet": "nachreden",
    "nachreiche": "nachreichen",
    "nachreichend": "nachreichen",
    "nachreichende": "nachreichend",
    "nachreichendem": "nachreichend",
    "nachreichenden": "nachreichend",
    "nachreichender": "nachreichend",
    "nachreichendes": "nachreichend",
    "nachreichest": "nachreichen",
    "nachreichet": "nachreichen",
    "nachreichst": "nachreichen",
    "nachreicht": "nachreichen",
    "nachreichte": "nachreichen",
    "nachreichten": "nachreichen",
    "nachreichtest": "nachreichen",
    "nachreichtet": "nachreichen",
    "nachreife": "nachreifen",
    "nachreifend": "nachreifen",
    "nachreifende": "nachreifend",
    "nachreifendem": "nachreifend",
    "nachreifenden": "nachreifend",
    "nachreifender": "nachreifend",
    "nachreifendes": "nachreifend",
    "nachreifest": "nachreifen",
    "nachreifet": "nachreifen",
    "nachreifst": "nachreifen",
    "nachreift": "nachreifen",
    "nachreifte": "nachreifen",
    "nachreiften": "nachreifen",
    "nachreiftest": "nachreifen",
    "nachreiftet": "nachreifen",
    "nachreise": "nachreisen",
    "nachreisend": "nachreisen",
    "nachreisende": "nachreisend",
    "nachreisendem": "nachreisend",
    "nachreisenden": "nachreisend",
    "nachreisender": "nachreisend",
    "nachreisendes": "nachreisend",
    "nachreisest": "nachreisen",
    "nachreiset": "nachreisen",
    "nachreist": "nachreisen",
    "nachreiste": "nachreisen",
    "nachreisten": "nachreisen",
    "nachreistest": "nachreisen",
    "nachreistet": "nachreisen",
    "nachrenne": "nachrennen",
    "nachrennend": "nachrennen",
    "nachrennende": "nachrennend",
    "nachrennendem": "nachrennend",
    "nachrennenden": "nachrennend",
    "nachrennender": "nachrennend",
    "nachrennendes": "nachrennend",
    "nachrennest": "nachrennen",
    "nachrennet": "nachrennen",
    "nachrennst": "nachrennen",
    "nachrennt": "nachrennen",
    "nachrief": "nachrufen",
    "nachriefe": "nachrufen",
    "nachriefen": "nachrufen",
    "nachriefest": "nachrufen",
    "nachriefet": "nachrufen",
    "nachriefst": "nachrufen",
    "nachrieft": "nachrufen",
    "nachrufend": "nachrufen",
    "nachrufende": "nachrufend",
    "nachrufendem": "nachrufend",
    "nachrufenden": "nachrufend",
    "nachrufender": "nachrufend",
    "nachrufendes": "nachrufend",
    "nachrufest": "nachrufen",
    "nachrufet": "nachrufen",
    "nachrufst": "nachrufen",
    "nachruft": "nachrufen",
    "nachrühme": "nachrühmen",
    "nachrühmend": "nachrühmen",
    "nachrühmende": "nachrühmend",
    "nachrühmendem": "nachrühmend",
    "nachrühmenden": "nachrühmend",
    "nachrühmender": "nachrühmend",
    "nachrühmendes": "nachrühmend",
    "nachrühmest": "nachrühmen",
    "nachrühmet": "nachrühmen",
    "nachrühmst": "nachrühmen",
    "nachrühmt": "nachrühmen",
    "nachrühmte": "nachrühmen",
    "nachrühmten": "nachrühmen",
    "nachrühmtest": "nachrühmen",
    "nachrühmtet": "nachrühmen",
    "nachrüste": "nachrüsten",
    "nachrüstend": "nachrüsten",
    "nachrüstende": "nachrüstend",
    "nachrüstendem": "nachrüstend",
    "nachrüstenden": "nachrüstend",
    "nachrüstender": "nachrüstend",
    "nachrüstendes": "nachrüstend",
    "nachrüstest": "nachrüsten",
    "nachrüstet": "nachrüsten",
    "nachrüstete": "nachrüsten",
    "nachrüsteten": "nachrüsten",
    "nachrüstetest": "nachrüsten",
    "nachrüstetet": "nachrüsten",
    "nachsage": "nachsagen",
    "nachsagend": "nachsagen",
    "nachsagende": "nachsagend",
    "nachsagendem": "nachsagend",
    "nachsagenden": "nachsagend",
    "nachsagender": "nachsagend",
    "nachsagendes": "nachsagend",
    "nachsagest": "nachsagen",
    "nachsaget": "nachsagen",
    "nachsagst": "nachsagen",
    "nachsagt": "nachsagen",
    "nachsagte": "nachsagen",
    "nachsagten": "nachsagen",
    "nachsagtest": "nachsagen",
    "nachsagtet": "nachsagen",
    "nachsah": "nachsehen",
    "nachsahen": "nachsehen",
    "nachsahst": "nachsehen",
    "nachsaht": "nachsehen",
    "nachsandte": "nachsenden",
    "nachsandten": "nachsenden",
    "nachsandtest": "nachsenden",
    "nachsandtet": "nachsenden",
    "nachsang": "nachsingen",
    "nachsangen": "nachsingen",
    "nachsangst": "nachsingen",
    "nachsangt": "nachsingen",
    "nachsann": "nachsinnen",
    "nachsannen": "nachsinnen",
    "nachsannst": "nachsinnen",
    "nachsannt": "nachsinnen",
    "nachsaß": "nachsitzen",
    "nachsaßen": "nachsitzen",
    "nachsaßt": "nachsitzen",
    "nachschaffe": "nachschaffen",
    "nachschaffend": "nachschaffen",
    "nachschaffende": "nachschaffend",
    "nachschaffendem": "nachschaffend",
    "nachschaffenden": "nachschaffend",
    "nachschaffender": "nachschaffend",
    "nachschaffendes": "nachschaffend",
    "nachschaffest": "nachschaffen",
    "nachschaffet": "nachschaffen",
    "nachschaffst": "nachschaffen",
    "nachschafft": "nachschaffen",
    "nachschaffte": "nachschaffen",
    "nachschafften": "nachschaffen",
    "nachschafftest": "nachschaffen",
    "nachschafftet": "nachschaffen",
    "nachschaue": "nachschauen",
    "nachschauend": "nachschauen",
    "nachschauende": "nachschauend",
    "nachschauendem": "nachschauend",
    "nachschauenden": "nachschauend",
    "nachschauender": "nachschauend",
    "nachschauendes": "nachschauend",
    "nachschauest": "nachschauen",
    "nachschauet": "nachschauen",
    "nachschaust": "nachschauen",
    "nachschaut": "nachschauen",
    "nachschaute": "nachschauen",
    "nachschauten": "nachschauen",
    "nachschautest": "nachschauen",
    "nachschautet": "nachschauen",
    "nachschlage": "nachschlagen",
    "nachschlagend": "nachschlagen",
    "nachschlagende": "nachschlagend",
    "nachschlagendem": "nachschlagend",
    "nachschlagenden": "nachschlagend",
    "nachschlagender": "nachschlagend",
    "nachschlagendes": "nachschlagend",
    "nachschlagest": "nachschlagen",
    "nachschlaget": "nachschlagen",
    "nachschlagt": "nachschlagen",
    "nachschleiche": "nachschleichen",
    "nachschleichend": "nachschleichen",
    "nachschleichende": "nachschleichend",
    "nachschleichendem": "nachschleichend",
    "nachschleichenden": "nachschleichend",
    "nachschleichender": "nachschleichend",
    "nachschleichendes": "nachschleichend",
    "nachschleichest": "nachschleichen",
    "nachschleichet": "nachschleichen",
    "nachschleichst": "nachschleichen",
    "nachschleicht": "nachschleichen",
    "nachschleppe": "nachschleppen",
    "nachschleppend": "nachschleppen",
    "nachschleppende": "nachschleppend",
    "nachschleppendem": "nachschleppend",
    "nachschleppenden": "nachschleppend",
    "nachschleppender": "nachschleppend",
    "nachschleppendes": "nachschleppend",
    "nachschleppest": "nachschleppen",
    "nachschleppet": "nachschleppen",
    "nachschleppst": "nachschleppen",
    "nachschleppt": "nachschleppen",
    "nachschleppte": "nachschleppen",
    "nachschleppten": "nachschleppen",
    "nachschlepptest": "nachschleppen",
    "nachschlepptet": "nachschleppen",
    "nachschlich": "nachschleichen",
    "nachschliche": "nachschleichen",
    "nachschlichen": "nachschleichen",
    "nachschlichest": "nachschleichen",
    "nachschlichet": "nachschleichen",
    "nachschlichst": "nachschleichen",
    "nachschlicht": "nachschleichen",
    "nachschlug": "nachschlagen",
    "nachschlugen": "nachschlagen",
    "nachschlugst": "nachschlagen",
    "nachschlugt": "nachschlagen",
    "nachschlägst": "nachschlagen",
    "nachschlägt": "nachschlagen",
    "nachschlüge": "nachschlagen",
    "nachschlügen": "nachschlagen",
    "nachschlügest": "nachschlagen",
    "nachschlüget": "nachschlagen",
    "nachschmeiße": "nachschmeißen",
    "nachschmeißend": "nachschmeißen",
    "nachschmeißende": "nachschmeißend",
    "nachschmeißendem": "nachschmeißend",
    "nachschmeißenden": "nachschmeißend",
    "nachschmeißender": "nachschmeißend",
    "nachschmeißendes": "nachschmeißend",
    "nachschmeißest": "nachschmeißen",
    "nachschmeißet": "nachschmeißen",
    "nachschmeißt": "nachschmeißen",
    "nachschmisse": "nachschmeißen",
    "nachschmissen": "nachschmeißen",
    "nachschmissest": "nachschmeißen",
    "nachschmisset": "nachschmeißen",
    "nachschmiß": "nachschmeißen",
    "nachschmißt": "nachschmeißen",
    "nachschneide": "nachschneiden",
    "nachschneidend": "nachschneiden",
    "nachschneidende": "nachschneidend",
    "nachschneidendem": "nachschneidend",
    "nachschneidenden": "nachschneidend",
    "nachschneidender": "nachschneidend",
    "nachschneidendes": "nachschneidend",
    "nachschneidest": "nachschneiden",
    "nachschneidet": "nachschneiden",
    "nachschnitt": "nachschneiden",
    "nachschnitte": "nachschneiden",
    "nachschnitten": "nachschneiden",
    "nachschnittest": "nachschneiden",
    "nachschnittet": "nachschneiden",
    "nachschreibe": "nachschreiben",
    "nachschreibend": "nachschreiben",
    "nachschreibende": "nachschreibend",
    "nachschreibendem": "nachschreibend",
    "nachschreibenden": "nachschreibend",
    "nachschreibender": "nachschreibend",
    "nachschreibendes": "nachschreibend",
    "nachschreibest": "nachschreiben",
    "nachschreibet": "nachschreiben",
    "nachschreibst": "nachschreiben",
    "nachschreibt": "nachschreiben",
    "nachschrieb": "nachschreiben",
    "nachschriebe": "nachschreiben",
    "nachschrieben": "nachschreiben",
    "nachschriebest": "nachschreiben",
    "nachschriebet": "nachschreiben",
    "nachschriebst": "nachschreiben",
    "nachschriebt": "nachschreiben",
    "nachschuf": "nachschaffen",
    "nachschufen": "nachschaffen",
    "nachschufst": "nachschaffen",
    "nachschuft": "nachschaffen",
    "nachschwamm": "nachschwimmen",
    "nachschwammen": "nachschwimmen",
    "nachschwammst": "nachschwimmen",
    "nachschwammt": "nachschwimmen",
    "nachschwimme": "nachschwimmen",
    "nachschwimmend": "nachschwimmen",
    "nachschwimmende": "nachschwimmend",
    "nachschwimmendem": "nachschwimmend",
    "nachschwimmenden": "nachschwimmend",
    "nachschwimmender": "nachschwimmend",
    "nachschwimmendes": "nachschwimmend",
    "nachschwimmest": "nachschwimmen",
    "nachschwimmet": "nachschwimmen",
    "nachschwimmst": "nachschwimmen",
    "nachschwimmt": "nachschwimmen",
    "nachschwämme": "nachschwimmen",
    "nachschwämmen": "nachschwimmen",
    "nachschwämmest": "nachschwimmen",
    "nachschwämmet": "nachschwimmen",
    "nachschüfe": "nachschaffen",
    "nachschüfen": "nachschaffen",
    "nachschüfest": "nachschaffen",
    "nachschüfet": "nachschaffen",
    "nachschütte": "nachschütten",
    "nachschüttend": "nachschütten",
    "nachschüttende": "nachschüttend",
    "nachschüttendem": "nachschüttend",
    "nachschüttenden": "nachschüttend",
    "nachschüttender": "nachschüttend",
    "nachschüttendes": "nachschüttend",
    "nachschüttest": "nachschütten",
    "nachschüttet": "nachschütten",
    "nachschüttete": "nachschütten",
    "nachschütteten": "nachschütten",
    "nachschüttetest": "nachschütten",
    "nachschüttetet": "nachschütten",
    "nachsehe": "nachsehen",
    "nachsehend": "nachsehen",
    "nachsehende": "nachsehend",
    "nachsehendem": "nachsehend",
    "nachsehenden": "nachsehend",
    "nachsehender": "nachsehend",
    "nachsehendes": "nachsehend",
    "nachsehest": "nachsehen",
    "nachsehet": "nachsehen",
    "nachseht": "nachsehen",
    "nachsende": "nachsenden",
    "nachsendend": "nachsenden",
    "nachsendende": "nachsendend",
    "nachsendendem": "nachsendend",
    "nachsendenden": "nachsendend",
    "nachsendender": "nachsendend",
    "nachsendendes": "nachsendend",
    "nachsendest": "nachsenden",
    "nachsendet": "nachsenden",
    "nachsendete": "nachsenden",
    "nachsendeten": "nachsenden",
    "nachsendetest": "nachsenden",
    "nachsendetet": "nachsenden",
    "nachsetze": "nachsetzen",
    "nachsetzend": "nachsetzen",
    "nachsetzende": "nachsetzend",
    "nachsetzendem": "nachsetzend",
    "nachsetzenden": "nachsetzend",
    "nachsetzender": "nachsetzend",
    "nachsetzendere": "nachsetzend",
    "nachsetzenderem": "nachsetzend",
    "nachsetzenderen": "nachsetzend",
    "nachsetzenderer": "nachsetzend",
    "nachsetzenderes": "nachsetzend",
    "nachsetzendes": "nachsetzend",
    "nachsetzendste": "nachsetzend",
    "nachsetzendstem": "nachsetzend",
    "nachsetzendsten": "nachsetzend",
    "nachsetzendster": "nachsetzend",
    "nachsetzendstes": "nachsetzend",
    "nachsetzest": "nachsetzen",
    "nachsetzet": "nachsetzen",
    "nachsetzt": "nachsetzen",
    "nachsetzte": "nachsetzen",
    "nachsetzten": "nachsetzen",
    "nachsetztest": "nachsetzen",
    "nachsetztet": "nachsetzen",
    "nachsichtige": "nachsichtig",
    "nachsichtigem": "nachsichtig",
    "nachsichtigen": "nachsichtig",
    "nachsichtiger": "nachsichtig",
    "nachsichtigere": "nachsichtig",
    "nachsichtigerem": "nachsichtig",
    "nachsichtigeren": "nachsichtig",
    "nachsichtigerer": "nachsichtig",
    "nachsichtigeres": "nachsichtig",
    "nachsichtiges": "nachsichtig",
    "nachsichtigste": "nachsichtig",
    "nachsichtigstem": "nachsichtig",
    "nachsichtigsten": "nachsichtig",
    "nachsichtigster": "nachsichtig",
    "nachsichtigstes": "nachsichtig",
    "nachsiehst": "nachsehen",
    "nachsieht": "nachsehen",
    "nachsinge": "nachsingen",
    "nachsingend": "nachsingen",
    "nachsingende": "nachsingend",
    "nachsingendem": "nachsingend",
    "nachsingenden": "nachsingend",
    "nachsingender": "nachsingend",
    "nachsingendere": "nachsingend",
    "nachsingenderem": "nachsingend",
    "nachsingenderen": "nachsingend",
    "nachsingenderer": "nachsingend",
    "nachsingenderes": "nachsingend",
    "nachsingendes": "nachsingend",
    "nachsingendste": "nachsingend",
    "nachsingendstem": "nachsingend",
    "nachsingendsten": "nachsingend",
    "nachsingendster": "nachsingend",
    "nachsingendstes": "nachsingend",
    "nachsingest": "nachsingen",
    "nachsinget": "nachsingen",
    "nachsingst": "nachsingen",
    "nachsingt": "nachsingen",
    "nachsinne": "nachsinnen",
    "nachsinnend": "nachsinnen",
    "nachsinnende": "nachsinnend",
    "nachsinnendem": "nachsinnend",
    "nachsinnenden": "nachsinnend",
    "nachsinnender": "nachsinnend",
    "nachsinnendere": "nachsinnend",
    "nachsinnenderem": "nachsinnend",
    "nachsinnenderen": "nachsinnend",
    "nachsinnenderer": "nachsinnend",
    "nachsinnenderes": "nachsinnend",
    "nachsinnendes": "nachsinnend",
    "nachsinnendste": "nachsinnend",
    "nachsinnendstem": "nachsinnend",
    "nachsinnendsten": "nachsinnend",
    "nachsinnendster": "nachsinnend",
    "nachsinnendstes": "nachsinnend",
    "nachsinnest": "nachsinnen",
    "nachsinnet": "nachsinnen",
    "nachsinnst": "nachsinnen",
    "nachsinnt": "nachsinnen",
    "nachsitze": "nachsitzen",
    "nachsitzend": "nachsitzen",
    "nachsitzende": "nachsitzend",
    "nachsitzendem": "nachsitzend",
    "nachsitzenden": "nachsitzend",
    "nachsitzender": "nachsitzend",
    "nachsitzendes": "nachsitzend",
    "nachsitzest": "nachsitzen",
    "nachsitzet": "nachsitzen",
    "nachsitzt": "nachsitzen",
    "nachspiele": "nachspielen",
    "nachspielend": "nachspielen",
    "nachspielende": "nachspielend",
    "nachspielendem": "nachspielend",
    "nachspielenden": "nachspielend",
    "nachspielender": "nachspielend",
    "nachspielendes": "nachspielend",
    "nachspielest": "nachspielen",
    "nachspielet": "nachspielen",
    "nachspielst": "nachspielen",
    "nachspielt": "nachspielen",
    "nachspielte": "nachspielen",
    "nachspielten": "nachspielen",
    "nachspieltest": "nachspielen",
    "nachspieltet": "nachspielen",
    "nachsprach": "nachsprechen",
    "nachsprachen": "nachsprechen",
    "nachsprachst": "nachsprechen",
    "nachspracht": "nachsprechen",
    "nachsprang": "nachspringen",
    "nachsprangen": "nachspringen",
    "nachsprangst": "nachspringen",
    "nachsprangt": "nachspringen",
    "nachspreche": "nachsprechen",
    "nachsprechend": "nachsprechen",
    "nachsprechende": "nachsprechend",
    "nachsprechendem": "nachsprechend",
    "nachsprechenden": "nachsprechend",
    "nachsprechender": "nachsprechend",
    "nachsprechendere": "nachsprechend",
    "nachsprechenderem": "nachsprechend",
    "nachsprechenderen": "nachsprechend",
    "nachsprechenderer": "nachsprechend",
    "nachsprechenderes": "nachsprechend",
    "nachsprechendes": "nachsprechend",
    "nachsprechendste": "nachsprechend",
    "nachsprechendstem": "nachsprechend",
    "nachsprechendsten": "nachsprechend",
    "nachsprechendster": "nachsprechend",
    "nachsprechendstes": "nachsprechend",
    "nachsprechest": "nachsprechen",
    "nachsprechet": "nachsprechen",
    "nachsprecht": "nachsprechen",
    "nachsprichst": "nachsprechen",
    "nachspricht": "nachsprechen",
    "nachspringe": "nachspringen",
    "nachspringend": "nachspringen",
    "nachspringende": "nachspringend",
    "nachspringendem": "nachspringend",
    "nachspringenden": "nachspringend",
    "nachspringender": "nachspringend",
    "nachspringendes": "nachspringend",
    "nachspringest": "nachspringen",
    "nachspringet": "nachspringen",
    "nachspringst": "nachspringen",
    "nachspringt": "nachspringen",
    "nachspräche": "nachsprechen",
    "nachsprächen": "nachsprechen",
    "nachsprächest": "nachsprechen",
    "nachsprächet": "nachsprechen",
    "nachspränge": "nachspringen",
    "nachsprängen": "nachspringen",
    "nachsprängest": "nachspringen",
    "nachspränget": "nachspringen",
    "nachspüle": "nachspülen",
    "nachspülend": "nachspülen",
    "nachspülende": "nachspülend",
    "nachspülendem": "nachspülend",
    "nachspülenden": "nachspülend",
    "nachspülender": "nachspülend",
    "nachspülendes": "nachspülend",
    "nachspülest": "nachspülen",
    "nachspület": "nachspülen",
    "nachspülst": "nachspülen",
    "nachspült": "nachspülen",
    "nachspülte": "nachspülen",
    "nachspülten": "nachspülen",
    "nachspültest": "nachspülen",
    "nachspültet": "nachspülen",
    "nachspüre": "nachspüren",
    "nachspürend": "nachspüren",
    "nachspürende": "nachspürend",
    "nachspürendem": "nachspürend",
    "nachspürenden": "nachspürend",
    "nachspürender": "nachspürend",
    "nachspürendere": "nachspürend",
    "nachspürenderem": "nachspürend",
    "nachspürenderen": "nachspürend",
    "nachspürenderer": "nachspürend",
    "nachspürenderes": "nachspürend",
    "nachspürendes": "nachspürend",
    "nachspürendste": "nachspürend",
    "nachspürendstem": "nachspürend",
    "nachspürendsten": "nachspürend",
    "nachspürendster": "nachspürend",
    "nachspürendstes": "nachspürend",
    "nachspürest": "nachspüren",
    "nachspüret": "nachspüren",
    "nachspürst": "nachspüren",
    "nachspürt": "nachspüren",
    "nachspürte": "nachspüren",
    "nachspürten": "nachspüren",
    "nachspürtest": "nachspüren",
    "nachspürtet": "nachspüren",
    "nachstand": "nachstehen",
    "nachstanden": "nachstehen",
    "nachstandest": "nachstehen",
    "nachstandet": "nachstehen",
    "nachstehe": "nachstehen",
    "nachstehend": "nachstehen",
    "nachstehende": "nachstehend",
    "nachstehendem": "nachstehend",
    "nachstehenden": "nachstehend",
    "nachstehender": "nachstehend",
    "nachstehendes": "nachstehend",
    "nachstehest": "nachstehen",
    "nachstehet": "nachstehen",
    "nachstehst": "nachstehen",
    "nachsteht": "nachstehen",
    "nachsteige": "nachsteigen",
    "nachsteigend": "nachsteigen",
    "nachsteigende": "nachsteigend",
    "nachsteigendem": "nachsteigend",
    "nachsteigenden": "nachsteigend",
    "nachsteigender": "nachsteigend",
    "nachsteigendes": "nachsteigend",
    "nachsteigest": "nachsteigen",
    "nachsteiget": "nachsteigen",
    "nachsteigst": "nachsteigen",
    "nachsteigt": "nachsteigen",
    "nachstelle": "nachstellen",
    "nachstellend": "nachstellen",
    "nachstellende": "nachstellend",
    "nachstellendem": "nachstellend",
    "nachstellenden": "nachstellend",
    "nachstellender": "nachstellend",
    "nachstellendes": "nachstellend",
    "nachstellest": "nachstellen",
    "nachstellet": "nachstellen",
    "nachstellst": "nachstellen",
    "nachstellt": "nachstellen",
    "nachstellte": "nachstellen",
    "nachstellten": "nachstellen",
    "nachstelltest": "nachstellen",
    "nachstelltet": "nachstellen",
    "nachstieg": "nachsteigen",
    "nachstiege": "nachsteigen",
    "nachstiegen": "nachsteigen",
    "nachstiegest": "nachsteigen",
    "nachstieget": "nachsteigen",
    "nachstiegst": "nachsteigen",
    "nachstiegt": "nachsteigen",
    "nachstimme": "nachstimmen",
    "nachstimmend": "nachstimmen",
    "nachstimmende": "nachstimmend",
    "nachstimmendem": "nachstimmend",
    "nachstimmenden": "nachstimmend",
    "nachstimmender": "nachstimmend",
    "nachstimmendes": "nachstimmend",
    "nachstimmest": "nachstimmen",
    "nachstimmet": "nachstimmen",
    "nachstimmst": "nachstimmen",
    "nachstimmt": "nachstimmen",
    "nachstimmte": "nachstimmen",
    "nachstimmten": "nachstimmen",
    "nachstimmtest": "nachstimmen",
    "nachstimmtet": "nachstimmen",
    "nachstrebe": "nachstreben",
    "nachstrebend": "nachstreben",
    "nachstrebende": "nachstrebend",
    "nachstrebendem": "nachstrebend",
    "nachstrebenden": "nachstrebend",
    "nachstrebender": "nachstrebend",
    "nachstrebendere": "nachstrebend",
    "nachstrebenderem": "nachstrebend",
    "nachstrebenderen": "nachstrebend",
    "nachstrebenderer": "nachstrebend",
    "nachstrebenderes": "nachstrebend",
    "nachstrebendes": "nachstrebend",
    "nachstrebendste": "nachstrebend",
    "nachstrebendstem": "nachstrebend",
    "nachstrebendsten": "nachstrebend",
    "nachstrebendster": "nachstrebend",
    "nachstrebendstes": "nachstrebend",
    "nachstrebest": "nachstreben",
    "nachstrebet": "nachstreben",
    "nachstrebst": "nachstreben",
    "nachstrebt": "nachstreben",
    "nachstrebte": "nachstreben",
    "nachstrebten": "nachstreben",
    "nachstrebtest": "nachstreben",
    "nachstrebtet": "nachstreben",
    "nachstünde": "nachstehen",
    "nachstünden": "nachstehen",
    "nachstündest": "nachstehen",
    "nachstündet": "nachstehen",
    "nachstürze": "nachstürzen",
    "nachstürzend": "nachstürzen",
    "nachstürzende": "nachstürzend",
    "nachstürzendem": "nachstürzend",
    "nachstürzenden": "nachstürzend",
    "nachstürzender": "nachstürzend",
    "nachstürzendes": "nachstürzend",
    "nachstürzest": "nachstürzen",
    "nachstürzet": "nachstürzen",
    "nachstürzt": "nachstürzen",
    "nachstürzte": "nachstürzen",
    "nachstürzten": "nachstürzen",
    "nachstürztest": "nachstürzen",
    "nachstürztet": "nachstürzen",
    "nachsuche": "nachsuchen",
    "nachsuchend": "nachsuchen",
    "nachsuchende": "nachsuchend",
    "nachsuchendem": "nachsuchend",
    "nachsuchenden": "nachsuchend",
    "nachsuchender": "nachsuchend",
    "nachsuchendes": "nachsuchend",
    "nachsuchest": "nachsuchen",
    "nachsuchet": "nachsuchen",
    "nachsuchst": "nachsuchen",
    "nachsucht": "nachsuchen",
    "nachsuchte": "nachsuchen",
    "nachsuchten": "nachsuchen",
    "nachsuchtest": "nachsuchen",
    "nachsuchtet": "nachsuchen",
    "nachsähe": "nachsehen",
    "nachsähen": "nachsehen",
    "nachsähest": "nachsehen",
    "nachsähet": "nachsehen",
    "nachsänge": "nachsingen",
    "nachsängen": "nachsingen",
    "nachsängest": "nachsingen",
    "nachsänget": "nachsingen",
    "nachsänne": "nachsinnen",
    "nachsännen": "nachsinnen",
    "nachsännest": "nachsinnen",
    "nachsännet": "nachsinnen",
    "nachsäße": "nachsitzen",
    "nachsäßen": "nachsitzen",
    "nachsäßest": "nachsitzen",
    "nachsäßet": "nachsitzen",
    "nachtanke": "nachtanken",
    "nachtankend": "nachtanken",
    "nachtankende": "nachtankend",
    "nachtankendem": "nachtankend",
    "nachtankenden": "nachtankend",
    "nachtankender": "nachtankend",
    "nachtankendes": "nachtankend",
    "nachtankest": "nachtanken",
    "nachtanket": "nachtanken",
    "nachtankst": "nachtanken",
    "nachtankt": "nachtanken",
    "nachtankte": "nachtanken",
    "nachtankten": "nachtanken",
    "nachtanktest": "nachtanken",
    "nachtanktet": "nachtanken",
    "nachtragend": "nachtragen",
    "nachtragende": "nachtragend",
    "nachtragendem": "nachtragend",
    "nachtragenden": "nachtragend",
    "nachtragender": "nachtragend",
    "nachtragendere": "nachtragend",
    "nachtragenderem": "nachtragend",
    "nachtragenderen": "nachtragend",
    "nachtragenderer": "nachtragend",
    "nachtragenderes": "nachtragend",
    "nachtragendes": "nachtragend",
    "nachtragendste": "nachtragend",
    "nachtragendstem": "nachtragend",
    "nachtragendsten": "nachtragend",
    "nachtragendster": "nachtragend",
    "nachtragendstes": "nachtragend",
    "nachtragest": "nachtragen",
    "nachtraget": "nachtragen",
    "nachtragt": "nachtragen",
    "nachtrauere": "nachtrauern",
    "nachtrauernd": "nachtrauern",
    "nachtrauernde": "nachtrauernd",
    "nachtrauerndem": "nachtrauernd",
    "nachtrauernden": "nachtrauernd",
    "nachtrauernder": "nachtrauernd",
    "nachtrauerndes": "nachtrauernd",
    "nachtrauerst": "nachtrauern",
    "nachtrauert": "nachtrauern",
    "nachtrauerte": "nachtrauern",
    "nachtrauerten": "nachtrauern",
    "nachtrauertest": "nachtrauern",
    "nachtrauertet": "nachtrauern",
    "nachtrug": "nachtragen",
    "nachtrugen": "nachtragen",
    "nachtrugst": "nachtragen",
    "nachtrugt": "nachtragen",
    "nachträgliche": "nachträglich",
    "nachträglichem": "nachträglich",
    "nachträglichen": "nachträglich",
    "nachträglicher": "nachträglich",
    "nachträgliches": "nachträglich",
    "nachträgst": "nachtragen",
    "nachträgt": "nachtragen",
    "nachtrüge": "nachtragen",
    "nachtrügen": "nachtragen",
    "nachtrügest": "nachtragen",
    "nachtrüget": "nachtragen",
    "nachtschlafendem": "nachtschlafend",
    "nachtschlafenden": "nachtschlafend",
    "nachtschlafender": "nachtschlafend",
    "nachtschlafendes": "nachtschlafend",
    "nachtwandlerischem": "nachtwandlerisch",
    "nachtwandlerischen": "nachtwandlerisch",
    "nachtwandlerischer": "nachtwandlerisch",
    "nachtwandlerisches": "nachtwandlerisch",
    "nachtöne": "nachtönen",
    "nachtönend": "nachtönen",
    "nachtönende": "nachtönend",
    "nachtönendem": "nachtönend",
    "nachtönenden": "nachtönend",
    "nachtönender": "nachtönend",
    "nachtönendes": "nachtönend",
    "nachtönest": "nachtönen",
    "nachtönet": "nachtönen",
    "nachtönst": "nachtönen",
    "nachtönt": "nachtönen",
    "nachtönte": "nachtönen",
    "nachtönten": "nachtönen",
    "nachtöntest": "nachtönen",
    "nachtöntet": "nachtönen",
    "nachversichere": "nachversichern",
    "nachversichernd": "nachversichern",
    "nachversichernde": "nachversichernd",
    "nachversicherndem": "nachversichernd",
    "nachversichernden": "nachversichernd",
    "nachversichernder": "nachversichernd",
    "nachversicherndes": "nachversichernd",
    "nachversicherst": "nachversichern",
    "nachversichert": "nachversichern",
    "nachversicherte": "nachversichern",
    "nachversichertem": "nachversichert",
    "nachversicherten": "nachversichern",
    "nachversicherter": "nachversichert",
    "nachversichertes": "nachversichert",
    "nachversichertest": "nachversichern",
    "nachversichertet": "nachversichern",
    "nachvertone": "nachvertonen",
    "nachvertonend": "nachvertonen",
    "nachvertonende": "nachvertonend",
    "nachvertonendem": "nachvertonend",
    "nachvertonenden": "nachvertonend",
    "nachvertonender": "nachvertonend",
    "nachvertonendes": "nachvertonend",
    "nachvertonest": "nachvertonen",
    "nachvertonet": "nachvertonen",
    "nachvertonst": "nachvertonen",
    "nachvertont": "nachvertonen",
    "nachvertonte": "nachvertonen",
    "nachvertontem": "nachvertont",
    "nachvertonten": "nachvertonen",
    "nachvertonter": "nachvertont",
    "nachvertontes": "nachvertont",
    "nachvertontest": "nachvertonen",
    "nachvertontet": "nachvertonen",
    "nachvollziehbare": "nachvollziehbar",
    "nachvollziehbarem": "nachvollziehbar",
    "nachvollziehbaren": "nachvollziehbar",
    "nachvollziehbarer": "nachvollziehbar",
    "nachvollziehbares": "nachvollziehbar",
    "nachvollziehe": "nachvollziehen",
    "nachvollziehend": "nachvollziehen",
    "nachvollziehende": "nachvollziehend",
    "nachvollziehendem": "nachvollziehend",
    "nachvollziehenden": "nachvollziehend",
    "nachvollziehender": "nachvollziehend",
    "nachvollziehendere": "nachvollziehend",
    "nachvollziehenderem": "nachvollziehend",
    "nachvollziehenderen": "nachvollziehend",
    "nachvollziehenderer": "nachvollziehend",
    "nachvollziehenderes": "nachvollziehend",
    "nachvollziehendes": "nachvollziehend",
    "nachvollziehendste": "nachvollziehend",
    "nachvollziehendstem": "nachvollziehend",
    "nachvollziehendsten": "nachvollziehend",
    "nachvollziehendster": "nachvollziehend",
    "nachvollziehendstes": "nachvollziehend",
    "nachvollziehest": "nachvollziehen",
    "nachvollziehet": "nachvollziehen",
    "nachvollziehst": "nachvollziehen",
    "nachvollzieht": "nachvollziehen",
    "nachvollzog": "nachvollziehen",
    "nachvollzogen": "nachvollziehen",
    "nachvollzogene": "nachvollzogen",
    "nachvollzogenem": "nachvollzogen",
    "nachvollzogenen": "nachvollzogen",
    "nachvollzogener": "nachvollzogen",
    "nachvollzogenere": "nachvollzogen",
    "nachvollzogenerem": "nachvollzogen",
    "nachvollzogeneren": "nachvollzogen",
    "nachvollzogenerer": "nachvollzogen",
    "nachvollzogeneres": "nachvollzogen",
    "nachvollzogenes": "nachvollzogen",
    "nachvollzogenste": "nachvollzogen",
    "nachvollzogenstem": "nachvollzogen",
    "nachvollzogensten": "nachvollzogen",
    "nachvollzogenster": "nachvollzogen",
    "nachvollzogenstes": "nachvollzogen",
    "nachvollzogst": "nachvollziehen",
    "nachvollzogt": "nachvollziehen",
    "nachvollzöge": "nachvollziehen",
    "nachvollzögen": "nachvollziehen",
    "nachvollzögest": "nachvollziehen",
    "nachvollzöget": "nachvollziehen",
    "nachwachse": "nachwachsen",
    "nachwachsend": "nachwachsen",
    "nachwachsende": "nachwachsend",
    "nachwachsendem": "nachwachsend",
    "nachwachsenden": "nachwachsend",
    "nachwachsender": "nachwachsend",
    "nachwachsendes": "nachwachsend",
    "nachwachsest": "nachwachsen",
    "nachwachset": "nachwachsen",
    "nachwachst": "nachwachsen",
    "nachwachste": "nachwachsen",
    "nachwachsten": "nachwachsen",
    "nachwachstest": "nachwachsen",
    "nachwachstet": "nachwachsen",
    "nachwarf": "nachwerfen",
    "nachwarfen": "nachwerfen",
    "nachwarfst": "nachwerfen",
    "nachwarft": "nachwerfen",
    "nachweine": "nachweinen",
    "nachweinend": "nachweinen",
    "nachweinende": "nachweinend",
    "nachweinendem": "nachweinend",
    "nachweinenden": "nachweinend",
    "nachweinender": "nachweinend",
    "nachweinendes": "nachweinend",
    "nachweinest": "nachweinen",
    "nachweinet": "nachweinen",
    "nachweinst": "nachweinen",
    "nachweint": "nachweinen",
    "nachweinte": "nachweinen",
    "nachweinten": "nachweinen",
    "nachweintest": "nachweinen",
    "nachweintet": "nachweinen",
    "nachweisbare": "nachweisbar",
    "nachweisbarem": "nachweisbar",
    "nachweisbaren": "nachweisbar",
    "nachweisbarer": "nachweisbar",
    "nachweisbares": "nachweisbar",
    "nachweisend": "nachweisen",
    "nachweisende": "nachweisend",
    "nachweisendem": "nachweisend",
    "nachweisenden": "nachweisend",
    "nachweisender": "nachweisend",
    "nachweisendes": "nachweisend",
    "nachweisest": "nachweisen",
    "nachweiset": "nachweisen",
    "nachweisliche": "nachweislich",
    "nachweislichem": "nachweislich",
    "nachweislichen": "nachweislich",
    "nachweislicher": "nachweislich",
    "nachweisliches": "nachweislich",
    "nachweist": "nachweisen",
    "nachwerfe": "nachwerfen",
    "nachwerfend": "nachwerfen",
    "nachwerfende": "nachwerfend",
    "nachwerfendem": "nachwerfend",
    "nachwerfenden": "nachwerfend",
    "nachwerfender": "nachwerfend",
    "nachwerfendes": "nachwerfend",
    "nachwerfest": "nachwerfen",
    "nachwerfet": "nachwerfen",
    "nachwerft": "nachwerfen",
    "nachwiege": "nachwiegen",
    "nachwiegend": "nachwiegen",
    "nachwiegende": "nachwiegend",
    "nachwiegendem": "nachwiegend",
    "nachwiegenden": "nachwiegend",
    "nachwiegender": "nachwiegend",
    "nachwiegendes": "nachwiegend",
    "nachwiegest": "nachwiegen",
    "nachwieget": "nachwiegen",
    "nachwiegst": "nachwiegen",
    "nachwiegt": "nachwiegen",
    "nachwies": "nachweisen",
    "nachwiese": "nachweisen",
    "nachwiesen": "nachweisen",
    "nachwiesest": "nachweisen",
    "nachwieset": "nachweisen",
    "nachwiest": "nachweisen",
    "nachwinke": "nachwinken",
    "nachwinkend": "nachwinken",
    "nachwinkende": "nachwinkend",
    "nachwinkendem": "nachwinkend",
    "nachwinkenden": "nachwinkend",
    "nachwinkender": "nachwinkend",
    "nachwinkendes": "nachwinkend",
    "nachwinkest": "nachwinken",
    "nachwinket": "nachwinken",
    "nachwinkst": "nachwinken",
    "nachwinkt": "nachwinken",
    "nachwinkte": "nachwinken",
    "nachwinkten": "nachwinken",
    "nachwinktest": "nachwinken",
    "nachwinktet": "nachwinken",
    "nachwirfst": "nachwerfen",
    "nachwirft": "nachwerfen",
    "nachwirke": "nachwirken",
    "nachwirkend": "nachwirken",
    "nachwirkende": "nachwirkend",
    "nachwirkendem": "nachwirkend",
    "nachwirkenden": "nachwirkend",
    "nachwirkender": "nachwirkend",
    "nachwirkendere": "nachwirkend",
    "nachwirkenderem": "nachwirkend",
    "nachwirkenderen": "nachwirkend",
    "nachwirkenderer": "nachwirkend",
    "nachwirkenderes": "nachwirkend",
    "nachwirkendes": "nachwirkend",
    "nachwirkendste": "nachwirkend",
    "nachwirkendstem": "nachwirkend",
    "nachwirkendsten": "nachwirkend",
    "nachwirkendster": "nachwirkend",
    "nachwirkendstes": "nachwirkend",
    "nachwirkest": "nachwirken",
    "nachwirket": "nachwirken",
    "nachwirkst": "nachwirken",
    "nachwirkt": "nachwirken",
    "nachwirkte": "nachwirken",
    "nachwirkten": "nachwirken",
    "nachwirktest": "nachwirken",
    "nachwirktet": "nachwirken",
    "nachwog": "nachwiegen",
    "nachwogen": "nachwiegen",
    "nachwogst": "nachwiegen",
    "nachwogt": "nachwiegen",
    "nachwuchs": "nachwachsen",
    "nachwuchsen": "nachwachsen",
    "nachwuchst": "nachwachsen",
    "nachwächst": "nachwachsen",
    "nachwärfe": "nachwerfen",
    "nachwärfen": "nachwerfen",
    "nachwärfest": "nachwerfen",
    "nachwärfet": "nachwerfen",
    "nachwöge": "nachwiegen",
    "nachwögen": "nachwiegen",
    "nachwögest": "nachwiegen",
    "nachwöget": "nachwiegen",
    "nachwüchsen": "nachwachsen",
    "nachwüchsest": "nachwachsen",
    "nachwüchset": "nachwachsen",
    "nachzahle": "nachzahlen",
    "nachzahlend": "nachzahlen",
    "nachzahlende": "nachzahlend",
    "nachzahlendem": "nachzahlend",
    "nachzahlenden": "nachzahlend",
    "nachzahlender": "nachzahlend",
    "nachzahlendes": "nachzahlend",
    "nachzahlest": "nachzahlen",
    "nachzahlet": "nachzahlen",
    "nachzahlst": "nachzahlen",
    "nachzahlt": "nachzahlen",
    "nachzahlte": "nachzahlen",
    "nachzahlten": "nachzahlen",
    "nachzahltest": "nachzahlen",
    "nachzahltet": "nachzahlen",
    "nachzeichne": "nachzeichnen",
    "nachzeichnend": "nachzeichnen",
    "nachzeichnende": "nachzeichnend",
    "nachzeichnendem": "nachzeichnend",
    "nachzeichnenden": "nachzeichnend",
    "nachzeichnender": "nachzeichnend",
    "nachzeichnendes": "nachzeichnend",
    "nachzeichnest": "nachzeichnen",
    "nachzeichnet": "nachzeichnen",
    "nachzeichnete": "nachzeichnen",
    "nachzeichneten": "nachzeichnen",
    "nachzeichnetest": "nachzeichnen",
    "nachzeichnetet": "nachzeichnen",
    "nachziehe": "nachziehen",
    "nachziehend": "nachziehen",
    "nachziehende": "nachziehend",
    "nachziehendem": "nachziehend",
    "nachziehenden": "nachziehend",
    "nachziehender": "nachziehend",
    "nachziehendes": "nachziehend",
    "nachziehest": "nachziehen",
    "nachziehet": "nachziehen",
    "nachziehst": "nachziehen",
    "nachzieht": "nachziehen",
    "nachzog": "nachziehen",
    "nachzogen": "nachziehen",
    "nachzogst": "nachziehen",
    "nachzogt": "nachziehen",
    "nachzuahmen": "nachahmen",
    "nachzuarbeiten": "nacharbeiten",
    "nachzubauen": "nachbauen",
    "nachzuberechnen": "nachberechnen",
    "nachzubereiten": "nachbereiten",
    "nachzubestellen": "nachbestellen",
    "nachzubeten": "nachbeten",
    "nachzubilden": "nachbilden",
    "nachzubleiben": "nachbleiben",
    "nachzubleichen": "nachbleichen",
    "nachzublicken": "nachblicken",
    "nachzubluten": "nachbluten",
    "nachzubohren": "nachbohren",
    "nachzubringen": "nachbringen",
    "nachzudatieren": "nachdatieren",
    "nachzudenken": "nachdenken",
    "nachzudichten": "nachdichten",
    "nachzudringen": "nachdringen",
    "nachzudrucken": "nachdrucken",
    "nachzudrängen": "nachdrängen",
    "nachzudunkeln": "nachdunkeln",
    "nachzueifern": "nacheifern",
    "nachzueilen": "nacheilen",
    "nachzuempfinden": "nachempfinden",
    "nachzuerzählen": "nacherzählen",
    "nachzuessen": "nachessen",
    "nachzufahren": "nachfahren",
    "nachzufassen": "nachfassen",
    "nachzufeiern": "nachfeiern",
    "nachzufilmen": "nachfilmen",
    "nachzufolgen": "nachfolgen",
    "nachzufordern": "nachfordern",
    "nachzuforschen": "nachforschen",
    "nachzufragen": "nachfragen",
    "nachzufühlen": "nachfühlen",
    "nachzufüllen": "nachfüllen",
    "nachzugeben": "nachgeben",
    "nachzugehen": "nachgehen",
    "nachzugeraten": "nachgeraten",
    "nachzugießen": "nachgießen",
    "nachzugrübeln": "nachgrübeln",
    "nachzugären": "nachgären",
    "nachzuhaken": "nachhaken",
    "nachzuhallen": "nachhallen",
    "nachzuhelfen": "nachhelfen",
    "nachzuhinken": "nachhinken",
    "nachzuholen": "nachholen",
    "nachzuhängen": "nachhängen",
    "nachzuimpfen": "nachimpfen",
    "nachzujagen": "nachjagen",
    "nachzukarten": "nachkarten",
    "nachzukaufen": "nachkaufen",
    "nachzuklingen": "nachklingen",
    "nachzukommen": "nachkommen",
    "nachzukontrollieren": "nachkontrollieren",
    "nachzuladen": "nachladen",
    "nachzulassen": "nachlassen",
    "nachzulaufen": "nachlaufen",
    "nachzuleben": "nachleben",
    "nachzulegen": "nachlegen",
    "nachzulernen": "nachlernen",
    "nachzulesen": "nachlesen",
    "nachzuliefern": "nachliefern",
    "nachzulösen": "nachlösen",
    "nachzumachen": "nachmachen",
    "nachzumalen": "nachmalen",
    "nachzumelden": "nachmelden",
    "nachzumessen": "nachmessen",
    "nachzunehmen": "nachnehmen",
    "nachzupfeifen": "nachpfeifen",
    "nachzuprüfen": "nachprüfen",
    "nachzurechnen": "nachrechnen",
    "nachzureden": "nachreden",
    "nachzureichen": "nachreichen",
    "nachzureifen": "nachreifen",
    "nachzureisen": "nachreisen",
    "nachzurennen": "nachrennen",
    "nachzurufen": "nachrufen",
    "nachzurühmen": "nachrühmen",
    "nachzurüsten": "nachrüsten",
    "nachzusagen": "nachsagen",
    "nachzuschaffen": "nachschaffen",
    "nachzuschauen": "nachschauen",
    "nachzuschlagen": "nachschlagen",
    "nachzuschleichen": "nachschleichen",
    "nachzuschleppen": "nachschleppen",
    "nachzuschmeißen": "nachschmeißen",
    "nachzuschneiden": "nachschneiden",
    "nachzuschreiben": "nachschreiben",
    "nachzuschwimmen": "nachschwimmen",
    "nachzuschütten": "nachschütten",
    "nachzusehen": "nachsehen",
    "nachzusenden": "nachsenden",
    "nachzusetzen": "nachsetzen",
    "nachzusingen": "nachsingen",
    "nachzusinnen": "nachsinnen",
    "nachzusitzen": "nachsitzen",
    "nachzuspielen": "nachspielen",
    "nachzusprechen": "nachsprechen",
    "nachzuspringen": "nachspringen",
    "nachzuspülen": "nachspülen",
    "nachzuspüren": "nachspüren",
    "nachzustehen": "nachstehen",
    "nachzusteigen": "nachsteigen",
    "nachzustellen": "nachstellen",
    "nachzustimmen": "nachstimmen",
    "nachzustreben": "nachstreben",
    "nachzustürzen": "nachstürzen",
    "nachzusuchen": "nachsuchen",
    "nachzutanken": "nachtanken",
    "nachzutragen": "nachtragen",
    "nachzutrauern": "nachtrauern",
    "nachzutönen": "nachtönen",
    "nachzuversichern": "nachversichern",
    "nachzuvertonen": "nachvertonen",
    "nachzuvollziehen": "nachvollziehen",
    "nachzuwachsen": "nachwachsen",
    "nachzuweinen": "nachweinen",
    "nachzuweisen": "nachweisen",
    "nachzuwerfen": "nachwerfen",
    "nachzuwiegen": "nachwiegen",
    "nachzuwinken": "nachwinken",
    "nachzuwirken": "nachwirken",
    "nachzuzahlen": "nachzahlen",
    "nachzuzeichnen": "nachzeichnen",
    "nachzuziehen": "nachziehen",
    "nachzuzählen": "nachzählen",
    "nachzuäffen": "nachäffen",
    "nachzähle": "nachzählen",
    "nachzählend": "nachzählen",
    "nachzählendem": "nachzählend",
    "nachzählender": "nachzählend",
    "nachzählendes": "nachzählend",
    "nachzählest": "nachzählen",
    "nachzählet": "nachzählen",
    "nachzählst": "nachzählen",
    "nachzählt": "nachzählen",
    "nachzählte": "nachzählen",
    "nachzählten": "nachzählen",
    "nachzähltest": "nachzählen",
    "nachzähltet": "nachzählen",
    "nachzöge": "nachziehen",
    "nachzögen": "nachziehen",
    "nachzögest": "nachziehen",
    "nachzöget": "nachziehen",
    "nachäffe": "nachäffen",
    "nachäffend": "nachäffen",
    "nachäffende": "nachäffend",
    "nachäffendem": "nachäffend",
    "nachäffenden": "nachäffend",
    "nachäffender": "nachäffend",
    "nachäffendere": "nachäffend",
    "nachäffenderem": "nachäffend",
    "nachäffenderen": "nachäffend",
    "nachäffenderer": "nachäffend",
    "nachäffenderes": "nachäffend",
    "nachäffendes": "nachäffend",
    "nachäffendste": "nachäffend",
    "nachäffendstem": "nachäffend",
    "nachäffendsten": "nachäffend",
    "nachäffendster": "nachäffend",
    "nachäffendstes": "nachäffend",
    "nachäffest": "nachäffen",
    "nachäffet": "nachäffen",
    "nachäffst": "nachäffen",
    "nachäfft": "nachäffen",
    "nachäffte": "nachäffen",
    "nachäfften": "nachäffen",
    "nachäfftest": "nachäffen",
    "nachäfftet": "nachäffen",
    "nachäße": "nachessen",
    "nachäßen": "nachessen",
    "nachäßest": "nachessen",
    "nachäßet": "nachessen",
    "nackte": "nackt",
    "nacktem": "nackt",
    "nackten": "nackt",
    "nackter": "nackt",
    "nacktere": "nackt",
    "nackterem": "nackt",
    "nackteren": "nackt",
    "nackterer": "nackt",
    "nackteres": "nackt",
    "nacktes": "nackt",
    "nackteste": "nackt",
    "nacktestem": "nackt",
    "nacktesten": "nackt",
    "nacktester": "nackt",
    "nacktestes": "nackt",
    "nage": "nagen",
    "nagele": "nageln",
    "nagelnd": "nageln",
    "nagelnde": "nagelnd",
    "nagelndem": "nagelnd",
    "nagelnden": "nagelnd",
    "nagelnder": "nagelnd",
    "nagelndes": "nagelnd",
    "nagelneue": "nagelneu",
    "nagelneuem": "nagelneu",
    "nagelneuen": "nagelneu",
    "nagelneuer": "nagelneu",
    "nagelneues": "nagelneu",
    "nagelst": "nageln",
    "nagelt": "nageln",
    "nagelte": "nageln",
    "nagelten": "nageln",
    "nageltest": "nageln",
    "nageltet": "nageln",
    "nagend": "nagen",
    "nagende": "nagend",
    "nagendem": "nagend",
    "nagenden": "nagend",
    "nagender": "nagend",
    "nagendere": "nagend",
    "nagenderem": "nagend",
    "nagenderen": "nagend",
    "nagenderer": "nagend",
    "nagenderes": "nagend",
    "nagendes": "nagend",
    "nagendste": "nagend",
    "nagendstem": "nagend",
    "nagendsten": "nagend",
    "nagendster": "nagend",
    "nagendstes": "nagend",
    "nagest": "nagen",
    "naget": "nagen",
    "nagle": "nageln",
    "nagst": "nagen",
    "nagt": "nagen",
    "nagte": "nagen",
    "nagten": "nagen",
    "nagtest": "nagen",
    "nagtet": "nagen",
    "nahebrachte": "nahebringen",
    "nahebrachten": "nahebringen",
    "nahebrachtest": "nahebringen",
    "nahebrachtet": "nahebringen",
    "nahebringe": "nahebringen",
    "nahebringend": "nahebringen",
    "nahebringende": "nahebringend",
    "nahebringendem": "nahebringend",
    "nahebringenden": "nahebringend",
    "nahebringender": "nahebringend",
    "nahebringendere": "nahebringend",
    "nahebringenderem": "nahebringend",
    "nahebringenderen": "nahebringend",
    "nahebringenderer": "nahebringend",
    "nahebringenderes": "nahebringend",
    "nahebringendes": "nahebringend",
    "nahebringendste": "nahebringend",
    "nahebringendstem": "nahebringend",
    "nahebringendsten": "nahebringend",
    "nahebringendster": "nahebringend",
    "nahebringendstes": "nahebringend",
    "nahebringest": "nahebringen",
    "nahebringet": "nahebringen",
    "nahebringst": "nahebringen",
    "nahebringt": "nahebringen",
    "nahebrächte": "nahebringen",
    "nahebrächten": "nahebringen",
    "nahebrächtest": "nahebringen",
    "nahebrächtet": "nahebringen",
    "nahegebracht": "nahebringen",
    "nahegebrachte": "nahegebracht",
    "nahegebrachtem": "nahegebracht",
    "nahegebrachten": "nahegebracht",
    "nahegebrachter": "nahegebracht",
    "nahegebrachtere": "nahegebracht",
    "nahegebrachterem": "nahegebracht",
    "nahegebrachteren": "nahegebracht",
    "nahegebrachterer": "nahegebracht",
    "nahegebrachteres": "nahegebracht",
    "nahegebrachtes": "nahegebracht",
    "nahegebrachteste": "nahegebracht",
    "nahegebrachtestem": "nahegebracht",
    "nahegebrachtesten": "nahegebracht",
    "nahegebrachtester": "nahegebracht",
    "nahegebrachtestes": "nahegebracht",
    "nahegegangen": "nahegehen",
    "nahegegangene": "nahegegangen",
    "nahegegangenem": "nahegegangen",
    "nahegegangenen": "nahegegangen",
    "nahegegangener": "nahegegangen",
    "nahegegangenes": "nahegegangen",
    "nahegehe": "nahegehen",
    "nahegehend": "nahegehen",
    "nahegehende": "nahegehend",
    "nahegehendem": "nahegehend",
    "nahegehenden": "nahegehend",
    "nahegehender": "nahegehend",
    "nahegehendes": "nahegehend",
    "nahegehest": "nahegehen",
    "nahegehet": "nahegehen",
    "nahegehst": "nahegehen",
    "nahegeht": "nahegehen",
    "nahegekommen": "nahekommen",
    "nahegekommene": "nahegekommen",
    "nahegekommenem": "nahegekommen",
    "nahegekommenen": "nahegekommen",
    "nahegekommener": "nahegekommen",
    "nahegekommenes": "nahegekommen",
    "nahegelegen": "naheliegen",
    "nahegelegene": "nahegelegen",
    "nahegelegenem": "nahegelegen",
    "nahegelegenen": "nahegelegen",
    "nahegelegener": "nahegelegen",
    "nahegelegenere": "nahegelegen",
    "nahegelegenerem": "nahegelegen",
    "nahegelegeneren": "nahegelegen",
    "nahegelegenerer": "nahegelegen",
    "nahegelegeneres": "nahegelegen",
    "nahegelegenes": "nahegelegen",
    "nahegelegenste": "nahegelegen",
    "nahegelegenstem": "nahegelegen",
    "nahegelegensten": "nahegelegen",
    "nahegelegenster": "nahegelegen",
    "nahegelegenstes": "nahegelegen",
    "nahegelegt": "nahelegen",
    "nahegelegte": "nahegelegt",
    "nahegelegtem": "nahegelegt",
    "nahegelegten": "nahegelegt",
    "nahegelegter": "nahegelegt",
    "nahegelegtes": "nahegelegt",
    "nahegestanden": "nahestehen",
    "nahegestandene": "nahegestanden",
    "nahegestandenem": "nahegestanden",
    "nahegestandenen": "nahegestanden",
    "nahegestandener": "nahegestanden",
    "nahegestandenere": "nahegestanden",
    "nahegestandenerem": "nahegestanden",
    "nahegestandeneren": "nahegestanden",
    "nahegestandenerer": "nahegestanden",
    "nahegestandeneres": "nahegestanden",
    "nahegestandenes": "nahegestanden",
    "nahegestandenste": "nahegestanden",
    "nahegestandenstem": "nahegestanden",
    "nahegestandensten": "nahegestanden",
    "nahegestandenster": "nahegestanden",
    "nahegestandenstes": "nahegestanden",
    "nahegetreten": "nahetreten",
    "nahegetretene": "nahegetreten",
    "nahegetretenem": "nahegetreten",
    "nahegetretenen": "nahegetreten",
    "nahegetretener": "nahegetreten",
    "nahegetretenes": "nahegetreten",
    "naheging": "nahegehen",
    "naheginge": "nahegehen",
    "nahegingen": "nahegehen",
    "nahegingest": "nahegehen",
    "naheginget": "nahegehen",
    "nahegingst": "nahegehen",
    "nahegingt": "nahegehen",
    "nahekam": "nahekommen",
    "nahekamen": "nahekommen",
    "nahekamst": "nahekommen",
    "nahekamt": "nahekommen",
    "nahekomme": "nahekommen",
    "nahekommend": "nahekommen",
    "nahekommende": "nahekommend",
    "nahekommendem": "nahekommend",
    "nahekommenden": "nahekommend",
    "nahekommender": "nahekommend",
    "nahekommendes": "nahekommend",
    "nahekommest": "nahekommen",
    "nahekommet": "nahekommen",
    "nahekommst": "nahekommen",
    "nahekommt": "nahekommen",
    "nahekäme": "nahekommen",
    "nahekämen": "nahekommen",
    "nahekämest": "nahekommen",
    "nahekämet": "nahekommen",
    "nahelag": "naheliegen",
    "nahelagen": "naheliegen",
    "nahelagst": "naheliegen",
    "nahelagt": "naheliegen",
    "nahelege": "nahelegen",
    "nahelegend": "nahelegen",
    "nahelegende": "nahelegend",
    "nahelegendem": "nahelegend",
    "nahelegenden": "nahelegend",
    "nahelegender": "nahelegend",
    "nahelegendes": "nahelegend",
    "nahelegest": "nahelegen",
    "naheleget": "nahelegen",
    "nahelegst": "nahelegen",
    "nahelegt": "nahelegen",
    "nahelegte": "nahelegen",
    "nahelegten": "nahelegen",
    "nahelegtest": "nahelegen",
    "nahelegtet": "nahelegen",
    "naheliege": "naheliegen",
    "naheliegend": "naheliegen",
    "naheliegende": "naheliegend",
    "naheliegendem": "naheliegend",
    "naheliegenden": "naheliegend",
    "naheliegender": "naheliegend",
    "naheliegendes": "naheliegend",
    "naheliegest": "naheliegen",
    "nahelieget": "naheliegen",
    "naheliegst": "naheliegen",
    "naheliegt": "naheliegen",
    "naheläge": "naheliegen",
    "nahelägen": "naheliegen",
    "nahelägest": "naheliegen",
    "naheläget": "naheliegen",
    "nahem": "nah",
    "nahen": "nah",
    "naher": "nah",
    "nahes": "nah",
    "nahestand": "nahestehen",
    "nahestanden": "nahestehen",
    "nahestandest": "nahestehen",
    "nahestandet": "nahestehen",
    "nahestehe": "nahestehen",
    "nahestehend": "nahestehen",
    "nahestehende": "nahestehend",
    "nahestehendem": "nahestehend",
    "nahestehenden": "nahestehend",
    "nahestehender": "nahestehend",
    "nahestehendere": "nahestehend",
    "nahestehenderem": "nahestehend",
    "nahestehenderen": "nahestehend",
    "nahestehenderer": "nahestehend",
    "nahestehenderes": "nahestehend",
    "nahestehendes": "nahestehend",
    "nahestehendste": "nahestehend",
    "nahestehendstem": "nahestehend",
    "nahestehendsten": "nahestehend",
    "nahestehendster": "nahestehend",
    "nahestehendstes": "nahestehend",
    "nahestehest": "nahestehen",
    "nahestehet": "nahestehen",
    "nahestehst": "nahestehen",
    "nahesteht": "nahestehen",
    "nahestünde": "nahestehen",
    "nahestünden": "nahestehen",
    "nahestündest": "nahestehen",
    "nahestündet": "nahestehen",
    "nahetrat": "nahetreten",
    "nahetraten": "nahetreten",
    "nahetratest": "nahetreten",
    "nahetratet": "nahetreten",
    "nahetrete": "nahetreten",
    "nahetretend": "nahetreten",
    "nahetretende": "nahetretend",
    "nahetretendem": "nahetretend",
    "nahetretenden": "nahetretend",
    "nahetretender": "nahetretend",
    "nahetretendes": "nahetretend",
    "nahetretest": "nahetreten",
    "nahetretet": "nahetreten",
    "nahetritt": "nahetreten",
    "nahetrittst": "nahetreten",
    "naheträte": "nahetreten",
    "naheträten": "nahetreten",
    "naheträtest": "nahetreten",
    "naheträtet": "nahetreten",
    "nahezubringen": "nahebringen",
    "nahezugehen": "nahegehen",
    "nahezukommen": "nahekommen",
    "nahezulegen": "nahelegen",
    "nahezuliegen": "naheliegen",
    "nahezustehen": "nahestehen",
    "nahezutreten": "nahetreten",
    "nahm": "nehmen",
    "nahmen": "nehmen",
    "nahmst": "nehmen",
    "nahmt": "nehmen",
    "nahrhafte": "nahrhaft",
    "nahrhaftem": "nahrhaft",
    "nahrhaften": "nahrhaft",
    "nahrhafter": "nahrhaft",
    "nahrhaftere": "nahrhaft",
    "nahrhafterem": "nahrhaft",
    "nahrhafteren": "nahrhaft",
    "nahrhafterer": "nahrhaft",
    "nahrhafteres": "nahrhaft",
    "nahrhaftes": "nahrhaft",
    "nahrhafteste": "nahrhaft",
    "nahrhaftestem": "nahrhaft",
    "nahrhaftesten": "nahrhaft",
    "nahrhaftester": "nahrhaft",
    "nahrhaftestes": "nahrhaft",
    "nahtlosem": "nahtlos",
    "nahtlosen": "nahtlos",
    "nahtloser": "nahtlos",
    "nahtlosere": "nahtlos",
    "nahtloserem": "nahtlos",
    "nahtloseren": "nahtlos",
    "nahtloserer": "nahtlos",
    "nahtloseres": "nahtlos",
    "nahtloses": "nahtlos",
    "nahtloseste": "nahtlos",
    "nahtlosestem": "nahtlos",
    "nahtlosesten": "nahtlos",
    "nahtlosester": "nahtlos",
    "nahtlosestes": "nahtlos",
    "naivem": "naiv",
    "naiven": "naiv",
    "naiver": "naiv",
    "naivere": "naiv",
    "naiverem": "naiv",
    "naiveren": "naiv",
    "naiverer": "naiv",
    "naiveres": "naiv",
    "naives": "naiv",
    "naivste": "naiv",
    "naivstem": "naiv",
    "naivsten": "naiv",
    "naivster": "naiv",
    "naivstes": "naiv",
    "namenlosem": "namenlos",
    "namenlosen": "namenlos",
    "namenloser": "namenlos",
    "namenloses": "namenlos",
    "namentlichem": "namentlich",
    "namentlichen": "namentlich",
    "namentlicher": "namentlich",
    "namentliches": "namentlich",
    "namhafte": "namhaft",
    "namhaftem": "namhaft",
    "namhaften": "namhaft",
    "namhafter": "namhaft",
    "namhaftes": "namhaft",
    "namibischem": "namibisch",
    "namibischen": "namibisch",
    "namibischer": "namibisch",
    "namibisches": "namibisch",
    "nannte": "nennen",
    "nannten": "nennen",
    "nanntest": "nennen",
    "nanntet": "nennen",
    "narbigem": "narbig",
    "narbigen": "narbig",
    "narbiger": "narbig",
    "narbigere": "narbig",
    "narbigerem": "narbig",
    "narbigeren": "narbig",
    "narbigerer": "narbig",
    "narbigeres": "narbig",
    "narbiges": "narbig",
    "narbigste": "narbig",
    "narbigstem": "narbig",
    "narbigsten": "narbig",
    "narbigster": "narbig",
    "narbigstes": "narbig",
    "narkotisierend": "narkotisieren",
    "narkotisierende": "narkotisierend",
    "narkotisierendem": "narkotisierend",
    "narkotisierenden": "narkotisierend",
    "narkotisierender": "narkotisierend",
    "narkotisierendere": "narkotisierend",
    "narkotisierenderem": "narkotisierend",
    "narkotisierenderen": "narkotisierend",
    "narkotisierenderer": "narkotisierend",
    "narkotisierenderes": "narkotisierend",
    "narkotisierendes": "narkotisierend",
    "narkotisierendste": "narkotisierend",
    "narkotisierendstem": "narkotisierend",
    "narkotisierendsten": "narkotisierend",
    "narkotisierendster": "narkotisierend",
    "narkotisierendstes": "narkotisierend",
    "narkotisierest": "narkotisieren",
    "narkotisieret": "narkotisieren",
    "narkotisierst": "narkotisieren",
    "narkotisiert": "narkotisieren",
    "narkotisierte": "narkotisieren",
    "narkotisiertem": "narkotisiert",
    "narkotisierten": "narkotisieren",
    "narkotisierter": "narkotisiert",
    "narkotisiertere": "narkotisiert",
    "narkotisierterem": "narkotisiert",
    "narkotisierteren": "narkotisiert",
    "narkotisierterer": "narkotisiert",
    "narkotisierteres": "narkotisiert",
    "narkotisiertes": "narkotisiert",
    "narkotisiertest": "narkotisieren",
    "narkotisierteste": "narkotisiert",
    "narkotisiertestem": "narkotisiert",
    "narkotisiertesten": "narkotisiert",
    "narkotisiertester": "narkotisiert",
    "narkotisiertestes": "narkotisiert",
    "narkotisiertet": "narkotisieren",
    "narrativem": "narrativ",
    "narrativen": "narrativ",
    "narrativer": "narrativ",
    "narratives": "narrativ",
    "narre": "narren",
    "narrend": "narren",
    "narrende": "narrend",
    "narrendem": "narrend",
    "narrenden": "narrend",
    "narrender": "narrend",
    "narrendere": "narrend",
    "narrenderem": "narrend",
    "narrenderen": "narrend",
    "narrenderer": "narrend",
    "narrenderes": "narrend",
    "narrendes": "narrend",
    "narrendste": "narrend",
    "narrendstem": "narrend",
    "narrendsten": "narrend",
    "narrendster": "narrend",
    "narrendstes": "narrend",
    "narrest": "narren",
    "narret": "narren",
    "narrst": "narren",
    "narrt": "narren",
    "narrte": "narren",
    "narrten": "narren",
    "narrtest": "narren",
    "narrtet": "narren",
    "nasalem": "nasal",
    "nasalen": "nasal",
    "nasaler": "nasal",
    "nasales": "nasal",
    "nasaliere": "nasalieren",
    "nasalierend": "nasalieren",
    "nasalierende": "nasalierend",
    "nasalierendem": "nasalierend",
    "nasalierenden": "nasalierend",
    "nasalierender": "nasalierend",
    "nasalierendes": "nasalierend",
    "nasalierest": "nasalieren",
    "nasalieret": "nasalieren",
    "nasalierst": "nasalieren",
    "nasaliert": "nasalieren",
    "nasalierte": "nasalieren",
    "nasaliertem": "nasaliert",
    "nasalierten": "nasalieren",
    "nasalierter": "nasaliert",
    "nasaliertes": "nasaliert",
    "nasaliertest": "nasalieren",
    "nasaliertet": "nasalieren",
    "nasche": "naschen",
    "naschend": "naschen",
    "naschende": "naschend",
    "naschendem": "naschend",
    "naschenden": "naschend",
    "naschender": "naschend",
    "naschendere": "naschend",
    "naschenderem": "naschend",
    "naschenderen": "naschend",
    "naschenderer": "naschend",
    "naschenderes": "naschend",
    "naschendes": "naschend",
    "naschendste": "naschend",
    "naschendstem": "naschend",
    "naschendsten": "naschend",
    "naschendster": "naschend",
    "naschendstes": "naschend",
    "naschest": "naschen",
    "naschet": "naschen",
    "naschhafte": "naschhaft",
    "naschhaftem": "naschhaft",
    "naschhaften": "naschhaft",
    "naschhafter": "naschhaft",
    "naschhaftere": "naschhaft",
    "naschhafterem": "naschhaft",
    "naschhafteren": "naschhaft",
    "naschhafterer": "naschhaft",
    "naschhafteres": "naschhaft",
    "naschhaftes": "naschhaft",
    "naschhafteste": "naschhaft",
    "naschhaftestem": "naschhaft",
    "naschhaftesten": "naschhaft",
    "naschhaftester": "naschhaft",
    "naschhaftestes": "naschhaft",
    "naschst": "naschen",
    "naschsüchtige": "naschsüchtig",
    "naschsüchtigem": "naschsüchtig",
    "naschsüchtigen": "naschsüchtig",
    "naschsüchtiger": "naschsüchtig",
    "naschsüchtigere": "naschsüchtig",
    "naschsüchtigerem": "naschsüchtig",
    "naschsüchtigeren": "naschsüchtig",
    "naschsüchtigerer": "naschsüchtig",
    "naschsüchtigeres": "naschsüchtig",
    "naschsüchtiges": "naschsüchtig",
    "naschsüchtigste": "naschsüchtig",
    "naschsüchtigstem": "naschsüchtig",
    "naschsüchtigsten": "naschsüchtig",
    "naschsüchtigster": "naschsüchtig",
    "naschsüchtigstes": "naschsüchtig",
    "nascht": "naschen",
    "naschte": "naschen",
    "naschten": "naschen",
    "naschtest": "naschen",
    "naschtet": "naschen",
    "nassauische": "nassauisch",
    "nassauischem": "nassauisch",
    "nassauischen": "nassauisch",
    "nassauischer": "nassauisch",
    "nassauisches": "nassauisch",
    "nassem": "naß",
    "nassen": "naß",
    "nasser": "naß",
    "nassere": "naß",
    "nasserem": "naß",
    "nasseren": "naß",
    "nasserer": "naß",
    "nasseres": "naß",
    "nasses": "naß",
    "nasseste": "naß",
    "nassestem": "naß",
    "nassesten": "naß",
    "nassester": "naß",
    "nassestes": "naß",
    "nationalbewußtem": "nationalbewußt",
    "nationalbewußten": "nationalbewußt",
    "nationalbewußter": "nationalbewußt",
    "nationalbewußtere": "nationalbewußt",
    "nationalbewußterem": "nationalbewußt",
    "nationalbewußteren": "nationalbewußt",
    "nationalbewußterer": "nationalbewußt",
    "nationalbewußteres": "nationalbewußt",
    "nationalbewußtes": "nationalbewußt",
    "nationalbewußteste": "nationalbewußt",
    "nationalbewußtestem": "nationalbewußt",
    "nationalbewußtesten": "nationalbewußt",
    "nationalbewußtester": "nationalbewußt",
    "nationalbewußtestes": "nationalbewußt",
    "nationale": "national",
    "nationalem": "national",
    "nationalen": "national",
    "nationaler": "national",
    "nationalere": "national",
    "nationalerem": "national",
    "nationaleren": "national",
    "nationalerer": "national",
    "nationaleres": "national",
    "nationales": "national",
    "nationalisiere": "nationalisieren",
    "nationalisierend": "nationalisieren",
    "nationalisierende": "nationalisierend",
    "nationalisierendem": "nationalisierend",
    "nationalisierenden": "nationalisierend",
    "nationalisierender": "nationalisierend",
    "nationalisierendere": "nationalisierend",
    "nationalisierenderem": "nationalisierend",
    "nationalisierenderen": "nationalisierend",
    "nationalisierenderer": "nationalisierend",
    "nationalisierenderes": "nationalisierend",
    "nationalisierendes": "nationalisierend",
    "nationalisierendste": "nationalisierend",
    "nationalisierendstem": "nationalisierend",
    "nationalisierendsten": "nationalisierend",
    "nationalisierendster": "nationalisierend",
    "nationalisierendstes": "nationalisierend",
    "nationalisierest": "nationalisieren",
    "nationalisieret": "nationalisieren",
    "nationalisierst": "nationalisieren",
    "nationalisiert": "nationalisieren",
    "nationalisierte": "nationalisieren",
    "nationalisiertem": "nationalisiert",
    "nationalisierten": "nationalisieren",
    "nationalisierter": "nationalisiert",
    "nationalisiertere": "nationalisiert",
    "nationalisierterem": "nationalisiert",
    "nationalisierteren": "nationalisiert",
    "nationalisierterer": "nationalisiert",
    "nationalisierteres": "nationalisiert",
    "nationalisiertes": "nationalisiert",
    "nationalisiertest": "nationalisieren",
    "nationalisierteste": "nationalisiert",
    "nationalisiertestem": "nationalisiert",
    "nationalisiertesten": "nationalisiert",
    "nationalisiertester": "nationalisiert",
    "nationalisiertestes": "nationalisiert",
    "nationalisiertet": "nationalisieren",
    "nationalistischem": "nationalistisch",
    "nationalistischen": "nationalistisch",
    "nationalistischer": "nationalistisch",
    "nationalistischere": "nationalistisch",
    "nationalistischerem": "nationalistisch",
    "nationalistischeren": "nationalistisch",
    "nationalistischerer": "nationalistisch",
    "nationalistischeres": "nationalistisch",
    "nationalistisches": "nationalistisch",
    "nationalistischste": "nationalistisch",
    "nationalistischstem": "nationalistisch",
    "nationalistischsten": "nationalistisch",
    "nationalistischster": "nationalistisch",
    "nationalistischstes": "nationalistisch",
    "nationalliberalem": "nationalliberal",
    "nationalliberalen": "nationalliberal",
    "nationalliberaler": "nationalliberal",
    "nationalliberales": "nationalliberal",
    "nationalstem": "national",
    "nationalsten": "national",
    "nationalster": "national",
    "nationalstes": "national",
    "nativem": "nativ",
    "nativen": "nativ",
    "nativer": "nativ",
    "natives": "nativ",
    "naturalisiere": "naturalisieren",
    "naturalisierend": "naturalisieren",
    "naturalisierende": "naturalisierend",
    "naturalisierendem": "naturalisierend",
    "naturalisierenden": "naturalisierend",
    "naturalisierender": "naturalisierend",
    "naturalisierendes": "naturalisierend",
    "naturalisierest": "naturalisieren",
    "naturalisieret": "naturalisieren",
    "naturalisierst": "naturalisieren",
    "naturalisiert": "naturalisieren",
    "naturalisierte": "naturalisieren",
    "naturalisiertem": "naturalisiert",
    "naturalisierten": "naturalisieren",
    "naturalisierter": "naturalisiert",
    "naturalisiertes": "naturalisiert",
    "naturalisiertest": "naturalisieren",
    "naturalisiertet": "naturalisieren",
    "naturalistischem": "naturalistisch",
    "naturalistischen": "naturalistisch",
    "naturalistischer": "naturalistisch",
    "naturalistisches": "naturalistisch",
    "naturelle": "naturell",
    "naturellem": "naturell",
    "naturellen": "naturell",
    "natureller": "naturell",
    "naturelles": "naturell",
    "naturgegebenem": "naturgegeben",
    "naturgegebenen": "naturgegeben",
    "naturgegebener": "naturgegeben",
    "naturgegebenes": "naturgegeben",
    "naturgemäße": "naturgemäß",
    "naturgemäßem": "naturgemäß",
    "naturgemäßen": "naturgemäß",
    "naturgemäßer": "naturgemäß",
    "naturgemäßes": "naturgemäß",
    "naturgetreue": "naturgetreu",
    "naturgetreuem": "naturgetreu",
    "naturgetreuen": "naturgetreu",
    "naturgetreuer": "naturgetreu",
    "naturgetreuere": "naturgetreu",
    "naturgetreuerem": "naturgetreu",
    "naturgetreueren": "naturgetreu",
    "naturgetreuerer": "naturgetreu",
    "naturgetreueres": "naturgetreu",
    "naturgetreues": "naturgetreu",
    "naturgetreuste": "naturgetreu",
    "naturgetreustem": "naturgetreu",
    "naturgetreusten": "naturgetreu",
    "naturgetreuster": "naturgetreu",
    "naturgetreustes": "naturgetreu",
    "naturinteressierte": "naturinteressiert",
    "naturinteressiertem": "naturinteressiert",
    "naturinteressierten": "naturinteressiert",
    "naturinteressierter": "naturinteressiert",
    "naturinteressiertere": "naturinteressiert",
    "naturinteressierterem": "naturinteressiert",
    "naturinteressierteren": "naturinteressiert",
    "naturinteressierterer": "naturinteressiert",
    "naturinteressierteres": "naturinteressiert",
    "naturinteressiertes": "naturinteressiert",
    "naturinteressierteste": "naturinteressiert",
    "naturinteressiertestem": "naturinteressiert",
    "naturinteressiertesten": "naturinteressiert",
    "naturinteressiertester": "naturinteressiert",
    "naturinteressiertestes": "naturinteressiert",
    "naturkundlichem": "naturkundlich",
    "naturkundlichen": "naturkundlich",
    "naturkundlicher": "naturkundlich",
    "naturkundliches": "naturkundlich",
    "naturreine": "naturrein",
    "naturreinem": "naturrein",
    "naturreinen": "naturrein",
    "naturreiner": "naturrein",
    "naturreinere": "naturrein",
    "naturreinerem": "naturrein",
    "naturreineren": "naturrein",
    "naturreinerer": "naturrein",
    "naturreineres": "naturrein",
    "naturreines": "naturrein",
    "naturreinste": "naturrein",
    "naturreinstem": "naturrein",
    "naturreinsten": "naturrein",
    "naturreinster": "naturrein",
    "naturreinstes": "naturrein",
    "naturtrübe": "naturtrüb",
    "naturtrübem": "naturtrüb",
    "naturtrüben": "naturtrüb",
    "naturtrüber": "naturtrüb",
    "naturtrübere": "naturtrüb",
    "naturtrüberem": "naturtrüb",
    "naturtrüberen": "naturtrüb",
    "naturtrüberer": "naturtrüb",
    "naturtrüberes": "naturtrüb",
    "naturtrübes": "naturtrüb",
    "naturtrübste": "naturtrüb",
    "naturtrübstem": "naturtrüb",
    "naturtrübsten": "naturtrüb",
    "naturtrübster": "naturtrüb",
    "naturtrübstes": "naturtrüb",
    "natürliche": "natürlich",
    "natürlichem": "natürlich",
    "natürlichen": "natürlich",
    "natürlicher": "natürlich",
    "natürlichere": "natürlich",
    "natürlicherem": "natürlich",
    "natürlicheren": "natürlich",
    "natürlicherer": "natürlich",
    "natürlicheres": "natürlich",
    "natürliches": "natürlich",
    "natürlichste": "natürlich",
    "natürlichstem": "natürlich",
    "natürlichsten": "natürlich",
    "natürlichster": "natürlich",
    "natürlichstes": "natürlich",
    "naßkalte": "naßkalt",
    "naßkaltem": "naßkalt",
    "naßkalten": "naßkalt",
    "naßkalter": "naßkalt",
    "naßkaltes": "naßkalt",
    "nebele": "nebeln",
    "nebelige": "nebelig",
    "nebeligem": "nebelig",
    "nebeligen": "nebelig",
    "nebeliger": "nebelig",
    "nebeligere": "nebelig",
    "nebeligerem": "nebelig",
    "nebeligeren": "nebelig",
    "nebeligerer": "nebelig",
    "nebeligeres": "nebelig",
    "nebeliges": "nebelig",
    "nebeligste": "nebelig",
    "nebeligstem": "nebelig",
    "nebeligsten": "nebelig",
    "nebeligster": "nebelig",
    "nebeligstes": "nebelig",
    "nebelnd": "nebeln",
    "nebelnde": "nebelnd",
    "nebelndem": "nebelnd",
    "nebelnden": "nebelnd",
    "nebelnder": "nebelnd",
    "nebelndes": "nebelnd",
    "nebelst": "nebeln",
    "nebelt": "nebeln",
    "nebelte": "nebeln",
    "nebelten": "nebeln",
    "nebeltest": "nebeln",
    "nebeltet": "nebeln",
    "nebenamtlichem": "nebenamtlich",
    "nebenamtlichen": "nebenamtlich",
    "nebenamtlicher": "nebenamtlich",
    "nebenamtliches": "nebenamtlich",
    "nebenberuflichem": "nebenberuflich",
    "nebenberuflichen": "nebenberuflich",
    "nebenberuflicher": "nebenberuflich",
    "nebenberufliches": "nebenberuflich",
    "nebengeordnet": "nebenordnen",
    "nebengeordnete": "nebengeordnet",
    "nebengeordnetem": "nebengeordnet",
    "nebengeordneten": "nebengeordnet",
    "nebengeordneter": "nebengeordnet",
    "nebengeordnetes": "nebengeordnet",
    "nebenordne": "nebenordnen",
    "nebenordnend": "nebenordnen",
    "nebenordnende": "nebenordnend",
    "nebenordnendem": "nebenordnend",
    "nebenordnenden": "nebenordnend",
    "nebenordnender": "nebenordnend",
    "nebenordnendes": "nebenordnend",
    "nebenordnest": "nebenordnen",
    "nebenordnet": "nebenordnen",
    "nebenordnete": "nebenordnen",
    "nebenordneten": "nebenordnen",
    "nebenordnetest": "nebenordnen",
    "nebenordnetet": "nebenordnen",
    "nebenstehendem": "nebenstehend",
    "nebenstehenden": "nebenstehend",
    "nebenstehender": "nebenstehend",
    "nebenstehendes": "nebenstehend",
    "nebensächlichem": "nebensächlich",
    "nebensächlichen": "nebensächlich",
    "nebensächlicher": "nebensächlich",
    "nebensächliches": "nebensächlich",
    "nebenzuordnen": "nebenordnen",
    "neble": "nebeln",
    "neblige": "neblig",
    "nebligem": "neblig",
    "nebligen": "neblig",
    "nebliger": "neblig",
    "nebligere": "neblig",
    "nebligerem": "neblig",
    "nebligeren": "neblig",
    "nebligerer": "neblig",
    "nebligeres": "neblig",
    "nebliges": "neblig",
    "nebligste": "neblig",
    "nebligstem": "neblig",
    "nebligsten": "neblig",
    "nebligster": "neblig",
    "nebligstes": "neblig",
    "negativem": "negativ",
    "negativen": "negativ",
    "negativer": "negativ",
    "negativere": "negativ",
    "negativerem": "negativ",
    "negativeren": "negativ",
    "negativerer": "negativ",
    "negativeres": "negativ",
    "negatives": "negativ",
    "negativstem": "negativ",
    "negativsten": "negativ",
    "negativster": "negativ",
    "negativstes": "negativ",
    "negiere": "negieren",
    "negierend": "negieren",
    "negierende": "negierend",
    "negierendem": "negierend",
    "negierenden": "negierend",
    "negierender": "negierend",
    "negierendes": "negierend",
    "negierest": "negieren",
    "negieret": "negieren",
    "negierst": "negieren",
    "negiert": "negieren",
    "negierte": "negieren",
    "negiertem": "negiert",
    "negierten": "negieren",
    "negierter": "negiert",
    "negiertes": "negiert",
    "negiertest": "negieren",
    "negiertet": "negieren",
    "nehme": "nehmen",
    "nehmend": "nehmen",
    "nehmende": "nehmend",
    "nehmendem": "nehmend",
    "nehmenden": "nehmend",
    "nehmender": "nehmend",
    "nehmendes": "nehmend",
    "nehmest": "nehmen",
    "nehmet": "nehmen",
    "nehmt": "nehmen",
    "neide": "neiden",
    "neidend": "neiden",
    "neidende": "neidend",
    "neidendem": "neidend",
    "neidenden": "neidend",
    "neidender": "neidend",
    "neidendere": "neidend",
    "neidenderem": "neidend",
    "neidenderen": "neidend",
    "neidenderer": "neidend",
    "neidenderes": "neidend",
    "neidendes": "neidend",
    "neidendste": "neidend",
    "neidendstem": "neidend",
    "neidendsten": "neidend",
    "neidendster": "neidend",
    "neidendstes": "neidend",
    "neidest": "neiden",
    "neidet": "neiden",
    "neidete": "neiden",
    "neideten": "neiden",
    "neidetest": "neiden",
    "neidetet": "neiden",
    "neidischem": "neidisch",
    "neidischen": "neidisch",
    "neidischer": "neidisch",
    "neidischere": "neidisch",
    "neidischerem": "neidisch",
    "neidischeren": "neidisch",
    "neidischerer": "neidisch",
    "neidischeres": "neidisch",
    "neidisches": "neidisch",
    "neidischste": "neidisch",
    "neidischstem": "neidisch",
    "neidischsten": "neidisch",
    "neidischster": "neidisch",
    "neidischstes": "neidisch",
    "neigend": "neigen",
    "neigende": "neigend",
    "neigendem": "neigend",
    "neigenden": "neigend",
    "neigender": "neigend",
    "neigendes": "neigend",
    "neigest": "neigen",
    "neiget": "neigen",
    "neigst": "neigen",
    "neigt": "neigen",
    "neigte": "neigen",
    "neigten": "neigen",
    "neigtest": "neigen",
    "neigtet": "neigen",
    "nenne": "nennen",
    "nennend": "nennen",
    "nennende": "nennend",
    "nennendem": "nennend",
    "nennenden": "nennend",
    "nennender": "nennend",
    "nennendes": "nennend",
    "nennenswertem": "nennenswert",
    "nennenswerten": "nennenswert",
    "nennenswerter": "nennenswert",
    "nennenswertes": "nennenswert",
    "nennest": "nennen",
    "nennet": "nennen",
    "nennst": "nennen",
    "nennt": "nennen",
    "neppe": "neppen",
    "neppend": "neppen",
    "neppende": "neppend",
    "neppendem": "neppend",
    "neppenden": "neppend",
    "neppender": "neppend",
    "neppendes": "neppend",
    "neppest": "neppen",
    "neppet": "neppen",
    "neppst": "neppen",
    "neppt": "neppen",
    "neppte": "neppen",
    "neppten": "neppen",
    "nepptest": "neppen",
    "nepptet": "neppen",
    "nervend": "nerven",
    "nervende": "nervend",
    "nervendem": "nervend",
    "nervenden": "nervend",
    "nervender": "nervend",
    "nervendere": "nervend",
    "nervenderem": "nervend",
    "nervenderen": "nervend",
    "nervenderer": "nervend",
    "nervenderes": "nervend",
    "nervendes": "nervend",
    "nervendste": "nervend",
    "nervendstem": "nervend",
    "nervendsten": "nervend",
    "nervendster": "nervend",
    "nervendstes": "nervend",
    "nervenkranke": "nervenkrank",
    "nervenkrankem": "nervenkrank",
    "nervenkranken": "nervenkrank",
    "nervenkranker": "nervenkrank",
    "nervenkrankes": "nervenkrank",
    "nervest": "nerven",
    "nervet": "nerven",
    "nervige": "nervig",
    "nervigem": "nervig",
    "nervigen": "nervig",
    "nerviger": "nervig",
    "nervigere": "nervig",
    "nervigerem": "nervig",
    "nervigeren": "nervig",
    "nervigerer": "nervig",
    "nervigeres": "nervig",
    "nerviges": "nervig",
    "nervigste": "nervig",
    "nervigstem": "nervig",
    "nervigsten": "nervig",
    "nervigster": "nervig",
    "nervigstes": "nervig",
    "nervst": "nerven",
    "nervt": "nerven",
    "nervte": "nerven",
    "nervten": "nerven",
    "nervtest": "nerven",
    "nervtet": "nerven",
    "nervöse": "nervös",
    "nervösem": "nervös",
    "nervösen": "nervös",
    "nervöser": "nervös",
    "nervösere": "nervös",
    "nervöserem": "nervös",
    "nervöseren": "nervös",
    "nervöserer": "nervös",
    "nervöseres": "nervös",
    "nervöses": "nervös",
    "nervöseste": "nervös",
    "nervösestem": "nervös",
    "nervösesten": "nervös",
    "nervösester": "nervös",
    "nervösestes": "nervös",
    "nestele": "nesteln",
    "nestelnd": "nesteln",
    "nestelnde": "nestelnd",
    "nestelndem": "nestelnd",
    "nestelnden": "nestelnd",
    "nestelnder": "nestelnd",
    "nestelndere": "nestelnd",
    "nestelnderem": "nestelnd",
    "nestelnderen": "nestelnd",
    "nestelnderer": "nestelnd",
    "nestelnderes": "nestelnd",
    "nestelndes": "nestelnd",
    "nestelndste": "nestelnd",
    "nestelndstem": "nestelnd",
    "nestelndsten": "nestelnd",
    "nestelndster": "nestelnd",
    "nestelndstes": "nestelnd",
    "nestelst": "nesteln",
    "nestelt": "nesteln",
    "nestelte": "nesteln",
    "nestelten": "nesteln",
    "nesteltest": "nesteln",
    "nesteltet": "nesteln",
    "nestle": "nesteln",
    "nettem": "nett",
    "netten": "nett",
    "netter": "nett",
    "nettere": "nett",
    "netterem": "nett",
    "netteren": "nett",
    "netterer": "nett",
    "netteres": "nett",
    "nettes": "nett",
    "netteste": "nett",
    "nettestem": "nett",
    "nettesten": "nett",
    "nettester": "nett",
    "nettestes": "nett",
    "neuartigem": "neuartig",
    "neuartigen": "neuartig",
    "neuartiger": "neuartig",
    "neuartiges": "neuartig",
    "neuem": "neu",
    "neuen": "neu",
    "neuer": "neu",
    "neuere": "neu",
    "neuerem": "neu",
    "neueren": "neu",
    "neuerer": "neu",
    "neueres": "neu",
    "neuerliche": "neuerlich",
    "neuerlichem": "neuerlich",
    "neuerlichen": "neuerlich",
    "neuerlicher": "neuerlich",
    "neuerliches": "neuerlich",
    "neues": "neu",
    "neugeborenem": "neugeboren",
    "neugeborenen": "neugeboren",
    "neugeborener": "neugeboren",
    "neugeborenes": "neugeboren",
    "neugemacht": "neumachen",
    "neugeschaffene": "neugeschaffen",
    "neugeschaffenem": "neugeschaffen",
    "neugeschaffenen": "neugeschaffen",
    "neugeschaffener": "neugeschaffen",
    "neugeschaffenes": "neugeschaffen",
    "neugierigem": "neugierig",
    "neugierigen": "neugierig",
    "neugieriger": "neugierig",
    "neugierigere": "neugierig",
    "neugierigerem": "neugierig",
    "neugierigeren": "neugierig",
    "neugierigerer": "neugierig",
    "neugierigeres": "neugierig",
    "neugieriges": "neugierig",
    "neugierigste": "neugierig",
    "neugierigstem": "neugierig",
    "neugierigsten": "neugierig",
    "neugierigster": "neugierig",
    "neugierigstes": "neugierig",
    "neuhochdeutschem": "neuhochdeutsch",
    "neuhochdeutschen": "neuhochdeutsch",
    "neuhochdeutscher": "neuhochdeutsch",
    "neuhochdeutsches": "neuhochdeutsch",
    "neumache": "neumachen",
    "neumachend": "neumachen",
    "neumachest": "neumachen",
    "neumachet": "neumachen",
    "neumachst": "neumachen",
    "neumacht": "neumachen",
    "neumachte": "neumachen",
    "neumachten": "neumachen",
    "neumachtest": "neumachen",
    "neumachtet": "neumachen",
    "neureichem": "neureich",
    "neureichen": "neureich",
    "neureicher": "neureich",
    "neureiches": "neureich",
    "neurologischem": "neurologisch",
    "neurologischen": "neurologisch",
    "neurologischer": "neurologisch",
    "neurologisches": "neurologisch",
    "neuronale": "neuronal",
    "neuronalem": "neuronal",
    "neuronalen": "neuronal",
    "neuronaler": "neuronal",
    "neuronales": "neuronal",
    "neurotischem": "neurotisch",
    "neurotischen": "neurotisch",
    "neurotischer": "neurotisch",
    "neurotischere": "neurotisch",
    "neurotischerem": "neurotisch",
    "neurotischeren": "neurotisch",
    "neurotischerer": "neurotisch",
    "neurotischeres": "neurotisch",
    "neurotisches": "neurotisch",
    "neurotischste": "neurotisch",
    "neurotischstem": "neurotisch",
    "neurotischsten": "neurotisch",
    "neurotischster": "neurotisch",
    "neurotischstes": "neurotisch",
    "neurotisiere": "neurotisieren",
    "neurotisierend": "neurotisieren",
    "neurotisierende": "neurotisierend",
    "neurotisierendem": "neurotisierend",
    "neurotisierenden": "neurotisierend",
    "neurotisierender": "neurotisierend",
    "neurotisierendere": "neurotisierend",
    "neurotisierenderem": "neurotisierend",
    "neurotisierenderen": "neurotisierend",
    "neurotisierenderer": "neurotisierend",
    "neurotisierenderes": "neurotisierend",
    "neurotisierendes": "neurotisierend",
    "neurotisierendste": "neurotisierend",
    "neurotisierendstem": "neurotisierend",
    "neurotisierendsten": "neurotisierend",
    "neurotisierendster": "neurotisierend",
    "neurotisierendstes": "neurotisierend",
    "neurotisierest": "neurotisieren",
    "neurotisieret": "neurotisieren",
    "neurotisierst": "neurotisieren",
    "neurotisiert": "neurotisieren",
    "neurotisierte": "neurotisieren",
    "neurotisiertem": "neurotisiert",
    "neurotisierten": "neurotisieren",
    "neurotisierter": "neurotisiert",
    "neurotisiertere": "neurotisiert",
    "neurotisierterem": "neurotisiert",
    "neurotisierteren": "neurotisiert",
    "neurotisierterer": "neurotisiert",
    "neurotisierteres": "neurotisiert",
    "neurotisiertes": "neurotisiert",
    "neurotisiertest": "neurotisieren",
    "neurotisierteste": "neurotisiert",
    "neurotisiertestem": "neurotisiert",
    "neurotisiertesten": "neurotisiert",
    "neurotisiertester": "neurotisiert",
    "neurotisiertestes": "neurotisiert",
    "neurotisiertet": "neurotisieren",
    "neustem": "neu",
    "neusten": "neu",
    "neuster": "neu",
    "neustes": "neu",
    "neutestamentlichem": "neutestamentlich",
    "neutestamentlichen": "neutestamentlich",
    "neutestamentlicher": "neutestamentlich",
    "neutestamentliches": "neutestamentlich",
    "neutrale": "neutral",
    "neutralem": "neutral",
    "neutralen": "neutral",
    "neutraler": "neutral",
    "neutralere": "neutral",
    "neutralerem": "neutral",
    "neutraleren": "neutral",
    "neutralerer": "neutral",
    "neutraleres": "neutral",
    "neutrales": "neutral",
    "neutralisiere": "neutralisieren",
    "neutralisierend": "neutralisieren",
    "neutralisierende": "neutralisierend",
    "neutralisierendem": "neutralisierend",
    "neutralisierenden": "neutralisierend",
    "neutralisierender": "neutralisierend",
    "neutralisierendes": "neutralisierend",
    "neutralisierest": "neutralisieren",
    "neutralisieret": "neutralisieren",
    "neutralisierst": "neutralisieren",
    "neutralisiert": "neutralisieren",
    "neutralisierte": "neutralisieren",
    "neutralisiertem": "neutralisiert",
    "neutralisierten": "neutralisieren",
    "neutralisierter": "neutralisiert",
    "neutralisiertes": "neutralisiert",
    "neutralisiertest": "neutralisieren",
    "neutralisiertet": "neutralisieren",
    "neutralstem": "neutral",
    "neutralsten": "neutral",
    "neutralster": "neutral",
    "neutralstes": "neutral",
    "neuvermähltem": "neuvermählt",
    "neuvermählten": "neuvermählt",
    "neuvermählter": "neuvermählt",
    "neuvermähltes": "neuvermählt",
    "neuzeitlichem": "neuzeitlich",
    "neuzeitlichen": "neuzeitlich",
    "neuzeitlicher": "neuzeitlich",
    "neuzeitliches": "neuzeitlich",
    "neuzumachen": "neumachen",
    "nichtautomatischem": "nichtautomatisch",
    "nichtautomatischen": "nichtautomatisch",
    "nichtautomatischer": "nichtautomatisch",
    "nichtautomatisches": "nichtautomatisch",
    "nichtigem": "nichtig",
    "nichtigen": "nichtig",
    "nichtiger": "nichtig",
    "nichtiges": "nichtig",
    "nichtrevanchistischem": "nichtrevanchistisch",
    "nichtrevanchistischen": "nichtrevanchistisch",
    "nichtrevanchistischer": "nichtrevanchistisch",
    "nichtrevanchistisches": "nichtrevanchistisch",
    "nichtsnutzigem": "nichtsnutzig",
    "nichtsnutzigen": "nichtsnutzig",
    "nichtsnutziger": "nichtsnutzig",
    "nichtsnutzigere": "nichtsnutzig",
    "nichtsnutzigerem": "nichtsnutzig",
    "nichtsnutzigeren": "nichtsnutzig",
    "nichtsnutzigerer": "nichtsnutzig",
    "nichtsnutzigeres": "nichtsnutzig",
    "nichtsnutziges": "nichtsnutzig",
    "nichtsnutzigste": "nichtsnutzig",
    "nichtsnutzigstem": "nichtsnutzig",
    "nichtsnutzigsten": "nichtsnutzig",
    "nichtsnutzigster": "nichtsnutzig",
    "nichtsnutzigstes": "nichtsnutzig",
    "nichtssagende": "nichtssagend",
    "nichtssagendem": "nichtssagend",
    "nichtssagenden": "nichtssagend",
    "nichtssagender": "nichtssagend",
    "nichtssagendes": "nichtssagend",
    "nichtöffentlichem": "nichtöffentlich",
    "nichtöffentlichen": "nichtöffentlich",
    "nichtöffentlicher": "nichtöffentlich",
    "nichtöffentliches": "nichtöffentlich",
    "nicke": "nicken",
    "nickend": "nicken",
    "nickende": "nickend",
    "nickendem": "nickend",
    "nickenden": "nickend",
    "nickender": "nickend",
    "nickendes": "nickend",
    "nickest": "nicken",
    "nicket": "nicken",
    "nickst": "nicken",
    "nickt": "nicken",
    "nickte": "nicken",
    "nickten": "nicken",
    "nicktest": "nicken",
    "nicktet": "nicken",
    "niederbeuge": "niederbeugen",
    "niederbeugend": "niederbeugen",
    "niederbeugende": "niederbeugend",
    "niederbeugendem": "niederbeugend",
    "niederbeugenden": "niederbeugend",
    "niederbeugender": "niederbeugend",
    "niederbeugendes": "niederbeugend",
    "niederbeugest": "niederbeugen",
    "niederbeuget": "niederbeugen",
    "niederbeugst": "niederbeugen",
    "niederbeugt": "niederbeugen",
    "niederbeugte": "niederbeugen",
    "niederbeugten": "niederbeugen",
    "niederbeugtest": "niederbeugen",
    "niederbeugtet": "niederbeugen",
    "niederbiege": "niederbiegen",
    "niederbiegend": "niederbiegen",
    "niederbiegende": "niederbiegend",
    "niederbiegendem": "niederbiegend",
    "niederbiegenden": "niederbiegend",
    "niederbiegender": "niederbiegend",
    "niederbiegendes": "niederbiegend",
    "niederbiegest": "niederbiegen",
    "niederbieget": "niederbiegen",
    "niederbiegst": "niederbiegen",
    "niederbiegt": "niederbiegen",
    "niederblase": "niederblasen",
    "niederblasend": "niederblasen",
    "niederblasende": "niederblasend",
    "niederblasendem": "niederblasend",
    "niederblasenden": "niederblasend",
    "niederblasender": "niederblasend",
    "niederblasendes": "niederblasend",
    "niederblasest": "niederblasen",
    "niederblaset": "niederblasen",
    "niederblast": "niederblasen",
    "niederblies": "niederblasen",
    "niederbliese": "niederblasen",
    "niederbliesen": "niederblasen",
    "niederbliesest": "niederblasen",
    "niederblieset": "niederblasen",
    "niederbliest": "niederblasen",
    "niederbläst": "niederblasen",
    "niederbog": "niederbiegen",
    "niederbogen": "niederbiegen",
    "niederbogst": "niederbiegen",
    "niederbogt": "niederbiegen",
    "niederbrach": "niederbrechen",
    "niederbrachen": "niederbrechen",
    "niederbrachst": "niederbrechen",
    "niederbracht": "niederbrechen",
    "niederbrachte": "niederbringen",
    "niederbrachten": "niederbringen",
    "niederbrachtest": "niederbringen",
    "niederbrachtet": "niederbringen",
    "niederbrannte": "niederbrennen",
    "niederbrannten": "niederbrennen",
    "niederbranntest": "niederbrennen",
    "niederbranntet": "niederbrennen",
    "niederbreche": "niederbrechen",
    "niederbrechend": "niederbrechen",
    "niederbrechende": "niederbrechend",
    "niederbrechendem": "niederbrechend",
    "niederbrechenden": "niederbrechend",
    "niederbrechender": "niederbrechend",
    "niederbrechendes": "niederbrechend",
    "niederbrechest": "niederbrechen",
    "niederbrechet": "niederbrechen",
    "niederbrecht": "niederbrechen",
    "niederbrenne": "niederbrennen",
    "niederbrennend": "niederbrennen",
    "niederbrennende": "niederbrennend",
    "niederbrennendem": "niederbrennend",
    "niederbrennenden": "niederbrennend",
    "niederbrennender": "niederbrennend",
    "niederbrennendes": "niederbrennend",
    "niederbrennest": "niederbrennen",
    "niederbrennet": "niederbrennen",
    "niederbrennst": "niederbrennen",
    "niederbrennt": "niederbrennen",
    "niederbrichst": "niederbrechen",
    "niederbricht": "niederbrechen",
    "niederbringe": "niederbringen",
    "niederbringend": "niederbringen",
    "niederbringende": "niederbringend",
    "niederbringendem": "niederbringend",
    "niederbringenden": "niederbringend",
    "niederbringender": "niederbringend",
    "niederbringendes": "niederbringend",
    "niederbringest": "niederbringen",
    "niederbringet": "niederbringen",
    "niederbringst": "niederbringen",
    "niederbringt": "niederbringen",
    "niederbräche": "niederbrechen",
    "niederbrächen": "niederbrechen",
    "niederbrächest": "niederbrechen",
    "niederbrächet": "niederbrechen",
    "niederbrächte": "niederbringen",
    "niederbrächten": "niederbringen",
    "niederbrächtest": "niederbringen",
    "niederbrächtet": "niederbringen",
    "niederböge": "niederbiegen",
    "niederbögen": "niederbiegen",
    "niederbögest": "niederbiegen",
    "niederböget": "niederbiegen",
    "niederbügele": "niederbügeln",
    "niederbügelnd": "niederbügeln",
    "niederbügelnde": "niederbügelnd",
    "niederbügelndem": "niederbügelnd",
    "niederbügelnden": "niederbügelnd",
    "niederbügelnder": "niederbügelnd",
    "niederbügelndes": "niederbügelnd",
    "niederbügelst": "niederbügeln",
    "niederbügelt": "niederbügeln",
    "niederbügelte": "niederbügeln",
    "niederbügelten": "niederbügeln",
    "niederbügeltest": "niederbügeln",
    "niederbügeltet": "niederbügeln",
    "niederbügle": "niederbügeln",
    "niederem": "nieder",
    "niederen": "nieder",
    "niederer": "nieder",
    "niederere": "nieder",
    "niedererem": "nieder",
    "niedereren": "nieder",
    "niedererer": "nieder",
    "niedereres": "nieder",
    "niederes": "nieder",
    "niederfalle": "niederfallen",
    "niederfallend": "niederfallen",
    "niederfallende": "niederfallend",
    "niederfallendem": "niederfallend",
    "niederfallenden": "niederfallend",
    "niederfallender": "niederfallend",
    "niederfallendes": "niederfallend",
    "niederfallest": "niederfallen",
    "niederfallet": "niederfallen",
    "niederfallt": "niederfallen",
    "niederfiel": "niederfallen",
    "niederfiele": "niederfallen",
    "niederfielen": "niederfallen",
    "niederfielest": "niederfallen",
    "niederfielet": "niederfallen",
    "niederfielst": "niederfallen",
    "niederfielt": "niederfallen",
    "niederfällst": "niederfallen",
    "niederfällt": "niederfallen",
    "niedergebeugt": "niederbeugen",
    "niedergebeugte": "niedergebeugt",
    "niedergebeugtem": "niedergebeugt",
    "niedergebeugten": "niedergebeugt",
    "niedergebeugter": "niedergebeugt",
    "niedergebeugtes": "niedergebeugt",
    "niedergeblasen": "niederblasen",
    "niedergeblasene": "niedergeblasen",
    "niedergeblasenem": "niedergeblasen",
    "niedergeblasenen": "niedergeblasen",
    "niedergeblasener": "niedergeblasen",
    "niedergeblasenes": "niedergeblasen",
    "niedergebogen": "niederbiegen",
    "niedergebogene": "niedergebogen",
    "niedergebogenem": "niedergebogen",
    "niedergebogenen": "niedergebogen",
    "niedergebogener": "niedergebogen",
    "niedergebogenes": "niedergebogen",
    "niedergebracht": "niederbringen",
    "niedergebrachte": "niedergebracht",
    "niedergebrachtem": "niedergebracht",
    "niedergebrachten": "niedergebracht",
    "niedergebrachter": "niedergebracht",
    "niedergebrachtes": "niedergebracht",
    "niedergebrannt": "niederbrennen",
    "niedergebrannte": "niedergebrannt",
    "niedergebranntem": "niedergebrannt",
    "niedergebrannten": "niedergebrannt",
    "niedergebrannter": "niedergebrannt",
    "niedergebranntes": "niedergebrannt",
    "niedergebrochen": "niederbrechen",
    "niedergebrochene": "niedergebrochen",
    "niedergebrochenem": "niedergebrochen",
    "niedergebrochenen": "niedergebrochen",
    "niedergebrochener": "niedergebrochen",
    "niedergebrochenes": "niedergebrochen",
    "niedergebügelt": "niederbügeln",
    "niedergebügelte": "niedergebügelt",
    "niedergebügeltem": "niedergebügelt",
    "niedergebügelten": "niedergebügelt",
    "niedergebügelter": "niedergebügelt",
    "niedergebügeltes": "niedergebügelt",
    "niedergefallen": "niederfallen",
    "niedergefallene": "niedergefallen",
    "niedergefallenem": "niedergefallen",
    "niedergefallenen": "niedergefallen",
    "niedergefallener": "niedergefallen",
    "niedergefallenes": "niedergefallen",
    "niedergeglitten": "niedergleiten",
    "niedergeglittene": "niedergeglitten",
    "niedergeglittenem": "niedergeglitten",
    "niedergeglittenen": "niedergeglitten",
    "niedergeglittener": "niedergeglitten",
    "niedergeglittenes": "niedergeglitten",
    "niedergehalten": "niederhalten",
    "niedergehaltene": "niedergehalten",
    "niedergehaltenem": "niedergehalten",
    "niedergehaltenen": "niedergehalten",
    "niedergehaltener": "niedergehalten",
    "niedergehaltenere": "niedergehalten",
    "niedergehaltenerem": "niedergehalten",
    "niedergehalteneren": "niedergehalten",
    "niedergehaltenerer": "niedergehalten",
    "niedergehalteneres": "niedergehalten",
    "niedergehaltenes": "niedergehalten",
    "niedergehaltenste": "niedergehalten",
    "niedergehaltenstem": "niedergehalten",
    "niedergehaltensten": "niedergehalten",
    "niedergehaltenster": "niedergehalten",
    "niedergehaltenstes": "niedergehalten",
    "niedergehauen": "niederhauen",
    "niedergehauene": "niedergehauen",
    "niedergehauenem": "niedergehauen",
    "niedergehauenen": "niedergehauen",
    "niedergehauener": "niedergehauen",
    "niedergehauenes": "niedergehauen",
    "niedergeholt": "niederholen",
    "niedergeholte": "niedergeholt",
    "niedergeholtem": "niedergeholt",
    "niedergeholten": "niedergeholt",
    "niedergeholter": "niedergeholt",
    "niedergeholtes": "niedergeholt",
    "niedergekniet": "niederknien",
    "niedergekniete": "niedergekniet",
    "niedergeknietem": "niedergekniet",
    "niedergeknieten": "niedergekniet",
    "niedergeknieter": "niedergekniet",
    "niedergeknietes": "niedergekniet",
    "niedergeknüppelt": "niederknüppeln",
    "niedergeknüppelte": "niedergeknüppelt",
    "niedergeknüppeltem": "niedergeknüppelt",
    "niedergeknüppelten": "niedergeknüppelt",
    "niedergeknüppelter": "niedergeknüppelt",
    "niedergeknüppeltes": "niedergeknüppelt",
    "niedergekämpft": "niederkämpfen",
    "niedergekämpfte": "niedergekämpft",
    "niedergekämpftem": "niedergekämpft",
    "niedergekämpften": "niedergekämpft",
    "niedergekämpfter": "niedergekämpft",
    "niedergekämpftere": "niedergekämpft",
    "niedergekämpfterem": "niedergekämpft",
    "niedergekämpfteren": "niedergekämpft",
    "niedergekämpfterer": "niedergekämpft",
    "niedergekämpfteres": "niedergekämpft",
    "niedergekämpftes": "niedergekämpft",
    "niedergekämpfteste": "niedergekämpft",
    "niedergekämpftestem": "niedergekämpft",
    "niedergekämpftesten": "niedergekämpft",
    "niedergekämpftester": "niedergekämpft",
    "niedergekämpftestes": "niedergekämpft",
    "niedergelassen": "niederlassen",
    "niedergelassene": "niedergelassen",
    "niedergelassenem": "niedergelassen",
    "niedergelassenen": "niedergelassen",
    "niedergelassener": "niedergelassen",
    "niedergelassenes": "niedergelassen",
    "niedergelegt": "niederlegen",
    "niedergelegte": "niedergelegt",
    "niedergelegtem": "niedergelegt",
    "niedergelegten": "niedergelegt",
    "niedergelegter": "niedergelegt",
    "niedergelegtes": "niedergelegt",
    "niedergemacht": "niedermachen",
    "niedergemachte": "niedergemacht",
    "niedergemachtem": "niedergemacht",
    "niedergemachten": "niedergemacht",
    "niedergemachter": "niedergemacht",
    "niedergemachtes": "niedergemacht",
    "niedergemetzelt": "niedermetzeln",
    "niedergemetzelte": "niedergemetzelt",
    "niedergemetzeltem": "niedergemetzelt",
    "niedergemetzelten": "niedergemetzelt",
    "niedergemetzelter": "niedergemetzelt",
    "niedergemetzeltes": "niedergemetzelt",
    "niedergemäht": "niedermähen",
    "niedergemähte": "niedergemäht",
    "niedergemähtem": "niedergemäht",
    "niedergemähten": "niedergemäht",
    "niedergemähter": "niedergemäht",
    "niedergemähtere": "niedergemäht",
    "niedergemähterem": "niedergemäht",
    "niedergemähteren": "niedergemäht",
    "niedergemähterer": "niedergemäht",
    "niedergemähteres": "niedergemäht",
    "niedergemähtes": "niedergemäht",
    "niedergemähteste": "niedergemäht",
    "niedergemähtestem": "niedergemäht",
    "niedergemähtesten": "niedergemäht",
    "niedergemähtester": "niedergemäht",
    "niedergemähtestes": "niedergemäht",
    "niedergeprasselt": "niederprasseln",
    "niedergeprasselte": "niedergeprasselt",
    "niedergeprasseltem": "niedergeprasselt",
    "niedergeprasselten": "niedergeprasselt",
    "niedergeprasselter": "niedergeprasselt",
    "niedergeprasseltere": "niedergeprasselt",
    "niedergeprasselterem": "niedergeprasselt",
    "niedergeprasselteren": "niedergeprasselt",
    "niedergeprasselterer": "niedergeprasselt",
    "niedergeprasselteres": "niedergeprasselt",
    "niedergeprasseltes": "niedergeprasselt",
    "niedergeprasselteste": "niedergeprasselt",
    "niedergeprasseltestem": "niedergeprasselt",
    "niedergeprasseltesten": "niedergeprasselt",
    "niedergeprasseltester": "niedergeprasselt",
    "niedergeprasseltestes": "niedergeprasselt",
    "niedergerissen": "niederreißen",
    "niedergerissene": "niedergerissen",
    "niedergerissenem": "niedergerissen",
    "niedergerissenen": "niedergerissen",
    "niedergerissener": "niedergerissen",
    "niedergerissenes": "niedergerissen",
    "niedergerungen": "niederringen",
    "niedergerungene": "niedergerungen",
    "niedergerungenem": "niedergerungen",
    "niedergerungenen": "niedergerungen",
    "niedergerungener": "niedergerungen",
    "niedergerungenere": "niedergerungen",
    "niedergerungenerem": "niedergerungen",
    "niedergerungeneren": "niedergerungen",
    "niedergerungenerer": "niedergerungen",
    "niedergerungeneres": "niedergerungen",
    "niedergerungenes": "niedergerungen",
    "niedergerungenste": "niedergerungen",
    "niedergerungenstem": "niedergerungen",
    "niedergerungensten": "niedergerungen",
    "niedergerungenster": "niedergerungen",
    "niedergerungenstes": "niedergerungen",
    "niedergesaust": "niedersausen",
    "niedergesauste": "niedergesaust",
    "niedergesaustem": "niedergesaust",
    "niedergesausten": "niedergesaust",
    "niedergesauster": "niedergesaust",
    "niedergesaustes": "niedergesaust",
    "niedergeschlagen": "niederschlagen",
    "niedergeschlagene": "niedergeschlagen",
    "niedergeschlagenem": "niedergeschlagen",
    "niedergeschlagenen": "niedergeschlagen",
    "niedergeschlagener": "niedergeschlagen",
    "niedergeschlagenere": "niedergeschlagen",
    "niedergeschlagenerem": "niedergeschlagen",
    "niedergeschlageneren": "niedergeschlagen",
    "niedergeschlagenerer": "niedergeschlagen",
    "niedergeschlageneres": "niedergeschlagen",
    "niedergeschlagenes": "niedergeschlagen",
    "niedergeschlagenste": "niedergeschlagen",
    "niedergeschlagenstem": "niedergeschlagen",
    "niedergeschlagensten": "niedergeschlagen",
    "niedergeschlagenster": "niedergeschlagen",
    "niedergeschlagenstes": "niedergeschlagen",
    "niedergeschmettert": "niederschmettern",
    "niedergeschmetterte": "niedergeschmettert",
    "niedergeschmettertem": "niedergeschmettert",
    "niedergeschmetterten": "niedergeschmettert",
    "niedergeschmetterter": "niedergeschmettert",
    "niedergeschmettertere": "niedergeschmettert",
    "niedergeschmetterterem": "niedergeschmettert",
    "niedergeschmetterteren": "niedergeschmettert",
    "niedergeschmetterterer": "niedergeschmettert",
    "niedergeschmetterteres": "niedergeschmettert",
    "niedergeschmettertes": "niedergeschmettert",
    "niedergeschmetterteste": "niedergeschmettert",
    "niedergeschmettertestem": "niedergeschmettert",
    "niedergeschmettertesten": "niedergeschmettert",
    "niedergeschmettertester": "niedergeschmettert",
    "niedergeschmettertestes": "niedergeschmettert",
    "niedergeschossen": "niederschießen",
    "niedergeschossene": "niedergeschossen",
    "niedergeschossenem": "niedergeschossen",
    "niedergeschossenen": "niedergeschossen",
    "niedergeschossener": "niedergeschossen",
    "niedergeschossenes": "niedergeschossen",
    "niedergeschrieben": "niederschreiben",
    "niedergeschriebene": "niedergeschrieben",
    "niedergeschriebenem": "niedergeschrieben",
    "niedergeschriebenen": "niedergeschrieben",
    "niedergeschriebener": "niedergeschrieben",
    "niedergeschriebenes": "niedergeschrieben",
    "niedergeschrien": "niederschreien",
    "niedergeschriene": "niedergeschrien",
    "niedergeschrienem": "niedergeschrien",
    "niedergeschrienen": "niedergeschrien",
    "niedergeschriener": "niedergeschrien",
    "niedergeschrienere": "niedergeschrien",
    "niedergeschrienerem": "niedergeschrien",
    "niedergeschrieneren": "niedergeschrien",
    "niedergeschrienerer": "niedergeschrien",
    "niedergeschrieneres": "niedergeschrien",
    "niedergeschrienes": "niedergeschrien",
    "niedergeschrienste": "niedergeschrien",
    "niedergeschrienstem": "niedergeschrien",
    "niedergeschriensten": "niedergeschrien",
    "niedergeschrienster": "niedergeschrien",
    "niedergeschrienstes": "niedergeschrien",
    "niedergesetzt": "niedersetzen",
    "niedergesetzte": "niedergesetzt",
    "niedergesetztem": "niedergesetzt",
    "niedergesetzten": "niedergesetzt",
    "niedergesetzter": "niedergesetzt",
    "niedergesetztes": "niedergesetzt",
    "niedergestampft": "niederstampfen",
    "niedergestampfte": "niedergestampft",
    "niedergestampftem": "niedergestampft",
    "niedergestampften": "niedergestampft",
    "niedergestampfter": "niedergestampft",
    "niedergestampftes": "niedergestampft",
    "niedergestiegen": "niedersteigen",
    "niedergestiegene": "niedergestiegen",
    "niedergestiegenem": "niedergestiegen",
    "niedergestiegenen": "niedergestiegen",
    "niedergestiegener": "niedergestiegen",
    "niedergestiegenere": "niedergestiegen",
    "niedergestiegenerem": "niedergestiegen",
    "niedergestiegeneren": "niedergestiegen",
    "niedergestiegenerer": "niedergestiegen",
    "niedergestiegeneres": "niedergestiegen",
    "niedergestiegenes": "niedergestiegen",
    "niedergestiegenste": "niedergestiegen",
    "niedergestiegenstem": "niedergestiegen",
    "niedergestiegensten": "niedergestiegen",
    "niedergestiegenster": "niedergestiegen",
    "niedergestiegenstes": "niedergestiegen",
    "niedergestochen": "niederstechen",
    "niedergestochene": "niedergestochen",
    "niedergestochenem": "niedergestochen",
    "niedergestochenen": "niedergestochen",
    "niedergestochener": "niedergestochen",
    "niedergestochenes": "niedergestochen",
    "niedergestoßen": "niederstoßen",
    "niedergestoßene": "niedergestoßen",
    "niedergestoßenem": "niedergestoßen",
    "niedergestoßenen": "niedergestoßen",
    "niedergestoßener": "niedergestoßen",
    "niedergestoßenes": "niedergestoßen",
    "niedergestreckt": "niederstrecken",
    "niedergestreckte": "niedergestreckt",
    "niedergestrecktem": "niedergestreckt",
    "niedergestreckten": "niedergestreckt",
    "niedergestreckter": "niedergestreckt",
    "niedergestrecktes": "niedergestreckt",
    "niedergesunken": "niedersinken",
    "niedergesunkene": "niedergesunken",
    "niedergesunkenem": "niedergesunken",
    "niedergesunkenen": "niedergesunken",
    "niedergesunkener": "niedergesunken",
    "niedergesunkenes": "niedergesunken",
    "niedergetrampelt": "niedertrampeln",
    "niedergetrampelte": "niedergetrampelt",
    "niedergetrampeltem": "niedergetrampelt",
    "niedergetrampelten": "niedergetrampelt",
    "niedergetrampelter": "niedergetrampelt",
    "niedergetrampeltere": "niedergetrampelt",
    "niedergetrampelterem": "niedergetrampelt",
    "niedergetrampelteren": "niedergetrampelt",
    "niedergetrampelterer": "niedergetrampelt",
    "niedergetrampelteres": "niedergetrampelt",
    "niedergetrampeltes": "niedergetrampelt",
    "niedergetrampelteste": "niedergetrampelt",
    "niedergetrampeltestem": "niedergetrampelt",
    "niedergetrampeltesten": "niedergetrampelt",
    "niedergetrampeltester": "niedergetrampelt",
    "niedergetrampeltestes": "niedergetrampelt",
    "niedergetreten": "niedertreten",
    "niedergetretene": "niedergetreten",
    "niedergetretenem": "niedergetreten",
    "niedergetretenen": "niedergetreten",
    "niedergetretener": "niedergetreten",
    "niedergetretenere": "niedergetreten",
    "niedergetretenerem": "niedergetreten",
    "niedergetreteneren": "niedergetreten",
    "niedergetretenerer": "niedergetreten",
    "niedergetreteneres": "niedergetreten",
    "niedergetretenes": "niedergetreten",
    "niedergetretenste": "niedergetreten",
    "niedergetretenstem": "niedergetreten",
    "niedergetretensten": "niedergetreten",
    "niedergetretenster": "niedergetreten",
    "niedergetretenstes": "niedergetreten",
    "niedergeworfen": "niederwerfen",
    "niedergeworfene": "niedergeworfen",
    "niedergeworfenem": "niedergeworfen",
    "niedergeworfenen": "niedergeworfen",
    "niedergeworfener": "niedergeworfen",
    "niedergeworfenes": "niedergeworfen",
    "niedergezwungen": "niederzwingen",
    "niedergezwungene": "niedergezwungen",
    "niedergezwungenem": "niedergezwungen",
    "niedergezwungenen": "niedergezwungen",
    "niedergezwungener": "niedergezwungen",
    "niedergezwungenes": "niedergezwungen",
    "niedergleite": "niedergleiten",
    "niedergleitend": "niedergleiten",
    "niedergleitende": "niedergleitend",
    "niedergleitendem": "niedergleitend",
    "niedergleitenden": "niedergleitend",
    "niedergleitender": "niedergleitend",
    "niedergleitendes": "niedergleitend",
    "niedergleitest": "niedergleiten",
    "niedergleitet": "niedergleiten",
    "niederglitt": "niedergleiten",
    "niederglitte": "niedergleiten",
    "niederglitten": "niedergleiten",
    "niederglittest": "niedergleiten",
    "niederglittet": "niedergleiten",
    "niederhalte": "niederhalten",
    "niederhaltend": "niederhalten",
    "niederhaltende": "niederhaltend",
    "niederhaltendem": "niederhaltend",
    "niederhaltenden": "niederhaltend",
    "niederhaltender": "niederhaltend",
    "niederhaltendere": "niederhaltend",
    "niederhaltenderem": "niederhaltend",
    "niederhaltenderen": "niederhaltend",
    "niederhaltenderer": "niederhaltend",
    "niederhaltenderes": "niederhaltend",
    "niederhaltendes": "niederhaltend",
    "niederhaltendste": "niederhaltend",
    "niederhaltendstem": "niederhaltend",
    "niederhaltendsten": "niederhaltend",
    "niederhaltendster": "niederhaltend",
    "niederhaltendstes": "niederhaltend",
    "niederhaltest": "niederhalten",
    "niederhaltet": "niederhalten",
    "niederhaue": "niederhauen",
    "niederhauend": "niederhauen",
    "niederhauende": "niederhauend",
    "niederhauendem": "niederhauend",
    "niederhauenden": "niederhauend",
    "niederhauender": "niederhauend",
    "niederhauendes": "niederhauend",
    "niederhauest": "niederhauen",
    "niederhauet": "niederhauen",
    "niederhaust": "niederhauen",
    "niederhaut": "niederhauen",
    "niederhaute": "niederhauen",
    "niederhauten": "niederhauen",
    "niederhautest": "niederhauen",
    "niederhautet": "niederhauen",
    "niederhielt": "niederhalten",
    "niederhielte": "niederhalten",
    "niederhielten": "niederhalten",
    "niederhieltest": "niederhalten",
    "niederhieltet": "niederhalten",
    "niederhole": "niederholen",
    "niederholend": "niederholen",
    "niederholende": "niederholend",
    "niederholendem": "niederholend",
    "niederholenden": "niederholend",
    "niederholender": "niederholend",
    "niederholendes": "niederholend",
    "niederholest": "niederholen",
    "niederholet": "niederholen",
    "niederholst": "niederholen",
    "niederholt": "niederholen",
    "niederholte": "niederholen",
    "niederholten": "niederholen",
    "niederholtest": "niederholen",
    "niederholtet": "niederholen",
    "niederhält": "niederhalten",
    "niederhältst": "niederhalten",
    "niederknie": "niederknien",
    "niederkniend": "niederknien",
    "niederkniende": "niederkniend",
    "niederkniendem": "niederkniend",
    "niederknienden": "niederkniend",
    "niederkniender": "niederkniend",
    "niederkniendes": "niederkniend",
    "niederkniest": "niederknien",
    "niederkniet": "niederknien",
    "niederkniete": "niederknien",
    "niederknieten": "niederknien",
    "niederknietest": "niederknien",
    "niederknietet": "niederknien",
    "niederknüppele": "niederknüppeln",
    "niederknüppelnd": "niederknüppeln",
    "niederknüppelnde": "niederknüppelnd",
    "niederknüppelndem": "niederknüppelnd",
    "niederknüppelnden": "niederknüppelnd",
    "niederknüppelnder": "niederknüppelnd",
    "niederknüppelndes": "niederknüppelnd",
    "niederknüppelst": "niederknüppeln",
    "niederknüppelt": "niederknüppeln",
    "niederknüppelte": "niederknüppeln",
    "niederknüppelten": "niederknüppeln",
    "niederknüppeltest": "niederknüppeln",
    "niederknüppeltet": "niederknüppeln",
    "niederknüpple": "niederknüppeln",
    "niederkämpfe": "niederkämpfen",
    "niederkämpfend": "niederkämpfen",
    "niederkämpfende": "niederkämpfend",
    "niederkämpfendem": "niederkämpfend",
    "niederkämpfenden": "niederkämpfend",
    "niederkämpfender": "niederkämpfend",
    "niederkämpfendere": "niederkämpfend",
    "niederkämpfenderem": "niederkämpfend",
    "niederkämpfenderen": "niederkämpfend",
    "niederkämpfenderer": "niederkämpfend",
    "niederkämpfenderes": "niederkämpfend",
    "niederkämpfendes": "niederkämpfend",
    "niederkämpfendste": "niederkämpfend",
    "niederkämpfendstem": "niederkämpfend",
    "niederkämpfendsten": "niederkämpfend",
    "niederkämpfendster": "niederkämpfend",
    "niederkämpfendstes": "niederkämpfend",
    "niederkämpfest": "niederkämpfen",
    "niederkämpfet": "niederkämpfen",
    "niederkämpfst": "niederkämpfen",
    "niederkämpft": "niederkämpfen",
    "niederkämpfte": "niederkämpfen",
    "niederkämpften": "niederkämpfen",
    "niederkämpftest": "niederkämpfen",
    "niederkämpftet": "niederkämpfen",
    "niederlasse": "niederlassen",
    "niederlassend": "niederlassen",
    "niederlassende": "niederlassend",
    "niederlassendem": "niederlassend",
    "niederlassenden": "niederlassend",
    "niederlassender": "niederlassend",
    "niederlassendes": "niederlassend",
    "niederlassest": "niederlassen",
    "niederlasset": "niederlassen",
    "niederlaßt": "niederlassen",
    "niederlege": "niederlegen",
    "niederlegend": "niederlegen",
    "niederlegende": "niederlegend",
    "niederlegendem": "niederlegend",
    "niederlegenden": "niederlegend",
    "niederlegender": "niederlegend",
    "niederlegendes": "niederlegend",
    "niederlegest": "niederlegen",
    "niederleget": "niederlegen",
    "niederlegst": "niederlegen",
    "niederlegt": "niederlegen",
    "niederlegte": "niederlegen",
    "niederlegten": "niederlegen",
    "niederlegtest": "niederlegen",
    "niederlegtet": "niederlegen",
    "niederließ": "niederlassen",
    "niederließe": "niederlassen",
    "niederließen": "niederlassen",
    "niederließest": "niederlassen",
    "niederließet": "niederlassen",
    "niederließt": "niederlassen",
    "niederländischem": "niederländisch",
    "niederländischen": "niederländisch",
    "niederländischer": "niederländisch",
    "niederländischere": "niederländisch",
    "niederländischerem": "niederländisch",
    "niederländischeren": "niederländisch",
    "niederländischerer": "niederländisch",
    "niederländischeres": "niederländisch",
    "niederländisches": "niederländisch",
    "niederländischste": "niederländisch",
    "niederländischstem": "niederländisch",
    "niederländischsten": "niederländisch",
    "niederländischster": "niederländisch",
    "niederländischstes": "niederländisch",
    "niederläßt": "niederlassen",
    "niedermache": "niedermachen",
    "niedermachend": "niedermachen",
    "niedermachende": "niedermachend",
    "niedermachendem": "niedermachend",
    "niedermachenden": "niedermachend",
    "niedermachender": "niedermachend",
    "niedermachendes": "niedermachend",
    "niedermachest": "niedermachen",
    "niedermachet": "niedermachen",
    "niedermachst": "niedermachen",
    "niedermacht": "niedermachen",
    "niedermachte": "niedermachen",
    "niedermachten": "niedermachen",
    "niedermachtest": "niedermachen",
    "niedermachtet": "niedermachen",
    "niedermetzele": "niedermetzeln",
    "niedermetzelnd": "niedermetzeln",
    "niedermetzelnde": "niedermetzelnd",
    "niedermetzelndem": "niedermetzelnd",
    "niedermetzelnden": "niedermetzelnd",
    "niedermetzelnder": "niedermetzelnd",
    "niedermetzelndes": "niedermetzelnd",
    "niedermetzelst": "niedermetzeln",
    "niedermetzelt": "niedermetzeln",
    "niedermetzelte": "niedermetzeln",
    "niedermetzelten": "niedermetzeln",
    "niedermetzeltest": "niedermetzeln",
    "niedermetzeltet": "niedermetzeln",
    "niedermetzle": "niedermetzeln",
    "niedermähe": "niedermähen",
    "niedermähend": "niedermähen",
    "niedermähende": "niedermähend",
    "niedermähendem": "niedermähend",
    "niedermähenden": "niedermähend",
    "niedermähender": "niedermähend",
    "niedermähendere": "niedermähend",
    "niedermähenderem": "niedermähend",
    "niedermähenderen": "niedermähend",
    "niedermähenderer": "niedermähend",
    "niedermähenderes": "niedermähend",
    "niedermähendes": "niedermähend",
    "niedermähendste": "niedermähend",
    "niedermähendstem": "niedermähend",
    "niedermähendsten": "niedermähend",
    "niedermähendster": "niedermähend",
    "niedermähendstes": "niedermähend",
    "niedermähest": "niedermähen",
    "niedermähet": "niedermähen",
    "niedermähst": "niedermähen",
    "niedermäht": "niedermähen",
    "niedermähte": "niedermähen",
    "niedermähten": "niedermähen",
    "niedermähtest": "niedermähen",
    "niedermähtet": "niedermähen",
    "niederprassele": "niederprasseln",
    "niederprasselnd": "niederprasseln",
    "niederprasselnde": "niederprasselnd",
    "niederprasselndem": "niederprasselnd",
    "niederprasselnden": "niederprasselnd",
    "niederprasselnder": "niederprasselnd",
    "niederprasselndere": "niederprasselnd",
    "niederprasselnderem": "niederprasselnd",
    "niederprasselnderen": "niederprasselnd",
    "niederprasselnderer": "niederprasselnd",
    "niederprasselnderes": "niederprasselnd",
    "niederprasselndes": "niederprasselnd",
    "niederprasselndste": "niederprasselnd",
    "niederprasselndstem": "niederprasselnd",
    "niederprasselndsten": "niederprasselnd",
    "niederprasselndster": "niederprasselnd",
    "niederprasselndstes": "niederprasselnd",
    "niederprasselst": "niederprasseln",
    "niederprasselt": "niederprasseln",
    "niederprasselte": "niederprasseln",
    "niederprasselten": "niederprasseln",
    "niederprasseltest": "niederprasseln",
    "niederprasseltet": "niederprasseln",
    "niederprassle": "niederprasseln",
    "niederrang": "niederringen",
    "niederrangen": "niederringen",
    "niederrangst": "niederringen",
    "niederrangt": "niederringen",
    "niederreiße": "niederreißen",
    "niederreißend": "niederreißen",
    "niederreißende": "niederreißend",
    "niederreißendem": "niederreißend",
    "niederreißenden": "niederreißend",
    "niederreißender": "niederreißend",
    "niederreißendes": "niederreißend",
    "niederreißest": "niederreißen",
    "niederreißet": "niederreißen",
    "niederreißt": "niederreißen",
    "niederringe": "niederringen",
    "niederringend": "niederringen",
    "niederringende": "niederringend",
    "niederringendem": "niederringend",
    "niederringenden": "niederringend",
    "niederringender": "niederringend",
    "niederringendere": "niederringend",
    "niederringenderem": "niederringend",
    "niederringenderen": "niederringend",
    "niederringenderer": "niederringend",
    "niederringenderes": "niederringend",
    "niederringendes": "niederringend",
    "niederringendste": "niederringend",
    "niederringendstem": "niederringend",
    "niederringendsten": "niederringend",
    "niederringendster": "niederringend",
    "niederringendstes": "niederringend",
    "niederringest": "niederringen",
    "niederringet": "niederringen",
    "niederringst": "niederringen",
    "niederringt": "niederringen",
    "niederrisse": "niederreißen",
    "niederrissen": "niederreißen",
    "niederrissest": "niederreißen",
    "niederrisset": "niederreißen",
    "niederriß": "niederreißen",
    "niederrißt": "niederreißen",
    "niederränge": "niederringen",
    "niederrängen": "niederringen",
    "niederrängest": "niederringen",
    "niederränget": "niederringen",
    "niedersank": "niedersinken",
    "niedersanken": "niedersinken",
    "niedersankst": "niedersinken",
    "niedersankt": "niedersinken",
    "niedersause": "niedersausen",
    "niedersausend": "niedersausen",
    "niedersausende": "niedersausend",
    "niedersausendem": "niedersausend",
    "niedersausenden": "niedersausend",
    "niedersausender": "niedersausend",
    "niedersausendes": "niedersausend",
    "niedersausest": "niedersausen",
    "niedersauset": "niedersausen",
    "niedersaust": "niedersausen",
    "niedersauste": "niedersausen",
    "niedersausten": "niedersausen",
    "niedersaustest": "niedersausen",
    "niedersaustet": "niedersausen",
    "niederschieße": "niederschießen",
    "niederschießend": "niederschießen",
    "niederschießende": "niederschießend",
    "niederschießendem": "niederschießend",
    "niederschießenden": "niederschießend",
    "niederschießender": "niederschießend",
    "niederschießendes": "niederschießend",
    "niederschießest": "niederschießen",
    "niederschießet": "niederschießen",
    "niederschießt": "niederschießen",
    "niederschlagend": "niederschlagen",
    "niederschlagende": "niederschlagend",
    "niederschlagendem": "niederschlagend",
    "niederschlagenden": "niederschlagend",
    "niederschlagender": "niederschlagend",
    "niederschlagendere": "niederschlagend",
    "niederschlagenderem": "niederschlagend",
    "niederschlagenderen": "niederschlagend",
    "niederschlagenderer": "niederschlagend",
    "niederschlagenderes": "niederschlagend",
    "niederschlagendes": "niederschlagend",
    "niederschlagendste": "niederschlagend",
    "niederschlagendstem": "niederschlagend",
    "niederschlagendsten": "niederschlagend",
    "niederschlagendster": "niederschlagend",
    "niederschlagendstes": "niederschlagend",
    "niederschlagest": "niederschlagen",
    "niederschlaget": "niederschlagen",
    "niederschlagt": "niederschlagen",
    "niederschlug": "niederschlagen",
    "niederschlugen": "niederschlagen",
    "niederschlugst": "niederschlagen",
    "niederschlugt": "niederschlagen",
    "niederschlägst": "niederschlagen",
    "niederschlägt": "niederschlagen",
    "niederschlüge": "niederschlagen",
    "niederschlügen": "niederschlagen",
    "niederschlügest": "niederschlagen",
    "niederschlüget": "niederschlagen",
    "niederschmettere": "niederschmettern",
    "niederschmetternd": "niederschmettern",
    "niederschmetternde": "niederschmetternd",
    "niederschmetterndem": "niederschmetternd",
    "niederschmetternden": "niederschmetternd",
    "niederschmetternder": "niederschmetternd",
    "niederschmetterndere": "niederschmetternd",
    "niederschmetternderem": "niederschmetternd",
    "niederschmetternderen": "niederschmetternd",
    "niederschmetternderer": "niederschmetternd",
    "niederschmetternderes": "niederschmetternd",
    "niederschmetterndes": "niederschmetternd",
    "niederschmetterndste": "niederschmetternd",
    "niederschmetterndstem": "niederschmetternd",
    "niederschmetterndsten": "niederschmetternd",
    "niederschmetterndster": "niederschmetternd",
    "niederschmetterndstes": "niederschmetternd",
    "niederschmetterst": "niederschmettern",
    "niederschmettert": "niederschmettern",
    "niederschmetterte": "niederschmettern",
    "niederschmetterten": "niederschmettern",
    "niederschmettertest": "niederschmettern",
    "niederschmettertet": "niederschmettern",
    "niederschossen": "niederschießen",
    "niederschoß": "niederschießen",
    "niederschoßt": "niederschießen",
    "niederschreibe": "niederschreiben",
    "niederschreibend": "niederschreiben",
    "niederschreibende": "niederschreibend",
    "niederschreibendem": "niederschreibend",
    "niederschreibenden": "niederschreibend",
    "niederschreibender": "niederschreibend",
    "niederschreibendes": "niederschreibend",
    "niederschreibest": "niederschreiben",
    "niederschreibet": "niederschreiben",
    "niederschreibst": "niederschreiben",
    "niederschreibt": "niederschreiben",
    "niederschreie": "niederschreien",
    "niederschreiend": "niederschreien",
    "niederschreiende": "niederschreiend",
    "niederschreiendem": "niederschreiend",
    "niederschreienden": "niederschreiend",
    "niederschreiender": "niederschreiend",
    "niederschreiendere": "niederschreiend",
    "niederschreienderem": "niederschreiend",
    "niederschreienderen": "niederschreiend",
    "niederschreienderer": "niederschreiend",
    "niederschreienderes": "niederschreiend",
    "niederschreiendes": "niederschreiend",
    "niederschreiendste": "niederschreiend",
    "niederschreiendstem": "niederschreiend",
    "niederschreiendsten": "niederschreiend",
    "niederschreiendster": "niederschreiend",
    "niederschreiendstes": "niederschreiend",
    "niederschreiest": "niederschreien",
    "niederschreiet": "niederschreien",
    "niederschreist": "niederschreien",
    "niederschreit": "niederschreien",
    "niederschrie": "niederschreien",
    "niederschrieb": "niederschreiben",
    "niederschriebe": "niederschreiben",
    "niederschrieben": "niederschreiben",
    "niederschriebest": "niederschreiben",
    "niederschriebet": "niederschreiben",
    "niederschriebst": "niederschreiben",
    "niederschriebt": "niederschreiben",
    "niederschriee": "niederschreien",
    "niederschrieen": "niederschreien",
    "niederschrieest": "niederschreien",
    "niederschrieet": "niederschreien",
    "niederschrien": "niederschreien",
    "niederschriest": "niederschreien",
    "niederschriet": "niederschreien",
    "niederschösse": "niederschießen",
    "niederschössen": "niederschießen",
    "niederschössest": "niederschießen",
    "niederschösset": "niederschießen",
    "niedersetze": "niedersetzen",
    "niedersetzend": "niedersetzen",
    "niedersetzende": "niedersetzend",
    "niedersetzendem": "niedersetzend",
    "niedersetzenden": "niedersetzend",
    "niedersetzender": "niedersetzend",
    "niedersetzendes": "niedersetzend",
    "niedersetzest": "niedersetzen",
    "niedersetzet": "niedersetzen",
    "niedersetzt": "niedersetzen",
    "niedersetzte": "niedersetzen",
    "niedersetzten": "niedersetzen",
    "niedersetztest": "niedersetzen",
    "niedersetztet": "niedersetzen",
    "niedersinke": "niedersinken",
    "niedersinkend": "niedersinken",
    "niedersinkende": "niedersinkend",
    "niedersinkendem": "niedersinkend",
    "niedersinkenden": "niedersinkend",
    "niedersinkender": "niedersinkend",
    "niedersinkendes": "niedersinkend",
    "niedersinkest": "niedersinken",
    "niedersinket": "niedersinken",
    "niedersinkst": "niedersinken",
    "niedersinkt": "niedersinken",
    "niederstach": "niederstechen",
    "niederstachen": "niederstechen",
    "niederstachst": "niederstechen",
    "niederstacht": "niederstechen",
    "niederstampfe": "niederstampfen",
    "niederstampfend": "niederstampfen",
    "niederstampfende": "niederstampfend",
    "niederstampfendem": "niederstampfend",
    "niederstampfenden": "niederstampfend",
    "niederstampfender": "niederstampfend",
    "niederstampfendes": "niederstampfend",
    "niederstampfest": "niederstampfen",
    "niederstampfet": "niederstampfen",
    "niederstampfst": "niederstampfen",
    "niederstampft": "niederstampfen",
    "niederstampfte": "niederstampfen",
    "niederstampften": "niederstampfen",
    "niederstampftest": "niederstampfen",
    "niederstampftet": "niederstampfen",
    "niederste": "nieder",
    "niedersteche": "niederstechen",
    "niederstechend": "niederstechen",
    "niederstechende": "niederstechend",
    "niederstechendem": "niederstechend",
    "niederstechenden": "niederstechend",
    "niederstechender": "niederstechend",
    "niederstechendes": "niederstechend",
    "niederstechest": "niederstechen",
    "niederstechet": "niederstechen",
    "niederstecht": "niederstechen",
    "niedersteige": "niedersteigen",
    "niedersteigend": "niedersteigen",
    "niedersteigende": "niedersteigend",
    "niedersteigendem": "niedersteigend",
    "niedersteigenden": "niedersteigend",
    "niedersteigender": "niedersteigend",
    "niedersteigendere": "niedersteigend",
    "niedersteigenderem": "niedersteigend",
    "niedersteigenderen": "niedersteigend",
    "niedersteigenderer": "niedersteigend",
    "niedersteigenderes": "niedersteigend",
    "niedersteigendes": "niedersteigend",
    "niedersteigendste": "niedersteigend",
    "niedersteigendstem": "niedersteigend",
    "niedersteigendsten": "niedersteigend",
    "niedersteigendster": "niedersteigend",
    "niedersteigendstes": "niedersteigend",
    "niedersteigest": "niedersteigen",
    "niedersteiget": "niedersteigen",
    "niedersteigst": "niedersteigen",
    "niedersteigt": "niedersteigen",
    "niederstem": "nieder",
    "niedersten": "nieder",
    "niederster": "nieder",
    "niederstes": "nieder",
    "niederstichst": "niederstechen",
    "niedersticht": "niederstechen",
    "niederstieg": "niedersteigen",
    "niederstiege": "niedersteigen",
    "niederstiegen": "niedersteigen",
    "niederstiegest": "niedersteigen",
    "niederstieget": "niedersteigen",
    "niederstiegst": "niedersteigen",
    "niederstiegt": "niedersteigen",
    "niederstieß": "niederstoßen",
    "niederstieße": "niederstoßen",
    "niederstießen": "niederstoßen",
    "niederstießest": "niederstoßen",
    "niederstießet": "niederstoßen",
    "niederstießt": "niederstoßen",
    "niederstoße": "niederstoßen",
    "niederstoßend": "niederstoßen",
    "niederstoßende": "niederstoßend",
    "niederstoßendem": "niederstoßend",
    "niederstoßenden": "niederstoßend",
    "niederstoßender": "niederstoßend",
    "niederstoßendes": "niederstoßend",
    "niederstoßest": "niederstoßen",
    "niederstoßet": "niederstoßen",
    "niederstoßt": "niederstoßen",
    "niederstrecke": "niederstrecken",
    "niederstreckend": "niederstrecken",
    "niederstreckende": "niederstreckend",
    "niederstreckendem": "niederstreckend",
    "niederstreckenden": "niederstreckend",
    "niederstreckender": "niederstreckend",
    "niederstreckendes": "niederstreckend",
    "niederstreckest": "niederstrecken",
    "niederstrecket": "niederstrecken",
    "niederstreckst": "niederstrecken",
    "niederstreckt": "niederstrecken",
    "niederstreckte": "niederstrecken",
    "niederstreckten": "niederstrecken",
    "niederstrecktest": "niederstrecken",
    "niederstrecktet": "niederstrecken",
    "niederstäche": "niederstechen",
    "niederstächen": "niederstechen",
    "niederstächest": "niederstechen",
    "niederstächet": "niederstechen",
    "niederstößt": "niederstoßen",
    "niedersächsischem": "niedersächsisch",
    "niedersächsischen": "niedersächsisch",
    "niedersächsischer": "niedersächsisch",
    "niedersächsisches": "niedersächsisch",
    "niedersänke": "niedersinken",
    "niedersänken": "niedersinken",
    "niedersänkest": "niedersinken",
    "niedersänket": "niedersinken",
    "niedertrampele": "niedertrampeln",
    "niedertrampelnd": "niedertrampeln",
    "niedertrampelnde": "niedertrampelnd",
    "niedertrampelndem": "niedertrampelnd",
    "niedertrampelnden": "niedertrampelnd",
    "niedertrampelnder": "niedertrampelnd",
    "niedertrampelndere": "niedertrampelnd",
    "niedertrampelnderem": "niedertrampelnd",
    "niedertrampelnderen": "niedertrampelnd",
    "niedertrampelnderer": "niedertrampelnd",
    "niedertrampelnderes": "niedertrampelnd",
    "niedertrampelndes": "niedertrampelnd",
    "niedertrampelndste": "niedertrampelnd",
    "niedertrampelndstem": "niedertrampelnd",
    "niedertrampelndsten": "niedertrampelnd",
    "niedertrampelndster": "niedertrampelnd",
    "niedertrampelndstes": "niedertrampelnd",
    "niedertrampelst": "niedertrampeln",
    "niedertrampelt": "niedertrampeln",
    "niedertrampelte": "niedertrampeln",
    "niedertrampelten": "niedertrampeln",
    "niedertrampeltest": "niedertrampeln",
    "niedertrampeltet": "niedertrampeln",
    "niedertrample": "niedertrampeln",
    "niedertrat": "niedertreten",
    "niedertraten": "niedertreten",
    "niedertratest": "niedertreten",
    "niedertratet": "niedertreten",
    "niedertrete": "niedertreten",
    "niedertretend": "niedertreten",
    "niedertretende": "niedertretend",
    "niedertretendem": "niedertretend",
    "niedertretenden": "niedertretend",
    "niedertretender": "niedertretend",
    "niedertretendere": "niedertretend",
    "niedertretenderem": "niedertretend",
    "niedertretenderen": "niedertretend",
    "niedertretenderer": "niedertretend",
    "niedertretenderes": "niedertretend",
    "niedertretendes": "niedertretend",
    "niedertretendste": "niedertretend",
    "niedertretendstem": "niedertretend",
    "niedertretendsten": "niedertretend",
    "niedertretendster": "niedertretend",
    "niedertretendstes": "niedertretend",
    "niedertretest": "niedertreten",
    "niedertretet": "niedertreten",
    "niedertritt": "niedertreten",
    "niedertrittst": "niedertreten",
    "niederträchtige": "niederträchtig",
    "niederträchtigem": "niederträchtig",
    "niederträchtigen": "niederträchtig",
    "niederträchtiger": "niederträchtig",
    "niederträchtigere": "niederträchtig",
    "niederträchtigerem": "niederträchtig",
    "niederträchtigeren": "niederträchtig",
    "niederträchtigerer": "niederträchtig",
    "niederträchtigeres": "niederträchtig",
    "niederträchtiges": "niederträchtig",
    "niederträchtigstem": "niederträchtig",
    "niederträchtigsten": "niederträchtig",
    "niederträchtigster": "niederträchtig",
    "niederträchtigstes": "niederträchtig",
    "niederträte": "niedertreten",
    "niederträten": "niedertreten",
    "niederträtest": "niedertreten",
    "niederträtet": "niedertreten",
    "niederwarf": "niederwerfen",
    "niederwarfen": "niederwerfen",
    "niederwarfst": "niederwerfen",
    "niederwarft": "niederwerfen",
    "niederwerfe": "niederwerfen",
    "niederwerfend": "niederwerfen",
    "niederwerfende": "niederwerfend",
    "niederwerfendem": "niederwerfend",
    "niederwerfenden": "niederwerfend",
    "niederwerfender": "niederwerfend",
    "niederwerfendes": "niederwerfend",
    "niederwerfest": "niederwerfen",
    "niederwerfet": "niederwerfen",
    "niederwerft": "niederwerfen",
    "niederwirfst": "niederwerfen",
    "niederwirft": "niederwerfen",
    "niederwärfe": "niederwerfen",
    "niederwärfen": "niederwerfen",
    "niederwärfest": "niederwerfen",
    "niederwärfet": "niederwerfen",
    "niederzubeugen": "niederbeugen",
    "niederzubiegen": "niederbiegen",
    "niederzublasen": "niederblasen",
    "niederzubrechen": "niederbrechen",
    "niederzubrennen": "niederbrennen",
    "niederzubringen": "niederbringen",
    "niederzubügeln": "niederbügeln",
    "niederzufallen": "niederfallen",
    "niederzugleiten": "niedergleiten",
    "niederzuhalten": "niederhalten",
    "niederzuhauen": "niederhauen",
    "niederzuholen": "niederholen",
    "niederzuknien": "niederknien",
    "niederzuknüppeln": "niederknüppeln",
    "niederzukämpfen": "niederkämpfen",
    "niederzulassen": "niederlassen",
    "niederzulegen": "niederlegen",
    "niederzumachen": "niedermachen",
    "niederzumetzeln": "niedermetzeln",
    "niederzumähen": "niedermähen",
    "niederzuprasseln": "niederprasseln",
    "niederzureißen": "niederreißen",
    "niederzuringen": "niederringen",
    "niederzusausen": "niedersausen",
    "niederzuschießen": "niederschießen",
    "niederzuschlagen": "niederschlagen",
    "niederzuschmettern": "niederschmettern",
    "niederzuschreiben": "niederschreiben",
    "niederzuschreien": "niederschreien",
    "niederzusetzen": "niedersetzen",
    "niederzusinken": "niedersinken",
    "niederzustampfen": "niederstampfen",
    "niederzustechen": "niederstechen",
    "niederzusteigen": "niedersteigen",
    "niederzustoßen": "niederstoßen",
    "niederzustrecken": "niederstrecken",
    "niederzutrampeln": "niedertrampeln",
    "niederzutreten": "niedertreten",
    "niederzuwerfen": "niederwerfen",
    "niederzuzwingen": "niederzwingen",
    "niederzwang": "niederzwingen",
    "niederzwangen": "niederzwingen",
    "niederzwangst": "niederzwingen",
    "niederzwangt": "niederzwingen",
    "niederzwinge": "niederzwingen",
    "niederzwingend": "niederzwingen",
    "niederzwingende": "niederzwingend",
    "niederzwingendem": "niederzwingend",
    "niederzwingenden": "niederzwingend",
    "niederzwingender": "niederzwingend",
    "niederzwingendes": "niederzwingend",
    "niederzwingest": "niederzwingen",
    "niederzwinget": "niederzwingen",
    "niederzwingst": "niederzwingen",
    "niederzwingt": "niederzwingen",
    "niederzwänge": "niederzwingen",
    "niederzwängen": "niederzwingen",
    "niederzwängest": "niederzwingen",
    "niederzwänget": "niederzwingen",
    "niedliche": "niedlich",
    "niedlichem": "niedlich",
    "niedlichen": "niedlich",
    "niedlicher": "niedlich",
    "niedlichere": "niedlich",
    "niedlicherem": "niedlich",
    "niedlicheren": "niedlich",
    "niedlicherer": "niedlich",
    "niedlicheres": "niedlich",
    "niedliches": "niedlich",
    "niedlichste": "niedlich",
    "niedlichstem": "niedlich",
    "niedlichsten": "niedlich",
    "niedlichster": "niedlich",
    "niedlichstes": "niedlich",
    "niedrigem": "niedrig",
    "niedrigen": "niedrig",
    "niedriger": "niedrig",
    "niedrigere": "niedrig",
    "niedrigerem": "niedrig",
    "niedrigeren": "niedrig",
    "niedrigerer": "niedrig",
    "niedrigeres": "niedrig",
    "niedriges": "niedrig",
    "niedrigste": "niedrig",
    "niedrigstem": "niedrig",
    "niedrigsten": "niedrig",
    "niedrigster": "niedrig",
    "niedrigstes": "niedrig",
    "niemandem": "niemand",
    "niemanden": "niemand",
    "niemandes": "niemand",
    "niemands": "niemand",
    "niese": "niesen",
    "niesele": "nieseln",
    "nieselnd": "nieseln",
    "nieselnde": "nieselnd",
    "nieselndem": "nieselnd",
    "nieselnden": "nieselnd",
    "nieselnder": "nieselnd",
    "nieselndere": "nieselnd",
    "nieselnderem": "nieselnd",
    "nieselnderen": "nieselnd",
    "nieselnderer": "nieselnd",
    "nieselnderes": "nieselnd",
    "nieselndes": "nieselnd",
    "nieselndste": "nieselnd",
    "nieselndstem": "nieselnd",
    "nieselndsten": "nieselnd",
    "nieselndster": "nieselnd",
    "nieselndstes": "nieselnd",
    "nieselst": "nieseln",
    "nieselt": "nieseln",
    "nieselte": "nieseln",
    "nieselten": "nieseln",
    "nieseltest": "nieseln",
    "nieseltet": "nieseln",
    "niesend": "niesen",
    "niesende": "niesend",
    "niesendem": "niesend",
    "niesenden": "niesend",
    "niesender": "niesend",
    "niesendere": "niesend",
    "niesenderem": "niesend",
    "niesenderen": "niesend",
    "niesenderer": "niesend",
    "niesenderes": "niesend",
    "niesendes": "niesend",
    "niesendste": "niesend",
    "niesendstem": "niesend",
    "niesendsten": "niesend",
    "niesendster": "niesend",
    "niesendstes": "niesend",
    "niesest": "niesen",
    "nieset": "niesen",
    "niesle": "nieseln",
    "niest": "niesen",
    "nieste": "niesen",
    "niesten": "niesen",
    "niestest": "niesen",
    "niestet": "niesen",
    "niete": "nieten",
    "nietend": "nieten",
    "nietende": "nietend",
    "nietendem": "nietend",
    "nietenden": "nietend",
    "nietender": "nietend",
    "nietendes": "nietend",
    "nietest": "nieten",
    "nietet": "nieten",
    "nietete": "nieten",
    "nieteten": "nieten",
    "nietetest": "nieten",
    "nietetet": "nieten",
    "nihilistischem": "nihilistisch",
    "nihilistischen": "nihilistisch",
    "nihilistischer": "nihilistisch",
    "nihilistisches": "nihilistisch",
    "nikotinarmem": "nikotinarm",
    "nikotinarmen": "nikotinarm",
    "nikotinarmer": "nikotinarm",
    "nikotinarmes": "nikotinarm",
    "nikotinärmer": "nikotinarm",
    "nikotinärmere": "nikotinarm",
    "nikotinärmerem": "nikotinarm",
    "nikotinärmeren": "nikotinarm",
    "nikotinärmerer": "nikotinarm",
    "nikotinärmeres": "nikotinarm",
    "nikotinärmsten": "nikotinarm",
    "nimm": "nehmen",
    "nimmersatte": "nimmersatt",
    "nimmersattem": "nimmersatt",
    "nimmersatten": "nimmersatt",
    "nimmersatter": "nimmersatt",
    "nimmersattes": "nimmersatt",
    "nimmst": "nehmen",
    "nimmt": "nehmen",
    "nippe": "nippen",
    "nippend": "nippen",
    "nippende": "nippend",
    "nippendem": "nippend",
    "nippenden": "nippend",
    "nippender": "nippend",
    "nippendes": "nippend",
    "nippest": "nippen",
    "nippet": "nippen",
    "nippst": "nippen",
    "nippt": "nippen",
    "nippte": "nippen",
    "nippten": "nippen",
    "nipptest": "nippen",
    "nipptet": "nippen",
    "niste": "nisten",
    "nistend": "nisten",
    "nistende": "nistend",
    "nistendem": "nistend",
    "nistenden": "nistend",
    "nistender": "nistend",
    "nistendes": "nistend",
    "nistest": "nisten",
    "nistet": "nisten",
    "nistete": "nisten",
    "nisteten": "nisten",
    "nistetest": "nisten",
    "nistetet": "nisten",
    "nobelstem": "nobel",
    "nobelsten": "nobel",
    "nobelster": "nobel",
    "nobelstes": "nobel",
    "noble": "nobel",
    "noblem": "nobel",
    "noblen": "nobel",
    "nobler": "nobel",
    "noblere": "nobel",
    "noblerem": "nobel",
    "nobleren": "nobel",
    "noblerer": "nobel",
    "nobleres": "nobel",
    "nobles": "nobel",
    "nochmalige": "nochmalig",
    "nochmaligem": "nochmalig",
    "nochmaligen": "nochmalig",
    "nochmaliger": "nochmalig",
    "nochmaliges": "nochmalig",
    "nomadischem": "nomadisch",
    "nomadischen": "nomadisch",
    "nomadischer": "nomadisch",
    "nomadisches": "nomadisch",
    "nomadisiere": "nomadisieren",
    "nomadisierend": "nomadisieren",
    "nomadisierende": "nomadisierend",
    "nomadisierendem": "nomadisierend",
    "nomadisierenden": "nomadisierend",
    "nomadisierender": "nomadisierend",
    "nomadisierendes": "nomadisierend",
    "nomadisierest": "nomadisieren",
    "nomadisieret": "nomadisieren",
    "nomadisierst": "nomadisieren",
    "nomadisiert": "nomadisieren",
    "nomadisierte": "nomadisieren",
    "nomadisiertem": "nomadisiert",
    "nomadisierten": "nomadisieren",
    "nomadisierter": "nomadisiert",
    "nomadisiertes": "nomadisiert",
    "nomadisiertest": "nomadisieren",
    "nomadisiertet": "nomadisieren",
    "nominalem": "nominal",
    "nominalen": "nominal",
    "nominaler": "nominal",
    "nominales": "nominal",
    "nominalisiere": "nominalisieren",
    "nominalisierend": "nominalisieren",
    "nominalisierende": "nominalisierend",
    "nominalisierendem": "nominalisierend",
    "nominalisierenden": "nominalisierend",
    "nominalisierender": "nominalisierend",
    "nominalisierendes": "nominalisierend",
    "nominalisierest": "nominalisieren",
    "nominalisieret": "nominalisieren",
    "nominalisierst": "nominalisieren",
    "nominalisiert": "nominalisieren",
    "nominalisierte": "nominalisieren",
    "nominalisiertem": "nominalisiert",
    "nominalisierten": "nominalisieren",
    "nominalisierter": "nominalisiert",
    "nominalisiertes": "nominalisiert",
    "nominalisiertest": "nominalisieren",
    "nominalisiertet": "nominalisieren",
    "nominellem": "nominell",
    "nominellen": "nominell",
    "nomineller": "nominell",
    "nominelles": "nominell",
    "nominiere": "nominieren",
    "nominierend": "nominieren",
    "nominierende": "nominierend",
    "nominierendem": "nominierend",
    "nominierenden": "nominierend",
    "nominierender": "nominierend",
    "nominierendes": "nominierend",
    "nominierest": "nominieren",
    "nominieret": "nominieren",
    "nominierst": "nominieren",
    "nominiert": "nominieren",
    "nominierte": "nominieren",
    "nominiertem": "nominiert",
    "nominierten": "nominieren",
    "nominierter": "nominiert",
    "nominiertes": "nominiert",
    "nominiertest": "nominieren",
    "nominiertet": "nominieren",
    "norddeutschem": "norddeutsch",
    "norddeutschen": "norddeutsch",
    "norddeutscher": "norddeutsch",
    "norddeutsches": "norddeutsch",
    "nordend": "norden",
    "nordendem": "nordend",
    "nordenden": "nordend",
    "nordender": "nordend",
    "nordendes": "nordend",
    "nordest": "norden",
    "nordet": "norden",
    "nordete": "norden",
    "nordeten": "norden",
    "nordetest": "norden",
    "nordetet": "norden",
    "nordische": "nordisch",
    "nordischem": "nordisch",
    "nordischen": "nordisch",
    "nordischer": "nordisch",
    "nordischere": "nordisch",
    "nordischerem": "nordisch",
    "nordischeren": "nordisch",
    "nordischerer": "nordisch",
    "nordischeres": "nordisch",
    "nordisches": "nordisch",
    "nordischste": "nordisch",
    "nordischstem": "nordisch",
    "nordischsten": "nordisch",
    "nordischster": "nordisch",
    "nordischstes": "nordisch",
    "nordländischem": "nordländisch",
    "nordländischen": "nordländisch",
    "nordländischer": "nordländisch",
    "nordländisches": "nordländisch",
    "nordwestlichem": "nordwestlich",
    "nordwestlichen": "nordwestlich",
    "nordwestlicher": "nordwestlich",
    "nordwestliches": "nordwestlich",
    "nordöstlichem": "nordöstlich",
    "nordöstlichen": "nordöstlich",
    "nordöstlicher": "nordöstlich",
    "nordöstlichere": "nordöstlich",
    "nordöstlicherem": "nordöstlich",
    "nordöstlicheren": "nordöstlich",
    "nordöstlicherer": "nordöstlich",
    "nordöstlicheres": "nordöstlich",
    "nordöstliches": "nordöstlich",
    "nordöstlichste": "nordöstlich",
    "nordöstlichstem": "nordöstlich",
    "nordöstlichsten": "nordöstlich",
    "nordöstlichster": "nordöstlich",
    "nordöstlichstes": "nordöstlich",
    "normalem": "normal",
    "normalen": "normal",
    "normaler": "normal",
    "normalere": "normal",
    "normalerem": "normal",
    "normaleren": "normal",
    "normalerer": "normal",
    "normaleres": "normal",
    "normales": "normal",
    "normalisiere": "normalisieren",
    "normalisierend": "normalisieren",
    "normalisierende": "normalisierend",
    "normalisierendem": "normalisierend",
    "normalisierenden": "normalisierend",
    "normalisierender": "normalisierend",
    "normalisierendere": "normalisierend",
    "normalisierenderem": "normalisierend",
    "normalisierenderen": "normalisierend",
    "normalisierenderer": "normalisierend",
    "normalisierenderes": "normalisierend",
    "normalisierendes": "normalisierend",
    "normalisierendste": "normalisierend",
    "normalisierendstem": "normalisierend",
    "normalisierendsten": "normalisierend",
    "normalisierendster": "normalisierend",
    "normalisierendstes": "normalisierend",
    "normalisierest": "normalisieren",
    "normalisieret": "normalisieren",
    "normalisierst": "normalisieren",
    "normalisiert": "normalisieren",
    "normalisierte": "normalisieren",
    "normalisiertem": "normalisiert",
    "normalisierten": "normalisieren",
    "normalisierter": "normalisiert",
    "normalisiertere": "normalisiert",
    "normalisierterem": "normalisiert",
    "normalisierteren": "normalisiert",
    "normalisierterer": "normalisiert",
    "normalisierteres": "normalisiert",
    "normalisiertes": "normalisiert",
    "normalisiertest": "normalisieren",
    "normalisierteste": "normalisiert",
    "normalisiertestem": "normalisiert",
    "normalisiertesten": "normalisiert",
    "normalisiertester": "normalisiert",
    "normalisiertestes": "normalisiert",
    "normalisiertet": "normalisieren",
    "normalstem": "normal",
    "normalsten": "normal",
    "normalster": "normal",
    "normalstes": "normal",
    "normannischem": "normannisch",
    "normannischen": "normannisch",
    "normannischer": "normannisch",
    "normannisches": "normannisch",
    "normative": "normativ",
    "normativem": "normativ",
    "normativen": "normativ",
    "normativer": "normativ",
    "normatives": "normativ",
    "norme": "normen",
    "normend": "normen",
    "normende": "normend",
    "normendem": "normend",
    "normenden": "normend",
    "normender": "normend",
    "normendere": "normend",
    "normenderem": "normend",
    "normenderen": "normend",
    "normenderer": "normend",
    "normenderes": "normend",
    "normendes": "normend",
    "normendste": "normend",
    "normendstem": "normend",
    "normendsten": "normend",
    "normendster": "normend",
    "normendstes": "normend",
    "normest": "normen",
    "normet": "normen",
    "normiere": "normieren",
    "normierend": "normieren",
    "normierende": "normierend",
    "normierendem": "normierend",
    "normierenden": "normierend",
    "normierender": "normierend",
    "normierendere": "normierend",
    "normierenderem": "normierend",
    "normierenderen": "normierend",
    "normierenderer": "normierend",
    "normierenderes": "normierend",
    "normierendes": "normierend",
    "normierendste": "normierend",
    "normierendstem": "normierend",
    "normierendsten": "normierend",
    "normierendster": "normierend",
    "normierendstes": "normierend",
    "normierest": "normieren",
    "normieret": "normieren",
    "normierst": "normieren",
    "normiert": "normieren",
    "normierte": "normieren",
    "normiertem": "normiert",
    "normierten": "normieren",
    "normierter": "normiert",
    "normiertere": "normiert",
    "normierterem": "normiert",
    "normierteren": "normiert",
    "normierterer": "normiert",
    "normierteres": "normiert",
    "normiertes": "normiert",
    "normiertest": "normieren",
    "normierteste": "normiert",
    "normiertestem": "normiert",
    "normiertesten": "normiert",
    "normiertester": "normiert",
    "normiertestes": "normiert",
    "normiertet": "normieren",
    "normst": "normen",
    "normt": "normen",
    "normte": "normen",
    "normten": "normen",
    "normtest": "normen",
    "normtet": "normen",
    "normwidrige": "normwidrig",
    "normwidrigem": "normwidrig",
    "normwidrigen": "normwidrig",
    "normwidriger": "normwidrig",
    "normwidriges": "normwidrig",
    "norwegischem": "norwegisch",
    "norwegischen": "norwegisch",
    "norwegischer": "norwegisch",
    "norwegisches": "norwegisch",
    "nostalgischem": "nostalgisch",
    "nostalgischen": "nostalgisch",
    "nostalgischer": "nostalgisch",
    "nostalgischere": "nostalgisch",
    "nostalgischerem": "nostalgisch",
    "nostalgischeren": "nostalgisch",
    "nostalgischerer": "nostalgisch",
    "nostalgischeres": "nostalgisch",
    "nostalgisches": "nostalgisch",
    "nostalgischste": "nostalgisch",
    "nostalgischstem": "nostalgisch",
    "nostalgischsten": "nostalgisch",
    "nostalgischster": "nostalgisch",
    "nostalgischstes": "nostalgisch",
    "notariellem": "notariell",
    "notariellen": "notariell",
    "notarieller": "notariell",
    "notarielles": "notariell",
    "notarische": "notarisch",
    "notarischem": "notarisch",
    "notarischen": "notarisch",
    "notarischer": "notarisch",
    "notarisches": "notarisch",
    "notdürftigem": "notdürftig",
    "notdürftigen": "notdürftig",
    "notdürftiger": "notdürftig",
    "notdürftigere": "notdürftig",
    "notdürftigerem": "notdürftig",
    "notdürftigeren": "notdürftig",
    "notdürftigerer": "notdürftig",
    "notdürftigeres": "notdürftig",
    "notdürftiges": "notdürftig",
    "notdürftigste": "notdürftig",
    "notdürftigstem": "notdürftig",
    "notdürftigsten": "notdürftig",
    "notdürftigster": "notdürftig",
    "notdürftigstes": "notdürftig",
    "notgedrungenem": "notgedrungen",
    "notgedrungenen": "notgedrungen",
    "notgedrungener": "notgedrungen",
    "notgedrungenes": "notgedrungen",
    "notiere": "notieren",
    "notierend": "notieren",
    "notierende": "notierend",
    "notierendem": "notierend",
    "notierenden": "notierend",
    "notierender": "notierend",
    "notierendes": "notierend",
    "notierest": "notieren",
    "notieret": "notieren",
    "notierst": "notieren",
    "notiert": "notieren",
    "notierte": "notieren",
    "notiertem": "notiert",
    "notierten": "notieren",
    "notierter": "notiert",
    "notiertes": "notiert",
    "notiertest": "notieren",
    "notiertet": "notieren",
    "notorischem": "notorisch",
    "notorischen": "notorisch",
    "notorischer": "notorisch",
    "notorisches": "notorisch",
    "notwendigem": "notwendig",
    "notwendigen": "notwendig",
    "notwendiger": "notwendig",
    "notwendigere": "notwendig",
    "notwendigerem": "notwendig",
    "notwendigeren": "notwendig",
    "notwendigerer": "notwendig",
    "notwendigeres": "notwendig",
    "notwendiges": "notwendig",
    "notwendigstem": "notwendig",
    "notwendigsten": "notwendig",
    "notwendigster": "notwendig",
    "notwendigstes": "notwendig",
    "nudele": "nudeln",
    "nudelnd": "nudeln",
    "nudelnde": "nudelnd",
    "nudelndem": "nudelnd",
    "nudelnden": "nudelnd",
    "nudelnder": "nudelnd",
    "nudelndes": "nudelnd",
    "nudelst": "nudeln",
    "nudelt": "nudeln",
    "nudelte": "nudeln",
    "nudelten": "nudeln",
    "nudeltest": "nudeln",
    "nudeltet": "nudeln",
    "nudle": "nudeln",
    "nukleare": "nuklear",
    "nuklearem": "nuklear",
    "nuklearen": "nuklear",
    "nuklearer": "nuklear",
    "nukleares": "nuklear",
    "null": "nullen",
    "nulle": "nullen",
    "nullend": "nullen",
    "nullende": "nullend",
    "nullendem": "nullend",
    "nullenden": "nullend",
    "nullender": "nullend",
    "nullendes": "nullend",
    "nullest": "nullen",
    "nullet": "nullen",
    "nullst": "nullen",
    "nullt": "nullen",
    "nullte": "nullen",
    "nullten": "nullen",
    "nulltest": "nullen",
    "nulltet": "nullen",
    "numeriere": "numerieren",
    "numerierend": "numerieren",
    "numerierende": "numerierend",
    "numerierendem": "numerierend",
    "numerierenden": "numerierend",
    "numerierender": "numerierend",
    "numerierendes": "numerierend",
    "numerierest": "numerieren",
    "numerieret": "numerieren",
    "numerierst": "numerieren",
    "numeriert": "numerieren",
    "numerierte": "numerieren",
    "numeriertem": "numeriert",
    "numerierten": "numerieren",
    "numerierter": "numeriert",
    "numeriertes": "numeriert",
    "numeriertest": "numerieren",
    "numeriertet": "numerieren",
    "numerischem": "numerisch",
    "numerischen": "numerisch",
    "numerischer": "numerisch",
    "numerischere": "numerisch",
    "numerischerem": "numerisch",
    "numerischeren": "numerisch",
    "numerischerer": "numerisch",
    "numerischeres": "numerisch",
    "numerisches": "numerisch",
    "numerischste": "numerisch",
    "numerischstem": "numerisch",
    "numerischsten": "numerisch",
    "numerischster": "numerisch",
    "numerischstes": "numerisch",
    "nuschele": "nuscheln",
    "nuschelnd": "nuscheln",
    "nuschelnde": "nuschelnd",
    "nuschelndem": "nuschelnd",
    "nuschelnden": "nuschelnd",
    "nuschelnder": "nuschelnd",
    "nuschelndere": "nuschelnd",
    "nuschelnderem": "nuschelnd",
    "nuschelnderen": "nuschelnd",
    "nuschelnderer": "nuschelnd",
    "nuschelnderes": "nuschelnd",
    "nuschelndes": "nuschelnd",
    "nuschelndste": "nuschelnd",
    "nuschelndstem": "nuschelnd",
    "nuschelndsten": "nuschelnd",
    "nuschelndster": "nuschelnd",
    "nuschelndstes": "nuschelnd",
    "nuschelst": "nuscheln",
    "nuschelt": "nuscheln",
    "nuschelte": "nuscheln",
    "nuschelten": "nuscheln",
    "nuscheltest": "nuscheln",
    "nuscheltet": "nuscheln",
    "nuschle": "nuscheln",
    "nutzbarem": "nutzbar",
    "nutzbaren": "nutzbar",
    "nutzbarer": "nutzbar",
    "nutzbares": "nutzbar",
    "nutzbringendem": "nutzbringend",
    "nutzbringenden": "nutzbringend",
    "nutzbringender": "nutzbringend",
    "nutzbringendere": "nutzbringend",
    "nutzbringenderem": "nutzbringend",
    "nutzbringenderen": "nutzbringend",
    "nutzbringenderer": "nutzbringend",
    "nutzbringenderes": "nutzbringend",
    "nutzbringendes": "nutzbringend",
    "nutzbringendste": "nutzbringend",
    "nutzbringendstem": "nutzbringend",
    "nutzbringendsten": "nutzbringend",
    "nutzbringendster": "nutzbringend",
    "nutzbringendstes": "nutzbringend",
    "nutze": "nutzen",
    "nutzend": "nutzen",
    "nutzende": "nutzend",
    "nutzendem": "nutzend",
    "nutzenden": "nutzend",
    "nutzender": "nutzend",
    "nutzendes": "nutzend",
    "nutzest": "nutzen",
    "nutzet": "nutzen",
    "nutzlose": "nutzlos",
    "nutzlosem": "nutzlos",
    "nutzlosen": "nutzlos",
    "nutzloser": "nutzlos",
    "nutzlosere": "nutzlos",
    "nutzloserem": "nutzlos",
    "nutzloseren": "nutzlos",
    "nutzloserer": "nutzlos",
    "nutzloseres": "nutzlos",
    "nutzloses": "nutzlos",
    "nutzloseste": "nutzlos",
    "nutzlosestem": "nutzlos",
    "nutzlosesten": "nutzlos",
    "nutzlosester": "nutzlos",
    "nutzlosestes": "nutzlos",
    "nutzt": "nutzen",
    "nutzte": "nutzen",
    "nutzten": "nutzen",
    "nutztest": "nutzen",
    "nutztet": "nutzen",
    "nutzungsfähigem": "nutzungsfähig",
    "nutzungsfähigen": "nutzungsfähig",
    "nutzungsfähiger": "nutzungsfähig",
    "nutzungsfähigere": "nutzungsfähig",
    "nutzungsfähigerem": "nutzungsfähig",
    "nutzungsfähigeren": "nutzungsfähig",
    "nutzungsfähigerer": "nutzungsfähig",
    "nutzungsfähigeres": "nutzungsfähig",
    "nutzungsfähiges": "nutzungsfähig",
    "nutzungsfähigste": "nutzungsfähig",
    "nutzungsfähigstem": "nutzungsfähig",
    "nutzungsfähigsten": "nutzungsfähig",
    "nutzungsfähigster": "nutzungsfähig",
    "nutzungsfähigstes": "nutzungsfähig",
    "nußbraune": "nußbraun",
    "nußbraunem": "nußbraun",
    "nußbraunen": "nußbraun",
    "nußbrauner": "nußbraun",
    "nußbraunes": "nußbraun",
    "nymphomanem": "nymphoman",
    "nymphomanen": "nymphoman",
    "nymphomaner": "nymphoman",
    "nymphomanes": "nymphoman",
    "nächste": "nächst",
    "nächstem": "nächst",
    "nächsten": "nächst",
    "nächster": "nächst",
    "nächstes": "nächst",
    "nächstliegende": "nächstliegend",
    "nächstliegendem": "nächstliegend",
    "nächstliegenden": "nächstliegend",
    "nächstliegender": "nächstliegend",
    "nächstliegendere": "nächstliegend",
    "nächstliegenderem": "nächstliegend",
    "nächstliegenderen": "nächstliegend",
    "nächstliegenderer": "nächstliegend",
    "nächstliegenderes": "nächstliegend",
    "nächstliegendes": "nächstliegend",
    "nächstliegendste": "nächstliegend",
    "nächstliegendstem": "nächstliegend",
    "nächstliegendsten": "nächstliegend",
    "nächstliegendster": "nächstliegend",
    "nächstliegendstes": "nächstliegend",
    "nächtige": "nächtigen",
    "nächtigend": "nächtigen",
    "nächtigende": "nächtigend",
    "nächtigendem": "nächtigend",
    "nächtigenden": "nächtigend",
    "nächtigender": "nächtigend",
    "nächtigendes": "nächtigend",
    "nächtigest": "nächtigen",
    "nächtiget": "nächtigen",
    "nächtigst": "nächtigen",
    "nächtigt": "nächtigen",
    "nächtigte": "nächtigen",
    "nächtigten": "nächtigen",
    "nächtigtest": "nächtigen",
    "nächtigtet": "nächtigen",
    "nächtlichem": "nächtlich",
    "nächtlichen": "nächtlich",
    "nächtlicher": "nächtlich",
    "nächtliches": "nächtlich",
    "nähe": "nähen",
    "nähend": "nähen",
    "nähende": "nähend",
    "nähendem": "nähend",
    "nähenden": "nähend",
    "nähender": "nähend",
    "nähendes": "nähend",
    "näher": "nähern",
    "näherbrachte": "näherbringen",
    "näherbrachten": "näherbringen",
    "näherbrachtest": "näherbringen",
    "näherbrachtet": "näherbringen",
    "näherbringe": "näherbringen",
    "näherbringend": "näherbringen",
    "näherbringende": "näherbringend",
    "näherbringendem": "näherbringend",
    "näherbringenden": "näherbringend",
    "näherbringender": "näherbringend",
    "näherbringendere": "näherbringend",
    "näherbringenderem": "näherbringend",
    "näherbringenderen": "näherbringend",
    "näherbringenderer": "näherbringend",
    "näherbringenderes": "näherbringend",
    "näherbringendes": "näherbringend",
    "näherbringendste": "näherbringend",
    "näherbringendstem": "näherbringend",
    "näherbringendsten": "näherbringend",
    "näherbringendster": "näherbringend",
    "näherbringendstes": "näherbringend",
    "näherbringest": "näherbringen",
    "näherbringet": "näherbringen",
    "näherbringst": "näherbringen",
    "näherbringt": "näherbringen",
    "näherbrächte": "näherbringen",
    "näherbrächten": "näherbringen",
    "näherbrächtest": "näherbringen",
    "näherbrächtet": "näherbringen",
    "nähere": "nah",
    "näherem": "nah",
    "näheren": "nah",
    "näherer": "nah",
    "näheres": "nah",
    "nähergebracht": "näherbringen",
    "nähergebrachte": "nähergebracht",
    "nähergebrachtem": "nähergebracht",
    "nähergebrachten": "nähergebracht",
    "nähergebrachter": "nähergebracht",
    "nähergebrachtere": "nähergebracht",
    "nähergebrachterem": "nähergebracht",
    "nähergebrachteren": "nähergebracht",
    "nähergebrachterer": "nähergebracht",
    "nähergebrachteres": "nähergebracht",
    "nähergebrachtes": "nähergebracht",
    "nähergebrachteste": "nähergebracht",
    "nähergebrachtestem": "nähergebracht",
    "nähergebrachtesten": "nähergebracht",
    "nähergebrachtester": "nähergebracht",
    "nähergebrachtestes": "nähergebracht",
    "nähernd": "nähern",
    "nähernde": "nähernd",
    "näherndem": "nähernd",
    "nähernden": "nähernd",
    "nähernder": "nähernd",
    "näherndere": "nähernd",
    "nähernderem": "nähernd",
    "nähernderen": "nähernd",
    "nähernderer": "nähernd",
    "nähernderes": "nähernd",
    "näherndes": "nähernd",
    "näherndste": "nähernd",
    "näherndstem": "nähernd",
    "näherndsten": "nähernd",
    "näherndster": "nähernd",
    "näherndstes": "nähernd",
    "näherst": "nähern",
    "nähert": "nähern",
    "näherte": "nähern",
    "näherten": "nähern",
    "nähertest": "nähern",
    "nähertet": "nähern",
    "näherzubringen": "näherbringen",
    "nähest": "nähen",
    "näheste": "nah",
    "nähestem": "nah",
    "nähesten": "nah",
    "nähester": "nah",
    "nähestes": "nah",
    "nähet": "nähen",
    "nähme": "nehmen",
    "nähmen": "nehmen",
    "nähmest": "nehmen",
    "nähmet": "nehmen",
    "nähre": "nähren",
    "nährend": "nähren",
    "nährende": "nährend",
    "nährendem": "nährend",
    "nährenden": "nährend",
    "nährender": "nährend",
    "nährendes": "nährend",
    "nährest": "nähren",
    "nähret": "nähren",
    "nährst": "nähren",
    "nährt": "nähren",
    "nährte": "nähren",
    "nährten": "nähren",
    "nährtest": "nähren",
    "nährtet": "nähren",
    "nähst": "nähen",
    "näht": "nähen",
    "nähte": "nähen",
    "nähten": "nähen",
    "nähtest": "nähen",
    "nähtet": "nähen",
    "närrische": "närrisch",
    "närrischem": "närrisch",
    "närrischen": "närrisch",
    "närrischer": "närrisch",
    "närrischere": "närrisch",
    "närrischerem": "närrisch",
    "närrischeren": "närrisch",
    "närrischerer": "närrisch",
    "närrischeres": "närrisch",
    "närrisches": "närrisch",
    "närrischste": "närrisch",
    "närrischstem": "närrisch",
    "närrischsten": "närrisch",
    "närrischster": "närrisch",
    "närrischstes": "närrisch",
    "näsele": "näseln",
    "näselnd": "näseln",
    "näselnde": "näselnd",
    "näselndem": "näselnd",
    "näselnden": "näselnd",
    "näselnder": "näselnd",
    "näselndere": "näselnd",
    "näselnderem": "näselnd",
    "näselnderen": "näselnd",
    "näselnderer": "näselnd",
    "näselnderes": "näselnd",
    "näselndes": "näselnd",
    "näselndste": "näselnd",
    "näselndstem": "näselnd",
    "näselndsten": "näselnd",
    "näselndster": "näselnd",
    "näselndstes": "näselnd",
    "näselst": "näseln",
    "näselt": "näseln",
    "näselte": "näseln",
    "näselten": "näseln",
    "näseltest": "näseln",
    "näseltet": "näseln",
    "näsle": "näseln",
    "nässele": "nässeln",
    "nässelnd": "nässeln",
    "nässelnde": "nässelnd",
    "nässelndem": "nässelnd",
    "nässelnden": "nässelnd",
    "nässelnder": "nässelnd",
    "nässelndere": "nässelnd",
    "nässelnderem": "nässelnd",
    "nässelnderen": "nässelnd",
    "nässelnderer": "nässelnd",
    "nässelnderes": "nässelnd",
    "nässelndes": "nässelnd",
    "nässelndste": "nässelnd",
    "nässelndstem": "nässelnd",
    "nässelndsten": "nässelnd",
    "nässelndster": "nässelnd",
    "nässelndstes": "nässelnd",
    "nässelst": "nässeln",
    "nässelt": "nässeln",
    "nässelte": "nässeln",
    "nässelten": "nässeln",
    "nässeltest": "nässeln",
    "nässeltet": "nässeln",
    "nässend": "nässen",
    "nässende": "nässend",
    "nässendem": "nässend",
    "nässenden": "nässend",
    "nässender": "nässend",
    "nässendere": "nässend",
    "nässenderem": "nässend",
    "nässenderen": "nässend",
    "nässenderer": "nässend",
    "nässenderes": "nässend",
    "nässendes": "nässend",
    "nässendste": "nässend",
    "nässendstem": "nässend",
    "nässendsten": "nässend",
    "nässendster": "nässend",
    "nässendstes": "nässend",
    "nässest": "nässen",
    "nässet": "nässen",
    "nässle": "nässeln",
    "näßt": "nässen",
    "näßte": "nässen",
    "näßten": "nässen",
    "näßtest": "nässen",
    "näßtet": "nässen",
    "nöle": "nölen",
    "nölend": "nölen",
    "nölende": "nölend",
    "nölendem": "nölend",
    "nölenden": "nölend",
    "nölender": "nölend",
    "nölendere": "nölend",
    "nölenderem": "nölend",
    "nölenderen": "nölend",
    "nölenderer": "nölend",
    "nölenderes": "nölend",
    "nölendes": "nölend",
    "nölendste": "nölend",
    "nölendstem": "nölend",
    "nölendsten": "nölend",
    "nölendster": "nölend",
    "nölendstes": "nölend",
    "nölest": "nölen",
    "nölet": "nölen",
    "nölst": "nölen",
    "nölt": "nölen",
    "nölte": "nölen",
    "nölten": "nölen",
    "nöltest": "nölen",
    "nöltet": "nölen",
    "nördliche": "nördlich",
    "nördlichem": "nördlich",
    "nördlichen": "nördlich",
    "nördlicher": "nördlich",
    "nördlichere": "nördlich",
    "nördlicherem": "nördlich",
    "nördlicheren": "nördlich",
    "nördlicherer": "nördlich",
    "nördlicheres": "nördlich",
    "nördliches": "nördlich",
    "nördlichste": "nördlich",
    "nördlichstem": "nördlich",
    "nördlichsten": "nördlich",
    "nördlichster": "nördlich",
    "nördlichstes": "nördlich",
    "nörgele": "nörgeln",
    "nörgelige": "nörgelig",
    "nörgeligem": "nörgelig",
    "nörgeligen": "nörgelig",
    "nörgeliger": "nörgelig",
    "nörgeligere": "nörgelig",
    "nörgeligerem": "nörgelig",
    "nörgeligeren": "nörgelig",
    "nörgeligerer": "nörgelig",
    "nörgeligeres": "nörgelig",
    "nörgeliges": "nörgelig",
    "nörgeligste": "nörgelig",
    "nörgeligstem": "nörgelig",
    "nörgeligsten": "nörgelig",
    "nörgeligster": "nörgelig",
    "nörgeligstes": "nörgelig",
    "nörgelnd": "nörgeln",
    "nörgelnde": "nörgelnd",
    "nörgelndem": "nörgelnd",
    "nörgelnden": "nörgelnd",
    "nörgelnder": "nörgelnd",
    "nörgelndere": "nörgelnd",
    "nörgelnderem": "nörgelnd",
    "nörgelnderen": "nörgelnd",
    "nörgelnderer": "nörgelnd",
    "nörgelnderes": "nörgelnd",
    "nörgelndes": "nörgelnd",
    "nörgelndste": "nörgelnd",
    "nörgelndstem": "nörgelnd",
    "nörgelndsten": "nörgelnd",
    "nörgelndster": "nörgelnd",
    "nörgelndstes": "nörgelnd",
    "nörgelst": "nörgeln",
    "nörgelt": "nörgeln",
    "nörgelte": "nörgeln",
    "nörgelten": "nörgeln",
    "nörgeltest": "nörgeln",
    "nörgeltet": "nörgeln",
    "nörgle": "nörgeln",
    "nötig": "nötigen",
    "nötige": "nötig",
    "nötigem": "nötig",
    "nötigen": "nötig",
    "nötigend": "nötigen",
    "nötigende": "nötigend",
    "nötigendem": "nötigend",
    "nötigenden": "nötigend",
    "nötigender": "nötigend",
    "nötigendes": "nötigend",
    "nötiger": "nötig",
    "nötigere": "nötig",
    "nötigerem": "nötig",
    "nötigeren": "nötig",
    "nötigerer": "nötig",
    "nötigeres": "nötig",
    "nötiges": "nötig",
    "nötigest": "nötigen",
    "nötiget": "nötigen",
    "nötigst": "nötigen",
    "nötigste": "nötig",
    "nötigstem": "nötig",
    "nötigsten": "nötig",
    "nötigster": "nötig",
    "nötigstes": "nötig",
    "nötigt": "nötigen",
    "nötigte": "nötigen",
    "nötigten": "nötigen",
    "nötigtest": "nötigen",
    "nötigtet": "nötigen",
    "nüchternem": "nüchtern",
    "nüchternen": "nüchtern",
    "nüchterner": "nüchtern",
    "nüchternere": "nüchtern",
    "nüchternerem": "nüchtern",
    "nüchterneren": "nüchtern",
    "nüchternerer": "nüchtern",
    "nüchterneres": "nüchtern",
    "nüchternes": "nüchtern",
    "nüchternste": "nüchtern",
    "nüchternstem": "nüchtern",
    "nüchternsten": "nüchtern",
    "nüchternster": "nüchtern",
    "nüchternstes": "nüchtern",
    "nütze": "nützen",
    "nützend": "nützen",
    "nützendem": "nützend",
    "nützender": "nützend",
    "nützendes": "nützend",
    "nützest": "nützen",
    "nützet": "nützen",
    "nützlichem": "nützlich",
    "nützlichen": "nützlich",
    "nützlicher": "nützlich",
    "nützlichere": "nützlich",
    "nützlicherem": "nützlich",
    "nützlicheren": "nützlich",
    "nützlicherer": "nützlich",
    "nützlicheres": "nützlich",
    "nützliches": "nützlich",
    "nützlichste": "nützlich",
    "nützlichstem": "nützlich",
    "nützlichsten": "nützlich",
    "nützlichster": "nützlich",
    "nützlichstes": "nützlich",
    "nützt": "nützen",
    "nützte": "nützen",
    "nützten": "nützen",
    "nütztest": "nützen",
    "nütztet": "nützen",
    "obdachlosem": "obdachlos",
    "obdachlosen": "obdachlos",
    "obdachloser": "obdachlos",
    "obdachloses": "obdachlos",
    "obduziere": "obduzieren",
    "obduzierend": "obduzieren",
    "obduzierende": "obduzierend",
    "obduzierendem": "obduzierend",
    "obduzierenden": "obduzierend",
    "obduzierender": "obduzierend",
    "obduzierendes": "obduzierend",
    "obduzierest": "obduzieren",
    "obduzieret": "obduzieren",
    "obduzierst": "obduzieren",
    "obduziert": "obduzieren",
    "obduzierte": "obduzieren",
    "obduziertem": "obduziert",
    "obduzierten": "obduzieren",
    "obduzierter": "obduziert",
    "obduziertes": "obduziert",
    "obduziertest": "obduzieren",
    "obduziertet": "obduzieren",
    "oberem": "ober",
    "oberen": "ober",
    "oberer": "ober",
    "oberere": "ober",
    "obererem": "ober",
    "obereren": "ober",
    "obererer": "ober",
    "obereres": "ober",
    "oberes": "ober",
    "oberflächigem": "oberflächig",
    "oberflächigen": "oberflächig",
    "oberflächiger": "oberflächig",
    "oberflächigere": "oberflächig",
    "oberflächigerem": "oberflächig",
    "oberflächigeren": "oberflächig",
    "oberflächigerer": "oberflächig",
    "oberflächigeres": "oberflächig",
    "oberflächiges": "oberflächig",
    "oberflächigste": "oberflächig",
    "oberflächigstem": "oberflächig",
    "oberflächigsten": "oberflächig",
    "oberflächigster": "oberflächig",
    "oberflächigstes": "oberflächig",
    "oberflächliche": "oberflächlich",
    "oberflächlichem": "oberflächlich",
    "oberflächlichen": "oberflächlich",
    "oberflächlicher": "oberflächlich",
    "oberflächlichere": "oberflächlich",
    "oberflächlicherem": "oberflächlich",
    "oberflächlicheren": "oberflächlich",
    "oberflächlicherer": "oberflächlich",
    "oberflächlicheres": "oberflächlich",
    "oberflächliches": "oberflächlich",
    "oberflächlichste": "oberflächlich",
    "oberflächlichstem": "oberflächlich",
    "oberflächlichsten": "oberflächlich",
    "oberflächlichster": "oberflächlich",
    "oberflächlichstes": "oberflächlich",
    "oberlehrerhaftem": "oberlehrerhaft",
    "oberlehrerhaften": "oberlehrerhaft",
    "oberlehrerhafter": "oberlehrerhaft",
    "oberlehrerhaftere": "oberlehrerhaft",
    "oberlehrerhafterem": "oberlehrerhaft",
    "oberlehrerhafteren": "oberlehrerhaft",
    "oberlehrerhafterer": "oberlehrerhaft",
    "oberlehrerhafteres": "oberlehrerhaft",
    "oberlehrerhaftes": "oberlehrerhaft",
    "oberlehrerhafteste": "oberlehrerhaft",
    "oberlehrerhaftestem": "oberlehrerhaft",
    "oberlehrerhaftesten": "oberlehrerhaft",
    "oberlehrerhaftester": "oberlehrerhaft",
    "oberlehrerhaftestes": "oberlehrerhaft",
    "oberstem": "ober",
    "obersten": "ober",
    "oberster": "ober",
    "oberstes": "ober",
    "obigem": "obig",
    "obigen": "obig",
    "obiger": "obig",
    "obiges": "obig",
    "objektivem": "objektiv",
    "objektiven": "objektiv",
    "objektiver": "objektiv",
    "objektivere": "objektiv",
    "objektiverem": "objektiv",
    "objektiveren": "objektiv",
    "objektiverer": "objektiv",
    "objektiveres": "objektiv",
    "objektives": "objektiv",
    "objektivierend": "objektivieren",
    "objektivierende": "objektivierend",
    "objektivierendem": "objektivierend",
    "objektivierenden": "objektivierend",
    "objektivierender": "objektivierend",
    "objektivierendere": "objektivierend",
    "objektivierenderem": "objektivierend",
    "objektivierenderen": "objektivierend",
    "objektivierenderer": "objektivierend",
    "objektivierenderes": "objektivierend",
    "objektivierendes": "objektivierend",
    "objektivierendste": "objektivierend",
    "objektivierendstem": "objektivierend",
    "objektivierendsten": "objektivierend",
    "objektivierendster": "objektivierend",
    "objektivierendstes": "objektivierend",
    "objektivierest": "objektivieren",
    "objektivieret": "objektivieren",
    "objektivierst": "objektivieren",
    "objektiviert": "objektivieren",
    "objektivierte": "objektivieren",
    "objektiviertem": "objektiviert",
    "objektivierten": "objektivieren",
    "objektivierter": "objektiviert",
    "objektiviertere": "objektiviert",
    "objektivierterem": "objektiviert",
    "objektivierteren": "objektiviert",
    "objektivierterer": "objektiviert",
    "objektivierteres": "objektiviert",
    "objektiviertes": "objektiviert",
    "objektiviertest": "objektivieren",
    "objektivierteste": "objektiviert",
    "objektiviertestem": "objektiviert",
    "objektiviertesten": "objektiviert",
    "objektiviertester": "objektiviert",
    "objektiviertestes": "objektiviert",
    "objektiviertet": "objektivieren",
    "objektivistische": "objektivistisch",
    "objektivistischem": "objektivistisch",
    "objektivistischen": "objektivistisch",
    "objektivistischer": "objektivistisch",
    "objektivistischere": "objektivistisch",
    "objektivistischerem": "objektivistisch",
    "objektivistischeren": "objektivistisch",
    "objektivistischerer": "objektivistisch",
    "objektivistischeres": "objektivistisch",
    "objektivistisches": "objektivistisch",
    "objektivistischste": "objektivistisch",
    "objektivistischstem": "objektivistisch",
    "objektivistischsten": "objektivistisch",
    "objektivistischster": "objektivistisch",
    "objektivistischstes": "objektivistisch",
    "objektivstem": "objektiv",
    "objektivsten": "objektiv",
    "objektivster": "objektiv",
    "objektivstes": "objektiv",
    "obligatorischem": "obligatorisch",
    "obligatorischen": "obligatorisch",
    "obligatorischer": "obligatorisch",
    "obligatorischere": "obligatorisch",
    "obligatorischerem": "obligatorisch",
    "obligatorischeren": "obligatorisch",
    "obligatorischerer": "obligatorisch",
    "obligatorischeres": "obligatorisch",
    "obligatorisches": "obligatorisch",
    "obligatorischste": "obligatorisch",
    "obligatorischstem": "obligatorisch",
    "obligatorischsten": "obligatorisch",
    "obligatorischster": "obligatorisch",
    "obligatorischstes": "obligatorisch",
    "obsessivem": "obsessiv",
    "obsessiven": "obsessiv",
    "obsessiver": "obsessiv",
    "obsessives": "obsessiv",
    "odontologischem": "odontologisch",
    "odontologischen": "odontologisch",
    "odontologischer": "odontologisch",
    "odontologisches": "odontologisch",
    "ofenfrische": "ofenfrisch",
    "ofenfrischem": "ofenfrisch",
    "ofenfrischen": "ofenfrisch",
    "ofenfrischer": "ofenfrisch",
    "ofenfrisches": "ofenfrisch",
    "offenbar": "offenbaren",
    "offenbare": "offenbaren",
    "offenbarend": "offenbaren",
    "offenbarende": "offenbarend",
    "offenbarendem": "offenbarend",
    "offenbarenden": "offenbarend",
    "offenbarender": "offenbarend",
    "offenbarendere": "offenbarend",
    "offenbarenderem": "offenbarend",
    "offenbarenderen": "offenbarend",
    "offenbarenderer": "offenbarend",
    "offenbarenderes": "offenbarend",
    "offenbarendes": "offenbarend",
    "offenbarendste": "offenbarend",
    "offenbarendstem": "offenbarend",
    "offenbarendsten": "offenbarend",
    "offenbarendster": "offenbarend",
    "offenbarendstes": "offenbarend",
    "offenbarest": "offenbaren",
    "offenbaret": "offenbaren",
    "offenbarst": "offenbaren",
    "offenbart": "offenbaren",
    "offenbarte": "offenbaren",
    "offenbartem": "offenbart",
    "offenbarten": "offenbaren",
    "offenbarter": "offenbart",
    "offenbartes": "offenbart",
    "offenbartest": "offenbaren",
    "offenbartet": "offenbaren",
    "offenbleibe": "offenbleiben",
    "offenbleibend": "offenbleiben",
    "offenbleibende": "offenbleibend",
    "offenbleibendem": "offenbleibend",
    "offenbleibenden": "offenbleibend",
    "offenbleibender": "offenbleibend",
    "offenbleibendes": "offenbleibend",
    "offenbleibest": "offenbleiben",
    "offenbleibet": "offenbleiben",
    "offenbleibst": "offenbleiben",
    "offenbleibt": "offenbleiben",
    "offenblieb": "offenbleiben",
    "offenbliebe": "offenbleiben",
    "offenblieben": "offenbleiben",
    "offenbliebest": "offenbleiben",
    "offenbliebet": "offenbleiben",
    "offenbliebst": "offenbleiben",
    "offenbliebt": "offenbleiben",
    "offene": "offen",
    "offenem": "offen",
    "offenen": "offen",
    "offener": "offen",
    "offenere": "offen",
    "offenerem": "offen",
    "offeneren": "offen",
    "offenerer": "offen",
    "offeneres": "offen",
    "offenes": "offen",
    "offengeblieben": "offenbleiben",
    "offengebliebene": "offengeblieben",
    "offengebliebenem": "offengeblieben",
    "offengebliebenen": "offengeblieben",
    "offengebliebener": "offengeblieben",
    "offengebliebenes": "offengeblieben",
    "offengehalten": "offenhalten",
    "offengehaltene": "offengehalten",
    "offengehaltenem": "offengehalten",
    "offengehaltenen": "offengehalten",
    "offengehaltener": "offengehalten",
    "offengehaltenere": "offengehalten",
    "offengehaltenerem": "offengehalten",
    "offengehalteneren": "offengehalten",
    "offengehaltenerer": "offengehalten",
    "offengehalteneres": "offengehalten",
    "offengehaltenes": "offengehalten",
    "offengehaltenste": "offengehalten",
    "offengehaltenstem": "offengehalten",
    "offengehaltensten": "offengehalten",
    "offengehaltenster": "offengehalten",
    "offengehaltenstes": "offengehalten",
    "offengelassen": "offenlassen",
    "offengelassene": "offengelassen",
    "offengelassenem": "offengelassen",
    "offengelassenen": "offengelassen",
    "offengelassener": "offengelassen",
    "offengelassenes": "offengelassen",
    "offengelegt": "offenlegen",
    "offengelegte": "offengelegt",
    "offengelegtem": "offengelegt",
    "offengelegten": "offengelegt",
    "offengelegter": "offengelegt",
    "offengelegtes": "offengelegt",
    "offenhalte": "offenhalten",
    "offenhaltend": "offenhalten",
    "offenhaltende": "offenhaltend",
    "offenhaltendem": "offenhaltend",
    "offenhaltenden": "offenhaltend",
    "offenhaltender": "offenhaltend",
    "offenhaltendere": "offenhaltend",
    "offenhaltenderem": "offenhaltend",
    "offenhaltenderen": "offenhaltend",
    "offenhaltenderer": "offenhaltend",
    "offenhaltenderes": "offenhaltend",
    "offenhaltendes": "offenhaltend",
    "offenhaltendste": "offenhaltend",
    "offenhaltendstem": "offenhaltend",
    "offenhaltendsten": "offenhaltend",
    "offenhaltendster": "offenhaltend",
    "offenhaltendstes": "offenhaltend",
    "offenhaltest": "offenhalten",
    "offenhaltet": "offenhalten",
    "offenherzigem": "offenherzig",
    "offenherzigen": "offenherzig",
    "offenherziger": "offenherzig",
    "offenherzigere": "offenherzig",
    "offenherzigerem": "offenherzig",
    "offenherzigeren": "offenherzig",
    "offenherzigerer": "offenherzig",
    "offenherzigeres": "offenherzig",
    "offenherziges": "offenherzig",
    "offenherzigste": "offenherzig",
    "offenherzigstem": "offenherzig",
    "offenherzigsten": "offenherzig",
    "offenherzigster": "offenherzig",
    "offenherzigstes": "offenherzig",
    "offenhielt": "offenhalten",
    "offenhielte": "offenhalten",
    "offenhielten": "offenhalten",
    "offenhieltest": "offenhalten",
    "offenhieltet": "offenhalten",
    "offenhält": "offenhalten",
    "offenhältst": "offenhalten",
    "offenkundige": "offenkundig",
    "offenkundigem": "offenkundig",
    "offenkundigen": "offenkundig",
    "offenkundiger": "offenkundig",
    "offenkundigere": "offenkundig",
    "offenkundigerem": "offenkundig",
    "offenkundigeren": "offenkundig",
    "offenkundigerer": "offenkundig",
    "offenkundigeres": "offenkundig",
    "offenkundiges": "offenkundig",
    "offenkundigste": "offenkundig",
    "offenkundigstem": "offenkundig",
    "offenkundigsten": "offenkundig",
    "offenkundigster": "offenkundig",
    "offenkundigstes": "offenkundig",
    "offenlasse": "offenlassen",
    "offenlassend": "offenlassen",
    "offenlassende": "offenlassend",
    "offenlassendem": "offenlassend",
    "offenlassenden": "offenlassend",
    "offenlassender": "offenlassend",
    "offenlassendes": "offenlassend",
    "offenlassest": "offenlassen",
    "offenlasset": "offenlassen",
    "offenlaßt": "offenlassen",
    "offenlege": "offenlegen",
    "offenlegend": "offenlegen",
    "offenlegende": "offenlegend",
    "offenlegendem": "offenlegend",
    "offenlegenden": "offenlegend",
    "offenlegender": "offenlegend",
    "offenlegendes": "offenlegend",
    "offenlegest": "offenlegen",
    "offenleget": "offenlegen",
    "offenlegst": "offenlegen",
    "offenlegt": "offenlegen",
    "offenlegte": "offenlegen",
    "offenlegten": "offenlegen",
    "offenlegtest": "offenlegen",
    "offenlegtet": "offenlegen",
    "offenließ": "offenlassen",
    "offenließe": "offenlassen",
    "offenließen": "offenlassen",
    "offenließest": "offenlassen",
    "offenließet": "offenlassen",
    "offenließt": "offenlassen",
    "offenläßt": "offenlassen",
    "offensichtliche": "offensichtlich",
    "offensichtlichem": "offensichtlich",
    "offensichtlichen": "offensichtlich",
    "offensichtlicher": "offensichtlich",
    "offensichtlichere": "offensichtlich",
    "offensichtlicherem": "offensichtlich",
    "offensichtlicheren": "offensichtlich",
    "offensichtlicherer": "offensichtlich",
    "offensichtlicheres": "offensichtlich",
    "offensichtliches": "offensichtlich",
    "offensichtlichste": "offensichtlich",
    "offensichtlichstem": "offensichtlich",
    "offensichtlichsten": "offensichtlich",
    "offensichtlichster": "offensichtlich",
    "offensichtlichstes": "offensichtlich",
    "offensive": "offensiv",
    "offensivem": "offensiv",
    "offensiven": "offensiv",
    "offensiver": "offensiv",
    "offensivere": "offensiv",
    "offensiverem": "offensiv",
    "offensiveren": "offensiv",
    "offensiverer": "offensiv",
    "offensiveres": "offensiv",
    "offensives": "offensiv",
    "offensivste": "offensiv",
    "offensivstem": "offensiv",
    "offensivsten": "offensiv",
    "offensivster": "offensiv",
    "offensivstes": "offensiv",
    "offenste": "offen",
    "offenstem": "offen",
    "offensten": "offen",
    "offenster": "offen",
    "offenstes": "offen",
    "offenzubleiben": "offenbleiben",
    "offenzuhalten": "offenhalten",
    "offenzulassen": "offenlassen",
    "offenzulegen": "offenlegen",
    "offeriere": "offerieren",
    "offerierend": "offerieren",
    "offerierende": "offerierend",
    "offerierendem": "offerierend",
    "offerierenden": "offerierend",
    "offerierender": "offerierend",
    "offerierendes": "offerierend",
    "offerierest": "offerieren",
    "offerieret": "offerieren",
    "offerierst": "offerieren",
    "offeriert": "offerieren",
    "offerierte": "offerieren",
    "offeriertem": "offeriert",
    "offerierten": "offerieren",
    "offerierter": "offeriert",
    "offeriertes": "offeriert",
    "offeriertest": "offerieren",
    "offeriertet": "offerieren",
    "offiziellem": "offiziell",
    "offiziellen": "offiziell",
    "offizieller": "offiziell",
    "offiziellere": "offiziell",
    "offiziellerem": "offiziell",
    "offizielleren": "offiziell",
    "offiziellerer": "offiziell",
    "offizielleres": "offiziell",
    "offizielles": "offiziell",
    "offiziellste": "offiziell",
    "offiziellstem": "offiziell",
    "offiziellsten": "offiziell",
    "offiziellster": "offiziell",
    "offiziellstes": "offiziell",
    "ohnmächtigem": "ohnmächtig",
    "ohnmächtigen": "ohnmächtig",
    "ohnmächtiger": "ohnmächtig",
    "ohnmächtigere": "ohnmächtig",
    "ohnmächtigerem": "ohnmächtig",
    "ohnmächtigeren": "ohnmächtig",
    "ohnmächtigerer": "ohnmächtig",
    "ohnmächtigeres": "ohnmächtig",
    "ohnmächtiges": "ohnmächtig",
    "ohnmächtigste": "ohnmächtig",
    "ohnmächtigstem": "ohnmächtig",
    "ohnmächtigsten": "ohnmächtig",
    "ohnmächtigster": "ohnmächtig",
    "ohnmächtigstes": "ohnmächtig",
    "ohrenbetäubendem": "ohrenbetäubend",
    "ohrenbetäubenden": "ohrenbetäubend",
    "ohrenbetäubender": "ohrenbetäubend",
    "ohrenbetäubendere": "ohrenbetäubend",
    "ohrenbetäubenderem": "ohrenbetäubend",
    "ohrenbetäubenderen": "ohrenbetäubend",
    "ohrenbetäubenderer": "ohrenbetäubend",
    "ohrenbetäubenderes": "ohrenbetäubend",
    "ohrenbetäubendes": "ohrenbetäubend",
    "ohrenbetäubendste": "ohrenbetäubend",
    "ohrenbetäubendstem": "ohrenbetäubend",
    "ohrenbetäubendsten": "ohrenbetäubend",
    "ohrenbetäubendster": "ohrenbetäubend",
    "ohrenbetäubendstes": "ohrenbetäubend",
    "ohrfeige": "ohrfeigen",
    "ohrfeigend": "ohrfeigen",
    "ohrfeigende": "ohrfeigend",
    "ohrfeigendem": "ohrfeigend",
    "ohrfeigenden": "ohrfeigend",
    "ohrfeigender": "ohrfeigend",
    "ohrfeigendes": "ohrfeigend",
    "ohrfeigest": "ohrfeigen",
    "ohrfeiget": "ohrfeigen",
    "ohrfeigst": "ohrfeigen",
    "ohrfeigt": "ohrfeigen",
    "ohrfeigte": "ohrfeigen",
    "ohrfeigten": "ohrfeigen",
    "ohrfeigtest": "ohrfeigen",
    "ohrfeigtet": "ohrfeigen",
    "okkasionellem": "okkasionell",
    "okkasionellen": "okkasionell",
    "okkasioneller": "okkasionell",
    "okkasionelles": "okkasionell",
    "okkludiere": "okkludieren",
    "okkludierend": "okkludieren",
    "okkludierende": "okkludierend",
    "okkludierendem": "okkludierend",
    "okkludierenden": "okkludierend",
    "okkludierender": "okkludierend",
    "okkludierendes": "okkludierend",
    "okkludierest": "okkludieren",
    "okkludieret": "okkludieren",
    "okkludierst": "okkludieren",
    "okkludiert": "okkludieren",
    "okkludierte": "okkludieren",
    "okkludiertem": "okkludiert",
    "okkludierten": "okkludieren",
    "okkludierter": "okkludiert",
    "okkludiertes": "okkludiert",
    "okkludiertest": "okkludieren",
    "okkludiertet": "okkludieren",
    "okklusivem": "okklusiv",
    "okklusiven": "okklusiv",
    "okklusiver": "okklusiv",
    "okklusives": "okklusiv",
    "okkulte": "okkult",
    "okkultem": "okkult",
    "okkulten": "okkult",
    "okkulter": "okkult",
    "okkultes": "okkult",
    "okkultistischem": "okkultistisch",
    "okkultistischen": "okkultistisch",
    "okkultistischer": "okkultistisch",
    "okkultistisches": "okkultistisch",
    "okkupiere": "okkupieren",
    "okkupierend": "okkupieren",
    "okkupierende": "okkupierend",
    "okkupierendem": "okkupierend",
    "okkupierenden": "okkupierend",
    "okkupierender": "okkupierend",
    "okkupierendere": "okkupierend",
    "okkupierenderem": "okkupierend",
    "okkupierenderen": "okkupierend",
    "okkupierenderer": "okkupierend",
    "okkupierenderes": "okkupierend",
    "okkupierendes": "okkupierend",
    "okkupierendste": "okkupierend",
    "okkupierendstem": "okkupierend",
    "okkupierendsten": "okkupierend",
    "okkupierendster": "okkupierend",
    "okkupierendstes": "okkupierend",
    "okkupierest": "okkupieren",
    "okkupieret": "okkupieren",
    "okkupierst": "okkupieren",
    "okkupiert": "okkupieren",
    "okkupierte": "okkupieren",
    "okkupiertem": "okkupiert",
    "okkupierten": "okkupieren",
    "okkupierter": "okkupiert",
    "okkupiertere": "okkupiert",
    "okkupierterem": "okkupiert",
    "okkupierteren": "okkupiert",
    "okkupierterer": "okkupiert",
    "okkupierteres": "okkupiert",
    "okkupiertes": "okkupiert",
    "okkupiertest": "okkupieren",
    "okkupierteste": "okkupiert",
    "okkupiertestem": "okkupiert",
    "okkupiertesten": "okkupiert",
    "okkupiertester": "okkupiert",
    "okkupiertestes": "okkupiert",
    "okkupiertet": "okkupieren",
    "okularem": "okular",
    "okularen": "okular",
    "okularer": "okular",
    "okulares": "okular",
    "ollem": "oll",
    "ollen": "oll",
    "oller": "oll",
    "ollere": "oll",
    "ollerem": "oll",
    "olleren": "oll",
    "ollerer": "oll",
    "olleres": "oll",
    "olles": "oll",
    "ollste": "oll",
    "ollstem": "oll",
    "ollsten": "oll",
    "ollster": "oll",
    "ollstes": "oll",
    "olympischem": "olympisch",
    "olympischen": "olympisch",
    "olympischer": "olympisch",
    "olympisches": "olympisch",
    "ominösem": "ominös",
    "ominösen": "ominös",
    "ominöser": "ominös",
    "ominösere": "ominös",
    "ominöserem": "ominös",
    "ominöseren": "ominös",
    "ominöserer": "ominös",
    "ominöseres": "ominös",
    "ominöses": "ominös",
    "ominöseste": "ominös",
    "ominösestem": "ominös",
    "ominösesten": "ominös",
    "ominösester": "ominös",
    "ominösestes": "ominös",
    "omittiere": "omittieren",
    "omittierend": "omittieren",
    "omittierende": "omittierend",
    "omittierendem": "omittierend",
    "omittierenden": "omittierend",
    "omittierender": "omittierend",
    "omittierendes": "omittierend",
    "omittierest": "omittieren",
    "omittieret": "omittieren",
    "omittierst": "omittieren",
    "omittiert": "omittieren",
    "omittierte": "omittieren",
    "omittiertem": "omittiert",
    "omittierten": "omittieren",
    "omittierter": "omittiert",
    "omittiertes": "omittiert",
    "omittiertest": "omittieren",
    "omittiertet": "omittieren",
    "omnipotentem": "omnipotent",
    "omnipotenten": "omnipotent",
    "omnipotenter": "omnipotent",
    "omnipotentere": "omnipotent",
    "omnipotenterem": "omnipotent",
    "omnipotenteren": "omnipotent",
    "omnipotenterer": "omnipotent",
    "omnipotenteres": "omnipotent",
    "omnipotentes": "omnipotent",
    "omnipotenteste": "omnipotent",
    "omnipotentestem": "omnipotent",
    "omnipotentesten": "omnipotent",
    "omnipotentester": "omnipotent",
    "omnipotentestes": "omnipotent",
    "omnipräsente": "omnipräsent",
    "omnipräsentem": "omnipräsent",
    "omnipräsenten": "omnipräsent",
    "omnipräsenter": "omnipräsent",
    "omnipräsentes": "omnipräsent",
    "onaniere": "onanieren",
    "onanierend": "onanieren",
    "onanierende": "onanierend",
    "onanierendem": "onanierend",
    "onanierenden": "onanierend",
    "onanierender": "onanierend",
    "onanierendes": "onanierend",
    "onanierest": "onanieren",
    "onanieret": "onanieren",
    "onanierst": "onanieren",
    "onaniert": "onanieren",
    "onanierte": "onanieren",
    "onaniertem": "onaniert",
    "onanierten": "onanieren",
    "onanierter": "onaniert",
    "onaniertes": "onaniert",
    "onaniertest": "onanieren",
    "onaniertet": "onanieren",
    "onkelhafte": "onkelhaft",
    "onkelhaftem": "onkelhaft",
    "onkelhaften": "onkelhaft",
    "onkelhafter": "onkelhaft",
    "onkelhaftere": "onkelhaft",
    "onkelhafterem": "onkelhaft",
    "onkelhafteren": "onkelhaft",
    "onkelhafterer": "onkelhaft",
    "onkelhafteres": "onkelhaft",
    "onkelhaftes": "onkelhaft",
    "onkelhafteste": "onkelhaft",
    "onkelhaftestem": "onkelhaft",
    "onkelhaftesten": "onkelhaft",
    "onkelhaftester": "onkelhaft",
    "onkelhaftestes": "onkelhaft",
    "onkologischem": "onkologisch",
    "onkologischen": "onkologisch",
    "onkologischer": "onkologisch",
    "onkologisches": "onkologisch",
    "ontologische": "ontologisch",
    "ontologischem": "ontologisch",
    "ontologischen": "ontologisch",
    "ontologischer": "ontologisch",
    "ontologisches": "ontologisch",
    "operablem": "operabel",
    "operablen": "operabel",
    "operabler": "operabel",
    "operables": "operabel",
    "operativem": "operativ",
    "operativen": "operativ",
    "operativer": "operativ",
    "operatives": "operativ",
    "operiere": "operieren",
    "operierend": "operieren",
    "operierende": "operierend",
    "operierendem": "operierend",
    "operierenden": "operierend",
    "operierender": "operierend",
    "operierendes": "operierend",
    "operierest": "operieren",
    "operieret": "operieren",
    "operierst": "operieren",
    "operiert": "operieren",
    "operierte": "operieren",
    "operiertem": "operiert",
    "operierten": "operieren",
    "operierter": "operiert",
    "operiertes": "operiert",
    "operiertest": "operieren",
    "operiertet": "operieren",
    "opferbereitem": "opferbereit",
    "opferbereiten": "opferbereit",
    "opferbereiter": "opferbereit",
    "opferbereitere": "opferbereit",
    "opferbereiterem": "opferbereit",
    "opferbereiteren": "opferbereit",
    "opferbereiterer": "opferbereit",
    "opferbereiteres": "opferbereit",
    "opferbereites": "opferbereit",
    "opferbereiteste": "opferbereit",
    "opferbereitestem": "opferbereit",
    "opferbereitesten": "opferbereit",
    "opferbereitester": "opferbereit",
    "opferbereitestes": "opferbereit",
    "opfere": "opfern",
    "opfernd": "opfern",
    "opfernde": "opfernd",
    "opferndem": "opfernd",
    "opfernden": "opfernd",
    "opfernder": "opfernd",
    "opferndes": "opfernd",
    "opferst": "opfern",
    "opfert": "opfern",
    "opferte": "opfern",
    "opferten": "opfern",
    "opfertest": "opfern",
    "opfertet": "opfern",
    "opferwilligem": "opferwillig",
    "opferwilligen": "opferwillig",
    "opferwilliger": "opferwillig",
    "opferwilligere": "opferwillig",
    "opferwilligerem": "opferwillig",
    "opferwilligeren": "opferwillig",
    "opferwilligerer": "opferwillig",
    "opferwilligeres": "opferwillig",
    "opferwilliges": "opferwillig",
    "opferwilligste": "opferwillig",
    "opferwilligstem": "opferwillig",
    "opferwilligsten": "opferwillig",
    "opferwilligster": "opferwillig",
    "opferwilligstes": "opferwillig",
    "opponiere": "opponieren",
    "opponierend": "opponieren",
    "opponierende": "opponierend",
    "opponierendem": "opponierend",
    "opponierenden": "opponierend",
    "opponierender": "opponierend",
    "opponierendere": "opponierend",
    "opponierenderem": "opponierend",
    "opponierenderen": "opponierend",
    "opponierenderer": "opponierend",
    "opponierenderes": "opponierend",
    "opponierendes": "opponierend",
    "opponierendste": "opponierend",
    "opponierendstem": "opponierend",
    "opponierendsten": "opponierend",
    "opponierendster": "opponierend",
    "opponierendstes": "opponierend",
    "opponierest": "opponieren",
    "opponieret": "opponieren",
    "opponierst": "opponieren",
    "opponiert": "opponieren",
    "opponierte": "opponieren",
    "opponiertem": "opponiert",
    "opponierten": "opponieren",
    "opponierter": "opponiert",
    "opponiertere": "opponiert",
    "opponierterem": "opponiert",
    "opponierteren": "opponiert",
    "opponierterer": "opponiert",
    "opponierteres": "opponiert",
    "opponiertes": "opponiert",
    "opponiertest": "opponieren",
    "opponierteste": "opponiert",
    "opponiertestem": "opponiert",
    "opponiertesten": "opponiert",
    "opponiertester": "opponiert",
    "opponiertestes": "opponiert",
    "opponiertet": "opponieren",
    "opportune": "opportun",
    "opportunem": "opportun",
    "opportunen": "opportun",
    "opportuner": "opportun",
    "opportunes": "opportun",
    "opportunistische": "opportunistisch",
    "opportunistischem": "opportunistisch",
    "opportunistischen": "opportunistisch",
    "opportunistischer": "opportunistisch",
    "opportunistischere": "opportunistisch",
    "opportunistischerem": "opportunistisch",
    "opportunistischeren": "opportunistisch",
    "opportunistischerer": "opportunistisch",
    "opportunistischeres": "opportunistisch",
    "opportunistisches": "opportunistisch",
    "opportunistischste": "opportunistisch",
    "opportunistischstem": "opportunistisch",
    "opportunistischsten": "opportunistisch",
    "opportunistischster": "opportunistisch",
    "opportunistischstes": "opportunistisch",
    "oppositionelle": "oppositionell",
    "oppositionellem": "oppositionell",
    "oppositionellen": "oppositionell",
    "oppositioneller": "oppositionell",
    "oppositionelles": "oppositionell",
    "optimalem": "optimal",
    "optimalen": "optimal",
    "optimaler": "optimal",
    "optimales": "optimal",
    "optimiere": "optimieren",
    "optimierend": "optimieren",
    "optimierende": "optimierend",
    "optimierendem": "optimierend",
    "optimierenden": "optimierend",
    "optimierender": "optimierend",
    "optimierendere": "optimierend",
    "optimierenderem": "optimierend",
    "optimierenderen": "optimierend",
    "optimierenderer": "optimierend",
    "optimierenderes": "optimierend",
    "optimierendes": "optimierend",
    "optimierendste": "optimierend",
    "optimierendstem": "optimierend",
    "optimierendsten": "optimierend",
    "optimierendster": "optimierend",
    "optimierendstes": "optimierend",
    "optimierest": "optimieren",
    "optimieret": "optimieren",
    "optimierst": "optimieren",
    "optimiert": "optimieren",
    "optimierte": "optimieren",
    "optimiertem": "optimiert",
    "optimierten": "optimieren",
    "optimierter": "optimiert",
    "optimiertere": "optimiert",
    "optimierterem": "optimiert",
    "optimierteren": "optimiert",
    "optimierterer": "optimiert",
    "optimierteres": "optimiert",
    "optimiertes": "optimiert",
    "optimiertest": "optimieren",
    "optimierteste": "optimiert",
    "optimiertestem": "optimiert",
    "optimiertesten": "optimiert",
    "optimiertester": "optimiert",
    "optimiertestes": "optimiert",
    "optimiertet": "optimieren",
    "optimistischem": "optimistisch",
    "optimistischen": "optimistisch",
    "optimistischer": "optimistisch",
    "optimistischere": "optimistisch",
    "optimistischerem": "optimistisch",
    "optimistischeren": "optimistisch",
    "optimistischerer": "optimistisch",
    "optimistischeres": "optimistisch",
    "optimistisches": "optimistisch",
    "optimistischste": "optimistisch",
    "optimistischstem": "optimistisch",
    "optimistischsten": "optimistisch",
    "optimistischster": "optimistisch",
    "optimistischstes": "optimistisch",
    "optischem": "optisch",
    "optischen": "optisch",
    "optischer": "optisch",
    "optisches": "optisch",
    "opulentem": "opulent",
    "opulenten": "opulent",
    "opulenter": "opulent",
    "opulentere": "opulent",
    "opulenterem": "opulent",
    "opulenteren": "opulent",
    "opulenterer": "opulent",
    "opulenteres": "opulent",
    "opulentes": "opulent",
    "opulenteste": "opulent",
    "opulentestem": "opulent",
    "opulentesten": "opulent",
    "opulentester": "opulent",
    "opulentestes": "opulent",
    "oratorischem": "oratorisch",
    "oratorischen": "oratorisch",
    "oratorischer": "oratorisch",
    "oratorisches": "oratorisch",
    "orbitale": "orbital",
    "orbitalem": "orbital",
    "orbitalen": "orbital",
    "orbitaler": "orbital",
    "orbitales": "orbital",
    "ordentlichem": "ordentlich",
    "ordentlichen": "ordentlich",
    "ordentlicher": "ordentlich",
    "ordentlichere": "ordentlich",
    "ordentlicherem": "ordentlich",
    "ordentlicheren": "ordentlich",
    "ordentlicherer": "ordentlich",
    "ordentlicheres": "ordentlich",
    "ordentliches": "ordentlich",
    "ordentlichste": "ordentlich",
    "ordentlichstem": "ordentlich",
    "ordentlichsten": "ordentlich",
    "ordentlichster": "ordentlich",
    "ordentlichstes": "ordentlich",
    "ordere": "ordern",
    "ordernd": "ordern",
    "ordernde": "ordernd",
    "orderndem": "ordernd",
    "ordernden": "ordernd",
    "ordernder": "ordernd",
    "orderndere": "ordernd",
    "ordernderem": "ordernd",
    "ordernderen": "ordernd",
    "ordernderer": "ordernd",
    "ordernderes": "ordernd",
    "orderndes": "ordernd",
    "orderndste": "ordernd",
    "orderndstem": "ordernd",
    "orderndsten": "ordernd",
    "orderndster": "ordernd",
    "orderndstes": "ordernd",
    "orderst": "ordern",
    "ordert": "ordern",
    "orderte": "ordern",
    "orderten": "ordern",
    "ordertest": "ordern",
    "ordertet": "ordern",
    "ordiniere": "ordinieren",
    "ordinierend": "ordinieren",
    "ordinierende": "ordinierend",
    "ordinierendem": "ordinierend",
    "ordinierenden": "ordinierend",
    "ordinierender": "ordinierend",
    "ordinierendes": "ordinierend",
    "ordinierest": "ordinieren",
    "ordinieret": "ordinieren",
    "ordinierst": "ordinieren",
    "ordiniert": "ordinieren",
    "ordinierte": "ordinieren",
    "ordiniertem": "ordiniert",
    "ordinierten": "ordinieren",
    "ordinierter": "ordiniert",
    "ordiniertes": "ordiniert",
    "ordiniertest": "ordinieren",
    "ordiniertet": "ordinieren",
    "ordinärem": "ordinär",
    "ordinären": "ordinär",
    "ordinärer": "ordinär",
    "ordinärere": "ordinär",
    "ordinärerem": "ordinär",
    "ordinäreren": "ordinär",
    "ordinärerer": "ordinär",
    "ordinäreres": "ordinär",
    "ordinäres": "ordinär",
    "ordinärste": "ordinär",
    "ordinärstem": "ordinär",
    "ordinärsten": "ordinär",
    "ordinärster": "ordinär",
    "ordinärstes": "ordinär",
    "ordne": "ordnen",
    "ordnend": "ordnen",
    "ordnende": "ordnend",
    "ordnendem": "ordnend",
    "ordnenden": "ordnend",
    "ordnender": "ordnend",
    "ordnendes": "ordnend",
    "ordnest": "ordnen",
    "ordnet": "ordnen",
    "ordnete": "ordnen",
    "ordneten": "ordnen",
    "ordnetest": "ordnen",
    "ordnetet": "ordnen",
    "ordnungsgemäßem": "ordnungsgemäß",
    "ordnungsgemäßen": "ordnungsgemäß",
    "ordnungsgemäßer": "ordnungsgemäß",
    "ordnungsgemäßes": "ordnungsgemäß",
    "ordnungsliebende": "ordnungsliebend",
    "ordnungsliebendem": "ordnungsliebend",
    "ordnungsliebenden": "ordnungsliebend",
    "ordnungsliebender": "ordnungsliebend",
    "ordnungsliebendere": "ordnungsliebend",
    "ordnungsliebenderem": "ordnungsliebend",
    "ordnungsliebenderen": "ordnungsliebend",
    "ordnungsliebenderer": "ordnungsliebend",
    "ordnungsliebenderes": "ordnungsliebend",
    "ordnungsliebendes": "ordnungsliebend",
    "ordnungsliebendste": "ordnungsliebend",
    "ordnungsliebendstem": "ordnungsliebend",
    "ordnungsliebendsten": "ordnungsliebend",
    "ordnungsliebendster": "ordnungsliebend",
    "ordnungsliebendstes": "ordnungsliebend",
    "ordnungsmäßige": "ordnungsmäßig",
    "ordnungsmäßigem": "ordnungsmäßig",
    "ordnungsmäßigen": "ordnungsmäßig",
    "ordnungsmäßiger": "ordnungsmäßig",
    "ordnungsmäßiges": "ordnungsmäßig",
    "ordnungswidrige": "ordnungswidrig",
    "ordnungswidrigem": "ordnungswidrig",
    "ordnungswidrigen": "ordnungswidrig",
    "ordnungswidriger": "ordnungswidrig",
    "ordnungswidrigere": "ordnungswidrig",
    "ordnungswidrigerem": "ordnungswidrig",
    "ordnungswidrigeren": "ordnungswidrig",
    "ordnungswidrigerer": "ordnungswidrig",
    "ordnungswidrigeres": "ordnungswidrig",
    "ordnungswidriges": "ordnungswidrig",
    "ordnungswidrigste": "ordnungswidrig",
    "ordnungswidrigstem": "ordnungswidrig",
    "ordnungswidrigsten": "ordnungswidrig",
    "ordnungswidrigster": "ordnungswidrig",
    "ordnungswidrigstes": "ordnungswidrig",
    "organisatorischem": "organisatorisch",
    "organisatorischen": "organisatorisch",
    "organisatorischer": "organisatorisch",
    "organisatorisches": "organisatorisch",
    "organische": "organisch",
    "organischem": "organisch",
    "organischen": "organisch",
    "organischer": "organisch",
    "organisches": "organisch",
    "organisiere": "organisieren",
    "organisierend": "organisieren",
    "organisierende": "organisierend",
    "organisierendem": "organisierend",
    "organisierenden": "organisierend",
    "organisierender": "organisierend",
    "organisierendes": "organisierend",
    "organisierest": "organisieren",
    "organisieret": "organisieren",
    "organisierst": "organisieren",
    "organisiert": "organisieren",
    "organisierte": "organisieren",
    "organisiertem": "organisiert",
    "organisierten": "organisieren",
    "organisierter": "organisiert",
    "organisiertes": "organisiert",
    "organisiertest": "organisieren",
    "organisiertet": "organisieren",
    "orgele": "orgeln",
    "orgelnd": "orgeln",
    "orgelnde": "orgelnd",
    "orgelndem": "orgelnd",
    "orgelnden": "orgelnd",
    "orgelnder": "orgelnd",
    "orgelndes": "orgelnd",
    "orgelst": "orgeln",
    "orgelt": "orgeln",
    "orgelte": "orgeln",
    "orgelten": "orgeln",
    "orgeltest": "orgeln",
    "orgeltet": "orgeln",
    "orgle": "orgeln",
    "orientalischem": "orientalisch",
    "orientalischen": "orientalisch",
    "orientalischer": "orientalisch",
    "orientalischere": "orientalisch",
    "orientalischerem": "orientalisch",
    "orientalischeren": "orientalisch",
    "orientalischerer": "orientalisch",
    "orientalischeres": "orientalisch",
    "orientalisches": "orientalisch",
    "orientalischste": "orientalisch",
    "orientalischstem": "orientalisch",
    "orientalischsten": "orientalisch",
    "orientalischster": "orientalisch",
    "orientalischstes": "orientalisch",
    "orientiere": "orientieren",
    "orientierend": "orientieren",
    "orientierende": "orientierend",
    "orientierendem": "orientierend",
    "orientierenden": "orientierend",
    "orientierender": "orientierend",
    "orientierendes": "orientierend",
    "orientierest": "orientieren",
    "orientieret": "orientieren",
    "orientierst": "orientieren",
    "orientiert": "orientieren",
    "orientierte": "orientieren",
    "orientiertem": "orientiert",
    "orientierten": "orientieren",
    "orientierter": "orientiert",
    "orientiertes": "orientiert",
    "orientiertest": "orientieren",
    "orientiertet": "orientieren",
    "originalem": "original",
    "originalen": "original",
    "originaler": "original",
    "originales": "original",
    "originelle": "originell",
    "originellem": "originell",
    "originellen": "originell",
    "origineller": "originell",
    "originellere": "originell",
    "originellerem": "originell",
    "originelleren": "originell",
    "originellerer": "originell",
    "originelleres": "originell",
    "originelles": "originell",
    "originellste": "originell",
    "originellstem": "originell",
    "originellsten": "originell",
    "originellster": "originell",
    "originellstes": "originell",
    "originärem": "originär",
    "originären": "originär",
    "originärer": "originär",
    "originäres": "originär",
    "ornamentalem": "ornamental",
    "ornamentalen": "ornamental",
    "ornamentaler": "ornamental",
    "ornamentales": "ornamental",
    "ornithologischem": "ornithologisch",
    "ornithologischen": "ornithologisch",
    "ornithologischer": "ornithologisch",
    "ornithologisches": "ornithologisch",
    "ortend": "orten",
    "ortende": "ortend",
    "ortendem": "ortend",
    "ortenden": "ortend",
    "ortender": "ortend",
    "ortendes": "ortend",
    "ortest": "orten",
    "ortet": "orten",
    "ortete": "orten",
    "orteten": "orten",
    "ortetest": "orten",
    "ortetet": "orten",
    "orthodoxe": "orthodox",
    "orthodoxem": "orthodox",
    "orthodoxen": "orthodox",
    "orthodoxer": "orthodox",
    "orthodoxes": "orthodox",
    "orthogonale": "orthogonal",
    "orthogonalem": "orthogonal",
    "orthogonalen": "orthogonal",
    "orthogonaler": "orthogonal",
    "orthogonales": "orthogonal",
    "orthographischem": "orthographisch",
    "orthographischen": "orthographisch",
    "orthographischer": "orthographisch",
    "orthographisches": "orthographisch",
    "orthopädischem": "orthopädisch",
    "orthopädischen": "orthopädisch",
    "orthopädischer": "orthopädisch",
    "orthopädischere": "orthopädisch",
    "orthopädischerem": "orthopädisch",
    "orthopädischeren": "orthopädisch",
    "orthopädischerer": "orthopädisch",
    "orthopädischeres": "orthopädisch",
    "orthopädisches": "orthopädisch",
    "orthopädischste": "orthopädisch",
    "orthopädischstem": "orthopädisch",
    "orthopädischsten": "orthopädisch",
    "orthopädischster": "orthopädisch",
    "orthopädischstes": "orthopädisch",
    "ortsansässigem": "ortsansässig",
    "ortsansässigen": "ortsansässig",
    "ortsansässiger": "ortsansässig",
    "ortsansässiges": "ortsansässig",
    "ortsbewegliche": "ortsbeweglich",
    "ortsbeweglichem": "ortsbeweglich",
    "ortsbeweglichen": "ortsbeweglich",
    "ortsbeweglicher": "ortsbeweglich",
    "ortsbewegliches": "ortsbeweglich",
    "ortsfestem": "ortsfest",
    "ortsfesten": "ortsfest",
    "ortsfester": "ortsfest",
    "ortsfestes": "ortsfest",
    "ortsfremde": "ortsfremd",
    "ortsfremdem": "ortsfremd",
    "ortsfremden": "ortsfremd",
    "ortsfremder": "ortsfremd",
    "ortsfremdere": "ortsfremd",
    "ortsfremderem": "ortsfremd",
    "ortsfremderen": "ortsfremd",
    "ortsfremderer": "ortsfremd",
    "ortsfremderes": "ortsfremd",
    "ortsfremdes": "ortsfremd",
    "ortsfremdeste": "ortsfremd",
    "ortsfremdestem": "ortsfremd",
    "ortsfremdesten": "ortsfremd",
    "ortsfremdester": "ortsfremd",
    "ortsfremdestes": "ortsfremd",
    "ortskundige": "ortskundig",
    "ortskundigem": "ortskundig",
    "ortskundigen": "ortskundig",
    "ortskundiger": "ortskundig",
    "ortskundigere": "ortskundig",
    "ortskundigerem": "ortskundig",
    "ortskundigeren": "ortskundig",
    "ortskundigerer": "ortskundig",
    "ortskundigeres": "ortskundig",
    "ortskundiges": "ortskundig",
    "ortskundigste": "ortskundig",
    "ortskundigstem": "ortskundig",
    "ortskundigsten": "ortskundig",
    "ortskundigster": "ortskundig",
    "ortskundigstes": "ortskundig",
    "ortsübliche": "ortsüblich",
    "ortsüblichem": "ortsüblich",
    "ortsüblichen": "ortsüblich",
    "ortsüblicher": "ortsüblich",
    "ortsübliches": "ortsüblich",
    "osmanischem": "osmanisch",
    "osmanischen": "osmanisch",
    "osmanischer": "osmanisch",
    "osmanisches": "osmanisch",
    "ostdeutschem": "ostdeutsch",
    "ostdeutschen": "ostdeutsch",
    "ostdeutscher": "ostdeutsch",
    "ostdeutsches": "ostdeutsch",
    "osteuropäischem": "osteuropäisch",
    "osteuropäischen": "osteuropäisch",
    "osteuropäischer": "osteuropäisch",
    "osteuropäisches": "osteuropäisch",
    "ostmitteldeutschem": "ostmitteldeutsch",
    "ostmitteldeutschen": "ostmitteldeutsch",
    "ostmitteldeutscher": "ostmitteldeutsch",
    "ostmitteldeutsches": "ostmitteldeutsch",
    "oszilliere": "oszillieren",
    "oszillierend": "oszillieren",
    "oszillierende": "oszillierend",
    "oszillierendem": "oszillierend",
    "oszillierenden": "oszillierend",
    "oszillierender": "oszillierend",
    "oszillierendes": "oszillierend",
    "oszillierest": "oszillieren",
    "oszillieret": "oszillieren",
    "oszillierst": "oszillieren",
    "oszilliert": "oszillieren",
    "oszillierte": "oszillieren",
    "oszilliertem": "oszilliert",
    "oszillierten": "oszillieren",
    "oszillierter": "oszilliert",
    "oszilliertes": "oszilliert",
    "oszilliertest": "oszillieren",
    "oszilliertet": "oszillieren",
    "oxidiere": "oxidieren",
    "oxidierend": "oxidieren",
    "oxidierende": "oxidierend",
    "oxidierendem": "oxidierend",
    "oxidierenden": "oxidierend",
    "oxidierender": "oxidierend",
    "oxidierendes": "oxidierend",
    "oxidierest": "oxidieren",
    "oxidieret": "oxidieren",
    "oxidierst": "oxidieren",
    "oxidiert": "oxidieren",
    "oxidierte": "oxidieren",
    "oxidiertem": "oxidiert",
    "oxidierten": "oxidieren",
    "oxidierter": "oxidiert",
    "oxidiertes": "oxidiert",
    "oxidiertest": "oxidieren",
    "oxidiertet": "oxidieren",
    "ozonisiere": "ozonisieren",
    "ozonisierend": "ozonisieren",
    "ozonisierende": "ozonisierend",
    "ozonisierendem": "ozonisierend",
    "ozonisierenden": "ozonisierend",
    "ozonisierender": "ozonisierend",
    "ozonisierendes": "ozonisierend",
    "ozonisierest": "ozonisieren",
    "ozonisieret": "ozonisieren",
    "ozonisierst": "ozonisieren",
    "ozonisiert": "ozonisieren",
    "ozonisierte": "ozonisieren",
    "ozonisiertem": "ozonisiert",
    "ozonisierten": "ozonisieren",
    "ozonisierter": "ozonisiert",
    "ozonisiertes": "ozonisiert",
    "ozonisiertest": "ozonisieren",
    "ozonisiertet": "ozonisieren",
    "paarend": "paaren",
    "paarende": "paarend",
    "paarendem": "paarend",
    "paarenden": "paarend",
    "paarender": "paarend",
    "paarendes": "paarend",
    "paarest": "paaren",
    "paaret": "paaren",
    "paarst": "paaren",
    "paart": "paaren",
    "paarte": "paaren",
    "paarten": "paaren",
    "paartest": "paaren",
    "paartet": "paaren",
    "paarweisem": "paarweise",
    "paarweisen": "paarweise",
    "paarweiser": "paarweise",
    "paarweises": "paarweise",
    "pachte": "pachten",
    "pachtend": "pachten",
    "pachtende": "pachtend",
    "pachtendem": "pachtend",
    "pachtenden": "pachtend",
    "pachtender": "pachtend",
    "pachtendes": "pachtend",
    "pachtest": "pachten",
    "pachtet": "pachten",
    "pachtete": "pachten",
    "pachteten": "pachten",
    "pachtetest": "pachten",
    "pachtetet": "pachten",
    "packe": "packen",
    "packend": "packen",
    "packende": "packend",
    "packendem": "packend",
    "packenden": "packend",
    "packender": "packend",
    "packendere": "packend",
    "packenderem": "packend",
    "packenderen": "packend",
    "packenderer": "packend",
    "packenderes": "packend",
    "packendes": "packend",
    "packendste": "packend",
    "packendstem": "packend",
    "packendsten": "packend",
    "packendster": "packend",
    "packendstes": "packend",
    "packest": "packen",
    "packet": "packen",
    "packst": "packen",
    "packt": "packen",
    "packte": "packen",
    "packten": "packen",
    "packtest": "packen",
    "packtet": "packen",
    "paddele": "paddeln",
    "paddelnd": "paddeln",
    "paddelnde": "paddelnd",
    "paddelndem": "paddelnd",
    "paddelnden": "paddelnd",
    "paddelnder": "paddelnd",
    "paddelndes": "paddelnd",
    "paddelst": "paddeln",
    "paddelt": "paddeln",
    "paddelte": "paddeln",
    "paddelten": "paddeln",
    "paddeltest": "paddeln",
    "paddeltet": "paddeln",
    "paddle": "paddeln",
    "paffe": "paffen",
    "paffend": "paffen",
    "paffende": "paffend",
    "paffendem": "paffend",
    "paffenden": "paffend",
    "paffender": "paffend",
    "paffendes": "paffend",
    "paffest": "paffen",
    "paffet": "paffen",
    "paffst": "paffen",
    "pafft": "paffen",
    "paffte": "paffen",
    "pafften": "paffen",
    "pafftest": "paffen",
    "pafftet": "paffen",
    "pakistanischem": "pakistanisch",
    "pakistanischen": "pakistanisch",
    "pakistanischer": "pakistanisch",
    "pakistanisches": "pakistanisch",
    "palästinensischem": "palästinensisch",
    "palästinensischen": "palästinensisch",
    "palästinensischer": "palästinensisch",
    "palästinensisches": "palästinensisch",
    "pampigem": "pampig",
    "pampigen": "pampig",
    "pampiger": "pampig",
    "pampigere": "pampig",
    "pampigerem": "pampig",
    "pampigeren": "pampig",
    "pampigerer": "pampig",
    "pampigeres": "pampig",
    "pampiges": "pampig",
    "pampigste": "pampig",
    "pampigstem": "pampig",
    "pampigsten": "pampig",
    "pampigster": "pampig",
    "pampigstes": "pampig",
    "paniere": "panieren",
    "panierend": "panieren",
    "panierende": "panierend",
    "panierendem": "panierend",
    "panierenden": "panierend",
    "panierender": "panierend",
    "panierendes": "panierend",
    "panierest": "panieren",
    "panieret": "panieren",
    "panierst": "panieren",
    "paniert": "panieren",
    "panierte": "panieren",
    "paniertem": "paniert",
    "panierten": "panieren",
    "panierter": "paniert",
    "paniertes": "paniert",
    "paniertest": "panieren",
    "paniertet": "panieren",
    "panischem": "panisch",
    "panischen": "panisch",
    "panischer": "panisch",
    "panischere": "panisch",
    "panischerem": "panisch",
    "panischeren": "panisch",
    "panischerer": "panisch",
    "panischeres": "panisch",
    "panisches": "panisch",
    "panischste": "panisch",
    "panischstem": "panisch",
    "panischsten": "panisch",
    "panischster": "panisch",
    "panischstes": "panisch",
    "pansche": "panschen",
    "panschend": "panschen",
    "panschende": "panschend",
    "panschendem": "panschend",
    "panschenden": "panschend",
    "panschender": "panschend",
    "panschendere": "panschend",
    "panschenderem": "panschend",
    "panschenderen": "panschend",
    "panschenderer": "panschend",
    "panschenderes": "panschend",
    "panschendes": "panschend",
    "panschendste": "panschend",
    "panschendstem": "panschend",
    "panschendsten": "panschend",
    "panschendster": "panschend",
    "panschendstes": "panschend",
    "panschest": "panschen",
    "panschet": "panschen",
    "panschst": "panschen",
    "panscht": "panschen",
    "panschte": "panschen",
    "panschten": "panschen",
    "panschtest": "panschen",
    "panschtet": "panschen",
    "pantomimischem": "pantomimisch",
    "pantomimischen": "pantomimisch",
    "pantomimischer": "pantomimisch",
    "pantomimisches": "pantomimisch",
    "pantsche": "pantschen",
    "pantschend": "pantschen",
    "pantschende": "pantschend",
    "pantschendem": "pantschend",
    "pantschenden": "pantschend",
    "pantschender": "pantschend",
    "pantschendes": "pantschend",
    "pantschest": "pantschen",
    "pantschet": "pantschen",
    "pantschst": "pantschen",
    "pantscht": "pantschen",
    "pantschte": "pantschen",
    "pantschten": "pantschen",
    "pantschtest": "pantschen",
    "pantschtet": "pantschen",
    "panzere": "panzern",
    "panzernd": "panzern",
    "panzernde": "panzernd",
    "panzerndem": "panzernd",
    "panzernden": "panzernd",
    "panzernder": "panzernd",
    "panzerndere": "panzernd",
    "panzernderem": "panzernd",
    "panzernderen": "panzernd",
    "panzernderer": "panzernd",
    "panzernderes": "panzernd",
    "panzerndes": "panzernd",
    "panzerndste": "panzernd",
    "panzerndstem": "panzernd",
    "panzerndsten": "panzernd",
    "panzerndster": "panzernd",
    "panzerndstes": "panzernd",
    "panzerst": "panzern",
    "panzert": "panzern",
    "panzerte": "panzern",
    "panzerten": "panzern",
    "panzertest": "panzern",
    "panzertet": "panzern",
    "papierenem": "papieren",
    "papierenen": "papieren",
    "papierener": "papieren",
    "papierenes": "papieren",
    "papillarem": "papillar",
    "papillaren": "papillar",
    "papillarer": "papillar",
    "papillares": "papillar",
    "pappend": "pappen",
    "pappende": "pappend",
    "pappendem": "pappend",
    "pappenden": "pappend",
    "pappender": "pappend",
    "pappendes": "pappend",
    "pappest": "pappen",
    "pappet": "pappen",
    "pappige": "pappig",
    "pappigem": "pappig",
    "pappigen": "pappig",
    "pappiger": "pappig",
    "pappigere": "pappig",
    "pappigerem": "pappig",
    "pappigeren": "pappig",
    "pappigerer": "pappig",
    "pappigeres": "pappig",
    "pappiges": "pappig",
    "pappigste": "pappig",
    "pappigstem": "pappig",
    "pappigsten": "pappig",
    "pappigster": "pappig",
    "pappigstes": "pappig",
    "pappsattem": "pappsatt",
    "pappsatten": "pappsatt",
    "pappsatter": "pappsatt",
    "pappsattes": "pappsatt",
    "pappst": "pappen",
    "pappt": "pappen",
    "pappte": "pappen",
    "pappten": "pappen",
    "papptest": "pappen",
    "papptet": "pappen",
    "parabolischem": "parabolisch",
    "parabolischen": "parabolisch",
    "parabolischer": "parabolisch",
    "parabolisches": "parabolisch",
    "parabolisiere": "parabolisieren",
    "parabolisierend": "parabolisieren",
    "parabolisierende": "parabolisierend",
    "parabolisierendem": "parabolisierend",
    "parabolisierenden": "parabolisierend",
    "parabolisierender": "parabolisierend",
    "parabolisierendes": "parabolisierend",
    "parabolisierest": "parabolisieren",
    "parabolisieret": "parabolisieren",
    "parabolisierst": "parabolisieren",
    "parabolisiert": "parabolisieren",
    "parabolisierte": "parabolisieren",
    "parabolisiertem": "parabolisiert",
    "parabolisierten": "parabolisieren",
    "parabolisierter": "parabolisiert",
    "parabolisiertes": "parabolisiert",
    "parabolisiertest": "parabolisieren",
    "parabolisiertet": "parabolisieren",
    "paradiesischem": "paradiesisch",
    "paradiesischen": "paradiesisch",
    "paradiesischer": "paradiesisch",
    "paradiesisches": "paradiesisch",
    "paradigmatischem": "paradigmatisch",
    "paradigmatischen": "paradigmatisch",
    "paradigmatischer": "paradigmatisch",
    "paradigmatisches": "paradigmatisch",
    "paradoxem": "paradox",
    "paradoxen": "paradox",
    "paradoxer": "paradox",
    "paradoxere": "paradox",
    "paradoxerem": "paradox",
    "paradoxeren": "paradox",
    "paradoxerer": "paradox",
    "paradoxeres": "paradox",
    "paradoxes": "paradox",
    "paradoxeste": "paradox",
    "paradoxestem": "paradox",
    "paradoxesten": "paradox",
    "paradoxester": "paradox",
    "paradoxestes": "paradox",
    "paragraphiere": "paragraphieren",
    "paragraphierend": "paragraphieren",
    "paragraphierende": "paragraphierend",
    "paragraphierendem": "paragraphierend",
    "paragraphierenden": "paragraphierend",
    "paragraphierender": "paragraphierend",
    "paragraphierendes": "paragraphierend",
    "paragraphierest": "paragraphieren",
    "paragraphieret": "paragraphieren",
    "paragraphierst": "paragraphieren",
    "paragraphiert": "paragraphieren",
    "paragraphierte": "paragraphieren",
    "paragraphiertem": "paragraphiert",
    "paragraphierten": "paragraphieren",
    "paragraphierter": "paragraphiert",
    "paragraphiertes": "paragraphiert",
    "paragraphiertest": "paragraphieren",
    "paragraphiertet": "paragraphieren",
    "parallelgeschaltet": "parallelschalten",
    "parallelgeschaltete": "parallelgeschaltet",
    "parallelgeschaltetem": "parallelgeschaltet",
    "parallelgeschalteten": "parallelgeschaltet",
    "parallelgeschalteter": "parallelgeschaltet",
    "parallelgeschaltetes": "parallelgeschaltet",
    "parallelschalte": "parallelschalten",
    "parallelschaltend": "parallelschalten",
    "parallelschaltende": "parallelschaltend",
    "parallelschaltendem": "parallelschaltend",
    "parallelschaltenden": "parallelschaltend",
    "parallelschaltender": "parallelschaltend",
    "parallelschaltendes": "parallelschaltend",
    "parallelschaltest": "parallelschalten",
    "parallelschaltet": "parallelschalten",
    "parallelschaltete": "parallelschalten",
    "parallelschalteten": "parallelschalten",
    "parallelschaltetest": "parallelschalten",
    "parallelschaltetet": "parallelschalten",
    "parallelzuschalten": "parallelschalten",
    "paralysiere": "paralysieren",
    "paralysierend": "paralysieren",
    "paralysierende": "paralysierend",
    "paralysierendem": "paralysierend",
    "paralysierenden": "paralysierend",
    "paralysierender": "paralysierend",
    "paralysierendere": "paralysierend",
    "paralysierenderem": "paralysierend",
    "paralysierenderen": "paralysierend",
    "paralysierenderer": "paralysierend",
    "paralysierenderes": "paralysierend",
    "paralysierendes": "paralysierend",
    "paralysierendste": "paralysierend",
    "paralysierendstem": "paralysierend",
    "paralysierendsten": "paralysierend",
    "paralysierendster": "paralysierend",
    "paralysierendstes": "paralysierend",
    "paralysierest": "paralysieren",
    "paralysieret": "paralysieren",
    "paralysierst": "paralysieren",
    "paralysiert": "paralysieren",
    "paralysierte": "paralysieren",
    "paralysiertem": "paralysiert",
    "paralysierten": "paralysieren",
    "paralysierter": "paralysiert",
    "paralysiertere": "paralysiert",
    "paralysierterem": "paralysiert",
    "paralysierteren": "paralysiert",
    "paralysierterer": "paralysiert",
    "paralysierteres": "paralysiert",
    "paralysiertes": "paralysiert",
    "paralysiertest": "paralysieren",
    "paralysierteste": "paralysiert",
    "paralysiertestem": "paralysiert",
    "paralysiertesten": "paralysiert",
    "paralysiertester": "paralysiert",
    "paralysiertestes": "paralysiert",
    "paralysiertet": "paralysieren",
    "paralytische": "paralytisch",
    "paralytischem": "paralytisch",
    "paralytischen": "paralytisch",
    "paralytischer": "paralytisch",
    "paralytisches": "paralytisch",
    "paramilitärischem": "paramilitärisch",
    "paramilitärischen": "paramilitärisch",
    "paramilitärischer": "paramilitärisch",
    "paramilitärisches": "paramilitärisch",
    "paranoide": "paranoid",
    "paranoidem": "paranoid",
    "paranoiden": "paranoid",
    "paranoider": "paranoid",
    "paranoidere": "paranoid",
    "paranoiderem": "paranoid",
    "paranoideren": "paranoid",
    "paranoiderer": "paranoid",
    "paranoideres": "paranoid",
    "paranoides": "paranoid",
    "paranoideste": "paranoid",
    "paranoidestem": "paranoid",
    "paranoidesten": "paranoid",
    "paranoidester": "paranoid",
    "paranoidestes": "paranoid",
    "paraphrasiere": "paraphrasieren",
    "paraphrasierend": "paraphrasieren",
    "paraphrasierende": "paraphrasierend",
    "paraphrasierendem": "paraphrasierend",
    "paraphrasierenden": "paraphrasierend",
    "paraphrasierender": "paraphrasierend",
    "paraphrasierendes": "paraphrasierend",
    "paraphrasierest": "paraphrasieren",
    "paraphrasieret": "paraphrasieren",
    "paraphrasierst": "paraphrasieren",
    "paraphrasiert": "paraphrasieren",
    "paraphrasierte": "paraphrasieren",
    "paraphrasiertem": "paraphrasiert",
    "paraphrasierten": "paraphrasieren",
    "paraphrasierter": "paraphrasiert",
    "paraphrasiertes": "paraphrasiert",
    "paraphrasiertest": "paraphrasieren",
    "paraphrasiertet": "paraphrasieren",
    "parasitischem": "parasitisch",
    "parasitischen": "parasitisch",
    "parasitischer": "parasitisch",
    "parasitischere": "parasitisch",
    "parasitischerem": "parasitisch",
    "parasitischeren": "parasitisch",
    "parasitischerer": "parasitisch",
    "parasitischeres": "parasitisch",
    "parasitisches": "parasitisch",
    "parasitischste": "parasitisch",
    "parasitischstem": "parasitisch",
    "parasitischsten": "parasitisch",
    "parasitischster": "parasitisch",
    "parasitischstes": "parasitisch",
    "parasitäre": "parasitär",
    "parasitärem": "parasitär",
    "parasitären": "parasitär",
    "parasitärer": "parasitär",
    "parasitärere": "parasitär",
    "parasitärerem": "parasitär",
    "parasitäreren": "parasitär",
    "parasitärerer": "parasitär",
    "parasitäreres": "parasitär",
    "parasitäres": "parasitär",
    "parasitärste": "parasitär",
    "parasitärstem": "parasitär",
    "parasitärsten": "parasitär",
    "parasitärster": "parasitär",
    "parasitärstes": "parasitär",
    "paratem": "parat",
    "paraten": "parat",
    "parater": "parat",
    "paratere": "parat",
    "paraterem": "parat",
    "parateren": "parat",
    "paraterer": "parat",
    "parateres": "parat",
    "parates": "parat",
    "parateste": "parat",
    "paratestem": "parat",
    "paratesten": "parat",
    "paratester": "parat",
    "paratestes": "parat",
    "parentalem": "parental",
    "parentalen": "parental",
    "parentaler": "parental",
    "parentales": "parental",
    "parfümiere": "parfümieren",
    "parfümierend": "parfümieren",
    "parfümierende": "parfümierend",
    "parfümierendem": "parfümierend",
    "parfümierenden": "parfümierend",
    "parfümierender": "parfümierend",
    "parfümierendere": "parfümierend",
    "parfümierenderem": "parfümierend",
    "parfümierenderen": "parfümierend",
    "parfümierenderer": "parfümierend",
    "parfümierenderes": "parfümierend",
    "parfümierendes": "parfümierend",
    "parfümierendste": "parfümierend",
    "parfümierendstem": "parfümierend",
    "parfümierendsten": "parfümierend",
    "parfümierendster": "parfümierend",
    "parfümierendstes": "parfümierend",
    "parfümierest": "parfümieren",
    "parfümieret": "parfümieren",
    "parfümierst": "parfümieren",
    "parfümiert": "parfümieren",
    "parfümierte": "parfümieren",
    "parfümiertem": "parfümiert",
    "parfümierten": "parfümieren",
    "parfümierter": "parfümiert",
    "parfümiertere": "parfümiert",
    "parfümierterem": "parfümiert",
    "parfümierteren": "parfümiert",
    "parfümierterer": "parfümiert",
    "parfümierteres": "parfümiert",
    "parfümiertes": "parfümiert",
    "parfümiertest": "parfümieren",
    "parfümierteste": "parfümiert",
    "parfümiertestem": "parfümiert",
    "parfümiertesten": "parfümiert",
    "parfümiertester": "parfümiert",
    "parfümiertestes": "parfümiert",
    "parfümiertet": "parfümieren",
    "pariere": "parieren",
    "parierend": "parieren",
    "parierende": "parierend",
    "parierendem": "parierend",
    "parierenden": "parierend",
    "parierender": "parierend",
    "parierendes": "parierend",
    "parierest": "parieren",
    "parieret": "parieren",
    "parierst": "parieren",
    "pariert": "parieren",
    "parierte": "parieren",
    "pariertem": "pariert",
    "parierten": "parieren",
    "parierter": "pariert",
    "pariertes": "pariert",
    "pariertest": "parieren",
    "pariertet": "parieren",
    "paritätischem": "paritätisch",
    "paritätischen": "paritätisch",
    "paritätischer": "paritätisch",
    "paritätisches": "paritätisch",
    "parke": "parken",
    "parkend": "parken",
    "parkende": "parkend",
    "parkendem": "parkend",
    "parkenden": "parkend",
    "parkender": "parkend",
    "parkendes": "parkend",
    "parkest": "parken",
    "parket": "parken",
    "parkettiere": "parkettieren",
    "parkettierend": "parkettieren",
    "parkettierende": "parkettierend",
    "parkettierendem": "parkettierend",
    "parkettierenden": "parkettierend",
    "parkettierender": "parkettierend",
    "parkettierendes": "parkettierend",
    "parkettierest": "parkettieren",
    "parkettieret": "parkettieren",
    "parkettierst": "parkettieren",
    "parkettiert": "parkettieren",
    "parkettierte": "parkettieren",
    "parkettiertem": "parkettiert",
    "parkettierten": "parkettieren",
    "parkettierter": "parkettiert",
    "parkettiertes": "parkettiert",
    "parkettiertest": "parkettieren",
    "parkettiertet": "parkettieren",
    "parkst": "parken",
    "parkt": "parken",
    "parkte": "parken",
    "parkten": "parken",
    "parktest": "parken",
    "parktet": "parken",
    "parlamentarischem": "parlamentarisch",
    "parlamentarischen": "parlamentarisch",
    "parlamentarischer": "parlamentarisch",
    "parlamentarisches": "parlamentarisch",
    "parse": "parsen",
    "parsend": "parsen",
    "parsende": "parsend",
    "parsendem": "parsend",
    "parsenden": "parsend",
    "parsender": "parsend",
    "parsendes": "parsend",
    "parsest": "parsen",
    "parset": "parsen",
    "parst": "parsen",
    "parste": "parsen",
    "parsten": "parsen",
    "parstest": "parsen",
    "parstet": "parsen",
    "parteiinternem": "parteiintern",
    "parteiinternen": "parteiintern",
    "parteiinterner": "parteiintern",
    "parteiinternes": "parteiintern",
    "parteiische": "parteiisch",
    "parteiischem": "parteiisch",
    "parteiischen": "parteiisch",
    "parteiischer": "parteiisch",
    "parteiischere": "parteiisch",
    "parteiischerem": "parteiisch",
    "parteiischeren": "parteiisch",
    "parteiischerer": "parteiisch",
    "parteiischeres": "parteiisch",
    "parteiisches": "parteiisch",
    "parteiischste": "parteiisch",
    "parteiischstem": "parteiisch",
    "parteiischsten": "parteiisch",
    "parteiischster": "parteiisch",
    "parteiischstes": "parteiisch",
    "parteiliche": "parteilich",
    "parteilichem": "parteilich",
    "parteilichen": "parteilich",
    "parteilicher": "parteilich",
    "parteilichere": "parteilich",
    "parteilicherem": "parteilich",
    "parteilicheren": "parteilich",
    "parteilicherer": "parteilich",
    "parteilicheres": "parteilich",
    "parteiliches": "parteilich",
    "parteilichste": "parteilich",
    "parteilichstem": "parteilich",
    "parteilichsten": "parteilich",
    "parteilichster": "parteilich",
    "parteilichstes": "parteilich",
    "parteilose": "parteilos",
    "parteilosem": "parteilos",
    "parteilosen": "parteilos",
    "parteiloser": "parteilos",
    "parteiloses": "parteilos",
    "partikularem": "partikular",
    "partikularen": "partikular",
    "partikularer": "partikular",
    "partikulares": "partikular",
    "partikularistische": "partikularistisch",
    "partikularistischem": "partikularistisch",
    "partikularistischen": "partikularistisch",
    "partikularistischer": "partikularistisch",
    "partikularistischere": "partikularistisch",
    "partikularistischerem": "partikularistisch",
    "partikularistischeren": "partikularistisch",
    "partikularistischerer": "partikularistisch",
    "partikularistischeres": "partikularistisch",
    "partikularistisches": "partikularistisch",
    "partikularistischste": "partikularistisch",
    "partikularistischstem": "partikularistisch",
    "partikularistischsten": "partikularistisch",
    "partikularistischster": "partikularistisch",
    "partikularistischstes": "partikularistisch",
    "partizipierend": "partizipieren",
    "partizipierende": "partizipierend",
    "partizipierendem": "partizipierend",
    "partizipierenden": "partizipierend",
    "partizipierender": "partizipierend",
    "partizipierendere": "partizipierend",
    "partizipierenderem": "partizipierend",
    "partizipierenderen": "partizipierend",
    "partizipierenderer": "partizipierend",
    "partizipierenderes": "partizipierend",
    "partizipierendes": "partizipierend",
    "partizipierendste": "partizipierend",
    "partizipierendstem": "partizipierend",
    "partizipierendsten": "partizipierend",
    "partizipierendster": "partizipierend",
    "partizipierendstes": "partizipierend",
    "partizipierest": "partizipieren",
    "partizipieret": "partizipieren",
    "partizipierst": "partizipieren",
    "partizipiert": "partizipieren",
    "partizipierte": "partizipieren",
    "partizipiertem": "partizipiert",
    "partizipierten": "partizipieren",
    "partizipierter": "partizipiert",
    "partizipiertere": "partizipiert",
    "partizipierterem": "partizipiert",
    "partizipierteren": "partizipiert",
    "partizipierterer": "partizipiert",
    "partizipierteres": "partizipiert",
    "partizipiertes": "partizipiert",
    "partizipiertest": "partizipieren",
    "partizipierteste": "partizipiert",
    "partizipiertestem": "partizipiert",
    "partizipiertesten": "partizipiert",
    "partizipiertester": "partizipiert",
    "partizipiertestes": "partizipiert",
    "partizipiertet": "partizipieren",
    "parzelliere": "parzellieren",
    "parzellierend": "parzellieren",
    "parzellierende": "parzellierend",
    "parzellierendem": "parzellierend",
    "parzellierenden": "parzellierend",
    "parzellierender": "parzellierend",
    "parzellierendere": "parzellierend",
    "parzellierenderem": "parzellierend",
    "parzellierenderen": "parzellierend",
    "parzellierenderer": "parzellierend",
    "parzellierenderes": "parzellierend",
    "parzellierendes": "parzellierend",
    "parzellierendste": "parzellierend",
    "parzellierendstem": "parzellierend",
    "parzellierendsten": "parzellierend",
    "parzellierendster": "parzellierend",
    "parzellierendstes": "parzellierend",
    "parzellierest": "parzellieren",
    "parzellieret": "parzellieren",
    "parzellierst": "parzellieren",
    "parzelliert": "parzellieren",
    "parzellierte": "parzellieren",
    "parzelliertem": "parzelliert",
    "parzellierten": "parzellieren",
    "parzellierter": "parzelliert",
    "parzelliertere": "parzelliert",
    "parzellierterem": "parzelliert",
    "parzellierteren": "parzelliert",
    "parzellierterer": "parzelliert",
    "parzellierteres": "parzelliert",
    "parzelliertes": "parzelliert",
    "parzelliertest": "parzellieren",
    "parzellierteste": "parzelliert",
    "parzelliertestem": "parzelliert",
    "parzelliertesten": "parzelliert",
    "parzelliertester": "parzelliert",
    "parzelliertestes": "parzelliert",
    "parzelliertet": "parzellieren",
    "passabelstem": "passabel",
    "passabelsten": "passabel",
    "passabelster": "passabel",
    "passabelstes": "passabel",
    "passable": "passabel",
    "passablem": "passabel",
    "passablen": "passabel",
    "passabler": "passabel",
    "passablere": "passabel",
    "passablerem": "passabel",
    "passableren": "passabel",
    "passablerer": "passabel",
    "passableres": "passabel",
    "passables": "passabel",
    "passend": "passen",
    "passende": "passend",
    "passendem": "passend",
    "passenden": "passend",
    "passender": "passend",
    "passendes": "passend",
    "passest": "passen",
    "passet": "passen",
    "passierbare": "passierbar",
    "passierbarem": "passierbar",
    "passierbaren": "passierbar",
    "passierbarer": "passierbar",
    "passierbarere": "passierbar",
    "passierbarerem": "passierbar",
    "passierbareren": "passierbar",
    "passierbarerer": "passierbar",
    "passierbareres": "passierbar",
    "passierbares": "passierbar",
    "passierbarste": "passierbar",
    "passierbarstem": "passierbar",
    "passierbarsten": "passierbar",
    "passierbarster": "passierbar",
    "passierbarstes": "passierbar",
    "passiere": "passieren",
    "passierend": "passieren",
    "passierende": "passierend",
    "passierendem": "passierend",
    "passierenden": "passierend",
    "passierender": "passierend",
    "passierendes": "passierend",
    "passierest": "passieren",
    "passieret": "passieren",
    "passierst": "passieren",
    "passiert": "passieren",
    "passierte": "passieren",
    "passiertem": "passiert",
    "passierten": "passieren",
    "passierter": "passiert",
    "passiertes": "passiert",
    "passiertest": "passieren",
    "passiertet": "passieren",
    "passioniertem": "passioniert",
    "passionierten": "passioniert",
    "passionierter": "passioniert",
    "passioniertere": "passioniert",
    "passionierterem": "passioniert",
    "passionierteren": "passioniert",
    "passionierterer": "passioniert",
    "passionierteres": "passioniert",
    "passioniertes": "passioniert",
    "passionierteste": "passioniert",
    "passioniertestem": "passioniert",
    "passioniertesten": "passioniert",
    "passioniertester": "passioniert",
    "passioniertestes": "passioniert",
    "passivem": "passiv",
    "passiven": "passiv",
    "passiver": "passiv",
    "passivere": "passiv",
    "passiverem": "passiv",
    "passiveren": "passiv",
    "passiverer": "passiv",
    "passiveres": "passiv",
    "passives": "passiv",
    "passivstem": "passiv",
    "passivsten": "passiv",
    "passivster": "passiv",
    "passivstes": "passiv",
    "pastoralem": "pastoral",
    "pastoralen": "pastoral",
    "pastoraler": "pastoral",
    "pastorales": "pastoral",
    "patentem": "patent",
    "patenten": "patent",
    "patenter": "patent",
    "patentere": "patent",
    "patenterem": "patent",
    "patenteren": "patent",
    "patenterer": "patent",
    "patenteres": "patent",
    "patentes": "patent",
    "patentestem": "patent",
    "patentesten": "patent",
    "patentester": "patent",
    "patentestes": "patent",
    "patentiere": "patentieren",
    "patentierend": "patentieren",
    "patentierende": "patentierend",
    "patentierendem": "patentierend",
    "patentierenden": "patentierend",
    "patentierender": "patentierend",
    "patentierendes": "patentierend",
    "patentierest": "patentieren",
    "patentieret": "patentieren",
    "patentierst": "patentieren",
    "patentiert": "patentieren",
    "patentierte": "patentieren",
    "patentiertem": "patentiert",
    "patentierten": "patentieren",
    "patentierter": "patentiert",
    "patentiertes": "patentiert",
    "patentiertest": "patentieren",
    "patentiertet": "patentieren",
    "pathetischem": "pathetisch",
    "pathetischen": "pathetisch",
    "pathetischer": "pathetisch",
    "pathetischere": "pathetisch",
    "pathetischerem": "pathetisch",
    "pathetischeren": "pathetisch",
    "pathetischerer": "pathetisch",
    "pathetischeres": "pathetisch",
    "pathetisches": "pathetisch",
    "pathetischste": "pathetisch",
    "pathetischstem": "pathetisch",
    "pathetischsten": "pathetisch",
    "pathetischster": "pathetisch",
    "pathetischstes": "pathetisch",
    "pathologischem": "pathologisch",
    "pathologischen": "pathologisch",
    "pathologischer": "pathologisch",
    "pathologisches": "pathologisch",
    "patriarchischem": "patriarchisch",
    "patriarchischen": "patriarchisch",
    "patriarchischer": "patriarchisch",
    "patriarchisches": "patriarchisch",
    "patsche": "patschen",
    "patschenasse": "patschenaß",
    "patschenassem": "patschenaß",
    "patschenassen": "patschenaß",
    "patschenasser": "patschenaß",
    "patschenasses": "patschenaß",
    "patschend": "patschen",
    "patschende": "patschend",
    "patschendem": "patschend",
    "patschenden": "patschend",
    "patschender": "patschend",
    "patschendes": "patschend",
    "patschest": "patschen",
    "patschet": "patschen",
    "patschnassem": "patschnaß",
    "patschnassen": "patschnaß",
    "patschnasser": "patschnaß",
    "patschnasses": "patschnaß",
    "patschst": "patschen",
    "patscht": "patschen",
    "patschte": "patschen",
    "patschten": "patschen",
    "patschtest": "patschen",
    "patschtet": "patschen",
    "patze": "patzen",
    "patzend": "patzen",
    "patzende": "patzend",
    "patzendem": "patzend",
    "patzenden": "patzend",
    "patzender": "patzend",
    "patzendere": "patzend",
    "patzenderem": "patzend",
    "patzenderen": "patzend",
    "patzenderer": "patzend",
    "patzenderes": "patzend",
    "patzendes": "patzend",
    "patzendste": "patzend",
    "patzendstem": "patzend",
    "patzendsten": "patzend",
    "patzendster": "patzend",
    "patzendstes": "patzend",
    "patzest": "patzen",
    "patzet": "patzen",
    "patzige": "patzig",
    "patzigem": "patzig",
    "patzigen": "patzig",
    "patziger": "patzig",
    "patzigere": "patzig",
    "patzigerem": "patzig",
    "patzigeren": "patzig",
    "patzigerer": "patzig",
    "patzigeres": "patzig",
    "patziges": "patzig",
    "patzigste": "patzig",
    "patzigstem": "patzig",
    "patzigsten": "patzig",
    "patzigster": "patzig",
    "patzigstes": "patzig",
    "patzt": "patzen",
    "patzte": "patzen",
    "patzten": "patzen",
    "patztest": "patzen",
    "patztet": "patzen",
    "pauke": "pauken",
    "paukend": "pauken",
    "paukende": "paukend",
    "paukendem": "paukend",
    "paukenden": "paukend",
    "paukender": "paukend",
    "paukendes": "paukend",
    "paukest": "pauken",
    "pauket": "pauken",
    "paukst": "pauken",
    "paukt": "pauken",
    "paukte": "pauken",
    "paukten": "pauken",
    "pauktest": "pauken",
    "pauktet": "pauken",
    "pauschalem": "pauschal",
    "pauschalen": "pauschal",
    "pauschaler": "pauschal",
    "pauschalere": "pauschal",
    "pauschalerem": "pauschal",
    "pauschaleren": "pauschal",
    "pauschalerer": "pauschal",
    "pauschaleres": "pauschal",
    "pauschales": "pauschal",
    "pauschaliere": "pauschalieren",
    "pauschalierend": "pauschalieren",
    "pauschalierende": "pauschalierend",
    "pauschalierendem": "pauschalierend",
    "pauschalierenden": "pauschalierend",
    "pauschalierender": "pauschalierend",
    "pauschalierendere": "pauschalierend",
    "pauschalierenderem": "pauschalierend",
    "pauschalierenderen": "pauschalierend",
    "pauschalierenderer": "pauschalierend",
    "pauschalierenderes": "pauschalierend",
    "pauschalierendes": "pauschalierend",
    "pauschalierendste": "pauschalierend",
    "pauschalierendstem": "pauschalierend",
    "pauschalierendsten": "pauschalierend",
    "pauschalierendster": "pauschalierend",
    "pauschalierendstes": "pauschalierend",
    "pauschalierest": "pauschalieren",
    "pauschalieret": "pauschalieren",
    "pauschalierst": "pauschalieren",
    "pauschaliert": "pauschalieren",
    "pauschalierte": "pauschalieren",
    "pauschaliertem": "pauschaliert",
    "pauschalierten": "pauschalieren",
    "pauschalierter": "pauschaliert",
    "pauschaliertere": "pauschaliert",
    "pauschalierterem": "pauschaliert",
    "pauschalierteren": "pauschaliert",
    "pauschalierterer": "pauschaliert",
    "pauschalierteres": "pauschaliert",
    "pauschaliertes": "pauschaliert",
    "pauschaliertest": "pauschalieren",
    "pauschalierteste": "pauschaliert",
    "pauschaliertestem": "pauschaliert",
    "pauschaliertesten": "pauschaliert",
    "pauschaliertester": "pauschaliert",
    "pauschaliertestes": "pauschaliert",
    "pauschaliertet": "pauschalieren",
    "pauschalisiere": "pauschalisieren",
    "pauschalisierend": "pauschalisieren",
    "pauschalisierende": "pauschalisierend",
    "pauschalisierendem": "pauschalisierend",
    "pauschalisierenden": "pauschalisierend",
    "pauschalisierender": "pauschalisierend",
    "pauschalisierendere": "pauschalisierend",
    "pauschalisierenderem": "pauschalisierend",
    "pauschalisierenderen": "pauschalisierend",
    "pauschalisierenderer": "pauschalisierend",
    "pauschalisierenderes": "pauschalisierend",
    "pauschalisierendes": "pauschalisierend",
    "pauschalisierendste": "pauschalisierend",
    "pauschalisierendstem": "pauschalisierend",
    "pauschalisierendsten": "pauschalisierend",
    "pauschalisierendster": "pauschalisierend",
    "pauschalisierendstes": "pauschalisierend",
    "pauschalisierest": "pauschalisieren",
    "pauschalisieret": "pauschalisieren",
    "pauschalisierst": "pauschalisieren",
    "pauschalisiert": "pauschalisieren",
    "pauschalisierte": "pauschalisieren",
    "pauschalisiertem": "pauschalisiert",
    "pauschalisierten": "pauschalisieren",
    "pauschalisierter": "pauschalisiert",
    "pauschalisiertere": "pauschalisiert",
    "pauschalisierterem": "pauschalisiert",
    "pauschalisierteren": "pauschalisiert",
    "pauschalisierterer": "pauschalisiert",
    "pauschalisierteres": "pauschalisiert",
    "pauschalisiertes": "pauschalisiert",
    "pauschalisiertest": "pauschalisieren",
    "pauschalisierteste": "pauschalisiert",
    "pauschalisiertestem": "pauschalisiert",
    "pauschalisiertesten": "pauschalisiert",
    "pauschalisiertester": "pauschalisiert",
    "pauschalisiertestes": "pauschalisiert",
    "pauschalisiertet": "pauschalisieren",
    "pauschalste": "pauschal",
    "pauschalstem": "pauschal",
    "pauschalsten": "pauschal",
    "pauschalster": "pauschal",
    "pauschalstes": "pauschal",
    "pausend": "pausen",
    "pausende": "pausend",
    "pausendem": "pausend",
    "pausenden": "pausend",
    "pausender": "pausend",
    "pausendes": "pausend",
    "pausenlose": "pausenlos",
    "pausenlosem": "pausenlos",
    "pausenlosen": "pausenlos",
    "pausenloser": "pausenlos",
    "pausenloses": "pausenlos",
    "pausest": "pausen",
    "pauset": "pausen",
    "pausiere": "pausieren",
    "pausierend": "pausieren",
    "pausierende": "pausierend",
    "pausierendem": "pausierend",
    "pausierenden": "pausierend",
    "pausierender": "pausierend",
    "pausierendes": "pausierend",
    "pausierest": "pausieren",
    "pausieret": "pausieren",
    "pausierst": "pausieren",
    "pausiert": "pausieren",
    "pausierte": "pausieren",
    "pausiertem": "pausiert",
    "pausierten": "pausieren",
    "pausierter": "pausiert",
    "pausiertes": "pausiert",
    "pausiertest": "pausieren",
    "pausiertet": "pausieren",
    "paust": "pausen",
    "pauste": "pausen",
    "pausten": "pausen",
    "paustest": "pausen",
    "paustet": "pausen",
    "pazifischem": "pazifisch",
    "pazifischen": "pazifisch",
    "pazifischer": "pazifisch",
    "pazifisches": "pazifisch",
    "paßt": "passen",
    "paßte": "passen",
    "paßten": "passen",
    "paßtest": "passen",
    "paßtet": "passen",
    "pedantem": "pedant",
    "pedanten": "pedant",
    "pedanter": "pedant",
    "pedantere": "pedant",
    "pedanterem": "pedant",
    "pedanteren": "pedant",
    "pedanterer": "pedant",
    "pedanteres": "pedant",
    "pedantes": "pedant",
    "pedanteste": "pedant",
    "pedantestem": "pedant",
    "pedantesten": "pedant",
    "pedantester": "pedant",
    "pedantestes": "pedant",
    "pedantische": "pedantisch",
    "pedantischem": "pedantisch",
    "pedantischen": "pedantisch",
    "pedantischer": "pedantisch",
    "pedantischere": "pedantisch",
    "pedantischerem": "pedantisch",
    "pedantischeren": "pedantisch",
    "pedantischerer": "pedantisch",
    "pedantischeres": "pedantisch",
    "pedantisches": "pedantisch",
    "pedantischste": "pedantisch",
    "pedantischstem": "pedantisch",
    "pedantischsten": "pedantisch",
    "pedantischster": "pedantisch",
    "pedantischstes": "pedantisch",
    "pediküre": "pediküren",
    "pedikürend": "pediküren",
    "pedikürende": "pedikürend",
    "pedikürendem": "pedikürend",
    "pedikürenden": "pedikürend",
    "pedikürender": "pedikürend",
    "pedikürendere": "pedikürend",
    "pedikürenderem": "pedikürend",
    "pedikürenderen": "pedikürend",
    "pedikürenderer": "pedikürend",
    "pedikürenderes": "pedikürend",
    "pedikürendes": "pedikürend",
    "pedikürendste": "pedikürend",
    "pedikürendstem": "pedikürend",
    "pedikürendsten": "pedikürend",
    "pedikürendster": "pedikürend",
    "pedikürendstes": "pedikürend",
    "pedikürest": "pediküren",
    "pediküret": "pediküren",
    "pedikürst": "pediküren",
    "pedikürt": "pediküren",
    "pedikürte": "pediküren",
    "pedikürtem": "pedikürt",
    "pedikürten": "pediküren",
    "pedikürter": "pedikürt",
    "pedikürtere": "pedikürt",
    "pedikürterem": "pedikürt",
    "pedikürteren": "pedikürt",
    "pedikürterer": "pedikürt",
    "pedikürteres": "pedikürt",
    "pedikürtes": "pedikürt",
    "pedikürtest": "pediküren",
    "pedikürteste": "pedikürt",
    "pedikürtestem": "pedikürt",
    "pedikürtesten": "pedikürt",
    "pedikürtester": "pedikürt",
    "pedikürtestes": "pedikürt",
    "pedikürtet": "pediküren",
    "peile": "peilen",
    "peilend": "peilen",
    "peilende": "peilend",
    "peilendem": "peilend",
    "peilenden": "peilend",
    "peilender": "peilend",
    "peilendes": "peilend",
    "peilest": "peilen",
    "peilet": "peilen",
    "peilst": "peilen",
    "peilt": "peilen",
    "peilte": "peilen",
    "peilten": "peilen",
    "peiltest": "peilen",
    "peiltet": "peilen",
    "peinige": "peinigen",
    "peinigend": "peinigen",
    "peinigende": "peinigend",
    "peinigendem": "peinigend",
    "peinigenden": "peinigend",
    "peinigender": "peinigend",
    "peinigendere": "peinigend",
    "peinigenderem": "peinigend",
    "peinigenderen": "peinigend",
    "peinigenderer": "peinigend",
    "peinigenderes": "peinigend",
    "peinigendes": "peinigend",
    "peinigendste": "peinigend",
    "peinigendstem": "peinigend",
    "peinigendsten": "peinigend",
    "peinigendster": "peinigend",
    "peinigendstes": "peinigend",
    "peinigest": "peinigen",
    "peiniget": "peinigen",
    "peinigst": "peinigen",
    "peinigt": "peinigen",
    "peinigte": "peinigen",
    "peinigten": "peinigen",
    "peinigtest": "peinigen",
    "peinigtet": "peinigen",
    "peinlichem": "peinlich",
    "peinlichen": "peinlich",
    "peinlicher": "peinlich",
    "peinlichere": "peinlich",
    "peinlicherem": "peinlich",
    "peinlicheren": "peinlich",
    "peinlicherer": "peinlich",
    "peinlicheres": "peinlich",
    "peinliches": "peinlich",
    "peinlichste": "peinlich",
    "peinlichstem": "peinlich",
    "peinlichsten": "peinlich",
    "peinlichster": "peinlich",
    "peinlichstes": "peinlich",
    "peitsche": "peitschen",
    "peitschend": "peitschen",
    "peitschende": "peitschend",
    "peitschendem": "peitschend",
    "peitschenden": "peitschend",
    "peitschender": "peitschend",
    "peitschendes": "peitschend",
    "peitschest": "peitschen",
    "peitschet": "peitschen",
    "peitschst": "peitschen",
    "peitscht": "peitschen",
    "peitschte": "peitschen",
    "peitschten": "peitschen",
    "peitschtest": "peitschen",
    "peitschtet": "peitschen",
    "pejorative": "pejorativ",
    "pejorativem": "pejorativ",
    "pejorativen": "pejorativ",
    "pejorativer": "pejorativ",
    "pejorativere": "pejorativ",
    "pejorativerem": "pejorativ",
    "pejorativeren": "pejorativ",
    "pejorativerer": "pejorativ",
    "pejorativeres": "pejorativ",
    "pejoratives": "pejorativ",
    "pejorativste": "pejorativ",
    "pejorativstem": "pejorativ",
    "pejorativsten": "pejorativ",
    "pejorativster": "pejorativ",
    "pejorativstes": "pejorativ",
    "pellend": "pellen",
    "pellende": "pellend",
    "pellendem": "pellend",
    "pellenden": "pellend",
    "pellender": "pellend",
    "pellendere": "pellend",
    "pellenderem": "pellend",
    "pellenderen": "pellend",
    "pellenderer": "pellend",
    "pellenderes": "pellend",
    "pellendes": "pellend",
    "pellendste": "pellend",
    "pellendstem": "pellend",
    "pellendsten": "pellend",
    "pellendster": "pellend",
    "pellendstes": "pellend",
    "pellest": "pellen",
    "pellet": "pellen",
    "pellst": "pellen",
    "pellt": "pellen",
    "pellte": "pellen",
    "pellten": "pellen",
    "pelltest": "pellen",
    "pelltet": "pellen",
    "pelzigem": "pelzig",
    "pelzigen": "pelzig",
    "pelziger": "pelzig",
    "pelzigere": "pelzig",
    "pelzigerem": "pelzig",
    "pelzigeren": "pelzig",
    "pelzigerer": "pelzig",
    "pelzigeres": "pelzig",
    "pelziges": "pelzig",
    "pelzigste": "pelzig",
    "pelzigstem": "pelzig",
    "pelzigsten": "pelzig",
    "pelzigster": "pelzig",
    "pelzigstes": "pelzig",
    "pendele": "pendeln",
    "pendelnd": "pendeln",
    "pendelnde": "pendelnd",
    "pendelndem": "pendelnd",
    "pendelnden": "pendelnd",
    "pendelnder": "pendelnd",
    "pendelndere": "pendelnd",
    "pendelnderem": "pendelnd",
    "pendelnderen": "pendelnd",
    "pendelnderer": "pendelnd",
    "pendelnderes": "pendelnd",
    "pendelndes": "pendelnd",
    "pendelndste": "pendelnd",
    "pendelndstem": "pendelnd",
    "pendelndsten": "pendelnd",
    "pendelndster": "pendelnd",
    "pendelndstes": "pendelnd",
    "pendelst": "pendeln",
    "pendelt": "pendeln",
    "pendelte": "pendeln",
    "pendelten": "pendeln",
    "pendeltest": "pendeln",
    "pendeltet": "pendeln",
    "pendle": "pendeln",
    "penetrantem": "penetrant",
    "penetranten": "penetrant",
    "penetranter": "penetrant",
    "penetrantere": "penetrant",
    "penetranterem": "penetrant",
    "penetranteren": "penetrant",
    "penetranterer": "penetrant",
    "penetranteres": "penetrant",
    "penetrantes": "penetrant",
    "penetranteste": "penetrant",
    "penetrantestem": "penetrant",
    "penetrantesten": "penetrant",
    "penetrantester": "penetrant",
    "penetrantestes": "penetrant",
    "penibelste": "penibel",
    "penibelstem": "penibel",
    "penibelsten": "penibel",
    "penibelster": "penibel",
    "penibelstes": "penibel",
    "penible": "penibel",
    "peniblem": "penibel",
    "peniblen": "penibel",
    "penibler": "penibel",
    "peniblere": "penibel",
    "peniblerem": "penibel",
    "penibleren": "penibel",
    "peniblerer": "penibel",
    "penibleres": "penibel",
    "penibles": "penibel",
    "pennend": "pennen",
    "pennende": "pennend",
    "pennendem": "pennend",
    "pennenden": "pennend",
    "pennender": "pennend",
    "pennendere": "pennend",
    "pennenderem": "pennend",
    "pennenderen": "pennend",
    "pennenderer": "pennend",
    "pennenderes": "pennend",
    "pennendes": "pennend",
    "pennendste": "pennend",
    "pennendstem": "pennend",
    "pennendsten": "pennend",
    "pennendster": "pennend",
    "pennendstes": "pennend",
    "pennest": "pennen",
    "pennet": "pennen",
    "pennst": "pennen",
    "pennt": "pennen",
    "pennte": "pennen",
    "pennten": "pennen",
    "penntest": "pennen",
    "penntet": "pennen",
    "pensioniere": "pensionieren",
    "pensionierend": "pensionieren",
    "pensionierende": "pensionierend",
    "pensionierendem": "pensionierend",
    "pensionierenden": "pensionierend",
    "pensionierender": "pensionierend",
    "pensionierendes": "pensionierend",
    "pensionierest": "pensionieren",
    "pensionieret": "pensionieren",
    "pensionierst": "pensionieren",
    "pensioniert": "pensionieren",
    "pensionierte": "pensionieren",
    "pensioniertem": "pensioniert",
    "pensionierten": "pensionieren",
    "pensionierter": "pensioniert",
    "pensioniertes": "pensioniert",
    "pensioniertest": "pensionieren",
    "pensioniertet": "pensionieren",
    "peppigem": "peppig",
    "peppigen": "peppig",
    "peppiger": "peppig",
    "peppigere": "peppig",
    "peppigerem": "peppig",
    "peppigeren": "peppig",
    "peppigerer": "peppig",
    "peppigeres": "peppig",
    "peppiges": "peppig",
    "peppigste": "peppig",
    "peppigstem": "peppig",
    "peppigsten": "peppig",
    "peppigster": "peppig",
    "peppigstes": "peppig",
    "perfektem": "perfekt",
    "perfekten": "perfekt",
    "perfekter": "perfekt",
    "perfektere": "perfekt",
    "perfekterem": "perfekt",
    "perfekteren": "perfekt",
    "perfekterer": "perfekt",
    "perfekteres": "perfekt",
    "perfektes": "perfekt",
    "perfekteste": "perfekt",
    "perfektestem": "perfekt",
    "perfektesten": "perfekt",
    "perfektester": "perfekt",
    "perfektestes": "perfekt",
    "perfektioniere": "perfektionieren",
    "perfektionierend": "perfektionieren",
    "perfektionierende": "perfektionierend",
    "perfektionierendem": "perfektionierend",
    "perfektionierenden": "perfektionierend",
    "perfektionierender": "perfektionierend",
    "perfektionierendere": "perfektionierend",
    "perfektionierenderem": "perfektionierend",
    "perfektionierenderen": "perfektionierend",
    "perfektionierenderer": "perfektionierend",
    "perfektionierenderes": "perfektionierend",
    "perfektionierendes": "perfektionierend",
    "perfektionierendste": "perfektionierend",
    "perfektionierendstem": "perfektionierend",
    "perfektionierendsten": "perfektionierend",
    "perfektionierendster": "perfektionierend",
    "perfektionierendstes": "perfektionierend",
    "perfektionierest": "perfektionieren",
    "perfektionieret": "perfektionieren",
    "perfektionierst": "perfektionieren",
    "perfektioniert": "perfektionieren",
    "perfektionierte": "perfektionieren",
    "perfektioniertem": "perfektioniert",
    "perfektionierten": "perfektionieren",
    "perfektionierter": "perfektioniert",
    "perfektioniertere": "perfektioniert",
    "perfektionierterem": "perfektioniert",
    "perfektionierteren": "perfektioniert",
    "perfektionierterer": "perfektioniert",
    "perfektionierteres": "perfektioniert",
    "perfektioniertes": "perfektioniert",
    "perfektioniertest": "perfektionieren",
    "perfektionierteste": "perfektioniert",
    "perfektioniertestem": "perfektioniert",
    "perfektioniertesten": "perfektioniert",
    "perfektioniertester": "perfektioniert",
    "perfektioniertestes": "perfektioniert",
    "perfektioniertet": "perfektionieren",
    "perfektionistischem": "perfektionistisch",
    "perfektionistischen": "perfektionistisch",
    "perfektionistischer": "perfektionistisch",
    "perfektionistischere": "perfektionistisch",
    "perfektionistischerem": "perfektionistisch",
    "perfektionistischeren": "perfektionistisch",
    "perfektionistischerer": "perfektionistisch",
    "perfektionistischeres": "perfektionistisch",
    "perfektionistisches": "perfektionistisch",
    "perfektionistischste": "perfektionistisch",
    "perfektionistischstem": "perfektionistisch",
    "perfektionistischsten": "perfektionistisch",
    "perfektionistischster": "perfektionistisch",
    "perfektionistischstes": "perfektionistisch",
    "perfide": "perfid",
    "perfidem": "perfid",
    "perfiden": "perfid",
    "perfider": "perfid",
    "perfidere": "perfid",
    "perfiderem": "perfid",
    "perfideren": "perfid",
    "perfiderer": "perfid",
    "perfideres": "perfid",
    "perfides": "perfid",
    "perfideste": "perfid",
    "perfidestem": "perfid",
    "perfidesten": "perfid",
    "perfidester": "perfid",
    "perfidestes": "perfid",
    "perforiere": "perforieren",
    "perforierend": "perforieren",
    "perforierende": "perforierend",
    "perforierendem": "perforierend",
    "perforierenden": "perforierend",
    "perforierender": "perforierend",
    "perforierendere": "perforierend",
    "perforierenderem": "perforierend",
    "perforierenderen": "perforierend",
    "perforierenderer": "perforierend",
    "perforierenderes": "perforierend",
    "perforierendes": "perforierend",
    "perforierendste": "perforierend",
    "perforierendstem": "perforierend",
    "perforierendsten": "perforierend",
    "perforierendster": "perforierend",
    "perforierendstes": "perforierend",
    "perforierest": "perforieren",
    "perforieret": "perforieren",
    "perforierst": "perforieren",
    "perforiert": "perforieren",
    "perforierte": "perforieren",
    "perforiertem": "perforiert",
    "perforierten": "perforieren",
    "perforierter": "perforiert",
    "perforiertere": "perforiert",
    "perforierterem": "perforiert",
    "perforierteren": "perforiert",
    "perforierterer": "perforiert",
    "perforierteres": "perforiert",
    "perforiertes": "perforiert",
    "perforiertest": "perforieren",
    "perforierteste": "perforiert",
    "perforiertestem": "perforiert",
    "perforiertesten": "perforiert",
    "perforiertester": "perforiert",
    "perforiertestes": "perforiert",
    "perforiertet": "perforieren",
    "periodischem": "periodisch",
    "periodischen": "periodisch",
    "periodischer": "periodisch",
    "periodisches": "periodisch",
    "periodisiere": "periodisieren",
    "periodisierend": "periodisieren",
    "periodisierende": "periodisierend",
    "periodisierendem": "periodisierend",
    "periodisierenden": "periodisierend",
    "periodisierender": "periodisierend",
    "periodisierendere": "periodisierend",
    "periodisierenderem": "periodisierend",
    "periodisierenderen": "periodisierend",
    "periodisierenderer": "periodisierend",
    "periodisierenderes": "periodisierend",
    "periodisierendes": "periodisierend",
    "periodisierendste": "periodisierend",
    "periodisierendstem": "periodisierend",
    "periodisierendsten": "periodisierend",
    "periodisierendster": "periodisierend",
    "periodisierendstes": "periodisierend",
    "periodisierest": "periodisieren",
    "periodisieret": "periodisieren",
    "periodisierst": "periodisieren",
    "periodisiert": "periodisieren",
    "periodisierte": "periodisieren",
    "periodisiertem": "periodisiert",
    "periodisierten": "periodisieren",
    "periodisierter": "periodisiert",
    "periodisiertere": "periodisiert",
    "periodisierterem": "periodisiert",
    "periodisierteren": "periodisiert",
    "periodisierterer": "periodisiert",
    "periodisierteres": "periodisiert",
    "periodisiertes": "periodisiert",
    "periodisiertest": "periodisieren",
    "periodisierteste": "periodisiert",
    "periodisiertestem": "periodisiert",
    "periodisiertesten": "periodisiert",
    "periodisiertester": "periodisiert",
    "periodisiertestes": "periodisiert",
    "periodisiertet": "periodisieren",
    "periphere": "peripher",
    "peripherem": "peripher",
    "peripheren": "peripher",
    "peripherer": "peripher",
    "peripheres": "peripher",
    "perlend": "perlen",
    "perlende": "perlend",
    "perlendem": "perlend",
    "perlenden": "perlend",
    "perlender": "perlend",
    "perlendere": "perlend",
    "perlenderem": "perlend",
    "perlenderen": "perlend",
    "perlenderer": "perlend",
    "perlenderes": "perlend",
    "perlendes": "perlend",
    "perlendste": "perlend",
    "perlendstem": "perlend",
    "perlendsten": "perlend",
    "perlendster": "perlend",
    "perlendstes": "perlend",
    "perlest": "perlen",
    "perlet": "perlen",
    "perlst": "perlen",
    "perlt": "perlen",
    "perlte": "perlen",
    "perlten": "perlen",
    "perltest": "perlen",
    "perltet": "perlen",
    "permanentem": "permanent",
    "permanenten": "permanent",
    "permanenter": "permanent",
    "permanentes": "permanent",
    "permutable": "permutabel",
    "permutablem": "permutabel",
    "permutablen": "permutabel",
    "permutabler": "permutabel",
    "permutables": "permutabel",
    "permutiere": "permutieren",
    "permutierend": "permutieren",
    "permutierende": "permutierend",
    "permutierendem": "permutierend",
    "permutierenden": "permutierend",
    "permutierender": "permutierend",
    "permutierendes": "permutierend",
    "permutierest": "permutieren",
    "permutieret": "permutieren",
    "permutierst": "permutieren",
    "permutiert": "permutieren",
    "permutierte": "permutieren",
    "permutiertem": "permutiert",
    "permutierten": "permutieren",
    "permutierter": "permutiert",
    "permutiertes": "permutiert",
    "permutiertest": "permutieren",
    "permutiertet": "permutieren",
    "peronistische": "peronistisch",
    "peronistischem": "peronistisch",
    "peronistischen": "peronistisch",
    "peronistischer": "peronistisch",
    "peronistischere": "peronistisch",
    "peronistischerem": "peronistisch",
    "peronistischeren": "peronistisch",
    "peronistischerer": "peronistisch",
    "peronistischeres": "peronistisch",
    "peronistisches": "peronistisch",
    "peronistischste": "peronistisch",
    "peronistischstem": "peronistisch",
    "peronistischsten": "peronistisch",
    "peronistischster": "peronistisch",
    "peronistischstes": "peronistisch",
    "perplexem": "perplex",
    "perplexen": "perplex",
    "perplexer": "perplex",
    "perplexere": "perplex",
    "perplexerem": "perplex",
    "perplexeren": "perplex",
    "perplexerer": "perplex",
    "perplexeres": "perplex",
    "perplexes": "perplex",
    "perplexeste": "perplex",
    "perplexestem": "perplex",
    "perplexesten": "perplex",
    "perplexester": "perplex",
    "perplexestes": "perplex",
    "persischem": "persisch",
    "persischen": "persisch",
    "persischer": "persisch",
    "persisches": "persisch",
    "persistente": "persistent",
    "persistentem": "persistent",
    "persistenten": "persistent",
    "persistenter": "persistent",
    "persistentes": "persistent",
    "personale": "personal",
    "personalem": "personal",
    "personalen": "personal",
    "personaler": "personal",
    "personales": "personal",
    "personalisiere": "personalisieren",
    "personalisierend": "personalisieren",
    "personalisierende": "personalisierend",
    "personalisierendem": "personalisierend",
    "personalisierenden": "personalisierend",
    "personalisierender": "personalisierend",
    "personalisierendes": "personalisierend",
    "personalisierest": "personalisieren",
    "personalisieret": "personalisieren",
    "personalisierst": "personalisieren",
    "personalisiert": "personalisieren",
    "personalisierte": "personalisieren",
    "personalisiertem": "personalisiert",
    "personalisierten": "personalisieren",
    "personalisierter": "personalisiert",
    "personalisiertes": "personalisiert",
    "personalisiertest": "personalisieren",
    "personalisiertet": "personalisieren",
    "personellem": "personell",
    "personellen": "personell",
    "personeller": "personell",
    "personelles": "personell",
    "personifiziere": "personifizieren",
    "personifizierend": "personifizieren",
    "personifizierende": "personifizierend",
    "personifizierendem": "personifizierend",
    "personifizierenden": "personifizierend",
    "personifizierender": "personifizierend",
    "personifizierendere": "personifizierend",
    "personifizierenderem": "personifizierend",
    "personifizierenderen": "personifizierend",
    "personifizierenderer": "personifizierend",
    "personifizierenderes": "personifizierend",
    "personifizierendes": "personifizierend",
    "personifizierendste": "personifizierend",
    "personifizierendstem": "personifizierend",
    "personifizierendsten": "personifizierend",
    "personifizierendster": "personifizierend",
    "personifizierendstes": "personifizierend",
    "personifizierest": "personifizieren",
    "personifizieret": "personifizieren",
    "personifizierst": "personifizieren",
    "personifiziert": "personifizieren",
    "personifizierte": "personifizieren",
    "personifiziertem": "personifiziert",
    "personifizierten": "personifizieren",
    "personifizierter": "personifiziert",
    "personifiziertere": "personifiziert",
    "personifizierterem": "personifiziert",
    "personifizierteren": "personifiziert",
    "personifizierterer": "personifiziert",
    "personifizierteres": "personifiziert",
    "personifiziertes": "personifiziert",
    "personifiziertest": "personifizieren",
    "personifizierteste": "personifiziert",
    "personifiziertestem": "personifiziert",
    "personifiziertesten": "personifiziert",
    "personifiziertester": "personifiziert",
    "personifiziertestes": "personifiziert",
    "personifiziertet": "personifizieren",
    "perspektivischem": "perspektivisch",
    "perspektivischen": "perspektivisch",
    "perspektivischer": "perspektivisch",
    "perspektivischere": "perspektivisch",
    "perspektivischerem": "perspektivisch",
    "perspektivischeren": "perspektivisch",
    "perspektivischerer": "perspektivisch",
    "perspektivischeres": "perspektivisch",
    "perspektivisches": "perspektivisch",
    "perspektivischste": "perspektivisch",
    "perspektivischstem": "perspektivisch",
    "perspektivischsten": "perspektivisch",
    "perspektivischster": "perspektivisch",
    "perspektivischstes": "perspektivisch",
    "persönliche": "persönlich",
    "persönlichem": "persönlich",
    "persönlichen": "persönlich",
    "persönlicher": "persönlich",
    "persönlichere": "persönlich",
    "persönlicherem": "persönlich",
    "persönlicheren": "persönlich",
    "persönlicherer": "persönlich",
    "persönlicheres": "persönlich",
    "persönliches": "persönlich",
    "persönlichstem": "persönlich",
    "persönlichsten": "persönlich",
    "persönlichster": "persönlich",
    "persönlichstes": "persönlich",
    "peruanische": "peruanisch",
    "peruanischem": "peruanisch",
    "peruanischen": "peruanisch",
    "peruanischer": "peruanisch",
    "peruanischere": "peruanisch",
    "peruanischerem": "peruanisch",
    "peruanischeren": "peruanisch",
    "peruanischerer": "peruanisch",
    "peruanischeres": "peruanisch",
    "peruanisches": "peruanisch",
    "peruanischste": "peruanisch",
    "peruanischstem": "peruanisch",
    "peruanischsten": "peruanisch",
    "peruanischster": "peruanisch",
    "peruanischstes": "peruanisch",
    "perversem": "pervers",
    "perversen": "pervers",
    "perverser": "pervers",
    "perversere": "pervers",
    "perverserem": "pervers",
    "perverseren": "pervers",
    "perverserer": "pervers",
    "perverseres": "pervers",
    "perverses": "pervers",
    "perverseste": "pervers",
    "perversestem": "pervers",
    "perversesten": "pervers",
    "perversester": "pervers",
    "perversestes": "pervers",
    "pervertiere": "pervertieren",
    "pervertierend": "pervertieren",
    "pervertierende": "pervertierend",
    "pervertierendem": "pervertierend",
    "pervertierenden": "pervertierend",
    "pervertierender": "pervertierend",
    "pervertierendere": "pervertierend",
    "pervertierenderem": "pervertierend",
    "pervertierenderen": "pervertierend",
    "pervertierenderer": "pervertierend",
    "pervertierenderes": "pervertierend",
    "pervertierendes": "pervertierend",
    "pervertierendste": "pervertierend",
    "pervertierendstem": "pervertierend",
    "pervertierendsten": "pervertierend",
    "pervertierendster": "pervertierend",
    "pervertierendstes": "pervertierend",
    "pervertierest": "pervertieren",
    "pervertieret": "pervertieren",
    "pervertierst": "pervertieren",
    "pervertiert": "pervertieren",
    "pervertierte": "pervertieren",
    "pervertiertem": "pervertiert",
    "pervertierten": "pervertieren",
    "pervertierter": "pervertiert",
    "pervertiertere": "pervertiert",
    "pervertierterem": "pervertiert",
    "pervertierteren": "pervertiert",
    "pervertierterer": "pervertiert",
    "pervertierteres": "pervertiert",
    "pervertiertes": "pervertiert",
    "pervertiertest": "pervertieren",
    "pervertierteste": "pervertiert",
    "pervertiertestem": "pervertiert",
    "pervertiertesten": "pervertiert",
    "pervertiertester": "pervertiert",
    "pervertiertestes": "pervertiert",
    "pervertiertet": "pervertieren",
    "perzeptivem": "perzeptiv",
    "perzeptiven": "perzeptiv",
    "perzeptiver": "perzeptiv",
    "perzeptives": "perzeptiv",
    "pese": "pesen",
    "pesend": "pesen",
    "pesende": "pesend",
    "pesendem": "pesend",
    "pesenden": "pesend",
    "pesender": "pesend",
    "pesendes": "pesend",
    "pesest": "pesen",
    "peset": "pesen",
    "pessimistischem": "pessimistisch",
    "pessimistischen": "pessimistisch",
    "pessimistischer": "pessimistisch",
    "pessimistischere": "pessimistisch",
    "pessimistischerem": "pessimistisch",
    "pessimistischeren": "pessimistisch",
    "pessimistischerer": "pessimistisch",
    "pessimistischeres": "pessimistisch",
    "pessimistisches": "pessimistisch",
    "pessimistischste": "pessimistisch",
    "pessimistischstem": "pessimistisch",
    "pessimistischsten": "pessimistisch",
    "pessimistischster": "pessimistisch",
    "pessimistischstes": "pessimistisch",
    "pest": "pesen",
    "peste": "pesen",
    "pesten": "pesen",
    "pestest": "pesen",
    "pestet": "pesen",
    "petitioniere": "petitionieren",
    "petitionierend": "petitionieren",
    "petitionierende": "petitionierend",
    "petitionierendem": "petitionierend",
    "petitionierenden": "petitionierend",
    "petitionierender": "petitionierend",
    "petitionierendes": "petitionierend",
    "petitionierest": "petitionieren",
    "petitionieret": "petitionieren",
    "petitionierst": "petitionieren",
    "petitioniert": "petitionieren",
    "petitionierte": "petitionieren",
    "petitioniertem": "petitioniert",
    "petitionierten": "petitionieren",
    "petitionierter": "petitioniert",
    "petitioniertes": "petitioniert",
    "petitioniertest": "petitionieren",
    "petitioniertet": "petitionieren",
    "petzend": "petzen",
    "petzende": "petzend",
    "petzendem": "petzend",
    "petzenden": "petzend",
    "petzender": "petzend",
    "petzendere": "petzend",
    "petzenderem": "petzend",
    "petzenderen": "petzend",
    "petzenderer": "petzend",
    "petzenderes": "petzend",
    "petzendes": "petzend",
    "petzendste": "petzend",
    "petzendstem": "petzend",
    "petzendsten": "petzend",
    "petzendster": "petzend",
    "petzendstes": "petzend",
    "petzest": "petzen",
    "petzet": "petzen",
    "petzt": "petzen",
    "petzte": "petzen",
    "petzten": "petzen",
    "petztest": "petzen",
    "petztet": "petzen",
    "pfarrlichem": "pfarrlich",
    "pfarrlichen": "pfarrlich",
    "pfarrlicher": "pfarrlich",
    "pfarrliches": "pfarrlich",
    "pfeffere": "pfeffern",
    "pfeffernd": "pfeffern",
    "pfeffernde": "pfeffernd",
    "pfefferndem": "pfeffernd",
    "pfeffernden": "pfeffernd",
    "pfeffernder": "pfeffernd",
    "pfefferndere": "pfeffernd",
    "pfeffernderem": "pfeffernd",
    "pfeffernderen": "pfeffernd",
    "pfeffernderer": "pfeffernd",
    "pfeffernderes": "pfeffernd",
    "pfefferndes": "pfeffernd",
    "pfefferndste": "pfeffernd",
    "pfefferndstem": "pfeffernd",
    "pfefferndsten": "pfeffernd",
    "pfefferndster": "pfeffernd",
    "pfefferndstes": "pfeffernd",
    "pfefferst": "pfeffern",
    "pfeffert": "pfeffern",
    "pfefferte": "pfeffern",
    "pfefferten": "pfeffern",
    "pfeffertest": "pfeffern",
    "pfeffertet": "pfeffern",
    "pfeife": "pfeifen",
    "pfeifend": "pfeifen",
    "pfeifende": "pfeifend",
    "pfeifendem": "pfeifend",
    "pfeifenden": "pfeifend",
    "pfeifender": "pfeifend",
    "pfeifendes": "pfeifend",
    "pfeifest": "pfeifen",
    "pfeifet": "pfeifen",
    "pfeifst": "pfeifen",
    "pfeift": "pfeifen",
    "pfeilschnellem": "pfeilschnell",
    "pfeilschnellen": "pfeilschnell",
    "pfeilschneller": "pfeilschnell",
    "pfeilschnelles": "pfeilschnell",
    "pferche": "pferchen",
    "pferchend": "pferchen",
    "pferchende": "pferchend",
    "pferchendem": "pferchend",
    "pferchenden": "pferchend",
    "pferchender": "pferchend",
    "pferchendere": "pferchend",
    "pferchenderem": "pferchend",
    "pferchenderen": "pferchend",
    "pferchenderer": "pferchend",
    "pferchenderes": "pferchend",
    "pferchendes": "pferchend",
    "pferchendste": "pferchend",
    "pferchendstem": "pferchend",
    "pferchendsten": "pferchend",
    "pferchendster": "pferchend",
    "pferchendstes": "pferchend",
    "pferchest": "pferchen",
    "pferchet": "pferchen",
    "pferchst": "pferchen",
    "pfercht": "pferchen",
    "pferchte": "pferchen",
    "pferchten": "pferchen",
    "pferchtest": "pferchen",
    "pferchtet": "pferchen",
    "pfiff": "pfeifen",
    "pfiffe": "pfeifen",
    "pfiffen": "pfeifen",
    "pfiffest": "pfeifen",
    "pfiffet": "pfeifen",
    "pfiffige": "pfiffig",
    "pfiffigem": "pfiffig",
    "pfiffigen": "pfiffig",
    "pfiffiger": "pfiffig",
    "pfiffigere": "pfiffig",
    "pfiffigerem": "pfiffig",
    "pfiffigeren": "pfiffig",
    "pfiffigerer": "pfiffig",
    "pfiffigeres": "pfiffig",
    "pfiffiges": "pfiffig",
    "pfiffigste": "pfiffig",
    "pfiffigstem": "pfiffig",
    "pfiffigsten": "pfiffig",
    "pfiffigster": "pfiffig",
    "pfiffigstes": "pfiffig",
    "pfiffst": "pfeifen",
    "pfifft": "pfeifen",
    "pfingstlichem": "pfingstlich",
    "pfingstlichen": "pfingstlich",
    "pfingstlicher": "pfingstlich",
    "pfingstliches": "pfingstlich",
    "pflanzend": "pflanzen",
    "pflanzende": "pflanzend",
    "pflanzendem": "pflanzend",
    "pflanzenden": "pflanzend",
    "pflanzender": "pflanzend",
    "pflanzendes": "pflanzend",
    "pflanzest": "pflanzen",
    "pflanzet": "pflanzen",
    "pflanzlichem": "pflanzlich",
    "pflanzlichen": "pflanzlich",
    "pflanzlicher": "pflanzlich",
    "pflanzliches": "pflanzlich",
    "pflanzt": "pflanzen",
    "pflanzte": "pflanzen",
    "pflanzten": "pflanzen",
    "pflanztest": "pflanzen",
    "pflanztet": "pflanzen",
    "pflaumend": "pflaumen",
    "pflaumende": "pflaumend",
    "pflaumendem": "pflaumend",
    "pflaumenden": "pflaumend",
    "pflaumender": "pflaumend",
    "pflaumendere": "pflaumend",
    "pflaumenderem": "pflaumend",
    "pflaumenderen": "pflaumend",
    "pflaumenderer": "pflaumend",
    "pflaumenderes": "pflaumend",
    "pflaumendes": "pflaumend",
    "pflaumendste": "pflaumend",
    "pflaumendstem": "pflaumend",
    "pflaumendsten": "pflaumend",
    "pflaumendster": "pflaumend",
    "pflaumendstes": "pflaumend",
    "pflaumest": "pflaumen",
    "pflaumet": "pflaumen",
    "pflaumst": "pflaumen",
    "pflaumt": "pflaumen",
    "pflaumte": "pflaumen",
    "pflaumten": "pflaumen",
    "pflaumtest": "pflaumen",
    "pflaumtet": "pflaumen",
    "pflege": "pflegen",
    "pflegebedürftigem": "pflegebedürftig",
    "pflegebedürftigen": "pflegebedürftig",
    "pflegebedürftiger": "pflegebedürftig",
    "pflegebedürftigere": "pflegebedürftig",
    "pflegebedürftigerem": "pflegebedürftig",
    "pflegebedürftigeren": "pflegebedürftig",
    "pflegebedürftigerer": "pflegebedürftig",
    "pflegebedürftigeres": "pflegebedürftig",
    "pflegebedürftiges": "pflegebedürftig",
    "pflegebedürftigste": "pflegebedürftig",
    "pflegebedürftigstem": "pflegebedürftig",
    "pflegebedürftigsten": "pflegebedürftig",
    "pflegebedürftigster": "pflegebedürftig",
    "pflegebedürftigstes": "pflegebedürftig",
    "pflegeleichte": "pflegeleicht",
    "pflegeleichtem": "pflegeleicht",
    "pflegeleichten": "pflegeleicht",
    "pflegeleichter": "pflegeleicht",
    "pflegeleichtes": "pflegeleicht",
    "pflegend": "pflegen",
    "pflegende": "pflegend",
    "pflegendem": "pflegend",
    "pflegenden": "pflegend",
    "pflegender": "pflegend",
    "pflegendere": "pflegend",
    "pflegenderem": "pflegend",
    "pflegenderen": "pflegend",
    "pflegenderer": "pflegend",
    "pflegenderes": "pflegend",
    "pflegendes": "pflegend",
    "pflegendste": "pflegend",
    "pflegendstem": "pflegend",
    "pflegendsten": "pflegend",
    "pflegendster": "pflegend",
    "pflegendstes": "pflegend",
    "pflegerischem": "pflegerisch",
    "pflegerischen": "pflegerisch",
    "pflegerischer": "pflegerisch",
    "pflegerisches": "pflegerisch",
    "pflegest": "pflegen",
    "pfleget": "pflegen",
    "pflegliche": "pfleglich",
    "pfleglichem": "pfleglich",
    "pfleglichen": "pfleglich",
    "pfleglicher": "pfleglich",
    "pflegliches": "pfleglich",
    "pflegst": "pflegen",
    "pflegt": "pflegen",
    "pflegte": "pflegen",
    "pflegten": "pflegen",
    "pflegtest": "pflegen",
    "pflegtet": "pflegen",
    "pflichtbewußte": "pflichtbewußt",
    "pflichtbewußtem": "pflichtbewußt",
    "pflichtbewußten": "pflichtbewußt",
    "pflichtbewußter": "pflichtbewußt",
    "pflichtbewußtere": "pflichtbewußt",
    "pflichtbewußterem": "pflichtbewußt",
    "pflichtbewußteren": "pflichtbewußt",
    "pflichtbewußterer": "pflichtbewußt",
    "pflichtbewußteres": "pflichtbewußt",
    "pflichtbewußtes": "pflichtbewußt",
    "pflichtbewußteste": "pflichtbewußt",
    "pflichtbewußtestem": "pflichtbewußt",
    "pflichtbewußtesten": "pflichtbewußt",
    "pflichtbewußtester": "pflichtbewußt",
    "pflichtbewußtestes": "pflichtbewußt",
    "pflichte": "pflichten",
    "pflichtend": "pflichten",
    "pflichtende": "pflichtend",
    "pflichtendem": "pflichtend",
    "pflichtenden": "pflichtend",
    "pflichtender": "pflichtend",
    "pflichtendes": "pflichtend",
    "pflichtest": "pflichten",
    "pflichtet": "pflichten",
    "pflichtete": "pflichten",
    "pflichteten": "pflichten",
    "pflichtetest": "pflichten",
    "pflichtetet": "pflichten",
    "pflichtgemäßem": "pflichtgemäß",
    "pflichtgemäßen": "pflichtgemäß",
    "pflichtgemäßer": "pflichtgemäß",
    "pflichtgemäßes": "pflichtgemäß",
    "pflichtige": "pflichtig",
    "pflichtigem": "pflichtig",
    "pflichtigen": "pflichtig",
    "pflichtiger": "pflichtig",
    "pflichtiges": "pflichtig",
    "pflücke": "pflücken",
    "pflückend": "pflücken",
    "pflückende": "pflückend",
    "pflückendem": "pflückend",
    "pflückenden": "pflückend",
    "pflückender": "pflückend",
    "pflückendes": "pflückend",
    "pflückest": "pflücken",
    "pflücket": "pflücken",
    "pflückst": "pflücken",
    "pflückt": "pflücken",
    "pflückte": "pflücken",
    "pflückten": "pflücken",
    "pflücktest": "pflücken",
    "pflücktet": "pflücken",
    "pflügend": "pflügen",
    "pflügende": "pflügend",
    "pflügendem": "pflügend",
    "pflügenden": "pflügend",
    "pflügender": "pflügend",
    "pflügendes": "pflügend",
    "pflügest": "pflügen",
    "pflüget": "pflügen",
    "pflügst": "pflügen",
    "pflügt": "pflügen",
    "pflügte": "pflügen",
    "pflügten": "pflügen",
    "pflügtest": "pflügen",
    "pflügtet": "pflügen",
    "pfropfe": "pfropfen",
    "pfropfend": "pfropfen",
    "pfropfende": "pfropfend",
    "pfropfendem": "pfropfend",
    "pfropfenden": "pfropfend",
    "pfropfender": "pfropfend",
    "pfropfendes": "pfropfend",
    "pfropfest": "pfropfen",
    "pfropfet": "pfropfen",
    "pfropfst": "pfropfen",
    "pfropft": "pfropfen",
    "pfropfte": "pfropfen",
    "pfropften": "pfropfen",
    "pfropftest": "pfropfen",
    "pfropftet": "pfropfen",
    "pfundigem": "pfundig",
    "pfundigen": "pfundig",
    "pfundiger": "pfundig",
    "pfundigere": "pfundig",
    "pfundigerem": "pfundig",
    "pfundigeren": "pfundig",
    "pfundigerer": "pfundig",
    "pfundigeres": "pfundig",
    "pfundiges": "pfundig",
    "pfundigste": "pfundig",
    "pfundigstem": "pfundig",
    "pfundigsten": "pfundig",
    "pfundigster": "pfundig",
    "pfundigstes": "pfundig",
    "pfuschend": "pfuschen",
    "pfuschende": "pfuschend",
    "pfuschendem": "pfuschend",
    "pfuschenden": "pfuschend",
    "pfuschender": "pfuschend",
    "pfuschendere": "pfuschend",
    "pfuschenderem": "pfuschend",
    "pfuschenderen": "pfuschend",
    "pfuschenderer": "pfuschend",
    "pfuschenderes": "pfuschend",
    "pfuschendes": "pfuschend",
    "pfuschendste": "pfuschend",
    "pfuschendstem": "pfuschend",
    "pfuschendsten": "pfuschend",
    "pfuschendster": "pfuschend",
    "pfuschendstes": "pfuschend",
    "pfuschest": "pfuschen",
    "pfuschet": "pfuschen",
    "pfuschst": "pfuschen",
    "pfuscht": "pfuschen",
    "pfuschte": "pfuschen",
    "pfuschten": "pfuschen",
    "pfuschtest": "pfuschen",
    "pfuschtet": "pfuschen",
    "pfälzischem": "pfälzisch",
    "pfälzischen": "pfälzisch",
    "pfälzischer": "pfälzisch",
    "pfälzisches": "pfälzisch",
    "pfändbare": "pfändbar",
    "pfändbarem": "pfändbar",
    "pfändbaren": "pfändbar",
    "pfändbarer": "pfändbar",
    "pfändbares": "pfändbar",
    "pfände": "pfänden",
    "pfändend": "pfänden",
    "pfändende": "pfändend",
    "pfändendem": "pfändend",
    "pfändenden": "pfändend",
    "pfändender": "pfändend",
    "pfändendes": "pfändend",
    "pfändest": "pfänden",
    "pfändet": "pfänden",
    "pfändete": "pfänden",
    "pfändeten": "pfänden",
    "pfändetest": "pfänden",
    "pfändetet": "pfänden",
    "phantasielosem": "phantasielos",
    "phantasielosen": "phantasielos",
    "phantasieloser": "phantasielos",
    "phantasielosere": "phantasielos",
    "phantasieloserem": "phantasielos",
    "phantasieloseren": "phantasielos",
    "phantasieloserer": "phantasielos",
    "phantasieloseres": "phantasielos",
    "phantasieloses": "phantasielos",
    "phantasieloseste": "phantasielos",
    "phantasielosestem": "phantasielos",
    "phantasielosesten": "phantasielos",
    "phantasielosester": "phantasielos",
    "phantasielosestes": "phantasielos",
    "phantasiere": "phantasieren",
    "phantasierend": "phantasieren",
    "phantasierende": "phantasierend",
    "phantasierendem": "phantasierend",
    "phantasierenden": "phantasierend",
    "phantasierender": "phantasierend",
    "phantasierendere": "phantasierend",
    "phantasierenderem": "phantasierend",
    "phantasierenderen": "phantasierend",
    "phantasierenderer": "phantasierend",
    "phantasierenderes": "phantasierend",
    "phantasierendes": "phantasierend",
    "phantasierendste": "phantasierend",
    "phantasierendstem": "phantasierend",
    "phantasierendsten": "phantasierend",
    "phantasierendster": "phantasierend",
    "phantasierendstes": "phantasierend",
    "phantasierest": "phantasieren",
    "phantasieret": "phantasieren",
    "phantasierst": "phantasieren",
    "phantasiert": "phantasieren",
    "phantasierte": "phantasieren",
    "phantasiertem": "phantasiert",
    "phantasierten": "phantasieren",
    "phantasierter": "phantasiert",
    "phantasiertere": "phantasiert",
    "phantasierterem": "phantasiert",
    "phantasierteren": "phantasiert",
    "phantasierterer": "phantasiert",
    "phantasierteres": "phantasiert",
    "phantasiertes": "phantasiert",
    "phantasiertest": "phantasieren",
    "phantasierteste": "phantasiert",
    "phantasiertestem": "phantasiert",
    "phantasiertesten": "phantasiert",
    "phantasiertester": "phantasiert",
    "phantasiertestes": "phantasiert",
    "phantasiertet": "phantasieren",
    "phantasievolle": "phantasievoll",
    "phantasievollem": "phantasievoll",
    "phantasievollen": "phantasievoll",
    "phantasievoller": "phantasievoll",
    "phantasievollere": "phantasievoll",
    "phantasievollerem": "phantasievoll",
    "phantasievolleren": "phantasievoll",
    "phantasievollerer": "phantasievoll",
    "phantasievolleres": "phantasievoll",
    "phantasievolles": "phantasievoll",
    "phantasievollste": "phantasievoll",
    "phantasievollstem": "phantasievoll",
    "phantasievollsten": "phantasievoll",
    "phantasievollster": "phantasievoll",
    "phantasievollstes": "phantasievoll",
    "phantastischem": "phantastisch",
    "phantastischen": "phantastisch",
    "phantastischer": "phantastisch",
    "phantastischere": "phantastisch",
    "phantastischerem": "phantastisch",
    "phantastischeren": "phantastisch",
    "phantastischerer": "phantastisch",
    "phantastischeres": "phantastisch",
    "phantastisches": "phantastisch",
    "phantastischste": "phantastisch",
    "phantastischstem": "phantastisch",
    "phantastischsten": "phantastisch",
    "phantastischster": "phantastisch",
    "phantastischstes": "phantastisch",
    "pharisäischem": "pharisäisch",
    "pharisäischen": "pharisäisch",
    "pharisäischer": "pharisäisch",
    "pharisäisches": "pharisäisch",
    "pharmazeutischem": "pharmazeutisch",
    "pharmazeutischen": "pharmazeutisch",
    "pharmazeutischer": "pharmazeutisch",
    "pharmazeutisches": "pharmazeutisch",
    "philologischem": "philologisch",
    "philologischen": "philologisch",
    "philologischer": "philologisch",
    "philologisches": "philologisch",
    "philosophiere": "philosophieren",
    "philosophierend": "philosophieren",
    "philosophierende": "philosophierend",
    "philosophierendem": "philosophierend",
    "philosophierenden": "philosophierend",
    "philosophierender": "philosophierend",
    "philosophierendere": "philosophierend",
    "philosophierenderem": "philosophierend",
    "philosophierenderen": "philosophierend",
    "philosophierenderer": "philosophierend",
    "philosophierenderes": "philosophierend",
    "philosophierendes": "philosophierend",
    "philosophierendste": "philosophierend",
    "philosophierendstem": "philosophierend",
    "philosophierendsten": "philosophierend",
    "philosophierendster": "philosophierend",
    "philosophierendstes": "philosophierend",
    "philosophierest": "philosophieren",
    "philosophieret": "philosophieren",
    "philosophierst": "philosophieren",
    "philosophiert": "philosophieren",
    "philosophierte": "philosophieren",
    "philosophiertem": "philosophiert",
    "philosophierten": "philosophieren",
    "philosophierter": "philosophiert",
    "philosophiertes": "philosophiert",
    "philosophiertest": "philosophieren",
    "philosophiertet": "philosophieren",
    "philosophische": "philosophisch",
    "philosophischem": "philosophisch",
    "philosophischen": "philosophisch",
    "philosophischer": "philosophisch",
    "philosophischere": "philosophisch",
    "philosophischerem": "philosophisch",
    "philosophischeren": "philosophisch",
    "philosophischerer": "philosophisch",
    "philosophischeres": "philosophisch",
    "philosophisches": "philosophisch",
    "philosophischste": "philosophisch",
    "philosophischstem": "philosophisch",
    "philosophischsten": "philosophisch",
    "philosophischster": "philosophisch",
    "philosophischstes": "philosophisch",
    "phlegmatische": "phlegmatisch",
    "phlegmatischem": "phlegmatisch",
    "phlegmatischen": "phlegmatisch",
    "phlegmatischer": "phlegmatisch",
    "phlegmatisches": "phlegmatisch",
    "phonetischem": "phonetisch",
    "phonetischen": "phonetisch",
    "phonetischer": "phonetisch",
    "phonetisches": "phonetisch",
    "phonologischem": "phonologisch",
    "phonologischen": "phonologisch",
    "phonologischer": "phonologisch",
    "phonologisches": "phonologisch",
    "photographiere": "photographieren",
    "photographierend": "photographieren",
    "photographierende": "photographierend",
    "photographierendem": "photographierend",
    "photographierenden": "photographierend",
    "photographierender": "photographierend",
    "photographierendes": "photographierend",
    "photographierest": "photographieren",
    "photographieret": "photographieren",
    "photographierst": "photographieren",
    "photographiert": "photographieren",
    "photographierte": "photographieren",
    "photographiertem": "photographiert",
    "photographierten": "photographieren",
    "photographierter": "photographiert",
    "photographiertere": "photographiert",
    "photographierterem": "photographiert",
    "photographierteren": "photographiert",
    "photographierterer": "photographiert",
    "photographierteres": "photographiert",
    "photographiertes": "photographiert",
    "photographiertest": "photographieren",
    "photographierteste": "photographiert",
    "photographiertestem": "photographiert",
    "photographiertesten": "photographiert",
    "photographiertester": "photographiert",
    "photographiertestes": "photographiert",
    "photographiertet": "photographieren",
    "phrasenhaftem": "phrasenhaft",
    "phrasenhaften": "phrasenhaft",
    "phrasenhafter": "phrasenhaft",
    "phrasenhaftere": "phrasenhaft",
    "phrasenhafterem": "phrasenhaft",
    "phrasenhafteren": "phrasenhaft",
    "phrasenhafterer": "phrasenhaft",
    "phrasenhafteres": "phrasenhaft",
    "phrasenhaftes": "phrasenhaft",
    "phrasenhafteste": "phrasenhaft",
    "phrasenhaftestem": "phrasenhaft",
    "phrasenhaftesten": "phrasenhaft",
    "phrasenhaftester": "phrasenhaft",
    "phrasenhaftestes": "phrasenhaft",
    "phrenetischem": "phrenetisch",
    "phrenetischen": "phrenetisch",
    "phrenetischer": "phrenetisch",
    "phrenetischere": "phrenetisch",
    "phrenetischerem": "phrenetisch",
    "phrenetischeren": "phrenetisch",
    "phrenetischerer": "phrenetisch",
    "phrenetischeres": "phrenetisch",
    "phrenetisches": "phrenetisch",
    "phrenetischste": "phrenetisch",
    "phrenetischstem": "phrenetisch",
    "phrenetischsten": "phrenetisch",
    "phrenetischster": "phrenetisch",
    "phrenetischstes": "phrenetisch",
    "physikalische": "physikalisch",
    "physikalischem": "physikalisch",
    "physikalischen": "physikalisch",
    "physikalischer": "physikalisch",
    "physikalisches": "physikalisch",
    "physiologischem": "physiologisch",
    "physiologischen": "physiologisch",
    "physiologischer": "physiologisch",
    "physiologisches": "physiologisch",
    "physischem": "physisch",
    "physischen": "physisch",
    "physischer": "physisch",
    "physisches": "physisch",
    "phänologischem": "phänologisch",
    "phänologischen": "phänologisch",
    "phänologischer": "phänologisch",
    "phänologisches": "phänologisch",
    "phänomenale": "phänomenal",
    "phänomenalem": "phänomenal",
    "phänomenalen": "phänomenal",
    "phänomenaler": "phänomenal",
    "phänomenalere": "phänomenal",
    "phänomenalerem": "phänomenal",
    "phänomenaleren": "phänomenal",
    "phänomenalerer": "phänomenal",
    "phänomenaleres": "phänomenal",
    "phänomenales": "phänomenal",
    "phänomenalste": "phänomenal",
    "phänomenalstem": "phänomenal",
    "phänomenalsten": "phänomenal",
    "phänomenalster": "phänomenal",
    "phänomenalstes": "phänomenal",
    "phänomenologischem": "phänomenologisch",
    "phänomenologischen": "phänomenologisch",
    "phänomenologischer": "phänomenologisch",
    "phänomenologisches": "phänomenologisch",
    "pichele": "picheln",
    "pichelnd": "picheln",
    "pichelnde": "pichelnd",
    "pichelndem": "pichelnd",
    "pichelnden": "pichelnd",
    "pichelnder": "pichelnd",
    "pichelndere": "pichelnd",
    "pichelnderem": "pichelnd",
    "pichelnderen": "pichelnd",
    "pichelnderer": "pichelnd",
    "pichelnderes": "pichelnd",
    "pichelndes": "pichelnd",
    "pichelndste": "pichelnd",
    "pichelndstem": "pichelnd",
    "pichelndsten": "pichelnd",
    "pichelndster": "pichelnd",
    "pichelndstes": "pichelnd",
    "pichelst": "picheln",
    "pichelt": "picheln",
    "pichelte": "picheln",
    "pichelten": "picheln",
    "picheltest": "picheln",
    "picheltet": "picheln",
    "pichle": "picheln",
    "picke": "picken",
    "pickend": "picken",
    "pickende": "pickend",
    "pickendem": "pickend",
    "pickenden": "pickend",
    "pickender": "pickend",
    "pickendes": "pickend",
    "pickest": "picken",
    "picket": "picken",
    "pickst": "picken",
    "pickt": "picken",
    "pickte": "picken",
    "pickten": "picken",
    "picktest": "picken",
    "picktet": "picken",
    "piekfeinem": "piekfein",
    "piekfeinen": "piekfein",
    "piekfeiner": "piekfein",
    "piekfeines": "piekfein",
    "piepe": "piepen",
    "piepend": "piepen",
    "piepende": "piepend",
    "piependem": "piepend",
    "piependen": "piepend",
    "piepender": "piepend",
    "piependere": "piepend",
    "piependerem": "piepend",
    "piependeren": "piepend",
    "piependerer": "piepend",
    "piependeres": "piepend",
    "piependes": "piepend",
    "piependste": "piepend",
    "piependstem": "piepend",
    "piependsten": "piepend",
    "piependster": "piepend",
    "piependstes": "piepend",
    "piepest": "piepen",
    "piepet": "piepen",
    "piepse": "piepsen",
    "piepsend": "piepsen",
    "piepsende": "piepsend",
    "piepsendem": "piepsend",
    "piepsenden": "piepsend",
    "piepsender": "piepsend",
    "piepsendere": "piepsend",
    "piepsenderem": "piepsend",
    "piepsenderen": "piepsend",
    "piepsenderer": "piepsend",
    "piepsenderes": "piepsend",
    "piepsendes": "piepsend",
    "piepsendste": "piepsend",
    "piepsendstem": "piepsend",
    "piepsendsten": "piepsend",
    "piepsendster": "piepsend",
    "piepsendstes": "piepsend",
    "piepsest": "piepsen",
    "piepset": "piepsen",
    "piepsige": "piepsig",
    "piepsigem": "piepsig",
    "piepsigen": "piepsig",
    "piepsiger": "piepsig",
    "piepsigere": "piepsig",
    "piepsigerem": "piepsig",
    "piepsigeren": "piepsig",
    "piepsigerer": "piepsig",
    "piepsigeres": "piepsig",
    "piepsiges": "piepsig",
    "piepsigste": "piepsig",
    "piepsigstem": "piepsig",
    "piepsigsten": "piepsig",
    "piepsigster": "piepsig",
    "piepsigstes": "piepsig",
    "piepst": "piepsen",
    "piepste": "piepsen",
    "piepsten": "piepsen",
    "piepstest": "piepsen",
    "piepstet": "piepsen",
    "piept": "piepen",
    "piepte": "piepen",
    "piepten": "piepen",
    "pieptest": "piepen",
    "pieptet": "piepen",
    "piesele": "pieseln",
    "pieselnd": "pieseln",
    "pieselnde": "pieselnd",
    "pieselndem": "pieselnd",
    "pieselnden": "pieselnd",
    "pieselnder": "pieselnd",
    "pieselndere": "pieselnd",
    "pieselnderem": "pieselnd",
    "pieselnderen": "pieselnd",
    "pieselnderer": "pieselnd",
    "pieselnderes": "pieselnd",
    "pieselndes": "pieselnd",
    "pieselndste": "pieselnd",
    "pieselndstem": "pieselnd",
    "pieselndsten": "pieselnd",
    "pieselndster": "pieselnd",
    "pieselndstes": "pieselnd",
    "pieselst": "pieseln",
    "pieselt": "pieseln",
    "pieselte": "pieseln",
    "pieselten": "pieseln",
    "pieseltest": "pieseln",
    "pieseltet": "pieseln",
    "piesle": "pieseln",
    "pigmentiere": "pigmentieren",
    "pigmentierend": "pigmentieren",
    "pigmentierende": "pigmentierend",
    "pigmentierendem": "pigmentierend",
    "pigmentierenden": "pigmentierend",
    "pigmentierender": "pigmentierend",
    "pigmentierendere": "pigmentierend",
    "pigmentierenderem": "pigmentierend",
    "pigmentierenderen": "pigmentierend",
    "pigmentierenderer": "pigmentierend",
    "pigmentierenderes": "pigmentierend",
    "pigmentierendes": "pigmentierend",
    "pigmentierendste": "pigmentierend",
    "pigmentierendstem": "pigmentierend",
    "pigmentierendsten": "pigmentierend",
    "pigmentierendster": "pigmentierend",
    "pigmentierendstes": "pigmentierend",
    "pigmentierest": "pigmentieren",
    "pigmentieret": "pigmentieren",
    "pigmentierst": "pigmentieren",
    "pigmentiert": "pigmentieren",
    "pigmentierte": "pigmentieren",
    "pigmentiertem": "pigmentiert",
    "pigmentierten": "pigmentieren",
    "pigmentierter": "pigmentiert",
    "pigmentiertere": "pigmentiert",
    "pigmentierterem": "pigmentiert",
    "pigmentierteren": "pigmentiert",
    "pigmentierterer": "pigmentiert",
    "pigmentierteres": "pigmentiert",
    "pigmentiertes": "pigmentiert",
    "pigmentiertest": "pigmentieren",
    "pigmentierteste": "pigmentiert",
    "pigmentiertestem": "pigmentiert",
    "pigmentiertesten": "pigmentiert",
    "pigmentiertester": "pigmentiert",
    "pigmentiertestes": "pigmentiert",
    "pigmentiertet": "pigmentieren",
    "pikantem": "pikant",
    "pikanten": "pikant",
    "pikanter": "pikant",
    "pikantere": "pikant",
    "pikanterem": "pikant",
    "pikanteren": "pikant",
    "pikanterer": "pikant",
    "pikanteres": "pikant",
    "pikantes": "pikant",
    "pikanteste": "pikant",
    "pikantestem": "pikant",
    "pikantesten": "pikant",
    "pikantester": "pikant",
    "pikantestes": "pikant",
    "pilgere": "pilgern",
    "pilgernd": "pilgern",
    "pilgernde": "pilgernd",
    "pilgerndem": "pilgernd",
    "pilgernden": "pilgernd",
    "pilgernder": "pilgernd",
    "pilgerndes": "pilgernd",
    "pilgerst": "pilgern",
    "pilgert": "pilgern",
    "pilgerte": "pilgern",
    "pilgerten": "pilgern",
    "pilgertest": "pilgern",
    "pilgertet": "pilgern",
    "pingeligem": "pingelig",
    "pingeligen": "pingelig",
    "pingeliger": "pingelig",
    "pingeligere": "pingelig",
    "pingeligerem": "pingelig",
    "pingeligeren": "pingelig",
    "pingeligerer": "pingelig",
    "pingeligeres": "pingelig",
    "pingeliges": "pingelig",
    "pingeligste": "pingelig",
    "pingeligstem": "pingelig",
    "pingeligsten": "pingelig",
    "pingeligster": "pingelig",
    "pingeligstes": "pingelig",
    "pinkele": "pinkeln",
    "pinkelnd": "pinkeln",
    "pinkelnde": "pinkelnd",
    "pinkelndem": "pinkelnd",
    "pinkelnden": "pinkelnd",
    "pinkelnder": "pinkelnd",
    "pinkelndere": "pinkelnd",
    "pinkelnderem": "pinkelnd",
    "pinkelnderen": "pinkelnd",
    "pinkelnderer": "pinkelnd",
    "pinkelnderes": "pinkelnd",
    "pinkelndes": "pinkelnd",
    "pinkelndste": "pinkelnd",
    "pinkelndstem": "pinkelnd",
    "pinkelndsten": "pinkelnd",
    "pinkelndster": "pinkelnd",
    "pinkelndstes": "pinkelnd",
    "pinkelst": "pinkeln",
    "pinkelt": "pinkeln",
    "pinkelte": "pinkeln",
    "pinkelten": "pinkeln",
    "pinkeltest": "pinkeln",
    "pinkeltet": "pinkeln",
    "pinkle": "pinkeln",
    "pinne": "pinnen",
    "pinnend": "pinnen",
    "pinnende": "pinnend",
    "pinnendem": "pinnend",
    "pinnenden": "pinnend",
    "pinnender": "pinnend",
    "pinnendes": "pinnend",
    "pinnest": "pinnen",
    "pinnet": "pinnen",
    "pinnst": "pinnen",
    "pinnt": "pinnen",
    "pinnte": "pinnen",
    "pinnten": "pinnen",
    "pinntest": "pinnen",
    "pinntet": "pinnen",
    "pinsele": "pinseln",
    "pinselnd": "pinseln",
    "pinselnde": "pinselnd",
    "pinselndem": "pinselnd",
    "pinselnden": "pinselnd",
    "pinselnder": "pinselnd",
    "pinselndere": "pinselnd",
    "pinselnderem": "pinselnd",
    "pinselnderen": "pinselnd",
    "pinselnderer": "pinselnd",
    "pinselnderes": "pinselnd",
    "pinselndes": "pinselnd",
    "pinselndste": "pinselnd",
    "pinselndstem": "pinselnd",
    "pinselndsten": "pinselnd",
    "pinselndster": "pinselnd",
    "pinselndstes": "pinselnd",
    "pinselst": "pinseln",
    "pinselt": "pinseln",
    "pinselte": "pinseln",
    "pinselten": "pinseln",
    "pinseltest": "pinseln",
    "pinseltet": "pinseln",
    "pinsle": "pinseln",
    "pirsche": "pirschen",
    "pirschend": "pirschen",
    "pirschende": "pirschend",
    "pirschendem": "pirschend",
    "pirschenden": "pirschend",
    "pirschender": "pirschend",
    "pirschendes": "pirschend",
    "pirschest": "pirschen",
    "pirschet": "pirschen",
    "pirschst": "pirschen",
    "pirscht": "pirschen",
    "pirschte": "pirschen",
    "pirschten": "pirschen",
    "pirschtest": "pirschen",
    "pirschtet": "pirschen",
    "pisse": "pissen",
    "pissend": "pissen",
    "pissende": "pissend",
    "pissendem": "pissend",
    "pissenden": "pissend",
    "pissender": "pissend",
    "pissendere": "pissend",
    "pissenderem": "pissend",
    "pissenderen": "pissend",
    "pissenderer": "pissend",
    "pissenderes": "pissend",
    "pissendes": "pissend",
    "pissendste": "pissend",
    "pissendstem": "pissend",
    "pissendsten": "pissend",
    "pissendster": "pissend",
    "pissendstes": "pissend",
    "pissest": "pissen",
    "pisset": "pissen",
    "pißt": "pissen",
    "pißte": "pissen",
    "pißten": "pissen",
    "pißtest": "pissen",
    "pißtet": "pissen",
    "plagend": "plagen",
    "plagende": "plagend",
    "plagendem": "plagend",
    "plagenden": "plagend",
    "plagender": "plagend",
    "plagendere": "plagend",
    "plagenderem": "plagend",
    "plagenderen": "plagend",
    "plagenderer": "plagend",
    "plagenderes": "plagend",
    "plagendes": "plagend",
    "plagendste": "plagend",
    "plagendstem": "plagend",
    "plagendsten": "plagend",
    "plagendster": "plagend",
    "plagendstes": "plagend",
    "plagest": "plagen",
    "plaget": "plagen",
    "plagst": "plagen",
    "plagt": "plagen",
    "plagte": "plagen",
    "plagten": "plagen",
    "plagtest": "plagen",
    "plagtet": "plagen",
    "plakatiere": "plakatieren",
    "plakatierend": "plakatieren",
    "plakatierende": "plakatierend",
    "plakatierendem": "plakatierend",
    "plakatierenden": "plakatierend",
    "plakatierender": "plakatierend",
    "plakatierendere": "plakatierend",
    "plakatierenderem": "plakatierend",
    "plakatierenderen": "plakatierend",
    "plakatierenderer": "plakatierend",
    "plakatierenderes": "plakatierend",
    "plakatierendes": "plakatierend",
    "plakatierendste": "plakatierend",
    "plakatierendstem": "plakatierend",
    "plakatierendsten": "plakatierend",
    "plakatierendster": "plakatierend",
    "plakatierendstes": "plakatierend",
    "plakatierest": "plakatieren",
    "plakatieret": "plakatieren",
    "plakatierst": "plakatieren",
    "plakatiert": "plakatieren",
    "plakatierte": "plakatieren",
    "plakatiertem": "plakatiert",
    "plakatierten": "plakatieren",
    "plakatierter": "plakatiert",
    "plakatiertere": "plakatiert",
    "plakatierterem": "plakatiert",
    "plakatierteren": "plakatiert",
    "plakatierterer": "plakatiert",
    "plakatierteres": "plakatiert",
    "plakatiertes": "plakatiert",
    "plakatiertest": "plakatieren",
    "plakatierteste": "plakatiert",
    "plakatiertestem": "plakatiert",
    "plakatiertesten": "plakatiert",
    "plakatiertester": "plakatiert",
    "plakatiertestes": "plakatiert",
    "plakatiertet": "plakatieren",
    "plakative": "plakativ",
    "plakativem": "plakativ",
    "plakativen": "plakativ",
    "plakativer": "plakativ",
    "plakativere": "plakativ",
    "plakativerem": "plakativ",
    "plakativeren": "plakativ",
    "plakativerer": "plakativ",
    "plakativeres": "plakativ",
    "plakatives": "plakativ",
    "plakativste": "plakativ",
    "plakativstem": "plakativ",
    "plakativsten": "plakativ",
    "plakativster": "plakativ",
    "plakativstes": "plakativ",
    "planend": "planen",
    "planende": "planend",
    "planendem": "planend",
    "planenden": "planend",
    "planender": "planend",
    "planendere": "planend",
    "planenderem": "planend",
    "planenderen": "planend",
    "planenderer": "planend",
    "planenderes": "planend",
    "planendes": "planend",
    "planendste": "planend",
    "planendstem": "planend",
    "planendsten": "planend",
    "planendster": "planend",
    "planendstes": "planend",
    "planest": "planen",
    "planet": "planen",
    "planetarischem": "planetarisch",
    "planetarischen": "planetarisch",
    "planetarischer": "planetarisch",
    "planetarisches": "planetarisch",
    "plangemäßem": "plangemäß",
    "plangemäßen": "plangemäß",
    "plangemäßer": "plangemäß",
    "plangemäßes": "plangemäß",
    "planiere": "planieren",
    "planierend": "planieren",
    "planierende": "planierend",
    "planierendem": "planierend",
    "planierenden": "planierend",
    "planierender": "planierend",
    "planierendere": "planierend",
    "planierenderem": "planierend",
    "planierenderen": "planierend",
    "planierenderer": "planierend",
    "planierenderes": "planierend",
    "planierendes": "planierend",
    "planierendste": "planierend",
    "planierendstem": "planierend",
    "planierendsten": "planierend",
    "planierendster": "planierend",
    "planierendstes": "planierend",
    "planierest": "planieren",
    "planieret": "planieren",
    "planierst": "planieren",
    "planiert": "planieren",
    "planierte": "planieren",
    "planiertem": "planiert",
    "planierten": "planieren",
    "planierter": "planiert",
    "planiertere": "planiert",
    "planierterem": "planiert",
    "planierteren": "planiert",
    "planierterer": "planiert",
    "planierteres": "planiert",
    "planiertes": "planiert",
    "planiertest": "planieren",
    "planierteste": "planiert",
    "planiertestem": "planiert",
    "planiertesten": "planiert",
    "planiertester": "planiert",
    "planiertestes": "planiert",
    "planiertet": "planieren",
    "planlosem": "planlos",
    "planlosen": "planlos",
    "planloser": "planlos",
    "planlosere": "planlos",
    "planloserem": "planlos",
    "planloseren": "planlos",
    "planloserer": "planlos",
    "planloseres": "planlos",
    "planloses": "planlos",
    "planloseste": "planlos",
    "planlosestem": "planlos",
    "planlosesten": "planlos",
    "planlosester": "planlos",
    "planlosestes": "planlos",
    "planmäßige": "planmäßig",
    "planmäßigem": "planmäßig",
    "planmäßigen": "planmäßig",
    "planmäßiger": "planmäßig",
    "planmäßigere": "planmäßig",
    "planmäßigerem": "planmäßig",
    "planmäßigeren": "planmäßig",
    "planmäßigerer": "planmäßig",
    "planmäßigeres": "planmäßig",
    "planmäßiges": "planmäßig",
    "planmäßigste": "planmäßig",
    "planmäßigstem": "planmäßig",
    "planmäßigsten": "planmäßig",
    "planmäßigster": "planmäßig",
    "planmäßigstes": "planmäßig",
    "plansche": "planschen",
    "planschend": "planschen",
    "planschende": "planschend",
    "planschendem": "planschend",
    "planschenden": "planschend",
    "planschender": "planschend",
    "planschendere": "planschend",
    "planschenderem": "planschend",
    "planschenderen": "planschend",
    "planschenderer": "planschend",
    "planschenderes": "planschend",
    "planschendes": "planschend",
    "planschendste": "planschend",
    "planschendstem": "planschend",
    "planschendsten": "planschend",
    "planschendster": "planschend",
    "planschendstes": "planschend",
    "planschest": "planschen",
    "planschet": "planschen",
    "planschst": "planschen",
    "planscht": "planschen",
    "planschte": "planschen",
    "planschten": "planschen",
    "planschtest": "planschen",
    "planschtet": "planschen",
    "planst": "planen",
    "plant": "planen",
    "plante": "planen",
    "planten": "planen",
    "plantest": "planen",
    "plantet": "planen",
    "planvollem": "planvoll",
    "planvollen": "planvoll",
    "planvoller": "planvoll",
    "planvollere": "planvoll",
    "planvollerem": "planvoll",
    "planvolleren": "planvoll",
    "planvollerer": "planvoll",
    "planvolleres": "planvoll",
    "planvolles": "planvoll",
    "planvollste": "planvoll",
    "planvollstem": "planvoll",
    "planvollsten": "planvoll",
    "planvollster": "planvoll",
    "planvollstes": "planvoll",
    "plappere": "plappern",
    "plappernd": "plappern",
    "plappernde": "plappernd",
    "plapperndem": "plappernd",
    "plappernden": "plappernd",
    "plappernder": "plappernd",
    "plapperndere": "plappernd",
    "plappernderem": "plappernd",
    "plappernderen": "plappernd",
    "plappernderer": "plappernd",
    "plappernderes": "plappernd",
    "plapperndes": "plappernd",
    "plapperndste": "plappernd",
    "plapperndstem": "plappernd",
    "plapperndsten": "plappernd",
    "plapperndster": "plappernd",
    "plapperndstes": "plappernd",
    "plapperst": "plappern",
    "plappert": "plappern",
    "plapperte": "plappern",
    "plapperten": "plappern",
    "plappertest": "plappern",
    "plappertet": "plappern",
    "plasmatische": "plasmatisch",
    "plasmatischem": "plasmatisch",
    "plasmatischen": "plasmatisch",
    "plasmatischer": "plasmatisch",
    "plasmatisches": "plasmatisch",
    "plastischem": "plastisch",
    "plastischen": "plastisch",
    "plastischer": "plastisch",
    "plastischere": "plastisch",
    "plastischerem": "plastisch",
    "plastischeren": "plastisch",
    "plastischerer": "plastisch",
    "plastischeres": "plastisch",
    "plastisches": "plastisch",
    "plastischste": "plastisch",
    "plastischstem": "plastisch",
    "plastischsten": "plastisch",
    "plastischster": "plastisch",
    "plastischstes": "plastisch",
    "platinblondem": "platinblond",
    "platinblonden": "platinblond",
    "platinblonder": "platinblond",
    "platinblondes": "platinblond",
    "platonische": "platonisch",
    "platonischem": "platonisch",
    "platonischen": "platonisch",
    "platonischer": "platonisch",
    "platonisches": "platonisch",
    "platsche": "platschen",
    "platschend": "platschen",
    "platschende": "platschend",
    "platschendem": "platschend",
    "platschenden": "platschend",
    "platschender": "platschend",
    "platschendere": "platschend",
    "platschenderem": "platschend",
    "platschenderen": "platschend",
    "platschenderer": "platschend",
    "platschenderes": "platschend",
    "platschendes": "platschend",
    "platschendste": "platschend",
    "platschendstem": "platschend",
    "platschendsten": "platschend",
    "platschendster": "platschend",
    "platschendstes": "platschend",
    "platschest": "platschen",
    "platschet": "platschen",
    "platschst": "platschen",
    "platscht": "platschen",
    "platschte": "platschen",
    "platschten": "platschen",
    "platschtest": "platschen",
    "platschtet": "platschen",
    "plattdeutsche": "plattdeutsch",
    "plattdeutschem": "plattdeutsch",
    "plattdeutschen": "plattdeutsch",
    "plattdeutscher": "plattdeutsch",
    "plattdeutsches": "plattdeutsch",
    "platte": "platt",
    "plattem": "platt",
    "platten": "platt",
    "platter": "platt",
    "platterem": "platt",
    "platteren": "platt",
    "platterer": "platt",
    "platteres": "platt",
    "plattes": "platt",
    "platteste": "platt",
    "plattestem": "platt",
    "plattesten": "platt",
    "plattester": "platt",
    "plattestes": "platt",
    "plattfüßigem": "plattfüßig",
    "plattfüßigen": "plattfüßig",
    "plattfüßiger": "plattfüßig",
    "plattfüßigere": "plattfüßig",
    "plattfüßigerem": "plattfüßig",
    "plattfüßigeren": "plattfüßig",
    "plattfüßigerer": "plattfüßig",
    "plattfüßigeres": "plattfüßig",
    "plattfüßiges": "plattfüßig",
    "plattfüßigste": "plattfüßig",
    "plattfüßigstem": "plattfüßig",
    "plattfüßigsten": "plattfüßig",
    "plattfüßigster": "plattfüßig",
    "plattfüßigstes": "plattfüßig",
    "platzend": "platzen",
    "platzende": "platzend",
    "platzendem": "platzend",
    "platzenden": "platzend",
    "platzender": "platzend",
    "platzendere": "platzend",
    "platzenderem": "platzend",
    "platzenderen": "platzend",
    "platzenderer": "platzend",
    "platzenderes": "platzend",
    "platzendes": "platzend",
    "platzendste": "platzend",
    "platzendstem": "platzend",
    "platzendsten": "platzend",
    "platzendster": "platzend",
    "platzendstes": "platzend",
    "platzest": "platzen",
    "platzet": "platzen",
    "platzt": "platzen",
    "platzte": "platzen",
    "platzten": "platzen",
    "platztest": "platzen",
    "platztet": "platzen",
    "plaudere": "plaudern",
    "plaudernd": "plaudern",
    "plaudernde": "plaudernd",
    "plauderndem": "plaudernd",
    "plaudernden": "plaudernd",
    "plaudernder": "plaudernd",
    "plauderndere": "plaudernd",
    "plaudernderem": "plaudernd",
    "plaudernderen": "plaudernd",
    "plaudernderer": "plaudernd",
    "plaudernderes": "plaudernd",
    "plauderndes": "plaudernd",
    "plauderndste": "plaudernd",
    "plauderndstem": "plaudernd",
    "plauderndsten": "plaudernd",
    "plauderndster": "plaudernd",
    "plauderndstes": "plaudernd",
    "plauderst": "plaudern",
    "plaudert": "plaudern",
    "plauderte": "plaudern",
    "plauderten": "plaudern",
    "plaudertest": "plaudern",
    "plaudertet": "plaudern",
    "plauschend": "plauschen",
    "plauschende": "plauschend",
    "plauschendem": "plauschend",
    "plauschenden": "plauschend",
    "plauschender": "plauschend",
    "plauschendere": "plauschend",
    "plauschenderem": "plauschend",
    "plauschenderen": "plauschend",
    "plauschenderer": "plauschend",
    "plauschenderes": "plauschend",
    "plauschendes": "plauschend",
    "plauschendste": "plauschend",
    "plauschendstem": "plauschend",
    "plauschendsten": "plauschend",
    "plauschendster": "plauschend",
    "plauschendstes": "plauschend",
    "plauschest": "plauschen",
    "plauschet": "plauschen",
    "plauschst": "plauschen",
    "plauscht": "plauschen",
    "plauschte": "plauschen",
    "plauschten": "plauschen",
    "plauschtest": "plauschen",
    "plauschtet": "plauschen",
    "plausibelste": "plausibel",
    "plausibelstem": "plausibel",
    "plausibelsten": "plausibel",
    "plausibelster": "plausibel",
    "plausibelstes": "plausibel",
    "plausiblem": "plausibel",
    "plausiblen": "plausibel",
    "plausibler": "plausibel",
    "plausiblere": "plausibel",
    "plausiblerem": "plausibel",
    "plausibleren": "plausibel",
    "plausiblerer": "plausibel",
    "plausibleres": "plausibel",
    "plausibles": "plausibel",
    "plazentalem": "plazental",
    "plazentalen": "plazental",
    "plazentaler": "plazental",
    "plazentales": "plazental",
    "plaziere": "plazieren",
    "plazierend": "plazieren",
    "plazierende": "plazierend",
    "plazierendem": "plazierend",
    "plazierenden": "plazierend",
    "plazierender": "plazierend",
    "plazierendes": "plazierend",
    "plazierest": "plazieren",
    "plazieret": "plazieren",
    "plazierst": "plazieren",
    "plaziert": "plazieren",
    "plazierte": "plazieren",
    "plaziertem": "plaziert",
    "plazierten": "plazieren",
    "plazierter": "plaziert",
    "plaziertes": "plaziert",
    "plaziertest": "plazieren",
    "plaziertet": "plazieren",
    "plempere": "plempern",
    "plempernd": "plempern",
    "plempernde": "plempernd",
    "plemperndem": "plempernd",
    "plempernden": "plempernd",
    "plempernder": "plempernd",
    "plemperndere": "plempernd",
    "plempernderem": "plempernd",
    "plempernderen": "plempernd",
    "plempernderer": "plempernd",
    "plempernderes": "plempernd",
    "plemperndes": "plempernd",
    "plemperndste": "plempernd",
    "plemperndstem": "plempernd",
    "plemperndsten": "plempernd",
    "plemperndster": "plempernd",
    "plemperndstes": "plempernd",
    "plemperst": "plempern",
    "plempert": "plempern",
    "plemperte": "plempern",
    "plemperten": "plempern",
    "plempertest": "plempern",
    "plempertet": "plempern",
    "plombiere": "plombieren",
    "plombierend": "plombieren",
    "plombierende": "plombierend",
    "plombierendem": "plombierend",
    "plombierenden": "plombierend",
    "plombierender": "plombierend",
    "plombierendere": "plombierend",
    "plombierenderem": "plombierend",
    "plombierenderen": "plombierend",
    "plombierenderer": "plombierend",
    "plombierenderes": "plombierend",
    "plombierendes": "plombierend",
    "plombierendste": "plombierend",
    "plombierendstem": "plombierend",
    "plombierendsten": "plombierend",
    "plombierendster": "plombierend",
    "plombierendstes": "plombierend",
    "plombierest": "plombieren",
    "plombieret": "plombieren",
    "plombierst": "plombieren",
    "plombiert": "plombieren",
    "plombierte": "plombieren",
    "plombiertem": "plombiert",
    "plombierten": "plombieren",
    "plombierter": "plombiert",
    "plombiertere": "plombiert",
    "plombierterem": "plombiert",
    "plombierteren": "plombiert",
    "plombierterer": "plombiert",
    "plombierteres": "plombiert",
    "plombiertes": "plombiert",
    "plombiertest": "plombieren",
    "plombierteste": "plombiert",
    "plombiertestem": "plombiert",
    "plombiertesten": "plombiert",
    "plombiertester": "plombiert",
    "plombiertestes": "plombiert",
    "plombiertet": "plombieren",
    "plotte": "plotten",
    "plottend": "plotten",
    "plottende": "plottend",
    "plottendem": "plottend",
    "plottenden": "plottend",
    "plottender": "plottend",
    "plottendes": "plottend",
    "plottest": "plotten",
    "plottet": "plotten",
    "plottete": "plotten",
    "plotteten": "plotten",
    "plottetest": "plotten",
    "plottetet": "plotten",
    "pluderigem": "pluderig",
    "pluderigen": "pluderig",
    "pluderiger": "pluderig",
    "pluderigere": "pluderig",
    "pluderigerem": "pluderig",
    "pluderigeren": "pluderig",
    "pluderigerer": "pluderig",
    "pluderigeres": "pluderig",
    "pluderiges": "pluderig",
    "pluderigste": "pluderig",
    "pluderigstem": "pluderig",
    "pluderigsten": "pluderig",
    "pluderigster": "pluderig",
    "pluderigstes": "pluderig",
    "plumpe": "plump",
    "plumpem": "plump",
    "plumpen": "plump",
    "plumper": "plump",
    "plumpere": "plump",
    "plumperem": "plump",
    "plumperen": "plump",
    "plumperer": "plump",
    "plumperes": "plump",
    "plumpes": "plump",
    "plumpeste": "plump",
    "plumpestem": "plump",
    "plumpesten": "plump",
    "plumpester": "plump",
    "plumpestes": "plump",
    "plumpse": "plumpsen",
    "plumpsend": "plumpsen",
    "plumpsende": "plumpsend",
    "plumpsendem": "plumpsend",
    "plumpsenden": "plumpsend",
    "plumpsender": "plumpsend",
    "plumpsendes": "plumpsend",
    "plumpsest": "plumpsen",
    "plumpset": "plumpsen",
    "plumpst": "plumpsen",
    "plumpste": "plumpsen",
    "plumpsten": "plumpsen",
    "plumpstest": "plumpsen",
    "plumpstet": "plumpsen",
    "plustere": "plustern",
    "plusternd": "plustern",
    "plusternde": "plusternd",
    "plusterndem": "plusternd",
    "plusternden": "plusternd",
    "plusternder": "plusternd",
    "plusterndes": "plusternd",
    "plusterst": "plustern",
    "plustert": "plustern",
    "plusterte": "plustern",
    "plusterten": "plustern",
    "plustertest": "plustern",
    "plustertet": "plustern",
    "plutonische": "plutonisch",
    "plutonischem": "plutonisch",
    "plutonischen": "plutonisch",
    "plutonischer": "plutonisch",
    "plutonisches": "plutonisch",
    "plädiere": "plädieren",
    "plädierend": "plädieren",
    "plädierende": "plädierend",
    "plädierendem": "plädierend",
    "plädierenden": "plädierend",
    "plädierender": "plädierend",
    "plädierendes": "plädierend",
    "plädierest": "plädieren",
    "plädieret": "plädieren",
    "plädierst": "plädieren",
    "plädiert": "plädieren",
    "plädierte": "plädieren",
    "plädiertem": "plädiert",
    "plädierten": "plädieren",
    "plädierter": "plädiert",
    "plädiertes": "plädiert",
    "plädiertest": "plädieren",
    "plädiertet": "plädieren",
    "plätschere": "plätschern",
    "plätschernd": "plätschern",
    "plätschernde": "plätschernd",
    "plätscherndem": "plätschernd",
    "plätschernden": "plätschernd",
    "plätschernder": "plätschernd",
    "plätscherndere": "plätschernd",
    "plätschernderem": "plätschernd",
    "plätschernderen": "plätschernd",
    "plätschernderer": "plätschernd",
    "plätschernderes": "plätschernd",
    "plätscherndes": "plätschernd",
    "plätscherndste": "plätschernd",
    "plätscherndstem": "plätschernd",
    "plätscherndsten": "plätschernd",
    "plätscherndster": "plätschernd",
    "plätscherndstes": "plätschernd",
    "plätscherst": "plätschern",
    "plätschert": "plätschern",
    "plätscherte": "plätschern",
    "plätscherten": "plätschern",
    "plätschertest": "plätschern",
    "plätschertet": "plätschern",
    "plätte": "plätten",
    "plättend": "plätten",
    "plättende": "plättend",
    "plättendem": "plättend",
    "plättenden": "plättend",
    "plättender": "plättend",
    "plättendere": "plättend",
    "plättenderem": "plättend",
    "plättenderen": "plättend",
    "plättenderer": "plättend",
    "plättenderes": "plättend",
    "plättendes": "plättend",
    "plättendste": "plättend",
    "plättendstem": "plättend",
    "plättendsten": "plättend",
    "plättendster": "plättend",
    "plättendstes": "plättend",
    "plättest": "plätten",
    "plättet": "plätten",
    "plättete": "plätten",
    "plätteten": "plätten",
    "plättetest": "plätten",
    "plättetet": "plätten",
    "plötzliche": "plötzlich",
    "plötzlichem": "plötzlich",
    "plötzlichen": "plötzlich",
    "plötzlicher": "plötzlich",
    "plötzlichere": "plötzlich",
    "plötzlicherem": "plötzlich",
    "plötzlicheren": "plötzlich",
    "plötzlicherer": "plötzlich",
    "plötzlicheres": "plötzlich",
    "plötzliches": "plötzlich",
    "plötzlichste": "plötzlich",
    "plötzlichstem": "plötzlich",
    "plötzlichsten": "plötzlich",
    "plötzlichster": "plötzlich",
    "plötzlichstes": "plötzlich",
    "plündere": "plündern",
    "plündernd": "plündern",
    "plündernde": "plündernd",
    "plünderndem": "plündernd",
    "plündernden": "plündernd",
    "plündernder": "plündernd",
    "plünderndere": "plündernd",
    "plündernderem": "plündernd",
    "plündernderen": "plündernd",
    "plündernderer": "plündernd",
    "plündernderes": "plündernd",
    "plünderndes": "plündernd",
    "plünderndste": "plündernd",
    "plünderndstem": "plündernd",
    "plünderndsten": "plündernd",
    "plünderndster": "plündernd",
    "plünderndstes": "plündernd",
    "plünderst": "plündern",
    "plündert": "plündern",
    "plünderte": "plündern",
    "plünderten": "plündern",
    "plündertest": "plündern",
    "plündertet": "plündern",
    "pneumatischem": "pneumatisch",
    "pneumatischen": "pneumatisch",
    "pneumatischer": "pneumatisch",
    "pneumatisches": "pneumatisch",
    "poche": "pochen",
    "pochend": "pochen",
    "pochende": "pochend",
    "pochendem": "pochend",
    "pochenden": "pochend",
    "pochender": "pochend",
    "pochendes": "pochend",
    "pochest": "pochen",
    "pochet": "pochen",
    "pochst": "pochen",
    "pocht": "pochen",
    "pochte": "pochen",
    "pochten": "pochen",
    "pochtest": "pochen",
    "pochtet": "pochen",
    "poetischem": "poetisch",
    "poetischen": "poetisch",
    "poetischer": "poetisch",
    "poetischere": "poetisch",
    "poetischerem": "poetisch",
    "poetischeren": "poetisch",
    "poetischerer": "poetisch",
    "poetischeres": "poetisch",
    "poetisches": "poetisch",
    "poetischste": "poetisch",
    "poetischstem": "poetisch",
    "poetischsten": "poetisch",
    "poetischster": "poetisch",
    "poetischstes": "poetisch",
    "poetisiere": "poetisieren",
    "poetisierend": "poetisieren",
    "poetisierende": "poetisierend",
    "poetisierendem": "poetisierend",
    "poetisierenden": "poetisierend",
    "poetisierender": "poetisierend",
    "poetisierendere": "poetisierend",
    "poetisierenderem": "poetisierend",
    "poetisierenderen": "poetisierend",
    "poetisierenderer": "poetisierend",
    "poetisierenderes": "poetisierend",
    "poetisierendes": "poetisierend",
    "poetisierendste": "poetisierend",
    "poetisierendstem": "poetisierend",
    "poetisierendsten": "poetisierend",
    "poetisierendster": "poetisierend",
    "poetisierendstes": "poetisierend",
    "poetisierest": "poetisieren",
    "poetisieret": "poetisieren",
    "poetisierst": "poetisieren",
    "poetisiert": "poetisieren",
    "poetisierte": "poetisieren",
    "poetisiertem": "poetisiert",
    "poetisierten": "poetisieren",
    "poetisierter": "poetisiert",
    "poetisiertere": "poetisiert",
    "poetisierterem": "poetisiert",
    "poetisierteren": "poetisiert",
    "poetisierterer": "poetisiert",
    "poetisierteres": "poetisiert",
    "poetisiertes": "poetisiert",
    "poetisiertest": "poetisieren",
    "poetisierteste": "poetisiert",
    "poetisiertestem": "poetisiert",
    "poetisiertesten": "poetisiert",
    "poetisiertester": "poetisiert",
    "poetisiertestes": "poetisiert",
    "poetisiertet": "poetisieren",
    "pokere": "pokern",
    "pokernd": "pokern",
    "pokernde": "pokernd",
    "pokerndem": "pokernd",
    "pokernden": "pokernd",
    "pokernder": "pokernd",
    "pokerndere": "pokernd",
    "pokernderem": "pokernd",
    "pokernderen": "pokernd",
    "pokernderer": "pokernd",
    "pokernderes": "pokernd",
    "pokerndes": "pokernd",
    "pokerndste": "pokernd",
    "pokerndstem": "pokernd",
    "pokerndsten": "pokernd",
    "pokerndster": "pokernd",
    "pokerndstes": "pokernd",
    "pokerst": "pokern",
    "pokert": "pokern",
    "pokerte": "pokern",
    "pokerten": "pokern",
    "pokertest": "pokern",
    "pokertet": "pokern",
    "polarem": "polar",
    "polaren": "polar",
    "polarer": "polar",
    "polares": "polar",
    "polarisiere": "polarisieren",
    "polarisierend": "polarisieren",
    "polarisierende": "polarisierend",
    "polarisierendem": "polarisierend",
    "polarisierenden": "polarisierend",
    "polarisierender": "polarisierend",
    "polarisierendere": "polarisierend",
    "polarisierenderem": "polarisierend",
    "polarisierenderen": "polarisierend",
    "polarisierenderer": "polarisierend",
    "polarisierenderes": "polarisierend",
    "polarisierendes": "polarisierend",
    "polarisierendste": "polarisierend",
    "polarisierendstem": "polarisierend",
    "polarisierendsten": "polarisierend",
    "polarisierendster": "polarisierend",
    "polarisierendstes": "polarisierend",
    "polarisierest": "polarisieren",
    "polarisieret": "polarisieren",
    "polarisierst": "polarisieren",
    "polarisiert": "polarisieren",
    "polarisierte": "polarisieren",
    "polarisiertem": "polarisiert",
    "polarisierten": "polarisieren",
    "polarisierter": "polarisiert",
    "polarisiertere": "polarisiert",
    "polarisierterem": "polarisiert",
    "polarisierteren": "polarisiert",
    "polarisierterer": "polarisiert",
    "polarisierteres": "polarisiert",
    "polarisiertes": "polarisiert",
    "polarisiertest": "polarisieren",
    "polarisierteste": "polarisiert",
    "polarisiertestem": "polarisiert",
    "polarisiertesten": "polarisiert",
    "polarisiertester": "polarisiert",
    "polarisiertestes": "polarisiert",
    "polarisiertet": "polarisieren",
    "polemischem": "polemisch",
    "polemischen": "polemisch",
    "polemischer": "polemisch",
    "polemischere": "polemisch",
    "polemischerem": "polemisch",
    "polemischeren": "polemisch",
    "polemischerer": "polemisch",
    "polemischeres": "polemisch",
    "polemisches": "polemisch",
    "polemischste": "polemisch",
    "polemischstem": "polemisch",
    "polemischsten": "polemisch",
    "polemischster": "polemisch",
    "polemischstes": "polemisch",
    "polemisiere": "polemisieren",
    "polemisierend": "polemisieren",
    "polemisierende": "polemisierend",
    "polemisierendem": "polemisierend",
    "polemisierenden": "polemisierend",
    "polemisierender": "polemisierend",
    "polemisierendere": "polemisierend",
    "polemisierenderem": "polemisierend",
    "polemisierenderen": "polemisierend",
    "polemisierenderer": "polemisierend",
    "polemisierenderes": "polemisierend",
    "polemisierendes": "polemisierend",
    "polemisierendste": "polemisierend",
    "polemisierendstem": "polemisierend",
    "polemisierendsten": "polemisierend",
    "polemisierendster": "polemisierend",
    "polemisierendstes": "polemisierend",
    "polemisierest": "polemisieren",
    "polemisieret": "polemisieren",
    "polemisierst": "polemisieren",
    "polemisiert": "polemisieren",
    "polemisierte": "polemisieren",
    "polemisiertem": "polemisiert",
    "polemisierten": "polemisieren",
    "polemisierter": "polemisiert",
    "polemisiertere": "polemisiert",
    "polemisierterem": "polemisiert",
    "polemisierteren": "polemisiert",
    "polemisierterer": "polemisiert",
    "polemisierteres": "polemisiert",
    "polemisiertes": "polemisiert",
    "polemisiertest": "polemisieren",
    "polemisierteste": "polemisiert",
    "polemisiertestem": "polemisiert",
    "polemisiertesten": "polemisiert",
    "polemisiertester": "polemisiert",
    "polemisiertestes": "polemisiert",
    "polemisiertet": "polemisieren",
    "polend": "polen",
    "polende": "polend",
    "polendem": "polend",
    "polenden": "polend",
    "polender": "polend",
    "polendes": "polend",
    "polest": "polen",
    "polet": "polen",
    "polierend": "polieren",
    "polierende": "polierend",
    "polierendem": "polierend",
    "polierenden": "polierend",
    "polierender": "polierend",
    "polierendere": "polierend",
    "polierenderem": "polierend",
    "polierenderen": "polierend",
    "polierenderer": "polierend",
    "polierenderes": "polierend",
    "polierendes": "polierend",
    "polierendste": "polierend",
    "polierendstem": "polierend",
    "polierendsten": "polierend",
    "polierendster": "polierend",
    "polierendstes": "polierend",
    "polierest": "polieren",
    "polieret": "polieren",
    "polierst": "polieren",
    "poliert": "polieren",
    "polierte": "polieren",
    "poliertem": "poliert",
    "polierten": "polieren",
    "polierter": "poliert",
    "poliertere": "poliert",
    "polierterem": "poliert",
    "polierteren": "poliert",
    "polierterer": "poliert",
    "polierteres": "poliert",
    "poliertes": "poliert",
    "poliertest": "polieren",
    "polierteste": "poliert",
    "poliertestem": "poliert",
    "poliertesten": "poliert",
    "poliertester": "poliert",
    "poliertestes": "poliert",
    "poliertet": "polieren",
    "politischem": "politisch",
    "politischen": "politisch",
    "politischer": "politisch",
    "politischere": "politisch",
    "politischerem": "politisch",
    "politischeren": "politisch",
    "politischerer": "politisch",
    "politischeres": "politisch",
    "politisches": "politisch",
    "politischste": "politisch",
    "politischstem": "politisch",
    "politischsten": "politisch",
    "politischster": "politisch",
    "politischstes": "politisch",
    "politisiere": "politisieren",
    "politisierend": "politisieren",
    "politisierende": "politisierend",
    "politisierendem": "politisierend",
    "politisierenden": "politisierend",
    "politisierender": "politisierend",
    "politisierendere": "politisierend",
    "politisierenderem": "politisierend",
    "politisierenderen": "politisierend",
    "politisierenderer": "politisierend",
    "politisierenderes": "politisierend",
    "politisierendes": "politisierend",
    "politisierendste": "politisierend",
    "politisierendstem": "politisierend",
    "politisierendsten": "politisierend",
    "politisierendster": "politisierend",
    "politisierendstes": "politisierend",
    "politisierest": "politisieren",
    "politisieret": "politisieren",
    "politisierst": "politisieren",
    "politisiert": "politisieren",
    "politisierte": "politisieren",
    "politisiertem": "politisiert",
    "politisierten": "politisieren",
    "politisierter": "politisiert",
    "politisiertere": "politisiert",
    "politisierterem": "politisiert",
    "politisierteren": "politisiert",
    "politisierterer": "politisiert",
    "politisierteres": "politisiert",
    "politisiertes": "politisiert",
    "politisiertest": "politisieren",
    "politisierteste": "politisiert",
    "politisiertestem": "politisiert",
    "politisiertesten": "politisiert",
    "politisiertester": "politisiert",
    "politisiertestes": "politisiert",
    "politisiertet": "politisieren",
    "politologischem": "politologisch",
    "politologischen": "politologisch",
    "politologischer": "politologisch",
    "politologisches": "politologisch",
    "polivalentem": "polivalent",
    "polivalenten": "polivalent",
    "polivalenter": "polivalent",
    "polivalentere": "polivalent",
    "polivalenterem": "polivalent",
    "polivalenteren": "polivalent",
    "polivalenterer": "polivalent",
    "polivalenteres": "polivalent",
    "polivalentes": "polivalent",
    "polivalenteste": "polivalent",
    "polivalentestem": "polivalent",
    "polivalentesten": "polivalent",
    "polivalentester": "polivalent",
    "polivalentestes": "polivalent",
    "polizeiliche": "polizeilich",
    "polizeilichem": "polizeilich",
    "polizeilichen": "polizeilich",
    "polizeilicher": "polizeilich",
    "polizeiliches": "polizeilich",
    "polizeiwidrige": "polizeiwidrig",
    "polizeiwidrigem": "polizeiwidrig",
    "polizeiwidrigen": "polizeiwidrig",
    "polizeiwidriger": "polizeiwidrig",
    "polizeiwidriges": "polizeiwidrig",
    "polnischem": "polnisch",
    "polnischen": "polnisch",
    "polnischer": "polnisch",
    "polnischere": "polnisch",
    "polnischerem": "polnisch",
    "polnischeren": "polnisch",
    "polnischerer": "polnisch",
    "polnischeres": "polnisch",
    "polnisches": "polnisch",
    "polnischste": "polnisch",
    "polnischstem": "polnisch",
    "polnischsten": "polnisch",
    "polnischster": "polnisch",
    "polnischstes": "polnisch",
    "polst": "polen",
    "polstere": "polstern",
    "polsternd": "polstern",
    "polsternde": "polsternd",
    "polsterndem": "polsternd",
    "polsternden": "polsternd",
    "polsternder": "polsternd",
    "polsterndere": "polsternd",
    "polsternderem": "polsternd",
    "polsternderen": "polsternd",
    "polsternderer": "polsternd",
    "polsternderes": "polsternd",
    "polsterndes": "polsternd",
    "polsterndste": "polsternd",
    "polsterndstem": "polsternd",
    "polsterndsten": "polsternd",
    "polsterndster": "polsternd",
    "polsterndstes": "polsternd",
    "polsterst": "polstern",
    "polstert": "polstern",
    "polsterte": "polstern",
    "polsterten": "polstern",
    "polstertest": "polstern",
    "polstertet": "polstern",
    "polt": "polen",
    "polte": "polen",
    "polten": "polen",
    "poltere": "poltern",
    "polternd": "poltern",
    "polternde": "polternd",
    "polterndem": "polternd",
    "polternden": "polternd",
    "polternder": "polternd",
    "polterndere": "polternd",
    "polternderem": "polternd",
    "polternderen": "polternd",
    "polternderer": "polternd",
    "polternderes": "polternd",
    "polterndes": "polternd",
    "polterndste": "polternd",
    "polterndstem": "polternd",
    "polterndsten": "polternd",
    "polterndster": "polternd",
    "polterndstes": "polternd",
    "polterst": "poltern",
    "poltert": "poltern",
    "polterte": "poltern",
    "polterten": "poltern",
    "poltertest": "poltern",
    "poltertet": "poltern",
    "poltest": "polen",
    "poltet": "polen",
    "polygame": "polygam",
    "polygamem": "polygam",
    "polygamen": "polygam",
    "polygamer": "polygam",
    "polygames": "polygam",
    "polygonale": "polygonal",
    "polygonalem": "polygonal",
    "polygonalen": "polygonal",
    "polygonaler": "polygonal",
    "polygonales": "polygonal",
    "polygraphische": "polygraphisch",
    "polygraphischem": "polygraphisch",
    "polygraphischen": "polygraphisch",
    "polygraphischer": "polygraphisch",
    "polygraphisches": "polygraphisch",
    "polymorphe": "polymorph",
    "polymorphem": "polymorph",
    "polymorphen": "polymorph",
    "polymorpher": "polymorph",
    "polymorphes": "polymorph",
    "polynomischem": "polynomisch",
    "polynomischen": "polynomisch",
    "polynomischer": "polynomisch",
    "polynomisches": "polynomisch",
    "polyphonem": "polyphon",
    "polyphonen": "polyphon",
    "polyphoner": "polyphon",
    "polyphones": "polyphon",
    "polytechnischem": "polytechnisch",
    "polytechnischen": "polytechnisch",
    "polytechnischer": "polytechnisch",
    "polytechnisches": "polytechnisch",
    "pomadigem": "pomadig",
    "pomadigen": "pomadig",
    "pomadiger": "pomadig",
    "pomadigere": "pomadig",
    "pomadigerem": "pomadig",
    "pomadigeren": "pomadig",
    "pomadigerer": "pomadig",
    "pomadigeres": "pomadig",
    "pomadiges": "pomadig",
    "pomadigste": "pomadig",
    "pomadigstem": "pomadig",
    "pomadigsten": "pomadig",
    "pomadigster": "pomadig",
    "pomadigstes": "pomadig",
    "pompösem": "pompös",
    "pompösen": "pompös",
    "pompöser": "pompös",
    "pompösere": "pompös",
    "pompöserem": "pompös",
    "pompöseren": "pompös",
    "pompöserer": "pompös",
    "pompöseres": "pompös",
    "pompöses": "pompös",
    "pompöseste": "pompös",
    "pompösestem": "pompös",
    "pompösesten": "pompös",
    "pompösester": "pompös",
    "pompösestes": "pompös",
    "popele": "popeln",
    "popelige": "popelig",
    "popeligem": "popelig",
    "popeligen": "popelig",
    "popeliger": "popelig",
    "popeligere": "popelig",
    "popeligerem": "popelig",
    "popeligeren": "popelig",
    "popeligerer": "popelig",
    "popeligeres": "popelig",
    "popeliges": "popelig",
    "popeligste": "popelig",
    "popeligstem": "popelig",
    "popeligsten": "popelig",
    "popeligster": "popelig",
    "popeligstes": "popelig",
    "popelnd": "popeln",
    "popelnde": "popelnd",
    "popelndem": "popelnd",
    "popelnden": "popelnd",
    "popelnder": "popelnd",
    "popelndere": "popelnd",
    "popelnderem": "popelnd",
    "popelnderen": "popelnd",
    "popelnderer": "popelnd",
    "popelnderes": "popelnd",
    "popelndes": "popelnd",
    "popelndste": "popelnd",
    "popelndstem": "popelnd",
    "popelndsten": "popelnd",
    "popelndster": "popelnd",
    "popelndstes": "popelnd",
    "popelst": "popeln",
    "popelt": "popeln",
    "popelte": "popeln",
    "popelten": "popeln",
    "popeltest": "popeln",
    "popeltet": "popeln",
    "pople": "popeln",
    "poplige": "poplig",
    "popligem": "poplig",
    "popligen": "poplig",
    "popliger": "poplig",
    "popligere": "poplig",
    "popligerem": "poplig",
    "popligeren": "poplig",
    "popligerer": "poplig",
    "popligeres": "poplig",
    "popliges": "poplig",
    "popligste": "poplig",
    "popligstem": "poplig",
    "popligsten": "poplig",
    "popligster": "poplig",
    "popligstes": "poplig",
    "poppe": "poppen",
    "poppend": "poppen",
    "poppende": "poppend",
    "poppendem": "poppend",
    "poppenden": "poppend",
    "poppender": "poppend",
    "poppendes": "poppend",
    "poppest": "poppen",
    "poppet": "poppen",
    "poppige": "poppig",
    "poppigem": "poppig",
    "poppigen": "poppig",
    "poppiger": "poppig",
    "poppigere": "poppig",
    "poppigerem": "poppig",
    "poppigeren": "poppig",
    "poppigerer": "poppig",
    "poppigeres": "poppig",
    "poppiges": "poppig",
    "poppigste": "poppig",
    "poppigstem": "poppig",
    "poppigsten": "poppig",
    "poppigster": "poppig",
    "poppigstes": "poppig",
    "poppst": "poppen",
    "poppt": "poppen",
    "poppte": "poppen",
    "poppten": "poppen",
    "popptest": "poppen",
    "popptet": "poppen",
    "popularisiere": "popularisieren",
    "popularisierend": "popularisieren",
    "popularisierende": "popularisierend",
    "popularisierendem": "popularisierend",
    "popularisierenden": "popularisierend",
    "popularisierender": "popularisierend",
    "popularisierendere": "popularisierend",
    "popularisierenderem": "popularisierend",
    "popularisierenderen": "popularisierend",
    "popularisierenderer": "popularisierend",
    "popularisierenderes": "popularisierend",
    "popularisierendes": "popularisierend",
    "popularisierendste": "popularisierend",
    "popularisierendstem": "popularisierend",
    "popularisierendsten": "popularisierend",
    "popularisierendster": "popularisierend",
    "popularisierendstes": "popularisierend",
    "popularisierest": "popularisieren",
    "popularisieret": "popularisieren",
    "popularisierst": "popularisieren",
    "popularisiert": "popularisieren",
    "popularisierte": "popularisieren",
    "popularisiertem": "popularisiert",
    "popularisierten": "popularisieren",
    "popularisierter": "popularisiert",
    "popularisiertere": "popularisiert",
    "popularisierterem": "popularisiert",
    "popularisierteren": "popularisiert",
    "popularisierterer": "popularisiert",
    "popularisierteres": "popularisiert",
    "popularisiertes": "popularisiert",
    "popularisiertest": "popularisieren",
    "popularisiertestem": "popularisiert",
    "popularisiertesten": "popularisiert",
    "popularisiertester": "popularisiert",
    "popularisiertestes": "popularisiert",
    "popularisiertet": "popularisieren",
    "populärem": "populär",
    "populären": "populär",
    "populärer": "populär",
    "populärere": "populär",
    "populärerem": "populär",
    "populäreren": "populär",
    "populärerer": "populär",
    "populäreres": "populär",
    "populäres": "populär",
    "populärstem": "populär",
    "populärsten": "populär",
    "populärster": "populär",
    "populärstes": "populär",
    "porigem": "porig",
    "porigen": "porig",
    "poriger": "porig",
    "porigere": "porig",
    "porigerem": "porig",
    "porigeren": "porig",
    "porigerer": "porig",
    "porigeres": "porig",
    "poriges": "porig",
    "porigste": "porig",
    "porigstem": "porig",
    "porigsten": "porig",
    "porigster": "porig",
    "porigstes": "porig",
    "pornographischem": "pornographisch",
    "pornographischen": "pornographisch",
    "pornographischer": "pornographisch",
    "pornographisches": "pornographisch",
    "portiere": "portieren",
    "portierend": "portieren",
    "portierende": "portierend",
    "portierendem": "portierend",
    "portierenden": "portierend",
    "portierender": "portierend",
    "portierendes": "portierend",
    "portierest": "portieren",
    "portieret": "portieren",
    "portierst": "portieren",
    "portiert": "portieren",
    "portierte": "portieren",
    "portiertem": "portiert",
    "portierten": "portieren",
    "portierter": "portiert",
    "portiertes": "portiert",
    "portiertest": "portieren",
    "portiertet": "portieren",
    "portioniere": "portionieren",
    "portionierend": "portionieren",
    "portionierende": "portionierend",
    "portionierendem": "portionierend",
    "portionierenden": "portionierend",
    "portionierender": "portionierend",
    "portionierendes": "portionierend",
    "portionierest": "portionieren",
    "portionieret": "portionieren",
    "portionierst": "portionieren",
    "portioniert": "portionieren",
    "portionierte": "portionieren",
    "portioniertem": "portioniert",
    "portionierten": "portionieren",
    "portionierter": "portioniert",
    "portioniertes": "portioniert",
    "portioniertest": "portionieren",
    "portioniertet": "portionieren",
    "portofreie": "portofrei",
    "portofreiem": "portofrei",
    "portofreien": "portofrei",
    "portofreier": "portofrei",
    "portofreies": "portofrei",
    "porträtiere": "porträtieren",
    "porträtierend": "porträtieren",
    "porträtierende": "porträtierend",
    "porträtierendem": "porträtierend",
    "porträtierenden": "porträtierend",
    "porträtierender": "porträtierend",
    "porträtierendes": "porträtierend",
    "porträtierest": "porträtieren",
    "porträtieret": "porträtieren",
    "porträtierst": "porträtieren",
    "porträtiert": "porträtieren",
    "porträtierte": "porträtieren",
    "porträtiertem": "porträtiert",
    "porträtierten": "porträtieren",
    "porträtierter": "porträtiert",
    "porträtiertes": "porträtiert",
    "porträtiertest": "porträtieren",
    "porträtiertet": "porträtieren",
    "portugiesischem": "portugiesisch",
    "portugiesischen": "portugiesisch",
    "portugiesischer": "portugiesisch",
    "portugiesischere": "portugiesisch",
    "portugiesischerem": "portugiesisch",
    "portugiesischeren": "portugiesisch",
    "portugiesischerer": "portugiesisch",
    "portugiesischeres": "portugiesisch",
    "portugiesisches": "portugiesisch",
    "portugiesischste": "portugiesisch",
    "portugiesischstem": "portugiesisch",
    "portugiesischsten": "portugiesisch",
    "portugiesischster": "portugiesisch",
    "portugiesischstes": "portugiesisch",
    "porösem": "porös",
    "porösen": "porös",
    "poröser": "porös",
    "porösere": "porös",
    "poröserem": "porös",
    "poröseren": "porös",
    "poröserer": "porös",
    "poröseres": "porös",
    "poröses": "porös",
    "poröseste": "porös",
    "porösestem": "porös",
    "porösesten": "porös",
    "porösester": "porös",
    "porösestes": "porös",
    "posaunend": "posaunen",
    "posaunende": "posaunend",
    "posaunendem": "posaunend",
    "posaunenden": "posaunend",
    "posaunender": "posaunend",
    "posaunendes": "posaunend",
    "posaunest": "posaunen",
    "posaunet": "posaunen",
    "posaunst": "posaunen",
    "posaunt": "posaunen",
    "posaunte": "posaunen",
    "posauntem": "posaunt",
    "posaunten": "posaunen",
    "posaunter": "posaunt",
    "posauntes": "posaunt",
    "posauntest": "posaunen",
    "posauntet": "posaunen",
    "posiere": "posieren",
    "posierend": "posieren",
    "posierende": "posierend",
    "posierendem": "posierend",
    "posierenden": "posierend",
    "posierender": "posierend",
    "posierendes": "posierend",
    "posierest": "posieren",
    "posieret": "posieren",
    "posierst": "posieren",
    "posiert": "posieren",
    "posierte": "posieren",
    "posiertem": "posiert",
    "posierten": "posieren",
    "posierter": "posiert",
    "posiertes": "posiert",
    "posiertest": "posieren",
    "posiertet": "posieren",
    "positioniere": "positionieren",
    "positionierend": "positionieren",
    "positionierende": "positionierend",
    "positionierendem": "positionierend",
    "positionierenden": "positionierend",
    "positionierender": "positionierend",
    "positionierendes": "positionierend",
    "positionierest": "positionieren",
    "positionieret": "positionieren",
    "positionierst": "positionieren",
    "positioniert": "positionieren",
    "positionierte": "positionieren",
    "positioniertem": "positioniert",
    "positionierten": "positionieren",
    "positionierter": "positioniert",
    "positioniertes": "positioniert",
    "positioniertest": "positionieren",
    "positioniertet": "positionieren",
    "positive": "positiv",
    "positivem": "positiv",
    "positiven": "positiv",
    "positiver": "positiv",
    "positivere": "positiv",
    "positiverem": "positiv",
    "positiveren": "positiv",
    "positiverer": "positiv",
    "positiveres": "positiv",
    "positives": "positiv",
    "positivstem": "positiv",
    "positivsten": "positiv",
    "positivster": "positiv",
    "positivstes": "positiv",
    "possenhaftem": "possenhaft",
    "possenhaften": "possenhaft",
    "possenhafter": "possenhaft",
    "possenhaftere": "possenhaft",
    "possenhafterem": "possenhaft",
    "possenhafteren": "possenhaft",
    "possenhafterer": "possenhaft",
    "possenhafteres": "possenhaft",
    "possenhaftes": "possenhaft",
    "possenhafteste": "possenhaft",
    "possenhaftestem": "possenhaft",
    "possenhaftesten": "possenhaft",
    "possenhaftester": "possenhaft",
    "possenhaftestes": "possenhaft",
    "possierlichem": "possierlich",
    "possierlichen": "possierlich",
    "possierlicher": "possierlich",
    "possierlichere": "possierlich",
    "possierlicherem": "possierlich",
    "possierlicheren": "possierlich",
    "possierlicherer": "possierlich",
    "possierlicheres": "possierlich",
    "possierliches": "possierlich",
    "possierlichste": "possierlich",
    "possierlichstem": "possierlich",
    "possierlichsten": "possierlich",
    "possierlichster": "possierlich",
    "possierlichstes": "possierlich",
    "postalische": "postalisch",
    "postalischem": "postalisch",
    "postalischen": "postalisch",
    "postalischer": "postalisch",
    "postalisches": "postalisch",
    "postfrischem": "postfrisch",
    "postfrischen": "postfrisch",
    "postfrischer": "postfrisch",
    "postfrisches": "postfrisch",
    "posthumem": "posthum",
    "posthumen": "posthum",
    "posthumer": "posthum",
    "posthumes": "posthum",
    "postiere": "postieren",
    "postierend": "postieren",
    "postierende": "postierend",
    "postierendem": "postierend",
    "postierenden": "postierend",
    "postierender": "postierend",
    "postierendes": "postierend",
    "postierest": "postieren",
    "postieret": "postieren",
    "postierst": "postieren",
    "postiert": "postieren",
    "postierte": "postieren",
    "postiertem": "postiert",
    "postierten": "postieren",
    "postierter": "postiert",
    "postiertes": "postiert",
    "postiertest": "postieren",
    "postiertet": "postieren",
    "postlagernde": "postlagernd",
    "postlagerndem": "postlagernd",
    "postlagernden": "postlagernd",
    "postlagernder": "postlagernd",
    "postlagerndes": "postlagernd",
    "postmoderne": "postmodern",
    "postmodernem": "postmodern",
    "postmodernen": "postmodern",
    "postmoderner": "postmodern",
    "postmodernes": "postmodern",
    "postmortale": "postmortal",
    "postmortalem": "postmortal",
    "postmortalen": "postmortal",
    "postmortaler": "postmortal",
    "postmortales": "postmortal",
    "postnatale": "postnatal",
    "postnatalem": "postnatal",
    "postnatalen": "postnatal",
    "postnataler": "postnatal",
    "postnatales": "postnatal",
    "postnationale": "postnational",
    "postnationalem": "postnational",
    "postnationalen": "postnational",
    "postnationaler": "postnational",
    "postnationalere": "postnational",
    "postnationalerem": "postnational",
    "postnationaleren": "postnational",
    "postnationalerer": "postnational",
    "postnationaleres": "postnational",
    "postnationales": "postnational",
    "postnationalste": "postnational",
    "postnationalstem": "postnational",
    "postnationalsten": "postnational",
    "postnationalster": "postnational",
    "postnationalstes": "postnational",
    "postoperative": "postoperativ",
    "postoperativem": "postoperativ",
    "postoperativen": "postoperativ",
    "postoperativer": "postoperativ",
    "postoperatives": "postoperativ",
    "posttraumatische": "posttraumatisch",
    "posttraumatischem": "posttraumatisch",
    "posttraumatischen": "posttraumatisch",
    "posttraumatischer": "posttraumatisch",
    "posttraumatisches": "posttraumatisch",
    "postuliere": "postulieren",
    "postulierend": "postulieren",
    "postulierende": "postulierend",
    "postulierendem": "postulierend",
    "postulierenden": "postulierend",
    "postulierender": "postulierend",
    "postulierendes": "postulierend",
    "postulierest": "postulieren",
    "postulieret": "postulieren",
    "postulierst": "postulieren",
    "postuliert": "postulieren",
    "postulierte": "postulieren",
    "postuliertem": "postuliert",
    "postulierten": "postulieren",
    "postulierter": "postuliert",
    "postuliertes": "postuliert",
    "postuliertest": "postulieren",
    "postuliertet": "postulieren",
    "postwendende": "postwendend",
    "postwendendem": "postwendend",
    "postwendenden": "postwendend",
    "postwendender": "postwendend",
    "postwendendes": "postwendend",
    "potente": "potent",
    "potentem": "potent",
    "potenten": "potent",
    "potenter": "potent",
    "potentere": "potent",
    "potenterem": "potent",
    "potenteren": "potent",
    "potenterer": "potent",
    "potenteres": "potent",
    "potentes": "potent",
    "potenteste": "potent",
    "potentestem": "potent",
    "potentesten": "potent",
    "potentester": "potent",
    "potentestes": "potent",
    "potentiellem": "potentiell",
    "potentiellen": "potentiell",
    "potentieller": "potentiell",
    "potentiellere": "potentiell",
    "potentiellerem": "potentiell",
    "potentielleren": "potentiell",
    "potentiellerer": "potentiell",
    "potentielleres": "potentiell",
    "potentielles": "potentiell",
    "potentiellste": "potentiell",
    "potentiellstem": "potentiell",
    "potentiellsten": "potentiell",
    "potentiellster": "potentiell",
    "potentiellstes": "potentiell",
    "potenziere": "potenzieren",
    "potenzierend": "potenzieren",
    "potenzierende": "potenzierend",
    "potenzierendem": "potenzierend",
    "potenzierenden": "potenzierend",
    "potenzierender": "potenzierend",
    "potenzierendes": "potenzierend",
    "potenzierest": "potenzieren",
    "potenzieret": "potenzieren",
    "potenzierst": "potenzieren",
    "potenziert": "potenzieren",
    "potenzierte": "potenzieren",
    "potenziertem": "potenziert",
    "potenzierten": "potenzieren",
    "potenzierter": "potenziert",
    "potenziertes": "potenziert",
    "potenziertest": "potenzieren",
    "potenziertet": "potenzieren",
    "potthäßlichem": "potthäßlich",
    "potthäßlichen": "potthäßlich",
    "potthäßlicher": "potthäßlich",
    "potthäßliches": "potthäßlich",
    "powere": "powern",
    "powernd": "powern",
    "powernde": "powernd",
    "powerndem": "powernd",
    "powernden": "powernd",
    "powernder": "powernd",
    "powerndere": "powernd",
    "powernderem": "powernd",
    "powernderen": "powernd",
    "powernderer": "powernd",
    "powernderes": "powernd",
    "powerndes": "powernd",
    "powerndste": "powernd",
    "powerndstem": "powernd",
    "powerndsten": "powernd",
    "powerndster": "powernd",
    "powerndstes": "powernd",
    "powerst": "powern",
    "powert": "powern",
    "powerte": "powern",
    "powerten": "powern",
    "powertest": "powern",
    "powertet": "powern",
    "prachtvollem": "prachtvoll",
    "prachtvollen": "prachtvoll",
    "prachtvoller": "prachtvoll",
    "prachtvollere": "prachtvoll",
    "prachtvollerem": "prachtvoll",
    "prachtvolleren": "prachtvoll",
    "prachtvollerer": "prachtvoll",
    "prachtvolleres": "prachtvoll",
    "prachtvolles": "prachtvoll",
    "prachtvollste": "prachtvoll",
    "prachtvollstem": "prachtvoll",
    "prachtvollsten": "prachtvoll",
    "prachtvollster": "prachtvoll",
    "prachtvollstes": "prachtvoll",
    "pragmatischem": "pragmatisch",
    "pragmatischen": "pragmatisch",
    "pragmatischer": "pragmatisch",
    "pragmatischere": "pragmatisch",
    "pragmatischerem": "pragmatisch",
    "pragmatischeren": "pragmatisch",
    "pragmatischerer": "pragmatisch",
    "pragmatischeres": "pragmatisch",
    "pragmatisches": "pragmatisch",
    "pragmatischste": "pragmatisch",
    "pragmatischstem": "pragmatisch",
    "pragmatischsten": "pragmatisch",
    "pragmatischster": "pragmatisch",
    "pragmatischstes": "pragmatisch",
    "prahle": "prahlen",
    "prahlend": "prahlen",
    "prahlende": "prahlend",
    "prahlendem": "prahlend",
    "prahlenden": "prahlend",
    "prahlender": "prahlend",
    "prahlendere": "prahlend",
    "prahlenderem": "prahlend",
    "prahlenderen": "prahlend",
    "prahlenderer": "prahlend",
    "prahlenderes": "prahlend",
    "prahlendes": "prahlend",
    "prahlendste": "prahlend",
    "prahlendstem": "prahlend",
    "prahlendsten": "prahlend",
    "prahlendster": "prahlend",
    "prahlendstes": "prahlend",
    "prahlerischem": "prahlerisch",
    "prahlerischen": "prahlerisch",
    "prahlerischer": "prahlerisch",
    "prahlerischere": "prahlerisch",
    "prahlerischerem": "prahlerisch",
    "prahlerischeren": "prahlerisch",
    "prahlerischerer": "prahlerisch",
    "prahlerischeres": "prahlerisch",
    "prahlerisches": "prahlerisch",
    "prahlerischste": "prahlerisch",
    "prahlerischstem": "prahlerisch",
    "prahlerischsten": "prahlerisch",
    "prahlerischster": "prahlerisch",
    "prahlerischstes": "prahlerisch",
    "prahlest": "prahlen",
    "prahlet": "prahlen",
    "prahlst": "prahlen",
    "prahlt": "prahlen",
    "prahlte": "prahlen",
    "prahlten": "prahlen",
    "prahltest": "prahlen",
    "prahltet": "prahlen",
    "praktikabelstem": "praktikabel",
    "praktikabelsten": "praktikabel",
    "praktikabelster": "praktikabel",
    "praktikabelstes": "praktikabel",
    "praktikable": "praktikabel",
    "praktikablem": "praktikabel",
    "praktikablen": "praktikabel",
    "praktikabler": "praktikabel",
    "praktikablere": "praktikabel",
    "praktikablerem": "praktikabel",
    "praktikableren": "praktikabel",
    "praktikablerer": "praktikabel",
    "praktikableres": "praktikabel",
    "praktikables": "praktikabel",
    "praktischem": "praktisch",
    "praktischen": "praktisch",
    "praktischer": "praktisch",
    "praktischere": "praktisch",
    "praktischerem": "praktisch",
    "praktischeren": "praktisch",
    "praktischerer": "praktisch",
    "praktischeres": "praktisch",
    "praktisches": "praktisch",
    "praktischste": "praktisch",
    "praktischstem": "praktisch",
    "praktischsten": "praktisch",
    "praktischster": "praktisch",
    "praktischstes": "praktisch",
    "praktiziere": "praktizieren",
    "praktizierend": "praktizieren",
    "praktizierende": "praktizierend",
    "praktizierendem": "praktizierend",
    "praktizierenden": "praktizierend",
    "praktizierender": "praktizierend",
    "praktizierendes": "praktizierend",
    "praktizierest": "praktizieren",
    "praktizieret": "praktizieren",
    "praktizierst": "praktizieren",
    "praktiziert": "praktizieren",
    "praktizierte": "praktizieren",
    "praktiziertem": "praktiziert",
    "praktizierten": "praktizieren",
    "praktizierter": "praktiziert",
    "praktiziertes": "praktiziert",
    "praktiziertest": "praktizieren",
    "praktiziertet": "praktizieren",
    "pralle": "prallen",
    "prallend": "prallen",
    "prallende": "prallend",
    "prallendem": "prallend",
    "prallenden": "prallend",
    "prallender": "prallend",
    "prallendes": "prallend",
    "prallest": "prallen",
    "prallet": "prallen",
    "prallst": "prallen",
    "prallt": "prallen",
    "prallte": "prallen",
    "prallten": "prallen",
    "pralltest": "prallen",
    "pralltet": "prallen",
    "prange": "prangen",
    "prangend": "prangen",
    "prangende": "prangend",
    "prangendem": "prangend",
    "prangenden": "prangend",
    "prangender": "prangend",
    "prangendes": "prangend",
    "prangere": "prangern",
    "prangernd": "prangern",
    "prangernde": "prangernd",
    "prangerndem": "prangernd",
    "prangernden": "prangernd",
    "prangernder": "prangernd",
    "prangerndere": "prangernd",
    "prangernderem": "prangernd",
    "prangernderen": "prangernd",
    "prangernderer": "prangernd",
    "prangernderes": "prangernd",
    "prangerndes": "prangernd",
    "prangerndste": "prangernd",
    "prangerndstem": "prangernd",
    "prangerndsten": "prangernd",
    "prangerndster": "prangernd",
    "prangerndstes": "prangernd",
    "prangerst": "prangern",
    "prangert": "prangern",
    "prangerte": "prangern",
    "prangerten": "prangern",
    "prangertest": "prangern",
    "prangertet": "prangern",
    "prangest": "prangen",
    "pranget": "prangen",
    "prangst": "prangen",
    "prangt": "prangen",
    "prangte": "prangen",
    "prangten": "prangen",
    "prangtest": "prangen",
    "prangtet": "prangen",
    "prassele": "prasseln",
    "prasselnd": "prasseln",
    "prasselnde": "prasselnd",
    "prasselndem": "prasselnd",
    "prasselnden": "prasselnd",
    "prasselnder": "prasselnd",
    "prasselndes": "prasselnd",
    "prasselst": "prasseln",
    "prasselt": "prasseln",
    "prasselte": "prasseln",
    "prasselten": "prasseln",
    "prasseltest": "prasseln",
    "prasseltet": "prasseln",
    "prassle": "prasseln",
    "praxisreifem": "praxisreif",
    "praxisreifen": "praxisreif",
    "praxisreifer": "praxisreif",
    "praxisreifere": "praxisreif",
    "praxisreiferem": "praxisreif",
    "praxisreiferen": "praxisreif",
    "praxisreiferer": "praxisreif",
    "praxisreiferes": "praxisreif",
    "praxisreifes": "praxisreif",
    "praxisreifste": "praxisreif",
    "praxisreifstem": "praxisreif",
    "praxisreifsten": "praxisreif",
    "praxisreifster": "praxisreif",
    "praxisreifstes": "praxisreif",
    "predige": "predigen",
    "predigend": "predigen",
    "predigende": "predigend",
    "predigendem": "predigend",
    "predigenden": "predigend",
    "predigender": "predigend",
    "predigendere": "predigend",
    "predigenderem": "predigend",
    "predigenderen": "predigend",
    "predigenderer": "predigend",
    "predigenderes": "predigend",
    "predigendes": "predigend",
    "predigendste": "predigend",
    "predigendstem": "predigend",
    "predigendsten": "predigend",
    "predigendster": "predigend",
    "predigendstes": "predigend",
    "predigest": "predigen",
    "prediget": "predigen",
    "predigst": "predigen",
    "predigt": "predigen",
    "predigte": "predigen",
    "predigten": "predigen",
    "predigtest": "predigen",
    "predigtet": "predigen",
    "preisend": "preisen",
    "preisende": "preisend",
    "preisendem": "preisend",
    "preisenden": "preisend",
    "preisender": "preisend",
    "preisendes": "preisend",
    "preisest": "preisen",
    "preiset": "preisen",
    "preisgab": "preisgeben",
    "preisgaben": "preisgeben",
    "preisgabst": "preisgeben",
    "preisgabt": "preisgeben",
    "preisgebe": "preisgeben",
    "preisgebend": "preisgeben",
    "preisgebende": "preisgebend",
    "preisgebendem": "preisgebend",
    "preisgebenden": "preisgebend",
    "preisgebender": "preisgebend",
    "preisgebendes": "preisgebend",
    "preisgebest": "preisgeben",
    "preisgebet": "preisgeben",
    "preisgebt": "preisgeben",
    "preisgebundene": "preisgebunden",
    "preisgebundenem": "preisgebunden",
    "preisgebundenen": "preisgebunden",
    "preisgebundener": "preisgebunden",
    "preisgebundenes": "preisgebunden",
    "preisgegeben": "preisgeben",
    "preisgegebene": "preisgegeben",
    "preisgegebenem": "preisgegeben",
    "preisgegebenen": "preisgegeben",
    "preisgegebener": "preisgegeben",
    "preisgegebenere": "preisgegeben",
    "preisgegebenerem": "preisgegeben",
    "preisgegebeneren": "preisgegeben",
    "preisgegebenerer": "preisgegeben",
    "preisgegebeneres": "preisgegeben",
    "preisgegebenes": "preisgegeben",
    "preisgegebenste": "preisgegeben",
    "preisgegebenstem": "preisgegeben",
    "preisgegebensten": "preisgegeben",
    "preisgegebenster": "preisgegeben",
    "preisgegebenstes": "preisgegeben",
    "preisgekrönte": "preisgekrönt",
    "preisgekröntem": "preisgekrönt",
    "preisgekrönten": "preisgekrönt",
    "preisgekrönter": "preisgekrönt",
    "preisgekröntes": "preisgekrönt",
    "preisgibst": "preisgeben",
    "preisgibt": "preisgeben",
    "preisgäbe": "preisgeben",
    "preisgäben": "preisgeben",
    "preisgäbest": "preisgeben",
    "preisgäbet": "preisgeben",
    "preisgünstige": "preisgünstig",
    "preisgünstigem": "preisgünstig",
    "preisgünstigen": "preisgünstig",
    "preisgünstiger": "preisgünstig",
    "preisgünstigere": "preisgünstig",
    "preisgünstigerem": "preisgünstig",
    "preisgünstigeren": "preisgünstig",
    "preisgünstigerer": "preisgünstig",
    "preisgünstigeres": "preisgünstig",
    "preisgünstiges": "preisgünstig",
    "preisgünstigste": "preisgünstig",
    "preisgünstigstem": "preisgünstig",
    "preisgünstigsten": "preisgünstig",
    "preisgünstigster": "preisgünstig",
    "preisgünstigstes": "preisgünstig",
    "preisliche": "preislich",
    "preislichem": "preislich",
    "preislichen": "preislich",
    "preislicher": "preislich",
    "preisliches": "preislich",
    "preist": "preisen",
    "preiswerte": "preiswert",
    "preiswertem": "preiswert",
    "preiswerten": "preiswert",
    "preiswerter": "preiswert",
    "preiswertere": "preiswert",
    "preiswerterem": "preiswert",
    "preiswerteren": "preiswert",
    "preiswerterer": "preiswert",
    "preiswerteres": "preiswert",
    "preiswertes": "preiswert",
    "preiswerteste": "preiswert",
    "preiswertestem": "preiswert",
    "preiswertesten": "preiswert",
    "preiswertester": "preiswert",
    "preiswertestes": "preiswert",
    "preiswürdige": "preiswürdig",
    "preiswürdigem": "preiswürdig",
    "preiswürdigen": "preiswürdig",
    "preiswürdiger": "preiswürdig",
    "preiswürdigere": "preiswürdig",
    "preiswürdigerem": "preiswürdig",
    "preiswürdigeren": "preiswürdig",
    "preiswürdigerer": "preiswürdig",
    "preiswürdigeres": "preiswürdig",
    "preiswürdiges": "preiswürdig",
    "preiswürdigste": "preiswürdig",
    "preiswürdigstem": "preiswürdig",
    "preiswürdigsten": "preiswürdig",
    "preiswürdigster": "preiswürdig",
    "preiswürdigstes": "preiswürdig",
    "preiszugeben": "preisgeben",
    "prekäre": "prekär",
    "prekärem": "prekär",
    "prekären": "prekär",
    "prekärer": "prekär",
    "prekärere": "prekär",
    "prekärerem": "prekär",
    "prekäreren": "prekär",
    "prekärerer": "prekär",
    "prekäreres": "prekär",
    "prekäres": "prekär",
    "prekärste": "prekär",
    "prekärstem": "prekär",
    "prekärsten": "prekär",
    "prekärster": "prekär",
    "prekärstes": "prekär",
    "prelle": "prellen",
    "prellend": "prellen",
    "prellende": "prellend",
    "prellendem": "prellend",
    "prellenden": "prellend",
    "prellender": "prellend",
    "prellendere": "prellend",
    "prellenderem": "prellend",
    "prellenderen": "prellend",
    "prellenderer": "prellend",
    "prellenderes": "prellend",
    "prellendes": "prellend",
    "prellendste": "prellend",
    "prellendstem": "prellend",
    "prellendsten": "prellend",
    "prellendster": "prellend",
    "prellendstes": "prellend",
    "prellest": "prellen",
    "prellet": "prellen",
    "prellst": "prellen",
    "prellt": "prellen",
    "prellte": "prellen",
    "prellten": "prellen",
    "prelltest": "prellen",
    "prelltet": "prellen",
    "presche": "preschen",
    "preschend": "preschen",
    "preschende": "preschend",
    "preschendem": "preschend",
    "preschenden": "preschend",
    "preschender": "preschend",
    "preschendes": "preschend",
    "preschest": "preschen",
    "preschet": "preschen",
    "preschst": "preschen",
    "prescht": "preschen",
    "preschte": "preschen",
    "preschten": "preschen",
    "preschtest": "preschen",
    "preschtet": "preschen",
    "presse": "pressen",
    "pressend": "pressen",
    "pressende": "pressend",
    "pressendem": "pressend",
    "pressenden": "pressend",
    "pressender": "pressend",
    "pressendes": "pressend",
    "pressest": "pressen",
    "presset": "pressen",
    "pressiere": "pressieren",
    "pressierend": "pressieren",
    "pressierende": "pressierend",
    "pressierendem": "pressierend",
    "pressierenden": "pressierend",
    "pressierender": "pressierend",
    "pressierendere": "pressierend",
    "pressierenderem": "pressierend",
    "pressierenderen": "pressierend",
    "pressierenderer": "pressierend",
    "pressierenderes": "pressierend",
    "pressierendes": "pressierend",
    "pressierendste": "pressierend",
    "pressierendstem": "pressierend",
    "pressierendsten": "pressierend",
    "pressierendster": "pressierend",
    "pressierendstes": "pressierend",
    "pressierest": "pressieren",
    "pressieret": "pressieren",
    "pressierst": "pressieren",
    "pressiert": "pressieren",
    "pressierte": "pressieren",
    "pressiertem": "pressiert",
    "pressierten": "pressieren",
    "pressierter": "pressiert",
    "pressiertere": "pressiert",
    "pressierterem": "pressiert",
    "pressierteren": "pressiert",
    "pressierterer": "pressiert",
    "pressierteres": "pressiert",
    "pressiertes": "pressiert",
    "pressiertest": "pressieren",
    "pressierteste": "pressiert",
    "pressiertestem": "pressiert",
    "pressiertesten": "pressiert",
    "pressiertester": "pressiert",
    "pressiertestes": "pressiert",
    "pressiertet": "pressieren",
    "preußischem": "preußisch",
    "preußischen": "preußisch",
    "preußischer": "preußisch",
    "preußischere": "preußisch",
    "preußischerem": "preußisch",
    "preußischeren": "preußisch",
    "preußischerer": "preußisch",
    "preußischeres": "preußisch",
    "preußisches": "preußisch",
    "preußischste": "preußisch",
    "preußischstem": "preußisch",
    "preußischsten": "preußisch",
    "preußischster": "preußisch",
    "preußischstes": "preußisch",
    "preßt": "pressen",
    "preßte": "pressen",
    "preßten": "pressen",
    "preßtest": "pressen",
    "preßtet": "pressen",
    "pries": "preisen",
    "priese": "preisen",
    "priesen": "preisen",
    "priesest": "preisen",
    "prieset": "preisen",
    "priest": "preisen",
    "priesterliche": "priesterlich",
    "priesterlichem": "priesterlich",
    "priesterlichen": "priesterlich",
    "priesterlicher": "priesterlich",
    "priesterliches": "priesterlich",
    "primitivem": "primitiv",
    "primitiven": "primitiv",
    "primitiver": "primitiv",
    "primitivere": "primitiv",
    "primitiverem": "primitiv",
    "primitiveren": "primitiv",
    "primitiverer": "primitiv",
    "primitiveres": "primitiv",
    "primitives": "primitiv",
    "primitivste": "primitiv",
    "primitivstem": "primitiv",
    "primitivsten": "primitiv",
    "primitivster": "primitiv",
    "primitivstes": "primitiv",
    "primärem": "primär",
    "primären": "primär",
    "primärer": "primär",
    "primäres": "primär",
    "prinzipiellem": "prinzipiell",
    "prinzipiellen": "prinzipiell",
    "prinzipieller": "prinzipiell",
    "prinzipielles": "prinzipiell",
    "pritschend": "pritschen",
    "pritschende": "pritschend",
    "pritschendem": "pritschend",
    "pritschenden": "pritschend",
    "pritschender": "pritschend",
    "pritschendes": "pritschend",
    "pritschest": "pritschen",
    "pritschet": "pritschen",
    "pritschst": "pritschen",
    "pritscht": "pritschen",
    "pritschte": "pritschen",
    "pritschten": "pritschen",
    "pritschtest": "pritschen",
    "pritschtet": "pritschen",
    "private": "privat",
    "privatem": "privat",
    "privaten": "privat",
    "privater": "privat",
    "privatere": "privat",
    "privaterem": "privat",
    "privateren": "privat",
    "privaterer": "privat",
    "privateres": "privat",
    "privates": "privat",
    "privateste": "privat",
    "privatestem": "privat",
    "privatesten": "privat",
    "privatester": "privat",
    "privatestes": "privat",
    "privatisiere": "privatisieren",
    "privatisierend": "privatisieren",
    "privatisierende": "privatisierend",
    "privatisierendem": "privatisierend",
    "privatisierenden": "privatisierend",
    "privatisierender": "privatisierend",
    "privatisierendes": "privatisierend",
    "privatisierest": "privatisieren",
    "privatisieret": "privatisieren",
    "privatisierst": "privatisieren",
    "privatisiert": "privatisieren",
    "privatisierte": "privatisieren",
    "privatisiertem": "privatisiert",
    "privatisierten": "privatisieren",
    "privatisierter": "privatisiert",
    "privatisiertere": "privatisiert",
    "privatisierterem": "privatisiert",
    "privatisierteren": "privatisiert",
    "privatisierterer": "privatisiert",
    "privatisierteres": "privatisiert",
    "privatisiertes": "privatisiert",
    "privatisiertest": "privatisieren",
    "privatisierteste": "privatisiert",
    "privatisiertestem": "privatisiert",
    "privatisiertesten": "privatisiert",
    "privatisiertester": "privatisiert",
    "privatisiertestes": "privatisiert",
    "privatisiertet": "privatisieren",
    "probatem": "probat",
    "probaten": "probat",
    "probater": "probat",
    "probatere": "probat",
    "probaterem": "probat",
    "probateren": "probat",
    "probaterer": "probat",
    "probateres": "probat",
    "probates": "probat",
    "probateste": "probat",
    "probatestem": "probat",
    "probatesten": "probat",
    "probatester": "probat",
    "probatestes": "probat",
    "probe": "proben",
    "probend": "proben",
    "probende": "probend",
    "probendem": "probend",
    "probenden": "probend",
    "probender": "probend",
    "probendes": "probend",
    "probest": "proben",
    "probet": "proben",
    "probiere": "probieren",
    "probierend": "probieren",
    "probierende": "probierend",
    "probierendem": "probierend",
    "probierenden": "probierend",
    "probierender": "probierend",
    "probierendes": "probierend",
    "probierest": "probieren",
    "probieret": "probieren",
    "probierst": "probieren",
    "probiert": "probieren",
    "probierte": "probieren",
    "probiertem": "probiert",
    "probierten": "probieren",
    "probierter": "probiert",
    "probiertes": "probiert",
    "probiertest": "probieren",
    "probiertet": "probieren",
    "problematischem": "problematisch",
    "problematischen": "problematisch",
    "problematischer": "problematisch",
    "problematischere": "problematisch",
    "problematischerem": "problematisch",
    "problematischeren": "problematisch",
    "problematischerer": "problematisch",
    "problematischeres": "problematisch",
    "problematisches": "problematisch",
    "problematischste": "problematisch",
    "problematischstem": "problematisch",
    "problematischsten": "problematisch",
    "problematischster": "problematisch",
    "problematischstes": "problematisch",
    "problematisiere": "problematisieren",
    "problematisierend": "problematisieren",
    "problematisierende": "problematisierend",
    "problematisierendem": "problematisierend",
    "problematisierenden": "problematisierend",
    "problematisierender": "problematisierend",
    "problematisierendes": "problematisierend",
    "problematisierest": "problematisieren",
    "problematisieret": "problematisieren",
    "problematisierst": "problematisieren",
    "problematisiert": "problematisieren",
    "problematisierte": "problematisieren",
    "problematisiertem": "problematisiert",
    "problematisierten": "problematisieren",
    "problematisierter": "problematisiert",
    "problematisiertes": "problematisiert",
    "problematisiertest": "problematisieren",
    "problematisiertet": "problematisieren",
    "problemgeladenem": "problemgeladen",
    "problemgeladenen": "problemgeladen",
    "problemgeladener": "problemgeladen",
    "problemgeladenere": "problemgeladen",
    "problemgeladenerem": "problemgeladen",
    "problemgeladeneren": "problemgeladen",
    "problemgeladenerer": "problemgeladen",
    "problemgeladeneres": "problemgeladen",
    "problemgeladenes": "problemgeladen",
    "problemgeladenste": "problemgeladen",
    "problemgeladenstem": "problemgeladen",
    "problemgeladensten": "problemgeladen",
    "problemgeladenster": "problemgeladen",
    "problemgeladenstes": "problemgeladen",
    "problemlose": "problemlos",
    "problemlosem": "problemlos",
    "problemlosen": "problemlos",
    "problemloser": "problemlos",
    "problemlosere": "problemlos",
    "problemloserem": "problemlos",
    "problemloseren": "problemlos",
    "problemloserer": "problemlos",
    "problemloseres": "problemlos",
    "problemloses": "problemlos",
    "problemloseste": "problemlos",
    "problemlosestem": "problemlos",
    "problemlosesten": "problemlos",
    "problemlosester": "problemlos",
    "problemlosestes": "problemlos",
    "problemorientierte": "problemorientiert",
    "problemorientiertem": "problemorientiert",
    "problemorientierten": "problemorientiert",
    "problemorientierter": "problemorientiert",
    "problemorientiertere": "problemorientiert",
    "problemorientierterem": "problemorientiert",
    "problemorientierteren": "problemorientiert",
    "problemorientierterer": "problemorientiert",
    "problemorientierteres": "problemorientiert",
    "problemorientiertes": "problemorientiert",
    "problemorientierteste": "problemorientiert",
    "problemorientiertestem": "problemorientiert",
    "problemorientiertesten": "problemorientiert",
    "problemorientiertester": "problemorientiert",
    "problemorientiertestes": "problemorientiert",
    "probst": "proben",
    "probt": "proben",
    "probte": "proben",
    "probten": "proben",
    "probtest": "proben",
    "probtet": "proben",
    "produktivem": "produktiv",
    "produktiven": "produktiv",
    "produktiver": "produktiv",
    "produktivere": "produktiv",
    "produktiverem": "produktiv",
    "produktiveren": "produktiv",
    "produktiverer": "produktiv",
    "produktiveres": "produktiv",
    "produktives": "produktiv",
    "produktivstem": "produktiv",
    "produktivsten": "produktiv",
    "produktivster": "produktiv",
    "produktivstes": "produktiv",
    "produziere": "produzieren",
    "produzierend": "produzieren",
    "produzierende": "produzierend",
    "produzierendem": "produzierend",
    "produzierenden": "produzierend",
    "produzierender": "produzierend",
    "produzierendes": "produzierend",
    "produzierest": "produzieren",
    "produzieret": "produzieren",
    "produzierst": "produzieren",
    "produziert": "produzieren",
    "produzierte": "produzieren",
    "produziertem": "produziert",
    "produzierten": "produzieren",
    "produzierter": "produziert",
    "produziertes": "produziert",
    "produziertest": "produzieren",
    "produziertet": "produzieren",
    "profane": "profan",
    "profanem": "profan",
    "profanen": "profan",
    "profaner": "profan",
    "profanere": "profan",
    "profanerem": "profan",
    "profaneren": "profan",
    "profanerer": "profan",
    "profaneres": "profan",
    "profanes": "profan",
    "profanste": "profan",
    "profanstem": "profan",
    "profansten": "profan",
    "profanster": "profan",
    "profanstes": "profan",
    "professionalisiere": "professionalisieren",
    "professionalisierend": "professionalisieren",
    "professionalisierende": "professionalisierend",
    "professionalisierendem": "professionalisierend",
    "professionalisierenden": "professionalisierend",
    "professionalisierender": "professionalisierend",
    "professionalisierendere": "professionalisierend",
    "professionalisierenderem": "professionalisierend",
    "professionalisierenderen": "professionalisierend",
    "professionalisierenderer": "professionalisierend",
    "professionalisierenderes": "professionalisierend",
    "professionalisierendes": "professionalisierend",
    "professionalisierendste": "professionalisierend",
    "professionalisierendstem": "professionalisierend",
    "professionalisierendsten": "professionalisierend",
    "professionalisierendster": "professionalisierend",
    "professionalisierendstes": "professionalisierend",
    "professionalisierest": "professionalisieren",
    "professionalisieret": "professionalisieren",
    "professionalisierst": "professionalisieren",
    "professionalisiert": "professionalisieren",
    "professionalisierte": "professionalisieren",
    "professionalisiertem": "professionalisiert",
    "professionalisierten": "professionalisieren",
    "professionalisierter": "professionalisiert",
    "professionalisiertere": "professionalisiert",
    "professionalisierterem": "professionalisiert",
    "professionalisierteren": "professionalisiert",
    "professionalisierterer": "professionalisiert",
    "professionalisierteres": "professionalisiert",
    "professionalisiertes": "professionalisiert",
    "professionalisiertest": "professionalisieren",
    "professionalisierteste": "professionalisiert",
    "professionalisiertestem": "professionalisiert",
    "professionalisiertesten": "professionalisiert",
    "professionalisiertester": "professionalisiert",
    "professionalisiertestes": "professionalisiert",
    "professionalisiertet": "professionalisieren",
    "professionelle": "professionell",
    "professionellem": "professionell",
    "professionellen": "professionell",
    "professioneller": "professionell",
    "professionellere": "professionell",
    "professionellerem": "professionell",
    "professionelleren": "professionell",
    "professionellerer": "professionell",
    "professionelleres": "professionell",
    "professionelles": "professionell",
    "professionellste": "professionell",
    "professionellstem": "professionell",
    "professionellsten": "professionell",
    "professionellster": "professionell",
    "professionellstes": "professionell",
    "professorale": "professoral",
    "professoralem": "professoral",
    "professoralen": "professoral",
    "professoraler": "professoral",
    "professorales": "professoral",
    "profiliere": "profilieren",
    "profilierend": "profilieren",
    "profilierende": "profilierend",
    "profilierendem": "profilierend",
    "profilierenden": "profilierend",
    "profilierender": "profilierend",
    "profilierendere": "profilierend",
    "profilierenderem": "profilierend",
    "profilierenderen": "profilierend",
    "profilierenderer": "profilierend",
    "profilierenderes": "profilierend",
    "profilierendes": "profilierend",
    "profilierendste": "profilierend",
    "profilierendstem": "profilierend",
    "profilierendsten": "profilierend",
    "profilierendster": "profilierend",
    "profilierendstes": "profilierend",
    "profilierest": "profilieren",
    "profilieret": "profilieren",
    "profilierst": "profilieren",
    "profiliert": "profilieren",
    "profilierte": "profilieren",
    "profiliertem": "profiliert",
    "profilierten": "profilieren",
    "profilierter": "profiliert",
    "profiliertere": "profiliert",
    "profilierterem": "profiliert",
    "profilierteren": "profiliert",
    "profilierterer": "profiliert",
    "profilierteres": "profiliert",
    "profiliertes": "profiliert",
    "profiliertest": "profilieren",
    "profilierteste": "profiliert",
    "profiliertestem": "profiliert",
    "profiliertesten": "profiliert",
    "profiliertester": "profiliert",
    "profiliertestes": "profiliert",
    "profiliertet": "profilieren",
    "profilierungssüchtige": "profilierungssüchtig",
    "profilierungssüchtigem": "profilierungssüchtig",
    "profilierungssüchtigen": "profilierungssüchtig",
    "profilierungssüchtiger": "profilierungssüchtig",
    "profilierungssüchtigere": "profilierungssüchtig",
    "profilierungssüchtigerem": "profilierungssüchtig",
    "profilierungssüchtigeren": "profilierungssüchtig",
    "profilierungssüchtigerer": "profilierungssüchtig",
    "profilierungssüchtigeres": "profilierungssüchtig",
    "profilierungssüchtiges": "profilierungssüchtig",
    "profilierungssüchtigste": "profilierungssüchtig",
    "profilierungssüchtigstem": "profilierungssüchtig",
    "profilierungssüchtigsten": "profilierungssüchtig",
    "profilierungssüchtigster": "profilierungssüchtig",
    "profilierungssüchtigstes": "profilierungssüchtig",
    "profitabelstem": "profitabel",
    "profitabelsten": "profitabel",
    "profitabelster": "profitabel",
    "profitabelstes": "profitabel",
    "profitable": "profitabel",
    "profitablem": "profitabel",
    "profitablen": "profitabel",
    "profitabler": "profitabel",
    "profitablere": "profitabel",
    "profitablerem": "profitabel",
    "profitableren": "profitabel",
    "profitablerer": "profitabel",
    "profitableres": "profitabel",
    "profitables": "profitabel",
    "profitiere": "profitieren",
    "profitierend": "profitieren",
    "profitierende": "profitierend",
    "profitierendem": "profitierend",
    "profitierenden": "profitierend",
    "profitierender": "profitierend",
    "profitierendere": "profitierend",
    "profitierenderem": "profitierend",
    "profitierenderen": "profitierend",
    "profitierenderer": "profitierend",
    "profitierenderes": "profitierend",
    "profitierendes": "profitierend",
    "profitierendste": "profitierend",
    "profitierendstem": "profitierend",
    "profitierendsten": "profitierend",
    "profitierendster": "profitierend",
    "profitierendstes": "profitierend",
    "profitierest": "profitieren",
    "profitieret": "profitieren",
    "profitierst": "profitieren",
    "profitiert": "profitieren",
    "profitierte": "profitieren",
    "profitiertem": "profitiert",
    "profitierten": "profitieren",
    "profitierter": "profitiert",
    "profitiertes": "profitiert",
    "profitiertest": "profitieren",
    "profitiertet": "profitieren",
    "programmatischem": "programmatisch",
    "programmatischen": "programmatisch",
    "programmatischer": "programmatisch",
    "programmatisches": "programmatisch",
    "programmgemäßem": "programmgemäß",
    "programmgemäßen": "programmgemäß",
    "programmgemäßer": "programmgemäß",
    "programmgemäßes": "programmgemäß",
    "programmgesteuerte": "programmgesteuert",
    "programmgesteuertem": "programmgesteuert",
    "programmgesteuerten": "programmgesteuert",
    "programmgesteuerter": "programmgesteuert",
    "programmgesteuertes": "programmgesteuert",
    "programmiere": "programmieren",
    "programmierend": "programmieren",
    "programmierende": "programmierend",
    "programmierendem": "programmierend",
    "programmierenden": "programmierend",
    "programmierender": "programmierend",
    "programmierendere": "programmierend",
    "programmierenderem": "programmierend",
    "programmierenderen": "programmierend",
    "programmierenderer": "programmierend",
    "programmierenderes": "programmierend",
    "programmierendes": "programmierend",
    "programmierendste": "programmierend",
    "programmierendstem": "programmierend",
    "programmierendsten": "programmierend",
    "programmierendster": "programmierend",
    "programmierendstes": "programmierend",
    "programmierest": "programmieren",
    "programmieret": "programmieren",
    "programmierst": "programmieren",
    "programmiert": "programmieren",
    "programmierte": "programmieren",
    "programmiertem": "programmiert",
    "programmierten": "programmieren",
    "programmierter": "programmiert",
    "programmiertere": "programmiert",
    "programmierterem": "programmiert",
    "programmierteren": "programmiert",
    "programmierterer": "programmiert",
    "programmierteres": "programmiert",
    "programmiertes": "programmiert",
    "programmiertest": "programmieren",
    "programmierteste": "programmiert",
    "programmiertestem": "programmiert",
    "programmiertesten": "programmiert",
    "programmiertester": "programmiert",
    "programmiertestes": "programmiert",
    "programmiertet": "programmieren",
    "progressivem": "progressiv",
    "progressiven": "progressiv",
    "progressiver": "progressiv",
    "progressivere": "progressiv",
    "progressiverem": "progressiv",
    "progressiveren": "progressiv",
    "progressiverer": "progressiv",
    "progressiveres": "progressiv",
    "progressives": "progressiv",
    "progressivste": "progressiv",
    "progressivstem": "progressiv",
    "progressivsten": "progressiv",
    "progressivster": "progressiv",
    "progressivstes": "progressiv",
    "prohibiere": "prohibieren",
    "prohibierend": "prohibieren",
    "prohibierende": "prohibierend",
    "prohibierendem": "prohibierend",
    "prohibierenden": "prohibierend",
    "prohibierender": "prohibierend",
    "prohibierendes": "prohibierend",
    "prohibierest": "prohibieren",
    "prohibieret": "prohibieren",
    "prohibierst": "prohibieren",
    "prohibiert": "prohibieren",
    "prohibierte": "prohibieren",
    "prohibiertem": "prohibiert",
    "prohibierten": "prohibieren",
    "prohibierter": "prohibiert",
    "prohibiertes": "prohibiert",
    "prohibiertest": "prohibieren",
    "prohibiertet": "prohibieren",
    "projektiere": "projektieren",
    "projektierend": "projektieren",
    "projektierende": "projektierend",
    "projektierendem": "projektierend",
    "projektierenden": "projektierend",
    "projektierender": "projektierend",
    "projektierendes": "projektierend",
    "projektierest": "projektieren",
    "projektieret": "projektieren",
    "projektierst": "projektieren",
    "projektiert": "projektieren",
    "projektierte": "projektieren",
    "projektiertem": "projektiert",
    "projektierten": "projektieren",
    "projektierter": "projektiert",
    "projektiertes": "projektiert",
    "projektiertest": "projektieren",
    "projektiertet": "projektieren",
    "projiziere": "projizieren",
    "projizierend": "projizieren",
    "projizierende": "projizierend",
    "projizierendem": "projizierend",
    "projizierenden": "projizierend",
    "projizierender": "projizierend",
    "projizierendes": "projizierend",
    "projizierest": "projizieren",
    "projizieret": "projizieren",
    "projizierst": "projizieren",
    "projiziert": "projizieren",
    "projizierte": "projizieren",
    "projiziertem": "projiziert",
    "projizierten": "projizieren",
    "projizierter": "projiziert",
    "projiziertes": "projiziert",
    "projiziertest": "projizieren",
    "projiziertet": "projizieren",
    "proklamiere": "proklamieren",
    "proklamierend": "proklamieren",
    "proklamierende": "proklamierend",
    "proklamierendem": "proklamierend",
    "proklamierenden": "proklamierend",
    "proklamierender": "proklamierend",
    "proklamierendes": "proklamierend",
    "proklamierest": "proklamieren",
    "proklamieret": "proklamieren",
    "proklamierst": "proklamieren",
    "proklamiert": "proklamieren",
    "proklamierte": "proklamieren",
    "proklamiertem": "proklamiert",
    "proklamierten": "proklamieren",
    "proklamierter": "proklamiert",
    "proklamiertes": "proklamiert",
    "proklamiertest": "proklamieren",
    "proklamiertet": "proklamieren",
    "proletarischem": "proletarisch",
    "proletarischen": "proletarisch",
    "proletarischer": "proletarisch",
    "proletarischere": "proletarisch",
    "proletarischerem": "proletarisch",
    "proletarischeren": "proletarisch",
    "proletarischerer": "proletarisch",
    "proletarischeres": "proletarisch",
    "proletarisches": "proletarisch",
    "proletarischste": "proletarisch",
    "proletarischstem": "proletarisch",
    "proletarischsten": "proletarisch",
    "proletarischster": "proletarisch",
    "proletarischstes": "proletarisch",
    "proletarisiere": "proletarisieren",
    "proletarisierend": "proletarisieren",
    "proletarisierende": "proletarisierend",
    "proletarisierendem": "proletarisierend",
    "proletarisierenden": "proletarisierend",
    "proletarisierender": "proletarisierend",
    "proletarisierendere": "proletarisierend",
    "proletarisierenderem": "proletarisierend",
    "proletarisierenderen": "proletarisierend",
    "proletarisierenderer": "proletarisierend",
    "proletarisierenderes": "proletarisierend",
    "proletarisierendes": "proletarisierend",
    "proletarisierendste": "proletarisierend",
    "proletarisierendstem": "proletarisierend",
    "proletarisierendsten": "proletarisierend",
    "proletarisierendster": "proletarisierend",
    "proletarisierendstes": "proletarisierend",
    "proletarisierest": "proletarisieren",
    "proletarisieret": "proletarisieren",
    "proletarisierst": "proletarisieren",
    "proletarisiert": "proletarisieren",
    "proletarisierte": "proletarisieren",
    "proletarisiertem": "proletarisiert",
    "proletarisierten": "proletarisieren",
    "proletarisierter": "proletarisiert",
    "proletarisiertere": "proletarisiert",
    "proletarisierterem": "proletarisiert",
    "proletarisierteren": "proletarisiert",
    "proletarisierterer": "proletarisiert",
    "proletarisierteres": "proletarisiert",
    "proletarisiertes": "proletarisiert",
    "proletarisiertest": "proletarisieren",
    "proletarisierteste": "proletarisiert",
    "proletarisiertestem": "proletarisiert",
    "proletarisiertesten": "proletarisiert",
    "proletarisiertester": "proletarisiert",
    "proletarisiertestes": "proletarisiert",
    "proletarisiertet": "proletarisieren",
    "proletenhaftem": "proletenhaft",
    "proletenhaften": "proletenhaft",
    "proletenhafter": "proletenhaft",
    "proletenhaftere": "proletenhaft",
    "proletenhafterem": "proletenhaft",
    "proletenhafteren": "proletenhaft",
    "proletenhafterer": "proletenhaft",
    "proletenhafteres": "proletenhaft",
    "proletenhaftes": "proletenhaft",
    "proletenhafteste": "proletenhaft",
    "proletenhaftestem": "proletenhaft",
    "proletenhaftesten": "proletenhaft",
    "proletenhaftester": "proletenhaft",
    "proletenhaftestes": "proletenhaft",
    "prominentem": "prominent",
    "prominenten": "prominent",
    "prominenter": "prominent",
    "prominentere": "prominent",
    "prominenterem": "prominent",
    "prominenteren": "prominent",
    "prominenterer": "prominent",
    "prominenteres": "prominent",
    "prominentes": "prominent",
    "prominenteste": "prominent",
    "prominentestem": "prominent",
    "prominentesten": "prominent",
    "prominentester": "prominent",
    "prominentestes": "prominent",
    "promote": "promoten",
    "promotend": "promoten",
    "promotende": "promotend",
    "promotendem": "promotend",
    "promotenden": "promotend",
    "promotender": "promotend",
    "promotendere": "promotend",
    "promotenderem": "promotend",
    "promotenderen": "promotend",
    "promotenderer": "promotend",
    "promotenderes": "promotend",
    "promotendes": "promotend",
    "promotendste": "promotend",
    "promotendstem": "promotend",
    "promotendsten": "promotend",
    "promotendster": "promotend",
    "promotendstes": "promotend",
    "promotest": "promoten",
    "promotet": "promoten",
    "promotete": "promoten",
    "promotetem": "promotet",
    "promoteten": "promoten",
    "promoteter": "promotet",
    "promotetere": "promotet",
    "promoteterem": "promotet",
    "promoteteren": "promotet",
    "promoteterer": "promotet",
    "promoteteres": "promotet",
    "promotetes": "promotet",
    "promotetest": "promoten",
    "promoteteste": "promotet",
    "promotetestem": "promotet",
    "promotetesten": "promotet",
    "promotetester": "promotet",
    "promotetestes": "promotet",
    "promotetet": "promoten",
    "promoviere": "promovieren",
    "promovierend": "promovieren",
    "promovierende": "promovierend",
    "promovierendem": "promovierend",
    "promovierenden": "promovierend",
    "promovierender": "promovierend",
    "promovierendes": "promovierend",
    "promovierest": "promovieren",
    "promovieret": "promovieren",
    "promovierst": "promovieren",
    "promoviert": "promovieren",
    "promovierte": "promovieren",
    "promoviertem": "promoviert",
    "promovierten": "promovieren",
    "promovierter": "promoviert",
    "promoviertes": "promoviert",
    "promoviertest": "promovieren",
    "promoviertet": "promovieren",
    "prompte": "prompt",
    "promptem": "prompt",
    "prompten": "prompt",
    "prompter": "prompt",
    "promptere": "prompt",
    "prompterem": "prompt",
    "prompteren": "prompt",
    "prompterer": "prompt",
    "prompteres": "prompt",
    "promptes": "prompt",
    "prompteste": "prompt",
    "promptestem": "prompt",
    "promptesten": "prompt",
    "promptester": "prompt",
    "promptestes": "prompt",
    "pronominalem": "pronominal",
    "pronominalen": "pronominal",
    "pronominaler": "pronominal",
    "pronominales": "pronominal",
    "propagandiere": "propagandieren",
    "propagandierend": "propagandieren",
    "propagandierende": "propagandierend",
    "propagandierendem": "propagandierend",
    "propagandierenden": "propagandierend",
    "propagandierender": "propagandierend",
    "propagandierendere": "propagandierend",
    "propagandierenderem": "propagandierend",
    "propagandierenderen": "propagandierend",
    "propagandierenderer": "propagandierend",
    "propagandierenderes": "propagandierend",
    "propagandierendes": "propagandierend",
    "propagandierendste": "propagandierend",
    "propagandierendstem": "propagandierend",
    "propagandierendsten": "propagandierend",
    "propagandierendster": "propagandierend",
    "propagandierendstes": "propagandierend",
    "propagandierest": "propagandieren",
    "propagandieret": "propagandieren",
    "propagandierst": "propagandieren",
    "propagandiert": "propagandieren",
    "propagandierte": "propagandieren",
    "propagandiertem": "propagandiert",
    "propagandierten": "propagandieren",
    "propagandierter": "propagandiert",
    "propagandiertere": "propagandiert",
    "propagandierterem": "propagandiert",
    "propagandierteren": "propagandiert",
    "propagandierterer": "propagandiert",
    "propagandierteres": "propagandiert",
    "propagandiertes": "propagandiert",
    "propagandiertest": "propagandieren",
    "propagandiertestem": "propagandiert",
    "propagandiertesten": "propagandiert",
    "propagandiertester": "propagandiert",
    "propagandiertestes": "propagandiert",
    "propagandiertet": "propagandieren",
    "propagandistische": "propagandistisch",
    "propagandistischem": "propagandistisch",
    "propagandistischen": "propagandistisch",
    "propagandistischer": "propagandistisch",
    "propagandistisches": "propagandistisch",
    "propagiere": "propagieren",
    "propagierend": "propagieren",
    "propagierende": "propagierend",
    "propagierendem": "propagierend",
    "propagierenden": "propagierend",
    "propagierender": "propagierend",
    "propagierendes": "propagierend",
    "propagierest": "propagieren",
    "propagieret": "propagieren",
    "propagierst": "propagieren",
    "propagiert": "propagieren",
    "propagierte": "propagieren",
    "propagiertem": "propagiert",
    "propagierten": "propagieren",
    "propagierter": "propagiert",
    "propagiertes": "propagiert",
    "propagiertest": "propagieren",
    "propagiertet": "propagieren",
    "prophetischem": "prophetisch",
    "prophetischen": "prophetisch",
    "prophetischer": "prophetisch",
    "prophetisches": "prophetisch",
    "prophezeie": "prophezeien",
    "prophezeiend": "prophezeien",
    "prophezeiende": "prophezeiend",
    "prophezeiendem": "prophezeiend",
    "prophezeienden": "prophezeiend",
    "prophezeiender": "prophezeiend",
    "prophezeiendes": "prophezeiend",
    "prophezeiest": "prophezeien",
    "prophezeiet": "prophezeien",
    "prophezeist": "prophezeien",
    "prophezeit": "prophezeien",
    "prophezeite": "prophezeien",
    "prophezeitem": "prophezeit",
    "prophezeiten": "prophezeien",
    "prophezeiter": "prophezeit",
    "prophezeites": "prophezeit",
    "prophezeitest": "prophezeien",
    "prophezeitet": "prophezeien",
    "prophylaktischem": "prophylaktisch",
    "prophylaktischen": "prophylaktisch",
    "prophylaktischer": "prophylaktisch",
    "prophylaktisches": "prophylaktisch",
    "proportionale": "proportional",
    "proportionalem": "proportional",
    "proportionalen": "proportional",
    "proportionaler": "proportional",
    "proportionales": "proportional",
    "proportioniertem": "proportioniert",
    "proportionierten": "proportioniert",
    "proportionierter": "proportioniert",
    "proportioniertes": "proportioniert",
    "proppenvollem": "proppenvoll",
    "proppenvollen": "proppenvoll",
    "proppenvoller": "proppenvoll",
    "proppenvolles": "proppenvoll",
    "propädeutische": "propädeutisch",
    "propädeutischem": "propädeutisch",
    "propädeutischen": "propädeutisch",
    "propädeutischer": "propädeutisch",
    "propädeutisches": "propädeutisch",
    "prosaischem": "prosaisch",
    "prosaischen": "prosaisch",
    "prosaischer": "prosaisch",
    "prosaischere": "prosaisch",
    "prosaischerem": "prosaisch",
    "prosaischeren": "prosaisch",
    "prosaischerer": "prosaisch",
    "prosaischeres": "prosaisch",
    "prosaisches": "prosaisch",
    "prosaischste": "prosaisch",
    "prosaischstem": "prosaisch",
    "prosaischsten": "prosaisch",
    "prosaischster": "prosaisch",
    "prosaischstes": "prosaisch",
    "prosperiere": "prosperieren",
    "prosperierend": "prosperieren",
    "prosperierende": "prosperierend",
    "prosperierendem": "prosperierend",
    "prosperierenden": "prosperierend",
    "prosperierender": "prosperierend",
    "prosperierendere": "prosperierend",
    "prosperierenderem": "prosperierend",
    "prosperierenderen": "prosperierend",
    "prosperierenderer": "prosperierend",
    "prosperierenderes": "prosperierend",
    "prosperierendes": "prosperierend",
    "prosperierendste": "prosperierend",
    "prosperierendstem": "prosperierend",
    "prosperierendsten": "prosperierend",
    "prosperierendster": "prosperierend",
    "prosperierendstes": "prosperierend",
    "prosperierest": "prosperieren",
    "prosperieret": "prosperieren",
    "prosperierst": "prosperieren",
    "prosperiert": "prosperieren",
    "prosperierte": "prosperieren",
    "prosperiertem": "prosperiert",
    "prosperierten": "prosperieren",
    "prosperierter": "prosperiert",
    "prosperiertere": "prosperiert",
    "prosperierterem": "prosperiert",
    "prosperierteren": "prosperiert",
    "prosperierterer": "prosperiert",
    "prosperierteres": "prosperiert",
    "prosperiertes": "prosperiert",
    "prosperiertest": "prosperieren",
    "prosperierteste": "prosperiert",
    "prosperiertestem": "prosperiert",
    "prosperiertesten": "prosperiert",
    "prosperiertester": "prosperiert",
    "prosperiertestes": "prosperiert",
    "prosperiertet": "prosperieren",
    "proste": "prosten",
    "prostend": "prosten",
    "prostende": "prostend",
    "prostendem": "prostend",
    "prostenden": "prostend",
    "prostender": "prostend",
    "prostendes": "prostend",
    "prostest": "prosten",
    "prostet": "prosten",
    "prostete": "prosten",
    "prosteten": "prosten",
    "prostetest": "prosten",
    "prostetet": "prosten",
    "protektionistischem": "protektionistisch",
    "protektionistischen": "protektionistisch",
    "protektionistischer": "protektionistisch",
    "protektionistisches": "protektionistisch",
    "protestantischem": "protestantisch",
    "protestantischen": "protestantisch",
    "protestantischer": "protestantisch",
    "protestantisches": "protestantisch",
    "protestiere": "protestieren",
    "protestierend": "protestieren",
    "protestierende": "protestierend",
    "protestierendem": "protestierend",
    "protestierenden": "protestierend",
    "protestierender": "protestierend",
    "protestierendes": "protestierend",
    "protestierest": "protestieren",
    "protestieret": "protestieren",
    "protestierst": "protestieren",
    "protestiert": "protestieren",
    "protestierte": "protestieren",
    "protestiertem": "protestiert",
    "protestierten": "protestieren",
    "protestierter": "protestiert",
    "protestiertes": "protestiert",
    "protestiertest": "protestieren",
    "protestiertet": "protestieren",
    "protokollarischem": "protokollarisch",
    "protokollarischen": "protokollarisch",
    "protokollarischer": "protokollarisch",
    "protokollarisches": "protokollarisch",
    "protokolliere": "protokollieren",
    "protokollierend": "protokollieren",
    "protokollierende": "protokollierend",
    "protokollierendem": "protokollierend",
    "protokollierenden": "protokollierend",
    "protokollierender": "protokollierend",
    "protokollierendes": "protokollierend",
    "protokollierest": "protokollieren",
    "protokollieret": "protokollieren",
    "protokollierst": "protokollieren",
    "protokolliert": "protokollieren",
    "protokollierte": "protokollieren",
    "protokolliertem": "protokolliert",
    "protokollierten": "protokollieren",
    "protokollierter": "protokolliert",
    "protokolliertes": "protokolliert",
    "protokolliertest": "protokollieren",
    "protokolliertet": "protokollieren",
    "prototypischem": "prototypisch",
    "prototypischen": "prototypisch",
    "prototypischer": "prototypisch",
    "prototypisches": "prototypisch",
    "protze": "protzen",
    "protzend": "protzen",
    "protzende": "protzend",
    "protzendem": "protzend",
    "protzenden": "protzend",
    "protzender": "protzend",
    "protzendere": "protzend",
    "protzenderem": "protzend",
    "protzenderen": "protzend",
    "protzenderer": "protzend",
    "protzenderes": "protzend",
    "protzendes": "protzend",
    "protzendste": "protzend",
    "protzendstem": "protzend",
    "protzendsten": "protzend",
    "protzendster": "protzend",
    "protzendstes": "protzend",
    "protzest": "protzen",
    "protzet": "protzen",
    "protzige": "protzig",
    "protzigem": "protzig",
    "protzigen": "protzig",
    "protziger": "protzig",
    "protzigere": "protzig",
    "protzigerem": "protzig",
    "protzigeren": "protzig",
    "protzigerer": "protzig",
    "protzigeres": "protzig",
    "protziges": "protzig",
    "protzigste": "protzig",
    "protzigstem": "protzig",
    "protzigsten": "protzig",
    "protzigster": "protzig",
    "protzigstes": "protzig",
    "protzt": "protzen",
    "protzte": "protzen",
    "protzten": "protzen",
    "protztest": "protzen",
    "protztet": "protzen",
    "provinziellem": "provinziell",
    "provinziellen": "provinziell",
    "provinzieller": "provinziell",
    "provinziellere": "provinziell",
    "provinziellerem": "provinziell",
    "provinzielleren": "provinziell",
    "provinziellerer": "provinziell",
    "provinzielleres": "provinziell",
    "provinzielles": "provinziell",
    "provinziellste": "provinziell",
    "provinziellstem": "provinziell",
    "provinziellsten": "provinziell",
    "provinziellster": "provinziell",
    "provinziellstes": "provinziell",
    "provisorischem": "provisorisch",
    "provisorischen": "provisorisch",
    "provisorischer": "provisorisch",
    "provisorischere": "provisorisch",
    "provisorischerem": "provisorisch",
    "provisorischeren": "provisorisch",
    "provisorischerer": "provisorisch",
    "provisorischeres": "provisorisch",
    "provisorisches": "provisorisch",
    "provisorischste": "provisorisch",
    "provisorischstem": "provisorisch",
    "provisorischsten": "provisorisch",
    "provisorischster": "provisorisch",
    "provisorischstes": "provisorisch",
    "provoziere": "provozieren",
    "provozierend": "provozieren",
    "provozierende": "provozierend",
    "provozierendem": "provozierend",
    "provozierenden": "provozierend",
    "provozierender": "provozierend",
    "provozierendere": "provozierend",
    "provozierenderem": "provozierend",
    "provozierenderen": "provozierend",
    "provozierenderer": "provozierend",
    "provozierenderes": "provozierend",
    "provozierendes": "provozierend",
    "provozierendste": "provozierend",
    "provozierendstem": "provozierend",
    "provozierendsten": "provozierend",
    "provozierendster": "provozierend",
    "provozierendstes": "provozierend",
    "provozierest": "provozieren",
    "provozieret": "provozieren",
    "provozierst": "provozieren",
    "provoziert": "provozieren",
    "provozierte": "provozieren",
    "provoziertem": "provoziert",
    "provozierten": "provozieren",
    "provozierter": "provoziert",
    "provoziertere": "provoziert",
    "provozierterem": "provoziert",
    "provozierteren": "provoziert",
    "provozierterer": "provoziert",
    "provozierteres": "provoziert",
    "provoziertes": "provoziert",
    "provoziertest": "provozieren",
    "provozierteste": "provoziert",
    "provoziertestem": "provoziert",
    "provoziertesten": "provoziert",
    "provoziertester": "provoziert",
    "provoziertestes": "provoziert",
    "provoziertet": "provozieren",
    "prozentualem": "prozentual",
    "prozentualen": "prozentual",
    "prozentualer": "prozentual",
    "prozentuales": "prozentual",
    "prozessiere": "prozessieren",
    "prozessierend": "prozessieren",
    "prozessierende": "prozessierend",
    "prozessierendem": "prozessierend",
    "prozessierenden": "prozessierend",
    "prozessierender": "prozessierend",
    "prozessierendes": "prozessierend",
    "prozessierest": "prozessieren",
    "prozessieret": "prozessieren",
    "prozessierst": "prozessieren",
    "prozessiert": "prozessieren",
    "prozessierte": "prozessieren",
    "prozessiertem": "prozessiert",
    "prozessierten": "prozessieren",
    "prozessierter": "prozessiert",
    "prozessiertes": "prozessiert",
    "prozessiertest": "prozessieren",
    "prozessiertet": "prozessieren",
    "prozeßfähigem": "prozeßfähig",
    "prozeßfähigen": "prozeßfähig",
    "prozeßfähiger": "prozeßfähig",
    "prozeßfähiges": "prozeßfähig",
    "prunksüchtigem": "prunksüchtig",
    "prunksüchtigen": "prunksüchtig",
    "prunksüchtiger": "prunksüchtig",
    "prunksüchtigere": "prunksüchtig",
    "prunksüchtigerem": "prunksüchtig",
    "prunksüchtigeren": "prunksüchtig",
    "prunksüchtigerer": "prunksüchtig",
    "prunksüchtigeres": "prunksüchtig",
    "prunksüchtiges": "prunksüchtig",
    "prunksüchtigste": "prunksüchtig",
    "prunksüchtigstem": "prunksüchtig",
    "prunksüchtigsten": "prunksüchtig",
    "prunksüchtigster": "prunksüchtig",
    "prunksüchtigstes": "prunksüchtig",
    "prunkvolle": "prunkvoll",
    "prunkvollem": "prunkvoll",
    "prunkvollen": "prunkvoll",
    "prunkvoller": "prunkvoll",
    "prunkvollere": "prunkvoll",
    "prunkvollerem": "prunkvoll",
    "prunkvolleren": "prunkvoll",
    "prunkvollerer": "prunkvoll",
    "prunkvolleres": "prunkvoll",
    "prunkvolles": "prunkvoll",
    "prunkvollste": "prunkvoll",
    "prunkvollstem": "prunkvoll",
    "prunkvollsten": "prunkvoll",
    "prunkvollster": "prunkvoll",
    "prunkvollstes": "prunkvoll",
    "pruste": "prusten",
    "prustend": "prusten",
    "prustende": "prustend",
    "prustendem": "prustend",
    "prustenden": "prustend",
    "prustender": "prustend",
    "prustendere": "prustend",
    "prustenderem": "prustend",
    "prustenderen": "prustend",
    "prustenderer": "prustend",
    "prustenderes": "prustend",
    "prustendes": "prustend",
    "prustendste": "prustend",
    "prustendstem": "prustend",
    "prustendsten": "prustend",
    "prustendster": "prustend",
    "prustendstes": "prustend",
    "prustest": "prusten",
    "prustet": "prusten",
    "prustete": "prusten",
    "prusteten": "prusten",
    "prustetest": "prusten",
    "prustetet": "prusten",
    "prächtigem": "prächtig",
    "prächtigen": "prächtig",
    "prächtiger": "prächtig",
    "prächtigere": "prächtig",
    "prächtigerem": "prächtig",
    "prächtigeren": "prächtig",
    "prächtigerer": "prächtig",
    "prächtigeres": "prächtig",
    "prächtiges": "prächtig",
    "prächtigste": "prächtig",
    "prächtigstem": "prächtig",
    "prächtigsten": "prächtig",
    "prächtigster": "prächtig",
    "prächtigstes": "prächtig",
    "prädestiniere": "prädestinieren",
    "prädestinierend": "prädestinieren",
    "prädestinierende": "prädestinierend",
    "prädestinierendem": "prädestinierend",
    "prädestinierenden": "prädestinierend",
    "prädestinierender": "prädestinierend",
    "prädestinierendere": "prädestinierend",
    "prädestinierenderem": "prädestinierend",
    "prädestinierenderen": "prädestinierend",
    "prädestinierenderer": "prädestinierend",
    "prädestinierenderes": "prädestinierend",
    "prädestinierendes": "prädestinierend",
    "prädestinierendste": "prädestinierend",
    "prädestinierendstem": "prädestinierend",
    "prädestinierendsten": "prädestinierend",
    "prädestinierendster": "prädestinierend",
    "prädestinierendstes": "prädestinierend",
    "prädestinierest": "prädestinieren",
    "prädestinieret": "prädestinieren",
    "prädestinierst": "prädestinieren",
    "prädestiniert": "prädestinieren",
    "prädestinierte": "prädestinieren",
    "prädestiniertem": "prädestiniert",
    "prädestinierten": "prädestinieren",
    "prädestinierter": "prädestiniert",
    "prädestiniertere": "prädestiniert",
    "prädestinierterem": "prädestiniert",
    "prädestinierteren": "prädestiniert",
    "prädestinierterer": "prädestiniert",
    "prädestinierteres": "prädestiniert",
    "prädestiniertes": "prädestiniert",
    "prädestiniertest": "prädestinieren",
    "prädestiniertestem": "prädestiniert",
    "prädestiniertesten": "prädestiniert",
    "prädestiniertester": "prädestiniert",
    "prädestiniertestes": "prädestiniert",
    "prädestiniertet": "prädestinieren",
    "prädikativem": "prädikativ",
    "prädikativen": "prädikativ",
    "prädikativer": "prädikativ",
    "prädikatives": "prädikativ",
    "präfigiere": "präfigieren",
    "präfigierend": "präfigieren",
    "präfigierende": "präfigierend",
    "präfigierendem": "präfigierend",
    "präfigierenden": "präfigierend",
    "präfigierender": "präfigierend",
    "präfigierendes": "präfigierend",
    "präfigierest": "präfigieren",
    "präfigieret": "präfigieren",
    "präfigierst": "präfigieren",
    "präfigiert": "präfigieren",
    "präfigierte": "präfigieren",
    "präfigiertem": "präfigiert",
    "präfigierten": "präfigieren",
    "präfigierter": "präfigiert",
    "präfigiertes": "präfigiert",
    "präfigiertest": "präfigieren",
    "präfigiertet": "präfigieren",
    "präge": "prägen",
    "prägend": "prägen",
    "prägende": "prägend",
    "prägendem": "prägend",
    "prägenden": "prägend",
    "prägender": "prägend",
    "prägendere": "prägend",
    "prägenderem": "prägend",
    "prägenderen": "prägend",
    "prägenderer": "prägend",
    "prägenderes": "prägend",
    "prägendes": "prägend",
    "prägendste": "prägend",
    "prägendstem": "prägend",
    "prägendsten": "prägend",
    "prägendster": "prägend",
    "prägendstes": "prägend",
    "prägest": "prägen",
    "präget": "prägen",
    "prägst": "prägen",
    "prägt": "prägen",
    "prägte": "prägen",
    "prägten": "prägen",
    "prägtest": "prägen",
    "prägtet": "prägen",
    "prähistorischem": "prähistorisch",
    "prähistorischen": "prähistorisch",
    "prähistorischer": "prähistorisch",
    "prähistorisches": "prähistorisch",
    "präkolumbianischem": "präkolumbianisch",
    "präkolumbianischen": "präkolumbianisch",
    "präkolumbianischer": "präkolumbianisch",
    "präkolumbianisches": "präkolumbianisch",
    "prämienbegünstigtem": "prämienbegünstigt",
    "prämienbegünstigten": "prämienbegünstigt",
    "prämienbegünstigter": "prämienbegünstigt",
    "prämienbegünstigtes": "prämienbegünstigt",
    "prämienfreie": "prämienfrei",
    "prämienfreiem": "prämienfrei",
    "prämienfreien": "prämienfrei",
    "prämienfreier": "prämienfrei",
    "prämienfreies": "prämienfrei",
    "prämiere": "prämieren",
    "prämierend": "prämieren",
    "prämierende": "prämierend",
    "prämierendem": "prämierend",
    "prämierenden": "prämierend",
    "prämierender": "prämierend",
    "prämierendere": "prämierend",
    "prämierenderem": "prämierend",
    "prämierenderen": "prämierend",
    "prämierenderer": "prämierend",
    "prämierenderes": "prämierend",
    "prämierendes": "prämierend",
    "prämierendste": "prämierend",
    "prämierendstem": "prämierend",
    "prämierendsten": "prämierend",
    "prämierendster": "prämierend",
    "prämierendstes": "prämierend",
    "prämierest": "prämieren",
    "prämieret": "prämieren",
    "prämierst": "prämieren",
    "prämiert": "prämieren",
    "prämierte": "prämieren",
    "prämiertem": "prämiert",
    "prämierten": "prämieren",
    "prämierter": "prämiert",
    "prämiertere": "prämiert",
    "prämierterem": "prämiert",
    "prämierteren": "prämiert",
    "prämierterer": "prämiert",
    "prämierteres": "prämiert",
    "prämiertes": "prämiert",
    "prämiertest": "prämieren",
    "prämierteste": "prämiert",
    "prämiertestem": "prämiert",
    "prämiertesten": "prämiert",
    "prämiertester": "prämiert",
    "prämiertestes": "prämiert",
    "prämiertet": "prämieren",
    "präpariere": "präparieren",
    "präparierend": "präparieren",
    "präparierende": "präparierend",
    "präparierendem": "präparierend",
    "präparierenden": "präparierend",
    "präparierender": "präparierend",
    "präparierendere": "präparierend",
    "präparierenderem": "präparierend",
    "präparierenderen": "präparierend",
    "präparierenderer": "präparierend",
    "präparierenderes": "präparierend",
    "präparierendes": "präparierend",
    "präparierendste": "präparierend",
    "präparierendstem": "präparierend",
    "präparierendsten": "präparierend",
    "präparierendster": "präparierend",
    "präparierendstes": "präparierend",
    "präparierest": "präparieren",
    "präparieret": "präparieren",
    "präparierst": "präparieren",
    "präpariert": "präparieren",
    "präparierte": "präparieren",
    "präpariertem": "präpariert",
    "präparierten": "präparieren",
    "präparierter": "präpariert",
    "präpariertere": "präpariert",
    "präparierterem": "präpariert",
    "präparierteren": "präpariert",
    "präparierterer": "präpariert",
    "präparierteres": "präpariert",
    "präpariertes": "präpariert",
    "präpariertest": "präparieren",
    "präparierteste": "präpariert",
    "präpariertestem": "präpariert",
    "präpariertesten": "präpariert",
    "präpariertester": "präpariert",
    "präpariertestes": "präpariert",
    "präpariertet": "präparieren",
    "präsentem": "präsent",
    "präsenten": "präsent",
    "präsenter": "präsent",
    "präsentes": "präsent",
    "präsentiere": "präsentieren",
    "präsentierend": "präsentieren",
    "präsentierende": "präsentierend",
    "präsentierendem": "präsentierend",
    "präsentierenden": "präsentierend",
    "präsentierender": "präsentierend",
    "präsentierendes": "präsentierend",
    "präsentierest": "präsentieren",
    "präsentieret": "präsentieren",
    "präsentierst": "präsentieren",
    "präsentiert": "präsentieren",
    "präsentierte": "präsentieren",
    "präsentiertem": "präsentiert",
    "präsentierten": "präsentieren",
    "präsentierter": "präsentiert",
    "präsentiertes": "präsentiert",
    "präsentiertest": "präsentieren",
    "präsentiertet": "präsentieren",
    "präzisem": "präzis",
    "präzisen": "präzis",
    "präziser": "präzis",
    "präzisere": "präzis",
    "präziserem": "präzis",
    "präziseren": "präzis",
    "präziserer": "präzis",
    "präziseres": "präzis",
    "präzises": "präzis",
    "präziseste": "präzis",
    "präzisestem": "präzis",
    "präzisesten": "präzis",
    "präzisester": "präzis",
    "präzisestes": "präzis",
    "präzisiere": "präzisieren",
    "präzisierend": "präzisieren",
    "präzisierende": "präzisierend",
    "präzisierendem": "präzisierend",
    "präzisierenden": "präzisierend",
    "präzisierender": "präzisierend",
    "präzisierendere": "präzisierend",
    "präzisierenderem": "präzisierend",
    "präzisierenderen": "präzisierend",
    "präzisierenderer": "präzisierend",
    "präzisierenderes": "präzisierend",
    "präzisierendes": "präzisierend",
    "präzisierendste": "präzisierend",
    "präzisierendstem": "präzisierend",
    "präzisierendsten": "präzisierend",
    "präzisierendster": "präzisierend",
    "präzisierendstes": "präzisierend",
    "präzisierest": "präzisieren",
    "präzisieret": "präzisieren",
    "präzisierst": "präzisieren",
    "präzisiert": "präzisieren",
    "präzisierte": "präzisieren",
    "präzisiertem": "präzisiert",
    "präzisierten": "präzisieren",
    "präzisierter": "präzisiert",
    "präzisiertere": "präzisiert",
    "präzisierterem": "präzisiert",
    "präzisierteren": "präzisiert",
    "präzisierterer": "präzisiert",
    "präzisierteres": "präzisiert",
    "präzisiertes": "präzisiert",
    "präzisiertest": "präzisieren",
    "präzisierteste": "präzisiert",
    "präzisiertestem": "präzisiert",
    "präzisiertesten": "präzisiert",
    "präzisiertester": "präzisiert",
    "präzisiertestes": "präzisiert",
    "präzisiertet": "präzisieren",
    "prüdem": "prüde",
    "prüden": "prüde",
    "prüder": "prüde",
    "prüdere": "prüde",
    "prüderem": "prüde",
    "prüderen": "prüde",
    "prüderer": "prüde",
    "prüderes": "prüde",
    "prüdes": "prüde",
    "prüdeste": "prüde",
    "prüdestem": "prüde",
    "prüdesten": "prüde",
    "prüdester": "prüde",
    "prüdestes": "prüde",
    "prüfe": "prüfen",
    "prüfend": "prüfen",
    "prüfende": "prüfend",
    "prüfendem": "prüfend",
    "prüfenden": "prüfend",
    "prüfender": "prüfend",
    "prüfendes": "prüfend",
    "prüfest": "prüfen",
    "prüfet": "prüfen",
    "prüfst": "prüfen",
    "prüft": "prüfen",
    "prüfte": "prüfen",
    "prüften": "prüfen",
    "prüftest": "prüfen",
    "prüftet": "prüfen",
    "prügele": "prügeln",
    "prügelnd": "prügeln",
    "prügelnde": "prügelnd",
    "prügelndem": "prügelnd",
    "prügelnden": "prügelnd",
    "prügelnder": "prügelnd",
    "prügelndes": "prügelnd",
    "prügelst": "prügeln",
    "prügelt": "prügeln",
    "prügelte": "prügeln",
    "prügelten": "prügeln",
    "prügeltest": "prügeln",
    "prügeltet": "prügeln",
    "prügle": "prügeln",
    "psychiatrischem": "psychiatrisch",
    "psychiatrischen": "psychiatrisch",
    "psychiatrischer": "psychiatrisch",
    "psychiatrisches": "psychiatrisch",
    "psychische": "psychisch",
    "psychischem": "psychisch",
    "psychischen": "psychisch",
    "psychischer": "psychisch",
    "psychischere": "psychisch",
    "psychischerem": "psychisch",
    "psychischeren": "psychisch",
    "psychischerer": "psychisch",
    "psychischeres": "psychisch",
    "psychisches": "psychisch",
    "psychischste": "psychisch",
    "psychischstem": "psychisch",
    "psychischsten": "psychisch",
    "psychischster": "psychisch",
    "psychischstes": "psychisch",
    "psychoanalytischem": "psychoanalytisch",
    "psychoanalytischen": "psychoanalytisch",
    "psychoanalytischer": "psychoanalytisch",
    "psychoanalytischere": "psychoanalytisch",
    "psychoanalytischerem": "psychoanalytisch",
    "psychoanalytischeren": "psychoanalytisch",
    "psychoanalytischerer": "psychoanalytisch",
    "psychoanalytischeres": "psychoanalytisch",
    "psychoanalytisches": "psychoanalytisch",
    "psychoanalytischste": "psychoanalytisch",
    "psychoanalytischstem": "psychoanalytisch",
    "psychoanalytischsten": "psychoanalytisch",
    "psychoanalytischster": "psychoanalytisch",
    "psychoanalytischstes": "psychoanalytisch",
    "psychogene": "psychogen",
    "psychogenem": "psychogen",
    "psychogenen": "psychogen",
    "psychogener": "psychogen",
    "psychogenes": "psychogen",
    "psychologischem": "psychologisch",
    "psychologischen": "psychologisch",
    "psychologischer": "psychologisch",
    "psychologischere": "psychologisch",
    "psychologischerem": "psychologisch",
    "psychologischeren": "psychologisch",
    "psychologischerer": "psychologisch",
    "psychologischeres": "psychologisch",
    "psychologisches": "psychologisch",
    "psychologischste": "psychologisch",
    "psychologischstem": "psychologisch",
    "psychologischsten": "psychologisch",
    "psychologischster": "psychologisch",
    "psychologischstes": "psychologisch",
    "psychomotorische": "psychomotorisch",
    "psychomotorischem": "psychomotorisch",
    "psychomotorischen": "psychomotorisch",
    "psychomotorischer": "psychomotorisch",
    "psychomotorisches": "psychomotorisch",
    "psychopatischem": "psychopatisch",
    "psychopatischen": "psychopatisch",
    "psychopatischer": "psychopatisch",
    "psychopatisches": "psychopatisch",
    "psychosomatischem": "psychosomatisch",
    "psychosomatischen": "psychosomatisch",
    "psychosomatischer": "psychosomatisch",
    "psychosomatisches": "psychosomatisch",
    "psychosoziale": "psychosozial",
    "psychosozialem": "psychosozial",
    "psychosozialen": "psychosozial",
    "psychosozialer": "psychosozial",
    "psychosoziales": "psychosozial",
    "psychotherapeutischem": "psychotherapeutisch",
    "psychotherapeutischen": "psychotherapeutisch",
    "psychotherapeutischer": "psychotherapeutisch",
    "psychotherapeutisches": "psychotherapeutisch",
    "psychotischem": "psychotisch",
    "psychotischen": "psychotisch",
    "psychotischer": "psychotisch",
    "psychotischere": "psychotisch",
    "psychotischerem": "psychotisch",
    "psychotischeren": "psychotisch",
    "psychotischerer": "psychotisch",
    "psychotischeres": "psychotisch",
    "psychotisches": "psychotisch",
    "psychotischste": "psychotisch",
    "psychotischstem": "psychotisch",
    "psychotischsten": "psychotisch",
    "psychotischster": "psychotisch",
    "psychotischstes": "psychotisch",
    "psyschiatrische": "psyschiatrisch",
    "psyschiatrischem": "psyschiatrisch",
    "psyschiatrischen": "psyschiatrisch",
    "psyschiatrischer": "psyschiatrisch",
    "psyschiatrisches": "psyschiatrisch",
    "pubertiere": "pubertieren",
    "pubertierend": "pubertieren",
    "pubertierende": "pubertierend",
    "pubertierendem": "pubertierend",
    "pubertierenden": "pubertierend",
    "pubertierender": "pubertierend",
    "pubertierendere": "pubertierend",
    "pubertierenderem": "pubertierend",
    "pubertierenderen": "pubertierend",
    "pubertierenderer": "pubertierend",
    "pubertierenderes": "pubertierend",
    "pubertierendes": "pubertierend",
    "pubertierendste": "pubertierend",
    "pubertierendstem": "pubertierend",
    "pubertierendsten": "pubertierend",
    "pubertierendster": "pubertierend",
    "pubertierendstes": "pubertierend",
    "pubertierest": "pubertieren",
    "pubertieret": "pubertieren",
    "pubertierst": "pubertieren",
    "pubertiert": "pubertieren",
    "pubertierte": "pubertieren",
    "pubertiertem": "pubertiert",
    "pubertierten": "pubertieren",
    "pubertierter": "pubertiert",
    "pubertiertere": "pubertiert",
    "pubertierterem": "pubertiert",
    "pubertierteren": "pubertiert",
    "pubertierterer": "pubertiert",
    "pubertierteres": "pubertiert",
    "pubertiertes": "pubertiert",
    "pubertiertest": "pubertieren",
    "pubertierteste": "pubertiert",
    "pubertiertestem": "pubertiert",
    "pubertiertesten": "pubertiert",
    "pubertiertester": "pubertiert",
    "pubertiertestes": "pubertiert",
    "pubertiertet": "pubertieren",
    "publikumswirksamem": "publikumswirksam",
    "publikumswirksamen": "publikumswirksam",
    "publikumswirksamer": "publikumswirksam",
    "publikumswirksamere": "publikumswirksam",
    "publikumswirksamerem": "publikumswirksam",
    "publikumswirksameren": "publikumswirksam",
    "publikumswirksamerer": "publikumswirksam",
    "publikumswirksameres": "publikumswirksam",
    "publikumswirksames": "publikumswirksam",
    "publikumswirksamste": "publikumswirksam",
    "publikumswirksamstem": "publikumswirksam",
    "publikumswirksamsten": "publikumswirksam",
    "publikumswirksamster": "publikumswirksam",
    "publikumswirksamstes": "publikumswirksam",
    "publiziere": "publizieren",
    "publizierend": "publizieren",
    "publizierende": "publizierend",
    "publizierendem": "publizierend",
    "publizierenden": "publizierend",
    "publizierender": "publizierend",
    "publizierendere": "publizierend",
    "publizierenderem": "publizierend",
    "publizierenderen": "publizierend",
    "publizierenderer": "publizierend",
    "publizierenderes": "publizierend",
    "publizierendes": "publizierend",
    "publizierendste": "publizierend",
    "publizierendstem": "publizierend",
    "publizierendsten": "publizierend",
    "publizierendster": "publizierend",
    "publizierendstes": "publizierend",
    "publizierest": "publizieren",
    "publizieret": "publizieren",
    "publizierst": "publizieren",
    "publiziert": "publizieren",
    "publizierte": "publizieren",
    "publiziertem": "publiziert",
    "publizierten": "publizieren",
    "publizierter": "publiziert",
    "publiziertes": "publiziert",
    "publiziertest": "publizieren",
    "publiziertet": "publizieren",
    "publizistischem": "publizistisch",
    "publizistischen": "publizistisch",
    "publizistischer": "publizistisch",
    "publizistisches": "publizistisch",
    "pudelnacktem": "pudelnackt",
    "pudelnackten": "pudelnackt",
    "pudelnackter": "pudelnackt",
    "pudelnacktes": "pudelnackt",
    "pudelnasse": "pudelnaß",
    "pudelnassem": "pudelnaß",
    "pudelnassen": "pudelnaß",
    "pudelnasser": "pudelnaß",
    "pudelnasses": "pudelnaß",
    "pudere": "pudern",
    "puderige": "puderig",
    "puderigem": "puderig",
    "puderigen": "puderig",
    "puderiger": "puderig",
    "puderigere": "puderig",
    "puderigerem": "puderig",
    "puderigeren": "puderig",
    "puderigerer": "puderig",
    "puderigeres": "puderig",
    "puderiges": "puderig",
    "puderigste": "puderig",
    "puderigstem": "puderig",
    "puderigsten": "puderig",
    "puderigster": "puderig",
    "puderigstes": "puderig",
    "pudernd": "pudern",
    "pudernde": "pudernd",
    "puderndem": "pudernd",
    "pudernden": "pudernd",
    "pudernder": "pudernd",
    "puderndere": "pudernd",
    "pudernderem": "pudernd",
    "pudernderen": "pudernd",
    "pudernderer": "pudernd",
    "pudernderes": "pudernd",
    "puderndes": "pudernd",
    "puderndste": "pudernd",
    "puderndstem": "pudernd",
    "puderndsten": "pudernd",
    "puderndster": "pudernd",
    "puderndstes": "pudernd",
    "puderst": "pudern",
    "pudert": "pudern",
    "puderte": "pudern",
    "puderten": "pudern",
    "pudertest": "pudern",
    "pudertet": "pudern",
    "puffe": "puffen",
    "puffend": "puffen",
    "puffende": "puffend",
    "puffendem": "puffend",
    "puffenden": "puffend",
    "puffender": "puffend",
    "puffendere": "puffend",
    "puffenderem": "puffend",
    "puffenderen": "puffend",
    "puffenderer": "puffend",
    "puffenderes": "puffend",
    "puffendes": "puffend",
    "puffendste": "puffend",
    "puffendstem": "puffend",
    "puffendsten": "puffend",
    "puffendster": "puffend",
    "puffendstes": "puffend",
    "puffest": "puffen",
    "puffet": "puffen",
    "puffst": "puffen",
    "pufft": "puffen",
    "puffte": "puffen",
    "pufften": "puffen",
    "pufftest": "puffen",
    "pufftet": "puffen",
    "pule": "pulen",
    "pulend": "pulen",
    "pulende": "pulend",
    "pulendem": "pulend",
    "pulenden": "pulend",
    "pulender": "pulend",
    "pulendere": "pulend",
    "pulenderem": "pulend",
    "pulenderen": "pulend",
    "pulenderer": "pulend",
    "pulenderes": "pulend",
    "pulendes": "pulend",
    "pulendste": "pulend",
    "pulendstem": "pulend",
    "pulendsten": "pulend",
    "pulendster": "pulend",
    "pulendstes": "pulend",
    "pulest": "pulen",
    "pulet": "pulen",
    "pulsiere": "pulsieren",
    "pulsierend": "pulsieren",
    "pulsierende": "pulsierend",
    "pulsierendem": "pulsierend",
    "pulsierenden": "pulsierend",
    "pulsierender": "pulsierend",
    "pulsierendere": "pulsierend",
    "pulsierenderem": "pulsierend",
    "pulsierenderen": "pulsierend",
    "pulsierenderer": "pulsierend",
    "pulsierenderes": "pulsierend",
    "pulsierendes": "pulsierend",
    "pulsierendste": "pulsierend",
    "pulsierendstem": "pulsierend",
    "pulsierendsten": "pulsierend",
    "pulsierendster": "pulsierend",
    "pulsierendstes": "pulsierend",
    "pulsierest": "pulsieren",
    "pulsieret": "pulsieren",
    "pulsierst": "pulsieren",
    "pulsiert": "pulsieren",
    "pulsierte": "pulsieren",
    "pulsiertem": "pulsiert",
    "pulsierten": "pulsieren",
    "pulsierter": "pulsiert",
    "pulsiertes": "pulsiert",
    "pulsiertest": "pulsieren",
    "pulsiertet": "pulsieren",
    "pulst": "pulen",
    "pult": "pulen",
    "pultest": "pulen",
    "pultet": "pulen",
    "pulvere": "pulvern",
    "pulverige": "pulverig",
    "pulverigem": "pulverig",
    "pulverigen": "pulverig",
    "pulveriger": "pulverig",
    "pulverigere": "pulverig",
    "pulverigerem": "pulverig",
    "pulverigeren": "pulverig",
    "pulverigerer": "pulverig",
    "pulverigeres": "pulverig",
    "pulveriges": "pulverig",
    "pulverigste": "pulverig",
    "pulverigstem": "pulverig",
    "pulverigsten": "pulverig",
    "pulverigster": "pulverig",
    "pulverigstes": "pulverig",
    "pulvernd": "pulvern",
    "pulvernde": "pulvernd",
    "pulverndem": "pulvernd",
    "pulvernden": "pulvernd",
    "pulvernder": "pulvernd",
    "pulverndere": "pulvernd",
    "pulvernderem": "pulvernd",
    "pulvernderen": "pulvernd",
    "pulvernderer": "pulvernd",
    "pulvernderes": "pulvernd",
    "pulverndes": "pulvernd",
    "pulverndste": "pulvernd",
    "pulverndstem": "pulvernd",
    "pulverndsten": "pulvernd",
    "pulverndster": "pulvernd",
    "pulverndstes": "pulvernd",
    "pulverst": "pulvern",
    "pulvert": "pulvern",
    "pulverte": "pulvern",
    "pulverten": "pulvern",
    "pulvertest": "pulvern",
    "pulvertet": "pulvern",
    "pummeligem": "pummelig",
    "pummeligen": "pummelig",
    "pummeliger": "pummelig",
    "pummeligere": "pummelig",
    "pummeligerem": "pummelig",
    "pummeligeren": "pummelig",
    "pummeligerer": "pummelig",
    "pummeligeres": "pummelig",
    "pummeliges": "pummelig",
    "pummeligste": "pummelig",
    "pummeligstem": "pummelig",
    "pummeligsten": "pummelig",
    "pummeligster": "pummelig",
    "pummeligstes": "pummelig",
    "pumpend": "pumpen",
    "pumpende": "pumpend",
    "pumpendem": "pumpend",
    "pumpenden": "pumpend",
    "pumpender": "pumpend",
    "pumpendes": "pumpend",
    "pumpest": "pumpen",
    "pumpet": "pumpen",
    "pumpst": "pumpen",
    "pumpt": "pumpen",
    "pumpte": "pumpen",
    "pumpten": "pumpen",
    "pumptest": "pumpen",
    "pumptet": "pumpen",
    "punktend": "punkten",
    "punktende": "punktend",
    "punktendem": "punktend",
    "punktenden": "punktend",
    "punktender": "punktend",
    "punktendes": "punktend",
    "punktest": "punkten",
    "punktet": "punkten",
    "punktete": "punkten",
    "punkteten": "punkten",
    "punktetest": "punkten",
    "punktetet": "punkten",
    "punktiere": "punktieren",
    "punktierend": "punktieren",
    "punktierende": "punktierend",
    "punktierendem": "punktierend",
    "punktierenden": "punktierend",
    "punktierender": "punktierend",
    "punktierendes": "punktierend",
    "punktierest": "punktieren",
    "punktieret": "punktieren",
    "punktierst": "punktieren",
    "punktiert": "punktieren",
    "punktierte": "punktieren",
    "punktiertem": "punktiert",
    "punktierten": "punktieren",
    "punktierter": "punktiert",
    "punktiertes": "punktiert",
    "punktiertest": "punktieren",
    "punktiertet": "punktieren",
    "punktuellem": "punktuell",
    "punktuellen": "punktuell",
    "punktueller": "punktuell",
    "punktuellere": "punktuell",
    "punktuellerem": "punktuell",
    "punktuelleren": "punktuell",
    "punktuellerer": "punktuell",
    "punktuelleres": "punktuell",
    "punktuelles": "punktuell",
    "punktuellste": "punktuell",
    "punktuellstem": "punktuell",
    "punktuellsten": "punktuell",
    "punktuellster": "punktuell",
    "punktuellstes": "punktuell",
    "pupe": "pupen",
    "pupend": "pupen",
    "pupende": "pupend",
    "pupendem": "pupend",
    "pupenden": "pupend",
    "pupender": "pupend",
    "pupendere": "pupend",
    "pupenderem": "pupend",
    "pupenderen": "pupend",
    "pupenderer": "pupend",
    "pupenderes": "pupend",
    "pupendes": "pupend",
    "pupendste": "pupend",
    "pupendstem": "pupend",
    "pupendsten": "pupend",
    "pupendster": "pupend",
    "pupendstes": "pupend",
    "pupest": "pupen",
    "pupet": "pupen",
    "puppenhaftem": "puppenhaft",
    "puppenhaften": "puppenhaft",
    "puppenhafter": "puppenhaft",
    "puppenhaftere": "puppenhaft",
    "puppenhafterem": "puppenhaft",
    "puppenhafteren": "puppenhaft",
    "puppenhafterer": "puppenhaft",
    "puppenhafteres": "puppenhaft",
    "puppenhaftes": "puppenhaft",
    "puppenhafteste": "puppenhaft",
    "puppenhaftestem": "puppenhaft",
    "puppenhaftesten": "puppenhaft",
    "puppenhaftester": "puppenhaft",
    "puppenhaftestes": "puppenhaft",
    "pupst": "pupen",
    "pupt": "pupen",
    "pupte": "pupen",
    "pupten": "pupen",
    "puptest": "pupen",
    "puptet": "pupen",
    "pure": "pur",
    "purem": "pur",
    "puren": "pur",
    "purer": "pur",
    "purere": "pur",
    "purerem": "pur",
    "pureren": "pur",
    "purerer": "pur",
    "pureres": "pur",
    "pures": "pur",
    "pureste": "pur",
    "purestem": "pur",
    "puresten": "pur",
    "purester": "pur",
    "purestes": "pur",
    "puristischem": "puristisch",
    "puristischen": "puristisch",
    "puristischer": "puristisch",
    "puristisches": "puristisch",
    "puritanischem": "puritanisch",
    "puritanischen": "puritanisch",
    "puritanischer": "puritanisch",
    "puritanisches": "puritanisch",
    "purzele": "purzeln",
    "purzelnd": "purzeln",
    "purzelnde": "purzelnd",
    "purzelndem": "purzelnd",
    "purzelnden": "purzelnd",
    "purzelnder": "purzelnd",
    "purzelndes": "purzelnd",
    "purzelst": "purzeln",
    "purzelt": "purzeln",
    "purzelte": "purzeln",
    "purzelten": "purzeln",
    "purzeltest": "purzeln",
    "purzeltet": "purzeln",
    "purzle": "purzeln",
    "pusche": "puschen",
    "puschend": "puschen",
    "puschende": "puschend",
    "puschendem": "puschend",
    "puschenden": "puschend",
    "puschender": "puschend",
    "puschendere": "puschend",
    "puschenderem": "puschend",
    "puschenderen": "puschend",
    "puschenderer": "puschend",
    "puschenderes": "puschend",
    "puschendes": "puschend",
    "puschendste": "puschend",
    "puschendstem": "puschend",
    "puschendsten": "puschend",
    "puschendster": "puschend",
    "puschendstes": "puschend",
    "puschest": "puschen",
    "puschet": "puschen",
    "puschst": "puschen",
    "puscht": "puschen",
    "puschte": "puschen",
    "puschten": "puschen",
    "puschtest": "puschen",
    "puschtet": "puschen",
    "puste": "pusten",
    "pustend": "pusten",
    "pustende": "pustend",
    "pustendem": "pustend",
    "pustenden": "pustend",
    "pustender": "pustend",
    "pustendes": "pustend",
    "pustest": "pusten",
    "pustet": "pusten",
    "pustete": "pusten",
    "pusteten": "pusten",
    "pustetest": "pusten",
    "pustetet": "pusten",
    "putschend": "putschen",
    "putschende": "putschend",
    "putschendem": "putschend",
    "putschenden": "putschend",
    "putschender": "putschend",
    "putschendes": "putschend",
    "putschest": "putschen",
    "putschet": "putschen",
    "putschst": "putschen",
    "putscht": "putschen",
    "putschte": "putschen",
    "putschten": "putschen",
    "putschtest": "putschen",
    "putschtet": "putschen",
    "putte": "putten",
    "puttend": "putten",
    "puttende": "puttend",
    "puttendem": "puttend",
    "puttenden": "puttend",
    "puttender": "puttend",
    "puttendes": "puttend",
    "puttest": "putten",
    "puttet": "putten",
    "puttete": "putten",
    "putteten": "putten",
    "puttetest": "putten",
    "puttetet": "putten",
    "putzend": "putzen",
    "putzende": "putzend",
    "putzendem": "putzend",
    "putzenden": "putzend",
    "putzender": "putzend",
    "putzendere": "putzend",
    "putzenderem": "putzend",
    "putzenderen": "putzend",
    "putzenderer": "putzend",
    "putzenderes": "putzend",
    "putzendes": "putzend",
    "putzendste": "putzend",
    "putzendstem": "putzend",
    "putzendsten": "putzend",
    "putzendster": "putzend",
    "putzendstes": "putzend",
    "putzest": "putzen",
    "putzet": "putzen",
    "putzigem": "putzig",
    "putzigen": "putzig",
    "putziger": "putzig",
    "putzigere": "putzig",
    "putzigerem": "putzig",
    "putzigeren": "putzig",
    "putzigerer": "putzig",
    "putzigeres": "putzig",
    "putziges": "putzig",
    "putzigste": "putzig",
    "putzigstem": "putzig",
    "putzigsten": "putzig",
    "putzigster": "putzig",
    "putzigstes": "putzig",
    "putzmuntere": "putzmunter",
    "putzmunterem": "putzmunter",
    "putzmunteren": "putzmunter",
    "putzmunterer": "putzmunter",
    "putzmunterere": "putzmunter",
    "putzmuntererem": "putzmunter",
    "putzmuntereren": "putzmunter",
    "putzmuntererer": "putzmunter",
    "putzmuntereres": "putzmunter",
    "putzmunteres": "putzmunter",
    "putzmunterste": "putzmunter",
    "putzmunterstem": "putzmunter",
    "putzmuntersten": "putzmunter",
    "putzmunterster": "putzmunter",
    "putzmunterstes": "putzmunter",
    "putzsüchtige": "putzsüchtig",
    "putzsüchtigem": "putzsüchtig",
    "putzsüchtigen": "putzsüchtig",
    "putzsüchtiger": "putzsüchtig",
    "putzsüchtigere": "putzsüchtig",
    "putzsüchtigerem": "putzsüchtig",
    "putzsüchtigeren": "putzsüchtig",
    "putzsüchtigerer": "putzsüchtig",
    "putzsüchtigeres": "putzsüchtig",
    "putzsüchtiges": "putzsüchtig",
    "putzsüchtigste": "putzsüchtig",
    "putzsüchtigstem": "putzsüchtig",
    "putzsüchtigsten": "putzsüchtig",
    "putzsüchtigster": "putzsüchtig",
    "putzsüchtigstes": "putzsüchtig",
    "putzt": "putzen",
    "putzte": "putzen",
    "putzten": "putzen",
    "putztest": "putzen",
    "putztet": "putzen",
    "pygmäischem": "pygmäisch",
    "pygmäischen": "pygmäisch",
    "pygmäischer": "pygmäisch",
    "pygmäisches": "pygmäisch",
    "pyrotechnischem": "pyrotechnisch",
    "pyrotechnischen": "pyrotechnisch",
    "pyrotechnischer": "pyrotechnisch",
    "pyrotechnisches": "pyrotechnisch",
    "pythagoreische": "pythagoreisch",
    "pythagoreischem": "pythagoreisch",
    "pythagoreischen": "pythagoreisch",
    "pythagoreischer": "pythagoreisch",
    "pythagoreisches": "pythagoreisch",
    "pädagogischem": "pädagogisch",
    "pädagogischen": "pädagogisch",
    "pädagogischer": "pädagogisch",
    "pädagogisches": "pädagogisch",
    "päppele": "päppeln",
    "päppelnd": "päppeln",
    "päppelnde": "päppelnd",
    "päppelndem": "päppelnd",
    "päppelnden": "päppelnd",
    "päppelnder": "päppelnd",
    "päppelndes": "päppelnd",
    "päppelst": "päppeln",
    "päppelt": "päppeln",
    "päppelte": "päppeln",
    "päppelten": "päppeln",
    "päppeltest": "päppeln",
    "päppeltet": "päppeln",
    "päpple": "päppeln",
    "päpstlichem": "päpstlich",
    "päpstlichen": "päpstlich",
    "päpstlicher": "päpstlich",
    "päpstliches": "päpstlich",
    "pöbele": "pöbeln",
    "pöbelnd": "pöbeln",
    "pöbelnde": "pöbelnd",
    "pöbelndem": "pöbelnd",
    "pöbelnden": "pöbelnd",
    "pöbelnder": "pöbelnd",
    "pöbelndere": "pöbelnd",
    "pöbelnderem": "pöbelnd",
    "pöbelnderen": "pöbelnd",
    "pöbelnderer": "pöbelnd",
    "pöbelnderes": "pöbelnd",
    "pöbelndes": "pöbelnd",
    "pöbelndste": "pöbelnd",
    "pöbelndstem": "pöbelnd",
    "pöbelndsten": "pöbelnd",
    "pöbelndster": "pöbelnd",
    "pöbelndstes": "pöbelnd",
    "pöbelst": "pöbeln",
    "pöbelt": "pöbeln",
    "pöbelte": "pöbeln",
    "pöbelten": "pöbeln",
    "pöbeltest": "pöbeln",
    "pöbeltet": "pöbeln",
    "pöble": "pöbeln",
    "pökele": "pökeln",
    "pökelnd": "pökeln",
    "pökelnde": "pökelnd",
    "pökelndem": "pökelnd",
    "pökelnden": "pökelnd",
    "pökelnder": "pökelnd",
    "pökelndes": "pökelnd",
    "pökelst": "pökeln",
    "pökelt": "pökeln",
    "pökelte": "pökeln",
    "pökelten": "pökeln",
    "pökeltest": "pökeln",
    "pökeltet": "pökeln",
    "pökle": "pökeln",
    "pünktlichem": "pünktlich",
    "pünktlichen": "pünktlich",
    "pünktlicher": "pünktlich",
    "pünktlichere": "pünktlich",
    "pünktlicherem": "pünktlich",
    "pünktlicheren": "pünktlich",
    "pünktlicherer": "pünktlich",
    "pünktlicheres": "pünktlich",
    "pünktliches": "pünktlich",
    "pünktlichste": "pünktlich",
    "pünktlichstem": "pünktlich",
    "pünktlichsten": "pünktlich",
    "pünktlichster": "pünktlich",
    "pünktlichstes": "pünktlich",
    "quadratischem": "quadratisch",
    "quadratischen": "quadratisch",
    "quadratischer": "quadratisch",
    "quadratisches": "quadratisch",
    "quadriere": "quadrieren",
    "quadrierend": "quadrieren",
    "quadrierende": "quadrierend",
    "quadrierendem": "quadrierend",
    "quadrierenden": "quadrierend",
    "quadrierender": "quadrierend",
    "quadrierendes": "quadrierend",
    "quadrierest": "quadrieren",
    "quadrieret": "quadrieren",
    "quadrierst": "quadrieren",
    "quadriert": "quadrieren",
    "quadrierte": "quadrieren",
    "quadriertem": "quadriert",
    "quadrierten": "quadrieren",
    "quadrierter": "quadriert",
    "quadriertes": "quadriert",
    "quadriertest": "quadrieren",
    "quadriertet": "quadrieren",
    "quadrophone": "quadrophon",
    "quadrophonem": "quadrophon",
    "quadrophonen": "quadrophon",
    "quadrophoner": "quadrophon",
    "quadrophones": "quadrophon",
    "quake": "quaken",
    "quakend": "quaken",
    "quakende": "quakend",
    "quakendem": "quakend",
    "quakenden": "quakend",
    "quakender": "quakend",
    "quakendere": "quakend",
    "quakenderem": "quakend",
    "quakenderen": "quakend",
    "quakenderer": "quakend",
    "quakenderes": "quakend",
    "quakendes": "quakend",
    "quakendste": "quakend",
    "quakendstem": "quakend",
    "quakendsten": "quakend",
    "quakendster": "quakend",
    "quakendstes": "quakend",
    "quakest": "quaken",
    "quaket": "quaken",
    "quakst": "quaken",
    "quakt": "quaken",
    "quakte": "quaken",
    "quakten": "quaken",
    "quaktest": "quaken",
    "quaktet": "quaken",
    "qualifiziere": "qualifizieren",
    "qualifizierend": "qualifizieren",
    "qualifizierende": "qualifizierend",
    "qualifizierendem": "qualifizierend",
    "qualifizierenden": "qualifizierend",
    "qualifizierender": "qualifizierend",
    "qualifizierendes": "qualifizierend",
    "qualifizierest": "qualifizieren",
    "qualifizieret": "qualifizieren",
    "qualifizierst": "qualifizieren",
    "qualifiziert": "qualifizieren",
    "qualifizierte": "qualifizieren",
    "qualifiziertem": "qualifiziert",
    "qualifizierten": "qualifizieren",
    "qualifizierter": "qualifiziert",
    "qualifiziertere": "qualifiziert",
    "qualifizierterem": "qualifiziert",
    "qualifizierteren": "qualifiziert",
    "qualifizierterer": "qualifiziert",
    "qualifizierteres": "qualifiziert",
    "qualifiziertes": "qualifiziert",
    "qualifiziertest": "qualifizieren",
    "qualifizierteste": "qualifiziert",
    "qualifiziertestem": "qualifiziert",
    "qualifiziertesten": "qualifiziert",
    "qualifiziertester": "qualifiziert",
    "qualifiziertestes": "qualifiziert",
    "qualifiziertet": "qualifizieren",
    "qualitativem": "qualitativ",
    "qualitativen": "qualitativ",
    "qualitativer": "qualitativ",
    "qualitatives": "qualitativ",
    "qualitätsvolle": "qualitätsvoll",
    "qualitätsvollem": "qualitätsvoll",
    "qualitätsvollen": "qualitätsvoll",
    "qualitätsvoller": "qualitätsvoll",
    "qualitätsvollere": "qualitätsvoll",
    "qualitätsvollerem": "qualitätsvoll",
    "qualitätsvolleren": "qualitätsvoll",
    "qualitätsvollerer": "qualitätsvoll",
    "qualitätsvolleres": "qualitätsvoll",
    "qualitätsvolles": "qualitätsvoll",
    "qualitätsvollste": "qualitätsvoll",
    "qualitätsvollstem": "qualitätsvoll",
    "qualitätsvollsten": "qualitätsvoll",
    "qualitätsvollster": "qualitätsvoll",
    "qualitätsvollstes": "qualitätsvoll",
    "qualligem": "quallig",
    "qualligen": "quallig",
    "qualliger": "quallig",
    "qualligere": "quallig",
    "qualligerem": "quallig",
    "qualligeren": "quallig",
    "qualligerer": "quallig",
    "qualligeres": "quallig",
    "qualliges": "quallig",
    "qualligste": "quallig",
    "qualligstem": "quallig",
    "qualligsten": "quallig",
    "qualligster": "quallig",
    "qualligstes": "quallig",
    "qualmend": "qualmen",
    "qualmende": "qualmend",
    "qualmendem": "qualmend",
    "qualmenden": "qualmend",
    "qualmender": "qualmend",
    "qualmendere": "qualmend",
    "qualmenderem": "qualmend",
    "qualmenderen": "qualmend",
    "qualmenderer": "qualmend",
    "qualmenderes": "qualmend",
    "qualmendes": "qualmend",
    "qualmendste": "qualmend",
    "qualmendstem": "qualmend",
    "qualmendsten": "qualmend",
    "qualmendster": "qualmend",
    "qualmendstes": "qualmend",
    "qualmest": "qualmen",
    "qualmet": "qualmen",
    "qualmige": "qualmig",
    "qualmigem": "qualmig",
    "qualmigen": "qualmig",
    "qualmiger": "qualmig",
    "qualmigere": "qualmig",
    "qualmigerem": "qualmig",
    "qualmigeren": "qualmig",
    "qualmigerer": "qualmig",
    "qualmigeres": "qualmig",
    "qualmiges": "qualmig",
    "qualmigste": "qualmig",
    "qualmigstem": "qualmig",
    "qualmigsten": "qualmig",
    "qualmigster": "qualmig",
    "qualmigstes": "qualmig",
    "qualmst": "qualmen",
    "qualmt": "qualmen",
    "qualmte": "qualmen",
    "qualmten": "qualmen",
    "qualmtest": "qualmen",
    "qualmtet": "qualmen",
    "qualvolle": "qualvoll",
    "qualvollem": "qualvoll",
    "qualvollen": "qualvoll",
    "qualvoller": "qualvoll",
    "qualvollere": "qualvoll",
    "qualvollerem": "qualvoll",
    "qualvolleren": "qualvoll",
    "qualvollerer": "qualvoll",
    "qualvolleres": "qualvoll",
    "qualvolles": "qualvoll",
    "qualvollste": "qualvoll",
    "qualvollstem": "qualvoll",
    "qualvollsten": "qualvoll",
    "qualvollster": "qualvoll",
    "qualvollstes": "qualvoll",
    "quantifiziere": "quantifizieren",
    "quantifizierend": "quantifizieren",
    "quantifizierende": "quantifizierend",
    "quantifizierendem": "quantifizierend",
    "quantifizierenden": "quantifizierend",
    "quantifizierender": "quantifizierend",
    "quantifizierendes": "quantifizierend",
    "quantifizierest": "quantifizieren",
    "quantifizieret": "quantifizieren",
    "quantifizierst": "quantifizieren",
    "quantifiziert": "quantifizieren",
    "quantifizierte": "quantifizieren",
    "quantifiziertem": "quantifiziert",
    "quantifizierten": "quantifizieren",
    "quantifizierter": "quantifiziert",
    "quantifiziertes": "quantifiziert",
    "quantifiziertest": "quantifizieren",
    "quantifiziertet": "quantifizieren",
    "quantitativem": "quantitativ",
    "quantitativen": "quantitativ",
    "quantitativer": "quantitativ",
    "quantitatives": "quantitativ",
    "quartierend": "quartieren",
    "quartierende": "quartierend",
    "quartierendem": "quartierend",
    "quartierenden": "quartierend",
    "quartierender": "quartierend",
    "quartierendes": "quartierend",
    "quartierest": "quartieren",
    "quartieret": "quartieren",
    "quartierst": "quartieren",
    "quartiert": "quartieren",
    "quartierte": "quartieren",
    "quartiertem": "quartiert",
    "quartierten": "quartieren",
    "quartierter": "quartiert",
    "quartiertes": "quartiert",
    "quartiertest": "quartieren",
    "quartiertet": "quartieren",
    "quarze": "quarzen",
    "quarzend": "quarzen",
    "quarzende": "quarzend",
    "quarzendem": "quarzend",
    "quarzenden": "quarzend",
    "quarzender": "quarzend",
    "quarzendere": "quarzend",
    "quarzenderem": "quarzend",
    "quarzenderen": "quarzend",
    "quarzenderer": "quarzend",
    "quarzenderes": "quarzend",
    "quarzendes": "quarzend",
    "quarzendste": "quarzend",
    "quarzendstem": "quarzend",
    "quarzendsten": "quarzend",
    "quarzendster": "quarzend",
    "quarzendstes": "quarzend",
    "quarzest": "quarzen",
    "quarzet": "quarzen",
    "quarzige": "quarzig",
    "quarzigem": "quarzig",
    "quarzigen": "quarzig",
    "quarziger": "quarzig",
    "quarzigere": "quarzig",
    "quarzigerem": "quarzig",
    "quarzigeren": "quarzig",
    "quarzigerer": "quarzig",
    "quarzigeres": "quarzig",
    "quarziges": "quarzig",
    "quarzigste": "quarzig",
    "quarzigstem": "quarzig",
    "quarzigsten": "quarzig",
    "quarzigster": "quarzig",
    "quarzigstes": "quarzig",
    "quarzt": "quarzen",
    "quarzte": "quarzen",
    "quarzten": "quarzen",
    "quarztest": "quarzen",
    "quarztet": "quarzen",
    "quassele": "quasseln",
    "quasselnd": "quasseln",
    "quasselnde": "quasselnd",
    "quasselndem": "quasselnd",
    "quasselnden": "quasselnd",
    "quasselnder": "quasselnd",
    "quasselndere": "quasselnd",
    "quasselnderem": "quasselnd",
    "quasselnderen": "quasselnd",
    "quasselnderer": "quasselnd",
    "quasselnderes": "quasselnd",
    "quasselndes": "quasselnd",
    "quasselndste": "quasselnd",
    "quasselndstem": "quasselnd",
    "quasselndsten": "quasselnd",
    "quasselndster": "quasselnd",
    "quasselndstes": "quasselnd",
    "quasselst": "quasseln",
    "quasselt": "quasseln",
    "quasselte": "quasseln",
    "quasselten": "quasseln",
    "quasseltest": "quasseln",
    "quasseltet": "quasseln",
    "quassle": "quasseln",
    "quatsche": "quatschen",
    "quatschend": "quatschen",
    "quatschende": "quatschend",
    "quatschendem": "quatschend",
    "quatschenden": "quatschend",
    "quatschender": "quatschend",
    "quatschendere": "quatschend",
    "quatschenderem": "quatschend",
    "quatschenderen": "quatschend",
    "quatschenderer": "quatschend",
    "quatschenderes": "quatschend",
    "quatschendes": "quatschend",
    "quatschendste": "quatschend",
    "quatschendstem": "quatschend",
    "quatschendsten": "quatschend",
    "quatschendster": "quatschend",
    "quatschendstes": "quatschend",
    "quatschest": "quatschen",
    "quatschet": "quatschen",
    "quatschst": "quatschen",
    "quatscht": "quatschen",
    "quatschte": "quatschen",
    "quatschten": "quatschen",
    "quatschtest": "quatschen",
    "quatschtet": "quatschen",
    "quecksilberige": "quecksilberig",
    "quecksilberigem": "quecksilberig",
    "quecksilberigen": "quecksilberig",
    "quecksilberiger": "quecksilberig",
    "quecksilberiges": "quecksilberig",
    "quellend": "quellen",
    "quellende": "quellend",
    "quellendem": "quellend",
    "quellenden": "quellend",
    "quellender": "quellend",
    "quellendes": "quellend",
    "quellest": "quellen",
    "quellet": "quellen",
    "quellst": "quellen",
    "quellt": "quellen",
    "quellte": "quellen",
    "quellten": "quellen",
    "quelltest": "quellen",
    "quelltet": "quellen",
    "quengele": "quengeln",
    "quengelige": "quengelig",
    "quengeligem": "quengelig",
    "quengeligen": "quengelig",
    "quengeliger": "quengelig",
    "quengeligere": "quengelig",
    "quengeligerem": "quengelig",
    "quengeligeren": "quengelig",
    "quengeligerer": "quengelig",
    "quengeligeres": "quengelig",
    "quengeliges": "quengelig",
    "quengeligste": "quengelig",
    "quengeligstem": "quengelig",
    "quengeligsten": "quengelig",
    "quengeligster": "quengelig",
    "quengeligstes": "quengelig",
    "quengelnd": "quengeln",
    "quengelnde": "quengelnd",
    "quengelndem": "quengelnd",
    "quengelnden": "quengelnd",
    "quengelnder": "quengelnd",
    "quengelndere": "quengelnd",
    "quengelnderem": "quengelnd",
    "quengelnderen": "quengelnd",
    "quengelnderer": "quengelnd",
    "quengelnderes": "quengelnd",
    "quengelndes": "quengelnd",
    "quengelndste": "quengelnd",
    "quengelndstem": "quengelnd",
    "quengelndsten": "quengelnd",
    "quengelndster": "quengelnd",
    "quengelndstes": "quengelnd",
    "quengelst": "quengeln",
    "quengelt": "quengeln",
    "quengelte": "quengeln",
    "quengelten": "quengeln",
    "quengeltest": "quengeln",
    "quengeltet": "quengeln",
    "quengle": "quengeln",
    "querdachte": "querdenken",
    "querdachten": "querdenken",
    "querdachtest": "querdenken",
    "querdachtet": "querdenken",
    "querdenke": "querdenken",
    "querdenkend": "querdenken",
    "querdenkende": "querdenkend",
    "querdenkendem": "querdenkend",
    "querdenkenden": "querdenkend",
    "querdenkender": "querdenkend",
    "querdenkendere": "querdenkend",
    "querdenkenderem": "querdenkend",
    "querdenkenderen": "querdenkend",
    "querdenkenderer": "querdenkend",
    "querdenkenderes": "querdenkend",
    "querdenkendes": "querdenkend",
    "querdenkendste": "querdenkend",
    "querdenkendstem": "querdenkend",
    "querdenkendsten": "querdenkend",
    "querdenkendster": "querdenkend",
    "querdenkendstes": "querdenkend",
    "querdenkest": "querdenken",
    "querdenket": "querdenken",
    "querdenkst": "querdenken",
    "querdenkt": "querdenken",
    "querdächte": "querdenken",
    "querdächten": "querdenken",
    "querdächtest": "querdenken",
    "querdächtet": "querdenken",
    "quergedacht": "querdenken",
    "quergedachte": "quergedacht",
    "quergedachtem": "quergedacht",
    "quergedachten": "quergedacht",
    "quergedachter": "quergedacht",
    "quergedachtes": "quergedacht",
    "quergelegt": "querlegen",
    "quergelegte": "quergelegt",
    "quergelegtem": "quergelegt",
    "quergelegten": "quergelegt",
    "quergelegter": "quergelegt",
    "quergelegtes": "quergelegt",
    "quergeschossen": "querschießen",
    "quergeschossene": "quergeschossen",
    "quergeschossenem": "quergeschossen",
    "quergeschossenen": "quergeschossen",
    "quergeschossener": "quergeschossen",
    "quergeschossenes": "quergeschossen",
    "quergestreifte": "quergestreift",
    "quergestreiftem": "quergestreift",
    "quergestreiften": "quergestreift",
    "quergestreifter": "quergestreift",
    "quergestreiftes": "quergestreift",
    "querköpfige": "querköpfig",
    "querköpfigem": "querköpfig",
    "querköpfigen": "querköpfig",
    "querköpfiger": "querköpfig",
    "querköpfigere": "querköpfig",
    "querköpfigerem": "querköpfig",
    "querköpfigeren": "querköpfig",
    "querköpfigerer": "querköpfig",
    "querköpfigeres": "querköpfig",
    "querköpfiges": "querköpfig",
    "querköpfigste": "querköpfig",
    "querköpfigstem": "querköpfig",
    "querköpfigsten": "querköpfig",
    "querköpfigster": "querköpfig",
    "querköpfigstes": "querköpfig",
    "querlege": "querlegen",
    "querlegend": "querlegen",
    "querlegende": "querlegend",
    "querlegendem": "querlegend",
    "querlegenden": "querlegend",
    "querlegender": "querlegend",
    "querlegendes": "querlegend",
    "querlegest": "querlegen",
    "querleget": "querlegen",
    "querlegst": "querlegen",
    "querlegt": "querlegen",
    "querlegte": "querlegen",
    "querlegten": "querlegen",
    "querlegtest": "querlegen",
    "querlegtet": "querlegen",
    "querschieße": "querschießen",
    "querschießend": "querschießen",
    "querschießende": "querschießend",
    "querschießendem": "querschießend",
    "querschießenden": "querschießend",
    "querschießender": "querschießend",
    "querschießendes": "querschießend",
    "querschießest": "querschießen",
    "querschießet": "querschießen",
    "querschießt": "querschießen",
    "querschnittsgelähmtem": "querschnittsgelähmt",
    "querschnittsgelähmten": "querschnittsgelähmt",
    "querschnittsgelähmter": "querschnittsgelähmt",
    "querschnittsgelähmtes": "querschnittsgelähmt",
    "querschossen": "querschießen",
    "querschoß": "querschießen",
    "querschoßt": "querschießen",
    "querschösse": "querschießen",
    "querschössen": "querschießen",
    "querschössest": "querschießen",
    "querschösset": "querschießen",
    "querzudenken": "querdenken",
    "querzulegen": "querlegen",
    "querzuschießen": "querschießen",
    "quetsche": "quetschen",
    "quetschend": "quetschen",
    "quetschende": "quetschend",
    "quetschendem": "quetschend",
    "quetschenden": "quetschend",
    "quetschender": "quetschend",
    "quetschendere": "quetschend",
    "quetschenderem": "quetschend",
    "quetschenderen": "quetschend",
    "quetschenderer": "quetschend",
    "quetschenderes": "quetschend",
    "quetschendes": "quetschend",
    "quetschendste": "quetschend",
    "quetschendstem": "quetschend",
    "quetschendsten": "quetschend",
    "quetschendster": "quetschend",
    "quetschendstes": "quetschend",
    "quetschest": "quetschen",
    "quetschet": "quetschen",
    "quetschst": "quetschen",
    "quetscht": "quetschen",
    "quetschte": "quetschen",
    "quetschten": "quetschen",
    "quetschtest": "quetschen",
    "quetschtet": "quetschen",
    "quicklebendigem": "quicklebendig",
    "quicklebendigen": "quicklebendig",
    "quicklebendiger": "quicklebendig",
    "quicklebendiges": "quicklebendig",
    "quiecke": "quiecken",
    "quieckend": "quiecken",
    "quieckende": "quieckend",
    "quieckendem": "quieckend",
    "quieckenden": "quieckend",
    "quieckender": "quieckend",
    "quieckendere": "quieckend",
    "quieckenderem": "quieckend",
    "quieckenderen": "quieckend",
    "quieckenderer": "quieckend",
    "quieckenderes": "quieckend",
    "quieckendes": "quieckend",
    "quieckendste": "quieckend",
    "quieckendstem": "quieckend",
    "quieckendsten": "quieckend",
    "quieckendster": "quieckend",
    "quieckendstes": "quieckend",
    "quieckest": "quiecken",
    "quiecket": "quiecken",
    "quieckst": "quiecken",
    "quieckt": "quiecken",
    "quieckte": "quiecken",
    "quieckten": "quiecken",
    "quiecktest": "quiecken",
    "quiecktet": "quiecken",
    "quietsche": "quietschen",
    "quietschend": "quietschen",
    "quietschende": "quietschend",
    "quietschendem": "quietschend",
    "quietschenden": "quietschend",
    "quietschender": "quietschend",
    "quietschendere": "quietschend",
    "quietschenderem": "quietschend",
    "quietschenderen": "quietschend",
    "quietschenderer": "quietschend",
    "quietschenderes": "quietschend",
    "quietschendes": "quietschend",
    "quietschendste": "quietschend",
    "quietschendstem": "quietschend",
    "quietschendsten": "quietschend",
    "quietschendster": "quietschend",
    "quietschendstes": "quietschend",
    "quietschest": "quietschen",
    "quietschet": "quietschen",
    "quietschst": "quietschen",
    "quietscht": "quietschen",
    "quietschte": "quietschen",
    "quietschten": "quietschen",
    "quietschtest": "quietschen",
    "quietschtet": "quietschen",
    "quietschvergnügte": "quietschvergnügt",
    "quietschvergnügtem": "quietschvergnügt",
    "quietschvergnügten": "quietschvergnügt",
    "quietschvergnügter": "quietschvergnügt",
    "quietschvergnügtes": "quietschvergnügt",
    "quill": "quellen",
    "quillst": "quellen",
    "quillt": "quellen",
    "quirlend": "quirlen",
    "quirlende": "quirlend",
    "quirlendem": "quirlend",
    "quirlenden": "quirlend",
    "quirlender": "quirlend",
    "quirlendes": "quirlend",
    "quirlest": "quirlen",
    "quirlet": "quirlen",
    "quirlige": "quirlig",
    "quirligem": "quirlig",
    "quirligen": "quirlig",
    "quirliger": "quirlig",
    "quirligere": "quirlig",
    "quirligerem": "quirlig",
    "quirligeren": "quirlig",
    "quirligerer": "quirlig",
    "quirligeres": "quirlig",
    "quirliges": "quirlig",
    "quirligste": "quirlig",
    "quirligstem": "quirlig",
    "quirligsten": "quirlig",
    "quirligster": "quirlig",
    "quirligstes": "quirlig",
    "quirlst": "quirlen",
    "quirlt": "quirlen",
    "quirlte": "quirlen",
    "quirlten": "quirlen",
    "quirltest": "quirlen",
    "quirltet": "quirlen",
    "quittiere": "quittieren",
    "quittierend": "quittieren",
    "quittierende": "quittierend",
    "quittierendem": "quittierend",
    "quittierenden": "quittierend",
    "quittierender": "quittierend",
    "quittierendes": "quittierend",
    "quittierest": "quittieren",
    "quittieret": "quittieren",
    "quittierst": "quittieren",
    "quittiert": "quittieren",
    "quittierte": "quittieren",
    "quittiertem": "quittiert",
    "quittierten": "quittieren",
    "quittierter": "quittiert",
    "quittiertes": "quittiert",
    "quittiertest": "quittieren",
    "quittiertet": "quittieren",
    "quoll": "quellen",
    "quollen": "quellen",
    "quollst": "quellen",
    "quollt": "quellen",
    "quotiere": "quotieren",
    "quotierend": "quotieren",
    "quotierende": "quotierend",
    "quotierendem": "quotierend",
    "quotierenden": "quotierend",
    "quotierender": "quotierend",
    "quotierendes": "quotierend",
    "quotierest": "quotieren",
    "quotieret": "quotieren",
    "quotierst": "quotieren",
    "quotiert": "quotieren",
    "quotierte": "quotieren",
    "quotiertem": "quotiert",
    "quotierten": "quotieren",
    "quotierter": "quotiert",
    "quotiertes": "quotiert",
    "quotiertest": "quotieren",
    "quotiertet": "quotieren",
    "quäle": "quälen",
    "quälend": "quälen",
    "quälende": "quälend",
    "quälendem": "quälend",
    "quälenden": "quälend",
    "quälender": "quälend",
    "quälendere": "quälend",
    "quälenderem": "quälend",
    "quälenderen": "quälend",
    "quälenderer": "quälend",
    "quälenderes": "quälend",
    "quälendes": "quälend",
    "quälendste": "quälend",
    "quälendstem": "quälend",
    "quälendsten": "quälend",
    "quälendster": "quälend",
    "quälendstes": "quälend",
    "quälest": "quälen",
    "quälet": "quälen",
    "quälst": "quälen",
    "quält": "quälen",
    "quälte": "quälen",
    "quälten": "quälen",
    "quältest": "quälen",
    "quältet": "quälen",
    "quölle": "quellen",
    "quöllen": "quellen",
    "quöllest": "quellen",
    "quöllet": "quellen",
    "rabattiere": "rabattieren",
    "rabattierend": "rabattieren",
    "rabattierende": "rabattierend",
    "rabattierendem": "rabattierend",
    "rabattierenden": "rabattierend",
    "rabattierender": "rabattierend",
    "rabattierendes": "rabattierend",
    "rabattierest": "rabattieren",
    "rabattieret": "rabattieren",
    "rabattierst": "rabattieren",
    "rabattiert": "rabattieren",
    "rabattierte": "rabattieren",
    "rabattiertem": "rabattiert",
    "rabattierten": "rabattieren",
    "rabattierter": "rabattiert",
    "rabattiertes": "rabattiert",
    "rabattiertest": "rabattieren",
    "rabattiertet": "rabattieren",
    "rabiatem": "rabiat",
    "rabiaten": "rabiat",
    "rabiater": "rabiat",
    "rabiatere": "rabiat",
    "rabiaterem": "rabiat",
    "rabiateren": "rabiat",
    "rabiaterer": "rabiat",
    "rabiateres": "rabiat",
    "rabiates": "rabiat",
    "rabiateste": "rabiat",
    "rabiatestem": "rabiat",
    "rabiatesten": "rabiat",
    "rabiatester": "rabiat",
    "rabiatestes": "rabiat",
    "rachedurstige": "rachedurstig",
    "rachedurstigem": "rachedurstig",
    "rachedurstigen": "rachedurstig",
    "rachedurstiger": "rachedurstig",
    "rachedurstigere": "rachedurstig",
    "rachedurstigerem": "rachedurstig",
    "rachedurstigeren": "rachedurstig",
    "rachedurstigerer": "rachedurstig",
    "rachedurstigeres": "rachedurstig",
    "rachedurstiges": "rachedurstig",
    "rachedurstigste": "rachedurstig",
    "rachedurstigstem": "rachedurstig",
    "rachedurstigsten": "rachedurstig",
    "rachedurstigster": "rachedurstig",
    "rachedurstigstes": "rachedurstig",
    "rachsüchtige": "rachsüchtig",
    "rachsüchtigem": "rachsüchtig",
    "rachsüchtigen": "rachsüchtig",
    "rachsüchtiger": "rachsüchtig",
    "rachsüchtigere": "rachsüchtig",
    "rachsüchtigerem": "rachsüchtig",
    "rachsüchtigeren": "rachsüchtig",
    "rachsüchtigerer": "rachsüchtig",
    "rachsüchtigeres": "rachsüchtig",
    "rachsüchtiges": "rachsüchtig",
    "rachsüchtigste": "rachsüchtig",
    "rachsüchtigstem": "rachsüchtig",
    "rachsüchtigsten": "rachsüchtig",
    "rachsüchtigster": "rachsüchtig",
    "rachsüchtigstes": "rachsüchtig",
    "radele": "radeln",
    "radelnd": "radeln",
    "radelnde": "radelnd",
    "radelndem": "radelnd",
    "radelnden": "radelnd",
    "radelnder": "radelnd",
    "radelndere": "radelnd",
    "radelnderem": "radelnd",
    "radelnderen": "radelnd",
    "radelnderer": "radelnd",
    "radelnderes": "radelnd",
    "radelndes": "radelnd",
    "radelndste": "radelnd",
    "radelndstem": "radelnd",
    "radelndsten": "radelnd",
    "radelndster": "radelnd",
    "radelndstes": "radelnd",
    "radelst": "radeln",
    "radelt": "radeln",
    "radelte": "radeln",
    "radelten": "radeln",
    "radeltest": "radeln",
    "radeltet": "radeln",
    "radfahre": "radfahren",
    "radfahrend": "radfahren",
    "radfahrende": "radfahrend",
    "radfahrendem": "radfahrend",
    "radfahrenden": "radfahrend",
    "radfahrender": "radfahrend",
    "radfahrendes": "radfahrend",
    "radfahrest": "radfahren",
    "radfahret": "radfahren",
    "radfahrt": "radfahren",
    "radfuhr": "radfahren",
    "radfuhren": "radfahren",
    "radfuhrst": "radfahren",
    "radfuhrt": "radfahren",
    "radfährst": "radfahren",
    "radfährt": "radfahren",
    "radführe": "radfahren",
    "radführen": "radfahren",
    "radführest": "radfahren",
    "radführet": "radfahren",
    "radgefahren": "radfahren",
    "radgefahrene": "radgefahren",
    "radgefahrenem": "radgefahren",
    "radgefahrenen": "radgefahren",
    "radgefahrener": "radgefahren",
    "radgefahrenes": "radgefahren",
    "radiale": "radial",
    "radialem": "radial",
    "radialen": "radial",
    "radialer": "radial",
    "radiales": "radial",
    "radiere": "radieren",
    "radierend": "radieren",
    "radierende": "radierend",
    "radierendem": "radierend",
    "radierenden": "radierend",
    "radierender": "radierend",
    "radierendes": "radierend",
    "radierest": "radieren",
    "radieret": "radieren",
    "radierst": "radieren",
    "radiert": "radieren",
    "radierte": "radieren",
    "radiertem": "radiert",
    "radierten": "radieren",
    "radierter": "radiert",
    "radiertes": "radiert",
    "radiertest": "radieren",
    "radiertet": "radieren",
    "radikalem": "radikal",
    "radikalen": "radikal",
    "radikaler": "radikal",
    "radikalere": "radikal",
    "radikalerem": "radikal",
    "radikaleren": "radikal",
    "radikalerer": "radikal",
    "radikaleres": "radikal",
    "radikales": "radikal",
    "radikalisiere": "radikalisieren",
    "radikalisierend": "radikalisieren",
    "radikalisierende": "radikalisierend",
    "radikalisierendem": "radikalisierend",
    "radikalisierenden": "radikalisierend",
    "radikalisierender": "radikalisierend",
    "radikalisierendere": "radikalisierend",
    "radikalisierenderem": "radikalisierend",
    "radikalisierenderen": "radikalisierend",
    "radikalisierenderer": "radikalisierend",
    "radikalisierenderes": "radikalisierend",
    "radikalisierendes": "radikalisierend",
    "radikalisierendste": "radikalisierend",
    "radikalisierendstem": "radikalisierend",
    "radikalisierendsten": "radikalisierend",
    "radikalisierendster": "radikalisierend",
    "radikalisierendstes": "radikalisierend",
    "radikalisierest": "radikalisieren",
    "radikalisieret": "radikalisieren",
    "radikalisierst": "radikalisieren",
    "radikalisiert": "radikalisieren",
    "radikalisierte": "radikalisieren",
    "radikalisiertem": "radikalisiert",
    "radikalisierten": "radikalisieren",
    "radikalisierter": "radikalisiert",
    "radikalisiertere": "radikalisiert",
    "radikalisierterem": "radikalisiert",
    "radikalisierteren": "radikalisiert",
    "radikalisierterer": "radikalisiert",
    "radikalisierteres": "radikalisiert",
    "radikalisiertes": "radikalisiert",
    "radikalisiertest": "radikalisieren",
    "radikalisiertestem": "radikalisiert",
    "radikalisiertesten": "radikalisiert",
    "radikalisiertester": "radikalisiert",
    "radikalisiertestes": "radikalisiert",
    "radikalisiertet": "radikalisieren",
    "radikalistische": "radikalistisch",
    "radikalistischem": "radikalistisch",
    "radikalistischen": "radikalistisch",
    "radikalistischer": "radikalistisch",
    "radikalistischere": "radikalistisch",
    "radikalistischerem": "radikalistisch",
    "radikalistischeren": "radikalistisch",
    "radikalistischerer": "radikalistisch",
    "radikalistischeres": "radikalistisch",
    "radikalistisches": "radikalistisch",
    "radikalistischste": "radikalistisch",
    "radikalistischstem": "radikalistisch",
    "radikalistischsten": "radikalistisch",
    "radikalistischster": "radikalistisch",
    "radikalistischstes": "radikalistisch",
    "radikalste": "radikal",
    "radikalstem": "radikal",
    "radikalsten": "radikal",
    "radikalster": "radikal",
    "radikalstes": "radikal",
    "radioaktive": "radioaktiv",
    "radioaktivem": "radioaktiv",
    "radioaktiven": "radioaktiv",
    "radioaktiver": "radioaktiv",
    "radioaktivere": "radioaktiv",
    "radioaktiverem": "radioaktiv",
    "radioaktiveren": "radioaktiv",
    "radioaktiverer": "radioaktiv",
    "radioaktiveres": "radioaktiv",
    "radioaktives": "radioaktiv",
    "radioaktivstem": "radioaktiv",
    "radioaktivsten": "radioaktiv",
    "radioaktivster": "radioaktiv",
    "radioaktivstes": "radioaktiv",
    "radiologischem": "radiologisch",
    "radiologischen": "radiologisch",
    "radiologischer": "radiologisch",
    "radiologisches": "radiologisch",
    "radle": "radeln",
    "radzufahren": "radfahren",
    "raffe": "raffen",
    "raffend": "raffen",
    "raffende": "raffend",
    "raffendem": "raffend",
    "raffenden": "raffend",
    "raffender": "raffend",
    "raffendere": "raffend",
    "raffenderem": "raffend",
    "raffenderen": "raffend",
    "raffenderer": "raffend",
    "raffenderes": "raffend",
    "raffendes": "raffend",
    "raffendste": "raffend",
    "raffendstem": "raffend",
    "raffendsten": "raffend",
    "raffendster": "raffend",
    "raffendstes": "raffend",
    "raffest": "raffen",
    "raffet": "raffen",
    "raffgierige": "raffgierig",
    "raffgierigem": "raffgierig",
    "raffgierigen": "raffgierig",
    "raffgieriger": "raffgierig",
    "raffgierigere": "raffgierig",
    "raffgierigerem": "raffgierig",
    "raffgierigeren": "raffgierig",
    "raffgierigerer": "raffgierig",
    "raffgierigeres": "raffgierig",
    "raffgieriges": "raffgierig",
    "raffgierigste": "raffgierig",
    "raffgierigstem": "raffgierig",
    "raffgierigsten": "raffgierig",
    "raffgierigster": "raffgierig",
    "raffgierigstes": "raffgierig",
    "raffiniere": "raffinieren",
    "raffinierend": "raffinieren",
    "raffinierende": "raffinierend",
    "raffinierendem": "raffinierend",
    "raffinierenden": "raffinierend",
    "raffinierender": "raffinierend",
    "raffinierendes": "raffinierend",
    "raffinierest": "raffinieren",
    "raffinieret": "raffinieren",
    "raffinierst": "raffinieren",
    "raffiniert": "raffinieren",
    "raffinierte": "raffinieren",
    "raffiniertem": "raffiniert",
    "raffinierten": "raffinieren",
    "raffinierter": "raffiniert",
    "raffiniertere": "raffiniert",
    "raffinierterem": "raffiniert",
    "raffinierteren": "raffiniert",
    "raffinierterer": "raffiniert",
    "raffinierteres": "raffiniert",
    "raffiniertes": "raffiniert",
    "raffiniertest": "raffinieren",
    "raffinierteste": "raffiniert",
    "raffiniertestem": "raffiniert",
    "raffiniertesten": "raffiniert",
    "raffiniertester": "raffiniert",
    "raffiniertestes": "raffiniert",
    "raffiniertet": "raffinieren",
    "raffst": "raffen",
    "rafft": "raffen",
    "raffte": "raffen",
    "rafften": "raffen",
    "rafftest": "raffen",
    "rafftet": "raffen",
    "rage": "ragen",
    "ragend": "ragen",
    "ragende": "ragend",
    "ragendem": "ragend",
    "ragenden": "ragend",
    "ragender": "ragend",
    "ragendes": "ragend",
    "ragest": "ragen",
    "raget": "ragen",
    "ragst": "ragen",
    "ragt": "ragen",
    "ragte": "ragen",
    "ragten": "ragen",
    "ragtest": "ragen",
    "ragtet": "ragen",
    "rahme": "rahmen",
    "rahmend": "rahmen",
    "rahmende": "rahmend",
    "rahmendem": "rahmend",
    "rahmenden": "rahmend",
    "rahmender": "rahmend",
    "rahmendes": "rahmend",
    "rahmest": "rahmen",
    "rahmet": "rahmen",
    "rahmige": "rahmig",
    "rahmigem": "rahmig",
    "rahmigen": "rahmig",
    "rahmiger": "rahmig",
    "rahmigere": "rahmig",
    "rahmigerem": "rahmig",
    "rahmigeren": "rahmig",
    "rahmigerer": "rahmig",
    "rahmigeres": "rahmig",
    "rahmiges": "rahmig",
    "rahmigste": "rahmig",
    "rahmigstem": "rahmig",
    "rahmigsten": "rahmig",
    "rahmigster": "rahmig",
    "rahmigstes": "rahmig",
    "rahmst": "rahmen",
    "rahmt": "rahmen",
    "rahmte": "rahmen",
    "rahmten": "rahmen",
    "rahmtest": "rahmen",
    "rahmtet": "rahmen",
    "rammdösigem": "rammdösig",
    "rammdösigen": "rammdösig",
    "rammdösiger": "rammdösig",
    "rammdösigere": "rammdösig",
    "rammdösigerem": "rammdösig",
    "rammdösigeren": "rammdösig",
    "rammdösigerer": "rammdösig",
    "rammdösigeres": "rammdösig",
    "rammdösiges": "rammdösig",
    "rammdösigste": "rammdösig",
    "rammdösigstem": "rammdösig",
    "rammdösigsten": "rammdösig",
    "rammdösigster": "rammdösig",
    "rammdösigstes": "rammdösig",
    "ramme": "rammen",
    "rammele": "rammeln",
    "rammelnd": "rammeln",
    "rammelnde": "rammelnd",
    "rammelndem": "rammelnd",
    "rammelnden": "rammelnd",
    "rammelnder": "rammelnd",
    "rammelndere": "rammelnd",
    "rammelnderem": "rammelnd",
    "rammelnderen": "rammelnd",
    "rammelnderer": "rammelnd",
    "rammelnderes": "rammelnd",
    "rammelndes": "rammelnd",
    "rammelndste": "rammelnd",
    "rammelndstem": "rammelnd",
    "rammelndsten": "rammelnd",
    "rammelndster": "rammelnd",
    "rammelndstes": "rammelnd",
    "rammelst": "rammeln",
    "rammelt": "rammeln",
    "rammelte": "rammeln",
    "rammelten": "rammeln",
    "rammeltest": "rammeln",
    "rammeltet": "rammeln",
    "rammend": "rammen",
    "rammende": "rammend",
    "rammendem": "rammend",
    "rammenden": "rammend",
    "rammender": "rammend",
    "rammendes": "rammend",
    "rammest": "rammen",
    "rammet": "rammen",
    "rammle": "rammeln",
    "rammst": "rammen",
    "rammt": "rammen",
    "rammte": "rammen",
    "rammten": "rammen",
    "rammtest": "rammen",
    "rammtet": "rammen",
    "ramponiere": "ramponieren",
    "ramponierend": "ramponieren",
    "ramponierende": "ramponierend",
    "ramponierendem": "ramponierend",
    "ramponierenden": "ramponierend",
    "ramponierender": "ramponierend",
    "ramponierendere": "ramponierend",
    "ramponierenderem": "ramponierend",
    "ramponierenderen": "ramponierend",
    "ramponierenderer": "ramponierend",
    "ramponierenderes": "ramponierend",
    "ramponierendes": "ramponierend",
    "ramponierendste": "ramponierend",
    "ramponierendstem": "ramponierend",
    "ramponierendsten": "ramponierend",
    "ramponierendster": "ramponierend",
    "ramponierendstes": "ramponierend",
    "ramponierest": "ramponieren",
    "ramponieret": "ramponieren",
    "ramponierst": "ramponieren",
    "ramponiert": "ramponieren",
    "ramponierte": "ramponieren",
    "ramponiertem": "ramponiert",
    "ramponierten": "ramponieren",
    "ramponierter": "ramponiert",
    "ramponiertere": "ramponiert",
    "ramponierterem": "ramponiert",
    "ramponierteren": "ramponiert",
    "ramponierterer": "ramponiert",
    "ramponierteres": "ramponiert",
    "ramponiertes": "ramponiert",
    "ramponiertest": "ramponieren",
    "ramponierteste": "ramponiert",
    "ramponiertestem": "ramponiert",
    "ramponiertesten": "ramponiert",
    "ramponiertester": "ramponiert",
    "ramponiertestes": "ramponiert",
    "ramponiertet": "ramponieren",
    "ramschend": "ramschen",
    "ramschende": "ramschend",
    "ramschendem": "ramschend",
    "ramschenden": "ramschend",
    "ramschender": "ramschend",
    "ramschendere": "ramschend",
    "ramschenderem": "ramschend",
    "ramschenderen": "ramschend",
    "ramschenderer": "ramschend",
    "ramschenderes": "ramschend",
    "ramschendes": "ramschend",
    "ramschendste": "ramschend",
    "ramschendstem": "ramschend",
    "ramschendsten": "ramschend",
    "ramschendster": "ramschend",
    "ramschendstes": "ramschend",
    "ramschest": "ramschen",
    "ramschet": "ramschen",
    "ramschst": "ramschen",
    "ramscht": "ramschen",
    "ramschte": "ramschen",
    "ramschten": "ramschen",
    "ramschtest": "ramschen",
    "ramschtet": "ramschen",
    "randaliere": "randalieren",
    "randalierend": "randalieren",
    "randalierende": "randalierend",
    "randalierendem": "randalierend",
    "randalierenden": "randalierend",
    "randalierender": "randalierend",
    "randalierendere": "randalierend",
    "randalierenderem": "randalierend",
    "randalierenderen": "randalierend",
    "randalierenderer": "randalierend",
    "randalierenderes": "randalierend",
    "randalierendes": "randalierend",
    "randalierendste": "randalierend",
    "randalierendstem": "randalierend",
    "randalierendsten": "randalierend",
    "randalierendster": "randalierend",
    "randalierendstes": "randalierend",
    "randalierest": "randalieren",
    "randalieret": "randalieren",
    "randalierst": "randalieren",
    "randaliert": "randalieren",
    "randalierte": "randalieren",
    "randaliertem": "randaliert",
    "randalierten": "randalieren",
    "randalierter": "randaliert",
    "randaliertere": "randaliert",
    "randalierterem": "randaliert",
    "randalierteren": "randaliert",
    "randalierterer": "randaliert",
    "randalierteres": "randaliert",
    "randaliertes": "randaliert",
    "randaliertest": "randalieren",
    "randalierteste": "randaliert",
    "randaliertestem": "randaliert",
    "randaliertesten": "randaliert",
    "randaliertester": "randaliert",
    "randaliertestes": "randaliert",
    "randaliertet": "randalieren",
    "rangeklotzt": "ranklotzen",
    "rangeklotzte": "rangeklotzt",
    "rangeklotztem": "rangeklotzt",
    "rangeklotzten": "rangeklotzt",
    "rangeklotzter": "rangeklotzt",
    "rangeklotztes": "rangeklotzt",
    "rangekriegt": "rankriegen",
    "rangekriegte": "rangekriegt",
    "rangekriegtem": "rangekriegt",
    "rangekriegten": "rangekriegt",
    "rangekriegter": "rangekriegt",
    "rangekriegtes": "rangekriegt",
    "rangen": "ringen",
    "rangeschmissen": "ranschmeißen",
    "rangeschmissene": "rangeschmissen",
    "rangeschmissenem": "rangeschmissen",
    "rangeschmissenen": "rangeschmissen",
    "rangeschmissener": "rangeschmissen",
    "rangeschmissenes": "rangeschmissen",
    "rangiere": "rangieren",
    "rangierend": "rangieren",
    "rangierende": "rangierend",
    "rangierendem": "rangierend",
    "rangierenden": "rangierend",
    "rangierender": "rangierend",
    "rangierendes": "rangierend",
    "rangierest": "rangieren",
    "rangieret": "rangieren",
    "rangierst": "rangieren",
    "rangiert": "rangieren",
    "rangierte": "rangieren",
    "rangiertem": "rangiert",
    "rangierten": "rangieren",
    "rangierter": "rangiert",
    "rangiertes": "rangiert",
    "rangiertest": "rangieren",
    "rangiertet": "rangieren",
    "rangst": "ringen",
    "rangt": "ringen",
    "ranke": "ranken",
    "rankend": "ranken",
    "rankende": "rankend",
    "rankendem": "rankend",
    "rankenden": "rankend",
    "rankender": "rankend",
    "rankendere": "rankend",
    "rankenderem": "rankend",
    "rankenderen": "rankend",
    "rankenderer": "rankend",
    "rankenderes": "rankend",
    "rankendes": "rankend",
    "rankendste": "rankend",
    "rankendstem": "rankend",
    "rankendsten": "rankend",
    "rankendster": "rankend",
    "rankendstes": "rankend",
    "rankest": "ranken",
    "ranket": "ranken",
    "ranklotze": "ranklotzen",
    "ranklotzend": "ranklotzen",
    "ranklotzende": "ranklotzend",
    "ranklotzendem": "ranklotzend",
    "ranklotzenden": "ranklotzend",
    "ranklotzender": "ranklotzend",
    "ranklotzendere": "ranklotzend",
    "ranklotzenderem": "ranklotzend",
    "ranklotzenderen": "ranklotzend",
    "ranklotzenderer": "ranklotzend",
    "ranklotzenderes": "ranklotzend",
    "ranklotzendes": "ranklotzend",
    "ranklotzendste": "ranklotzend",
    "ranklotzendstem": "ranklotzend",
    "ranklotzendsten": "ranklotzend",
    "ranklotzendster": "ranklotzend",
    "ranklotzendstes": "ranklotzend",
    "ranklotzest": "ranklotzen",
    "ranklotzet": "ranklotzen",
    "ranklotzt": "ranklotzen",
    "ranklotzte": "ranklotzen",
    "ranklotzten": "ranklotzen",
    "ranklotztest": "ranklotzen",
    "ranklotztet": "ranklotzen",
    "rankriege": "rankriegen",
    "rankriegend": "rankriegen",
    "rankriegende": "rankriegend",
    "rankriegendem": "rankriegend",
    "rankriegenden": "rankriegend",
    "rankriegender": "rankriegend",
    "rankriegendes": "rankriegend",
    "rankriegest": "rankriegen",
    "rankrieget": "rankriegen",
    "rankriegst": "rankriegen",
    "rankriegt": "rankriegen",
    "rankriegte": "rankriegen",
    "rankriegten": "rankriegen",
    "rankriegtest": "rankriegen",
    "rankriegtet": "rankriegen",
    "rankst": "ranken",
    "rankt": "ranken",
    "rankte": "ranken",
    "rankten": "ranken",
    "ranktest": "ranken",
    "ranktet": "ranken",
    "rann": "rinnen",
    "rannen": "rinnen",
    "rannst": "rinnen",
    "rannt": "rinnen",
    "rannte": "rennen",
    "rannten": "rennen",
    "ranntest": "rennen",
    "ranntet": "rennen",
    "ranschmeiße": "ranschmeißen",
    "ranschmeißend": "ranschmeißen",
    "ranschmeißende": "ranschmeißend",
    "ranschmeißendem": "ranschmeißend",
    "ranschmeißenden": "ranschmeißend",
    "ranschmeißender": "ranschmeißend",
    "ranschmeißendes": "ranschmeißend",
    "ranschmeißest": "ranschmeißen",
    "ranschmeißet": "ranschmeißen",
    "ranschmeißt": "ranschmeißen",
    "ranschmisse": "ranschmeißen",
    "ranschmissen": "ranschmeißen",
    "ranschmissest": "ranschmeißen",
    "ranschmisset": "ranschmeißen",
    "ranschmiß": "ranschmeißen",
    "ranschmißt": "ranschmeißen",
    "ranze": "ranzen",
    "ranzend": "ranzen",
    "ranzende": "ranzend",
    "ranzendem": "ranzend",
    "ranzenden": "ranzend",
    "ranzender": "ranzend",
    "ranzendes": "ranzend",
    "ranzest": "ranzen",
    "ranzet": "ranzen",
    "ranzige": "ranzig",
    "ranzigem": "ranzig",
    "ranzigen": "ranzig",
    "ranziger": "ranzig",
    "ranzigere": "ranzig",
    "ranzigerem": "ranzig",
    "ranzigeren": "ranzig",
    "ranzigerer": "ranzig",
    "ranzigeres": "ranzig",
    "ranziges": "ranzig",
    "ranzigste": "ranzig",
    "ranzigstem": "ranzig",
    "ranzigsten": "ranzig",
    "ranzigster": "ranzig",
    "ranzigstes": "ranzig",
    "ranzt": "ranzen",
    "ranzte": "ranzen",
    "ranzten": "ranzen",
    "ranztest": "ranzen",
    "ranztet": "ranzen",
    "ranzuklotzen": "ranklotzen",
    "ranzukriegen": "rankriegen",
    "ranzuschmeißen": "ranschmeißen",
    "rapide": "rapid",
    "rapidem": "rapid",
    "rapiden": "rapid",
    "rapider": "rapid",
    "rapides": "rapid",
    "rappeldürrem": "rappeldürr",
    "rappeldürren": "rappeldürr",
    "rappeldürrer": "rappeldürr",
    "rappeldürres": "rappeldürr",
    "rappele": "rappeln",
    "rappelige": "rappelig",
    "rappeligem": "rappelig",
    "rappeligen": "rappelig",
    "rappeliger": "rappelig",
    "rappeligere": "rappelig",
    "rappeligerem": "rappelig",
    "rappeligeren": "rappelig",
    "rappeligerer": "rappelig",
    "rappeligeres": "rappelig",
    "rappeliges": "rappelig",
    "rappeligste": "rappelig",
    "rappeligstem": "rappelig",
    "rappeligsten": "rappelig",
    "rappeligster": "rappelig",
    "rappeligstes": "rappelig",
    "rappelnd": "rappeln",
    "rappelnde": "rappelnd",
    "rappelndem": "rappelnd",
    "rappelnden": "rappelnd",
    "rappelnder": "rappelnd",
    "rappelndere": "rappelnd",
    "rappelnderem": "rappelnd",
    "rappelnderen": "rappelnd",
    "rappelnderer": "rappelnd",
    "rappelnderes": "rappelnd",
    "rappelndes": "rappelnd",
    "rappelndste": "rappelnd",
    "rappelndstem": "rappelnd",
    "rappelndsten": "rappelnd",
    "rappelndster": "rappelnd",
    "rappelndstes": "rappelnd",
    "rappelst": "rappeln",
    "rappelt": "rappeln",
    "rappelte": "rappeln",
    "rappelten": "rappeln",
    "rappeltest": "rappeln",
    "rappeltet": "rappeln",
    "rapple": "rappeln",
    "rasantem": "rasant",
    "rasanten": "rasant",
    "rasanter": "rasant",
    "rasantere": "rasant",
    "rasanterem": "rasant",
    "rasanteren": "rasant",
    "rasanterer": "rasant",
    "rasanteres": "rasant",
    "rasantes": "rasant",
    "rasanteste": "rasant",
    "rasantestem": "rasant",
    "rasantesten": "rasant",
    "rasantester": "rasant",
    "rasantestes": "rasant",
    "rasche": "rasch",
    "raschele": "rascheln",
    "raschelnd": "rascheln",
    "raschelnde": "raschelnd",
    "raschelndem": "raschelnd",
    "raschelnden": "raschelnd",
    "raschelnder": "raschelnd",
    "raschelndere": "raschelnd",
    "raschelnderem": "raschelnd",
    "raschelnderen": "raschelnd",
    "raschelnderer": "raschelnd",
    "raschelnderes": "raschelnd",
    "raschelndes": "raschelnd",
    "raschelndste": "raschelnd",
    "raschelndstem": "raschelnd",
    "raschelndsten": "raschelnd",
    "raschelndster": "raschelnd",
    "raschelndstes": "raschelnd",
    "raschelst": "rascheln",
    "raschelt": "rascheln",
    "raschelte": "rascheln",
    "raschelten": "rascheln",
    "rascheltest": "rascheln",
    "rascheltet": "rascheln",
    "raschem": "rasch",
    "raschen": "rasch",
    "rascher": "rasch",
    "raschere": "rasch",
    "rascherem": "rasch",
    "rascheren": "rasch",
    "rascherer": "rasch",
    "rascheres": "rasch",
    "rasches": "rasch",
    "raschle": "rascheln",
    "raschste": "rasch",
    "raschstem": "rasch",
    "raschsten": "rasch",
    "raschster": "rasch",
    "raschstes": "rasch",
    "rase": "rasen",
    "rasend": "rasen",
    "rasende": "rasend",
    "rasendem": "rasend",
    "rasenden": "rasend",
    "rasender": "rasend",
    "rasendere": "rasend",
    "rasenderem": "rasend",
    "rasenderen": "rasend",
    "rasenderer": "rasend",
    "rasenderes": "rasend",
    "rasendes": "rasend",
    "rasendste": "rasend",
    "rasendstem": "rasend",
    "rasendsten": "rasend",
    "rasendster": "rasend",
    "rasendstes": "rasend",
    "rasest": "rasen",
    "raset": "rasen",
    "rasiere": "rasieren",
    "rasierend": "rasieren",
    "rasierende": "rasierend",
    "rasierendem": "rasierend",
    "rasierenden": "rasierend",
    "rasierender": "rasierend",
    "rasierendes": "rasierend",
    "rasierest": "rasieren",
    "rasieret": "rasieren",
    "rasierst": "rasieren",
    "rasiert": "rasieren",
    "rasierte": "rasieren",
    "rasiertem": "rasiert",
    "rasierten": "rasieren",
    "rasierter": "rasiert",
    "rasiertes": "rasiert",
    "rasiertest": "rasieren",
    "rasiertet": "rasieren",
    "raspele": "raspeln",
    "raspelnd": "raspeln",
    "raspelnde": "raspelnd",
    "raspelndem": "raspelnd",
    "raspelnden": "raspelnd",
    "raspelnder": "raspelnd",
    "raspelndere": "raspelnd",
    "raspelnderem": "raspelnd",
    "raspelnderen": "raspelnd",
    "raspelnderer": "raspelnd",
    "raspelnderes": "raspelnd",
    "raspelndes": "raspelnd",
    "raspelndste": "raspelnd",
    "raspelndstem": "raspelnd",
    "raspelndsten": "raspelnd",
    "raspelndster": "raspelnd",
    "raspelndstes": "raspelnd",
    "raspelst": "raspeln",
    "raspelt": "raspeln",
    "raspelte": "raspeln",
    "raspelten": "raspeln",
    "raspeltest": "raspeln",
    "raspeltet": "raspeln",
    "rasple": "raspeln",
    "rassele": "rasseln",
    "rasselnd": "rasseln",
    "rasselnde": "rasselnd",
    "rasselndem": "rasselnd",
    "rasselnden": "rasselnd",
    "rasselnder": "rasselnd",
    "rasselndere": "rasselnd",
    "rasselnderem": "rasselnd",
    "rasselnderen": "rasselnd",
    "rasselnderer": "rasselnd",
    "rasselnderes": "rasselnd",
    "rasselndes": "rasselnd",
    "rasselndste": "rasselnd",
    "rasselndstem": "rasselnd",
    "rasselndsten": "rasselnd",
    "rasselndster": "rasselnd",
    "rasselndstes": "rasselnd",
    "rasselst": "rasseln",
    "rasselt": "rasseln",
    "rasselte": "rasseln",
    "rasselten": "rasseln",
    "rasseltest": "rasseln",
    "rasseltet": "rasseln",
    "rassigem": "rassig",
    "rassigen": "rassig",
    "rassiger": "rassig",
    "rassigere": "rassig",
    "rassigerem": "rassig",
    "rassigeren": "rassig",
    "rassigerer": "rassig",
    "rassigeres": "rassig",
    "rassiges": "rassig",
    "rassigste": "rassig",
    "rassigstem": "rassig",
    "rassigsten": "rassig",
    "rassigster": "rassig",
    "rassigstes": "rassig",
    "rassische": "rassisch",
    "rassischem": "rassisch",
    "rassischen": "rassisch",
    "rassischer": "rassisch",
    "rassisches": "rassisch",
    "rassistische": "rassistisch",
    "rassistischem": "rassistisch",
    "rassistischen": "rassistisch",
    "rassistischer": "rassistisch",
    "rassistischere": "rassistisch",
    "rassistischerem": "rassistisch",
    "rassistischeren": "rassistisch",
    "rassistischerer": "rassistisch",
    "rassistischeres": "rassistisch",
    "rassistisches": "rassistisch",
    "rassistischste": "rassistisch",
    "rassistischstem": "rassistisch",
    "rassistischsten": "rassistisch",
    "rassistischster": "rassistisch",
    "rassistischstes": "rassistisch",
    "rassle": "rasseln",
    "rast": "rasen",
    "raste": "rasten",
    "rastend": "rasten",
    "rastende": "rastend",
    "rastendem": "rastend",
    "rastenden": "rastend",
    "rastender": "rastend",
    "rastendere": "rastend",
    "rastenderem": "rastend",
    "rastenderen": "rastend",
    "rastenderer": "rastend",
    "rastenderes": "rastend",
    "rastendes": "rastend",
    "rastendste": "rastend",
    "rastendstem": "rastend",
    "rastendsten": "rastend",
    "rastendster": "rastend",
    "rastendstes": "rastend",
    "rastere": "rastern",
    "rasternd": "rastern",
    "rasternde": "rasternd",
    "rasterndem": "rasternd",
    "rasternden": "rasternd",
    "rasternder": "rasternd",
    "rasterndes": "rasternd",
    "rasterst": "rastern",
    "rastert": "rastern",
    "rasterte": "rastern",
    "rasterten": "rastern",
    "rastertest": "rastern",
    "rastertet": "rastern",
    "rastest": "rasten",
    "rastet": "rasten",
    "rastete": "rasten",
    "rasteten": "rasten",
    "rastetest": "rasten",
    "rastetet": "rasten",
    "rastlose": "rastlos",
    "rastlosem": "rastlos",
    "rastlosen": "rastlos",
    "rastloser": "rastlos",
    "rastlosere": "rastlos",
    "rastloserem": "rastlos",
    "rastloseren": "rastlos",
    "rastloserer": "rastlos",
    "rastloseres": "rastlos",
    "rastloses": "rastlos",
    "rastloseste": "rastlos",
    "rastlosestem": "rastlos",
    "rastlosesten": "rastlos",
    "rastlosester": "rastlos",
    "rastlosestes": "rastlos",
    "ratend": "raten",
    "ratende": "ratend",
    "ratendem": "ratend",
    "ratenden": "ratend",
    "ratender": "ratend",
    "ratendes": "ratend",
    "ratest": "raten",
    "ratet": "raten",
    "ratifiziere": "ratifizieren",
    "ratifizierend": "ratifizieren",
    "ratifizierende": "ratifizierend",
    "ratifizierendem": "ratifizierend",
    "ratifizierenden": "ratifizierend",
    "ratifizierender": "ratifizierend",
    "ratifizierendes": "ratifizierend",
    "ratifizierest": "ratifizieren",
    "ratifizieret": "ratifizieren",
    "ratifizierst": "ratifizieren",
    "ratifiziert": "ratifizieren",
    "ratifizierte": "ratifizieren",
    "ratifiziertem": "ratifiziert",
    "ratifizierten": "ratifizieren",
    "ratifizierter": "ratifiziert",
    "ratifiziertes": "ratifiziert",
    "ratifiziertest": "ratifizieren",
    "ratifiziertet": "ratifizieren",
    "rationale": "rational",
    "rationalem": "rational",
    "rationalen": "rational",
    "rationaler": "rational",
    "rationalere": "rational",
    "rationalerem": "rational",
    "rationaleren": "rational",
    "rationalerer": "rational",
    "rationaleres": "rational",
    "rationales": "rational",
    "rationalisiere": "rationalisieren",
    "rationalisierend": "rationalisieren",
    "rationalisierende": "rationalisierend",
    "rationalisierendem": "rationalisierend",
    "rationalisierenden": "rationalisierend",
    "rationalisierender": "rationalisierend",
    "rationalisierendes": "rationalisierend",
    "rationalisierest": "rationalisieren",
    "rationalisieret": "rationalisieren",
    "rationalisierst": "rationalisieren",
    "rationalisiert": "rationalisieren",
    "rationalisierte": "rationalisieren",
    "rationalisiertem": "rationalisiert",
    "rationalisierten": "rationalisieren",
    "rationalisierter": "rationalisiert",
    "rationalisiertes": "rationalisiert",
    "rationalisiertest": "rationalisieren",
    "rationalisiertet": "rationalisieren",
    "rationalstem": "rational",
    "rationalsten": "rational",
    "rationalster": "rational",
    "rationalstes": "rational",
    "rationelle": "rationell",
    "rationellem": "rationell",
    "rationellen": "rationell",
    "rationeller": "rationell",
    "rationelles": "rationell",
    "rationiere": "rationieren",
    "rationierend": "rationieren",
    "rationierende": "rationierend",
    "rationierendem": "rationierend",
    "rationierenden": "rationierend",
    "rationierender": "rationierend",
    "rationierendere": "rationierend",
    "rationierenderem": "rationierend",
    "rationierenderen": "rationierend",
    "rationierenderer": "rationierend",
    "rationierenderes": "rationierend",
    "rationierendes": "rationierend",
    "rationierendste": "rationierend",
    "rationierendstem": "rationierend",
    "rationierendsten": "rationierend",
    "rationierendster": "rationierend",
    "rationierendstes": "rationierend",
    "rationierest": "rationieren",
    "rationieret": "rationieren",
    "rationierst": "rationieren",
    "rationiert": "rationieren",
    "rationierte": "rationieren",
    "rationiertem": "rationiert",
    "rationierten": "rationieren",
    "rationierter": "rationiert",
    "rationiertere": "rationiert",
    "rationierterem": "rationiert",
    "rationierteren": "rationiert",
    "rationierterer": "rationiert",
    "rationierteres": "rationiert",
    "rationiertes": "rationiert",
    "rationiertest": "rationieren",
    "rationierteste": "rationiert",
    "rationiertestem": "rationiert",
    "rationiertesten": "rationiert",
    "rationiertester": "rationiert",
    "rationiertestes": "rationiert",
    "rationiertet": "rationieren",
    "ratlose": "ratlos",
    "ratlosem": "ratlos",
    "ratlosen": "ratlos",
    "ratloser": "ratlos",
    "ratlosere": "ratlos",
    "ratloserem": "ratlos",
    "ratloseren": "ratlos",
    "ratloserer": "ratlos",
    "ratloseres": "ratlos",
    "ratloses": "ratlos",
    "ratloseste": "ratlos",
    "ratlosestem": "ratlos",
    "ratlosesten": "ratlos",
    "ratlosester": "ratlos",
    "ratlosestes": "ratlos",
    "ratsamem": "ratsam",
    "ratsamen": "ratsam",
    "ratsamer": "ratsam",
    "ratsames": "ratsam",
    "rattere": "rattern",
    "ratternd": "rattern",
    "ratternde": "ratternd",
    "ratterndem": "ratternd",
    "ratternden": "ratternd",
    "ratternder": "ratternd",
    "ratterndere": "ratternd",
    "ratternderem": "ratternd",
    "ratternderen": "ratternd",
    "ratternderer": "ratternd",
    "ratternderes": "ratternd",
    "ratterndes": "ratternd",
    "ratterndste": "ratternd",
    "ratterndstem": "ratternd",
    "ratterndsten": "ratternd",
    "ratterndster": "ratternd",
    "ratterndstes": "ratternd",
    "ratterst": "rattern",
    "rattert": "rattern",
    "ratterte": "rattern",
    "ratterten": "rattern",
    "rattertest": "rattern",
    "rattertet": "rattern",
    "ratze": "ratzen",
    "ratzend": "ratzen",
    "ratzende": "ratzend",
    "ratzendem": "ratzend",
    "ratzenden": "ratzend",
    "ratzender": "ratzend",
    "ratzendere": "ratzend",
    "ratzenderem": "ratzend",
    "ratzenderen": "ratzend",
    "ratzenderer": "ratzend",
    "ratzenderes": "ratzend",
    "ratzendes": "ratzend",
    "ratzendste": "ratzend",
    "ratzendstem": "ratzend",
    "ratzendsten": "ratzend",
    "ratzendster": "ratzend",
    "ratzendstes": "ratzend",
    "ratzest": "ratzen",
    "ratzet": "ratzen",
    "ratzt": "ratzen",
    "ratzte": "ratzen",
    "ratzten": "ratzen",
    "ratztest": "ratzen",
    "ratztet": "ratzen",
    "raubend": "rauben",
    "raubende": "raubend",
    "raubendem": "raubend",
    "raubenden": "raubend",
    "raubender": "raubend",
    "raubendes": "raubend",
    "raubest": "rauben",
    "raubet": "rauben",
    "raubst": "rauben",
    "raubt": "rauben",
    "raubte": "rauben",
    "raubten": "rauben",
    "raubtest": "rauben",
    "raubtet": "rauben",
    "rauche": "rauchen",
    "rauchend": "rauchen",
    "rauchende": "rauchend",
    "rauchendem": "rauchend",
    "rauchenden": "rauchend",
    "rauchender": "rauchend",
    "rauchendere": "rauchend",
    "rauchenderem": "rauchend",
    "rauchenderen": "rauchend",
    "rauchenderer": "rauchend",
    "rauchenderes": "rauchend",
    "rauchendes": "rauchend",
    "rauchendste": "rauchend",
    "rauchendstem": "rauchend",
    "rauchendsten": "rauchend",
    "rauchendster": "rauchend",
    "rauchendstes": "rauchend",
    "rauchest": "rauchen",
    "rauchet": "rauchen",
    "rauchige": "rauchig",
    "rauchigem": "rauchig",
    "rauchigen": "rauchig",
    "rauchiger": "rauchig",
    "rauchigere": "rauchig",
    "rauchigerem": "rauchig",
    "rauchigeren": "rauchig",
    "rauchigerer": "rauchig",
    "rauchigeres": "rauchig",
    "rauchiges": "rauchig",
    "rauchigste": "rauchig",
    "rauchigstem": "rauchig",
    "rauchigsten": "rauchig",
    "rauchigster": "rauchig",
    "rauchigstes": "rauchig",
    "rauchlose": "rauchlos",
    "rauchlosem": "rauchlos",
    "rauchlosen": "rauchlos",
    "rauchloser": "rauchlos",
    "rauchloses": "rauchlos",
    "rauchst": "rauchen",
    "raucht": "rauchen",
    "rauchte": "rauchen",
    "rauchten": "rauchen",
    "rauchtest": "rauchen",
    "rauchtet": "rauchen",
    "raue": "rauen",
    "rauend": "rauen",
    "rauende": "rauend",
    "rauendem": "rauend",
    "rauenden": "rauend",
    "rauender": "rauend",
    "rauendes": "rauend",
    "rauest": "rauen",
    "rauet": "rauen",
    "raufe": "raufen",
    "raufend": "raufen",
    "raufende": "raufend",
    "raufendem": "raufend",
    "raufenden": "raufend",
    "raufender": "raufend",
    "raufendere": "raufend",
    "raufenderem": "raufend",
    "raufenderen": "raufend",
    "raufenderer": "raufend",
    "raufenderes": "raufend",
    "raufendes": "raufend",
    "raufendste": "raufend",
    "raufendstem": "raufend",
    "raufendsten": "raufend",
    "raufendster": "raufend",
    "raufendstes": "raufend",
    "raufest": "raufen",
    "raufet": "raufen",
    "rauflustige": "rauflustig",
    "rauflustigem": "rauflustig",
    "rauflustigen": "rauflustig",
    "rauflustiger": "rauflustig",
    "rauflustigere": "rauflustig",
    "rauflustigerem": "rauflustig",
    "rauflustigeren": "rauflustig",
    "rauflustigerer": "rauflustig",
    "rauflustigeres": "rauflustig",
    "rauflustiges": "rauflustig",
    "rauflustigste": "rauflustig",
    "rauflustigstem": "rauflustig",
    "rauflustigsten": "rauflustig",
    "rauflustigster": "rauflustig",
    "rauflustigstes": "rauflustig",
    "raufst": "raufen",
    "rauft": "raufen",
    "raufte": "raufen",
    "rauften": "raufen",
    "rauftest": "raufen",
    "rauftet": "raufen",
    "rauh": "rauhen",
    "rauhe": "rauh",
    "rauhem": "rauh",
    "rauhen": "rauh",
    "rauhend": "rauhen",
    "rauhende": "rauhend",
    "rauhendem": "rauhend",
    "rauhenden": "rauhend",
    "rauhender": "rauhend",
    "rauhendes": "rauhend",
    "rauher": "rauh",
    "rauhere": "rauh",
    "rauherem": "rauh",
    "rauheren": "rauh",
    "rauherer": "rauh",
    "rauheres": "rauh",
    "rauhes": "rauh",
    "rauhest": "rauhen",
    "rauheste": "rauh",
    "rauhestem": "rauh",
    "rauhesten": "rauh",
    "rauhester": "rauh",
    "rauhestes": "rauh",
    "rauhet": "rauhen",
    "rauhst": "rauhen",
    "rauht": "rauhen",
    "rauhte": "rauhen",
    "rauhten": "rauhen",
    "rauhtest": "rauhen",
    "rauhtet": "rauhen",
    "raune": "raunen",
    "raunend": "raunen",
    "raunende": "raunend",
    "raunendem": "raunend",
    "raunenden": "raunend",
    "raunender": "raunend",
    "raunendes": "raunend",
    "raunest": "raunen",
    "raunet": "raunen",
    "raunst": "raunen",
    "raunt": "raunen",
    "raunte": "raunen",
    "raunten": "raunen",
    "rauntest": "raunen",
    "rauntet": "raunen",
    "rauscharmem": "rauscharm",
    "rauscharmen": "rauscharm",
    "rauscharmer": "rauscharm",
    "rauscharmes": "rauscharm",
    "rauschend": "rauschen",
    "rauschende": "rauschend",
    "rauschendem": "rauschend",
    "rauschenden": "rauschend",
    "rauschender": "rauschend",
    "rauschendere": "rauschend",
    "rauschenderem": "rauschend",
    "rauschenderen": "rauschend",
    "rauschenderer": "rauschend",
    "rauschenderes": "rauschend",
    "rauschendes": "rauschend",
    "rauschendste": "rauschend",
    "rauschendstem": "rauschend",
    "rauschendsten": "rauschend",
    "rauschendster": "rauschend",
    "rauschendstes": "rauschend",
    "rauschest": "rauschen",
    "rauschet": "rauschen",
    "rauschgiftsüchtige": "rauschgiftsüchtig",
    "rauschgiftsüchtigem": "rauschgiftsüchtig",
    "rauschgiftsüchtigen": "rauschgiftsüchtig",
    "rauschgiftsüchtiger": "rauschgiftsüchtig",
    "rauschgiftsüchtiges": "rauschgiftsüchtig",
    "rauschhafte": "rauschhaft",
    "rauschhaftem": "rauschhaft",
    "rauschhaften": "rauschhaft",
    "rauschhafter": "rauschhaft",
    "rauschhaftere": "rauschhaft",
    "rauschhafterem": "rauschhaft",
    "rauschhafteren": "rauschhaft",
    "rauschhafterer": "rauschhaft",
    "rauschhafteres": "rauschhaft",
    "rauschhaftes": "rauschhaft",
    "rauschhafteste": "rauschhaft",
    "rauschhaftestem": "rauschhaft",
    "rauschhaftesten": "rauschhaft",
    "rauschhaftester": "rauschhaft",
    "rauschhaftestes": "rauschhaft",
    "rauschst": "rauschen",
    "rauscht": "rauschen",
    "rauschte": "rauschen",
    "rauschten": "rauschen",
    "rauschtest": "rauschen",
    "rauschtet": "rauschen",
    "rauschärmer": "rauscharm",
    "rauschärmere": "rauscharm",
    "rauschärmerem": "rauscharm",
    "rauschärmeren": "rauscharm",
    "rauschärmerer": "rauscharm",
    "rauschärmeres": "rauscharm",
    "rauschärmsten": "rauscharm",
    "rausgelaufen": "rauslaufen",
    "rausgelaufene": "rausgelaufen",
    "rausgelaufenem": "rausgelaufen",
    "rausgelaufenen": "rausgelaufen",
    "rausgelaufener": "rausgelaufen",
    "rausgelaufenes": "rausgelaufen",
    "rauslaufe": "rauslaufen",
    "rauslaufend": "rauslaufen",
    "rauslaufende": "rauslaufend",
    "rauslaufendem": "rauslaufend",
    "rauslaufenden": "rauslaufend",
    "rauslaufender": "rauslaufend",
    "rauslaufendes": "rauslaufend",
    "rauslaufest": "rauslaufen",
    "rauslaufet": "rauslaufen",
    "rauslauft": "rauslaufen",
    "rauslief": "rauslaufen",
    "rausliefe": "rauslaufen",
    "rausliefen": "rauslaufen",
    "rausliefest": "rauslaufen",
    "rausliefet": "rauslaufen",
    "rausliefst": "rauslaufen",
    "rauslieft": "rauslaufen",
    "rausläufst": "rauslaufen",
    "rausläuft": "rauslaufen",
    "raust": "rauen",
    "rauszulaufen": "rauslaufen",
    "raut": "rauen",
    "raute": "rauen",
    "rautest": "rauen",
    "rautet": "rauen",
    "reagiere": "reagieren",
    "reagierend": "reagieren",
    "reagierende": "reagierend",
    "reagierendem": "reagierend",
    "reagierenden": "reagierend",
    "reagierender": "reagierend",
    "reagierendere": "reagierend",
    "reagierenderem": "reagierend",
    "reagierenderen": "reagierend",
    "reagierenderer": "reagierend",
    "reagierenderes": "reagierend",
    "reagierendes": "reagierend",
    "reagierendste": "reagierend",
    "reagierendstem": "reagierend",
    "reagierendsten": "reagierend",
    "reagierendster": "reagierend",
    "reagierendstes": "reagierend",
    "reagierest": "reagieren",
    "reagieret": "reagieren",
    "reagierst": "reagieren",
    "reagiert": "reagieren",
    "reagierte": "reagieren",
    "reagiertem": "reagiert",
    "reagierten": "reagieren",
    "reagierter": "reagiert",
    "reagiertes": "reagiert",
    "reagiertest": "reagieren",
    "reagiertet": "reagieren",
    "reaktionsfähigem": "reaktionsfähig",
    "reaktionsfähigen": "reaktionsfähig",
    "reaktionsfähiger": "reaktionsfähig",
    "reaktionsfähigere": "reaktionsfähig",
    "reaktionsfähigerem": "reaktionsfähig",
    "reaktionsfähigeren": "reaktionsfähig",
    "reaktionsfähigerer": "reaktionsfähig",
    "reaktionsfähigeres": "reaktionsfähig",
    "reaktionsfähiges": "reaktionsfähig",
    "reaktionsfähigste": "reaktionsfähig",
    "reaktionsfähigstem": "reaktionsfähig",
    "reaktionsfähigsten": "reaktionsfähig",
    "reaktionsfähigster": "reaktionsfähig",
    "reaktionsfähigstes": "reaktionsfähig",
    "reaktionäre": "reaktionär",
    "reaktionärem": "reaktionär",
    "reaktionären": "reaktionär",
    "reaktionärer": "reaktionär",
    "reaktionärere": "reaktionär",
    "reaktionärerem": "reaktionär",
    "reaktionäreren": "reaktionär",
    "reaktionärerer": "reaktionär",
    "reaktionäreres": "reaktionär",
    "reaktionäres": "reaktionär",
    "reaktionärste": "reaktionär",
    "reaktionärstem": "reaktionär",
    "reaktionärsten": "reaktionär",
    "reaktionärster": "reaktionär",
    "reaktionärstes": "reaktionär",
    "reaktive": "reaktiv",
    "reaktivem": "reaktiv",
    "reaktiven": "reaktiv",
    "reaktiver": "reaktiv",
    "reaktives": "reaktiv",
    "realem": "real",
    "realen": "real",
    "realer": "real",
    "realere": "real",
    "realerem": "real",
    "realeren": "real",
    "realerer": "real",
    "realeres": "real",
    "reales": "real",
    "realisierbarem": "realisierbar",
    "realisierbaren": "realisierbar",
    "realisierbarer": "realisierbar",
    "realisierbarere": "realisierbar",
    "realisierbarerem": "realisierbar",
    "realisierbareren": "realisierbar",
    "realisierbarerer": "realisierbar",
    "realisierbareres": "realisierbar",
    "realisierbares": "realisierbar",
    "realisierbarste": "realisierbar",
    "realisierbarstem": "realisierbar",
    "realisierbarsten": "realisierbar",
    "realisierbarster": "realisierbar",
    "realisierbarstes": "realisierbar",
    "realisiere": "realisieren",
    "realisierend": "realisieren",
    "realisierende": "realisierend",
    "realisierendem": "realisierend",
    "realisierenden": "realisierend",
    "realisierender": "realisierend",
    "realisierendes": "realisierend",
    "realisierest": "realisieren",
    "realisieret": "realisieren",
    "realisierst": "realisieren",
    "realisiert": "realisieren",
    "realisierte": "realisieren",
    "realisiertem": "realisiert",
    "realisierten": "realisieren",
    "realisierter": "realisiert",
    "realisiertes": "realisiert",
    "realisiertest": "realisieren",
    "realisiertet": "realisieren",
    "realistischem": "realistisch",
    "realistischen": "realistisch",
    "realistischer": "realistisch",
    "realistischere": "realistisch",
    "realistischerem": "realistisch",
    "realistischeren": "realistisch",
    "realistischerer": "realistisch",
    "realistischeres": "realistisch",
    "realistisches": "realistisch",
    "realistischste": "realistisch",
    "realistischstem": "realistisch",
    "realistischsten": "realistisch",
    "realistischster": "realistisch",
    "realistischstes": "realistisch",
    "realsozialistischem": "realsozialistisch",
    "realsozialistischen": "realsozialistisch",
    "realsozialistischer": "realsozialistisch",
    "realsozialistisches": "realsozialistisch",
    "realste": "real",
    "realstem": "real",
    "realsten": "real",
    "realster": "real",
    "realstes": "real",
    "rebelliere": "rebellieren",
    "rebellierend": "rebellieren",
    "rebellierende": "rebellierend",
    "rebellierendem": "rebellierend",
    "rebellierenden": "rebellierend",
    "rebellierender": "rebellierend",
    "rebellierendere": "rebellierend",
    "rebellierenderem": "rebellierend",
    "rebellierenderen": "rebellierend",
    "rebellierenderer": "rebellierend",
    "rebellierenderes": "rebellierend",
    "rebellierendes": "rebellierend",
    "rebellierendste": "rebellierend",
    "rebellierendstem": "rebellierend",
    "rebellierendsten": "rebellierend",
    "rebellierendster": "rebellierend",
    "rebellierendstes": "rebellierend",
    "rebellierest": "rebellieren",
    "rebellieret": "rebellieren",
    "rebellierst": "rebellieren",
    "rebelliert": "rebellieren",
    "rebellierte": "rebellieren",
    "rebelliertem": "rebelliert",
    "rebellierten": "rebellieren",
    "rebellierter": "rebelliert",
    "rebelliertes": "rebelliert",
    "rebelliertest": "rebellieren",
    "rebelliertet": "rebellieren",
    "rebellische": "rebellisch",
    "rebellischem": "rebellisch",
    "rebellischen": "rebellisch",
    "rebellischer": "rebellisch",
    "rebellischere": "rebellisch",
    "rebellischerem": "rebellisch",
    "rebellischeren": "rebellisch",
    "rebellischerer": "rebellisch",
    "rebellischeres": "rebellisch",
    "rebellisches": "rebellisch",
    "rebellischste": "rebellisch",
    "rebellischstem": "rebellisch",
    "rebellischsten": "rebellisch",
    "rebellischster": "rebellisch",
    "rebellischstes": "rebellisch",
    "rechne": "rechnen",
    "rechnend": "rechnen",
    "rechnende": "rechnend",
    "rechnendem": "rechnend",
    "rechnenden": "rechnend",
    "rechnender": "rechnend",
    "rechnendes": "rechnend",
    "rechnerischem": "rechnerisch",
    "rechnerischen": "rechnerisch",
    "rechnerischer": "rechnerisch",
    "rechnerisches": "rechnerisch",
    "rechnest": "rechnen",
    "rechnet": "rechnen",
    "rechnete": "rechnen",
    "rechneten": "rechnen",
    "rechnetest": "rechnen",
    "rechnetet": "rechnen",
    "rechtem": "recht",
    "rechten": "recht",
    "rechter": "recht",
    "rechtes": "recht",
    "rechtfertige": "rechtfertigen",
    "rechtfertigend": "rechtfertigen",
    "rechtfertigende": "rechtfertigend",
    "rechtfertigendem": "rechtfertigend",
    "rechtfertigenden": "rechtfertigend",
    "rechtfertigender": "rechtfertigend",
    "rechtfertigendere": "rechtfertigend",
    "rechtfertigenderem": "rechtfertigend",
    "rechtfertigenderen": "rechtfertigend",
    "rechtfertigenderer": "rechtfertigend",
    "rechtfertigenderes": "rechtfertigend",
    "rechtfertigendes": "rechtfertigend",
    "rechtfertigendste": "rechtfertigend",
    "rechtfertigendstem": "rechtfertigend",
    "rechtfertigendsten": "rechtfertigend",
    "rechtfertigendster": "rechtfertigend",
    "rechtfertigendstes": "rechtfertigend",
    "rechtfertigest": "rechtfertigen",
    "rechtfertiget": "rechtfertigen",
    "rechtfertigst": "rechtfertigen",
    "rechtfertigt": "rechtfertigen",
    "rechtfertigte": "rechtfertigen",
    "rechtfertigten": "rechtfertigen",
    "rechtfertigtest": "rechtfertigen",
    "rechtfertigtet": "rechtfertigen",
    "rechtgläubigem": "rechtgläubig",
    "rechtgläubigen": "rechtgläubig",
    "rechtgläubiger": "rechtgläubig",
    "rechtgläubiges": "rechtgläubig",
    "rechthaberische": "rechthaberisch",
    "rechthaberischem": "rechthaberisch",
    "rechthaberischen": "rechthaberisch",
    "rechthaberischer": "rechthaberisch",
    "rechthaberischere": "rechthaberisch",
    "rechthaberischerem": "rechthaberisch",
    "rechthaberischeren": "rechthaberisch",
    "rechthaberischerer": "rechthaberisch",
    "rechthaberischeres": "rechthaberisch",
    "rechthaberisches": "rechthaberisch",
    "rechthaberischste": "rechthaberisch",
    "rechthaberischstem": "rechthaberisch",
    "rechthaberischsten": "rechthaberisch",
    "rechthaberischster": "rechthaberisch",
    "rechthaberischstes": "rechthaberisch",
    "rechtlichem": "rechtlich",
    "rechtlichen": "rechtlich",
    "rechtlicher": "rechtlich",
    "rechtliches": "rechtlich",
    "rechtmäßige": "rechtmäßig",
    "rechtmäßigem": "rechtmäßig",
    "rechtmäßigen": "rechtmäßig",
    "rechtmäßiger": "rechtmäßig",
    "rechtmäßiges": "rechtmäßig",
    "rechtschaffendem": "rechtschaffend",
    "rechtschaffenden": "rechtschaffend",
    "rechtschaffender": "rechtschaffend",
    "rechtschaffendere": "rechtschaffend",
    "rechtschaffenderem": "rechtschaffend",
    "rechtschaffenderen": "rechtschaffend",
    "rechtschaffenderer": "rechtschaffend",
    "rechtschaffenderes": "rechtschaffend",
    "rechtschaffendes": "rechtschaffend",
    "rechtschaffendste": "rechtschaffend",
    "rechtschaffendstem": "rechtschaffend",
    "rechtschaffendsten": "rechtschaffend",
    "rechtschaffendster": "rechtschaffend",
    "rechtschaffendstes": "rechtschaffend",
    "rechtsdrehendem": "rechtsdrehend",
    "rechtsdrehenden": "rechtsdrehend",
    "rechtsdrehender": "rechtsdrehend",
    "rechtsdrehendes": "rechtsdrehend",
    "rechtsextreme": "rechtsextrem",
    "rechtsextremem": "rechtsextrem",
    "rechtsextremen": "rechtsextrem",
    "rechtsextremer": "rechtsextrem",
    "rechtsextremere": "rechtsextrem",
    "rechtsextremerem": "rechtsextrem",
    "rechtsextremeren": "rechtsextrem",
    "rechtsextremerer": "rechtsextrem",
    "rechtsextremeres": "rechtsextrem",
    "rechtsextremes": "rechtsextrem",
    "rechtsextremste": "rechtsextrem",
    "rechtsextremstem": "rechtsextrem",
    "rechtsextremsten": "rechtsextrem",
    "rechtsextremster": "rechtsextrem",
    "rechtsextremstes": "rechtsextrem",
    "rechtsfähige": "rechtsfähig",
    "rechtsfähigem": "rechtsfähig",
    "rechtsfähigen": "rechtsfähig",
    "rechtsfähiger": "rechtsfähig",
    "rechtsfähigere": "rechtsfähig",
    "rechtsfähigerem": "rechtsfähig",
    "rechtsfähigeren": "rechtsfähig",
    "rechtsfähigerer": "rechtsfähig",
    "rechtsfähigeres": "rechtsfähig",
    "rechtsfähiges": "rechtsfähig",
    "rechtsfähigste": "rechtsfähig",
    "rechtsfähigstem": "rechtsfähig",
    "rechtsfähigsten": "rechtsfähig",
    "rechtsfähigster": "rechtsfähig",
    "rechtsfähigstes": "rechtsfähig",
    "rechtsgelehrte": "rechtsgelehrt",
    "rechtsgelehrtem": "rechtsgelehrt",
    "rechtsgelehrten": "rechtsgelehrt",
    "rechtsgelehrter": "rechtsgelehrt",
    "rechtsgelehrtes": "rechtsgelehrt",
    "rechtsgerichtete": "rechtsgerichtet",
    "rechtsgerichtetem": "rechtsgerichtet",
    "rechtsgerichteten": "rechtsgerichtet",
    "rechtsgerichteter": "rechtsgerichtet",
    "rechtsgerichtetes": "rechtsgerichtet",
    "rechtsgültige": "rechtsgültig",
    "rechtsgültigem": "rechtsgültig",
    "rechtsgültigen": "rechtsgültig",
    "rechtsgültiger": "rechtsgültig",
    "rechtsgültiges": "rechtsgültig",
    "rechtshändigem": "rechtshändig",
    "rechtshändigen": "rechtshändig",
    "rechtshändiger": "rechtshändig",
    "rechtshändiges": "rechtshändig",
    "rechtskräftige": "rechtskräftig",
    "rechtskräftigem": "rechtskräftig",
    "rechtskräftigen": "rechtskräftig",
    "rechtskräftiger": "rechtskräftig",
    "rechtskräftiges": "rechtskräftig",
    "rechtslastige": "rechtslastig",
    "rechtslastigem": "rechtslastig",
    "rechtslastigen": "rechtslastig",
    "rechtslastiger": "rechtslastig",
    "rechtslastigere": "rechtslastig",
    "rechtslastigerem": "rechtslastig",
    "rechtslastigeren": "rechtslastig",
    "rechtslastigerer": "rechtslastig",
    "rechtslastigeres": "rechtslastig",
    "rechtslastiges": "rechtslastig",
    "rechtslastigste": "rechtslastig",
    "rechtslastigstem": "rechtslastig",
    "rechtslastigsten": "rechtslastig",
    "rechtslastigster": "rechtslastig",
    "rechtslastigstes": "rechtslastig",
    "rechtsliberale": "rechtsliberal",
    "rechtsliberalem": "rechtsliberal",
    "rechtsliberalen": "rechtsliberal",
    "rechtsliberaler": "rechtsliberal",
    "rechtsliberales": "rechtsliberal",
    "rechtsläufige": "rechtsläufig",
    "rechtsläufigem": "rechtsläufig",
    "rechtsläufigen": "rechtsläufig",
    "rechtsläufiger": "rechtsläufig",
    "rechtsläufiges": "rechtsläufig",
    "rechtsradikalem": "rechtsradikal",
    "rechtsradikalen": "rechtsradikal",
    "rechtsradikaler": "rechtsradikal",
    "rechtsradikalere": "rechtsradikal",
    "rechtsradikalerem": "rechtsradikal",
    "rechtsradikaleren": "rechtsradikal",
    "rechtsradikalerer": "rechtsradikal",
    "rechtsradikaleres": "rechtsradikal",
    "rechtsradikales": "rechtsradikal",
    "rechtsradikalste": "rechtsradikal",
    "rechtsradikalstem": "rechtsradikal",
    "rechtsradikalsten": "rechtsradikal",
    "rechtsradikalster": "rechtsradikal",
    "rechtsradikalstes": "rechtsradikal",
    "rechtsseitige": "rechtsseitig",
    "rechtsseitigem": "rechtsseitig",
    "rechtsseitigen": "rechtsseitig",
    "rechtsseitiger": "rechtsseitig",
    "rechtsseitiges": "rechtsseitig",
    "rechtsverbindlichem": "rechtsverbindlich",
    "rechtsverbindlichen": "rechtsverbindlich",
    "rechtsverbindlicher": "rechtsverbindlich",
    "rechtsverbindliches": "rechtsverbindlich",
    "rechtswidrigem": "rechtswidrig",
    "rechtswidrigen": "rechtswidrig",
    "rechtswidriger": "rechtswidrig",
    "rechtswidrigere": "rechtswidrig",
    "rechtswidrigerem": "rechtswidrig",
    "rechtswidrigeren": "rechtswidrig",
    "rechtswidrigerer": "rechtswidrig",
    "rechtswidrigeres": "rechtswidrig",
    "rechtswidriges": "rechtswidrig",
    "rechtswidrigste": "rechtswidrig",
    "rechtswidrigstem": "rechtswidrig",
    "rechtswidrigsten": "rechtswidrig",
    "rechtswidrigster": "rechtswidrig",
    "rechtswidrigstes": "rechtswidrig",
    "rechtwinklige": "rechtwinklig",
    "rechtwinkligem": "rechtwinklig",
    "rechtwinkligen": "rechtwinklig",
    "rechtwinkliger": "rechtwinklig",
    "rechtwinkliges": "rechtwinklig",
    "rechtzeitige": "rechtzeitig",
    "rechtzeitigem": "rechtzeitig",
    "rechtzeitigen": "rechtzeitig",
    "rechtzeitiger": "rechtzeitig",
    "rechtzeitiges": "rechtzeitig",
    "redaktionellem": "redaktionell",
    "redaktionellen": "redaktionell",
    "redaktioneller": "redaktionell",
    "redaktionelles": "redaktionell",
    "redegewandte": "redegewandt",
    "redegewandtem": "redegewandt",
    "redegewandten": "redegewandt",
    "redegewandter": "redegewandt",
    "redegewandtere": "redegewandt",
    "redegewandterem": "redegewandt",
    "redegewandteren": "redegewandt",
    "redegewandterer": "redegewandt",
    "redegewandteres": "redegewandt",
    "redegewandtes": "redegewandt",
    "redegewandteste": "redegewandt",
    "redegewandtestem": "redegewandt",
    "redegewandtesten": "redegewandt",
    "redegewandtester": "redegewandt",
    "redegewandtestes": "redegewandt",
    "redend": "reden",
    "redende": "redend",
    "redendem": "redend",
    "redenden": "redend",
    "redender": "redend",
    "redendes": "redend",
    "redest": "reden",
    "redet": "reden",
    "redete": "reden",
    "redeten": "reden",
    "redetest": "reden",
    "redetet": "reden",
    "redseligem": "redselig",
    "redseligen": "redselig",
    "redseliger": "redselig",
    "redseligere": "redselig",
    "redseligerem": "redselig",
    "redseligeren": "redselig",
    "redseligerer": "redselig",
    "redseligeres": "redselig",
    "redseliges": "redselig",
    "redseligste": "redselig",
    "redseligstem": "redselig",
    "redseligsten": "redselig",
    "redseligster": "redselig",
    "redseligstes": "redselig",
    "reduziblem": "reduzibel",
    "reduziblen": "reduzibel",
    "reduzibler": "reduzibel",
    "reduzibles": "reduzibel",
    "reduziere": "reduzieren",
    "reduzierend": "reduzieren",
    "reduzierende": "reduzierend",
    "reduzierendem": "reduzierend",
    "reduzierenden": "reduzierend",
    "reduzierender": "reduzierend",
    "reduzierendes": "reduzierend",
    "reduzierest": "reduzieren",
    "reduzieret": "reduzieren",
    "reduzierst": "reduzieren",
    "reduziert": "reduzieren",
    "reduzierte": "reduzieren",
    "reduziertem": "reduziert",
    "reduzierten": "reduzieren",
    "reduzierter": "reduziert",
    "reduziertere": "reduziert",
    "reduzierterem": "reduziert",
    "reduzierteren": "reduziert",
    "reduzierterer": "reduziert",
    "reduzierteres": "reduziert",
    "reduziertes": "reduziert",
    "reduziertest": "reduzieren",
    "reduzierteste": "reduziert",
    "reduziertestem": "reduziert",
    "reduziertesten": "reduziert",
    "reduziertester": "reduziert",
    "reduziertestes": "reduziert",
    "reduziertet": "reduzieren",
    "reellem": "reell",
    "reellen": "reell",
    "reeller": "reell",
    "reelles": "reell",
    "reetabliere": "reetablieren",
    "reetablierend": "reetablieren",
    "reetablierende": "reetablierend",
    "reetablierendem": "reetablierend",
    "reetablierenden": "reetablierend",
    "reetablierender": "reetablierend",
    "reetablierendere": "reetablierend",
    "reetablierenderem": "reetablierend",
    "reetablierenderen": "reetablierend",
    "reetablierenderer": "reetablierend",
    "reetablierenderes": "reetablierend",
    "reetablierendes": "reetablierend",
    "reetablierendste": "reetablierend",
    "reetablierendstem": "reetablierend",
    "reetablierendsten": "reetablierend",
    "reetablierendster": "reetablierend",
    "reetablierendstes": "reetablierend",
    "reetablierest": "reetablieren",
    "reetablieret": "reetablieren",
    "reetablierst": "reetablieren",
    "reetabliert": "reetablieren",
    "reetablierte": "reetablieren",
    "reetabliertem": "reetabliert",
    "reetablierten": "reetablieren",
    "reetablierter": "reetabliert",
    "reetabliertes": "reetabliert",
    "reetabliertest": "reetablieren",
    "reetabliertet": "reetablieren",
    "referiere": "referieren",
    "referierend": "referieren",
    "referierende": "referierend",
    "referierendem": "referierend",
    "referierenden": "referierend",
    "referierender": "referierend",
    "referierendes": "referierend",
    "referierest": "referieren",
    "referieret": "referieren",
    "referierst": "referieren",
    "referiert": "referieren",
    "referierte": "referieren",
    "referiertem": "referiert",
    "referierten": "referieren",
    "referierter": "referiert",
    "referiertes": "referiert",
    "referiertest": "referieren",
    "referiertet": "referieren",
    "refinanziere": "refinanzieren",
    "refinanzierend": "refinanzieren",
    "refinanzierende": "refinanzierend",
    "refinanzierendem": "refinanzierend",
    "refinanzierenden": "refinanzierend",
    "refinanzierender": "refinanzierend",
    "refinanzierendes": "refinanzierend",
    "refinanzierest": "refinanzieren",
    "refinanzieret": "refinanzieren",
    "refinanzierst": "refinanzieren",
    "refinanziert": "refinanzieren",
    "refinanzierte": "refinanzieren",
    "refinanziertem": "refinanziert",
    "refinanzierten": "refinanzieren",
    "refinanzierter": "refinanziert",
    "refinanziertes": "refinanziert",
    "refinanziertest": "refinanzieren",
    "refinanziertet": "refinanzieren",
    "reflektiere": "reflektieren",
    "reflektierend": "reflektieren",
    "reflektierende": "reflektierend",
    "reflektierendem": "reflektierend",
    "reflektierenden": "reflektierend",
    "reflektierender": "reflektierend",
    "reflektierendere": "reflektierend",
    "reflektierenderem": "reflektierend",
    "reflektierenderen": "reflektierend",
    "reflektierenderer": "reflektierend",
    "reflektierenderes": "reflektierend",
    "reflektierendes": "reflektierend",
    "reflektierendste": "reflektierend",
    "reflektierendstem": "reflektierend",
    "reflektierendsten": "reflektierend",
    "reflektierendster": "reflektierend",
    "reflektierendstes": "reflektierend",
    "reflektierest": "reflektieren",
    "reflektieret": "reflektieren",
    "reflektierst": "reflektieren",
    "reflektiert": "reflektieren",
    "reflektierte": "reflektieren",
    "reflektiertem": "reflektiert",
    "reflektierten": "reflektieren",
    "reflektierter": "reflektiert",
    "reflektiertere": "reflektiert",
    "reflektierterem": "reflektiert",
    "reflektierteren": "reflektiert",
    "reflektierterer": "reflektiert",
    "reflektierteres": "reflektiert",
    "reflektiertes": "reflektiert",
    "reflektiertest": "reflektieren",
    "reflektierteste": "reflektiert",
    "reflektiertestem": "reflektiert",
    "reflektiertesten": "reflektiert",
    "reflektiertester": "reflektiert",
    "reflektiertestes": "reflektiert",
    "reflektiertet": "reflektieren",
    "reflektorische": "reflektorisch",
    "reflektorischem": "reflektorisch",
    "reflektorischen": "reflektorisch",
    "reflektorischer": "reflektorisch",
    "reflektorisches": "reflektorisch",
    "reflexivem": "reflexiv",
    "reflexiven": "reflexiv",
    "reflexiver": "reflexiv",
    "reflexivere": "reflexiv",
    "reflexiverem": "reflexiv",
    "reflexiveren": "reflexiv",
    "reflexiverer": "reflexiv",
    "reflexiveres": "reflexiv",
    "reflexives": "reflexiv",
    "reflexivste": "reflexiv",
    "reflexivstem": "reflexiv",
    "reflexivsten": "reflexiv",
    "reflexivster": "reflexiv",
    "reflexivstes": "reflexiv",
    "reformatorischem": "reformatorisch",
    "reformatorischen": "reformatorisch",
    "reformatorischer": "reformatorisch",
    "reformatorisches": "reformatorisch",
    "reformerischem": "reformerisch",
    "reformerischen": "reformerisch",
    "reformerischer": "reformerisch",
    "reformerisches": "reformerisch",
    "reformiere": "reformieren",
    "reformierend": "reformieren",
    "reformierende": "reformierend",
    "reformierendem": "reformierend",
    "reformierenden": "reformierend",
    "reformierender": "reformierend",
    "reformierendere": "reformierend",
    "reformierenderem": "reformierend",
    "reformierenderen": "reformierend",
    "reformierenderer": "reformierend",
    "reformierenderes": "reformierend",
    "reformierendes": "reformierend",
    "reformierendste": "reformierend",
    "reformierendstem": "reformierend",
    "reformierendsten": "reformierend",
    "reformierendster": "reformierend",
    "reformierendstes": "reformierend",
    "reformierest": "reformieren",
    "reformieret": "reformieren",
    "reformierst": "reformieren",
    "reformiert": "reformieren",
    "reformierte": "reformieren",
    "reformiertem": "reformiert",
    "reformierten": "reformieren",
    "reformierter": "reformiert",
    "reformiertere": "reformiert",
    "reformierterem": "reformiert",
    "reformierteren": "reformiert",
    "reformierterer": "reformiert",
    "reformierteres": "reformiert",
    "reformiertes": "reformiert",
    "reformiertest": "reformieren",
    "reformierteste": "reformiert",
    "reformiertestem": "reformiert",
    "reformiertesten": "reformiert",
    "reformiertester": "reformiert",
    "reformiertestes": "reformiert",
    "reformiertet": "reformieren",
    "refundiere": "refundieren",
    "refundierend": "refundieren",
    "refundierende": "refundierend",
    "refundierendem": "refundierend",
    "refundierenden": "refundierend",
    "refundierender": "refundierend",
    "refundierendere": "refundierend",
    "refundierenderem": "refundierend",
    "refundierenderen": "refundierend",
    "refundierenderer": "refundierend",
    "refundierenderes": "refundierend",
    "refundierendes": "refundierend",
    "refundierendste": "refundierend",
    "refundierendstem": "refundierend",
    "refundierendsten": "refundierend",
    "refundierendster": "refundierend",
    "refundierendstes": "refundierend",
    "refundierest": "refundieren",
    "refundieret": "refundieren",
    "refundierst": "refundieren",
    "refundiert": "refundieren",
    "refundierte": "refundieren",
    "refundiertem": "refundiert",
    "refundierten": "refundieren",
    "refundierter": "refundiert",
    "refundiertere": "refundiert",
    "refundierterem": "refundiert",
    "refundierteren": "refundiert",
    "refundierterer": "refundiert",
    "refundierteres": "refundiert",
    "refundiertes": "refundiert",
    "refundiertest": "refundieren",
    "refundierteste": "refundiert",
    "refundiertestem": "refundiert",
    "refundiertesten": "refundiert",
    "refundiertester": "refundiert",
    "refundiertestes": "refundiert",
    "refundiertet": "refundieren",
    "rege": "regen",
    "regele": "regeln",
    "regellose": "regellos",
    "regellosem": "regellos",
    "regellosen": "regellos",
    "regelloser": "regellos",
    "regellosere": "regellos",
    "regelloserem": "regellos",
    "regelloseren": "regellos",
    "regelloserer": "regellos",
    "regelloseres": "regellos",
    "regelloses": "regellos",
    "regelloseste": "regellos",
    "regellosestem": "regellos",
    "regellosesten": "regellos",
    "regellosester": "regellos",
    "regellosestes": "regellos",
    "regelmäßige": "regelmäßig",
    "regelmäßigem": "regelmäßig",
    "regelmäßigen": "regelmäßig",
    "regelmäßiger": "regelmäßig",
    "regelmäßigere": "regelmäßig",
    "regelmäßigerem": "regelmäßig",
    "regelmäßigeren": "regelmäßig",
    "regelmäßigerer": "regelmäßig",
    "regelmäßigeres": "regelmäßig",
    "regelmäßiges": "regelmäßig",
    "regelmäßigste": "regelmäßig",
    "regelmäßigstem": "regelmäßig",
    "regelmäßigsten": "regelmäßig",
    "regelmäßigster": "regelmäßig",
    "regelmäßigstes": "regelmäßig",
    "regelnd": "regeln",
    "regelnde": "regelnd",
    "regelndem": "regelnd",
    "regelnden": "regelnd",
    "regelnder": "regelnd",
    "regelndes": "regelnd",
    "regelrechtem": "regelrecht",
    "regelrechten": "regelrecht",
    "regelrechter": "regelrecht",
    "regelrechtes": "regelrecht",
    "regelst": "regeln",
    "regelt": "regeln",
    "regelte": "regeln",
    "regelten": "regeln",
    "regeltest": "regeln",
    "regeltet": "regeln",
    "regelwidrigem": "regelwidrig",
    "regelwidrigen": "regelwidrig",
    "regelwidriger": "regelwidrig",
    "regelwidrigere": "regelwidrig",
    "regelwidrigerem": "regelwidrig",
    "regelwidrigeren": "regelwidrig",
    "regelwidrigerer": "regelwidrig",
    "regelwidrigeres": "regelwidrig",
    "regelwidriges": "regelwidrig",
    "regelwidrigste": "regelwidrig",
    "regelwidrigstem": "regelwidrig",
    "regelwidrigsten": "regelwidrig",
    "regelwidrigster": "regelwidrig",
    "regelwidrigstes": "regelwidrig",
    "regend": "regen",
    "regende": "regend",
    "regendem": "regend",
    "regenden": "regend",
    "regender": "regend",
    "regendes": "regend",
    "regenerativem": "regenerativ",
    "regenerativen": "regenerativ",
    "regenerativer": "regenerativ",
    "regeneratives": "regenerativ",
    "regeneriere": "regenerieren",
    "regenerierend": "regenerieren",
    "regenerierende": "regenerierend",
    "regenerierendem": "regenerierend",
    "regenerierenden": "regenerierend",
    "regenerierender": "regenerierend",
    "regenerierendes": "regenerierend",
    "regenerierest": "regenerieren",
    "regenerieret": "regenerieren",
    "regenerierst": "regenerieren",
    "regeneriert": "regenerieren",
    "regenerierte": "regenerieren",
    "regeneriertem": "regeneriert",
    "regenerierten": "regenerieren",
    "regenerierter": "regeneriert",
    "regeneriertes": "regeneriert",
    "regeneriertest": "regenerieren",
    "regeneriertet": "regenerieren",
    "regenreiche": "regenreich",
    "regenreichem": "regenreich",
    "regenreichen": "regenreich",
    "regenreicher": "regenreich",
    "regenreichere": "regenreich",
    "regenreicherem": "regenreich",
    "regenreicheren": "regenreich",
    "regenreicherer": "regenreich",
    "regenreicheres": "regenreich",
    "regenreiches": "regenreich",
    "regenreichste": "regenreich",
    "regenreichstem": "regenreich",
    "regenreichsten": "regenreich",
    "regenreichster": "regenreich",
    "regenreichstes": "regenreich",
    "regest": "regen",
    "reget": "regen",
    "regiere": "regieren",
    "regierend": "regieren",
    "regierende": "regierend",
    "regierendem": "regierend",
    "regierenden": "regierend",
    "regierender": "regierend",
    "regierendes": "regierend",
    "regierest": "regieren",
    "regieret": "regieren",
    "regierst": "regieren",
    "regiert": "regieren",
    "regierte": "regieren",
    "regiertem": "regiert",
    "regierten": "regieren",
    "regierter": "regiert",
    "regiertes": "regiert",
    "regiertest": "regieren",
    "regiertet": "regieren",
    "regierungstreuem": "regierungstreu",
    "regierungstreuen": "regierungstreu",
    "regierungstreuer": "regierungstreu",
    "regierungstreues": "regierungstreu",
    "regionalem": "regional",
    "regionalen": "regional",
    "regionaler": "regional",
    "regionales": "regional",
    "registrierbarem": "registrierbar",
    "registrierbaren": "registrierbar",
    "registrierbarer": "registrierbar",
    "registrierbares": "registrierbar",
    "registriere": "registrieren",
    "registrierend": "registrieren",
    "registrierende": "registrierend",
    "registrierendem": "registrierend",
    "registrierenden": "registrierend",
    "registrierender": "registrierend",
    "registrierendes": "registrierend",
    "registrierest": "registrieren",
    "registrieret": "registrieren",
    "registrierst": "registrieren",
    "registriert": "registrieren",
    "registrierte": "registrieren",
    "registriertem": "registriert",
    "registrierten": "registrieren",
    "registrierter": "registriert",
    "registriertes": "registriert",
    "registriertest": "registrieren",
    "registriertet": "registrieren",
    "regle": "regeln",
    "reglosem": "reglos",
    "reglosen": "reglos",
    "regloser": "reglos",
    "reglosere": "reglos",
    "regloserem": "reglos",
    "regloseren": "reglos",
    "regloserer": "reglos",
    "regloseres": "reglos",
    "regloses": "reglos",
    "regloseste": "reglos",
    "reglosestem": "reglos",
    "reglosesten": "reglos",
    "reglosester": "reglos",
    "reglosestes": "reglos",
    "regne": "regnen",
    "regnend": "regnen",
    "regnende": "regnend",
    "regnendem": "regnend",
    "regnenden": "regnend",
    "regnender": "regnend",
    "regnendes": "regnend",
    "regnerischem": "regnerisch",
    "regnerischen": "regnerisch",
    "regnerischer": "regnerisch",
    "regnerisches": "regnerisch",
    "regnest": "regnen",
    "regnet": "regnen",
    "regnete": "regnen",
    "regneten": "regnen",
    "regnetest": "regnen",
    "regnetet": "regnen",
    "regressivem": "regressiv",
    "regressiven": "regressiv",
    "regressiver": "regressiv",
    "regressives": "regressiv",
    "regst": "regen",
    "regt": "regen",
    "regte": "regen",
    "regten": "regen",
    "regtest": "regen",
    "regtet": "regen",
    "regulative": "regulativ",
    "regulativem": "regulativ",
    "regulativen": "regulativ",
    "regulativer": "regulativ",
    "regulatives": "regulativ",
    "reguliere": "regulieren",
    "regulierend": "regulieren",
    "regulierende": "regulierend",
    "regulierendem": "regulierend",
    "regulierenden": "regulierend",
    "regulierender": "regulierend",
    "regulierendes": "regulierend",
    "regulierest": "regulieren",
    "regulieret": "regulieren",
    "regulierst": "regulieren",
    "reguliert": "regulieren",
    "regulierte": "regulieren",
    "reguliertem": "reguliert",
    "regulierten": "regulieren",
    "regulierter": "reguliert",
    "reguliertes": "reguliert",
    "reguliertest": "regulieren",
    "reguliertet": "regulieren",
    "reguläre": "regulär",
    "regulärem": "regulär",
    "regulären": "regulär",
    "regulärer": "regulär",
    "reguläres": "regulär",
    "regungslosem": "regungslos",
    "regungslosen": "regungslos",
    "regungsloser": "regungslos",
    "regungsloses": "regungslos",
    "rehabilitiere": "rehabilitieren",
    "rehabilitierend": "rehabilitieren",
    "rehabilitierende": "rehabilitierend",
    "rehabilitierendem": "rehabilitierend",
    "rehabilitierenden": "rehabilitierend",
    "rehabilitierender": "rehabilitierend",
    "rehabilitierendes": "rehabilitierend",
    "rehabilitierest": "rehabilitieren",
    "rehabilitieret": "rehabilitieren",
    "rehabilitierst": "rehabilitieren",
    "rehabilitiert": "rehabilitieren",
    "rehabilitierte": "rehabilitieren",
    "rehabilitiertem": "rehabilitiert",
    "rehabilitierten": "rehabilitieren",
    "rehabilitierter": "rehabilitiert",
    "rehabilitiertere": "rehabilitiert",
    "rehabilitierterem": "rehabilitiert",
    "rehabilitierteren": "rehabilitiert",
    "rehabilitierterer": "rehabilitiert",
    "rehabilitierteres": "rehabilitiert",
    "rehabilitiertes": "rehabilitiert",
    "rehabilitiertest": "rehabilitieren",
    "rehabilitiertestem": "rehabilitiert",
    "rehabilitiertesten": "rehabilitiert",
    "rehabilitiertester": "rehabilitiert",
    "rehabilitiertestes": "rehabilitiert",
    "rehabilitiertet": "rehabilitieren",
    "reibe": "reiben",
    "reibend": "reiben",
    "reibende": "reibend",
    "reibendem": "reibend",
    "reibenden": "reibend",
    "reibender": "reibend",
    "reibendere": "reibend",
    "reibenderem": "reibend",
    "reibenderen": "reibend",
    "reibenderer": "reibend",
    "reibenderes": "reibend",
    "reibendes": "reibend",
    "reibendste": "reibend",
    "reibendstem": "reibend",
    "reibendsten": "reibend",
    "reibendster": "reibend",
    "reibendstes": "reibend",
    "reibest": "reiben",
    "reibet": "reiben",
    "reibst": "reiben",
    "reibt": "reiben",
    "reibungslosem": "reibungslos",
    "reibungslosen": "reibungslos",
    "reibungsloser": "reibungslos",
    "reibungslosere": "reibungslos",
    "reibungsloserem": "reibungslos",
    "reibungsloseren": "reibungslos",
    "reibungsloserer": "reibungslos",
    "reibungsloseres": "reibungslos",
    "reibungsloses": "reibungslos",
    "reibungsloseste": "reibungslos",
    "reibungslosestem": "reibungslos",
    "reibungslosesten": "reibungslos",
    "reibungslosester": "reibungslos",
    "reibungslosestes": "reibungslos",
    "reich": "reichen",
    "reiche": "reichen",
    "reichem": "reich",
    "reichen": "reich",
    "reichend": "reichen",
    "reichende": "reichend",
    "reichendem": "reichend",
    "reichenden": "reichend",
    "reichender": "reichend",
    "reichendes": "reichend",
    "reicher": "reichern",
    "reichere": "reich",
    "reicherem": "reich",
    "reicheren": "reich",
    "reicherer": "reich",
    "reicheres": "reich",
    "reichernd": "reichern",
    "reichernde": "reichernd",
    "reicherndem": "reichernd",
    "reichernden": "reichernd",
    "reichernder": "reichernd",
    "reicherndes": "reichernd",
    "reicherst": "reichern",
    "reichert": "reichern",
    "reicherte": "reichern",
    "reicherten": "reichern",
    "reichertest": "reichern",
    "reichertet": "reichern",
    "reiches": "reich",
    "reichest": "reichen",
    "reichet": "reichen",
    "reichhaltige": "reichhaltig",
    "reichhaltigem": "reichhaltig",
    "reichhaltigen": "reichhaltig",
    "reichhaltiger": "reichhaltig",
    "reichhaltigere": "reichhaltig",
    "reichhaltigerem": "reichhaltig",
    "reichhaltigeren": "reichhaltig",
    "reichhaltigerer": "reichhaltig",
    "reichhaltigeres": "reichhaltig",
    "reichhaltiges": "reichhaltig",
    "reichhaltigste": "reichhaltig",
    "reichhaltigstem": "reichhaltig",
    "reichhaltigsten": "reichhaltig",
    "reichhaltigster": "reichhaltig",
    "reichhaltigstes": "reichhaltig",
    "reichliche": "reichlich",
    "reichlichem": "reichlich",
    "reichlichen": "reichlich",
    "reichlicher": "reichlich",
    "reichlichere": "reichlich",
    "reichlicherem": "reichlich",
    "reichlicheren": "reichlich",
    "reichlicherer": "reichlich",
    "reichlicheres": "reichlich",
    "reichliches": "reichlich",
    "reichlichste": "reichlich",
    "reichlichstem": "reichlich",
    "reichlichsten": "reichlich",
    "reichlichster": "reichlich",
    "reichlichstes": "reichlich",
    "reichst": "reichen",
    "reichste": "reich",
    "reichstem": "reich",
    "reichsten": "reich",
    "reichster": "reich",
    "reichstes": "reich",
    "reicht": "reichen",
    "reichte": "reichen",
    "reichten": "reichen",
    "reichtest": "reichen",
    "reichtet": "reichen",
    "reife": "reif",
    "reifem": "reif",
    "reifen": "reif",
    "reifend": "reifen",
    "reifende": "reifend",
    "reifendem": "reifend",
    "reifenden": "reifend",
    "reifender": "reifend",
    "reifendere": "reifend",
    "reifenderem": "reifend",
    "reifenderen": "reifend",
    "reifenderer": "reifend",
    "reifenderes": "reifend",
    "reifendes": "reifend",
    "reifendste": "reifend",
    "reifendstem": "reifend",
    "reifendsten": "reifend",
    "reifendster": "reifend",
    "reifendstes": "reifend",
    "reifer": "reif",
    "reifere": "reif",
    "reiferem": "reif",
    "reiferen": "reif",
    "reiferer": "reif",
    "reiferes": "reif",
    "reifes": "reif",
    "reifest": "reifen",
    "reifet": "reifen",
    "reifliche": "reiflich",
    "reiflichem": "reiflich",
    "reiflichen": "reiflich",
    "reiflicher": "reiflich",
    "reifliches": "reiflich",
    "reifst": "reifen",
    "reifste": "reif",
    "reifstem": "reif",
    "reifsten": "reif",
    "reifster": "reif",
    "reifstes": "reif",
    "reift": "reifen",
    "reifte": "reifen",
    "reiften": "reifen",
    "reiftest": "reifen",
    "reiftet": "reifen",
    "reihend": "reihen",
    "reihende": "reihend",
    "reihendem": "reihend",
    "reihenden": "reihend",
    "reihender": "reihend",
    "reihendes": "reihend",
    "reihere": "reihern",
    "reihernd": "reihern",
    "reihernde": "reihernd",
    "reiherndem": "reihernd",
    "reihernden": "reihernd",
    "reihernder": "reihernd",
    "reiherndes": "reihernd",
    "reiherst": "reihern",
    "reihert": "reihern",
    "reiherte": "reihern",
    "reiherten": "reihern",
    "reihertest": "reihern",
    "reihertet": "reihern",
    "reihest": "reihen",
    "reihet": "reihen",
    "reihst": "reihen",
    "reiht": "reihen",
    "reihte": "reihen",
    "reihten": "reihen",
    "reihtest": "reihen",
    "reihtet": "reihen",
    "reime": "reimen",
    "reimend": "reimen",
    "reimende": "reimend",
    "reimendem": "reimend",
    "reimenden": "reimend",
    "reimender": "reimend",
    "reimendes": "reimend",
    "reimest": "reimen",
    "reimet": "reimen",
    "reimst": "reimen",
    "reimt": "reimen",
    "reimte": "reimen",
    "reimten": "reimen",
    "reimtest": "reimen",
    "reimtet": "reimen",
    "reinem": "rein",
    "reinen": "rein",
    "reiner": "rein",
    "reinere": "rein",
    "reinerem": "rein",
    "reineren": "rein",
    "reinerer": "rein",
    "reineres": "rein",
    "reines": "rein",
    "reinfalle": "reinfallen",
    "reinfallend": "reinfallen",
    "reinfallende": "reinfallend",
    "reinfallendem": "reinfallend",
    "reinfallenden": "reinfallend",
    "reinfallender": "reinfallend",
    "reinfallendes": "reinfallend",
    "reinfallest": "reinfallen",
    "reinfallet": "reinfallen",
    "reinfallt": "reinfallen",
    "reinfiel": "reinfallen",
    "reinfiele": "reinfallen",
    "reinfielen": "reinfallen",
    "reinfielest": "reinfallen",
    "reinfielet": "reinfallen",
    "reinfielst": "reinfallen",
    "reinfielt": "reinfallen",
    "reinfällst": "reinfallen",
    "reinfällt": "reinfallen",
    "reingefallen": "reinfallen",
    "reingefallene": "reingefallen",
    "reingefallenem": "reingefallen",
    "reingefallenen": "reingefallen",
    "reingefallener": "reingefallen",
    "reingefallenes": "reingefallen",
    "reingeredet": "reinreden",
    "reingeredete": "reingeredet",
    "reingeredetem": "reingeredet",
    "reingeredeten": "reingeredet",
    "reingeredeter": "reingeredet",
    "reingeredetes": "reingeredet",
    "reingerissen": "reinreißen",
    "reingerissene": "reingerissen",
    "reingerissenem": "reingerissen",
    "reingerissenen": "reingerissen",
    "reingerissener": "reingerissen",
    "reingerissenes": "reingerissen",
    "reingeritten": "reinreiten",
    "reingerittene": "reingeritten",
    "reingerittenem": "reingeritten",
    "reingerittenen": "reingeritten",
    "reingerittener": "reingeritten",
    "reingerittenes": "reingeritten",
    "reingerochen": "reinriechen",
    "reingerochene": "reingerochen",
    "reingerochenem": "reingerochen",
    "reingerochenen": "reingerochen",
    "reingerochener": "reingerochen",
    "reingerochenes": "reingerochen",
    "reingewaschen": "reinwaschen",
    "reingewaschene": "reingewaschen",
    "reingewaschenem": "reingewaschen",
    "reingewaschenen": "reingewaschen",
    "reingewaschener": "reingewaschen",
    "reingewaschenes": "reingewaschen",
    "reingewürgt": "reinwürgen",
    "reingewürgte": "reingewürgt",
    "reingewürgtem": "reingewürgt",
    "reingewürgten": "reingewürgt",
    "reingewürgter": "reingewürgt",
    "reingewürgtes": "reingewürgt",
    "reinige": "reinigen",
    "reinigend": "reinigen",
    "reinigende": "reinigend",
    "reinigendem": "reinigend",
    "reinigenden": "reinigend",
    "reinigender": "reinigend",
    "reinigendere": "reinigend",
    "reinigenderem": "reinigend",
    "reinigenderen": "reinigend",
    "reinigenderer": "reinigend",
    "reinigenderes": "reinigend",
    "reinigendes": "reinigend",
    "reinigendste": "reinigend",
    "reinigendstem": "reinigend",
    "reinigendsten": "reinigend",
    "reinigendster": "reinigend",
    "reinigendstes": "reinigend",
    "reinigest": "reinigen",
    "reiniget": "reinigen",
    "reinigst": "reinigen",
    "reinigt": "reinigen",
    "reinigte": "reinigen",
    "reinigten": "reinigen",
    "reinigtest": "reinigen",
    "reinigtet": "reinigen",
    "reinlichem": "reinlich",
    "reinlichen": "reinlich",
    "reinlicher": "reinlich",
    "reinlichere": "reinlich",
    "reinlicherem": "reinlich",
    "reinlicheren": "reinlich",
    "reinlicherer": "reinlich",
    "reinlicheres": "reinlich",
    "reinliches": "reinlich",
    "reinlichste": "reinlich",
    "reinlichstem": "reinlich",
    "reinlichsten": "reinlich",
    "reinlichster": "reinlich",
    "reinlichstes": "reinlich",
    "reinrassigem": "reinrassig",
    "reinrassigen": "reinrassig",
    "reinrassiger": "reinrassig",
    "reinrassigere": "reinrassig",
    "reinrassigerem": "reinrassig",
    "reinrassigeren": "reinrassig",
    "reinrassigerer": "reinrassig",
    "reinrassigeres": "reinrassig",
    "reinrassiges": "reinrassig",
    "reinrassigste": "reinrassig",
    "reinrassigstem": "reinrassig",
    "reinrassigsten": "reinrassig",
    "reinrassigster": "reinrassig",
    "reinrassigstes": "reinrassig",
    "reinrede": "reinreden",
    "reinredend": "reinreden",
    "reinredende": "reinredend",
    "reinredendem": "reinredend",
    "reinredenden": "reinredend",
    "reinredender": "reinredend",
    "reinredendere": "reinredend",
    "reinredenderem": "reinredend",
    "reinredenderen": "reinredend",
    "reinredenderer": "reinredend",
    "reinredenderes": "reinredend",
    "reinredendes": "reinredend",
    "reinredendste": "reinredend",
    "reinredendstem": "reinredend",
    "reinredendsten": "reinredend",
    "reinredendster": "reinredend",
    "reinredendstes": "reinredend",
    "reinredest": "reinreden",
    "reinredet": "reinreden",
    "reinredete": "reinreden",
    "reinredeten": "reinreden",
    "reinredetest": "reinreden",
    "reinredetet": "reinreden",
    "reinreite": "reinreiten",
    "reinreitend": "reinreiten",
    "reinreitende": "reinreitend",
    "reinreitendem": "reinreitend",
    "reinreitenden": "reinreitend",
    "reinreitender": "reinreitend",
    "reinreitendes": "reinreitend",
    "reinreitest": "reinreiten",
    "reinreitet": "reinreiten",
    "reinreiße": "reinreißen",
    "reinreißend": "reinreißen",
    "reinreißende": "reinreißend",
    "reinreißendem": "reinreißend",
    "reinreißenden": "reinreißend",
    "reinreißender": "reinreißend",
    "reinreißendes": "reinreißend",
    "reinreißest": "reinreißen",
    "reinreißet": "reinreißen",
    "reinreißt": "reinreißen",
    "reinrieche": "reinriechen",
    "reinriechend": "reinriechen",
    "reinriechende": "reinriechend",
    "reinriechendem": "reinriechend",
    "reinriechenden": "reinriechend",
    "reinriechender": "reinriechend",
    "reinriechendes": "reinriechend",
    "reinriechest": "reinriechen",
    "reinriechet": "reinriechen",
    "reinriechst": "reinriechen",
    "reinriecht": "reinriechen",
    "reinrisse": "reinreißen",
    "reinrissen": "reinreißen",
    "reinrissest": "reinreißen",
    "reinrisset": "reinreißen",
    "reinritt": "reinreiten",
    "reinritte": "reinreiten",
    "reinritten": "reinreiten",
    "reinrittest": "reinreiten",
    "reinrittet": "reinreiten",
    "reinriß": "reinreißen",
    "reinrißt": "reinreißen",
    "reinroch": "reinriechen",
    "reinrochen": "reinriechen",
    "reinrochst": "reinriechen",
    "reinrocht": "reinriechen",
    "reinröche": "reinriechen",
    "reinröchen": "reinriechen",
    "reinröchest": "reinriechen",
    "reinröchet": "reinriechen",
    "reinste": "rein",
    "reinstem": "rein",
    "reinsten": "rein",
    "reinster": "rein",
    "reinstes": "rein",
    "reinwasche": "reinwaschen",
    "reinwaschend": "reinwaschen",
    "reinwaschende": "reinwaschend",
    "reinwaschendem": "reinwaschend",
    "reinwaschenden": "reinwaschend",
    "reinwaschender": "reinwaschend",
    "reinwaschendes": "reinwaschend",
    "reinwaschest": "reinwaschen",
    "reinwaschet": "reinwaschen",
    "reinwascht": "reinwaschen",
    "reinwusch": "reinwaschen",
    "reinwuschen": "reinwaschen",
    "reinwuschst": "reinwaschen",
    "reinwuscht": "reinwaschen",
    "reinwäschst": "reinwaschen",
    "reinwäscht": "reinwaschen",
    "reinwürge": "reinwürgen",
    "reinwürgend": "reinwürgen",
    "reinwürgende": "reinwürgend",
    "reinwürgendem": "reinwürgend",
    "reinwürgenden": "reinwürgend",
    "reinwürgender": "reinwürgend",
    "reinwürgendes": "reinwürgend",
    "reinwürgest": "reinwürgen",
    "reinwürget": "reinwürgen",
    "reinwürgst": "reinwürgen",
    "reinwürgt": "reinwürgen",
    "reinwürgte": "reinwürgen",
    "reinwürgten": "reinwürgen",
    "reinwürgtest": "reinwürgen",
    "reinwürgtet": "reinwürgen",
    "reinwüsche": "reinwaschen",
    "reinwüschen": "reinwaschen",
    "reinwüschest": "reinwaschen",
    "reinwüschet": "reinwaschen",
    "reinzufallen": "reinfallen",
    "reinzureden": "reinreden",
    "reinzureiten": "reinreiten",
    "reinzureißen": "reinreißen",
    "reinzuriechen": "reinriechen",
    "reinzuwaschen": "reinwaschen",
    "reinzuwürgen": "reinwürgen",
    "reisefertige": "reisefertig",
    "reisefertigem": "reisefertig",
    "reisefertigen": "reisefertig",
    "reisefertiger": "reisefertig",
    "reisefertiges": "reisefertig",
    "reiselustige": "reiselustig",
    "reiselustigem": "reiselustig",
    "reiselustigen": "reiselustig",
    "reiselustiger": "reiselustig",
    "reiselustigere": "reiselustig",
    "reiselustigerem": "reiselustig",
    "reiselustigeren": "reiselustig",
    "reiselustigerer": "reiselustig",
    "reiselustigeres": "reiselustig",
    "reiselustiges": "reiselustig",
    "reiselustigste": "reiselustig",
    "reiselustigstem": "reiselustig",
    "reiselustigsten": "reiselustig",
    "reiselustigster": "reiselustig",
    "reiselustigstes": "reiselustig",
    "reisend": "reisen",
    "reisende": "reisend",
    "reisendem": "reisend",
    "reisenden": "reisend",
    "reisender": "reisend",
    "reisendes": "reisend",
    "reisest": "reisen",
    "reiset": "reisen",
    "reist": "reisen",
    "reiste": "reisen",
    "reisten": "reisen",
    "reistest": "reisen",
    "reistet": "reisen",
    "reite": "reiten",
    "reitend": "reiten",
    "reitende": "reitend",
    "reitendem": "reitend",
    "reitenden": "reitend",
    "reitender": "reitend",
    "reitendes": "reitend",
    "reitest": "reiten",
    "reitet": "reiten",
    "reizbarem": "reizbar",
    "reizbaren": "reizbar",
    "reizbarer": "reizbar",
    "reizbarere": "reizbar",
    "reizbarerem": "reizbar",
    "reizbareren": "reizbar",
    "reizbarerer": "reizbar",
    "reizbareres": "reizbar",
    "reizbares": "reizbar",
    "reizbarste": "reizbar",
    "reizbarstem": "reizbar",
    "reizbarsten": "reizbar",
    "reizbarster": "reizbar",
    "reizbarstes": "reizbar",
    "reizend": "reizen",
    "reizende": "reizend",
    "reizendem": "reizend",
    "reizenden": "reizend",
    "reizender": "reizend",
    "reizendes": "reizend",
    "reizest": "reizen",
    "reizet": "reizen",
    "reizlose": "reizlos",
    "reizlosem": "reizlos",
    "reizlosen": "reizlos",
    "reizloser": "reizlos",
    "reizlosere": "reizlos",
    "reizloserem": "reizlos",
    "reizloseren": "reizlos",
    "reizloserer": "reizlos",
    "reizloseres": "reizlos",
    "reizloses": "reizlos",
    "reizloseste": "reizlos",
    "reizlosestem": "reizlos",
    "reizlosesten": "reizlos",
    "reizlosester": "reizlos",
    "reizlosestes": "reizlos",
    "reizt": "reizen",
    "reizte": "reizen",
    "reizten": "reizen",
    "reiztest": "reizen",
    "reiztet": "reizen",
    "reizvollem": "reizvoll",
    "reizvollen": "reizvoll",
    "reizvoller": "reizvoll",
    "reizvollere": "reizvoll",
    "reizvollerem": "reizvoll",
    "reizvolleren": "reizvoll",
    "reizvollerer": "reizvoll",
    "reizvolleres": "reizvoll",
    "reizvolles": "reizvoll",
    "reizvollste": "reizvoll",
    "reizvollstem": "reizvoll",
    "reizvollsten": "reizvoll",
    "reizvollster": "reizvoll",
    "reizvollstes": "reizvoll",
    "reiße": "reißen",
    "reißend": "reißen",
    "reißende": "reißend",
    "reißendem": "reißend",
    "reißenden": "reißend",
    "reißender": "reißend",
    "reißendes": "reißend",
    "reißest": "reißen",
    "reißet": "reißen",
    "reißfestem": "reißfest",
    "reißfesten": "reißfest",
    "reißfester": "reißfest",
    "reißfestere": "reißfest",
    "reißfesterem": "reißfest",
    "reißfesteren": "reißfest",
    "reißfesterer": "reißfest",
    "reißfesteres": "reißfest",
    "reißfestes": "reißfest",
    "reißfesteste": "reißfest",
    "reißfestestem": "reißfest",
    "reißfestesten": "reißfest",
    "reißfestester": "reißfest",
    "reißfestestes": "reißfest",
    "reißt": "reißen",
    "rekapituliere": "rekapitulieren",
    "rekapitulierend": "rekapitulieren",
    "rekapitulierende": "rekapitulierend",
    "rekapitulierendem": "rekapitulierend",
    "rekapitulierenden": "rekapitulierend",
    "rekapitulierender": "rekapitulierend",
    "rekapitulierendes": "rekapitulierend",
    "rekapitulierest": "rekapitulieren",
    "rekapitulieret": "rekapitulieren",
    "rekapitulierst": "rekapitulieren",
    "rekapituliert": "rekapitulieren",
    "rekapitulierte": "rekapitulieren",
    "rekapituliertem": "rekapituliert",
    "rekapitulierten": "rekapitulieren",
    "rekapitulierter": "rekapituliert",
    "rekapituliertes": "rekapituliert",
    "rekapituliertest": "rekapitulieren",
    "rekapituliertet": "rekapitulieren",
    "reklamiere": "reklamieren",
    "reklamierend": "reklamieren",
    "reklamierende": "reklamierend",
    "reklamierendem": "reklamierend",
    "reklamierenden": "reklamierend",
    "reklamierender": "reklamierend",
    "reklamierendes": "reklamierend",
    "reklamierest": "reklamieren",
    "reklamieret": "reklamieren",
    "reklamierst": "reklamieren",
    "reklamiert": "reklamieren",
    "reklamierte": "reklamieren",
    "reklamiertem": "reklamiert",
    "reklamierten": "reklamieren",
    "reklamierter": "reklamiert",
    "reklamiertes": "reklamiert",
    "reklamiertest": "reklamieren",
    "reklamiertet": "reklamieren",
    "rekonstruiere": "rekonstruieren",
    "rekonstruierend": "rekonstruieren",
    "rekonstruierende": "rekonstruierend",
    "rekonstruierendem": "rekonstruierend",
    "rekonstruierenden": "rekonstruierend",
    "rekonstruierender": "rekonstruierend",
    "rekonstruierendes": "rekonstruierend",
    "rekonstruierest": "rekonstruieren",
    "rekonstruieret": "rekonstruieren",
    "rekonstruierst": "rekonstruieren",
    "rekonstruiert": "rekonstruieren",
    "rekonstruierte": "rekonstruieren",
    "rekonstruiertem": "rekonstruiert",
    "rekonstruierten": "rekonstruieren",
    "rekonstruierter": "rekonstruiert",
    "rekonstruiertere": "rekonstruiert",
    "rekonstruierterem": "rekonstruiert",
    "rekonstruierteren": "rekonstruiert",
    "rekonstruierterer": "rekonstruiert",
    "rekonstruierteres": "rekonstruiert",
    "rekonstruiertes": "rekonstruiert",
    "rekonstruiertest": "rekonstruieren",
    "rekonstruiertestem": "rekonstruiert",
    "rekonstruiertesten": "rekonstruiert",
    "rekonstruiertester": "rekonstruiert",
    "rekonstruiertestes": "rekonstruiert",
    "rekonstruiertet": "rekonstruieren",
    "rekrutiere": "rekrutieren",
    "rekrutierend": "rekrutieren",
    "rekrutierende": "rekrutierend",
    "rekrutierendem": "rekrutierend",
    "rekrutierenden": "rekrutierend",
    "rekrutierender": "rekrutierend",
    "rekrutierendes": "rekrutierend",
    "rekrutierest": "rekrutieren",
    "rekrutieret": "rekrutieren",
    "rekrutierst": "rekrutieren",
    "rekrutiert": "rekrutieren",
    "rekrutierte": "rekrutieren",
    "rekrutiertem": "rekrutiert",
    "rekrutierten": "rekrutieren",
    "rekrutierter": "rekrutiert",
    "rekrutiertes": "rekrutiert",
    "rekrutiertest": "rekrutieren",
    "rekrutiertet": "rekrutieren",
    "rektale": "rektal",
    "rektalem": "rektal",
    "rektalen": "rektal",
    "rektaler": "rektal",
    "rektales": "rektal",
    "rektifiziere": "rektifizieren",
    "rektifizierend": "rektifizieren",
    "rektifizierende": "rektifizierend",
    "rektifizierendem": "rektifizierend",
    "rektifizierenden": "rektifizierend",
    "rektifizierender": "rektifizierend",
    "rektifizierendes": "rektifizierend",
    "rektifizierest": "rektifizieren",
    "rektifizieret": "rektifizieren",
    "rektifizierst": "rektifizieren",
    "rektifiziert": "rektifizieren",
    "rektifizierte": "rektifizieren",
    "rektifiziertem": "rektifiziert",
    "rektifizierten": "rektifizieren",
    "rektifizierter": "rektifiziert",
    "rektifiziertes": "rektifiziert",
    "rektifiziertest": "rektifizieren",
    "rektifiziertet": "rektifizieren",
    "rekurrentem": "rekurrent",
    "rekurrenten": "rekurrent",
    "rekurrenter": "rekurrent",
    "rekurrentes": "rekurrent",
    "rekurriere": "rekurrieren",
    "rekurrierend": "rekurrieren",
    "rekurrierende": "rekurrierend",
    "rekurrierendem": "rekurrierend",
    "rekurrierenden": "rekurrierend",
    "rekurrierender": "rekurrierend",
    "rekurrierendes": "rekurrierend",
    "rekurrierest": "rekurrieren",
    "rekurrieret": "rekurrieren",
    "rekurrierst": "rekurrieren",
    "rekurriert": "rekurrieren",
    "rekurrierte": "rekurrieren",
    "rekurriertem": "rekurriert",
    "rekurrierten": "rekurrieren",
    "rekurrierter": "rekurriert",
    "rekurriertes": "rekurriert",
    "rekurriertest": "rekurrieren",
    "rekurriertet": "rekurrieren",
    "rekursive": "rekursiv",
    "rekursivem": "rekursiv",
    "rekursiven": "rekursiv",
    "rekursiver": "rekursiv",
    "rekursives": "rekursiv",
    "relativem": "relativ",
    "relativen": "relativ",
    "relativer": "relativ",
    "relatives": "relativ",
    "relevantem": "relevant",
    "relevanten": "relevant",
    "relevanter": "relevant",
    "relevantere": "relevant",
    "relevanterem": "relevant",
    "relevanteren": "relevant",
    "relevanterer": "relevant",
    "relevanteres": "relevant",
    "relevantes": "relevant",
    "relevanteste": "relevant",
    "relevantestem": "relevant",
    "relevantesten": "relevant",
    "relevantester": "relevant",
    "relevantestes": "relevant",
    "religionslosem": "religionslos",
    "religionslosen": "religionslos",
    "religionsloser": "religionslos",
    "religionsloses": "religionslos",
    "religiöse": "religiös",
    "religiösem": "religiös",
    "religiösen": "religiös",
    "religiöser": "religiös",
    "religiösere": "religiös",
    "religiöserem": "religiös",
    "religiöseren": "religiös",
    "religiöserer": "religiös",
    "religiöseres": "religiös",
    "religiöses": "religiös",
    "religiöseste": "religiös",
    "religiösestem": "religiös",
    "religiösesten": "religiös",
    "religiösester": "religiös",
    "religiösestes": "religiös",
    "remilitarisiere": "remilitarisieren",
    "remilitarisierend": "remilitarisieren",
    "remilitarisierende": "remilitarisierend",
    "remilitarisierendem": "remilitarisierend",
    "remilitarisierenden": "remilitarisierend",
    "remilitarisierender": "remilitarisierend",
    "remilitarisierendes": "remilitarisierend",
    "remilitarisierest": "remilitarisieren",
    "remilitarisieret": "remilitarisieren",
    "remilitarisierst": "remilitarisieren",
    "remilitarisiert": "remilitarisieren",
    "remilitarisierte": "remilitarisieren",
    "remilitarisiertem": "remilitarisiert",
    "remilitarisierten": "remilitarisieren",
    "remilitarisierter": "remilitarisiert",
    "remilitarisiertes": "remilitarisiert",
    "remilitarisiertest": "remilitarisieren",
    "remilitarisiertet": "remilitarisieren",
    "remontiere": "remontieren",
    "remontierend": "remontieren",
    "remontierende": "remontierend",
    "remontierendem": "remontierend",
    "remontierenden": "remontierend",
    "remontierender": "remontierend",
    "remontierendes": "remontierend",
    "remontierest": "remontieren",
    "remontieret": "remontieren",
    "remontierst": "remontieren",
    "remontiert": "remontieren",
    "remontierte": "remontieren",
    "remontiertem": "remontiert",
    "remontierten": "remontieren",
    "remontierter": "remontiert",
    "remontiertes": "remontiert",
    "remontiertest": "remontieren",
    "remontiertet": "remontieren",
    "rempele": "rempeln",
    "rempelnd": "rempeln",
    "rempelnde": "rempelnd",
    "rempelndem": "rempelnd",
    "rempelnden": "rempelnd",
    "rempelnder": "rempelnd",
    "rempelndere": "rempelnd",
    "rempelnderem": "rempelnd",
    "rempelnderen": "rempelnd",
    "rempelnderer": "rempelnd",
    "rempelnderes": "rempelnd",
    "rempelndes": "rempelnd",
    "rempelndste": "rempelnd",
    "rempelndstem": "rempelnd",
    "rempelndsten": "rempelnd",
    "rempelndster": "rempelnd",
    "rempelndstes": "rempelnd",
    "rempelst": "rempeln",
    "rempelt": "rempeln",
    "rempelte": "rempeln",
    "rempelten": "rempeln",
    "rempeltest": "rempeln",
    "rempeltet": "rempeln",
    "remple": "rempeln",
    "renaturiere": "renaturieren",
    "renaturierend": "renaturieren",
    "renaturierende": "renaturierend",
    "renaturierendem": "renaturierend",
    "renaturierenden": "renaturierend",
    "renaturierender": "renaturierend",
    "renaturierendere": "renaturierend",
    "renaturierenderem": "renaturierend",
    "renaturierenderen": "renaturierend",
    "renaturierenderer": "renaturierend",
    "renaturierenderes": "renaturierend",
    "renaturierendes": "renaturierend",
    "renaturierendste": "renaturierend",
    "renaturierendstem": "renaturierend",
    "renaturierendsten": "renaturierend",
    "renaturierendster": "renaturierend",
    "renaturierendstes": "renaturierend",
    "renaturierest": "renaturieren",
    "renaturieret": "renaturieren",
    "renaturierst": "renaturieren",
    "renaturiert": "renaturieren",
    "renaturierte": "renaturieren",
    "renaturiertem": "renaturiert",
    "renaturierten": "renaturieren",
    "renaturierter": "renaturiert",
    "renaturiertere": "renaturiert",
    "renaturierterem": "renaturiert",
    "renaturierteren": "renaturiert",
    "renaturierterer": "renaturiert",
    "renaturierteres": "renaturiert",
    "renaturiertes": "renaturiert",
    "renaturiertest": "renaturieren",
    "renaturierteste": "renaturiert",
    "renaturiertestem": "renaturiert",
    "renaturiertesten": "renaturiert",
    "renaturiertester": "renaturiert",
    "renaturiertestes": "renaturiert",
    "renaturiertet": "renaturieren",
    "renitentem": "renitent",
    "renitenten": "renitent",
    "renitenter": "renitent",
    "renitentere": "renitent",
    "renitenterem": "renitent",
    "renitenteren": "renitent",
    "renitenterer": "renitent",
    "renitenteres": "renitent",
    "renitentes": "renitent",
    "renitenteste": "renitent",
    "renitentestem": "renitent",
    "renitentesten": "renitent",
    "renitentester": "renitent",
    "renitentestes": "renitent",
    "renke": "renken",
    "renkend": "renken",
    "renkende": "renkend",
    "renkendem": "renkend",
    "renkenden": "renkend",
    "renkender": "renkend",
    "renkendes": "renkend",
    "renkest": "renken",
    "renket": "renken",
    "renkst": "renken",
    "renkt": "renken",
    "renkte": "renken",
    "renkten": "renken",
    "renktest": "renken",
    "renktet": "renken",
    "renne": "rennen",
    "rennend": "rennen",
    "rennende": "rennend",
    "rennendem": "rennend",
    "rennenden": "rennend",
    "rennender": "rennend",
    "rennendes": "rennend",
    "rennest": "rennen",
    "rennet": "rennen",
    "rennst": "rennen",
    "rennt": "rennen",
    "renommiertem": "renommiert",
    "renommierten": "renommiert",
    "renommierter": "renommiert",
    "renommiertere": "renommiert",
    "renommierterem": "renommiert",
    "renommierteren": "renommiert",
    "renommierterer": "renommiert",
    "renommierteres": "renommiert",
    "renommiertes": "renommiert",
    "renommierteste": "renommiert",
    "renommiertestem": "renommiert",
    "renommiertesten": "renommiert",
    "renommiertester": "renommiert",
    "renommiertestes": "renommiert",
    "renoviere": "renovieren",
    "renovierend": "renovieren",
    "renovierende": "renovierend",
    "renovierendem": "renovierend",
    "renovierenden": "renovierend",
    "renovierender": "renovierend",
    "renovierendes": "renovierend",
    "renovierest": "renovieren",
    "renovieret": "renovieren",
    "renovierst": "renovieren",
    "renoviert": "renovieren",
    "renovierte": "renovieren",
    "renoviertem": "renoviert",
    "renovierten": "renovieren",
    "renovierter": "renoviert",
    "renoviertere": "renoviert",
    "renovierterem": "renoviert",
    "renovierteren": "renoviert",
    "renovierterer": "renoviert",
    "renovierteres": "renoviert",
    "renoviertes": "renoviert",
    "renoviertest": "renovieren",
    "renovierteste": "renoviert",
    "renoviertestem": "renoviert",
    "renoviertesten": "renoviert",
    "renoviertester": "renoviert",
    "renoviertestes": "renoviert",
    "renoviertet": "renovieren",
    "rentabelstem": "rentabel",
    "rentabelsten": "rentabel",
    "rentabelster": "rentabel",
    "rentabelstes": "rentabel",
    "rentable": "rentabel",
    "rentablem": "rentabel",
    "rentablen": "rentabel",
    "rentabler": "rentabel",
    "rentablere": "rentabel",
    "rentablerem": "rentabel",
    "rentableren": "rentabel",
    "rentablerer": "rentabel",
    "rentableres": "rentabel",
    "rentables": "rentabel",
    "rentenpflichtigem": "rentenpflichtig",
    "rentenpflichtigen": "rentenpflichtig",
    "rentenpflichtiger": "rentenpflichtig",
    "rentenpflichtiges": "rentenpflichtig",
    "rentierend": "rentieren",
    "rentierende": "rentierend",
    "rentierendem": "rentierend",
    "rentierenden": "rentierend",
    "rentierender": "rentierend",
    "rentierendere": "rentierend",
    "rentierenderem": "rentierend",
    "rentierenderen": "rentierend",
    "rentierenderer": "rentierend",
    "rentierenderes": "rentierend",
    "rentierendes": "rentierend",
    "rentierendste": "rentierend",
    "rentierendstem": "rentierend",
    "rentierendsten": "rentierend",
    "rentierendster": "rentierend",
    "rentierendstes": "rentierend",
    "rentierest": "rentieren",
    "rentieret": "rentieren",
    "rentierst": "rentieren",
    "rentiert": "rentieren",
    "rentierte": "rentieren",
    "rentiertem": "rentiert",
    "rentierten": "rentieren",
    "rentierter": "rentiert",
    "rentiertes": "rentiert",
    "rentiertest": "rentieren",
    "rentiertet": "rentieren",
    "renumeriere": "renumerieren",
    "renumerierend": "renumerieren",
    "renumerierende": "renumerierend",
    "renumerierendem": "renumerierend",
    "renumerierenden": "renumerierend",
    "renumerierender": "renumerierend",
    "renumerierendes": "renumerierend",
    "renumerierest": "renumerieren",
    "renumerieret": "renumerieren",
    "renumerierst": "renumerieren",
    "renumeriert": "renumerieren",
    "renumerierte": "renumerieren",
    "renumeriertem": "renumeriert",
    "renumerierten": "renumerieren",
    "renumerierter": "renumeriert",
    "renumeriertes": "renumeriert",
    "renumeriertest": "renumerieren",
    "renumeriertet": "renumerieren",
    "reorganisiere": "reorganisieren",
    "reorganisierend": "reorganisieren",
    "reorganisierende": "reorganisierend",
    "reorganisierendem": "reorganisierend",
    "reorganisierenden": "reorganisierend",
    "reorganisierender": "reorganisierend",
    "reorganisierendere": "reorganisierend",
    "reorganisierenderem": "reorganisierend",
    "reorganisierenderen": "reorganisierend",
    "reorganisierenderer": "reorganisierend",
    "reorganisierenderes": "reorganisierend",
    "reorganisierendes": "reorganisierend",
    "reorganisierendste": "reorganisierend",
    "reorganisierendstem": "reorganisierend",
    "reorganisierendsten": "reorganisierend",
    "reorganisierendster": "reorganisierend",
    "reorganisierendstes": "reorganisierend",
    "reorganisierest": "reorganisieren",
    "reorganisieret": "reorganisieren",
    "reorganisierst": "reorganisieren",
    "reorganisiert": "reorganisieren",
    "reorganisierte": "reorganisieren",
    "reorganisiertem": "reorganisiert",
    "reorganisierten": "reorganisieren",
    "reorganisierter": "reorganisiert",
    "reorganisiertere": "reorganisiert",
    "reorganisierterem": "reorganisiert",
    "reorganisierteren": "reorganisiert",
    "reorganisierterer": "reorganisiert",
    "reorganisierteres": "reorganisiert",
    "reorganisiertes": "reorganisiert",
    "reorganisiertest": "reorganisieren",
    "reorganisiertestem": "reorganisiert",
    "reorganisiertesten": "reorganisiert",
    "reorganisiertester": "reorganisiert",
    "reorganisiertestes": "reorganisiert",
    "reorganisiertet": "reorganisieren",
    "reparable": "reparabel",
    "reparablem": "reparabel",
    "reparablen": "reparabel",
    "reparabler": "reparabel",
    "reparables": "reparabel",
    "repariere": "reparieren",
    "reparierend": "reparieren",
    "reparierende": "reparierend",
    "reparierendem": "reparierend",
    "reparierenden": "reparierend",
    "reparierender": "reparierend",
    "reparierendes": "reparierend",
    "reparierest": "reparieren",
    "reparieret": "reparieren",
    "reparierst": "reparieren",
    "repariert": "reparieren",
    "reparierte": "reparieren",
    "repariertem": "repariert",
    "reparierten": "reparieren",
    "reparierter": "repariert",
    "repariertes": "repariert",
    "repariertest": "reparieren",
    "repariertet": "reparieren",
    "repetitivem": "repetitiv",
    "repetitiven": "repetitiv",
    "repetitiver": "repetitiv",
    "repetitives": "repetitiv",
    "repressivem": "repressiv",
    "repressiven": "repressiv",
    "repressiver": "repressiv",
    "repressives": "repressiv",
    "reproduktivem": "reproduktiv",
    "reproduktiven": "reproduktiv",
    "reproduktiver": "reproduktiv",
    "reproduktives": "reproduktiv",
    "reproduziere": "reproduzieren",
    "reproduzierend": "reproduzieren",
    "reproduzierende": "reproduzierend",
    "reproduzierendem": "reproduzierend",
    "reproduzierenden": "reproduzierend",
    "reproduzierender": "reproduzierend",
    "reproduzierendes": "reproduzierend",
    "reproduzierest": "reproduzieren",
    "reproduzieret": "reproduzieren",
    "reproduzierst": "reproduzieren",
    "reproduziert": "reproduzieren",
    "reproduzierte": "reproduzieren",
    "reproduziertem": "reproduziert",
    "reproduzierten": "reproduzieren",
    "reproduzierter": "reproduziert",
    "reproduziertes": "reproduziert",
    "reproduziertest": "reproduzieren",
    "reproduziertet": "reproduzieren",
    "repräsentativem": "repräsentativ",
    "repräsentativen": "repräsentativ",
    "repräsentativer": "repräsentativ",
    "repräsentativere": "repräsentativ",
    "repräsentativerem": "repräsentativ",
    "repräsentativeren": "repräsentativ",
    "repräsentativerer": "repräsentativ",
    "repräsentativeres": "repräsentativ",
    "repräsentatives": "repräsentativ",
    "repräsentativste": "repräsentativ",
    "repräsentativstem": "repräsentativ",
    "repräsentativsten": "repräsentativ",
    "repräsentativster": "repräsentativ",
    "repräsentativstes": "repräsentativ",
    "repräsentiere": "repräsentieren",
    "repräsentierend": "repräsentieren",
    "repräsentierende": "repräsentierend",
    "repräsentierendem": "repräsentierend",
    "repräsentierenden": "repräsentierend",
    "repräsentierender": "repräsentierend",
    "repräsentierendere": "repräsentierend",
    "repräsentierenderem": "repräsentierend",
    "repräsentierenderen": "repräsentierend",
    "repräsentierenderer": "repräsentierend",
    "repräsentierenderes": "repräsentierend",
    "repräsentierendes": "repräsentierend",
    "repräsentierendste": "repräsentierend",
    "repräsentierendstem": "repräsentierend",
    "repräsentierendsten": "repräsentierend",
    "repräsentierendster": "repräsentierend",
    "repräsentierendstes": "repräsentierend",
    "repräsentierest": "repräsentieren",
    "repräsentieret": "repräsentieren",
    "repräsentierst": "repräsentieren",
    "repräsentiert": "repräsentieren",
    "repräsentierte": "repräsentieren",
    "repräsentiertem": "repräsentiert",
    "repräsentierten": "repräsentieren",
    "repräsentierter": "repräsentiert",
    "repräsentiertere": "repräsentiert",
    "repräsentierterem": "repräsentiert",
    "repräsentierteren": "repräsentiert",
    "repräsentierterer": "repräsentiert",
    "repräsentierteres": "repräsentiert",
    "repräsentiertes": "repräsentiert",
    "repräsentiertest": "repräsentieren",
    "repräsentiertestem": "repräsentiert",
    "repräsentiertesten": "repräsentiert",
    "repräsentiertester": "repräsentiert",
    "repräsentiertestes": "repräsentiert",
    "repräsentiertet": "repräsentieren",
    "repulsivem": "repulsiv",
    "repulsiven": "repulsiv",
    "repulsiver": "repulsiv",
    "repulsives": "repulsiv",
    "requiriere": "requirieren",
    "requirierend": "requirieren",
    "requirierende": "requirierend",
    "requirierendem": "requirierend",
    "requirierenden": "requirierend",
    "requirierender": "requirierend",
    "requirierendes": "requirierend",
    "requirierest": "requirieren",
    "requirieret": "requirieren",
    "requirierst": "requirieren",
    "requiriert": "requirieren",
    "requirierte": "requirieren",
    "requiriertem": "requiriert",
    "requirierten": "requirieren",
    "requirierter": "requiriert",
    "requiriertes": "requiriert",
    "requiriertest": "requirieren",
    "requiriertet": "requirieren",
    "reserviere": "reservieren",
    "reservierend": "reservieren",
    "reservierende": "reservierend",
    "reservierendem": "reservierend",
    "reservierenden": "reservierend",
    "reservierender": "reservierend",
    "reservierendes": "reservierend",
    "reservierest": "reservieren",
    "reservieret": "reservieren",
    "reservierst": "reservieren",
    "reserviert": "reservieren",
    "reservierte": "reservieren",
    "reserviertem": "reserviert",
    "reservierten": "reservieren",
    "reservierter": "reserviert",
    "reserviertes": "reserviert",
    "reserviertest": "reservieren",
    "reserviertet": "reservieren",
    "residentem": "resident",
    "residenten": "resident",
    "residenter": "resident",
    "residentere": "resident",
    "residenterem": "resident",
    "residenteren": "resident",
    "residenterer": "resident",
    "residenteres": "resident",
    "residentes": "resident",
    "residenteste": "resident",
    "residentestem": "resident",
    "residentesten": "resident",
    "residentester": "resident",
    "residentestes": "resident",
    "residiere": "residieren",
    "residierend": "residieren",
    "residierende": "residierend",
    "residierendem": "residierend",
    "residierenden": "residierend",
    "residierender": "residierend",
    "residierendes": "residierend",
    "residierest": "residieren",
    "residieret": "residieren",
    "residierst": "residieren",
    "residiert": "residieren",
    "residierte": "residieren",
    "residiertem": "residiert",
    "residierten": "residieren",
    "residierter": "residiert",
    "residiertes": "residiert",
    "residiertest": "residieren",
    "residiertet": "residieren",
    "residuale": "residual",
    "residualem": "residual",
    "residualen": "residual",
    "residualer": "residual",
    "residualere": "residual",
    "residualerem": "residual",
    "residualeren": "residual",
    "residualerer": "residual",
    "residualeres": "residual",
    "residuales": "residual",
    "residualste": "residual",
    "residualstem": "residual",
    "residualsten": "residual",
    "residualster": "residual",
    "residualstes": "residual",
    "resigniere": "resignieren",
    "resignierend": "resignieren",
    "resignierende": "resignierend",
    "resignierendem": "resignierend",
    "resignierenden": "resignierend",
    "resignierender": "resignierend",
    "resignierendes": "resignierend",
    "resignierest": "resignieren",
    "resignieret": "resignieren",
    "resignierst": "resignieren",
    "resigniert": "resignieren",
    "resignierte": "resignieren",
    "resigniertem": "resigniert",
    "resignierten": "resignieren",
    "resignierter": "resigniert",
    "resigniertere": "resigniert",
    "resignierterem": "resigniert",
    "resignierteren": "resigniert",
    "resignierterer": "resigniert",
    "resignierteres": "resigniert",
    "resigniertes": "resigniert",
    "resigniertest": "resignieren",
    "resignierteste": "resigniert",
    "resigniertestem": "resigniert",
    "resigniertesten": "resigniert",
    "resigniertester": "resigniert",
    "resigniertestes": "resigniert",
    "resigniertet": "resignieren",
    "resistente": "resistent",
    "resistentem": "resistent",
    "resistenten": "resistent",
    "resistenter": "resistent",
    "resistentere": "resistent",
    "resistenterem": "resistent",
    "resistenteren": "resistent",
    "resistenterer": "resistent",
    "resistenteres": "resistent",
    "resistentes": "resistent",
    "resistenteste": "resistent",
    "resistentestem": "resistent",
    "resistentesten": "resistent",
    "resistentester": "resistent",
    "resistentestes": "resistent",
    "resistiere": "resistieren",
    "resistierend": "resistieren",
    "resistierende": "resistierend",
    "resistierendem": "resistierend",
    "resistierenden": "resistierend",
    "resistierender": "resistierend",
    "resistierendere": "resistierend",
    "resistierenderem": "resistierend",
    "resistierenderen": "resistierend",
    "resistierenderer": "resistierend",
    "resistierenderes": "resistierend",
    "resistierendes": "resistierend",
    "resistierendste": "resistierend",
    "resistierendstem": "resistierend",
    "resistierendsten": "resistierend",
    "resistierendster": "resistierend",
    "resistierendstes": "resistierend",
    "resistierest": "resistieren",
    "resistieret": "resistieren",
    "resistierst": "resistieren",
    "resistiert": "resistieren",
    "resistierte": "resistieren",
    "resistiertem": "resistiert",
    "resistierten": "resistieren",
    "resistierter": "resistiert",
    "resistiertere": "resistiert",
    "resistierterem": "resistiert",
    "resistierteren": "resistiert",
    "resistierterer": "resistiert",
    "resistierteres": "resistiert",
    "resistiertes": "resistiert",
    "resistiertest": "resistieren",
    "resistierteste": "resistiert",
    "resistiertestem": "resistiert",
    "resistiertesten": "resistiert",
    "resistiertester": "resistiert",
    "resistiertestes": "resistiert",
    "resistiertet": "resistieren",
    "resolute": "resolut",
    "resolutem": "resolut",
    "resoluten": "resolut",
    "resoluter": "resolut",
    "resolutes": "resolut",
    "resorbiere": "resorbieren",
    "resorbierend": "resorbieren",
    "resorbierende": "resorbierend",
    "resorbierendem": "resorbierend",
    "resorbierenden": "resorbierend",
    "resorbierender": "resorbierend",
    "resorbierendere": "resorbierend",
    "resorbierenderem": "resorbierend",
    "resorbierenderen": "resorbierend",
    "resorbierenderer": "resorbierend",
    "resorbierenderes": "resorbierend",
    "resorbierendes": "resorbierend",
    "resorbierendste": "resorbierend",
    "resorbierendstem": "resorbierend",
    "resorbierendsten": "resorbierend",
    "resorbierendster": "resorbierend",
    "resorbierendstes": "resorbierend",
    "resorbierest": "resorbieren",
    "resorbieret": "resorbieren",
    "resorbierst": "resorbieren",
    "resorbiert": "resorbieren",
    "resorbierte": "resorbieren",
    "resorbiertem": "resorbiert",
    "resorbierten": "resorbieren",
    "resorbierter": "resorbiert",
    "resorbiertere": "resorbiert",
    "resorbierterem": "resorbiert",
    "resorbierteren": "resorbiert",
    "resorbierterer": "resorbiert",
    "resorbierteres": "resorbiert",
    "resorbiertes": "resorbiert",
    "resorbiertest": "resorbieren",
    "resorbierteste": "resorbiert",
    "resorbiertestem": "resorbiert",
    "resorbiertesten": "resorbiert",
    "resorbiertester": "resorbiert",
    "resorbiertestes": "resorbiert",
    "resorbiertet": "resorbieren",
    "resozialisiere": "resozialisieren",
    "resozialisierend": "resozialisieren",
    "resozialisierende": "resozialisierend",
    "resozialisierendem": "resozialisierend",
    "resozialisierenden": "resozialisierend",
    "resozialisierender": "resozialisierend",
    "resozialisierendere": "resozialisierend",
    "resozialisierenderem": "resozialisierend",
    "resozialisierenderen": "resozialisierend",
    "resozialisierenderer": "resozialisierend",
    "resozialisierenderes": "resozialisierend",
    "resozialisierendes": "resozialisierend",
    "resozialisierendste": "resozialisierend",
    "resozialisierendstem": "resozialisierend",
    "resozialisierendsten": "resozialisierend",
    "resozialisierendster": "resozialisierend",
    "resozialisierendstes": "resozialisierend",
    "resozialisierest": "resozialisieren",
    "resozialisieret": "resozialisieren",
    "resozialisierst": "resozialisieren",
    "resozialisiert": "resozialisieren",
    "resozialisierte": "resozialisieren",
    "resozialisiertem": "resozialisiert",
    "resozialisierten": "resozialisieren",
    "resozialisierter": "resozialisiert",
    "resozialisiertere": "resozialisiert",
    "resozialisierterem": "resozialisiert",
    "resozialisierteren": "resozialisiert",
    "resozialisierterer": "resozialisiert",
    "resozialisierteres": "resozialisiert",
    "resozialisiertes": "resozialisiert",
    "resozialisiertest": "resozialisieren",
    "resozialisierteste": "resozialisiert",
    "resozialisiertestem": "resozialisiert",
    "resozialisiertesten": "resozialisiert",
    "resozialisiertester": "resozialisiert",
    "resozialisiertestes": "resozialisiert",
    "resozialisiertet": "resozialisieren",
    "respektabelstem": "respektabel",
    "respektabelsten": "respektabel",
    "respektabelster": "respektabel",
    "respektabelstes": "respektabel",
    "respektable": "respektabel",
    "respektablem": "respektabel",
    "respektablen": "respektabel",
    "respektabler": "respektabel",
    "respektablere": "respektabel",
    "respektablerem": "respektabel",
    "respektableren": "respektabel",
    "respektablerer": "respektabel",
    "respektableres": "respektabel",
    "respektables": "respektabel",
    "respektiere": "respektieren",
    "respektierend": "respektieren",
    "respektierende": "respektierend",
    "respektierendem": "respektierend",
    "respektierenden": "respektierend",
    "respektierender": "respektierend",
    "respektierendes": "respektierend",
    "respektierest": "respektieren",
    "respektieret": "respektieren",
    "respektierst": "respektieren",
    "respektiert": "respektieren",
    "respektierte": "respektieren",
    "respektiertem": "respektiert",
    "respektierten": "respektieren",
    "respektierter": "respektiert",
    "respektiertere": "respektiert",
    "respektierterem": "respektiert",
    "respektierteren": "respektiert",
    "respektierterer": "respektiert",
    "respektierteres": "respektiert",
    "respektiertes": "respektiert",
    "respektiertest": "respektieren",
    "respektierteste": "respektiert",
    "respektiertestem": "respektiert",
    "respektiertesten": "respektiert",
    "respektiertester": "respektiert",
    "respektiertestes": "respektiert",
    "respektiertet": "respektieren",
    "respektlose": "respektlos",
    "respektlosem": "respektlos",
    "respektlosen": "respektlos",
    "respektloser": "respektlos",
    "respektlosere": "respektlos",
    "respektloserem": "respektlos",
    "respektloseren": "respektlos",
    "respektloserer": "respektlos",
    "respektloseres": "respektlos",
    "respektloses": "respektlos",
    "respektloseste": "respektlos",
    "respektlosestem": "respektlos",
    "respektlosesten": "respektlos",
    "respektlosester": "respektlos",
    "respektlosestes": "respektlos",
    "respektvollem": "respektvoll",
    "respektvollen": "respektvoll",
    "respektvoller": "respektvoll",
    "respektvollere": "respektvoll",
    "respektvollerem": "respektvoll",
    "respektvolleren": "respektvoll",
    "respektvollerer": "respektvoll",
    "respektvolleres": "respektvoll",
    "respektvolles": "respektvoll",
    "respektvollste": "respektvoll",
    "respektvollstem": "respektvoll",
    "respektvollsten": "respektvoll",
    "respektvollster": "respektvoll",
    "respektvollstes": "respektvoll",
    "restlichem": "restlich",
    "restlichen": "restlich",
    "restlicher": "restlich",
    "restliches": "restlich",
    "restlose": "restlos",
    "restlosem": "restlos",
    "restlosen": "restlos",
    "restloser": "restlos",
    "restlosere": "restlos",
    "restloserem": "restlos",
    "restloseren": "restlos",
    "restloserer": "restlos",
    "restloseres": "restlos",
    "restloses": "restlos",
    "restloseste": "restlos",
    "restlosestem": "restlos",
    "restlosesten": "restlos",
    "restlosester": "restlos",
    "restlosestes": "restlos",
    "restrukturiere": "restrukturieren",
    "restrukturierend": "restrukturieren",
    "restrukturierende": "restrukturierend",
    "restrukturierendem": "restrukturierend",
    "restrukturierenden": "restrukturierend",
    "restrukturierender": "restrukturierend",
    "restrukturierendere": "restrukturierend",
    "restrukturierenderem": "restrukturierend",
    "restrukturierenderen": "restrukturierend",
    "restrukturierenderer": "restrukturierend",
    "restrukturierenderes": "restrukturierend",
    "restrukturierendes": "restrukturierend",
    "restrukturierendste": "restrukturierend",
    "restrukturierendstem": "restrukturierend",
    "restrukturierendsten": "restrukturierend",
    "restrukturierendster": "restrukturierend",
    "restrukturierendstes": "restrukturierend",
    "restrukturierest": "restrukturieren",
    "restrukturieret": "restrukturieren",
    "restrukturierst": "restrukturieren",
    "restrukturiert": "restrukturieren",
    "restrukturierte": "restrukturieren",
    "restrukturiertem": "restrukturiert",
    "restrukturierten": "restrukturieren",
    "restrukturierter": "restrukturiert",
    "restrukturiertere": "restrukturiert",
    "restrukturierterem": "restrukturiert",
    "restrukturierteren": "restrukturiert",
    "restrukturierterer": "restrukturiert",
    "restrukturierteres": "restrukturiert",
    "restrukturiertes": "restrukturiert",
    "restrukturiertest": "restrukturieren",
    "restrukturierteste": "restrukturiert",
    "restrukturiertestem": "restrukturiert",
    "restrukturiertesten": "restrukturiert",
    "restrukturiertester": "restrukturiert",
    "restrukturiertestes": "restrukturiert",
    "restrukturiertet": "restrukturieren",
    "resultiere": "resultieren",
    "resultierend": "resultieren",
    "resultierende": "resultierend",
    "resultierendem": "resultierend",
    "resultierenden": "resultierend",
    "resultierender": "resultierend",
    "resultierendes": "resultierend",
    "resultierest": "resultieren",
    "resultieret": "resultieren",
    "resultierst": "resultieren",
    "resultiert": "resultieren",
    "resultierte": "resultieren",
    "resultiertem": "resultiert",
    "resultierten": "resultieren",
    "resultierter": "resultiert",
    "resultiertes": "resultiert",
    "resultiertest": "resultieren",
    "resultiertet": "resultieren",
    "resümiere": "resümieren",
    "resümierend": "resümieren",
    "resümierende": "resümierend",
    "resümierendem": "resümierend",
    "resümierenden": "resümierend",
    "resümierender": "resümierend",
    "resümierendes": "resümierend",
    "resümierest": "resümieren",
    "resümieret": "resümieren",
    "resümierst": "resümieren",
    "resümiert": "resümieren",
    "resümierte": "resümieren",
    "resümiertem": "resümiert",
    "resümierten": "resümieren",
    "resümierter": "resümiert",
    "resümiertes": "resümiert",
    "resümiertest": "resümieren",
    "resümiertet": "resümieren",
    "retardiere": "retardieren",
    "retardierend": "retardieren",
    "retardierende": "retardierend",
    "retardierendem": "retardierend",
    "retardierenden": "retardierend",
    "retardierender": "retardierend",
    "retardierendes": "retardierend",
    "retardierest": "retardieren",
    "retardieret": "retardieren",
    "retardierst": "retardieren",
    "retardiert": "retardieren",
    "retardierte": "retardieren",
    "retardiertem": "retardiert",
    "retardierten": "retardieren",
    "retardierter": "retardiert",
    "retardiertes": "retardiert",
    "retardiertest": "retardieren",
    "retardiertet": "retardieren",
    "rette": "retten",
    "rettend": "retten",
    "rettende": "rettend",
    "rettendem": "rettend",
    "rettenden": "rettend",
    "rettender": "rettend",
    "rettendes": "rettend",
    "rettest": "retten",
    "rettet": "retten",
    "rettete": "retten",
    "retteten": "retten",
    "rettetest": "retten",
    "rettetet": "retten",
    "retuschiere": "retuschieren",
    "retuschierend": "retuschieren",
    "retuschierende": "retuschierend",
    "retuschierendem": "retuschierend",
    "retuschierenden": "retuschierend",
    "retuschierender": "retuschierend",
    "retuschierendes": "retuschierend",
    "retuschierest": "retuschieren",
    "retuschieret": "retuschieren",
    "retuschierst": "retuschieren",
    "retuschiert": "retuschieren",
    "retuschierte": "retuschieren",
    "retuschiertem": "retuschiert",
    "retuschierten": "retuschieren",
    "retuschierter": "retuschiert",
    "retuschiertes": "retuschiert",
    "retuschiertest": "retuschieren",
    "retuschiertet": "retuschieren",
    "reuevolle": "reuevoll",
    "reuevollem": "reuevoll",
    "reuevollen": "reuevoll",
    "reuevoller": "reuevoll",
    "reuevollere": "reuevoll",
    "reuevollerem": "reuevoll",
    "reuevolleren": "reuevoll",
    "reuevollerer": "reuevoll",
    "reuevolleres": "reuevoll",
    "reuevolles": "reuevoll",
    "reuevollste": "reuevoll",
    "reuevollstem": "reuevoll",
    "reuevollsten": "reuevoll",
    "reuevollster": "reuevoll",
    "reuevollstes": "reuevoll",
    "reuige": "reuig",
    "reuigem": "reuig",
    "reuigen": "reuig",
    "reuiger": "reuig",
    "reuigere": "reuig",
    "reuigerem": "reuig",
    "reuigeren": "reuig",
    "reuigerer": "reuig",
    "reuigeres": "reuig",
    "reuiges": "reuig",
    "reuigste": "reuig",
    "reuigstem": "reuig",
    "reuigsten": "reuig",
    "reuigster": "reuig",
    "reuigstes": "reuig",
    "reumütige": "reumütig",
    "reumütigem": "reumütig",
    "reumütigen": "reumütig",
    "reumütiger": "reumütig",
    "reumütigere": "reumütig",
    "reumütigerem": "reumütig",
    "reumütigeren": "reumütig",
    "reumütigerer": "reumütig",
    "reumütigeres": "reumütig",
    "reumütiges": "reumütig",
    "reumütigste": "reumütig",
    "reumütigstem": "reumütig",
    "reumütigsten": "reumütig",
    "reumütigster": "reumütig",
    "reumütigstes": "reumütig",
    "revolutioniere": "revolutionieren",
    "revolutionierend": "revolutionieren",
    "revolutionierende": "revolutionierend",
    "revolutionierendem": "revolutionierend",
    "revolutionierenden": "revolutionierend",
    "revolutionierender": "revolutionierend",
    "revolutionierendere": "revolutionierend",
    "revolutionierenderem": "revolutionierend",
    "revolutionierenderen": "revolutionierend",
    "revolutionierenderer": "revolutionierend",
    "revolutionierenderes": "revolutionierend",
    "revolutionierendes": "revolutionierend",
    "revolutionierendste": "revolutionierend",
    "revolutionierendstem": "revolutionierend",
    "revolutionierendsten": "revolutionierend",
    "revolutionierendster": "revolutionierend",
    "revolutionierendstes": "revolutionierend",
    "revolutionierest": "revolutionieren",
    "revolutionieret": "revolutionieren",
    "revolutionierst": "revolutionieren",
    "revolutioniert": "revolutionieren",
    "revolutionierte": "revolutionieren",
    "revolutioniertem": "revolutioniert",
    "revolutionierten": "revolutionieren",
    "revolutionierter": "revolutioniert",
    "revolutioniertes": "revolutioniert",
    "revolutioniertest": "revolutionieren",
    "revolutioniertet": "revolutionieren",
    "revolutionärem": "revolutionär",
    "revolutionären": "revolutionär",
    "revolutionärer": "revolutionär",
    "revolutionärere": "revolutionär",
    "revolutionärerem": "revolutionär",
    "revolutionäreren": "revolutionär",
    "revolutionärerer": "revolutionär",
    "revolutionäreres": "revolutionär",
    "revolutionäres": "revolutionär",
    "revolutionärste": "revolutionär",
    "revolutionärstem": "revolutionär",
    "revolutionärsten": "revolutionär",
    "revolutionärster": "revolutionär",
    "revolutionärstes": "revolutionär",
    "rezensiere": "rezensieren",
    "rezensierend": "rezensieren",
    "rezensierende": "rezensierend",
    "rezensierendem": "rezensierend",
    "rezensierenden": "rezensierend",
    "rezensierender": "rezensierend",
    "rezensierendes": "rezensierend",
    "rezensierest": "rezensieren",
    "rezensieret": "rezensieren",
    "rezensierst": "rezensieren",
    "rezensiert": "rezensieren",
    "rezensierte": "rezensieren",
    "rezensiertem": "rezensiert",
    "rezensierten": "rezensieren",
    "rezensierter": "rezensiert",
    "rezensiertes": "rezensiert",
    "rezensiertest": "rezensieren",
    "rezensiertet": "rezensieren",
    "rezeptfreiem": "rezeptfrei",
    "rezeptfreien": "rezeptfrei",
    "rezeptfreier": "rezeptfrei",
    "rezeptfreies": "rezeptfrei",
    "rezeptivem": "rezeptiv",
    "rezeptiven": "rezeptiv",
    "rezeptiver": "rezeptiv",
    "rezeptives": "rezeptiv",
    "rezeptpflichtigem": "rezeptpflichtig",
    "rezeptpflichtigen": "rezeptpflichtig",
    "rezeptpflichtiger": "rezeptpflichtig",
    "rezeptpflichtiges": "rezeptpflichtig",
    "rezipiere": "rezipieren",
    "rezipierend": "rezipieren",
    "rezipierende": "rezipierend",
    "rezipierendem": "rezipierend",
    "rezipierenden": "rezipierend",
    "rezipierender": "rezipierend",
    "rezipierendes": "rezipierend",
    "rezipierest": "rezipieren",
    "rezipieret": "rezipieren",
    "rezipierst": "rezipieren",
    "rezipiert": "rezipieren",
    "rezipierte": "rezipieren",
    "rezipiertem": "rezipiert",
    "rezipierten": "rezipieren",
    "rezipierter": "rezipiert",
    "rezipiertes": "rezipiert",
    "rezipiertest": "rezipieren",
    "rezipiertet": "rezipieren",
    "rezitiere": "rezitieren",
    "rezitierend": "rezitieren",
    "rezitierende": "rezitierend",
    "rezitierendem": "rezitierend",
    "rezitierenden": "rezitierend",
    "rezitierender": "rezitierend",
    "rezitierendes": "rezitierend",
    "rezitierest": "rezitieren",
    "rezitieret": "rezitieren",
    "rezitierst": "rezitieren",
    "rezitiert": "rezitieren",
    "rezitierte": "rezitieren",
    "rezitiertem": "rezitiert",
    "rezitierten": "rezitieren",
    "rezitierter": "rezitiert",
    "rezitiertes": "rezitiert",
    "rezitiertest": "rezitieren",
    "rezitiertet": "rezitieren",
    "rheinischem": "rheinisch",
    "rheinischen": "rheinisch",
    "rheinischer": "rheinisch",
    "rheinisches": "rheinisch",
    "rheinländischem": "rheinländisch",
    "rheinländischen": "rheinländisch",
    "rheinländischer": "rheinländisch",
    "rheinländisches": "rheinländisch",
    "rhetorischem": "rhetorisch",
    "rhetorischen": "rhetorisch",
    "rhetorischer": "rhetorisch",
    "rhetorisches": "rhetorisch",
    "rheumatische": "rheumatisch",
    "rheumatischem": "rheumatisch",
    "rheumatischen": "rheumatisch",
    "rheumatischer": "rheumatisch",
    "rheumatisches": "rheumatisch",
    "rhythmischem": "rhythmisch",
    "rhythmischen": "rhythmisch",
    "rhythmischer": "rhythmisch",
    "rhythmischere": "rhythmisch",
    "rhythmischerem": "rhythmisch",
    "rhythmischeren": "rhythmisch",
    "rhythmischerer": "rhythmisch",
    "rhythmischeres": "rhythmisch",
    "rhythmisches": "rhythmisch",
    "rhythmischste": "rhythmisch",
    "rhythmischstem": "rhythmisch",
    "rhythmischsten": "rhythmisch",
    "rhythmischster": "rhythmisch",
    "rhythmischstes": "rhythmisch",
    "ribbele": "ribbeln",
    "ribbelnd": "ribbeln",
    "ribbelnde": "ribbelnd",
    "ribbelndem": "ribbelnd",
    "ribbelnden": "ribbelnd",
    "ribbelnder": "ribbelnd",
    "ribbelndes": "ribbelnd",
    "ribbelst": "ribbeln",
    "ribbelt": "ribbeln",
    "ribbelte": "ribbeln",
    "ribbelten": "ribbeln",
    "ribbeltest": "ribbeln",
    "ribbeltet": "ribbeln",
    "ribble": "ribbeln",
    "richte": "richten",
    "richtend": "richten",
    "richtende": "richtend",
    "richtendem": "richtend",
    "richtenden": "richtend",
    "richtender": "richtend",
    "richtendes": "richtend",
    "richterlichem": "richterlich",
    "richterlichen": "richterlich",
    "richterlicher": "richterlich",
    "richterliches": "richterlich",
    "richtest": "richten",
    "richtet": "richten",
    "richtete": "richten",
    "richteten": "richten",
    "richtetest": "richten",
    "richtetet": "richten",
    "richtigem": "richtig",
    "richtigen": "richtig",
    "richtiger": "richtig",
    "richtigere": "richtig",
    "richtigerem": "richtig",
    "richtigeren": "richtig",
    "richtigerer": "richtig",
    "richtigeres": "richtig",
    "richtiges": "richtig",
    "richtiggehende": "richtiggehend",
    "richtiggehendem": "richtiggehend",
    "richtiggehenden": "richtiggehend",
    "richtiggehender": "richtiggehend",
    "richtiggehendes": "richtiggehend",
    "richtiggelegen": "richtigliegen",
    "richtiggelegene": "richtiggelegen",
    "richtiggelegenem": "richtiggelegen",
    "richtiggelegenen": "richtiggelegen",
    "richtiggelegener": "richtiggelegen",
    "richtiggelegenes": "richtiggelegen",
    "richtiggestellt": "richtigstellen",
    "richtiggestellte": "richtiggestellt",
    "richtiggestelltem": "richtiggestellt",
    "richtiggestellten": "richtiggestellt",
    "richtiggestellter": "richtiggestellt",
    "richtiggestelltes": "richtiggestellt",
    "richtiglag": "richtigliegen",
    "richtiglagen": "richtigliegen",
    "richtiglagst": "richtigliegen",
    "richtiglagt": "richtigliegen",
    "richtigliege": "richtigliegen",
    "richtigliegend": "richtigliegen",
    "richtigliegende": "richtigliegend",
    "richtigliegendem": "richtigliegend",
    "richtigliegenden": "richtigliegend",
    "richtigliegender": "richtigliegend",
    "richtigliegendes": "richtigliegend",
    "richtigliegest": "richtigliegen",
    "richtiglieget": "richtigliegen",
    "richtigliegst": "richtigliegen",
    "richtigliegt": "richtigliegen",
    "richtigläge": "richtigliegen",
    "richtiglägen": "richtigliegen",
    "richtiglägest": "richtigliegen",
    "richtigläget": "richtigliegen",
    "richtigste": "richtig",
    "richtigstelle": "richtigstellen",
    "richtigstellend": "richtigstellen",
    "richtigstellende": "richtigstellend",
    "richtigstellendem": "richtigstellend",
    "richtigstellenden": "richtigstellend",
    "richtigstellender": "richtigstellend",
    "richtigstellendes": "richtigstellend",
    "richtigstellest": "richtigstellen",
    "richtigstellet": "richtigstellen",
    "richtigstellst": "richtigstellen",
    "richtigstellt": "richtigstellen",
    "richtigstellte": "richtigstellen",
    "richtigstellten": "richtigstellen",
    "richtigstelltest": "richtigstellen",
    "richtigstelltet": "richtigstellen",
    "richtigstem": "richtig",
    "richtigsten": "richtig",
    "richtigster": "richtig",
    "richtigstes": "richtig",
    "richtigzuliegen": "richtigliegen",
    "richtigzustellen": "richtigstellen",
    "richtungslosem": "richtungslos",
    "richtungslosen": "richtungslos",
    "richtungsloser": "richtungslos",
    "richtungslosere": "richtungslos",
    "richtungsloserem": "richtungslos",
    "richtungsloseren": "richtungslos",
    "richtungsloserer": "richtungslos",
    "richtungsloseres": "richtungslos",
    "richtungsloses": "richtungslos",
    "richtungsloseste": "richtungslos",
    "richtungslosestem": "richtungslos",
    "richtungslosesten": "richtungslos",
    "richtungslosester": "richtungslos",
    "richtungslosestes": "richtungslos",
    "rieb": "reiben",
    "riebe": "reiben",
    "rieben": "reiben",
    "riebest": "reiben",
    "riebet": "reiben",
    "riebst": "reiben",
    "riebt": "reiben",
    "rieche": "riechen",
    "riechend": "riechen",
    "riechende": "riechend",
    "riechendem": "riechend",
    "riechenden": "riechend",
    "riechender": "riechend",
    "riechendere": "riechend",
    "riechenderem": "riechend",
    "riechenderen": "riechend",
    "riechenderer": "riechend",
    "riechenderes": "riechend",
    "riechendes": "riechend",
    "riechendste": "riechend",
    "riechendstem": "riechend",
    "riechendsten": "riechend",
    "riechendster": "riechend",
    "riechendstes": "riechend",
    "riechest": "riechen",
    "riechet": "riechen",
    "riechst": "riechen",
    "riecht": "riechen",
    "rief": "rufen",
    "riefe": "rufen",
    "riefen": "rufen",
    "riefest": "rufen",
    "riefet": "rufen",
    "riefst": "rufen",
    "rieft": "rufen",
    "riegele": "riegeln",
    "riegelnd": "riegeln",
    "riegelnde": "riegelnd",
    "riegelndem": "riegelnd",
    "riegelnden": "riegelnd",
    "riegelnder": "riegelnd",
    "riegelndes": "riegelnd",
    "riegelst": "riegeln",
    "riegelt": "riegeln",
    "riegelte": "riegeln",
    "riegelten": "riegeln",
    "riegeltest": "riegeln",
    "riegeltet": "riegeln",
    "riegle": "riegeln",
    "riesele": "rieseln",
    "rieselnd": "rieseln",
    "rieselnde": "rieselnd",
    "rieselndem": "rieselnd",
    "rieselnden": "rieselnd",
    "rieselnder": "rieselnd",
    "rieselndere": "rieselnd",
    "rieselnderem": "rieselnd",
    "rieselnderen": "rieselnd",
    "rieselnderer": "rieselnd",
    "rieselnderes": "rieselnd",
    "rieselndes": "rieselnd",
    "rieselndste": "rieselnd",
    "rieselndstem": "rieselnd",
    "rieselndsten": "rieselnd",
    "rieselndster": "rieselnd",
    "rieselndstes": "rieselnd",
    "rieselst": "rieseln",
    "rieselt": "rieseln",
    "rieselte": "rieseln",
    "rieselten": "rieseln",
    "rieseltest": "rieseln",
    "rieseltet": "rieseln",
    "riesengroßem": "riesengroß",
    "riesengroßen": "riesengroß",
    "riesengroßer": "riesengroß",
    "riesengroßes": "riesengroß",
    "riesenhafte": "riesenhaft",
    "riesenhaftem": "riesenhaft",
    "riesenhaften": "riesenhaft",
    "riesenhafter": "riesenhaft",
    "riesenhaftere": "riesenhaft",
    "riesenhafterem": "riesenhaft",
    "riesenhafteren": "riesenhaft",
    "riesenhafterer": "riesenhaft",
    "riesenhafteres": "riesenhaft",
    "riesenhaftes": "riesenhaft",
    "riesenhafteste": "riesenhaft",
    "riesenhaftestem": "riesenhaft",
    "riesenhaftesten": "riesenhaft",
    "riesenhaftester": "riesenhaft",
    "riesenhaftestes": "riesenhaft",
    "riesigem": "riesig",
    "riesigen": "riesig",
    "riesiger": "riesig",
    "riesigere": "riesig",
    "riesigerem": "riesig",
    "riesigeren": "riesig",
    "riesigerer": "riesig",
    "riesigeres": "riesig",
    "riesiges": "riesig",
    "riesigste": "riesig",
    "riesigstem": "riesig",
    "riesigsten": "riesig",
    "riesigster": "riesig",
    "riesigstes": "riesig",
    "riesle": "rieseln",
    "riet": "raten",
    "riete": "raten",
    "rieten": "raten",
    "rietest": "raten",
    "rietet": "raten",
    "riffele": "riffeln",
    "riffelnd": "riffeln",
    "riffelnde": "riffelnd",
    "riffelndem": "riffelnd",
    "riffelnden": "riffelnd",
    "riffelnder": "riffelnd",
    "riffelndes": "riffelnd",
    "riffelst": "riffeln",
    "riffelt": "riffeln",
    "riffelte": "riffeln",
    "riffelten": "riffeln",
    "riffeltest": "riffeln",
    "riffeltet": "riffeln",
    "riffle": "riffeln",
    "rigide": "rigid",
    "rigidem": "rigid",
    "rigiden": "rigid",
    "rigider": "rigid",
    "rigides": "rigid",
    "rigorose": "rigoros",
    "rigorosem": "rigoros",
    "rigorosen": "rigoros",
    "rigoroser": "rigoros",
    "rigorosere": "rigoros",
    "rigoroserem": "rigoros",
    "rigoroseren": "rigoros",
    "rigoroserer": "rigoros",
    "rigoroseres": "rigoros",
    "rigoroses": "rigoros",
    "rigoroseste": "rigoros",
    "rigorosestem": "rigoros",
    "rigorosesten": "rigoros",
    "rigorosester": "rigoros",
    "rigorosestes": "rigoros",
    "rillend": "rillen",
    "rillende": "rillend",
    "rillendem": "rillend",
    "rillenden": "rillend",
    "rillender": "rillend",
    "rillendere": "rillend",
    "rillenderem": "rillend",
    "rillenderen": "rillend",
    "rillenderer": "rillend",
    "rillenderes": "rillend",
    "rillendes": "rillend",
    "rillendste": "rillend",
    "rillendstem": "rillend",
    "rillendsten": "rillend",
    "rillendster": "rillend",
    "rillendstes": "rillend",
    "rillest": "rillen",
    "rillet": "rillen",
    "rillst": "rillen",
    "rillt": "rillen",
    "rillte": "rillen",
    "rillten": "rillen",
    "rilltest": "rillen",
    "rilltet": "rillen",
    "rindend": "rinden",
    "rindende": "rindend",
    "rindendem": "rindend",
    "rindenden": "rindend",
    "rindender": "rindend",
    "rindendes": "rindend",
    "rindest": "rinden",
    "rindet": "rinden",
    "rindete": "rinden",
    "rindeten": "rinden",
    "rindetest": "rinden",
    "rindetet": "rinden",
    "ringele": "ringeln",
    "ringelige": "ringelig",
    "ringeligem": "ringelig",
    "ringeligen": "ringelig",
    "ringeliger": "ringelig",
    "ringeliges": "ringelig",
    "ringelnd": "ringeln",
    "ringelnde": "ringelnd",
    "ringelndem": "ringelnd",
    "ringelnden": "ringelnd",
    "ringelnder": "ringelnd",
    "ringelndere": "ringelnd",
    "ringelnderem": "ringelnd",
    "ringelnderen": "ringelnd",
    "ringelnderer": "ringelnd",
    "ringelnderes": "ringelnd",
    "ringelndes": "ringelnd",
    "ringelndste": "ringelnd",
    "ringelndstem": "ringelnd",
    "ringelndsten": "ringelnd",
    "ringelndster": "ringelnd",
    "ringelndstes": "ringelnd",
    "ringelst": "ringeln",
    "ringelt": "ringeln",
    "ringelte": "ringeln",
    "ringelten": "ringeln",
    "ringeltest": "ringeln",
    "ringeltet": "ringeln",
    "ringend": "ringen",
    "ringende": "ringend",
    "ringendem": "ringend",
    "ringenden": "ringend",
    "ringender": "ringend",
    "ringendere": "ringend",
    "ringenderem": "ringend",
    "ringenderen": "ringend",
    "ringenderer": "ringend",
    "ringenderes": "ringend",
    "ringendes": "ringend",
    "ringendste": "ringend",
    "ringendstem": "ringend",
    "ringendsten": "ringend",
    "ringendster": "ringend",
    "ringendstes": "ringend",
    "ringest": "ringen",
    "ringet": "ringen",
    "ringförmige": "ringförmig",
    "ringförmigem": "ringförmig",
    "ringförmigen": "ringförmig",
    "ringförmiger": "ringförmig",
    "ringförmiges": "ringförmig",
    "ringle": "ringeln",
    "ringst": "ringen",
    "ringt": "ringen",
    "rinne": "rinnen",
    "rinnend": "rinnen",
    "rinnende": "rinnend",
    "rinnendem": "rinnend",
    "rinnenden": "rinnend",
    "rinnender": "rinnend",
    "rinnendere": "rinnend",
    "rinnenderem": "rinnend",
    "rinnenderen": "rinnend",
    "rinnenderer": "rinnend",
    "rinnenderes": "rinnend",
    "rinnendes": "rinnend",
    "rinnendste": "rinnend",
    "rinnendstem": "rinnend",
    "rinnendsten": "rinnend",
    "rinnendster": "rinnend",
    "rinnendstes": "rinnend",
    "rinnest": "rinnen",
    "rinnet": "rinnen",
    "rinnst": "rinnen",
    "rinnt": "rinnen",
    "rippend": "rippen",
    "rippende": "rippend",
    "rippendem": "rippend",
    "rippenden": "rippend",
    "rippender": "rippend",
    "rippendere": "rippend",
    "rippenderem": "rippend",
    "rippenderen": "rippend",
    "rippenderer": "rippend",
    "rippenderes": "rippend",
    "rippendes": "rippend",
    "rippendste": "rippend",
    "rippendstem": "rippend",
    "rippendsten": "rippend",
    "rippendster": "rippend",
    "rippendstes": "rippend",
    "rippest": "rippen",
    "rippet": "rippen",
    "rippst": "rippen",
    "rippt": "rippen",
    "rippte": "rippen",
    "rippten": "rippen",
    "ripptest": "rippen",
    "ripptet": "rippen",
    "risikoreichem": "risikoreich",
    "risikoreichen": "risikoreich",
    "risikoreicher": "risikoreich",
    "risikoreichere": "risikoreich",
    "risikoreicherem": "risikoreich",
    "risikoreicheren": "risikoreich",
    "risikoreicherer": "risikoreich",
    "risikoreicheres": "risikoreich",
    "risikoreiches": "risikoreich",
    "risikoreichste": "risikoreich",
    "risikoreichstem": "risikoreich",
    "risikoreichsten": "risikoreich",
    "risikoreichster": "risikoreich",
    "risikoreichstes": "risikoreich",
    "riskantem": "riskant",
    "riskanten": "riskant",
    "riskanter": "riskant",
    "riskantere": "riskant",
    "riskanterem": "riskant",
    "riskanteren": "riskant",
    "riskanterer": "riskant",
    "riskanteres": "riskant",
    "riskantes": "riskant",
    "riskanteste": "riskant",
    "riskantestem": "riskant",
    "riskantesten": "riskant",
    "riskantester": "riskant",
    "riskantestes": "riskant",
    "riskiere": "riskieren",
    "riskierend": "riskieren",
    "riskierende": "riskierend",
    "riskierendem": "riskierend",
    "riskierenden": "riskierend",
    "riskierender": "riskierend",
    "riskierendes": "riskierend",
    "riskierest": "riskieren",
    "riskieret": "riskieren",
    "riskierst": "riskieren",
    "riskiert": "riskieren",
    "riskierte": "riskieren",
    "riskiertem": "riskiert",
    "riskierten": "riskieren",
    "riskierter": "riskiert",
    "riskiertes": "riskiert",
    "riskiertest": "riskieren",
    "riskiertet": "riskieren",
    "rissest": "reißen",
    "risset": "reißen",
    "rissige": "rissig",
    "rissigem": "rissig",
    "rissigen": "rissig",
    "rissiger": "rissig",
    "rissigere": "rissig",
    "rissigerem": "rissig",
    "rissigeren": "rissig",
    "rissigerer": "rissig",
    "rissigeres": "rissig",
    "rissiges": "rissig",
    "rissigste": "rissig",
    "rissigstem": "rissig",
    "rissigsten": "rissig",
    "rissigster": "rissig",
    "rissigstes": "rissig",
    "ritte": "reiten",
    "ritterlichem": "ritterlich",
    "ritterlichen": "ritterlich",
    "ritterlicher": "ritterlich",
    "ritterlichere": "ritterlich",
    "ritterlicherem": "ritterlich",
    "ritterlicheren": "ritterlich",
    "ritterlicherer": "ritterlich",
    "ritterlicheres": "ritterlich",
    "ritterliches": "ritterlich",
    "ritterlichste": "ritterlich",
    "ritterlichstem": "ritterlich",
    "ritterlichsten": "ritterlich",
    "ritterlichster": "ritterlich",
    "ritterlichstes": "ritterlich",
    "rittest": "reiten",
    "rittet": "reiten",
    "ritualisiere": "ritualisieren",
    "ritualisierend": "ritualisieren",
    "ritualisierende": "ritualisierend",
    "ritualisierendem": "ritualisierend",
    "ritualisierenden": "ritualisierend",
    "ritualisierender": "ritualisierend",
    "ritualisierendes": "ritualisierend",
    "ritualisierest": "ritualisieren",
    "ritualisieret": "ritualisieren",
    "ritualisierst": "ritualisieren",
    "ritualisiert": "ritualisieren",
    "ritualisierte": "ritualisieren",
    "ritualisiertem": "ritualisiert",
    "ritualisierten": "ritualisieren",
    "ritualisierter": "ritualisiert",
    "ritualisiertes": "ritualisiert",
    "ritualisiertest": "ritualisieren",
    "ritualisiertet": "ritualisieren",
    "ritzend": "ritzen",
    "ritzende": "ritzend",
    "ritzendem": "ritzend",
    "ritzenden": "ritzend",
    "ritzender": "ritzend",
    "ritzendes": "ritzend",
    "ritzest": "ritzen",
    "ritzet": "ritzen",
    "ritzt": "ritzen",
    "ritzte": "ritzen",
    "ritzten": "ritzen",
    "ritztest": "ritzen",
    "ritztet": "ritzen",
    "riß": "reißen",
    "rißt": "reißen",
    "robbend": "robben",
    "robbende": "robbend",
    "robbendem": "robbend",
    "robbenden": "robbend",
    "robbender": "robbend",
    "robbendes": "robbend",
    "robbest": "robben",
    "robbet": "robben",
    "robbst": "robben",
    "robbt": "robben",
    "robbte": "robben",
    "robbten": "robben",
    "robbtest": "robben",
    "robbtet": "robben",
    "robustem": "robust",
    "robusten": "robust",
    "robuster": "robust",
    "robustere": "robust",
    "robusterem": "robust",
    "robusteren": "robust",
    "robusterer": "robust",
    "robusteres": "robust",
    "robustes": "robust",
    "robusteste": "robust",
    "robustestem": "robust",
    "robustesten": "robust",
    "robustester": "robust",
    "robustestes": "robust",
    "roch": "riechen",
    "rochen": "riechen",
    "rochst": "riechen",
    "rocht": "riechen",
    "rode": "roden",
    "rodele": "rodeln",
    "rodelnd": "rodeln",
    "rodelnde": "rodelnd",
    "rodelndem": "rodelnd",
    "rodelnden": "rodelnd",
    "rodelnder": "rodelnd",
    "rodelndere": "rodelnd",
    "rodelnderem": "rodelnd",
    "rodelnderen": "rodelnd",
    "rodelnderer": "rodelnd",
    "rodelnderes": "rodelnd",
    "rodelndes": "rodelnd",
    "rodelndste": "rodelnd",
    "rodelndstem": "rodelnd",
    "rodelndsten": "rodelnd",
    "rodelndster": "rodelnd",
    "rodelndstes": "rodelnd",
    "rodelst": "rodeln",
    "rodelt": "rodeln",
    "rodelte": "rodeln",
    "rodelten": "rodeln",
    "rodeltest": "rodeln",
    "rodeltet": "rodeln",
    "rodend": "roden",
    "rodende": "rodend",
    "rodendem": "rodend",
    "rodenden": "rodend",
    "rodender": "rodend",
    "rodendere": "rodend",
    "rodenderem": "rodend",
    "rodenderen": "rodend",
    "rodenderer": "rodend",
    "rodenderes": "rodend",
    "rodendes": "rodend",
    "rodendste": "rodend",
    "rodendstem": "rodend",
    "rodendsten": "rodend",
    "rodendster": "rodend",
    "rodendstes": "rodend",
    "rodest": "roden",
    "rodet": "roden",
    "rodete": "roden",
    "rodeten": "roden",
    "rodetest": "roden",
    "rodetet": "roden",
    "rodle": "rodeln",
    "rohem": "roh",
    "rohen": "roh",
    "roher": "roh",
    "rohere": "roh",
    "roherem": "roh",
    "roheren": "roh",
    "roherer": "roh",
    "roheres": "roh",
    "rohes": "roh",
    "roheste": "roh",
    "rohestem": "roh",
    "rohesten": "roh",
    "rohester": "roh",
    "rohestes": "roh",
    "rollend": "rollen",
    "rollende": "rollend",
    "rollendem": "rollend",
    "rollenden": "rollend",
    "rollender": "rollend",
    "rollendes": "rollend",
    "rollest": "rollen",
    "rollet": "rollen",
    "rollst": "rollen",
    "rollt": "rollen",
    "rollte": "rollen",
    "rollten": "rollen",
    "rolltest": "rollen",
    "rolltet": "rollen",
    "romanischem": "romanisch",
    "romanischen": "romanisch",
    "romanischer": "romanisch",
    "romanisches": "romanisch",
    "romanistischem": "romanistisch",
    "romanistischen": "romanistisch",
    "romanistischer": "romanistisch",
    "romanistisches": "romanistisch",
    "romantischem": "romantisch",
    "romantischen": "romantisch",
    "romantischer": "romantisch",
    "romantischere": "romantisch",
    "romantischerem": "romantisch",
    "romantischeren": "romantisch",
    "romantischerer": "romantisch",
    "romantischeres": "romantisch",
    "romantisches": "romantisch",
    "romantischste": "romantisch",
    "romantischstem": "romantisch",
    "romantischsten": "romantisch",
    "romantischster": "romantisch",
    "romantischstes": "romantisch",
    "rosigem": "rosig",
    "rosigen": "rosig",
    "rosiger": "rosig",
    "rosigere": "rosig",
    "rosigerem": "rosig",
    "rosigeren": "rosig",
    "rosigerer": "rosig",
    "rosigeres": "rosig",
    "rosiges": "rosig",
    "rosigste": "rosig",
    "rosigstem": "rosig",
    "rosigsten": "rosig",
    "rosigster": "rosig",
    "rosigstes": "rosig",
    "rostend": "rosten",
    "rostende": "rostend",
    "rostendem": "rostend",
    "rostenden": "rostend",
    "rostender": "rostend",
    "rostendere": "rostend",
    "rostenderem": "rostend",
    "rostenderen": "rostend",
    "rostenderer": "rostend",
    "rostenderes": "rostend",
    "rostendes": "rostend",
    "rostendste": "rostend",
    "rostendstem": "rostend",
    "rostendsten": "rostend",
    "rostendster": "rostend",
    "rostendstes": "rostend",
    "rostest": "rosten",
    "rostet": "rosten",
    "rostete": "rosten",
    "rosteten": "rosten",
    "rostetest": "rosten",
    "rostetet": "rosten",
    "rostfreie": "rostfrei",
    "rostfreiem": "rostfrei",
    "rostfreien": "rostfrei",
    "rostfreier": "rostfrei",
    "rostfreies": "rostfrei",
    "rostige": "rostig",
    "rostigem": "rostig",
    "rostigen": "rostig",
    "rostiger": "rostig",
    "rostigere": "rostig",
    "rostigerem": "rostig",
    "rostigeren": "rostig",
    "rostigerer": "rostig",
    "rostigeres": "rostig",
    "rostiges": "rostig",
    "rostigste": "rostig",
    "rostigstem": "rostig",
    "rostigsten": "rostig",
    "rostigster": "rostig",
    "rostigstes": "rostig",
    "rotem": "rot",
    "roten": "rot",
    "roter": "rot",
    "rotere": "rot",
    "roterem": "rot",
    "roteren": "rot",
    "roterer": "rot",
    "roteres": "rot",
    "rotes": "rot",
    "roteste": "rot",
    "rotestem": "rot",
    "rotesten": "rot",
    "rotester": "rot",
    "rotestes": "rot",
    "rothaarigem": "rothaarig",
    "rothaarigen": "rothaarig",
    "rothaariger": "rothaarig",
    "rothaariges": "rothaarig",
    "rotiere": "rotieren",
    "rotierend": "rotieren",
    "rotierende": "rotierend",
    "rotierendem": "rotierend",
    "rotierenden": "rotierend",
    "rotierender": "rotierend",
    "rotierendere": "rotierend",
    "rotierenderem": "rotierend",
    "rotierenderen": "rotierend",
    "rotierenderer": "rotierend",
    "rotierenderes": "rotierend",
    "rotierendes": "rotierend",
    "rotierendste": "rotierend",
    "rotierendstem": "rotierend",
    "rotierendsten": "rotierend",
    "rotierendster": "rotierend",
    "rotierendstes": "rotierend",
    "rotierest": "rotieren",
    "rotieret": "rotieren",
    "rotierst": "rotieren",
    "rotiert": "rotieren",
    "rotierte": "rotieren",
    "rotiertem": "rotiert",
    "rotierten": "rotieren",
    "rotierter": "rotiert",
    "rotiertes": "rotiert",
    "rotiertest": "rotieren",
    "rotiertet": "rotieren",
    "rottend": "rotten",
    "rottende": "rottend",
    "rottendem": "rottend",
    "rottenden": "rottend",
    "rottender": "rottend",
    "rottendes": "rottend",
    "rottest": "rotten",
    "rottet": "rotten",
    "rottete": "rotten",
    "rotteten": "rotten",
    "rottetest": "rotten",
    "rottetet": "rotten",
    "rotze": "rotzen",
    "rotzend": "rotzen",
    "rotzende": "rotzend",
    "rotzendem": "rotzend",
    "rotzenden": "rotzend",
    "rotzender": "rotzend",
    "rotzendere": "rotzend",
    "rotzenderem": "rotzend",
    "rotzenderen": "rotzend",
    "rotzenderer": "rotzend",
    "rotzenderes": "rotzend",
    "rotzendes": "rotzend",
    "rotzendste": "rotzend",
    "rotzendstem": "rotzend",
    "rotzendsten": "rotzend",
    "rotzendster": "rotzend",
    "rotzendstes": "rotzend",
    "rotzest": "rotzen",
    "rotzet": "rotzen",
    "rotzfreche": "rotzfrech",
    "rotzfrechem": "rotzfrech",
    "rotzfrechen": "rotzfrech",
    "rotzfrecher": "rotzfrech",
    "rotzfreches": "rotzfrech",
    "rotzige": "rotzig",
    "rotzigem": "rotzig",
    "rotzigen": "rotzig",
    "rotziger": "rotzig",
    "rotzigere": "rotzig",
    "rotzigerem": "rotzig",
    "rotzigeren": "rotzig",
    "rotzigerer": "rotzig",
    "rotzigeres": "rotzig",
    "rotziges": "rotzig",
    "rotzigste": "rotzig",
    "rotzigstem": "rotzig",
    "rotzigsten": "rotzig",
    "rotzigster": "rotzig",
    "rotzigstes": "rotzig",
    "rotzt": "rotzen",
    "rotzte": "rotzen",
    "rotzten": "rotzen",
    "rotztest": "rotzen",
    "rotztet": "rotzen",
    "rubbele": "rubbeln",
    "rubbelige": "rubbelig",
    "rubbeligem": "rubbelig",
    "rubbeligen": "rubbelig",
    "rubbeliger": "rubbelig",
    "rubbeligere": "rubbelig",
    "rubbeligerem": "rubbelig",
    "rubbeligeren": "rubbelig",
    "rubbeligerer": "rubbelig",
    "rubbeligeres": "rubbelig",
    "rubbeliges": "rubbelig",
    "rubbeligste": "rubbelig",
    "rubbeligstem": "rubbelig",
    "rubbeligsten": "rubbelig",
    "rubbeligster": "rubbelig",
    "rubbeligstes": "rubbelig",
    "rubbelnd": "rubbeln",
    "rubbelnde": "rubbelnd",
    "rubbelndem": "rubbelnd",
    "rubbelnden": "rubbelnd",
    "rubbelnder": "rubbelnd",
    "rubbelndere": "rubbelnd",
    "rubbelnderem": "rubbelnd",
    "rubbelnderen": "rubbelnd",
    "rubbelnderer": "rubbelnd",
    "rubbelnderes": "rubbelnd",
    "rubbelndes": "rubbelnd",
    "rubbelndste": "rubbelnd",
    "rubbelndstem": "rubbelnd",
    "rubbelndsten": "rubbelnd",
    "rubbelndster": "rubbelnd",
    "rubbelndstes": "rubbelnd",
    "rubbelst": "rubbeln",
    "rubbelt": "rubbeln",
    "rubbelte": "rubbeln",
    "rubbelten": "rubbeln",
    "rubbeltest": "rubbeln",
    "rubbeltet": "rubbeln",
    "rubble": "rubbeln",
    "ruckartigem": "ruckartig",
    "ruckartigen": "ruckartig",
    "ruckartiger": "ruckartig",
    "ruckartigere": "ruckartig",
    "ruckartigerem": "ruckartig",
    "ruckartigeren": "ruckartig",
    "ruckartigerer": "ruckartig",
    "ruckartigeres": "ruckartig",
    "ruckartiges": "ruckartig",
    "ruckartigste": "ruckartig",
    "ruckartigstem": "ruckartig",
    "ruckartigsten": "ruckartig",
    "ruckartigster": "ruckartig",
    "ruckartigstes": "ruckartig",
    "ruckele": "ruckeln",
    "ruckelnd": "ruckeln",
    "ruckelnde": "ruckelnd",
    "ruckelndem": "ruckelnd",
    "ruckelnden": "ruckelnd",
    "ruckelnder": "ruckelnd",
    "ruckelndere": "ruckelnd",
    "ruckelnderem": "ruckelnd",
    "ruckelnderen": "ruckelnd",
    "ruckelnderer": "ruckelnd",
    "ruckelnderes": "ruckelnd",
    "ruckelndes": "ruckelnd",
    "ruckelndste": "ruckelnd",
    "ruckelndstem": "ruckelnd",
    "ruckelndsten": "ruckelnd",
    "ruckelndster": "ruckelnd",
    "ruckelndstes": "ruckelnd",
    "ruckelst": "ruckeln",
    "ruckelt": "ruckeln",
    "ruckelte": "ruckeln",
    "ruckelten": "ruckeln",
    "ruckeltest": "ruckeln",
    "ruckeltet": "ruckeln",
    "ruckle": "ruckeln",
    "rudere": "rudern",
    "rudernd": "rudern",
    "rudernde": "rudernd",
    "ruderndem": "rudernd",
    "rudernden": "rudernd",
    "rudernder": "rudernd",
    "ruderndere": "rudernd",
    "rudernderem": "rudernd",
    "rudernderen": "rudernd",
    "rudernderer": "rudernd",
    "rudernderes": "rudernd",
    "ruderndes": "rudernd",
    "ruderndste": "rudernd",
    "ruderndstem": "rudernd",
    "ruderndsten": "rudernd",
    "ruderndster": "rudernd",
    "ruderndstes": "rudernd",
    "ruderst": "rudern",
    "rudert": "rudern",
    "ruderte": "rudern",
    "ruderten": "rudern",
    "rudertest": "rudern",
    "rudertet": "rudern",
    "rudimentärem": "rudimentär",
    "rudimentären": "rudimentär",
    "rudimentärer": "rudimentär",
    "rudimentärere": "rudimentär",
    "rudimentärerem": "rudimentär",
    "rudimentäreren": "rudimentär",
    "rudimentärerer": "rudimentär",
    "rudimentäreres": "rudimentär",
    "rudimentäres": "rudimentär",
    "rudimentärste": "rudimentär",
    "rudimentärstem": "rudimentär",
    "rudimentärsten": "rudimentär",
    "rudimentärster": "rudimentär",
    "rudimentärstes": "rudimentär",
    "rufend": "rufen",
    "rufende": "rufend",
    "rufendem": "rufend",
    "rufenden": "rufend",
    "rufender": "rufend",
    "rufendes": "rufend",
    "rufest": "rufen",
    "rufet": "rufen",
    "rufst": "rufen",
    "ruft": "rufen",
    "ruhe": "ruhen",
    "ruhelosem": "ruhelos",
    "ruhelosen": "ruhelos",
    "ruheloser": "ruhelos",
    "ruhelosere": "ruhelos",
    "ruheloserem": "ruhelos",
    "ruheloseren": "ruhelos",
    "ruheloserer": "ruhelos",
    "ruheloseres": "ruhelos",
    "ruheloses": "ruhelos",
    "ruheloseste": "ruhelos",
    "ruhelosestem": "ruhelos",
    "ruhelosesten": "ruhelos",
    "ruhelosester": "ruhelos",
    "ruhelosestes": "ruhelos",
    "ruhend": "ruhen",
    "ruhende": "ruhend",
    "ruhendem": "ruhend",
    "ruhenden": "ruhend",
    "ruhender": "ruhend",
    "ruhendere": "ruhend",
    "ruhenderem": "ruhend",
    "ruhenderen": "ruhend",
    "ruhenderer": "ruhend",
    "ruhenderes": "ruhend",
    "ruhendes": "ruhend",
    "ruhendste": "ruhend",
    "ruhendstem": "ruhend",
    "ruhendsten": "ruhend",
    "ruhendster": "ruhend",
    "ruhendstes": "ruhend",
    "ruhest": "ruhen",
    "ruhestörendem": "ruhestörend",
    "ruhestörenden": "ruhestörend",
    "ruhestörender": "ruhestörend",
    "ruhestörendes": "ruhestörend",
    "ruhet": "ruhen",
    "ruhige": "ruhig",
    "ruhigem": "ruhig",
    "ruhigen": "ruhig",
    "ruhiger": "ruhig",
    "ruhigere": "ruhig",
    "ruhigerem": "ruhig",
    "ruhigeren": "ruhig",
    "ruhigerer": "ruhig",
    "ruhigeres": "ruhig",
    "ruhiges": "ruhig",
    "ruhigste": "ruhig",
    "ruhigstem": "ruhig",
    "ruhigsten": "ruhig",
    "ruhigster": "ruhig",
    "ruhigstes": "ruhig",
    "ruhmreiche": "ruhmreich",
    "ruhmreichem": "ruhmreich",
    "ruhmreichen": "ruhmreich",
    "ruhmreicher": "ruhmreich",
    "ruhmreichere": "ruhmreich",
    "ruhmreicherem": "ruhmreich",
    "ruhmreicheren": "ruhmreich",
    "ruhmreicherer": "ruhmreich",
    "ruhmreicheres": "ruhmreich",
    "ruhmreiches": "ruhmreich",
    "ruhmreichste": "ruhmreich",
    "ruhmreichstem": "ruhmreich",
    "ruhmreichsten": "ruhmreich",
    "ruhmreichster": "ruhmreich",
    "ruhmreichstes": "ruhmreich",
    "ruhst": "ruhen",
    "ruht": "ruhen",
    "ruhte": "ruhen",
    "ruhten": "ruhen",
    "ruhtest": "ruhen",
    "ruhtet": "ruhen",
    "ruiniere": "ruinieren",
    "ruinierend": "ruinieren",
    "ruinierende": "ruinierend",
    "ruinierendem": "ruinierend",
    "ruinierenden": "ruinierend",
    "ruinierender": "ruinierend",
    "ruinierendere": "ruinierend",
    "ruinierenderem": "ruinierend",
    "ruinierenderen": "ruinierend",
    "ruinierenderer": "ruinierend",
    "ruinierenderes": "ruinierend",
    "ruinierendes": "ruinierend",
    "ruinierendste": "ruinierend",
    "ruinierendstem": "ruinierend",
    "ruinierendsten": "ruinierend",
    "ruinierendster": "ruinierend",
    "ruinierendstes": "ruinierend",
    "ruinierest": "ruinieren",
    "ruinieret": "ruinieren",
    "ruinierst": "ruinieren",
    "ruiniert": "ruinieren",
    "ruinierte": "ruinieren",
    "ruiniertem": "ruiniert",
    "ruinierten": "ruinieren",
    "ruinierter": "ruiniert",
    "ruiniertere": "ruiniert",
    "ruinierterem": "ruiniert",
    "ruinierteren": "ruiniert",
    "ruinierterer": "ruiniert",
    "ruinierteres": "ruiniert",
    "ruiniertes": "ruiniert",
    "ruiniertest": "ruinieren",
    "ruinierteste": "ruiniert",
    "ruiniertestem": "ruiniert",
    "ruiniertesten": "ruiniert",
    "ruiniertester": "ruiniert",
    "ruiniertestes": "ruiniert",
    "ruiniertet": "ruinieren",
    "ruinöse": "ruinös",
    "ruinösem": "ruinös",
    "ruinösen": "ruinös",
    "ruinöser": "ruinös",
    "ruinösere": "ruinös",
    "ruinöserem": "ruinös",
    "ruinöseren": "ruinös",
    "ruinöserer": "ruinös",
    "ruinöseres": "ruinös",
    "ruinöses": "ruinös",
    "ruinöseste": "ruinös",
    "ruinösestem": "ruinös",
    "ruinösesten": "ruinös",
    "ruinösester": "ruinös",
    "ruinösestes": "ruinös",
    "rumgehangen": "rumhängen",
    "rumgehangene": "rumgehangen",
    "rumgehangenem": "rumgehangen",
    "rumgehangenen": "rumgehangen",
    "rumgehangener": "rumgehangen",
    "rumgehangenes": "rumgehangen",
    "rumgehängt": "rumhängen",
    "rumgehängte": "rumgehängt",
    "rumgehängtem": "rumgehängt",
    "rumgehängten": "rumgehängt",
    "rumgehängter": "rumgehängt",
    "rumgehängtes": "rumgehängt",
    "rumhing": "rumhängen",
    "rumhinge": "rumhängen",
    "rumhingen": "rumhängen",
    "rumhingest": "rumhängen",
    "rumhinget": "rumhängen",
    "rumhingst": "rumhängen",
    "rumhingt": "rumhängen",
    "rumhänge": "rumhängen",
    "rumhängend": "rumhängen",
    "rumhängende": "rumhängend",
    "rumhängendem": "rumhängend",
    "rumhängenden": "rumhängend",
    "rumhängender": "rumhängend",
    "rumhängendere": "rumhängend",
    "rumhängenderem": "rumhängend",
    "rumhängenderen": "rumhängend",
    "rumhängenderer": "rumhängend",
    "rumhängenderes": "rumhängend",
    "rumhängendes": "rumhängend",
    "rumhängendste": "rumhängend",
    "rumhängendstem": "rumhängend",
    "rumhängendsten": "rumhängend",
    "rumhängendster": "rumhängend",
    "rumhängendstes": "rumhängend",
    "rumhängest": "rumhängen",
    "rumhänget": "rumhängen",
    "rumhängst": "rumhängen",
    "rumhängt": "rumhängen",
    "rumhängte": "rumhängen",
    "rumhängten": "rumhängen",
    "rumhängtest": "rumhängen",
    "rumhängtet": "rumhängen",
    "rumore": "rumoren",
    "rumorend": "rumoren",
    "rumorende": "rumorend",
    "rumorendem": "rumorend",
    "rumorenden": "rumorend",
    "rumorender": "rumorend",
    "rumorendere": "rumorend",
    "rumorenderem": "rumorend",
    "rumorenderen": "rumorend",
    "rumorenderer": "rumorend",
    "rumorenderes": "rumorend",
    "rumorendes": "rumorend",
    "rumorendste": "rumorend",
    "rumorendstem": "rumorend",
    "rumorendsten": "rumorend",
    "rumorendster": "rumorend",
    "rumorendstes": "rumorend",
    "rumorest": "rumoren",
    "rumoret": "rumoren",
    "rumorst": "rumoren",
    "rumort": "rumoren",
    "rumorte": "rumoren",
    "rumortem": "rumort",
    "rumorten": "rumoren",
    "rumorter": "rumort",
    "rumortes": "rumort",
    "rumortest": "rumoren",
    "rumortet": "rumoren",
    "rumzuhängen": "rumhängen",
    "rumänischem": "rumänisch",
    "rumänischen": "rumänisch",
    "rumänischer": "rumänisch",
    "rumänisches": "rumänisch",
    "runde": "runden",
    "rundem": "rund",
    "runden": "rund",
    "rundend": "runden",
    "rundende": "rundend",
    "rundendem": "rundend",
    "rundenden": "rundend",
    "rundender": "rundend",
    "rundendes": "rundend",
    "runder": "rund",
    "rundere": "rund",
    "runderem": "rund",
    "runderen": "rund",
    "runderer": "rund",
    "runderes": "rund",
    "rundest": "runden",
    "rundeste": "rund",
    "rundestem": "rund",
    "rundesten": "rund",
    "rundester": "rund",
    "rundestes": "rund",
    "rundet": "runden",
    "rundete": "runden",
    "rundeten": "runden",
    "rundetest": "runden",
    "rundetet": "runden",
    "rundlichem": "rundlich",
    "rundlichen": "rundlich",
    "rundlicher": "rundlich",
    "rundlichere": "rundlich",
    "rundlicherem": "rundlich",
    "rundlicheren": "rundlich",
    "rundlicherer": "rundlich",
    "rundlicheres": "rundlich",
    "rundliches": "rundlich",
    "rundlichste": "rundlich",
    "rundlichstem": "rundlich",
    "rundlichsten": "rundlich",
    "rundlichster": "rundlich",
    "rundlichstes": "rundlich",
    "runtergesetzt": "runtersetzen",
    "runtergesetzte": "runtergesetzt",
    "runtergesetztem": "runtergesetzt",
    "runtergesetzten": "runtergesetzt",
    "runtergesetzter": "runtergesetzt",
    "runtergesetztere": "runtergesetzt",
    "runtergesetzterem": "runtergesetzt",
    "runtergesetzteren": "runtergesetzt",
    "runtergesetzterer": "runtergesetzt",
    "runtergesetzteres": "runtergesetzt",
    "runtergesetztes": "runtergesetzt",
    "runtergesetzteste": "runtergesetzt",
    "runtergesetztestem": "runtergesetzt",
    "runtergesetztesten": "runtergesetzt",
    "runtergesetztester": "runtergesetzt",
    "runtergesetztestes": "runtergesetzt",
    "runtergezogene": "runtergezogen",
    "runtergezogenem": "runtergezogen",
    "runtergezogenen": "runtergezogen",
    "runtergezogener": "runtergezogen",
    "runtergezogenes": "runtergezogen",
    "runtersetze": "runtersetzen",
    "runtersetzend": "runtersetzen",
    "runtersetzende": "runtersetzend",
    "runtersetzendem": "runtersetzend",
    "runtersetzenden": "runtersetzend",
    "runtersetzender": "runtersetzend",
    "runtersetzendes": "runtersetzend",
    "runtersetzest": "runtersetzen",
    "runtersetzet": "runtersetzen",
    "runtersetzt": "runtersetzen",
    "runtersetzte": "runtersetzen",
    "runtersetzten": "runtersetzen",
    "runtersetztest": "runtersetzen",
    "runtersetztet": "runtersetzen",
    "runterziehende": "runterziehend",
    "runterziehendem": "runterziehend",
    "runterziehenden": "runterziehend",
    "runterziehender": "runterziehend",
    "runterziehendes": "runterziehend",
    "runterzusetzen": "runtersetzen",
    "runzele": "runzeln",
    "runzelige": "runzelig",
    "runzeligem": "runzelig",
    "runzeligen": "runzelig",
    "runzeliger": "runzelig",
    "runzeligere": "runzelig",
    "runzeligerem": "runzelig",
    "runzeligeren": "runzelig",
    "runzeligerer": "runzelig",
    "runzeligeres": "runzelig",
    "runzeliges": "runzelig",
    "runzeligste": "runzelig",
    "runzeligstem": "runzelig",
    "runzeligsten": "runzelig",
    "runzeligster": "runzelig",
    "runzeligstes": "runzelig",
    "runzelnd": "runzeln",
    "runzelnde": "runzelnd",
    "runzelndem": "runzelnd",
    "runzelnden": "runzelnd",
    "runzelnder": "runzelnd",
    "runzelndere": "runzelnd",
    "runzelnderem": "runzelnd",
    "runzelnderen": "runzelnd",
    "runzelnderer": "runzelnd",
    "runzelnderes": "runzelnd",
    "runzelndes": "runzelnd",
    "runzelndste": "runzelnd",
    "runzelndstem": "runzelnd",
    "runzelndsten": "runzelnd",
    "runzelndster": "runzelnd",
    "runzelndstes": "runzelnd",
    "runzelst": "runzeln",
    "runzelt": "runzeln",
    "runzelte": "runzeln",
    "runzelten": "runzeln",
    "runzeltest": "runzeln",
    "runzeltet": "runzeln",
    "runzle": "runzeln",
    "runzlige": "runzlig",
    "runzligem": "runzlig",
    "runzligen": "runzlig",
    "runzliger": "runzlig",
    "runzligere": "runzlig",
    "runzligerem": "runzlig",
    "runzligeren": "runzlig",
    "runzligerer": "runzlig",
    "runzligeres": "runzlig",
    "runzliges": "runzlig",
    "runzligste": "runzlig",
    "runzligstem": "runzlig",
    "runzligsten": "runzlig",
    "runzligster": "runzlig",
    "runzligstes": "runzlig",
    "rupfe": "rupfen",
    "rupfend": "rupfen",
    "rupfende": "rupfend",
    "rupfendem": "rupfend",
    "rupfenden": "rupfend",
    "rupfender": "rupfend",
    "rupfendere": "rupfend",
    "rupfenderem": "rupfend",
    "rupfenderen": "rupfend",
    "rupfenderer": "rupfend",
    "rupfenderes": "rupfend",
    "rupfendes": "rupfend",
    "rupfendste": "rupfend",
    "rupfendstem": "rupfend",
    "rupfendsten": "rupfend",
    "rupfendster": "rupfend",
    "rupfendstes": "rupfend",
    "rupfest": "rupfen",
    "rupfet": "rupfen",
    "rupfst": "rupfen",
    "rupft": "rupfen",
    "rupfte": "rupfen",
    "rupften": "rupfen",
    "rupftest": "rupfen",
    "rupftet": "rupfen",
    "ruppige": "ruppig",
    "ruppigem": "ruppig",
    "ruppigen": "ruppig",
    "ruppiger": "ruppig",
    "ruppigere": "ruppig",
    "ruppigerem": "ruppig",
    "ruppigeren": "ruppig",
    "ruppigerer": "ruppig",
    "ruppigeres": "ruppig",
    "ruppiges": "ruppig",
    "ruppigste": "ruppig",
    "ruppigstem": "ruppig",
    "ruppigsten": "ruppig",
    "ruppigster": "ruppig",
    "ruppigstes": "ruppig",
    "russischem": "russisch",
    "russischen": "russisch",
    "russischer": "russisch",
    "russisches": "russisch",
    "rustikale": "rustikal",
    "rustikalem": "rustikal",
    "rustikalen": "rustikal",
    "rustikaler": "rustikal",
    "rustikalere": "rustikal",
    "rustikalerem": "rustikal",
    "rustikaleren": "rustikal",
    "rustikalerer": "rustikal",
    "rustikaleres": "rustikal",
    "rustikales": "rustikal",
    "rustikalste": "rustikal",
    "rustikalstem": "rustikal",
    "rustikalsten": "rustikal",
    "rustikalster": "rustikal",
    "rustikalstes": "rustikal",
    "rutschend": "rutschen",
    "rutschende": "rutschend",
    "rutschendem": "rutschend",
    "rutschenden": "rutschend",
    "rutschender": "rutschend",
    "rutschendes": "rutschend",
    "rutschest": "rutschen",
    "rutschet": "rutschen",
    "rutschfeste": "rutschfest",
    "rutschfestem": "rutschfest",
    "rutschfesten": "rutschfest",
    "rutschfester": "rutschfest",
    "rutschfestere": "rutschfest",
    "rutschfesterem": "rutschfest",
    "rutschfesteren": "rutschfest",
    "rutschfesterer": "rutschfest",
    "rutschfesteres": "rutschfest",
    "rutschfestes": "rutschfest",
    "rutschfesteste": "rutschfest",
    "rutschfestestem": "rutschfest",
    "rutschfestesten": "rutschfest",
    "rutschfestester": "rutschfest",
    "rutschfestestes": "rutschfest",
    "rutschige": "rutschig",
    "rutschigem": "rutschig",
    "rutschigen": "rutschig",
    "rutschiger": "rutschig",
    "rutschigere": "rutschig",
    "rutschigerem": "rutschig",
    "rutschigeren": "rutschig",
    "rutschigerer": "rutschig",
    "rutschigeres": "rutschig",
    "rutschiges": "rutschig",
    "rutschigste": "rutschig",
    "rutschigstem": "rutschig",
    "rutschigsten": "rutschig",
    "rutschigster": "rutschig",
    "rutschigstes": "rutschig",
    "rutschsicherem": "rutschsicher",
    "rutschsicheren": "rutschsicher",
    "rutschsicherer": "rutschsicher",
    "rutschsicherere": "rutschsicher",
    "rutschsichererem": "rutschsicher",
    "rutschsichereren": "rutschsicher",
    "rutschsichererer": "rutschsicher",
    "rutschsichereres": "rutschsicher",
    "rutschsicheres": "rutschsicher",
    "rutschsicherste": "rutschsicher",
    "rutschsicherstem": "rutschsicher",
    "rutschsichersten": "rutschsicher",
    "rutschsicherster": "rutschsicher",
    "rutschsicherstes": "rutschsicher",
    "rutschst": "rutschen",
    "rutscht": "rutschen",
    "rutschte": "rutschen",
    "rutschten": "rutschen",
    "rutschtest": "rutschen",
    "rutschtet": "rutschen",
    "räche": "rächen",
    "rächend": "rächen",
    "rächende": "rächend",
    "rächendem": "rächend",
    "rächenden": "rächend",
    "rächender": "rächend",
    "rächendes": "rächend",
    "rächest": "rächen",
    "rächet": "rächen",
    "rächst": "rächen",
    "rächt": "rächen",
    "rächte": "rächen",
    "rächten": "rächen",
    "rächtest": "rächen",
    "rächtet": "rächen",
    "rädere": "rädern",
    "rädernd": "rädern",
    "rädernde": "rädernd",
    "räderndem": "rädernd",
    "rädernden": "rädernd",
    "rädernder": "rädernd",
    "räderndes": "rädernd",
    "räderst": "rädern",
    "rädert": "rädern",
    "räderte": "rädern",
    "räderten": "rädern",
    "rädertest": "rädern",
    "rädertet": "rädern",
    "räkele": "räkeln",
    "räkelnd": "räkeln",
    "räkelnde": "räkelnd",
    "räkelndem": "räkelnd",
    "räkelnden": "räkelnd",
    "räkelnder": "räkelnd",
    "räkelndere": "räkelnd",
    "räkelnderem": "räkelnd",
    "räkelnderen": "räkelnd",
    "räkelnderer": "räkelnd",
    "räkelnderes": "räkelnd",
    "räkelndes": "räkelnd",
    "räkelndste": "räkelnd",
    "räkelndstem": "räkelnd",
    "räkelndsten": "räkelnd",
    "räkelndster": "räkelnd",
    "räkelndstes": "räkelnd",
    "räkelst": "räkeln",
    "räkelt": "räkeln",
    "räkelte": "räkeln",
    "räkelten": "räkeln",
    "räkeltest": "räkeln",
    "räkeltet": "räkeln",
    "räkle": "räkeln",
    "rängest": "ringen",
    "ränget": "ringen",
    "ränne": "rinnen",
    "rännen": "rinnen",
    "rännest": "rinnen",
    "rännet": "rinnen",
    "rät": "raten",
    "rätsele": "rätseln",
    "rätselhafte": "rätselhaft",
    "rätselhaftem": "rätselhaft",
    "rätselhaften": "rätselhaft",
    "rätselhafter": "rätselhaft",
    "rätselhaftere": "rätselhaft",
    "rätselhafterem": "rätselhaft",
    "rätselhafteren": "rätselhaft",
    "rätselhafterer": "rätselhaft",
    "rätselhafteres": "rätselhaft",
    "rätselhaftes": "rätselhaft",
    "rätselhafteste": "rätselhaft",
    "rätselhaftestem": "rätselhaft",
    "rätselhaftesten": "rätselhaft",
    "rätselhaftester": "rätselhaft",
    "rätselhaftestes": "rätselhaft",
    "rätselnd": "rätseln",
    "rätselnde": "rätselnd",
    "rätselndem": "rätselnd",
    "rätselnden": "rätselnd",
    "rätselnder": "rätselnd",
    "rätselndere": "rätselnd",
    "rätselnderem": "rätselnd",
    "rätselnderen": "rätselnd",
    "rätselnderer": "rätselnd",
    "rätselnderes": "rätselnd",
    "rätselndes": "rätselnd",
    "rätselndste": "rätselnd",
    "rätselndstem": "rätselnd",
    "rätselndsten": "rätselnd",
    "rätselndster": "rätselnd",
    "rätselndstes": "rätselnd",
    "rätselst": "rätseln",
    "rätselt": "rätseln",
    "rätselte": "rätseln",
    "rätselten": "rätseln",
    "rätseltest": "rätseln",
    "rätseltet": "rätseln",
    "rätsle": "rätseln",
    "rätst": "raten",
    "räuberischem": "räuberisch",
    "räuberischen": "räuberisch",
    "räuberischer": "räuberisch",
    "räuberisches": "räuberisch",
    "räuchere": "räuchern",
    "räuchernd": "räuchern",
    "räuchernde": "räuchernd",
    "räucherndem": "räuchernd",
    "räuchernden": "räuchernd",
    "räuchernder": "räuchernd",
    "räucherndes": "räuchernd",
    "räucherst": "räuchern",
    "räuchert": "räuchern",
    "räucherte": "räuchern",
    "räucherten": "räuchern",
    "räuchertest": "räuchern",
    "räuchertet": "räuchern",
    "räudigem": "räudig",
    "räudigen": "räudig",
    "räudiger": "räudig",
    "räudigere": "räudig",
    "räudigerem": "räudig",
    "räudigeren": "räudig",
    "räudigerer": "räudig",
    "räudigeres": "räudig",
    "räudiges": "räudig",
    "räudigste": "räudig",
    "räudigstem": "räudig",
    "räudigsten": "räudig",
    "räudigster": "räudig",
    "räudigstes": "räudig",
    "räumend": "räumen",
    "räumende": "räumend",
    "räumendem": "räumend",
    "räumenden": "räumend",
    "räumender": "räumend",
    "räumendes": "räumend",
    "räumest": "räumen",
    "räumet": "räumen",
    "räumlichem": "räumlich",
    "räumlichen": "räumlich",
    "räumlicher": "räumlich",
    "räumliches": "räumlich",
    "räumst": "räumen",
    "räumt": "räumen",
    "räumte": "räumen",
    "räumten": "räumen",
    "räumtest": "räumen",
    "räumtet": "räumen",
    "räuspere": "räuspern",
    "räuspernd": "räuspern",
    "räuspernde": "räuspernd",
    "räusperndem": "räuspernd",
    "räuspernden": "räuspernd",
    "räuspernder": "räuspernd",
    "räusperndere": "räuspernd",
    "räuspernderem": "räuspernd",
    "räuspernderen": "räuspernd",
    "räuspernderer": "räuspernd",
    "räuspernderes": "räuspernd",
    "räusperndes": "räuspernd",
    "räusperndste": "räuspernd",
    "räusperndstem": "räuspernd",
    "räusperndsten": "räuspernd",
    "räusperndster": "räuspernd",
    "räusperndstes": "räuspernd",
    "räusperst": "räuspern",
    "räuspert": "räuspern",
    "räusperte": "räuspern",
    "räusperten": "räuspern",
    "räuspertest": "räuspern",
    "räuspertet": "räuspern",
    "röche": "riechen",
    "röchele": "röcheln",
    "röchelnd": "röcheln",
    "röchelnde": "röchelnd",
    "röchelndem": "röchelnd",
    "röchelnden": "röchelnd",
    "röchelnder": "röchelnd",
    "röchelndere": "röchelnd",
    "röchelnderem": "röchelnd",
    "röchelnderen": "röchelnd",
    "röchelnderer": "röchelnd",
    "röchelnderes": "röchelnd",
    "röchelndes": "röchelnd",
    "röchelndste": "röchelnd",
    "röchelndstem": "röchelnd",
    "röchelndsten": "röchelnd",
    "röchelndster": "röchelnd",
    "röchelndstes": "röchelnd",
    "röchelst": "röcheln",
    "röchelt": "röcheln",
    "röchelte": "röcheln",
    "röchelten": "röcheln",
    "röcheltest": "röcheln",
    "röcheltet": "röcheln",
    "röchen": "riechen",
    "röchest": "riechen",
    "röchet": "riechen",
    "röchle": "röcheln",
    "römischem": "römisch",
    "römischen": "römisch",
    "römischer": "römisch",
    "römisches": "römisch",
    "röntge": "röntgen",
    "röntgend": "röntgen",
    "röntgende": "röntgend",
    "röntgendem": "röntgend",
    "röntgenden": "röntgend",
    "röntgender": "röntgend",
    "röntgendes": "röntgend",
    "röntgest": "röntgen",
    "röntget": "röntgen",
    "röntgst": "röntgen",
    "röntgt": "röntgen",
    "röntgte": "röntgen",
    "röntgten": "röntgen",
    "röntgtest": "röntgen",
    "röntgtet": "röntgen",
    "röste": "rösten",
    "röstend": "rösten",
    "röstendem": "röstend",
    "röstender": "röstend",
    "röstenderem": "röstend",
    "röstenderer": "röstend",
    "röstenderes": "röstend",
    "röstendes": "röstend",
    "röstendstem": "röstend",
    "röstendster": "röstend",
    "röstendstes": "röstend",
    "röstest": "rösten",
    "röstet": "rösten",
    "röstete": "rösten",
    "rösteten": "rösten",
    "röstetest": "rösten",
    "röstetet": "rösten",
    "röstfrische": "röstfrisch",
    "röstfrischem": "röstfrisch",
    "röstfrischen": "röstfrisch",
    "röstfrischer": "röstfrisch",
    "röstfrisches": "röstfrisch",
    "röte": "röten",
    "rötend": "röten",
    "rötende": "rötend",
    "rötendem": "rötend",
    "rötenden": "rötend",
    "rötender": "rötend",
    "rötendere": "rötend",
    "rötenderem": "rötend",
    "rötenderen": "rötend",
    "rötenderer": "rötend",
    "rötenderes": "rötend",
    "rötendes": "rötend",
    "rötendste": "rötend",
    "rötendstem": "rötend",
    "rötendsten": "rötend",
    "rötendster": "rötend",
    "rötendstes": "rötend",
    "rötest": "röten",
    "rötet": "röten",
    "rötete": "röten",
    "röteten": "röten",
    "rötetest": "röten",
    "rötetet": "röten",
    "rötlichem": "rötlich",
    "rötlichen": "rötlich",
    "rötlicher": "rötlich",
    "rötliches": "rötlich",
    "rückblickend": "rückblicken",
    "rückblickende": "rückblickend",
    "rückblickendem": "rückblickend",
    "rückblickenden": "rückblickend",
    "rückblickender": "rückblickend",
    "rückblickendes": "rückblickend",
    "rückblickest": "rückblicken",
    "rückblicket": "rückblicken",
    "rückblickst": "rückblicken",
    "rückblickt": "rückblicken",
    "rückblickte": "rückblicken",
    "rückblickten": "rückblicken",
    "rückblicktest": "rückblicken",
    "rückblicktet": "rückblicken",
    "rückdatiere": "rückdatieren",
    "rückdatierend": "rückdatieren",
    "rückdatierende": "rückdatierend",
    "rückdatierendem": "rückdatierend",
    "rückdatierenden": "rückdatierend",
    "rückdatierender": "rückdatierend",
    "rückdatierendes": "rückdatierend",
    "rückdatierest": "rückdatieren",
    "rückdatieret": "rückdatieren",
    "rückdatierst": "rückdatieren",
    "rückdatiert": "rückdatieren",
    "rückdatierte": "rückdatieren",
    "rückdatiertem": "rückdatiert",
    "rückdatierten": "rückdatieren",
    "rückdatierter": "rückdatiert",
    "rückdatiertes": "rückdatiert",
    "rückdatiertest": "rückdatieren",
    "rückdatiertet": "rückdatieren",
    "rücke": "rücken",
    "rückend": "rücken",
    "rückende": "rückend",
    "rückendem": "rückend",
    "rückenden": "rückend",
    "rückender": "rückend",
    "rückendes": "rückend",
    "rückerstatte": "rückerstatten",
    "rückerstattend": "rückerstatten",
    "rückerstattende": "rückerstattend",
    "rückerstattendem": "rückerstattend",
    "rückerstattenden": "rückerstattend",
    "rückerstattender": "rückerstattend",
    "rückerstattendes": "rückerstattend",
    "rückerstattest": "rückerstatten",
    "rückerstattet": "rückerstatten",
    "rückerstattete": "rückerstatten",
    "rückerstattetem": "rückerstattet",
    "rückerstatteten": "rückerstatten",
    "rückerstatteter": "rückerstattet",
    "rückerstattetes": "rückerstattet",
    "rückerstattetest": "rückerstatten",
    "rückerstattetet": "rückerstatten",
    "rückest": "rücken",
    "rücket": "rücken",
    "rückfälligem": "rückfällig",
    "rückfälligen": "rückfällig",
    "rückfälliger": "rückfällig",
    "rückfälligere": "rückfällig",
    "rückfälligerem": "rückfällig",
    "rückfälligeren": "rückfällig",
    "rückfälligerer": "rückfällig",
    "rückfälligeres": "rückfällig",
    "rückfälliges": "rückfällig",
    "rückfälligste": "rückfällig",
    "rückfälligstem": "rückfällig",
    "rückfälligsten": "rückfällig",
    "rückfälligster": "rückfällig",
    "rückfälligstes": "rückfällig",
    "rückgebildetem": "rückgebildet",
    "rückgebildeten": "rückgebildet",
    "rückgebildeter": "rückgebildet",
    "rückgebildetes": "rückgebildet",
    "rückgeblickt": "rückblicken",
    "rückgeblickte": "rückgeblickt",
    "rückgeblicktem": "rückgeblickt",
    "rückgeblickten": "rückgeblickt",
    "rückgeblickter": "rückgeblickt",
    "rückgeblicktes": "rückgeblickt",
    "rückgekoppelte": "rückgekoppelt",
    "rückgekoppeltem": "rückgekoppelt",
    "rückgekoppelten": "rückgekoppelt",
    "rückgekoppelter": "rückgekoppelt",
    "rückgekoppeltes": "rückgekoppelt",
    "rückgängigem": "rückgängig",
    "rückgängigen": "rückgängig",
    "rückgängiger": "rückgängig",
    "rückgängiges": "rückgängig",
    "rückläufigem": "rückläufig",
    "rückläufigen": "rückläufig",
    "rückläufiger": "rückläufig",
    "rückläufiges": "rückläufig",
    "rückschrittlichem": "rückschrittlich",
    "rückschrittlichen": "rückschrittlich",
    "rückschrittlicher": "rückschrittlich",
    "rückschrittliches": "rückschrittlich",
    "rückseitigem": "rückseitig",
    "rückseitigen": "rückseitig",
    "rückseitiger": "rückseitig",
    "rückseitiges": "rückseitig",
    "rücksichtslosem": "rücksichtslos",
    "rücksichtslosen": "rücksichtslos",
    "rücksichtsloser": "rücksichtslos",
    "rücksichtslosere": "rücksichtslos",
    "rücksichtsloserem": "rücksichtslos",
    "rücksichtsloseren": "rücksichtslos",
    "rücksichtsloserer": "rücksichtslos",
    "rücksichtsloseres": "rücksichtslos",
    "rücksichtsloses": "rücksichtslos",
    "rücksichtsloseste": "rücksichtslos",
    "rücksichtslosestem": "rücksichtslos",
    "rücksichtslosesten": "rücksichtslos",
    "rücksichtslosester": "rücksichtslos",
    "rücksichtslosestes": "rücksichtslos",
    "rücksichtsvolle": "rücksichtsvoll",
    "rücksichtsvollem": "rücksichtsvoll",
    "rücksichtsvollen": "rücksichtsvoll",
    "rücksichtsvoller": "rücksichtsvoll",
    "rücksichtsvollere": "rücksichtsvoll",
    "rücksichtsvollerem": "rücksichtsvoll",
    "rücksichtsvolleren": "rücksichtsvoll",
    "rücksichtsvollerer": "rücksichtsvoll",
    "rücksichtsvolleres": "rücksichtsvoll",
    "rücksichtsvolles": "rücksichtsvoll",
    "rücksichtsvollste": "rücksichtsvoll",
    "rücksichtsvollstem": "rücksichtsvoll",
    "rücksichtsvollsten": "rücksichtsvoll",
    "rücksichtsvollster": "rücksichtsvoll",
    "rücksichtsvollstes": "rücksichtsvoll",
    "rückst": "rücken",
    "rückständigem": "rückständig",
    "rückständigen": "rückständig",
    "rückständiger": "rückständig",
    "rückständiges": "rückständig",
    "rückt": "rücken",
    "rückte": "rücken",
    "rückten": "rücken",
    "rücktest": "rücken",
    "rücktet": "rücken",
    "rückversichere": "rückversichern",
    "rückversichernd": "rückversichern",
    "rückversichernde": "rückversichernd",
    "rückversicherndem": "rückversichernd",
    "rückversichernden": "rückversichernd",
    "rückversichernder": "rückversichernd",
    "rückversicherndes": "rückversichernd",
    "rückversicherst": "rückversichern",
    "rückversichert": "rückversichern",
    "rückversicherte": "rückversichern",
    "rückversichertem": "rückversichert",
    "rückversicherten": "rückversichern",
    "rückversicherter": "rückversichert",
    "rückversichertes": "rückversichert",
    "rückversichertest": "rückversichern",
    "rückversichertet": "rückversichern",
    "rückwirkendem": "rückwirkend",
    "rückwirkenden": "rückwirkend",
    "rückwirkender": "rückwirkend",
    "rückwirkendes": "rückwirkend",
    "rückwärtigem": "rückwärtig",
    "rückwärtigen": "rückwärtig",
    "rückwärtiger": "rückwärtig",
    "rückwärtiges": "rückwärtig",
    "rückwärtsgegangen": "rückwärtsgehen",
    "rückwärtsgegangene": "rückwärtsgegangen",
    "rückwärtsgegangenem": "rückwärtsgegangen",
    "rückwärtsgegangenen": "rückwärtsgegangen",
    "rückwärtsgegangener": "rückwärtsgegangen",
    "rückwärtsgegangenes": "rückwärtsgegangen",
    "rückwärtsgehe": "rückwärtsgehen",
    "rückwärtsgehend": "rückwärtsgehen",
    "rückwärtsgehende": "rückwärtsgehend",
    "rückwärtsgehendem": "rückwärtsgehend",
    "rückwärtsgehenden": "rückwärtsgehend",
    "rückwärtsgehender": "rückwärtsgehend",
    "rückwärtsgehendes": "rückwärtsgehend",
    "rückwärtsgehest": "rückwärtsgehen",
    "rückwärtsgehet": "rückwärtsgehen",
    "rückwärtsgehst": "rückwärtsgehen",
    "rückwärtsgeht": "rückwärtsgehen",
    "rückwärtsging": "rückwärtsgehen",
    "rückwärtsginge": "rückwärtsgehen",
    "rückwärtsgingen": "rückwärtsgehen",
    "rückwärtsgingest": "rückwärtsgehen",
    "rückwärtsginget": "rückwärtsgehen",
    "rückwärtsgingst": "rückwärtsgehen",
    "rückwärtsgingt": "rückwärtsgehen",
    "rückwärtszugehen": "rückwärtsgehen",
    "rückzublicken": "rückblicken",
    "rückzudatieren": "rückdatieren",
    "rüdem": "rüde",
    "rüden": "rüde",
    "rüder": "rüde",
    "rüdere": "rüde",
    "rüderem": "rüde",
    "rüderen": "rüde",
    "rüderer": "rüde",
    "rüderes": "rüde",
    "rüdes": "rüde",
    "rüdeste": "rüde",
    "rüdestem": "rüde",
    "rüdesten": "rüde",
    "rüdester": "rüde",
    "rüdestes": "rüde",
    "rüge": "rügen",
    "rügend": "rügen",
    "rügende": "rügend",
    "rügendem": "rügend",
    "rügenden": "rügend",
    "rügender": "rügend",
    "rügendere": "rügend",
    "rügenderem": "rügend",
    "rügenderen": "rügend",
    "rügenderer": "rügend",
    "rügenderes": "rügend",
    "rügendes": "rügend",
    "rügendste": "rügend",
    "rügendstem": "rügend",
    "rügendsten": "rügend",
    "rügendster": "rügend",
    "rügendstes": "rügend",
    "rügest": "rügen",
    "rüget": "rügen",
    "rügst": "rügen",
    "rügt": "rügen",
    "rügte": "rügen",
    "rügten": "rügen",
    "rügtest": "rügen",
    "rügtet": "rügen",
    "rühme": "rühmen",
    "rühmend": "rühmen",
    "rühmende": "rühmend",
    "rühmendem": "rühmend",
    "rühmenden": "rühmend",
    "rühmender": "rühmend",
    "rühmendere": "rühmend",
    "rühmenderem": "rühmend",
    "rühmenderen": "rühmend",
    "rühmenderer": "rühmend",
    "rühmenderes": "rühmend",
    "rühmendes": "rühmend",
    "rühmendste": "rühmend",
    "rühmendstem": "rühmend",
    "rühmendsten": "rühmend",
    "rühmendster": "rühmend",
    "rühmendstes": "rühmend",
    "rühmest": "rühmen",
    "rühmet": "rühmen",
    "rühmliche": "rühmlich",
    "rühmlichem": "rühmlich",
    "rühmlichen": "rühmlich",
    "rühmlicher": "rühmlich",
    "rühmlichere": "rühmlich",
    "rühmlicherem": "rühmlich",
    "rühmlicheren": "rühmlich",
    "rühmlicherer": "rühmlich",
    "rühmlicheres": "rühmlich",
    "rühmliches": "rühmlich",
    "rühmlichste": "rühmlich",
    "rühmlichstem": "rühmlich",
    "rühmlichsten": "rühmlich",
    "rühmlichster": "rühmlich",
    "rühmlichstes": "rühmlich",
    "rühmst": "rühmen",
    "rühmt": "rühmen",
    "rühmte": "rühmen",
    "rühmten": "rühmen",
    "rühmtest": "rühmen",
    "rühmtet": "rühmen",
    "rühre": "rühren",
    "rührend": "rühren",
    "rührende": "rührend",
    "rührendem": "rührend",
    "rührenden": "rührend",
    "rührender": "rührend",
    "rührendere": "rührend",
    "rührenderem": "rührend",
    "rührenderen": "rührend",
    "rührenderer": "rührend",
    "rührenderes": "rührend",
    "rührendes": "rührend",
    "rührendste": "rührend",
    "rührendstem": "rührend",
    "rührendsten": "rührend",
    "rührendster": "rührend",
    "rührendstes": "rührend",
    "rührest": "rühren",
    "rühret": "rühren",
    "rührige": "rührig",
    "rührigem": "rührig",
    "rührigen": "rührig",
    "rühriger": "rührig",
    "rührigere": "rührig",
    "rührigerem": "rührig",
    "rührigeren": "rührig",
    "rührigerer": "rührig",
    "rührigeres": "rührig",
    "rühriges": "rührig",
    "rührigste": "rührig",
    "rührigstem": "rührig",
    "rührigsten": "rührig",
    "rührigster": "rührig",
    "rührigstes": "rührig",
    "rührselige": "rührselig",
    "rührseligem": "rührselig",
    "rührseligen": "rührselig",
    "rührseliger": "rührselig",
    "rührseligere": "rührselig",
    "rührseligerem": "rührselig",
    "rührseligeren": "rührselig",
    "rührseligerer": "rührselig",
    "rührseligeres": "rührselig",
    "rührseliges": "rührselig",
    "rührseligste": "rührselig",
    "rührseligstem": "rührselig",
    "rührseligsten": "rührselig",
    "rührseligster": "rührselig",
    "rührseligstes": "rührselig",
    "rührst": "rühren",
    "rührt": "rühren",
    "rührte": "rühren",
    "rührten": "rühren",
    "rührtest": "rühren",
    "rührtet": "rühren",
    "rülpse": "rülpsen",
    "rülpsend": "rülpsen",
    "rülpsende": "rülpsend",
    "rülpsendem": "rülpsend",
    "rülpsenden": "rülpsend",
    "rülpsender": "rülpsend",
    "rülpsendere": "rülpsend",
    "rülpsenderem": "rülpsend",
    "rülpsenderen": "rülpsend",
    "rülpsenderer": "rülpsend",
    "rülpsenderes": "rülpsend",
    "rülpsendes": "rülpsend",
    "rülpsendste": "rülpsend",
    "rülpsendstem": "rülpsend",
    "rülpsendsten": "rülpsend",
    "rülpsendster": "rülpsend",
    "rülpsendstes": "rülpsend",
    "rülpsest": "rülpsen",
    "rülpset": "rülpsen",
    "rülpst": "rülpsen",
    "rülpste": "rülpsen",
    "rülpsten": "rülpsen",
    "rülpstest": "rülpsen",
    "rülpstet": "rülpsen",
    "rümpfend": "rümpfen",
    "rümpfende": "rümpfend",
    "rümpfendem": "rümpfend",
    "rümpfenden": "rümpfend",
    "rümpfender": "rümpfend",
    "rümpfendes": "rümpfend",
    "rümpfest": "rümpfen",
    "rümpfet": "rümpfen",
    "rümpfst": "rümpfen",
    "rümpft": "rümpfen",
    "rümpfte": "rümpfen",
    "rümpften": "rümpfen",
    "rümpftest": "rümpfen",
    "rümpftet": "rümpfen",
    "rüpelhafte": "rüpelhaft",
    "rüpelhaftem": "rüpelhaft",
    "rüpelhaften": "rüpelhaft",
    "rüpelhafter": "rüpelhaft",
    "rüpelhaftere": "rüpelhaft",
    "rüpelhafterem": "rüpelhaft",
    "rüpelhafteren": "rüpelhaft",
    "rüpelhafterer": "rüpelhaft",
    "rüpelhafteres": "rüpelhaft",
    "rüpelhaftes": "rüpelhaft",
    "rüpelhafteste": "rüpelhaft",
    "rüpelhaftestem": "rüpelhaft",
    "rüpelhaftesten": "rüpelhaft",
    "rüpelhaftester": "rüpelhaft",
    "rüpelhaftestes": "rüpelhaft",
    "rüste": "rüsten",
    "rüstend": "rüsten",
    "rüstende": "rüstend",
    "rüstendem": "rüstend",
    "rüstenden": "rüstend",
    "rüstender": "rüstend",
    "rüstendere": "rüstend",
    "rüstenderem": "rüstend",
    "rüstenderen": "rüstend",
    "rüstenderer": "rüstend",
    "rüstenderes": "rüstend",
    "rüstendes": "rüstend",
    "rüstendste": "rüstend",
    "rüstendstem": "rüstend",
    "rüstendsten": "rüstend",
    "rüstendster": "rüstend",
    "rüstendstes": "rüstend",
    "rüstest": "rüsten",
    "rüstet": "rüsten",
    "rüstete": "rüsten",
    "rüsteten": "rüsten",
    "rüstetest": "rüsten",
    "rüstetet": "rüsten",
    "rüstige": "rüstig",
    "rüstigem": "rüstig",
    "rüstigen": "rüstig",
    "rüstiger": "rüstig",
    "rüstigere": "rüstig",
    "rüstigerem": "rüstig",
    "rüstigeren": "rüstig",
    "rüstigerer": "rüstig",
    "rüstigeres": "rüstig",
    "rüstiges": "rüstig",
    "rüstigste": "rüstig",
    "rüstigstem": "rüstig",
    "rüstigsten": "rüstig",
    "rüstigster": "rüstig",
    "rüstigstes": "rüstig",
    "rüttele": "rütteln",
    "rüttelnd": "rütteln",
    "rüttelnde": "rüttelnd",
    "rüttelndem": "rüttelnd",
    "rüttelnden": "rüttelnd",
    "rüttelnder": "rüttelnd",
    "rüttelndes": "rüttelnd",
    "rüttelst": "rütteln",
    "rüttelt": "rütteln",
    "rüttelte": "rütteln",
    "rüttelten": "rütteln",
    "rütteltest": "rütteln",
    "rütteltet": "rütteln",
    "rüttle": "rütteln",
    "saarländischem": "saarländisch",
    "saarländischen": "saarländisch",
    "saarländischer": "saarländisch",
    "saarländisches": "saarländisch",
    "sabbele": "sabbeln",
    "sabbelnd": "sabbeln",
    "sabbelnde": "sabbelnd",
    "sabbelndem": "sabbelnd",
    "sabbelnden": "sabbelnd",
    "sabbelnder": "sabbelnd",
    "sabbelndere": "sabbelnd",
    "sabbelnderem": "sabbelnd",
    "sabbelnderen": "sabbelnd",
    "sabbelnderer": "sabbelnd",
    "sabbelnderes": "sabbelnd",
    "sabbelndes": "sabbelnd",
    "sabbelndste": "sabbelnd",
    "sabbelndstem": "sabbelnd",
    "sabbelndsten": "sabbelnd",
    "sabbelndster": "sabbelnd",
    "sabbelndstes": "sabbelnd",
    "sabbelst": "sabbeln",
    "sabbelt": "sabbeln",
    "sabbelte": "sabbeln",
    "sabbelten": "sabbeln",
    "sabbeltest": "sabbeln",
    "sabbeltet": "sabbeln",
    "sabbere": "sabbern",
    "sabbernd": "sabbern",
    "sabbernde": "sabbernd",
    "sabberndem": "sabbernd",
    "sabbernden": "sabbernd",
    "sabbernder": "sabbernd",
    "sabberndere": "sabbernd",
    "sabbernderem": "sabbernd",
    "sabbernderen": "sabbernd",
    "sabbernderer": "sabbernd",
    "sabbernderes": "sabbernd",
    "sabberndes": "sabbernd",
    "sabberndste": "sabbernd",
    "sabberndstem": "sabbernd",
    "sabberndsten": "sabbernd",
    "sabberndster": "sabbernd",
    "sabberndstes": "sabbernd",
    "sabberst": "sabbern",
    "sabbert": "sabbern",
    "sabberte": "sabbern",
    "sabberten": "sabbern",
    "sabbertest": "sabbern",
    "sabbertet": "sabbern",
    "sabble": "sabbeln",
    "sabotiere": "sabotieren",
    "sabotierend": "sabotieren",
    "sabotierende": "sabotierend",
    "sabotierendem": "sabotierend",
    "sabotierenden": "sabotierend",
    "sabotierender": "sabotierend",
    "sabotierendes": "sabotierend",
    "sabotierest": "sabotieren",
    "sabotieret": "sabotieren",
    "sabotierst": "sabotieren",
    "sabotiert": "sabotieren",
    "sabotierte": "sabotieren",
    "sabotiertem": "sabotiert",
    "sabotierten": "sabotieren",
    "sabotierter": "sabotiert",
    "sabotiertes": "sabotiert",
    "sabotiertest": "sabotieren",
    "sabotiertet": "sabotieren",
    "sachdienlichem": "sachdienlich",
    "sachdienlichen": "sachdienlich",
    "sachdienlicher": "sachdienlich",
    "sachdienliches": "sachdienlich",
    "sachgemäßem": "sachgemäß",
    "sachgemäßen": "sachgemäß",
    "sachgemäßer": "sachgemäß",
    "sachgemäßes": "sachgemäß",
    "sachkundigem": "sachkundig",
    "sachkundigen": "sachkundig",
    "sachkundiger": "sachkundig",
    "sachkundigere": "sachkundig",
    "sachkundigerem": "sachkundig",
    "sachkundigeren": "sachkundig",
    "sachkundigerer": "sachkundig",
    "sachkundigeres": "sachkundig",
    "sachkundiges": "sachkundig",
    "sachkundigste": "sachkundig",
    "sachkundigstem": "sachkundig",
    "sachkundigsten": "sachkundig",
    "sachkundigster": "sachkundig",
    "sachkundigstes": "sachkundig",
    "sachliche": "sachlich",
    "sachlichem": "sachlich",
    "sachlichen": "sachlich",
    "sachlicher": "sachlich",
    "sachlichere": "sachlich",
    "sachlicherem": "sachlich",
    "sachlicheren": "sachlich",
    "sachlicherer": "sachlich",
    "sachlicheres": "sachlich",
    "sachliches": "sachlich",
    "sachlichste": "sachlich",
    "sachlichstem": "sachlich",
    "sachlichsten": "sachlich",
    "sachlichster": "sachlich",
    "sachlichstes": "sachlich",
    "sachtem": "sachte",
    "sachten": "sachte",
    "sachter": "sachte",
    "sachtes": "sachte",
    "sachverständigem": "sachverständig",
    "sachverständigen": "sachverständig",
    "sachverständiger": "sachverständig",
    "sachverständiges": "sachverständig",
    "sadistischem": "sadistisch",
    "sadistischen": "sadistisch",
    "sadistischer": "sadistisch",
    "sadistischere": "sadistisch",
    "sadistischerem": "sadistisch",
    "sadistischeren": "sadistisch",
    "sadistischerer": "sadistisch",
    "sadistischeres": "sadistisch",
    "sadistisches": "sadistisch",
    "sadistischste": "sadistisch",
    "sadistischstem": "sadistisch",
    "sadistischsten": "sadistisch",
    "sadistischster": "sadistisch",
    "sadistischstes": "sadistisch",
    "saftend": "saften",
    "saftende": "saftend",
    "saftendem": "saftend",
    "saftenden": "saftend",
    "saftender": "saftend",
    "saftendes": "saftend",
    "saftest": "saften",
    "saftet": "saften",
    "saftete": "saften",
    "safteten": "saften",
    "saftetest": "saften",
    "saftetet": "saften",
    "saftige": "saftig",
    "saftigem": "saftig",
    "saftigen": "saftig",
    "saftiger": "saftig",
    "saftigere": "saftig",
    "saftigerem": "saftig",
    "saftigeren": "saftig",
    "saftigerer": "saftig",
    "saftigeres": "saftig",
    "saftiges": "saftig",
    "saftigste": "saftig",
    "saftigstem": "saftig",
    "saftigsten": "saftig",
    "saftigster": "saftig",
    "saftigstes": "saftig",
    "saftlose": "saftlos",
    "saftlosem": "saftlos",
    "saftlosen": "saftlos",
    "saftloser": "saftlos",
    "saftlosere": "saftlos",
    "saftloserem": "saftlos",
    "saftloseren": "saftlos",
    "saftloserer": "saftlos",
    "saftloseres": "saftlos",
    "saftloses": "saftlos",
    "saftloseste": "saftlos",
    "saftlosestem": "saftlos",
    "saftlosesten": "saftlos",
    "saftlosester": "saftlos",
    "saftlosestes": "saftlos",
    "sagend": "sagen",
    "sagende": "sagend",
    "sagendem": "sagend",
    "sagenden": "sagend",
    "sagender": "sagend",
    "sagendes": "sagend",
    "sagenhafte": "sagenhaft",
    "sagenhaftem": "sagenhaft",
    "sagenhaften": "sagenhaft",
    "sagenhafter": "sagenhaft",
    "sagenhaftere": "sagenhaft",
    "sagenhafterem": "sagenhaft",
    "sagenhafteren": "sagenhaft",
    "sagenhafterer": "sagenhaft",
    "sagenhafteres": "sagenhaft",
    "sagenhaftes": "sagenhaft",
    "sagenhafteste": "sagenhaft",
    "sagenhaftestem": "sagenhaft",
    "sagenhaftesten": "sagenhaft",
    "sagenhaftester": "sagenhaft",
    "sagenhaftestes": "sagenhaft",
    "sagest": "sagen",
    "saget": "sagen",
    "sagst": "sagen",
    "sagt": "sagen",
    "sagte": "sagen",
    "sagten": "sagen",
    "sagtest": "sagen",
    "sagtet": "sagen",
    "sah": "sehen",
    "sahen": "sehen",
    "sahnend": "sahnen",
    "sahnende": "sahnend",
    "sahnendem": "sahnend",
    "sahnenden": "sahnend",
    "sahnender": "sahnend",
    "sahnendes": "sahnend",
    "sahnest": "sahnen",
    "sahnet": "sahnen",
    "sahnige": "sahnig",
    "sahnigem": "sahnig",
    "sahnigen": "sahnig",
    "sahniger": "sahnig",
    "sahnigere": "sahnig",
    "sahnigerem": "sahnig",
    "sahnigeren": "sahnig",
    "sahnigerer": "sahnig",
    "sahnigeres": "sahnig",
    "sahniges": "sahnig",
    "sahnigste": "sahnig",
    "sahnigstem": "sahnig",
    "sahnigsten": "sahnig",
    "sahnigster": "sahnig",
    "sahnigstes": "sahnig",
    "sahnst": "sahnen",
    "sahnt": "sahnen",
    "sahnte": "sahnen",
    "sahnten": "sahnen",
    "sahntest": "sahnen",
    "sahntet": "sahnen",
    "sahst": "sehen",
    "saht": "sehen",
    "sakralem": "sakral",
    "sakralen": "sakral",
    "sakraler": "sakral",
    "sakrales": "sakral",
    "sakramentale": "sakramental",
    "sakramentalem": "sakramental",
    "sakramentalen": "sakramental",
    "sakramentaler": "sakramental",
    "sakramentales": "sakramental",
    "salbend": "salben",
    "salbende": "salbend",
    "salbendem": "salbend",
    "salbenden": "salbend",
    "salbender": "salbend",
    "salbendes": "salbend",
    "salbest": "salben",
    "salbet": "salben",
    "salbst": "salben",
    "salbt": "salben",
    "salbte": "salben",
    "salbten": "salben",
    "salbtest": "salben",
    "salbtet": "salben",
    "salbungsvolle": "salbungsvoll",
    "salbungsvollem": "salbungsvoll",
    "salbungsvollen": "salbungsvoll",
    "salbungsvoller": "salbungsvoll",
    "salbungsvollere": "salbungsvoll",
    "salbungsvollerem": "salbungsvoll",
    "salbungsvolleren": "salbungsvoll",
    "salbungsvollerer": "salbungsvoll",
    "salbungsvolleres": "salbungsvoll",
    "salbungsvolles": "salbungsvoll",
    "salbungsvollste": "salbungsvoll",
    "salbungsvollstem": "salbungsvoll",
    "salbungsvollsten": "salbungsvoll",
    "salbungsvollster": "salbungsvoll",
    "salbungsvollstes": "salbungsvoll",
    "salischem": "salisch",
    "salischen": "salisch",
    "salischer": "salisch",
    "salisches": "salisch",
    "salomonischem": "salomonisch",
    "salomonischen": "salomonisch",
    "salomonischer": "salomonisch",
    "salomonisches": "salomonisch",
    "saloppem": "salopp",
    "saloppen": "salopp",
    "salopper": "salopp",
    "saloppere": "salopp",
    "salopperem": "salopp",
    "salopperen": "salopp",
    "salopperer": "salopp",
    "salopperes": "salopp",
    "saloppes": "salopp",
    "saloppste": "salopp",
    "saloppstem": "salopp",
    "saloppsten": "salopp",
    "saloppster": "salopp",
    "saloppstes": "salopp",
    "salutiere": "salutieren",
    "salutierend": "salutieren",
    "salutierende": "salutierend",
    "salutierendem": "salutierend",
    "salutierenden": "salutierend",
    "salutierender": "salutierend",
    "salutierendere": "salutierend",
    "salutierenderem": "salutierend",
    "salutierenderen": "salutierend",
    "salutierenderer": "salutierend",
    "salutierenderes": "salutierend",
    "salutierendes": "salutierend",
    "salutierendste": "salutierend",
    "salutierendstem": "salutierend",
    "salutierendsten": "salutierend",
    "salutierendster": "salutierend",
    "salutierendstes": "salutierend",
    "salutierest": "salutieren",
    "salutieret": "salutieren",
    "salutierst": "salutieren",
    "salutiert": "salutieren",
    "salutierte": "salutieren",
    "salutiertem": "salutiert",
    "salutierten": "salutieren",
    "salutierter": "salutiert",
    "salutiertes": "salutiert",
    "salutiertest": "salutieren",
    "salutiertet": "salutieren",
    "salzend": "salzen",
    "salzende": "salzend",
    "salzendem": "salzend",
    "salzenden": "salzend",
    "salzender": "salzend",
    "salzendes": "salzend",
    "salzest": "salzen",
    "salzet": "salzen",
    "salzigem": "salzig",
    "salzigen": "salzig",
    "salziger": "salzig",
    "salzigere": "salzig",
    "salzigerem": "salzig",
    "salzigeren": "salzig",
    "salzigerer": "salzig",
    "salzigeres": "salzig",
    "salziges": "salzig",
    "salzigste": "salzig",
    "salzigstem": "salzig",
    "salzigsten": "salzig",
    "salzigster": "salzig",
    "salzigstes": "salzig",
    "salzlosem": "salzlos",
    "salzlosen": "salzlos",
    "salzloser": "salzlos",
    "salzlosere": "salzlos",
    "salzloserem": "salzlos",
    "salzloseren": "salzlos",
    "salzloserer": "salzlos",
    "salzloseres": "salzlos",
    "salzloses": "salzlos",
    "salzloseste": "salzlos",
    "salzlosestem": "salzlos",
    "salzlosesten": "salzlos",
    "salzlosester": "salzlos",
    "salzlosestes": "salzlos",
    "salzt": "salzen",
    "salzte": "salzen",
    "salzten": "salzen",
    "salztest": "salzen",
    "salztet": "salzen",
    "samaritanischem": "samaritanisch",
    "samaritanischen": "samaritanisch",
    "samaritanischer": "samaritanisch",
    "samaritanisches": "samaritanisch",
    "same": "samen",
    "samend": "samen",
    "samende": "samend",
    "samendem": "samend",
    "samenden": "samend",
    "samender": "samend",
    "samendes": "samend",
    "samest": "samen",
    "samet": "samen",
    "sammele": "sammeln",
    "sammelnd": "sammeln",
    "sammelnde": "sammelnd",
    "sammelndem": "sammelnd",
    "sammelnden": "sammelnd",
    "sammelnder": "sammelnd",
    "sammelndes": "sammelnd",
    "sammelst": "sammeln",
    "sammelt": "sammeln",
    "sammelte": "sammeln",
    "sammelten": "sammeln",
    "sammeltest": "sammeln",
    "sammeltet": "sammeln",
    "sammle": "sammeln",
    "samst": "samen",
    "samte": "samen",
    "samten": "samen",
    "samtest": "samen",
    "samtet": "samen",
    "samtigem": "samtig",
    "samtigen": "samtig",
    "samtiger": "samtig",
    "samtigere": "samtig",
    "samtigerem": "samtig",
    "samtigeren": "samtig",
    "samtigerer": "samtig",
    "samtigeres": "samtig",
    "samtiges": "samtig",
    "samtigste": "samtig",
    "samtigstem": "samtig",
    "samtigsten": "samtig",
    "samtigster": "samtig",
    "samtigstes": "samtig",
    "samtweichem": "samtweich",
    "samtweichen": "samtweich",
    "samtweicher": "samtweich",
    "samtweiches": "samtweich",
    "sandfarbenem": "sandfarben",
    "sandfarbenen": "sandfarben",
    "sandfarbener": "sandfarben",
    "sandfarbenes": "sandfarben",
    "sandige": "sandig",
    "sandigem": "sandig",
    "sandigen": "sandig",
    "sandiger": "sandig",
    "sandigere": "sandig",
    "sandigerem": "sandig",
    "sandigeren": "sandig",
    "sandigerer": "sandig",
    "sandigeres": "sandig",
    "sandiges": "sandig",
    "sandigste": "sandig",
    "sandigstem": "sandig",
    "sandigsten": "sandig",
    "sandigster": "sandig",
    "sandigstes": "sandig",
    "sandte": "senden",
    "sandten": "senden",
    "sandtest": "senden",
    "sandtet": "senden",
    "sanftem": "sanft",
    "sanften": "sanft",
    "sanfter": "sanft",
    "sanftere": "sanft",
    "sanfterem": "sanft",
    "sanfteren": "sanft",
    "sanfterer": "sanft",
    "sanfteres": "sanft",
    "sanftes": "sanft",
    "sanfteste": "sanft",
    "sanftestem": "sanft",
    "sanftesten": "sanft",
    "sanftester": "sanft",
    "sanftestes": "sanft",
    "sanftmütigem": "sanftmütig",
    "sanftmütigen": "sanftmütig",
    "sanftmütiger": "sanftmütig",
    "sanftmütigere": "sanftmütig",
    "sanftmütigerem": "sanftmütig",
    "sanftmütigeren": "sanftmütig",
    "sanftmütigerer": "sanftmütig",
    "sanftmütigeres": "sanftmütig",
    "sanftmütiges": "sanftmütig",
    "sanftmütigste": "sanftmütig",
    "sanftmütigstem": "sanftmütig",
    "sanftmütigsten": "sanftmütig",
    "sanftmütigster": "sanftmütig",
    "sanftmütigstes": "sanftmütig",
    "sang": "singen",
    "sangen": "singen",
    "sangeslustigem": "sangeslustig",
    "sangeslustigen": "sangeslustig",
    "sangeslustiger": "sangeslustig",
    "sangeslustigere": "sangeslustig",
    "sangeslustigerem": "sangeslustig",
    "sangeslustigeren": "sangeslustig",
    "sangeslustigerer": "sangeslustig",
    "sangeslustigeres": "sangeslustig",
    "sangeslustiges": "sangeslustig",
    "sangeslustigste": "sangeslustig",
    "sangeslustigstem": "sangeslustig",
    "sangeslustigsten": "sangeslustig",
    "sangeslustigster": "sangeslustig",
    "sangeslustigstes": "sangeslustig",
    "sangliche": "sanglich",
    "sanglichem": "sanglich",
    "sanglichen": "sanglich",
    "sanglicher": "sanglich",
    "sangliches": "sanglich",
    "sangst": "singen",
    "sangt": "singen",
    "saniere": "sanieren",
    "sanierend": "sanieren",
    "sanierende": "sanierend",
    "sanierendem": "sanierend",
    "sanierenden": "sanierend",
    "sanierender": "sanierend",
    "sanierendes": "sanierend",
    "sanierest": "sanieren",
    "sanieret": "sanieren",
    "sanierst": "sanieren",
    "saniert": "sanieren",
    "sanierte": "sanieren",
    "saniertem": "saniert",
    "sanierten": "sanieren",
    "sanierter": "saniert",
    "saniertes": "saniert",
    "saniertest": "sanieren",
    "saniertet": "sanieren",
    "sanitärem": "sanitär",
    "sanitären": "sanitär",
    "sanitärer": "sanitär",
    "sanitäres": "sanitär",
    "sanitätsdienstliche": "sanitätsdienstlich",
    "sanitätsdienstlichem": "sanitätsdienstlich",
    "sanitätsdienstlichen": "sanitätsdienstlich",
    "sanitätsdienstlicher": "sanitätsdienstlich",
    "sanitätsdienstliches": "sanitätsdienstlich",
    "sank": "sinken",
    "sanken": "sinken",
    "sankst": "sinken",
    "sankt": "sinken",
    "sanktionierend": "sanktionieren",
    "sanktionierende": "sanktionierend",
    "sanktionierendem": "sanktionierend",
    "sanktionierenden": "sanktionierend",
    "sanktionierender": "sanktionierend",
    "sanktionierendere": "sanktionierend",
    "sanktionierenderem": "sanktionierend",
    "sanktionierenderen": "sanktionierend",
    "sanktionierenderer": "sanktionierend",
    "sanktionierenderes": "sanktionierend",
    "sanktionierendes": "sanktionierend",
    "sanktionierendste": "sanktionierend",
    "sanktionierendstem": "sanktionierend",
    "sanktionierendsten": "sanktionierend",
    "sanktionierendster": "sanktionierend",
    "sanktionierendstes": "sanktionierend",
    "sanktionierest": "sanktionieren",
    "sanktionieret": "sanktionieren",
    "sanktionierst": "sanktionieren",
    "sanktioniert": "sanktionieren",
    "sanktionierte": "sanktionieren",
    "sanktioniertem": "sanktioniert",
    "sanktionierten": "sanktionieren",
    "sanktionierter": "sanktioniert",
    "sanktioniertere": "sanktioniert",
    "sanktionierterem": "sanktioniert",
    "sanktionierteren": "sanktioniert",
    "sanktionierterer": "sanktioniert",
    "sanktionierteres": "sanktioniert",
    "sanktioniertes": "sanktioniert",
    "sanktioniertest": "sanktionieren",
    "sanktionierteste": "sanktioniert",
    "sanktioniertestem": "sanktioniert",
    "sanktioniertesten": "sanktioniert",
    "sanktioniertester": "sanktioniert",
    "sanktioniertestes": "sanktioniert",
    "sanktioniertet": "sanktionieren",
    "sann": "sinnen",
    "sannen": "sinnen",
    "sannst": "sinnen",
    "sannt": "sinnen",
    "sardinischem": "sardinisch",
    "sardinischen": "sardinisch",
    "sardinischer": "sardinisch",
    "sardinisches": "sardinisch",
    "sargend": "sargen",
    "sargende": "sargend",
    "sargendem": "sargend",
    "sargenden": "sargend",
    "sargender": "sargend",
    "sargendes": "sargend",
    "sargest": "sargen",
    "sarget": "sargen",
    "sargst": "sargen",
    "sargt": "sargen",
    "sargte": "sargen",
    "sargten": "sargen",
    "sargtest": "sargen",
    "sargtet": "sargen",
    "sarkastische": "sarkastisch",
    "sarkastischem": "sarkastisch",
    "sarkastischen": "sarkastisch",
    "sarkastischer": "sarkastisch",
    "sarkastischere": "sarkastisch",
    "sarkastischerem": "sarkastisch",
    "sarkastischeren": "sarkastisch",
    "sarkastischerer": "sarkastisch",
    "sarkastischeres": "sarkastisch",
    "sarkastisches": "sarkastisch",
    "sarkastischste": "sarkastisch",
    "sarkastischstem": "sarkastisch",
    "sarkastischsten": "sarkastisch",
    "sarkastischster": "sarkastisch",
    "sarkastischstes": "sarkastisch",
    "satanische": "satanisch",
    "satanischem": "satanisch",
    "satanischen": "satanisch",
    "satanischer": "satanisch",
    "satanisches": "satanisch",
    "satirischem": "satirisch",
    "satirischen": "satirisch",
    "satirischer": "satirisch",
    "satirischere": "satirisch",
    "satirischerem": "satirisch",
    "satirischeren": "satirisch",
    "satirischerer": "satirisch",
    "satirischeres": "satirisch",
    "satirisches": "satirisch",
    "satirischste": "satirisch",
    "satirischstem": "satirisch",
    "satirischsten": "satirisch",
    "satirischster": "satirisch",
    "satirischstes": "satirisch",
    "sattele": "satteln",
    "sattelfeste": "sattelfest",
    "sattelfestem": "sattelfest",
    "sattelfesten": "sattelfest",
    "sattelfester": "sattelfest",
    "sattelfestere": "sattelfest",
    "sattelfesterem": "sattelfest",
    "sattelfesteren": "sattelfest",
    "sattelfesterer": "sattelfest",
    "sattelfesteres": "sattelfest",
    "sattelfestes": "sattelfest",
    "sattelfesteste": "sattelfest",
    "sattelfestestem": "sattelfest",
    "sattelfestesten": "sattelfest",
    "sattelfestester": "sattelfest",
    "sattelfestestes": "sattelfest",
    "sattelnd": "satteln",
    "sattelnde": "sattelnd",
    "sattelndem": "sattelnd",
    "sattelnden": "sattelnd",
    "sattelnder": "sattelnd",
    "sattelndes": "sattelnd",
    "sattelst": "satteln",
    "sattelt": "satteln",
    "sattelte": "satteln",
    "sattelten": "satteln",
    "satteltest": "satteln",
    "satteltet": "satteln",
    "sattem": "satt",
    "satten": "satt",
    "satter": "satt",
    "sattere": "satt",
    "satterem": "satt",
    "satteren": "satt",
    "satterer": "satt",
    "satteres": "satt",
    "sattes": "satt",
    "satteste": "satt",
    "sattestem": "satt",
    "sattesten": "satt",
    "sattester": "satt",
    "sattestes": "satt",
    "sattle": "satteln",
    "saturiere": "saturieren",
    "saturierend": "saturieren",
    "saturierende": "saturierend",
    "saturierendem": "saturierend",
    "saturierenden": "saturierend",
    "saturierender": "saturierend",
    "saturierendere": "saturierend",
    "saturierenderem": "saturierend",
    "saturierenderen": "saturierend",
    "saturierenderer": "saturierend",
    "saturierenderes": "saturierend",
    "saturierendes": "saturierend",
    "saturierendste": "saturierend",
    "saturierendstem": "saturierend",
    "saturierendsten": "saturierend",
    "saturierendster": "saturierend",
    "saturierendstes": "saturierend",
    "saturierest": "saturieren",
    "saturieret": "saturieren",
    "saturierst": "saturieren",
    "saturiert": "saturieren",
    "saturierte": "saturieren",
    "saturiertem": "saturiert",
    "saturierten": "saturieren",
    "saturierter": "saturiert",
    "saturiertere": "saturiert",
    "saturierterem": "saturiert",
    "saturierteren": "saturiert",
    "saturierterer": "saturiert",
    "saturierteres": "saturiert",
    "saturiertes": "saturiert",
    "saturiertest": "saturieren",
    "saturierteste": "saturiert",
    "saturiertestem": "saturiert",
    "saturiertesten": "saturiert",
    "saturiertester": "saturiert",
    "saturiertestes": "saturiert",
    "saturiertet": "saturieren",
    "satzungsgemäßem": "satzungsgemäß",
    "satzungsgemäßen": "satzungsgemäß",
    "satzungsgemäßer": "satzungsgemäß",
    "satzungsgemäßes": "satzungsgemäß",
    "sauberem": "sauber",
    "sauberen": "sauber",
    "sauberer": "sauber",
    "sauberere": "sauber",
    "saubererem": "sauber",
    "saubereren": "sauber",
    "saubererer": "sauber",
    "saubereres": "sauber",
    "sauberes": "sauber",
    "saubergehalten": "sauberhalten",
    "saubergehaltene": "saubergehalten",
    "saubergehaltenem": "saubergehalten",
    "saubergehaltenen": "saubergehalten",
    "saubergehaltener": "saubergehalten",
    "saubergehaltenere": "saubergehalten",
    "saubergehaltenerem": "saubergehalten",
    "saubergehalteneren": "saubergehalten",
    "saubergehaltenerer": "saubergehalten",
    "saubergehalteneres": "saubergehalten",
    "saubergehaltenes": "saubergehalten",
    "saubergehaltenste": "saubergehalten",
    "saubergehaltenstem": "saubergehalten",
    "saubergehaltensten": "saubergehalten",
    "saubergehaltenster": "saubergehalten",
    "saubergehaltenstes": "saubergehalten",
    "sauberhalte": "sauberhalten",
    "sauberhaltend": "sauberhalten",
    "sauberhaltende": "sauberhaltend",
    "sauberhaltendem": "sauberhaltend",
    "sauberhaltenden": "sauberhaltend",
    "sauberhaltender": "sauberhaltend",
    "sauberhaltendere": "sauberhaltend",
    "sauberhaltenderem": "sauberhaltend",
    "sauberhaltenderen": "sauberhaltend",
    "sauberhaltenderer": "sauberhaltend",
    "sauberhaltenderes": "sauberhaltend",
    "sauberhaltendes": "sauberhaltend",
    "sauberhaltendste": "sauberhaltend",
    "sauberhaltendstem": "sauberhaltend",
    "sauberhaltendsten": "sauberhaltend",
    "sauberhaltendster": "sauberhaltend",
    "sauberhaltendstes": "sauberhaltend",
    "sauberhaltest": "sauberhalten",
    "sauberhaltet": "sauberhalten",
    "sauberhielt": "sauberhalten",
    "sauberhielte": "sauberhalten",
    "sauberhielten": "sauberhalten",
    "sauberhieltest": "sauberhalten",
    "sauberhieltet": "sauberhalten",
    "sauberhält": "sauberhalten",
    "sauberhältst": "sauberhalten",
    "sauberstem": "sauber",
    "saubersten": "sauber",
    "sauberster": "sauber",
    "sauberstes": "sauber",
    "sauberzuhalten": "sauberhalten",
    "saublöde": "saublöd",
    "saublödem": "saublöd",
    "saublöden": "saublöd",
    "saublöder": "saublöd",
    "saublödes": "saublöd",
    "saudummem": "saudumm",
    "saudummen": "saudumm",
    "saudummer": "saudumm",
    "saudummes": "saudumm",
    "saue": "sauen",
    "sauend": "sauen",
    "sauende": "sauend",
    "sauendem": "sauend",
    "sauenden": "sauend",
    "sauender": "sauend",
    "sauendere": "sauend",
    "sauenderem": "sauend",
    "sauenderen": "sauend",
    "sauenderer": "sauend",
    "sauenderes": "sauend",
    "sauendes": "sauend",
    "sauendste": "sauend",
    "sauendstem": "sauend",
    "sauendsten": "sauend",
    "sauendster": "sauend",
    "sauendstes": "sauend",
    "sauer": "sauern",
    "sauere": "sauern",
    "sauernd": "sauern",
    "sauernde": "sauernd",
    "sauerndem": "sauernd",
    "sauernden": "sauernd",
    "sauernder": "sauernd",
    "sauerndere": "sauernd",
    "sauernderem": "sauernd",
    "sauernderen": "sauernd",
    "sauernderer": "sauernd",
    "sauernderes": "sauernd",
    "sauerndes": "sauernd",
    "sauerndste": "sauernd",
    "sauerndstem": "sauernd",
    "sauerndsten": "sauernd",
    "sauerndster": "sauernd",
    "sauerndstes": "sauernd",
    "sauerst": "sauern",
    "sauerste": "sauer",
    "sauerstem": "sauer",
    "sauersten": "sauer",
    "sauerster": "sauer",
    "sauerstes": "sauer",
    "sauersüßem": "sauersüß",
    "sauersüßen": "sauersüß",
    "sauersüßer": "sauersüß",
    "sauersüßes": "sauersüß",
    "sauert": "sauern",
    "sauerte": "sauern",
    "sauerten": "sauern",
    "sauertest": "sauern",
    "sauertet": "sauern",
    "sauest": "sauen",
    "sauet": "sauen",
    "saufe": "saufen",
    "saufend": "saufen",
    "saufende": "saufend",
    "saufendem": "saufend",
    "saufenden": "saufend",
    "saufender": "saufend",
    "saufendere": "saufend",
    "saufenderem": "saufend",
    "saufenderen": "saufend",
    "saufenderer": "saufend",
    "saufenderes": "saufend",
    "saufendes": "saufend",
    "saufendste": "saufend",
    "saufendstem": "saufend",
    "saufendsten": "saufend",
    "saufendster": "saufend",
    "saufendstes": "saufend",
    "saufest": "saufen",
    "saufet": "saufen",
    "sauft": "saufen",
    "saugbohnere": "saugbohnern",
    "saugbohnernd": "saugbohnern",
    "saugbohnernde": "saugbohnernd",
    "saugbohnerndem": "saugbohnernd",
    "saugbohnernden": "saugbohnernd",
    "saugbohnernder": "saugbohnernd",
    "saugbohnerndes": "saugbohnernd",
    "saugbohnerst": "saugbohnern",
    "saugbohnert": "saugbohnern",
    "saugbohnerte": "saugbohnern",
    "saugbohnerten": "saugbohnern",
    "saugbohnertest": "saugbohnern",
    "saugbohnertet": "saugbohnern",
    "sauge": "saugen",
    "saugend": "saugen",
    "saugende": "saugend",
    "saugendem": "saugend",
    "saugenden": "saugend",
    "saugender": "saugend",
    "saugendes": "saugend",
    "saugest": "saugen",
    "sauget": "saugen",
    "saugfähigem": "saugfähig",
    "saugfähigen": "saugfähig",
    "saugfähiger": "saugfähig",
    "saugfähigere": "saugfähig",
    "saugfähigerem": "saugfähig",
    "saugfähigeren": "saugfähig",
    "saugfähigerer": "saugfähig",
    "saugfähigeres": "saugfähig",
    "saugfähiges": "saugfähig",
    "saugfähigste": "saugfähig",
    "saugfähigstem": "saugfähig",
    "saugfähigsten": "saugfähig",
    "saugfähigster": "saugfähig",
    "saugfähigstes": "saugfähig",
    "saugkräftigem": "saugkräftig",
    "saugkräftigen": "saugkräftig",
    "saugkräftiger": "saugkräftig",
    "saugkräftigere": "saugkräftig",
    "saugkräftigerem": "saugkräftig",
    "saugkräftigeren": "saugkräftig",
    "saugkräftigerer": "saugkräftig",
    "saugkräftigeres": "saugkräftig",
    "saugkräftiges": "saugkräftig",
    "saugkräftigste": "saugkräftig",
    "saugkräftigstem": "saugkräftig",
    "saugkräftigsten": "saugkräftig",
    "saugkräftigster": "saugkräftig",
    "saugkräftigstes": "saugkräftig",
    "saugst": "saugen",
    "saugt": "saugen",
    "saugte": "saugen",
    "saugten": "saugen",
    "saugtest": "saugen",
    "saugtet": "saugen",
    "saukomische": "saukomisch",
    "saukomischem": "saukomisch",
    "saukomischen": "saukomisch",
    "saukomischer": "saukomisch",
    "saukomisches": "saukomisch",
    "saumäßigem": "saumäßig",
    "saumäßigen": "saumäßig",
    "saumäßiger": "saumäßig",
    "saumäßiges": "saumäßig",
    "saune": "saunen",
    "saunend": "saunen",
    "saunende": "saunend",
    "saunendem": "saunend",
    "saunenden": "saunend",
    "saunender": "saunend",
    "saunendes": "saunend",
    "saunest": "saunen",
    "saunet": "saunen",
    "saunst": "saunen",
    "saunt": "saunen",
    "saunte": "saunen",
    "saunten": "saunen",
    "sauntest": "saunen",
    "sauntet": "saunen",
    "saure": "sauer",
    "saurem": "sauer",
    "sauren": "sauer",
    "saurer": "sauer",
    "saurere": "sauer",
    "saurerem": "sauer",
    "saureren": "sauer",
    "saurerer": "sauer",
    "saureres": "sauer",
    "saures": "sauer",
    "sause": "sausen",
    "sausend": "sausen",
    "sausende": "sausend",
    "sausendem": "sausend",
    "sausenden": "sausend",
    "sausender": "sausend",
    "sausendere": "sausend",
    "sausenderem": "sausend",
    "sausenderen": "sausend",
    "sausenderer": "sausend",
    "sausenderes": "sausend",
    "sausendes": "sausend",
    "sausendste": "sausend",
    "sausendstem": "sausend",
    "sausendsten": "sausend",
    "sausendster": "sausend",
    "sausendstes": "sausend",
    "sausest": "sausen",
    "sauset": "sausen",
    "saust": "sausen",
    "sauste": "sausen",
    "sausten": "sausen",
    "saustest": "sausen",
    "saustet": "sausen",
    "saut": "sauen",
    "saute": "sauen",
    "sauten": "sauen",
    "sautest": "sauen",
    "sautet": "sauen",
    "saß": "sitzen",
    "saßen": "sitzen",
    "saßt": "sitzen",
    "schabe": "schaben",
    "schabend": "schaben",
    "schabende": "schabend",
    "schabendem": "schabend",
    "schabenden": "schabend",
    "schabender": "schabend",
    "schabendes": "schabend",
    "schabest": "schaben",
    "schabet": "schaben",
    "schabst": "schaben",
    "schabt": "schaben",
    "schabte": "schaben",
    "schabten": "schaben",
    "schabtest": "schaben",
    "schabtet": "schaben",
    "schachbrettartige": "schachbrettartig",
    "schachbrettartigem": "schachbrettartig",
    "schachbrettartigen": "schachbrettartig",
    "schachbrettartiger": "schachbrettartig",
    "schachbrettartiges": "schachbrettartig",
    "schachere": "schachern",
    "schachernd": "schachern",
    "schachernde": "schachernd",
    "schacherndem": "schachernd",
    "schachernden": "schachernd",
    "schachernder": "schachernd",
    "schacherndes": "schachernd",
    "schacherst": "schachern",
    "schachert": "schachern",
    "schacherte": "schachern",
    "schacherten": "schachern",
    "schachertest": "schachern",
    "schachertet": "schachern",
    "schachtele": "schachteln",
    "schachtelnd": "schachteln",
    "schachtelnde": "schachtelnd",
    "schachtelndem": "schachtelnd",
    "schachtelnden": "schachtelnd",
    "schachtelnder": "schachtelnd",
    "schachtelndere": "schachtelnd",
    "schachtelnderem": "schachtelnd",
    "schachtelnderen": "schachtelnd",
    "schachtelnderer": "schachtelnd",
    "schachtelnderes": "schachtelnd",
    "schachtelndes": "schachtelnd",
    "schachtelndste": "schachtelnd",
    "schachtelndstem": "schachtelnd",
    "schachtelndsten": "schachtelnd",
    "schachtelndster": "schachtelnd",
    "schachtelndstes": "schachtelnd",
    "schachtelst": "schachteln",
    "schachtelt": "schachteln",
    "schachtelte": "schachteln",
    "schachtelten": "schachteln",
    "schachteltest": "schachteln",
    "schachteltet": "schachteln",
    "schachtend": "schachten",
    "schachtende": "schachtend",
    "schachtendem": "schachtend",
    "schachtenden": "schachtend",
    "schachtender": "schachtend",
    "schachtendes": "schachtend",
    "schachtest": "schachten",
    "schachtet": "schachten",
    "schachtete": "schachten",
    "schachteten": "schachten",
    "schachtetest": "schachten",
    "schachtetet": "schachten",
    "schachtle": "schachteln",
    "schade": "schaden",
    "schadend": "schaden",
    "schadende": "schadend",
    "schadendem": "schadend",
    "schadenden": "schadend",
    "schadender": "schadend",
    "schadendere": "schadend",
    "schadenderem": "schadend",
    "schadenderen": "schadend",
    "schadenderer": "schadend",
    "schadenderes": "schadend",
    "schadendes": "schadend",
    "schadendste": "schadend",
    "schadendstem": "schadend",
    "schadendsten": "schadend",
    "schadendster": "schadend",
    "schadendstes": "schadend",
    "schadenfrohe": "schadenfroh",
    "schadenfrohem": "schadenfroh",
    "schadenfrohen": "schadenfroh",
    "schadenfroher": "schadenfroh",
    "schadenfrohere": "schadenfroh",
    "schadenfroherem": "schadenfroh",
    "schadenfroheren": "schadenfroh",
    "schadenfroherer": "schadenfroh",
    "schadenfroheres": "schadenfroh",
    "schadenfrohes": "schadenfroh",
    "schadenfroheste": "schadenfroh",
    "schadenfrohestem": "schadenfroh",
    "schadenfrohesten": "schadenfroh",
    "schadenfrohester": "schadenfroh",
    "schadenfrohestes": "schadenfroh",
    "schadest": "schaden",
    "schadet": "schaden",
    "schadete": "schaden",
    "schadeten": "schaden",
    "schadetest": "schaden",
    "schadetet": "schaden",
    "schadhafte": "schadhaft",
    "schadhaftem": "schadhaft",
    "schadhaften": "schadhaft",
    "schadhafter": "schadhaft",
    "schadhaftere": "schadhaft",
    "schadhafterem": "schadhaft",
    "schadhafteren": "schadhaft",
    "schadhafterer": "schadhaft",
    "schadhafteres": "schadhaft",
    "schadhaftes": "schadhaft",
    "schadhafteste": "schadhaft",
    "schadhaftestem": "schadhaft",
    "schadhaftesten": "schadhaft",
    "schadhaftester": "schadhaft",
    "schadhaftestes": "schadhaft",
    "schadstoffarmem": "schadstoffarm",
    "schadstoffarmen": "schadstoffarm",
    "schadstoffarmer": "schadstoffarm",
    "schadstoffarmes": "schadstoffarm",
    "schadstoffärmer": "schadstoffarm",
    "schadstoffärmere": "schadstoffarm",
    "schadstoffärmerem": "schadstoffarm",
    "schadstoffärmeren": "schadstoffarm",
    "schadstoffärmerer": "schadstoffarm",
    "schadstoffärmeres": "schadstoffarm",
    "schadstoffärmsten": "schadstoffarm",
    "schaffe": "schaffen",
    "schaffend": "schaffen",
    "schaffende": "schaffend",
    "schaffendem": "schaffend",
    "schaffenden": "schaffend",
    "schaffender": "schaffend",
    "schaffendes": "schaffend",
    "schaffest": "schaffen",
    "schaffet": "schaffen",
    "schaffst": "schaffen",
    "schafft": "schaffen",
    "schaffte": "schaffen",
    "schafften": "schaffen",
    "schafftest": "schaffen",
    "schafftet": "schaffen",
    "schalend": "schalen",
    "schalende": "schalend",
    "schalendem": "schalend",
    "schalenden": "schalend",
    "schalender": "schalend",
    "schalendes": "schalend",
    "schalest": "schalen",
    "schalet": "schalen",
    "schalkhaftem": "schalkhaft",
    "schalkhaften": "schalkhaft",
    "schalkhafter": "schalkhaft",
    "schalkhaftere": "schalkhaft",
    "schalkhafterem": "schalkhaft",
    "schalkhafteren": "schalkhaft",
    "schalkhafterer": "schalkhaft",
    "schalkhafteres": "schalkhaft",
    "schalkhaftes": "schalkhaft",
    "schalkhafteste": "schalkhaft",
    "schalkhaftestem": "schalkhaft",
    "schalkhaftesten": "schalkhaft",
    "schalkhaftester": "schalkhaft",
    "schalkhaftestes": "schalkhaft",
    "schalldichtem": "schalldicht",
    "schalldichten": "schalldicht",
    "schalldichter": "schalldicht",
    "schalldichtere": "schalldicht",
    "schalldichterem": "schalldicht",
    "schalldichteren": "schalldicht",
    "schalldichterer": "schalldicht",
    "schalldichteres": "schalldicht",
    "schalldichtes": "schalldicht",
    "schalldichteste": "schalldicht",
    "schalldichtestem": "schalldicht",
    "schalldichtesten": "schalldicht",
    "schalldichtester": "schalldicht",
    "schalldichtestes": "schalldicht",
    "schalle": "schallen",
    "schallend": "schallen",
    "schallende": "schallend",
    "schallendem": "schallend",
    "schallenden": "schallend",
    "schallender": "schallend",
    "schallendere": "schallend",
    "schallenderem": "schallend",
    "schallenderen": "schallend",
    "schallenderer": "schallend",
    "schallenderes": "schallend",
    "schallendes": "schallend",
    "schallendste": "schallend",
    "schallendstem": "schallend",
    "schallendsten": "schallend",
    "schallendster": "schallend",
    "schallendstes": "schallend",
    "schallest": "schallen",
    "schallet": "schallen",
    "schallsicherem": "schallsicher",
    "schallsicheren": "schallsicher",
    "schallsicherer": "schallsicher",
    "schallsicherere": "schallsicher",
    "schallsichererem": "schallsicher",
    "schallsichereren": "schallsicher",
    "schallsichererer": "schallsicher",
    "schallsichereres": "schallsicher",
    "schallsicheres": "schallsicher",
    "schallsicherste": "schallsicher",
    "schallsicherstem": "schallsicher",
    "schallsichersten": "schallsicher",
    "schallsicherster": "schallsicher",
    "schallsicherstes": "schallsicher",
    "schallst": "schallen",
    "schallt": "schallen",
    "schallte": "schallen",
    "schallten": "schallen",
    "schalltest": "schallen",
    "schalltet": "schallen",
    "schalst": "schalen",
    "schalt": "schelten",
    "schalte": "schalten",
    "schalten": "schalen",
    "schaltend": "schalten",
    "schaltende": "schaltend",
    "schaltendem": "schaltend",
    "schaltenden": "schaltend",
    "schaltender": "schaltend",
    "schaltendes": "schaltend",
    "schaltest": "schelten",
    "schaltet": "schelten",
    "schaltete": "schalten",
    "schalteten": "schalten",
    "schaltetest": "schalten",
    "schaltetet": "schalten",
    "schamhaftem": "schamhaft",
    "schamhaften": "schamhaft",
    "schamhafter": "schamhaft",
    "schamhaftere": "schamhaft",
    "schamhafterem": "schamhaft",
    "schamhafteren": "schamhaft",
    "schamhafterer": "schamhaft",
    "schamhafteres": "schamhaft",
    "schamhaftes": "schamhaft",
    "schamhafteste": "schamhaft",
    "schamhaftestem": "schamhaft",
    "schamhaftesten": "schamhaft",
    "schamhaftester": "schamhaft",
    "schamhaftestes": "schamhaft",
    "schamlosem": "schamlos",
    "schamlosen": "schamlos",
    "schamloser": "schamlos",
    "schamlosere": "schamlos",
    "schamloserem": "schamlos",
    "schamloseren": "schamlos",
    "schamloserer": "schamlos",
    "schamloseres": "schamlos",
    "schamloses": "schamlos",
    "schamloseste": "schamlos",
    "schamlosestem": "schamlos",
    "schamlosesten": "schamlos",
    "schamlosester": "schamlos",
    "schamlosestes": "schamlos",
    "schamponiere": "schamponieren",
    "schamponierend": "schamponieren",
    "schamponierende": "schamponierend",
    "schamponierendem": "schamponierend",
    "schamponierenden": "schamponierend",
    "schamponierender": "schamponierend",
    "schamponierendes": "schamponierend",
    "schamponierest": "schamponieren",
    "schamponieret": "schamponieren",
    "schamponierst": "schamponieren",
    "schamponiert": "schamponieren",
    "schamponierte": "schamponieren",
    "schamponiertem": "schamponiert",
    "schamponierten": "schamponieren",
    "schamponierter": "schamponiert",
    "schamponiertes": "schamponiert",
    "schamponiertest": "schamponieren",
    "schamponiertet": "schamponieren",
    "schanzend": "schanzen",
    "schanzende": "schanzend",
    "schanzendem": "schanzend",
    "schanzenden": "schanzend",
    "schanzender": "schanzend",
    "schanzendes": "schanzend",
    "schanzest": "schanzen",
    "schanzet": "schanzen",
    "schanzt": "schanzen",
    "schanzte": "schanzen",
    "schanzten": "schanzen",
    "schanztest": "schanzen",
    "schanztet": "schanzen",
    "schare": "scharen",
    "scharend": "scharen",
    "scharende": "scharend",
    "scharendem": "scharend",
    "scharenden": "scharend",
    "scharender": "scharend",
    "scharendes": "scharend",
    "scharest": "scharen",
    "scharet": "scharen",
    "scharfe": "scharf",
    "scharfem": "scharf",
    "scharfen": "scharf",
    "scharfer": "scharf",
    "scharfes": "scharf",
    "scharfgestellt": "scharfstellen",
    "scharfgestellte": "scharfgestellt",
    "scharfgestelltem": "scharfgestellt",
    "scharfgestellten": "scharfgestellt",
    "scharfgestellter": "scharfgestellt",
    "scharfgestelltere": "scharfgestellt",
    "scharfgestellterem": "scharfgestellt",
    "scharfgestellteren": "scharfgestellt",
    "scharfgestellterer": "scharfgestellt",
    "scharfgestellteres": "scharfgestellt",
    "scharfgestelltes": "scharfgestellt",
    "scharfgestellteste": "scharfgestellt",
    "scharfgestelltestem": "scharfgestellt",
    "scharfgestelltesten": "scharfgestellt",
    "scharfgestelltester": "scharfgestellt",
    "scharfgestelltestes": "scharfgestellt",
    "scharfkantige": "scharfkantig",
    "scharfkantigem": "scharfkantig",
    "scharfkantigen": "scharfkantig",
    "scharfkantiger": "scharfkantig",
    "scharfkantigere": "scharfkantig",
    "scharfkantigerem": "scharfkantig",
    "scharfkantigeren": "scharfkantig",
    "scharfkantigerer": "scharfkantig",
    "scharfkantigeres": "scharfkantig",
    "scharfkantiges": "scharfkantig",
    "scharfkantigste": "scharfkantig",
    "scharfkantigstem": "scharfkantig",
    "scharfkantigsten": "scharfkantig",
    "scharfkantigster": "scharfkantig",
    "scharfkantigstes": "scharfkantig",
    "scharfsichtigem": "scharfsichtig",
    "scharfsichtigen": "scharfsichtig",
    "scharfsichtiger": "scharfsichtig",
    "scharfsichtigere": "scharfsichtig",
    "scharfsichtigerem": "scharfsichtig",
    "scharfsichtigeren": "scharfsichtig",
    "scharfsichtigerer": "scharfsichtig",
    "scharfsichtigeres": "scharfsichtig",
    "scharfsichtiges": "scharfsichtig",
    "scharfsichtigste": "scharfsichtig",
    "scharfsichtigstem": "scharfsichtig",
    "scharfsichtigsten": "scharfsichtig",
    "scharfsichtigster": "scharfsichtig",
    "scharfsichtigstes": "scharfsichtig",
    "scharfsinnige": "scharfsinnig",
    "scharfsinnigem": "scharfsinnig",
    "scharfsinnigen": "scharfsinnig",
    "scharfsinniger": "scharfsinnig",
    "scharfsinnigere": "scharfsinnig",
    "scharfsinnigerem": "scharfsinnig",
    "scharfsinnigeren": "scharfsinnig",
    "scharfsinnigerer": "scharfsinnig",
    "scharfsinnigeres": "scharfsinnig",
    "scharfsinniges": "scharfsinnig",
    "scharfsinnigste": "scharfsinnig",
    "scharfsinnigstem": "scharfsinnig",
    "scharfsinnigsten": "scharfsinnig",
    "scharfsinnigster": "scharfsinnig",
    "scharfsinnigstes": "scharfsinnig",
    "scharfstellend": "scharfstellen",
    "scharfstellende": "scharfstellend",
    "scharfstellendem": "scharfstellend",
    "scharfstellenden": "scharfstellend",
    "scharfstellender": "scharfstellend",
    "scharfstellendere": "scharfstellend",
    "scharfstellenderem": "scharfstellend",
    "scharfstellenderen": "scharfstellend",
    "scharfstellenderer": "scharfstellend",
    "scharfstellenderes": "scharfstellend",
    "scharfstellendes": "scharfstellend",
    "scharfstellendste": "scharfstellend",
    "scharfstellendstem": "scharfstellend",
    "scharfstellendsten": "scharfstellend",
    "scharfstellendster": "scharfstellend",
    "scharfstellendstes": "scharfstellend",
    "scharfstellest": "scharfstellen",
    "scharfstellet": "scharfstellen",
    "scharfstellst": "scharfstellen",
    "scharfstellt": "scharfstellen",
    "scharfstellte": "scharfstellen",
    "scharfstellten": "scharfstellen",
    "scharfstelltest": "scharfstellen",
    "scharfstelltet": "scharfstellen",
    "scharfzustellen": "scharfstellen",
    "scharmantem": "scharmant",
    "scharmanten": "scharmant",
    "scharmanter": "scharmant",
    "scharmantere": "scharmant",
    "scharmanterem": "scharmant",
    "scharmanteren": "scharmant",
    "scharmanterer": "scharmant",
    "scharmanteres": "scharmant",
    "scharmantes": "scharmant",
    "scharmanteste": "scharmant",
    "scharmantestem": "scharmant",
    "scharmantesten": "scharmant",
    "scharmantester": "scharmant",
    "scharmantestes": "scharmant",
    "scharmützele": "scharmützeln",
    "scharmützelnd": "scharmützeln",
    "scharmützelnde": "scharmützelnd",
    "scharmützelndem": "scharmützelnd",
    "scharmützelnden": "scharmützelnd",
    "scharmützelnder": "scharmützelnd",
    "scharmützelndes": "scharmützelnd",
    "scharmützelst": "scharmützeln",
    "scharmützelt": "scharmützeln",
    "scharmützelte": "scharmützeln",
    "scharmützeltem": "scharmützelt",
    "scharmützelten": "scharmützeln",
    "scharmützelter": "scharmützelt",
    "scharmützeltes": "scharmützelt",
    "scharmützeltest": "scharmützeln",
    "scharmützeltet": "scharmützeln",
    "scharmützle": "scharmützeln",
    "scharre": "scharren",
    "scharrend": "scharren",
    "scharrende": "scharrend",
    "scharrendem": "scharrend",
    "scharrenden": "scharrend",
    "scharrender": "scharrend",
    "scharrendes": "scharrend",
    "scharrest": "scharren",
    "scharret": "scharren",
    "scharrst": "scharren",
    "scharrt": "scharren",
    "scharrte": "scharren",
    "scharrten": "scharren",
    "scharrtest": "scharren",
    "scharrtet": "scharren",
    "scharst": "scharen",
    "schart": "scharen",
    "scharte": "scharen",
    "scharten": "scharen",
    "schartest": "scharen",
    "schartet": "scharen",
    "schattenhafte": "schattenhaft",
    "schattenhaftem": "schattenhaft",
    "schattenhaften": "schattenhaft",
    "schattenhafter": "schattenhaft",
    "schattenhaftere": "schattenhaft",
    "schattenhafterem": "schattenhaft",
    "schattenhafteren": "schattenhaft",
    "schattenhafterer": "schattenhaft",
    "schattenhafteres": "schattenhaft",
    "schattenhaftes": "schattenhaft",
    "schattenhafteste": "schattenhaft",
    "schattenhaftestem": "schattenhaft",
    "schattenhaftesten": "schattenhaft",
    "schattenhaftester": "schattenhaft",
    "schattenhaftestes": "schattenhaft",
    "schattiere": "schattieren",
    "schattierend": "schattieren",
    "schattierende": "schattierend",
    "schattierendem": "schattierend",
    "schattierenden": "schattierend",
    "schattierender": "schattierend",
    "schattierendes": "schattierend",
    "schattierest": "schattieren",
    "schattieret": "schattieren",
    "schattierst": "schattieren",
    "schattiert": "schattieren",
    "schattierte": "schattieren",
    "schattiertem": "schattiert",
    "schattierten": "schattieren",
    "schattierter": "schattiert",
    "schattiertes": "schattiert",
    "schattiertest": "schattieren",
    "schattiertet": "schattieren",
    "schattigem": "schattig",
    "schattigen": "schattig",
    "schattiger": "schattig",
    "schattigere": "schattig",
    "schattigerem": "schattig",
    "schattigeren": "schattig",
    "schattigerer": "schattig",
    "schattigeres": "schattig",
    "schattiges": "schattig",
    "schattigste": "schattig",
    "schattigstem": "schattig",
    "schattigsten": "schattig",
    "schattigster": "schattig",
    "schattigstes": "schattig",
    "schaudere": "schaudern",
    "schauderhafte": "schauderhaft",
    "schauderhaftem": "schauderhaft",
    "schauderhaften": "schauderhaft",
    "schauderhafter": "schauderhaft",
    "schauderhaftere": "schauderhaft",
    "schauderhafterem": "schauderhaft",
    "schauderhafteren": "schauderhaft",
    "schauderhafterer": "schauderhaft",
    "schauderhafteres": "schauderhaft",
    "schauderhaftes": "schauderhaft",
    "schauderhafteste": "schauderhaft",
    "schauderhaftestem": "schauderhaft",
    "schauderhaftesten": "schauderhaft",
    "schauderhaftester": "schauderhaft",
    "schauderhaftestes": "schauderhaft",
    "schaudernd": "schaudern",
    "schaudernde": "schaudernd",
    "schauderndem": "schaudernd",
    "schaudernden": "schaudernd",
    "schaudernder": "schaudernd",
    "schauderndere": "schaudernd",
    "schaudernderem": "schaudernd",
    "schaudernderen": "schaudernd",
    "schaudernderer": "schaudernd",
    "schaudernderes": "schaudernd",
    "schauderndes": "schaudernd",
    "schauderndste": "schaudernd",
    "schauderndstem": "schaudernd",
    "schauderndsten": "schaudernd",
    "schauderndster": "schaudernd",
    "schauderndstes": "schaudernd",
    "schauderst": "schaudern",
    "schaudert": "schaudern",
    "schauderte": "schaudern",
    "schauderten": "schaudern",
    "schaudertest": "schaudern",
    "schaudertet": "schaudern",
    "schaue": "schauen",
    "schauend": "schauen",
    "schauende": "schauend",
    "schauendem": "schauend",
    "schauenden": "schauend",
    "schauender": "schauend",
    "schauendes": "schauend",
    "schauerlichem": "schauerlich",
    "schauerlichen": "schauerlich",
    "schauerlicher": "schauerlich",
    "schauerlichere": "schauerlich",
    "schauerlicherem": "schauerlich",
    "schauerlicheren": "schauerlich",
    "schauerlicherer": "schauerlich",
    "schauerlicheres": "schauerlich",
    "schauerliches": "schauerlich",
    "schauerlichste": "schauerlich",
    "schauerlichstem": "schauerlich",
    "schauerlichsten": "schauerlich",
    "schauerlichster": "schauerlich",
    "schauerlichstes": "schauerlich",
    "schauest": "schauen",
    "schauet": "schauen",
    "schaufele": "schaufeln",
    "schaufelnd": "schaufeln",
    "schaufelnde": "schaufelnd",
    "schaufelndem": "schaufelnd",
    "schaufelnden": "schaufelnd",
    "schaufelnder": "schaufelnd",
    "schaufelndere": "schaufelnd",
    "schaufelnderem": "schaufelnd",
    "schaufelnderen": "schaufelnd",
    "schaufelnderer": "schaufelnd",
    "schaufelnderes": "schaufelnd",
    "schaufelndes": "schaufelnd",
    "schaufelndste": "schaufelnd",
    "schaufelndstem": "schaufelnd",
    "schaufelndsten": "schaufelnd",
    "schaufelndster": "schaufelnd",
    "schaufelndstes": "schaufelnd",
    "schaufelst": "schaufeln",
    "schaufelt": "schaufeln",
    "schaufelte": "schaufeln",
    "schaufelten": "schaufeln",
    "schaufeltest": "schaufeln",
    "schaufeltet": "schaufeln",
    "schaufle": "schaufeln",
    "schaukele": "schaukeln",
    "schaukelnd": "schaukeln",
    "schaukelnde": "schaukelnd",
    "schaukelndem": "schaukelnd",
    "schaukelnden": "schaukelnd",
    "schaukelnder": "schaukelnd",
    "schaukelndes": "schaukelnd",
    "schaukelst": "schaukeln",
    "schaukelt": "schaukeln",
    "schaukelte": "schaukeln",
    "schaukelten": "schaukeln",
    "schaukeltest": "schaukeln",
    "schaukeltet": "schaukeln",
    "schaukle": "schaukeln",
    "schaulustige": "schaulustig",
    "schaulustigem": "schaulustig",
    "schaulustigen": "schaulustig",
    "schaulustiger": "schaulustig",
    "schaulustigere": "schaulustig",
    "schaulustigerem": "schaulustig",
    "schaulustigeren": "schaulustig",
    "schaulustigerer": "schaulustig",
    "schaulustigeres": "schaulustig",
    "schaulustiges": "schaulustig",
    "schaulustigste": "schaulustig",
    "schaulustigstem": "schaulustig",
    "schaulustigsten": "schaulustig",
    "schaulustigster": "schaulustig",
    "schaulustigstes": "schaulustig",
    "schaumigem": "schaumig",
    "schaumigen": "schaumig",
    "schaumiger": "schaumig",
    "schaumigere": "schaumig",
    "schaumigerem": "schaumig",
    "schaumigeren": "schaumig",
    "schaumigerer": "schaumig",
    "schaumigeres": "schaumig",
    "schaumiges": "schaumig",
    "schaumigste": "schaumig",
    "schaumigstem": "schaumig",
    "schaumigsten": "schaumig",
    "schaumigster": "schaumig",
    "schaumigstes": "schaumig",
    "schaurigem": "schaurig",
    "schaurigen": "schaurig",
    "schauriger": "schaurig",
    "schaurigere": "schaurig",
    "schaurigerem": "schaurig",
    "schaurigeren": "schaurig",
    "schaurigerer": "schaurig",
    "schaurigeres": "schaurig",
    "schauriges": "schaurig",
    "schaurigste": "schaurig",
    "schaurigstem": "schaurig",
    "schaurigsten": "schaurig",
    "schaurigster": "schaurig",
    "schaurigstes": "schaurig",
    "schauspielere": "schauspielern",
    "schauspielerischem": "schauspielerisch",
    "schauspielerischen": "schauspielerisch",
    "schauspielerischer": "schauspielerisch",
    "schauspielerisches": "schauspielerisch",
    "schauspielernd": "schauspielern",
    "schauspielernde": "schauspielernd",
    "schauspielerndem": "schauspielernd",
    "schauspielernden": "schauspielernd",
    "schauspielernder": "schauspielernd",
    "schauspielerndes": "schauspielernd",
    "schauspielerst": "schauspielern",
    "schauspielert": "schauspielern",
    "schauspielerte": "schauspielern",
    "schauspielerten": "schauspielern",
    "schauspielertest": "schauspielern",
    "schauspielertet": "schauspielern",
    "schaust": "schauen",
    "schaut": "schauen",
    "schaute": "schauen",
    "schauten": "schauen",
    "schautest": "schauen",
    "schautet": "schauen",
    "scheelstem": "scheel",
    "scheelsten": "scheel",
    "scheelster": "scheel",
    "scheelstes": "scheel",
    "scheffele": "scheffeln",
    "scheffelnd": "scheffeln",
    "scheffelnde": "scheffelnd",
    "scheffelndem": "scheffelnd",
    "scheffelnden": "scheffelnd",
    "scheffelnder": "scheffelnd",
    "scheffelndere": "scheffelnd",
    "scheffelnderem": "scheffelnd",
    "scheffelnderen": "scheffelnd",
    "scheffelnderer": "scheffelnd",
    "scheffelnderes": "scheffelnd",
    "scheffelndes": "scheffelnd",
    "scheffelndste": "scheffelnd",
    "scheffelndstem": "scheffelnd",
    "scheffelndsten": "scheffelnd",
    "scheffelndster": "scheffelnd",
    "scheffelndstes": "scheffelnd",
    "scheffelst": "scheffeln",
    "scheffelt": "scheffeln",
    "scheffelte": "scheffeln",
    "scheffelten": "scheffeln",
    "scheffeltest": "scheffeln",
    "scheffeltet": "scheffeln",
    "scheffle": "scheffeln",
    "scheidend": "scheiden",
    "scheidende": "scheidend",
    "scheidendem": "scheidend",
    "scheidenden": "scheidend",
    "scheidender": "scheidend",
    "scheidendes": "scheidend",
    "scheidest": "scheiden",
    "scheidet": "scheiden",
    "scheinbarem": "scheinbar",
    "scheinbaren": "scheinbar",
    "scheinbarer": "scheinbar",
    "scheinbarere": "scheinbar",
    "scheinbarerem": "scheinbar",
    "scheinbareren": "scheinbar",
    "scheinbarerer": "scheinbar",
    "scheinbareres": "scheinbar",
    "scheinbares": "scheinbar",
    "scheinbarste": "scheinbar",
    "scheinbarstem": "scheinbar",
    "scheinbarsten": "scheinbar",
    "scheinbarster": "scheinbar",
    "scheinbarstes": "scheinbar",
    "scheine": "scheinen",
    "scheinend": "scheinen",
    "scheinende": "scheinend",
    "scheinendem": "scheinend",
    "scheinenden": "scheinend",
    "scheinender": "scheinend",
    "scheinendere": "scheinend",
    "scheinenderem": "scheinend",
    "scheinenderen": "scheinend",
    "scheinenderer": "scheinend",
    "scheinenderes": "scheinend",
    "scheinendes": "scheinend",
    "scheinendste": "scheinend",
    "scheinendstem": "scheinend",
    "scheinendsten": "scheinend",
    "scheinendster": "scheinend",
    "scheinendstes": "scheinend",
    "scheinest": "scheinen",
    "scheinet": "scheinen",
    "scheinheilige": "scheinheilig",
    "scheinheiligem": "scheinheilig",
    "scheinheiligen": "scheinheilig",
    "scheinheiliger": "scheinheilig",
    "scheinheiligere": "scheinheilig",
    "scheinheiligerem": "scheinheilig",
    "scheinheiligeren": "scheinheilig",
    "scheinheiligerer": "scheinheilig",
    "scheinheiligeres": "scheinheilig",
    "scheinheiliges": "scheinheilig",
    "scheinheiligste": "scheinheilig",
    "scheinheiligstem": "scheinheilig",
    "scheinheiligsten": "scheinheilig",
    "scheinheiligster": "scheinheilig",
    "scheinheiligstes": "scheinheilig",
    "scheinst": "scheinen",
    "scheint": "scheinen",
    "scheintote": "scheintot",
    "scheintotem": "scheintot",
    "scheintoten": "scheintot",
    "scheintoter": "scheintot",
    "scheintotes": "scheintot",
    "scheitere": "scheitern",
    "scheiternd": "scheitern",
    "scheiternde": "scheiternd",
    "scheiterndem": "scheiternd",
    "scheiternden": "scheiternd",
    "scheiternder": "scheiternd",
    "scheiterndes": "scheiternd",
    "scheiterst": "scheitern",
    "scheitert": "scheitern",
    "scheiterte": "scheitern",
    "scheiterten": "scheitern",
    "scheitertest": "scheitern",
    "scheitertet": "scheitern",
    "scheiße": "scheißen",
    "scheißend": "scheißen",
    "scheißende": "scheißend",
    "scheißendem": "scheißend",
    "scheißenden": "scheißend",
    "scheißender": "scheißend",
    "scheißendes": "scheißend",
    "scheißest": "scheißen",
    "scheißet": "scheißen",
    "scheißfreundliche": "scheißfreundlich",
    "scheißfreundlichem": "scheißfreundlich",
    "scheißfreundlichen": "scheißfreundlich",
    "scheißfreundlicher": "scheißfreundlich",
    "scheißfreundliches": "scheißfreundlich",
    "scheißt": "scheißen",
    "schelem": "scheel",
    "schelen": "scheel",
    "scheler": "scheel",
    "schelere": "scheel",
    "schelerem": "scheel",
    "scheleren": "scheel",
    "schelerer": "scheel",
    "scheleres": "scheel",
    "scheles": "scheel",
    "schelle": "schellen",
    "schellend": "schellen",
    "schellende": "schellend",
    "schellendem": "schellend",
    "schellenden": "schellend",
    "schellender": "schellend",
    "schellendes": "schellend",
    "schellest": "schellen",
    "schellet": "schellen",
    "schellst": "schellen",
    "schellt": "schellen",
    "schellte": "schellen",
    "schellten": "schellen",
    "schelltest": "schellen",
    "schelltet": "schellen",
    "schelmischem": "schelmisch",
    "schelmischen": "schelmisch",
    "schelmischer": "schelmisch",
    "schelmischere": "schelmisch",
    "schelmischerem": "schelmisch",
    "schelmischeren": "schelmisch",
    "schelmischerer": "schelmisch",
    "schelmischeres": "schelmisch",
    "schelmisches": "schelmisch",
    "schelmischste": "schelmisch",
    "schelmischstem": "schelmisch",
    "schelmischsten": "schelmisch",
    "schelmischster": "schelmisch",
    "schelmischstes": "schelmisch",
    "schelte": "schelten",
    "scheltend": "schelten",
    "scheltende": "scheltend",
    "scheltendem": "scheltend",
    "scheltenden": "scheltend",
    "scheltender": "scheltend",
    "scheltendes": "scheltend",
    "scheltest": "schelten",
    "scheltet": "schelten",
    "schematischem": "schematisch",
    "schematischen": "schematisch",
    "schematischer": "schematisch",
    "schematischere": "schematisch",
    "schematischerem": "schematisch",
    "schematischeren": "schematisch",
    "schematischerer": "schematisch",
    "schematischeres": "schematisch",
    "schematisches": "schematisch",
    "schematischste": "schematisch",
    "schematischstem": "schematisch",
    "schematischsten": "schematisch",
    "schematischster": "schematisch",
    "schematischstes": "schematisch",
    "schematisiere": "schematisieren",
    "schematisierend": "schematisieren",
    "schematisierende": "schematisierend",
    "schematisierendem": "schematisierend",
    "schematisierenden": "schematisierend",
    "schematisierender": "schematisierend",
    "schematisierendere": "schematisierend",
    "schematisierenderem": "schematisierend",
    "schematisierenderen": "schematisierend",
    "schematisierenderer": "schematisierend",
    "schematisierenderes": "schematisierend",
    "schematisierendes": "schematisierend",
    "schematisierendste": "schematisierend",
    "schematisierendstem": "schematisierend",
    "schematisierendsten": "schematisierend",
    "schematisierendster": "schematisierend",
    "schematisierendstes": "schematisierend",
    "schematisierest": "schematisieren",
    "schematisieret": "schematisieren",
    "schematisierst": "schematisieren",
    "schematisiert": "schematisieren",
    "schematisierte": "schematisieren",
    "schematisiertem": "schematisiert",
    "schematisierten": "schematisieren",
    "schematisierter": "schematisiert",
    "schematisiertere": "schematisiert",
    "schematisierterem": "schematisiert",
    "schematisierteren": "schematisiert",
    "schematisierterer": "schematisiert",
    "schematisierteres": "schematisiert",
    "schematisiertes": "schematisiert",
    "schematisiertest": "schematisieren",
    "schematisiertestem": "schematisiert",
    "schematisiertesten": "schematisiert",
    "schematisiertester": "schematisiert",
    "schematisiertestes": "schematisiert",
    "schematisiertet": "schematisieren",
    "schemenhaftem": "schemenhaft",
    "schemenhaften": "schemenhaft",
    "schemenhafter": "schemenhaft",
    "schemenhaftere": "schemenhaft",
    "schemenhafterem": "schemenhaft",
    "schemenhafteren": "schemenhaft",
    "schemenhafterer": "schemenhaft",
    "schemenhafteres": "schemenhaft",
    "schemenhaftes": "schemenhaft",
    "schemenhafteste": "schemenhaft",
    "schemenhaftestem": "schemenhaft",
    "schemenhaftesten": "schemenhaft",
    "schemenhaftester": "schemenhaft",
    "schemenhaftestes": "schemenhaft",
    "schenke": "schenken",
    "schenkend": "schenken",
    "schenkende": "schenkend",
    "schenkendem": "schenkend",
    "schenkenden": "schenkend",
    "schenkender": "schenkend",
    "schenkendes": "schenkend",
    "schenkest": "schenken",
    "schenket": "schenken",
    "schenkst": "schenken",
    "schenkt": "schenken",
    "schenkte": "schenken",
    "schenkten": "schenken",
    "schenktest": "schenken",
    "schenktet": "schenken",
    "scheppere": "scheppern",
    "scheppernd": "scheppern",
    "scheppernde": "scheppernd",
    "schepperndem": "scheppernd",
    "scheppernden": "scheppernd",
    "scheppernder": "scheppernd",
    "schepperndere": "scheppernd",
    "scheppernderem": "scheppernd",
    "scheppernderen": "scheppernd",
    "scheppernderer": "scheppernd",
    "scheppernderes": "scheppernd",
    "schepperndes": "scheppernd",
    "schepperndste": "scheppernd",
    "schepperndstem": "scheppernd",
    "schepperndsten": "scheppernd",
    "schepperndster": "scheppernd",
    "schepperndstes": "scheppernd",
    "schepperst": "scheppern",
    "scheppert": "scheppern",
    "schepperte": "scheppern",
    "schepperten": "scheppern",
    "scheppertest": "scheppern",
    "scheppertet": "scheppern",
    "scherend": "scheren",
    "scherende": "scherend",
    "scherendem": "scherend",
    "scherenden": "scherend",
    "scherender": "scherend",
    "scherendes": "scherend",
    "scherest": "scheren",
    "scheret": "scheren",
    "scherst": "scheren",
    "schert": "scheren",
    "scherte": "scheren",
    "scherten": "scheren",
    "schertest": "scheren",
    "schertet": "scheren",
    "scherzend": "scherzen",
    "scherzende": "scherzend",
    "scherzendem": "scherzend",
    "scherzenden": "scherzend",
    "scherzender": "scherzend",
    "scherzendere": "scherzend",
    "scherzenderem": "scherzend",
    "scherzenderen": "scherzend",
    "scherzenderer": "scherzend",
    "scherzenderes": "scherzend",
    "scherzendes": "scherzend",
    "scherzendste": "scherzend",
    "scherzendstem": "scherzend",
    "scherzendsten": "scherzend",
    "scherzendster": "scherzend",
    "scherzendstes": "scherzend",
    "scherzest": "scherzen",
    "scherzet": "scherzen",
    "scherzhafte": "scherzhaft",
    "scherzhaftem": "scherzhaft",
    "scherzhaften": "scherzhaft",
    "scherzhafter": "scherzhaft",
    "scherzhaftere": "scherzhaft",
    "scherzhafterem": "scherzhaft",
    "scherzhafteren": "scherzhaft",
    "scherzhafterer": "scherzhaft",
    "scherzhafteres": "scherzhaft",
    "scherzhaftes": "scherzhaft",
    "scherzhafteste": "scherzhaft",
    "scherzhaftestem": "scherzhaft",
    "scherzhaftesten": "scherzhaft",
    "scherzhaftester": "scherzhaft",
    "scherzhaftestes": "scherzhaft",
    "scherzt": "scherzen",
    "scherzte": "scherzen",
    "scherzten": "scherzen",
    "scherztest": "scherzen",
    "scherztet": "scherzen",
    "scheuche": "scheuchen",
    "scheuchend": "scheuchen",
    "scheuchende": "scheuchend",
    "scheuchendem": "scheuchend",
    "scheuchenden": "scheuchend",
    "scheuchender": "scheuchend",
    "scheuchendere": "scheuchend",
    "scheuchenderem": "scheuchend",
    "scheuchenderen": "scheuchend",
    "scheuchenderer": "scheuchend",
    "scheuchenderes": "scheuchend",
    "scheuchendes": "scheuchend",
    "scheuchendste": "scheuchend",
    "scheuchendstem": "scheuchend",
    "scheuchendsten": "scheuchend",
    "scheuchendster": "scheuchend",
    "scheuchendstes": "scheuchend",
    "scheuchest": "scheuchen",
    "scheuchet": "scheuchen",
    "scheuchst": "scheuchen",
    "scheucht": "scheuchen",
    "scheuchte": "scheuchen",
    "scheuchten": "scheuchen",
    "scheuchtest": "scheuchen",
    "scheuchtet": "scheuchen",
    "scheue": "scheuen",
    "scheuend": "scheuen",
    "scheuende": "scheuend",
    "scheuendem": "scheuend",
    "scheuenden": "scheuend",
    "scheuender": "scheuend",
    "scheuendes": "scheuend",
    "scheuere": "scheuern",
    "scheuernd": "scheuern",
    "scheuernde": "scheuernd",
    "scheuerndem": "scheuernd",
    "scheuernden": "scheuernd",
    "scheuernder": "scheuernd",
    "scheuerndere": "scheuernd",
    "scheuernderem": "scheuernd",
    "scheuernderen": "scheuernd",
    "scheuernderer": "scheuernd",
    "scheuernderes": "scheuernd",
    "scheuerndes": "scheuernd",
    "scheuerndste": "scheuernd",
    "scheuerndstem": "scheuernd",
    "scheuerndsten": "scheuernd",
    "scheuerndster": "scheuernd",
    "scheuerndstes": "scheuernd",
    "scheuerst": "scheuern",
    "scheuert": "scheuern",
    "scheuerte": "scheuern",
    "scheuerten": "scheuern",
    "scheuertest": "scheuern",
    "scheuertet": "scheuern",
    "scheuest": "scheuen",
    "scheuet": "scheuen",
    "scheust": "scheuen",
    "scheut": "scheuen",
    "scheute": "scheuen",
    "scheuten": "scheuen",
    "scheutest": "scheuen",
    "scheutet": "scheuen",
    "scheußlichem": "scheußlich",
    "scheußlichen": "scheußlich",
    "scheußlicher": "scheußlich",
    "scheußlichere": "scheußlich",
    "scheußlicherem": "scheußlich",
    "scheußlicheren": "scheußlich",
    "scheußlicherer": "scheußlich",
    "scheußlicheres": "scheußlich",
    "scheußliches": "scheußlich",
    "scheußlichste": "scheußlich",
    "scheußlichstem": "scheußlich",
    "scheußlichsten": "scheußlich",
    "scheußlichster": "scheußlich",
    "scheußlichstes": "scheußlich",
    "schichte": "schichten",
    "schichtend": "schichten",
    "schichtende": "schichtend",
    "schichtendem": "schichtend",
    "schichtenden": "schichtend",
    "schichtender": "schichtend",
    "schichtendes": "schichtend",
    "schichtest": "schichten",
    "schichtet": "schichten",
    "schichtete": "schichten",
    "schichteten": "schichten",
    "schichtetest": "schichten",
    "schichtetet": "schichten",
    "schick": "schicken",
    "schickem": "schick",
    "schicken": "schick",
    "schickend": "schicken",
    "schickende": "schickend",
    "schickendem": "schickend",
    "schickenden": "schickend",
    "schickender": "schickend",
    "schickendes": "schickend",
    "schicker": "schick",
    "schickere": "schick",
    "schickerem": "schick",
    "schickeren": "schick",
    "schickerer": "schick",
    "schickeres": "schick",
    "schickes": "schick",
    "schickest": "schicken",
    "schicket": "schicken",
    "schicksalhaftem": "schicksalhaft",
    "schicksalhaften": "schicksalhaft",
    "schicksalhafter": "schicksalhaft",
    "schicksalhaftes": "schicksalhaft",
    "schickst": "schicken",
    "schickste": "schick",
    "schickstem": "schick",
    "schicksten": "schick",
    "schickster": "schick",
    "schickstes": "schick",
    "schickt": "schicken",
    "schickte": "schicken",
    "schickten": "schicken",
    "schicktest": "schicken",
    "schicktet": "schicken",
    "schiebe": "schieben",
    "schiebend": "schieben",
    "schiebende": "schiebend",
    "schiebendem": "schiebend",
    "schiebenden": "schiebend",
    "schiebender": "schiebend",
    "schiebendes": "schiebend",
    "schiebest": "schieben",
    "schiebet": "schieben",
    "schiebst": "schieben",
    "schiebt": "schieben",
    "schied": "scheiden",
    "schiede": "scheiden",
    "schieden": "scheiden",
    "schiedest": "scheiden",
    "schiedet": "scheiden",
    "schiedsrichterlichem": "schiedsrichterlich",
    "schiedsrichterlichen": "schiedsrichterlich",
    "schiedsrichterlicher": "schiedsrichterlich",
    "schiedsrichterliches": "schiedsrichterlich",
    "schiefere": "schiefern",
    "schiefernd": "schiefern",
    "schiefernde": "schiefernd",
    "schieferndem": "schiefernd",
    "schiefernden": "schiefernd",
    "schiefernder": "schiefernd",
    "schieferndes": "schiefernd",
    "schieferst": "schiefern",
    "schiefert": "schiefern",
    "schieferte": "schiefern",
    "schieferten": "schiefern",
    "schiefertest": "schiefern",
    "schiefertet": "schiefern",
    "schiefgegangen": "schiefgehen",
    "schiefgegangene": "schiefgegangen",
    "schiefgegangenem": "schiefgegangen",
    "schiefgegangenen": "schiefgegangen",
    "schiefgegangener": "schiefgegangen",
    "schiefgegangenes": "schiefgegangen",
    "schiefgehe": "schiefgehen",
    "schiefgehend": "schiefgehen",
    "schiefgehende": "schiefgehend",
    "schiefgehendem": "schiefgehend",
    "schiefgehenden": "schiefgehend",
    "schiefgehender": "schiefgehend",
    "schiefgehendes": "schiefgehend",
    "schiefgehest": "schiefgehen",
    "schiefgehet": "schiefgehen",
    "schiefgehst": "schiefgehen",
    "schiefgeht": "schiefgehen",
    "schiefgelacht": "schieflachen",
    "schiefgelachte": "schiefgelacht",
    "schiefgelachtem": "schiefgelacht",
    "schiefgelachten": "schiefgelacht",
    "schiefgelachter": "schiefgelacht",
    "schiefgelachtes": "schiefgelacht",
    "schiefgelegen": "schiefliegen",
    "schiefgelegene": "schiefgelegen",
    "schiefgelegenem": "schiefgelegen",
    "schiefgelegenen": "schiefgelegen",
    "schiefgelegener": "schiefgelegen",
    "schiefgelegenes": "schiefgelegen",
    "schiefging": "schiefgehen",
    "schiefginge": "schiefgehen",
    "schiefgingen": "schiefgehen",
    "schiefgingest": "schiefgehen",
    "schiefginget": "schiefgehen",
    "schiefgingst": "schiefgehen",
    "schiefgingt": "schiefgehen",
    "schieflache": "schieflachen",
    "schieflachend": "schieflachen",
    "schieflachende": "schieflachend",
    "schieflachendem": "schieflachend",
    "schieflachenden": "schieflachend",
    "schieflachender": "schieflachend",
    "schieflachendes": "schieflachend",
    "schieflachest": "schieflachen",
    "schieflachet": "schieflachen",
    "schieflachst": "schieflachen",
    "schieflacht": "schieflachen",
    "schieflachte": "schieflachen",
    "schieflachten": "schieflachen",
    "schieflachtest": "schieflachen",
    "schieflachtet": "schieflachen",
    "schieflag": "schiefliegen",
    "schieflagen": "schiefliegen",
    "schieflagst": "schiefliegen",
    "schieflagt": "schiefliegen",
    "schiefliege": "schiefliegen",
    "schiefliegend": "schiefliegen",
    "schiefliegende": "schiefliegend",
    "schiefliegendem": "schiefliegend",
    "schiefliegenden": "schiefliegend",
    "schiefliegender": "schiefliegend",
    "schiefliegendes": "schiefliegend",
    "schiefliegest": "schiefliegen",
    "schieflieget": "schiefliegen",
    "schiefliegst": "schiefliegen",
    "schiefliegt": "schiefliegen",
    "schiefläge": "schiefliegen",
    "schieflägen": "schiefliegen",
    "schieflägest": "schiefliegen",
    "schiefläget": "schiefliegen",
    "schiefwinklige": "schiefwinklig",
    "schiefwinkligem": "schiefwinklig",
    "schiefwinkligen": "schiefwinklig",
    "schiefwinkliger": "schiefwinklig",
    "schiefwinkliges": "schiefwinklig",
    "schiefzugehen": "schiefgehen",
    "schiefzulachen": "schieflachen",
    "schiefzuliegen": "schiefliegen",
    "schiele": "schielen",
    "schielend": "schielen",
    "schielende": "schielend",
    "schielendem": "schielend",
    "schielenden": "schielend",
    "schielender": "schielend",
    "schielendere": "schielend",
    "schielenderem": "schielend",
    "schielenderen": "schielend",
    "schielenderer": "schielend",
    "schielenderes": "schielend",
    "schielendes": "schielend",
    "schielendste": "schielend",
    "schielendstem": "schielend",
    "schielendsten": "schielend",
    "schielendster": "schielend",
    "schielendstes": "schielend",
    "schielest": "schielen",
    "schielet": "schielen",
    "schielst": "schielen",
    "schielt": "schielen",
    "schielte": "schielen",
    "schielten": "schielen",
    "schieltest": "schielen",
    "schieltet": "schielen",
    "schien": "scheinen",
    "schienen": "scheinen",
    "schienest": "scheinen",
    "schienet": "scheinen",
    "schienst": "scheinen",
    "schient": "scheinen",
    "schiere": "schier",
    "schierem": "schier",
    "schieren": "schier",
    "schierer": "schier",
    "schieres": "schier",
    "schieße": "schießen",
    "schießend": "schießen",
    "schießende": "schießend",
    "schießendem": "schießend",
    "schießenden": "schießend",
    "schießender": "schießend",
    "schießendes": "schießend",
    "schießest": "schießen",
    "schießet": "schießen",
    "schießt": "schießen",
    "schiffbrüchigem": "schiffbrüchig",
    "schiffbrüchigen": "schiffbrüchig",
    "schiffbrüchiger": "schiffbrüchig",
    "schiffbrüchigere": "schiffbrüchig",
    "schiffbrüchigerem": "schiffbrüchig",
    "schiffbrüchigeren": "schiffbrüchig",
    "schiffbrüchigerer": "schiffbrüchig",
    "schiffbrüchigeres": "schiffbrüchig",
    "schiffbrüchiges": "schiffbrüchig",
    "schiffbrüchigste": "schiffbrüchig",
    "schiffbrüchigstem": "schiffbrüchig",
    "schiffbrüchigsten": "schiffbrüchig",
    "schiffbrüchigster": "schiffbrüchig",
    "schiffbrüchigstes": "schiffbrüchig",
    "schiffend": "schiffen",
    "schiffende": "schiffend",
    "schiffendem": "schiffend",
    "schiffenden": "schiffend",
    "schiffender": "schiffend",
    "schiffendere": "schiffend",
    "schiffenderem": "schiffend",
    "schiffenderen": "schiffend",
    "schiffenderer": "schiffend",
    "schiffenderes": "schiffend",
    "schiffendes": "schiffend",
    "schiffendste": "schiffend",
    "schiffendstem": "schiffend",
    "schiffendsten": "schiffend",
    "schiffendster": "schiffend",
    "schiffendstes": "schiffend",
    "schiffest": "schiffen",
    "schiffet": "schiffen",
    "schiffst": "schiffen",
    "schifft": "schiffen",
    "schiffte": "schiffen",
    "schifften": "schiffen",
    "schifftest": "schiffen",
    "schifftet": "schiffen",
    "schiitischem": "schiitisch",
    "schiitischen": "schiitisch",
    "schiitischer": "schiitisch",
    "schiitisches": "schiitisch",
    "schikaniere": "schikanieren",
    "schikanierend": "schikanieren",
    "schikanierende": "schikanierend",
    "schikanierendem": "schikanierend",
    "schikanierenden": "schikanierend",
    "schikanierender": "schikanierend",
    "schikanierendere": "schikanierend",
    "schikanierenderem": "schikanierend",
    "schikanierenderen": "schikanierend",
    "schikanierenderer": "schikanierend",
    "schikanierenderes": "schikanierend",
    "schikanierendes": "schikanierend",
    "schikanierendste": "schikanierend",
    "schikanierendstem": "schikanierend",
    "schikanierendsten": "schikanierend",
    "schikanierendster": "schikanierend",
    "schikanierendstes": "schikanierend",
    "schikanierest": "schikanieren",
    "schikanieret": "schikanieren",
    "schikanierst": "schikanieren",
    "schikaniert": "schikanieren",
    "schikanierte": "schikanieren",
    "schikaniertem": "schikaniert",
    "schikanierten": "schikanieren",
    "schikanierter": "schikaniert",
    "schikaniertere": "schikaniert",
    "schikanierterem": "schikaniert",
    "schikanierteren": "schikaniert",
    "schikanierterer": "schikaniert",
    "schikanierteres": "schikaniert",
    "schikaniertes": "schikaniert",
    "schikaniertest": "schikanieren",
    "schikanierteste": "schikaniert",
    "schikaniertestem": "schikaniert",
    "schikaniertesten": "schikaniert",
    "schikaniertester": "schikaniert",
    "schikaniertestes": "schikaniert",
    "schikaniertet": "schikanieren",
    "schikanöse": "schikanös",
    "schikanösem": "schikanös",
    "schikanösen": "schikanös",
    "schikanöser": "schikanös",
    "schikanösere": "schikanös",
    "schikanöserem": "schikanös",
    "schikanöseren": "schikanös",
    "schikanöserer": "schikanös",
    "schikanöseres": "schikanös",
    "schikanöses": "schikanös",
    "schikanöseste": "schikanös",
    "schikanösestem": "schikanös",
    "schikanösesten": "schikanös",
    "schikanösester": "schikanös",
    "schikanösestes": "schikanös",
    "schildere": "schildern",
    "schildernd": "schildern",
    "schildernde": "schildernd",
    "schilderndem": "schildernd",
    "schildernden": "schildernd",
    "schildernder": "schildernd",
    "schilderndes": "schildernd",
    "schilderst": "schildern",
    "schildert": "schildern",
    "schilderte": "schildern",
    "schilderten": "schildern",
    "schildertest": "schildern",
    "schildertet": "schildern",
    "schilfigem": "schilfig",
    "schilfigen": "schilfig",
    "schilfiger": "schilfig",
    "schilfigere": "schilfig",
    "schilfigerem": "schilfig",
    "schilfigeren": "schilfig",
    "schilfigerer": "schilfig",
    "schilfigeres": "schilfig",
    "schilfiges": "schilfig",
    "schilfigste": "schilfig",
    "schilfigstem": "schilfig",
    "schilfigsten": "schilfig",
    "schilfigster": "schilfig",
    "schilfigstes": "schilfig",
    "schillere": "schillern",
    "schillernd": "schillern",
    "schillernde": "schillernd",
    "schillerndem": "schillernd",
    "schillernden": "schillernd",
    "schillernder": "schillernd",
    "schillerndere": "schillernd",
    "schillernderem": "schillernd",
    "schillernderen": "schillernd",
    "schillernderer": "schillernd",
    "schillernderes": "schillernd",
    "schillerndes": "schillernd",
    "schillerndste": "schillernd",
    "schillerndstem": "schillernd",
    "schillerndsten": "schillernd",
    "schillerndster": "schillernd",
    "schillerndstes": "schillernd",
    "schillerst": "schillern",
    "schillert": "schillern",
    "schillerte": "schillern",
    "schillerten": "schillern",
    "schillertest": "schillern",
    "schillertet": "schillern",
    "schilt": "schelten",
    "schiltst": "schelten",
    "schimmele": "schimmeln",
    "schimmelige": "schimmelig",
    "schimmeligem": "schimmelig",
    "schimmeligen": "schimmelig",
    "schimmeliger": "schimmelig",
    "schimmeligere": "schimmelig",
    "schimmeligerem": "schimmelig",
    "schimmeligeren": "schimmelig",
    "schimmeligerer": "schimmelig",
    "schimmeligeres": "schimmelig",
    "schimmeliges": "schimmelig",
    "schimmeligste": "schimmelig",
    "schimmeligstem": "schimmelig",
    "schimmeligsten": "schimmelig",
    "schimmeligster": "schimmelig",
    "schimmeligstes": "schimmelig",
    "schimmelnd": "schimmeln",
    "schimmelnde": "schimmelnd",
    "schimmelndem": "schimmelnd",
    "schimmelnden": "schimmelnd",
    "schimmelnder": "schimmelnd",
    "schimmelndere": "schimmelnd",
    "schimmelnderem": "schimmelnd",
    "schimmelnderen": "schimmelnd",
    "schimmelnderer": "schimmelnd",
    "schimmelnderes": "schimmelnd",
    "schimmelndes": "schimmelnd",
    "schimmelndste": "schimmelnd",
    "schimmelndstem": "schimmelnd",
    "schimmelndsten": "schimmelnd",
    "schimmelndster": "schimmelnd",
    "schimmelndstes": "schimmelnd",
    "schimmelst": "schimmeln",
    "schimmelt": "schimmeln",
    "schimmelte": "schimmeln",
    "schimmelten": "schimmeln",
    "schimmeltest": "schimmeln",
    "schimmeltet": "schimmeln",
    "schimmere": "schimmern",
    "schimmernd": "schimmern",
    "schimmernde": "schimmernd",
    "schimmerndem": "schimmernd",
    "schimmernden": "schimmernd",
    "schimmernder": "schimmernd",
    "schimmerndere": "schimmernd",
    "schimmernderem": "schimmernd",
    "schimmernderen": "schimmernd",
    "schimmernderer": "schimmernd",
    "schimmernderes": "schimmernd",
    "schimmerndes": "schimmernd",
    "schimmerndste": "schimmernd",
    "schimmerndstem": "schimmernd",
    "schimmerndsten": "schimmernd",
    "schimmerndster": "schimmernd",
    "schimmerndstes": "schimmernd",
    "schimmerst": "schimmern",
    "schimmert": "schimmern",
    "schimmerte": "schimmern",
    "schimmerten": "schimmern",
    "schimmertest": "schimmern",
    "schimmertet": "schimmern",
    "schimmle": "schimmeln",
    "schimmlige": "schimmlig",
    "schimmligem": "schimmlig",
    "schimmligen": "schimmlig",
    "schimmliger": "schimmlig",
    "schimmligere": "schimmlig",
    "schimmligerem": "schimmlig",
    "schimmligeren": "schimmlig",
    "schimmligerer": "schimmlig",
    "schimmligeres": "schimmlig",
    "schimmliges": "schimmlig",
    "schimmligste": "schimmlig",
    "schimmligstem": "schimmlig",
    "schimmligsten": "schimmlig",
    "schimmligster": "schimmlig",
    "schimmligstes": "schimmlig",
    "schimpfe": "schimpfen",
    "schimpfend": "schimpfen",
    "schimpfende": "schimpfend",
    "schimpfendem": "schimpfend",
    "schimpfenden": "schimpfend",
    "schimpfender": "schimpfend",
    "schimpfendes": "schimpfend",
    "schimpfest": "schimpfen",
    "schimpfet": "schimpfen",
    "schimpfst": "schimpfen",
    "schimpft": "schimpfen",
    "schimpfte": "schimpfen",
    "schimpften": "schimpfen",
    "schimpftest": "schimpfen",
    "schimpftet": "schimpfen",
    "schinde": "schinden",
    "schindend": "schinden",
    "schindende": "schindend",
    "schindendem": "schindend",
    "schindenden": "schindend",
    "schindender": "schindend",
    "schindendes": "schindend",
    "schindest": "schinden",
    "schindet": "schinden",
    "schindete": "schinden",
    "schindeten": "schinden",
    "schindetest": "schinden",
    "schindetet": "schinden",
    "schirmend": "schirmen",
    "schirmende": "schirmend",
    "schirmendem": "schirmend",
    "schirmenden": "schirmend",
    "schirmender": "schirmend",
    "schirmendes": "schirmend",
    "schirmest": "schirmen",
    "schirmet": "schirmen",
    "schirmst": "schirmen",
    "schirmt": "schirmen",
    "schirmte": "schirmen",
    "schirmten": "schirmen",
    "schirmtest": "schirmen",
    "schirmtet": "schirmen",
    "schirre": "schirren",
    "schirrend": "schirren",
    "schirrende": "schirrend",
    "schirrendem": "schirrend",
    "schirrenden": "schirrend",
    "schirrender": "schirrend",
    "schirrendes": "schirrend",
    "schirrest": "schirren",
    "schirret": "schirren",
    "schirrst": "schirren",
    "schirrt": "schirren",
    "schirrte": "schirren",
    "schirrten": "schirren",
    "schirrtest": "schirren",
    "schirrtet": "schirren",
    "schisse": "scheißen",
    "schissen": "scheißen",
    "schissest": "scheißen",
    "schisset": "scheißen",
    "schizoide": "schizoid",
    "schizoidem": "schizoid",
    "schizoiden": "schizoid",
    "schizoider": "schizoid",
    "schizoidere": "schizoid",
    "schizoiderem": "schizoid",
    "schizoideren": "schizoid",
    "schizoiderer": "schizoid",
    "schizoideres": "schizoid",
    "schizoides": "schizoid",
    "schizoideste": "schizoid",
    "schizoidestem": "schizoid",
    "schizoidesten": "schizoid",
    "schizoidester": "schizoid",
    "schizoidestes": "schizoid",
    "schizophrene": "schizophren",
    "schizophrenem": "schizophren",
    "schizophrenen": "schizophren",
    "schizophrener": "schizophren",
    "schizophrenere": "schizophren",
    "schizophrenerem": "schizophren",
    "schizophreneren": "schizophren",
    "schizophrenerer": "schizophren",
    "schizophreneres": "schizophren",
    "schizophrenes": "schizophren",
    "schizophrenstem": "schizophren",
    "schizophrensten": "schizophren",
    "schizophrenster": "schizophren",
    "schizophrenstes": "schizophren",
    "schiß": "scheißen",
    "schißt": "scheißen",
    "schlabbere": "schlabbern",
    "schlabberige": "schlabberig",
    "schlabberigem": "schlabberig",
    "schlabberigen": "schlabberig",
    "schlabberiger": "schlabberig",
    "schlabberigere": "schlabberig",
    "schlabberigerem": "schlabberig",
    "schlabberigeren": "schlabberig",
    "schlabberigerer": "schlabberig",
    "schlabberigeres": "schlabberig",
    "schlabberiges": "schlabberig",
    "schlabberigste": "schlabberig",
    "schlabberigstem": "schlabberig",
    "schlabberigsten": "schlabberig",
    "schlabberigster": "schlabberig",
    "schlabberigstes": "schlabberig",
    "schlabbernd": "schlabbern",
    "schlabbernde": "schlabbernd",
    "schlabberndem": "schlabbernd",
    "schlabbernden": "schlabbernd",
    "schlabbernder": "schlabbernd",
    "schlabberndere": "schlabbernd",
    "schlabbernderem": "schlabbernd",
    "schlabbernderen": "schlabbernd",
    "schlabbernderer": "schlabbernd",
    "schlabbernderes": "schlabbernd",
    "schlabberndes": "schlabbernd",
    "schlabberndste": "schlabbernd",
    "schlabberndstem": "schlabbernd",
    "schlabberndsten": "schlabbernd",
    "schlabberndster": "schlabbernd",
    "schlabberndstes": "schlabbernd",
    "schlabberst": "schlabbern",
    "schlabbert": "schlabbern",
    "schlabberte": "schlabbern",
    "schlabberten": "schlabbern",
    "schlabbertest": "schlabbern",
    "schlabbertet": "schlabbern",
    "schlachte": "schlachten",
    "schlachtend": "schlachten",
    "schlachtende": "schlachtend",
    "schlachtendem": "schlachtend",
    "schlachtenden": "schlachtend",
    "schlachtender": "schlachtend",
    "schlachtendes": "schlachtend",
    "schlachtest": "schlachten",
    "schlachtet": "schlachten",
    "schlachtete": "schlachten",
    "schlachteten": "schlachten",
    "schlachtetest": "schlachten",
    "schlachtetet": "schlachten",
    "schlachtreifem": "schlachtreif",
    "schlachtreifen": "schlachtreif",
    "schlachtreifer": "schlachtreif",
    "schlachtreifere": "schlachtreif",
    "schlachtreiferem": "schlachtreif",
    "schlachtreiferen": "schlachtreif",
    "schlachtreiferer": "schlachtreif",
    "schlachtreiferes": "schlachtreif",
    "schlachtreifes": "schlachtreif",
    "schlachtreifste": "schlachtreif",
    "schlachtreifstem": "schlachtreif",
    "schlachtreifsten": "schlachtreif",
    "schlachtreifster": "schlachtreif",
    "schlachtreifstes": "schlachtreif",
    "schlafend": "schlafen",
    "schlafende": "schlafend",
    "schlafendem": "schlafend",
    "schlafenden": "schlafend",
    "schlafender": "schlafend",
    "schlafendes": "schlafend",
    "schlafest": "schlafen",
    "schlafet": "schlafen",
    "schlaffe": "schlaffen",
    "schlaffend": "schlaffen",
    "schlaffende": "schlaffend",
    "schlaffendem": "schlaffend",
    "schlaffenden": "schlaffend",
    "schlaffender": "schlaffend",
    "schlaffendes": "schlaffend",
    "schlaffest": "schlaffen",
    "schlaffet": "schlaffen",
    "schlaffst": "schlaffen",
    "schlafft": "schlaffen",
    "schlaffte": "schlaffen",
    "schlafften": "schlaffen",
    "schlafftest": "schlaffen",
    "schlafftet": "schlaffen",
    "schlaflosem": "schlaflos",
    "schlaflosen": "schlaflos",
    "schlafloser": "schlaflos",
    "schlaflosere": "schlaflos",
    "schlafloserem": "schlaflos",
    "schlafloseren": "schlaflos",
    "schlafloserer": "schlaflos",
    "schlafloseres": "schlaflos",
    "schlafloses": "schlaflos",
    "schlafloseste": "schlaflos",
    "schlaflosestem": "schlaflos",
    "schlaflosesten": "schlaflos",
    "schlaflosester": "schlaflos",
    "schlaflosestes": "schlaflos",
    "schlafmützigem": "schlafmützig",
    "schlafmützigen": "schlafmützig",
    "schlafmütziger": "schlafmützig",
    "schlafmützigere": "schlafmützig",
    "schlafmützigerem": "schlafmützig",
    "schlafmützigeren": "schlafmützig",
    "schlafmützigerer": "schlafmützig",
    "schlafmützigeres": "schlafmützig",
    "schlafmütziges": "schlafmützig",
    "schlafmützigste": "schlafmützig",
    "schlafmützigstem": "schlafmützig",
    "schlafmützigsten": "schlafmützig",
    "schlafmützigster": "schlafmützig",
    "schlafmützigstes": "schlafmützig",
    "schlafsüchtigem": "schlafsüchtig",
    "schlafsüchtigen": "schlafsüchtig",
    "schlafsüchtiger": "schlafsüchtig",
    "schlafsüchtigere": "schlafsüchtig",
    "schlafsüchtigerem": "schlafsüchtig",
    "schlafsüchtigeren": "schlafsüchtig",
    "schlafsüchtigerer": "schlafsüchtig",
    "schlafsüchtigeres": "schlafsüchtig",
    "schlafsüchtiges": "schlafsüchtig",
    "schlafsüchtigste": "schlafsüchtig",
    "schlafsüchtigstem": "schlafsüchtig",
    "schlafsüchtigsten": "schlafsüchtig",
    "schlafsüchtigster": "schlafsüchtig",
    "schlafsüchtigstes": "schlafsüchtig",
    "schlaft": "schlafen",
    "schlaftrunkene": "schlaftrunken",
    "schlaftrunkenem": "schlaftrunken",
    "schlaftrunkenen": "schlaftrunken",
    "schlaftrunkener": "schlaftrunken",
    "schlaftrunkenere": "schlaftrunken",
    "schlaftrunkenerem": "schlaftrunken",
    "schlaftrunkeneren": "schlaftrunken",
    "schlaftrunkenerer": "schlaftrunken",
    "schlaftrunkeneres": "schlaftrunken",
    "schlaftrunkenes": "schlaftrunken",
    "schlaftrunkenste": "schlaftrunken",
    "schlaftrunkenstem": "schlaftrunken",
    "schlaftrunkensten": "schlaftrunken",
    "schlaftrunkenster": "schlaftrunken",
    "schlaftrunkenstes": "schlaftrunken",
    "schlafwandele": "schlafwandeln",
    "schlafwandelnd": "schlafwandeln",
    "schlafwandelnde": "schlafwandelnd",
    "schlafwandelndem": "schlafwandelnd",
    "schlafwandelnden": "schlafwandelnd",
    "schlafwandelnder": "schlafwandelnd",
    "schlafwandelndes": "schlafwandelnd",
    "schlafwandelst": "schlafwandeln",
    "schlafwandelt": "schlafwandeln",
    "schlafwandelte": "schlafwandeln",
    "schlafwandelten": "schlafwandeln",
    "schlafwandeltest": "schlafwandeln",
    "schlafwandeltet": "schlafwandeln",
    "schlafwandle": "schlafwandeln",
    "schlafwandlerische": "schlafwandlerisch",
    "schlafwandlerischem": "schlafwandlerisch",
    "schlafwandlerischen": "schlafwandlerisch",
    "schlafwandlerischer": "schlafwandlerisch",
    "schlafwandlerisches": "schlafwandlerisch",
    "schlagartigem": "schlagartig",
    "schlagartigen": "schlagartig",
    "schlagartiger": "schlagartig",
    "schlagartiges": "schlagartig",
    "schlagbare": "schlagbar",
    "schlagbarem": "schlagbar",
    "schlagbaren": "schlagbar",
    "schlagbarer": "schlagbar",
    "schlagbares": "schlagbar",
    "schlagend": "schlagen",
    "schlagende": "schlagend",
    "schlagendem": "schlagend",
    "schlagenden": "schlagend",
    "schlagender": "schlagend",
    "schlagendes": "schlagend",
    "schlagest": "schlagen",
    "schlaget": "schlagen",
    "schlagfertige": "schlagfertig",
    "schlagfertigem": "schlagfertig",
    "schlagfertigen": "schlagfertig",
    "schlagfertiger": "schlagfertig",
    "schlagfertigere": "schlagfertig",
    "schlagfertigerem": "schlagfertig",
    "schlagfertigeren": "schlagfertig",
    "schlagfertigerer": "schlagfertig",
    "schlagfertigeres": "schlagfertig",
    "schlagfertiges": "schlagfertig",
    "schlagfertigste": "schlagfertig",
    "schlagfertigstem": "schlagfertig",
    "schlagfertigsten": "schlagfertig",
    "schlagfertigster": "schlagfertig",
    "schlagfertigstes": "schlagfertig",
    "schlagkräftige": "schlagkräftig",
    "schlagkräftigem": "schlagkräftig",
    "schlagkräftigen": "schlagkräftig",
    "schlagkräftiger": "schlagkräftig",
    "schlagkräftigere": "schlagkräftig",
    "schlagkräftigerem": "schlagkräftig",
    "schlagkräftigeren": "schlagkräftig",
    "schlagkräftigerer": "schlagkräftig",
    "schlagkräftigeres": "schlagkräftig",
    "schlagkräftiges": "schlagkräftig",
    "schlagkräftigste": "schlagkräftig",
    "schlagkräftigstem": "schlagkräftig",
    "schlagkräftigsten": "schlagkräftig",
    "schlagkräftigster": "schlagkräftig",
    "schlagkräftigstes": "schlagkräftig",
    "schlagt": "schlagen",
    "schlaksigem": "schlaksig",
    "schlaksigen": "schlaksig",
    "schlaksiger": "schlaksig",
    "schlaksigere": "schlaksig",
    "schlaksigerem": "schlaksig",
    "schlaksigeren": "schlaksig",
    "schlaksigerer": "schlaksig",
    "schlaksigeres": "schlaksig",
    "schlaksiges": "schlaksig",
    "schlaksigste": "schlaksig",
    "schlaksigstem": "schlaksig",
    "schlaksigsten": "schlaksig",
    "schlaksigster": "schlaksig",
    "schlaksigstes": "schlaksig",
    "schlammige": "schlammig",
    "schlammigem": "schlammig",
    "schlammigen": "schlammig",
    "schlammiger": "schlammig",
    "schlammigere": "schlammig",
    "schlammigerem": "schlammig",
    "schlammigeren": "schlammig",
    "schlammigerer": "schlammig",
    "schlammigeres": "schlammig",
    "schlammiges": "schlammig",
    "schlammigste": "schlammig",
    "schlammigstem": "schlammig",
    "schlammigsten": "schlammig",
    "schlammigster": "schlammig",
    "schlammigstes": "schlammig",
    "schlampe": "schlampen",
    "schlampend": "schlampen",
    "schlampende": "schlampend",
    "schlampendem": "schlampend",
    "schlampenden": "schlampend",
    "schlampender": "schlampend",
    "schlampendere": "schlampend",
    "schlampenderem": "schlampend",
    "schlampenderen": "schlampend",
    "schlampenderer": "schlampend",
    "schlampenderes": "schlampend",
    "schlampendes": "schlampend",
    "schlampendste": "schlampend",
    "schlampendstem": "schlampend",
    "schlampendsten": "schlampend",
    "schlampendster": "schlampend",
    "schlampendstes": "schlampend",
    "schlampest": "schlampen",
    "schlampet": "schlampen",
    "schlampige": "schlampig",
    "schlampigem": "schlampig",
    "schlampigen": "schlampig",
    "schlampiger": "schlampig",
    "schlampigere": "schlampig",
    "schlampigerem": "schlampig",
    "schlampigeren": "schlampig",
    "schlampigerer": "schlampig",
    "schlampigeres": "schlampig",
    "schlampiges": "schlampig",
    "schlampigste": "schlampig",
    "schlampigstem": "schlampig",
    "schlampigsten": "schlampig",
    "schlampigster": "schlampig",
    "schlampigstes": "schlampig",
    "schlampst": "schlampen",
    "schlampt": "schlampen",
    "schlampte": "schlampen",
    "schlampten": "schlampen",
    "schlamptest": "schlampen",
    "schlamptet": "schlampen",
    "schlang": "schlingen",
    "schlangenhafte": "schlangenhaft",
    "schlangenhaftem": "schlangenhaft",
    "schlangenhaften": "schlangenhaft",
    "schlangenhafter": "schlangenhaft",
    "schlangenhaftere": "schlangenhaft",
    "schlangenhafterem": "schlangenhaft",
    "schlangenhafteren": "schlangenhaft",
    "schlangenhafterer": "schlangenhaft",
    "schlangenhafteres": "schlangenhaft",
    "schlangenhaftes": "schlangenhaft",
    "schlangenhafteste": "schlangenhaft",
    "schlangenhaftestem": "schlangenhaft",
    "schlangenhaftesten": "schlangenhaft",
    "schlangenhaftester": "schlangenhaft",
    "schlangenhaftestes": "schlangenhaft",
    "schlangst": "schlingen",
    "schlangt": "schlingen",
    "schlanke": "schlank",
    "schlankem": "schlank",
    "schlanken": "schlank",
    "schlanker": "schlank",
    "schlankere": "schlank",
    "schlankerem": "schlank",
    "schlankeren": "schlank",
    "schlankerer": "schlank",
    "schlankeres": "schlank",
    "schlankes": "schlank",
    "schlankste": "schlank",
    "schlankstem": "schlank",
    "schlanksten": "schlank",
    "schlankster": "schlank",
    "schlankstes": "schlank",
    "schlappe": "schlappen",
    "schlappend": "schlappen",
    "schlappende": "schlappend",
    "schlappendem": "schlappend",
    "schlappenden": "schlappend",
    "schlappender": "schlappend",
    "schlappendes": "schlappend",
    "schlappest": "schlappen",
    "schlappet": "schlappen",
    "schlappgemacht": "schlappmachen",
    "schlappgemachte": "schlappgemacht",
    "schlappgemachtem": "schlappgemacht",
    "schlappgemachten": "schlappgemacht",
    "schlappgemachter": "schlappgemacht",
    "schlappgemachtes": "schlappgemacht",
    "schlappmache": "schlappmachen",
    "schlappmachend": "schlappmachen",
    "schlappmachende": "schlappmachend",
    "schlappmachendem": "schlappmachend",
    "schlappmachenden": "schlappmachend",
    "schlappmachender": "schlappmachend",
    "schlappmachendere": "schlappmachend",
    "schlappmachenderem": "schlappmachend",
    "schlappmachenderen": "schlappmachend",
    "schlappmachenderer": "schlappmachend",
    "schlappmachenderes": "schlappmachend",
    "schlappmachendes": "schlappmachend",
    "schlappmachendste": "schlappmachend",
    "schlappmachendstem": "schlappmachend",
    "schlappmachendsten": "schlappmachend",
    "schlappmachendster": "schlappmachend",
    "schlappmachendstes": "schlappmachend",
    "schlappmachest": "schlappmachen",
    "schlappmachet": "schlappmachen",
    "schlappmachst": "schlappmachen",
    "schlappmacht": "schlappmachen",
    "schlappmachte": "schlappmachen",
    "schlappmachten": "schlappmachen",
    "schlappmachtest": "schlappmachen",
    "schlappmachtet": "schlappmachen",
    "schlappst": "schlappen",
    "schlappt": "schlappen",
    "schlappte": "schlappen",
    "schlappten": "schlappen",
    "schlapptest": "schlappen",
    "schlapptet": "schlappen",
    "schlappzumachen": "schlappmachen",
    "schlauchend": "schlauchen",
    "schlauchende": "schlauchend",
    "schlauchendem": "schlauchend",
    "schlauchenden": "schlauchend",
    "schlauchender": "schlauchend",
    "schlauchendere": "schlauchend",
    "schlauchenderem": "schlauchend",
    "schlauchenderen": "schlauchend",
    "schlauchenderer": "schlauchend",
    "schlauchenderes": "schlauchend",
    "schlauchendes": "schlauchend",
    "schlauchendste": "schlauchend",
    "schlauchendstem": "schlauchend",
    "schlauchendsten": "schlauchend",
    "schlauchendster": "schlauchend",
    "schlauchendstes": "schlauchend",
    "schlauchest": "schlauchen",
    "schlauchet": "schlauchen",
    "schlauchst": "schlauchen",
    "schlaucht": "schlauchen",
    "schlauchte": "schlauchen",
    "schlauchten": "schlauchen",
    "schlauchtest": "schlauchen",
    "schlauchtet": "schlauchen",
    "schlaue": "schlau",
    "schlauem": "schlau",
    "schlauen": "schlau",
    "schlauer": "schlau",
    "schlauere": "schlau",
    "schlauerem": "schlau",
    "schlaueren": "schlau",
    "schlauerer": "schlau",
    "schlaueres": "schlau",
    "schlaues": "schlau",
    "schlauste": "schlau",
    "schlaustem": "schlau",
    "schlausten": "schlau",
    "schlauster": "schlau",
    "schlaustes": "schlau",
    "schlechte": "schlecht",
    "schlechtem": "schlecht",
    "schlechten": "schlecht",
    "schlechter": "schlecht",
    "schlechtere": "schlecht",
    "schlechterem": "schlecht",
    "schlechteren": "schlecht",
    "schlechterer": "schlecht",
    "schlechteres": "schlecht",
    "schlechtes": "schlecht",
    "schlechteste": "schlecht",
    "schlechtestem": "schlecht",
    "schlechtesten": "schlecht",
    "schlechtester": "schlecht",
    "schlechtestes": "schlecht",
    "schleckere": "schleckern",
    "schleckernd": "schleckern",
    "schleckernde": "schleckernd",
    "schleckerndem": "schleckernd",
    "schleckernden": "schleckernd",
    "schleckernder": "schleckernd",
    "schleckerndere": "schleckernd",
    "schleckernderem": "schleckernd",
    "schleckernderen": "schleckernd",
    "schleckernderer": "schleckernd",
    "schleckernderes": "schleckernd",
    "schleckerndes": "schleckernd",
    "schleckerndste": "schleckernd",
    "schleckerndstem": "schleckernd",
    "schleckerndsten": "schleckernd",
    "schleckerndster": "schleckernd",
    "schleckerndstes": "schleckernd",
    "schleckerst": "schleckern",
    "schleckert": "schleckern",
    "schleckerte": "schleckern",
    "schleckerten": "schleckern",
    "schleckertest": "schleckern",
    "schleckertet": "schleckern",
    "schleiche": "schleichen",
    "schleichend": "schleichen",
    "schleichende": "schleichend",
    "schleichendem": "schleichend",
    "schleichenden": "schleichend",
    "schleichender": "schleichend",
    "schleichendere": "schleichend",
    "schleichenderem": "schleichend",
    "schleichenderen": "schleichend",
    "schleichenderer": "schleichend",
    "schleichenderes": "schleichend",
    "schleichendes": "schleichend",
    "schleichendste": "schleichend",
    "schleichendstem": "schleichend",
    "schleichendsten": "schleichend",
    "schleichendster": "schleichend",
    "schleichendstes": "schleichend",
    "schleichest": "schleichen",
    "schleichet": "schleichen",
    "schleichst": "schleichen",
    "schleicht": "schleichen",
    "schleierhaftem": "schleierhaft",
    "schleierhaften": "schleierhaft",
    "schleierhafter": "schleierhaft",
    "schleierhaftere": "schleierhaft",
    "schleierhafterem": "schleierhaft",
    "schleierhafteren": "schleierhaft",
    "schleierhafterer": "schleierhaft",
    "schleierhafteres": "schleierhaft",
    "schleierhaftes": "schleierhaft",
    "schleierhafteste": "schleierhaft",
    "schleierhaftestem": "schleierhaft",
    "schleierhaftesten": "schleierhaft",
    "schleierhaftester": "schleierhaft",
    "schleierhaftestes": "schleierhaft",
    "schleifend": "schleifen",
    "schleifende": "schleifend",
    "schleifendem": "schleifend",
    "schleifenden": "schleifend",
    "schleifender": "schleifend",
    "schleifendes": "schleifend",
    "schleifest": "schleifen",
    "schleifet": "schleifen",
    "schleifst": "schleifen",
    "schleift": "schleifen",
    "schleifte": "schleifen",
    "schleiften": "schleifen",
    "schleiftest": "schleifen",
    "schleiftet": "schleifen",
    "schleimend": "schleimen",
    "schleimende": "schleimend",
    "schleimendem": "schleimend",
    "schleimenden": "schleimend",
    "schleimender": "schleimend",
    "schleimendere": "schleimend",
    "schleimenderem": "schleimend",
    "schleimenderen": "schleimend",
    "schleimenderer": "schleimend",
    "schleimenderes": "schleimend",
    "schleimendes": "schleimend",
    "schleimendste": "schleimend",
    "schleimendstem": "schleimend",
    "schleimendsten": "schleimend",
    "schleimendster": "schleimend",
    "schleimendstes": "schleimend",
    "schleimest": "schleimen",
    "schleimet": "schleimen",
    "schleimige": "schleimig",
    "schleimigem": "schleimig",
    "schleimigen": "schleimig",
    "schleimiger": "schleimig",
    "schleimigere": "schleimig",
    "schleimigerem": "schleimig",
    "schleimigeren": "schleimig",
    "schleimigerer": "schleimig",
    "schleimigeres": "schleimig",
    "schleimiges": "schleimig",
    "schleimigste": "schleimig",
    "schleimigstem": "schleimig",
    "schleimigsten": "schleimig",
    "schleimigster": "schleimig",
    "schleimigstes": "schleimig",
    "schleimst": "schleimen",
    "schleimt": "schleimen",
    "schleimte": "schleimen",
    "schleimten": "schleimen",
    "schleimtest": "schleimen",
    "schleimtet": "schleimen",
    "schleiße": "schleißen",
    "schleißend": "schleißen",
    "schleißende": "schleißend",
    "schleißendem": "schleißend",
    "schleißenden": "schleißend",
    "schleißender": "schleißend",
    "schleißendes": "schleißend",
    "schleißest": "schleißen",
    "schleißet": "schleißen",
    "schleißt": "schleißen",
    "schleißte": "schleißen",
    "schleißten": "schleißen",
    "schleißtest": "schleißen",
    "schleißtet": "schleißen",
    "schlemme": "schlemmen",
    "schlemmend": "schlemmen",
    "schlemmende": "schlemmend",
    "schlemmendem": "schlemmend",
    "schlemmenden": "schlemmend",
    "schlemmender": "schlemmend",
    "schlemmendere": "schlemmend",
    "schlemmenderem": "schlemmend",
    "schlemmenderen": "schlemmend",
    "schlemmenderer": "schlemmend",
    "schlemmenderes": "schlemmend",
    "schlemmendes": "schlemmend",
    "schlemmendste": "schlemmend",
    "schlemmendstem": "schlemmend",
    "schlemmendsten": "schlemmend",
    "schlemmendster": "schlemmend",
    "schlemmendstes": "schlemmend",
    "schlemmest": "schlemmen",
    "schlemmet": "schlemmen",
    "schlemmst": "schlemmen",
    "schlemmt": "schlemmen",
    "schlemmte": "schlemmen",
    "schlemmten": "schlemmen",
    "schlemmtest": "schlemmen",
    "schlemmtet": "schlemmen",
    "schlendere": "schlendern",
    "schlendernd": "schlendern",
    "schlendernde": "schlendernd",
    "schlenderndem": "schlendernd",
    "schlendernden": "schlendernd",
    "schlendernder": "schlendernd",
    "schlenderndere": "schlendernd",
    "schlendernderem": "schlendernd",
    "schlendernderen": "schlendernd",
    "schlendernderer": "schlendernd",
    "schlendernderes": "schlendernd",
    "schlenderndes": "schlendernd",
    "schlenderndste": "schlendernd",
    "schlenderndstem": "schlendernd",
    "schlenderndsten": "schlendernd",
    "schlenderndster": "schlendernd",
    "schlenderndstes": "schlendernd",
    "schlenderst": "schlendern",
    "schlendert": "schlendern",
    "schlenderte": "schlendern",
    "schlenderten": "schlendern",
    "schlendertest": "schlendern",
    "schlendertet": "schlendern",
    "schlenkere": "schlenkern",
    "schlenkernd": "schlenkern",
    "schlenkernde": "schlenkernd",
    "schlenkerndem": "schlenkernd",
    "schlenkernden": "schlenkernd",
    "schlenkernder": "schlenkernd",
    "schlenkerndere": "schlenkernd",
    "schlenkernderem": "schlenkernd",
    "schlenkernderen": "schlenkernd",
    "schlenkernderer": "schlenkernd",
    "schlenkernderes": "schlenkernd",
    "schlenkerndes": "schlenkernd",
    "schlenkerndste": "schlenkernd",
    "schlenkerndstem": "schlenkernd",
    "schlenkerndsten": "schlenkernd",
    "schlenkerndster": "schlenkernd",
    "schlenkerndstes": "schlenkernd",
    "schlenkerst": "schlenkern",
    "schlenkert": "schlenkern",
    "schlenkerte": "schlenkern",
    "schlenkerten": "schlenkern",
    "schlenkertest": "schlenkern",
    "schlenkertet": "schlenkern",
    "schlenze": "schlenzen",
    "schlenzend": "schlenzen",
    "schlenzende": "schlenzend",
    "schlenzendem": "schlenzend",
    "schlenzenden": "schlenzend",
    "schlenzender": "schlenzend",
    "schlenzendes": "schlenzend",
    "schlenzest": "schlenzen",
    "schlenzet": "schlenzen",
    "schlenzt": "schlenzen",
    "schlenzte": "schlenzen",
    "schlenzten": "schlenzen",
    "schlenztest": "schlenzen",
    "schlenztet": "schlenzen",
    "schleppe": "schleppen",
    "schleppend": "schleppen",
    "schleppende": "schleppend",
    "schleppendem": "schleppend",
    "schleppenden": "schleppend",
    "schleppender": "schleppend",
    "schleppendes": "schleppend",
    "schleppest": "schleppen",
    "schleppet": "schleppen",
    "schleppst": "schleppen",
    "schleppt": "schleppen",
    "schleppte": "schleppen",
    "schleppten": "schleppen",
    "schlepptest": "schleppen",
    "schlepptet": "schleppen",
    "schlesische": "schlesisch",
    "schlesischem": "schlesisch",
    "schlesischen": "schlesisch",
    "schlesischer": "schlesisch",
    "schlesisches": "schlesisch",
    "schleudere": "schleudern",
    "schleudernd": "schleudern",
    "schleudernde": "schleudernd",
    "schleuderndem": "schleudernd",
    "schleudernden": "schleudernd",
    "schleudernder": "schleudernd",
    "schleuderndere": "schleudernd",
    "schleudernderem": "schleudernd",
    "schleudernderen": "schleudernd",
    "schleudernderer": "schleudernd",
    "schleudernderes": "schleudernd",
    "schleuderndes": "schleudernd",
    "schleuderndste": "schleudernd",
    "schleuderndstem": "schleudernd",
    "schleuderndsten": "schleudernd",
    "schleuderndster": "schleudernd",
    "schleuderndstes": "schleudernd",
    "schleuderst": "schleudern",
    "schleudert": "schleudern",
    "schleuderte": "schleudern",
    "schleuderten": "schleudern",
    "schleudertest": "schleudern",
    "schleudertet": "schleudern",
    "schleusend": "schleusen",
    "schleusende": "schleusend",
    "schleusendem": "schleusend",
    "schleusenden": "schleusend",
    "schleusender": "schleusend",
    "schleusendes": "schleusend",
    "schleusest": "schleusen",
    "schleuset": "schleusen",
    "schleust": "schleusen",
    "schleuste": "schleusen",
    "schleusten": "schleusen",
    "schleustest": "schleusen",
    "schleustet": "schleusen",
    "schlich": "schleichen",
    "schliche": "schleichen",
    "schlichen": "schleichen",
    "schlichest": "schleichen",
    "schlichet": "schleichen",
    "schlichst": "schleichen",
    "schlicht": "schleichen",
    "schlichte": "schlicht",
    "schlichtem": "schlicht",
    "schlichten": "schlicht",
    "schlichter": "schlicht",
    "schlichtere": "schlicht",
    "schlichterem": "schlicht",
    "schlichteren": "schlicht",
    "schlichterer": "schlicht",
    "schlichteres": "schlicht",
    "schlichtes": "schlicht",
    "schlichteste": "schlicht",
    "schlichtestem": "schlicht",
    "schlichtesten": "schlicht",
    "schlichtester": "schlicht",
    "schlichtestes": "schlicht",
    "schlief": "schlafen",
    "schliefe": "schlafen",
    "schliefen": "schlafen",
    "schliefest": "schlafen",
    "schliefet": "schlafen",
    "schliefst": "schlafen",
    "schlieft": "schlafen",
    "schlierigem": "schlierig",
    "schlierigen": "schlierig",
    "schlieriger": "schlierig",
    "schlierigere": "schlierig",
    "schlierigerem": "schlierig",
    "schlierigeren": "schlierig",
    "schlierigerer": "schlierig",
    "schlierigeres": "schlierig",
    "schlieriges": "schlierig",
    "schlierigste": "schlierig",
    "schlierigstem": "schlierig",
    "schlierigsten": "schlierig",
    "schlierigster": "schlierig",
    "schlierigstes": "schlierig",
    "schließe": "schließen",
    "schließend": "schließen",
    "schließende": "schließend",
    "schließendem": "schließend",
    "schließenden": "schließend",
    "schließender": "schließend",
    "schließendes": "schließend",
    "schließest": "schließen",
    "schließet": "schließen",
    "schließt": "schließen",
    "schliffe": "schleifen",
    "schliffest": "schleifen",
    "schliffet": "schleifen",
    "schliffst": "schleifen",
    "schlifft": "schleifen",
    "schlimme": "schlimm",
    "schlimmem": "schlimm",
    "schlimmen": "schlimm",
    "schlimmer": "schlimm",
    "schlimmere": "schlimm",
    "schlimmerem": "schlimm",
    "schlimmeren": "schlimm",
    "schlimmerer": "schlimm",
    "schlimmeres": "schlimm",
    "schlimmes": "schlimm",
    "schlimmste": "schlimm",
    "schlimmstem": "schlimm",
    "schlimmsten": "schlimm",
    "schlimmster": "schlimm",
    "schlimmstes": "schlimm",
    "schlinge": "schlingen",
    "schlingend": "schlingen",
    "schlingende": "schlingend",
    "schlingendem": "schlingend",
    "schlingenden": "schlingend",
    "schlingender": "schlingend",
    "schlingendere": "schlingend",
    "schlingenderem": "schlingend",
    "schlingenderen": "schlingend",
    "schlingenderer": "schlingend",
    "schlingenderes": "schlingend",
    "schlingendes": "schlingend",
    "schlingendste": "schlingend",
    "schlingendstem": "schlingend",
    "schlingendsten": "schlingend",
    "schlingendster": "schlingend",
    "schlingendstes": "schlingend",
    "schlingere": "schlingern",
    "schlingernd": "schlingern",
    "schlingernde": "schlingernd",
    "schlingerndem": "schlingernd",
    "schlingernden": "schlingernd",
    "schlingernder": "schlingernd",
    "schlingerndere": "schlingernd",
    "schlingernderem": "schlingernd",
    "schlingernderen": "schlingernd",
    "schlingernderer": "schlingernd",
    "schlingernderes": "schlingernd",
    "schlingerndes": "schlingernd",
    "schlingerndste": "schlingernd",
    "schlingerndstem": "schlingernd",
    "schlingerndsten": "schlingernd",
    "schlingerndster": "schlingernd",
    "schlingerndstes": "schlingernd",
    "schlingerst": "schlingern",
    "schlingert": "schlingern",
    "schlingerte": "schlingern",
    "schlingerten": "schlingern",
    "schlingertest": "schlingern",
    "schlingertet": "schlingern",
    "schlingest": "schlingen",
    "schlinget": "schlingen",
    "schlingst": "schlingen",
    "schlingt": "schlingen",
    "schlisse": "schleißen",
    "schlissen": "schleißen",
    "schlissest": "schleißen",
    "schlisset": "schleißen",
    "schlittere": "schlittern",
    "schlitternd": "schlittern",
    "schlitternde": "schlitternd",
    "schlitterndem": "schlitternd",
    "schlitternden": "schlitternd",
    "schlitternder": "schlitternd",
    "schlitterndes": "schlitternd",
    "schlitterst": "schlittern",
    "schlittert": "schlittern",
    "schlitterte": "schlittern",
    "schlitterten": "schlittern",
    "schlittertest": "schlittern",
    "schlittertet": "schlittern",
    "schlitze": "schlitzen",
    "schlitzend": "schlitzen",
    "schlitzende": "schlitzend",
    "schlitzendem": "schlitzend",
    "schlitzenden": "schlitzend",
    "schlitzender": "schlitzend",
    "schlitzendes": "schlitzend",
    "schlitzest": "schlitzen",
    "schlitzet": "schlitzen",
    "schlitzohrigem": "schlitzohrig",
    "schlitzohrigen": "schlitzohrig",
    "schlitzohriger": "schlitzohrig",
    "schlitzohrigere": "schlitzohrig",
    "schlitzohrigerem": "schlitzohrig",
    "schlitzohrigeren": "schlitzohrig",
    "schlitzohrigerer": "schlitzohrig",
    "schlitzohrigeres": "schlitzohrig",
    "schlitzohriges": "schlitzohrig",
    "schlitzohrigste": "schlitzohrig",
    "schlitzohrigstem": "schlitzohrig",
    "schlitzohrigsten": "schlitzohrig",
    "schlitzohrigster": "schlitzohrig",
    "schlitzohrigstes": "schlitzohrig",
    "schlitzt": "schlitzen",
    "schlitzte": "schlitzen",
    "schlitzten": "schlitzen",
    "schlitztest": "schlitzen",
    "schlitztet": "schlitzen",
    "schlitzäugigem": "schlitzäugig",
    "schlitzäugigen": "schlitzäugig",
    "schlitzäugiger": "schlitzäugig",
    "schlitzäugiges": "schlitzäugig",
    "schliß": "schleißen",
    "schlißt": "schleißen",
    "schlossen": "schließen",
    "schlossere": "schlossern",
    "schlossernd": "schlossern",
    "schlossernde": "schlossernd",
    "schlosserndem": "schlossernd",
    "schlossernden": "schlossernd",
    "schlossernder": "schlossernd",
    "schlosserndes": "schlossernd",
    "schlosserst": "schlossern",
    "schlossert": "schlossern",
    "schlosserte": "schlossern",
    "schlosserten": "schlossern",
    "schlossertest": "schlossern",
    "schlossertet": "schlossern",
    "schlottere": "schlottern",
    "schlotterige": "schlotterig",
    "schlotterigem": "schlotterig",
    "schlotterigen": "schlotterig",
    "schlotteriger": "schlotterig",
    "schlotterigere": "schlotterig",
    "schlotterigerem": "schlotterig",
    "schlotterigeren": "schlotterig",
    "schlotterigerer": "schlotterig",
    "schlotterigeres": "schlotterig",
    "schlotteriges": "schlotterig",
    "schlotterigste": "schlotterig",
    "schlotterigstem": "schlotterig",
    "schlotterigsten": "schlotterig",
    "schlotterigster": "schlotterig",
    "schlotterigstes": "schlotterig",
    "schlotternd": "schlottern",
    "schlotternde": "schlotternd",
    "schlotterndem": "schlotternd",
    "schlotternden": "schlotternd",
    "schlotternder": "schlotternd",
    "schlotterndere": "schlotternd",
    "schlotternderem": "schlotternd",
    "schlotternderen": "schlotternd",
    "schlotternderer": "schlotternd",
    "schlotternderes": "schlotternd",
    "schlotterndes": "schlotternd",
    "schlotterndste": "schlotternd",
    "schlotterndstem": "schlotternd",
    "schlotterndsten": "schlotternd",
    "schlotterndster": "schlotternd",
    "schlotterndstes": "schlotternd",
    "schlotterst": "schlottern",
    "schlottert": "schlottern",
    "schlotterte": "schlottern",
    "schlotterten": "schlottern",
    "schlottertest": "schlottern",
    "schlottertet": "schlottern",
    "schloß": "schließen",
    "schloßt": "schließen",
    "schluchze": "schluchzen",
    "schluchzend": "schluchzen",
    "schluchzende": "schluchzend",
    "schluchzendem": "schluchzend",
    "schluchzenden": "schluchzend",
    "schluchzender": "schluchzend",
    "schluchzendere": "schluchzend",
    "schluchzenderem": "schluchzend",
    "schluchzenderen": "schluchzend",
    "schluchzenderer": "schluchzend",
    "schluchzenderes": "schluchzend",
    "schluchzendes": "schluchzend",
    "schluchzendste": "schluchzend",
    "schluchzendstem": "schluchzend",
    "schluchzendsten": "schluchzend",
    "schluchzendster": "schluchzend",
    "schluchzendstes": "schluchzend",
    "schluchzest": "schluchzen",
    "schluchzet": "schluchzen",
    "schluchzt": "schluchzen",
    "schluchzte": "schluchzen",
    "schluchzten": "schluchzen",
    "schluchztest": "schluchzen",
    "schluchztet": "schluchzen",
    "schluckend": "schlucken",
    "schluckende": "schluckend",
    "schluckendem": "schluckend",
    "schluckenden": "schluckend",
    "schluckender": "schluckend",
    "schluckendes": "schluckend",
    "schluckest": "schlucken",
    "schlucket": "schlucken",
    "schluckst": "schlucken",
    "schluckt": "schlucken",
    "schluckte": "schlucken",
    "schluckten": "schlucken",
    "schlucktest": "schlucken",
    "schlucktet": "schlucken",
    "schludere": "schludern",
    "schluderige": "schluderig",
    "schluderigem": "schluderig",
    "schluderigen": "schluderig",
    "schluderiger": "schluderig",
    "schluderigere": "schluderig",
    "schluderigerem": "schluderig",
    "schluderigeren": "schluderig",
    "schluderigerer": "schluderig",
    "schluderigeres": "schluderig",
    "schluderiges": "schluderig",
    "schluderigste": "schluderig",
    "schluderigstem": "schluderig",
    "schluderigsten": "schluderig",
    "schluderigster": "schluderig",
    "schluderigstes": "schluderig",
    "schludernd": "schludern",
    "schludernde": "schludernd",
    "schluderndem": "schludernd",
    "schludernden": "schludernd",
    "schludernder": "schludernd",
    "schluderndere": "schludernd",
    "schludernderem": "schludernd",
    "schludernderen": "schludernd",
    "schludernderer": "schludernd",
    "schludernderes": "schludernd",
    "schluderndes": "schludernd",
    "schluderndste": "schludernd",
    "schluderndstem": "schludernd",
    "schluderndsten": "schludernd",
    "schluderndster": "schludernd",
    "schluderndstes": "schludernd",
    "schluderst": "schludern",
    "schludert": "schludern",
    "schluderte": "schludern",
    "schluderten": "schludern",
    "schludertest": "schludern",
    "schludertet": "schludern",
    "schludrigem": "schludrig",
    "schludrigen": "schludrig",
    "schludriger": "schludrig",
    "schludrigere": "schludrig",
    "schludrigerem": "schludrig",
    "schludrigeren": "schludrig",
    "schludrigerer": "schludrig",
    "schludrigeres": "schludrig",
    "schludriges": "schludrig",
    "schludrigste": "schludrig",
    "schludrigstem": "schludrig",
    "schludrigsten": "schludrig",
    "schludrigster": "schludrig",
    "schludrigstes": "schludrig",
    "schlug": "schlagen",
    "schlugen": "schlagen",
    "schlugst": "schlagen",
    "schlugt": "schlagen",
    "schlummere": "schlummern",
    "schlummernd": "schlummern",
    "schlummernde": "schlummernd",
    "schlummerndem": "schlummernd",
    "schlummernden": "schlummernd",
    "schlummernder": "schlummernd",
    "schlummerndere": "schlummernd",
    "schlummernderem": "schlummernd",
    "schlummernderen": "schlummernd",
    "schlummernderer": "schlummernd",
    "schlummernderes": "schlummernd",
    "schlummerndes": "schlummernd",
    "schlummerndste": "schlummernd",
    "schlummerndstem": "schlummernd",
    "schlummerndsten": "schlummernd",
    "schlummerndster": "schlummernd",
    "schlummerndstes": "schlummernd",
    "schlummerst": "schlummern",
    "schlummert": "schlummern",
    "schlummerte": "schlummern",
    "schlummerten": "schlummern",
    "schlummertest": "schlummern",
    "schlummertet": "schlummern",
    "schlunzigem": "schlunzig",
    "schlunzigen": "schlunzig",
    "schlunziger": "schlunzig",
    "schlunzigere": "schlunzig",
    "schlunzigerem": "schlunzig",
    "schlunzigeren": "schlunzig",
    "schlunzigerer": "schlunzig",
    "schlunzigeres": "schlunzig",
    "schlunziges": "schlunzig",
    "schlunzigste": "schlunzig",
    "schlunzigstem": "schlunzig",
    "schlunzigsten": "schlunzig",
    "schlunzigster": "schlunzig",
    "schlunzigstes": "schlunzig",
    "schläfere": "schläfern",
    "schläfernd": "schläfern",
    "schläfernde": "schläfernd",
    "schläferndem": "schläfernd",
    "schläfernden": "schläfernd",
    "schläfernder": "schläfernd",
    "schläferndes": "schläfernd",
    "schläferst": "schläfern",
    "schläfert": "schläfern",
    "schläferte": "schläfern",
    "schläferten": "schläfern",
    "schläfertest": "schläfern",
    "schläfertet": "schläfern",
    "schläfrige": "schläfrig",
    "schläfrigem": "schläfrig",
    "schläfrigen": "schläfrig",
    "schläfriger": "schläfrig",
    "schläfrigere": "schläfrig",
    "schläfrigerem": "schläfrig",
    "schläfrigeren": "schläfrig",
    "schläfrigerer": "schläfrig",
    "schläfrigeres": "schläfrig",
    "schläfriges": "schläfrig",
    "schläfrigste": "schläfrig",
    "schläfrigstem": "schläfrig",
    "schläfrigsten": "schläfrig",
    "schläfrigster": "schläfrig",
    "schläfrigstes": "schläfrig",
    "schläfst": "schlafen",
    "schläft": "schlafen",
    "schlägst": "schlagen",
    "schlägt": "schlagen",
    "schlämme": "schlämmen",
    "schlämmend": "schlämmen",
    "schlämmende": "schlämmend",
    "schlämmendem": "schlämmend",
    "schlämmenden": "schlämmend",
    "schlämmender": "schlämmend",
    "schlämmendere": "schlämmend",
    "schlämmenderem": "schlämmend",
    "schlämmenderen": "schlämmend",
    "schlämmenderer": "schlämmend",
    "schlämmenderes": "schlämmend",
    "schlämmendes": "schlämmend",
    "schlämmendste": "schlämmend",
    "schlämmendstem": "schlämmend",
    "schlämmendsten": "schlämmend",
    "schlämmendster": "schlämmend",
    "schlämmendstes": "schlämmend",
    "schlämmest": "schlämmen",
    "schlämmet": "schlämmen",
    "schlämmst": "schlämmen",
    "schlämmt": "schlämmen",
    "schlämmte": "schlämmen",
    "schlämmten": "schlämmen",
    "schlämmtest": "schlämmen",
    "schlämmtet": "schlämmen",
    "schlänge": "schlingen",
    "schlängele": "schlängeln",
    "schlängelnd": "schlängeln",
    "schlängelnde": "schlängelnd",
    "schlängelndem": "schlängelnd",
    "schlängelnden": "schlängelnd",
    "schlängelnder": "schlängelnd",
    "schlängelndere": "schlängelnd",
    "schlängelnderem": "schlängelnd",
    "schlängelnderen": "schlängelnd",
    "schlängelnderer": "schlängelnd",
    "schlängelnderes": "schlängelnd",
    "schlängelndes": "schlängelnd",
    "schlängelndste": "schlängelnd",
    "schlängelndstem": "schlängelnd",
    "schlängelndsten": "schlängelnd",
    "schlängelndster": "schlängelnd",
    "schlängelndstes": "schlängelnd",
    "schlängelst": "schlängeln",
    "schlängelt": "schlängeln",
    "schlängelte": "schlängeln",
    "schlängelten": "schlängeln",
    "schlängeltest": "schlängeln",
    "schlängeltet": "schlängeln",
    "schlängen": "schlingen",
    "schlängest": "schlingen",
    "schlänget": "schlingen",
    "schlängle": "schlängeln",
    "schlösse": "schließen",
    "schlössen": "schließen",
    "schlössest": "schließen",
    "schlösset": "schließen",
    "schlüge": "schlagen",
    "schlügen": "schlagen",
    "schlügest": "schlagen",
    "schlüget": "schlagen",
    "schlüpfe": "schlüpfen",
    "schlüpfend": "schlüpfen",
    "schlüpfende": "schlüpfend",
    "schlüpfendem": "schlüpfend",
    "schlüpfenden": "schlüpfend",
    "schlüpfender": "schlüpfend",
    "schlüpfendes": "schlüpfend",
    "schlüpfest": "schlüpfen",
    "schlüpfet": "schlüpfen",
    "schlüpfrigem": "schlüpfrig",
    "schlüpfrigen": "schlüpfrig",
    "schlüpfriger": "schlüpfrig",
    "schlüpfrigere": "schlüpfrig",
    "schlüpfrigerem": "schlüpfrig",
    "schlüpfrigeren": "schlüpfrig",
    "schlüpfrigerer": "schlüpfrig",
    "schlüpfrigeres": "schlüpfrig",
    "schlüpfriges": "schlüpfrig",
    "schlüpfrigste": "schlüpfrig",
    "schlüpfrigstem": "schlüpfrig",
    "schlüpfrigsten": "schlüpfrig",
    "schlüpfrigster": "schlüpfrig",
    "schlüpfrigstes": "schlüpfrig",
    "schlüpfst": "schlüpfen",
    "schlüpft": "schlüpfen",
    "schlüpfte": "schlüpfen",
    "schlüpften": "schlüpfen",
    "schlüpftest": "schlüpfen",
    "schlüpftet": "schlüpfen",
    "schlürfe": "schlürfen",
    "schlürfend": "schlürfen",
    "schlürfende": "schlürfend",
    "schlürfendem": "schlürfend",
    "schlürfenden": "schlürfend",
    "schlürfender": "schlürfend",
    "schlürfendere": "schlürfend",
    "schlürfenderem": "schlürfend",
    "schlürfenderen": "schlürfend",
    "schlürfenderer": "schlürfend",
    "schlürfenderes": "schlürfend",
    "schlürfendes": "schlürfend",
    "schlürfendste": "schlürfend",
    "schlürfendstem": "schlürfend",
    "schlürfendsten": "schlürfend",
    "schlürfendster": "schlürfend",
    "schlürfendstes": "schlürfend",
    "schlürfest": "schlürfen",
    "schlürfet": "schlürfen",
    "schlürfst": "schlürfen",
    "schlürft": "schlürfen",
    "schlürfte": "schlürfen",
    "schlürften": "schlürfen",
    "schlürftest": "schlürfen",
    "schlürftet": "schlürfen",
    "schlüssele": "schlüsseln",
    "schlüsselfertige": "schlüsselfertig",
    "schlüsselfertigem": "schlüsselfertig",
    "schlüsselfertigen": "schlüsselfertig",
    "schlüsselfertiger": "schlüsselfertig",
    "schlüsselfertiges": "schlüsselfertig",
    "schlüsselnd": "schlüsseln",
    "schlüsselnde": "schlüsselnd",
    "schlüsselndem": "schlüsselnd",
    "schlüsselnden": "schlüsselnd",
    "schlüsselnder": "schlüsselnd",
    "schlüsselndes": "schlüsselnd",
    "schlüsselst": "schlüsseln",
    "schlüsselt": "schlüsseln",
    "schlüsselte": "schlüsseln",
    "schlüsselten": "schlüsseln",
    "schlüsseltest": "schlüsseln",
    "schlüsseltet": "schlüsseln",
    "schlüssigem": "schlüssig",
    "schlüssigen": "schlüssig",
    "schlüssiger": "schlüssig",
    "schlüssigere": "schlüssig",
    "schlüssigerem": "schlüssig",
    "schlüssigeren": "schlüssig",
    "schlüssigerer": "schlüssig",
    "schlüssigeres": "schlüssig",
    "schlüssiges": "schlüssig",
    "schlüssigste": "schlüssig",
    "schlüssigstem": "schlüssig",
    "schlüssigsten": "schlüssig",
    "schlüssigster": "schlüssig",
    "schlüssigstes": "schlüssig",
    "schlüssle": "schlüsseln",
    "schmachte": "schmachten",
    "schmachtend": "schmachten",
    "schmachtende": "schmachtend",
    "schmachtendem": "schmachtend",
    "schmachtenden": "schmachtend",
    "schmachtender": "schmachtend",
    "schmachtendere": "schmachtend",
    "schmachtenderem": "schmachtend",
    "schmachtenderen": "schmachtend",
    "schmachtenderer": "schmachtend",
    "schmachtenderes": "schmachtend",
    "schmachtendes": "schmachtend",
    "schmachtendste": "schmachtend",
    "schmachtendstem": "schmachtend",
    "schmachtendsten": "schmachtend",
    "schmachtendster": "schmachtend",
    "schmachtendstes": "schmachtend",
    "schmachtest": "schmachten",
    "schmachtet": "schmachten",
    "schmachtete": "schmachten",
    "schmachteten": "schmachten",
    "schmachtetest": "schmachten",
    "schmachtetet": "schmachten",
    "schmachvolle": "schmachvoll",
    "schmachvollem": "schmachvoll",
    "schmachvollen": "schmachvoll",
    "schmachvoller": "schmachvoll",
    "schmachvollere": "schmachvoll",
    "schmachvollerem": "schmachvoll",
    "schmachvolleren": "schmachvoll",
    "schmachvollerer": "schmachvoll",
    "schmachvolleres": "schmachvoll",
    "schmachvolles": "schmachvoll",
    "schmachvollste": "schmachvoll",
    "schmachvollstem": "schmachvoll",
    "schmachvollsten": "schmachvoll",
    "schmachvollster": "schmachvoll",
    "schmachvollstes": "schmachvoll",
    "schmackhafte": "schmackhaft",
    "schmackhaftem": "schmackhaft",
    "schmackhaften": "schmackhaft",
    "schmackhafter": "schmackhaft",
    "schmackhaftere": "schmackhaft",
    "schmackhafterem": "schmackhaft",
    "schmackhafteren": "schmackhaft",
    "schmackhafterer": "schmackhaft",
    "schmackhafteres": "schmackhaft",
    "schmackhaftes": "schmackhaft",
    "schmackhafteste": "schmackhaft",
    "schmackhaftestem": "schmackhaft",
    "schmackhaftesten": "schmackhaft",
    "schmackhaftester": "schmackhaft",
    "schmackhaftestes": "schmackhaft",
    "schmalbrüstige": "schmalbrüstig",
    "schmalbrüstigem": "schmalbrüstig",
    "schmalbrüstigen": "schmalbrüstig",
    "schmalbrüstiger": "schmalbrüstig",
    "schmalbrüstigere": "schmalbrüstig",
    "schmalbrüstigerem": "schmalbrüstig",
    "schmalbrüstigeren": "schmalbrüstig",
    "schmalbrüstigerer": "schmalbrüstig",
    "schmalbrüstigeres": "schmalbrüstig",
    "schmalbrüstiges": "schmalbrüstig",
    "schmalbrüstigste": "schmalbrüstig",
    "schmalbrüstigstem": "schmalbrüstig",
    "schmalbrüstigsten": "schmalbrüstig",
    "schmalbrüstigster": "schmalbrüstig",
    "schmalbrüstigstes": "schmalbrüstig",
    "schmale": "schmal",
    "schmalem": "schmal",
    "schmalen": "schmal",
    "schmaler": "schmal",
    "schmalere": "schmal",
    "schmalerem": "schmal",
    "schmaleren": "schmal",
    "schmalerer": "schmal",
    "schmaleres": "schmal",
    "schmales": "schmal",
    "schmalspurige": "schmalspurig",
    "schmalspurigem": "schmalspurig",
    "schmalspurigen": "schmalspurig",
    "schmalspuriger": "schmalspurig",
    "schmalspurigere": "schmalspurig",
    "schmalspurigerem": "schmalspurig",
    "schmalspurigeren": "schmalspurig",
    "schmalspurigerer": "schmalspurig",
    "schmalspurigeres": "schmalspurig",
    "schmalspuriges": "schmalspurig",
    "schmalspurigste": "schmalspurig",
    "schmalspurigstem": "schmalspurig",
    "schmalspurigsten": "schmalspurig",
    "schmalspurigster": "schmalspurig",
    "schmalspurigstes": "schmalspurig",
    "schmalste": "schmal",
    "schmalstem": "schmal",
    "schmalsten": "schmal",
    "schmalster": "schmal",
    "schmalstes": "schmal",
    "schmalzigem": "schmalzig",
    "schmalzigen": "schmalzig",
    "schmalziger": "schmalzig",
    "schmalzigere": "schmalzig",
    "schmalzigerem": "schmalzig",
    "schmalzigeren": "schmalzig",
    "schmalzigerer": "schmalzig",
    "schmalzigeres": "schmalzig",
    "schmalziges": "schmalzig",
    "schmalzigste": "schmalzig",
    "schmalzigstem": "schmalzig",
    "schmalzigsten": "schmalzig",
    "schmalzigster": "schmalzig",
    "schmalzigstes": "schmalzig",
    "schmarotze": "schmarotzen",
    "schmarotzend": "schmarotzen",
    "schmarotzende": "schmarotzend",
    "schmarotzendem": "schmarotzend",
    "schmarotzenden": "schmarotzend",
    "schmarotzender": "schmarotzend",
    "schmarotzendere": "schmarotzend",
    "schmarotzenderem": "schmarotzend",
    "schmarotzenderen": "schmarotzend",
    "schmarotzenderer": "schmarotzend",
    "schmarotzenderes": "schmarotzend",
    "schmarotzendes": "schmarotzend",
    "schmarotzendste": "schmarotzend",
    "schmarotzendstem": "schmarotzend",
    "schmarotzendsten": "schmarotzend",
    "schmarotzendster": "schmarotzend",
    "schmarotzendstes": "schmarotzend",
    "schmarotzerischem": "schmarotzerisch",
    "schmarotzerischen": "schmarotzerisch",
    "schmarotzerischer": "schmarotzerisch",
    "schmarotzerischere": "schmarotzerisch",
    "schmarotzerischerem": "schmarotzerisch",
    "schmarotzerischeren": "schmarotzerisch",
    "schmarotzerischerer": "schmarotzerisch",
    "schmarotzerischeres": "schmarotzerisch",
    "schmarotzerisches": "schmarotzerisch",
    "schmarotzerischste": "schmarotzerisch",
    "schmarotzerischstem": "schmarotzerisch",
    "schmarotzerischsten": "schmarotzerisch",
    "schmarotzerischster": "schmarotzerisch",
    "schmarotzerischstes": "schmarotzerisch",
    "schmarotzest": "schmarotzen",
    "schmarotzet": "schmarotzen",
    "schmarotzt": "schmarotzen",
    "schmarotzte": "schmarotzen",
    "schmarotztem": "schmarotzt",
    "schmarotzten": "schmarotzen",
    "schmarotzter": "schmarotzt",
    "schmarotztes": "schmarotzt",
    "schmarotztest": "schmarotzen",
    "schmarotztet": "schmarotzen",
    "schmatze": "schmatzen",
    "schmatzend": "schmatzen",
    "schmatzende": "schmatzend",
    "schmatzendem": "schmatzend",
    "schmatzenden": "schmatzend",
    "schmatzender": "schmatzend",
    "schmatzendere": "schmatzend",
    "schmatzenderem": "schmatzend",
    "schmatzenderen": "schmatzend",
    "schmatzenderer": "schmatzend",
    "schmatzenderes": "schmatzend",
    "schmatzendes": "schmatzend",
    "schmatzendste": "schmatzend",
    "schmatzendstem": "schmatzend",
    "schmatzendsten": "schmatzend",
    "schmatzendster": "schmatzend",
    "schmatzendstes": "schmatzend",
    "schmatzest": "schmatzen",
    "schmatzet": "schmatzen",
    "schmatzt": "schmatzen",
    "schmatzte": "schmatzen",
    "schmatzten": "schmatzen",
    "schmatztest": "schmatzen",
    "schmatztet": "schmatzen",
    "schmecke": "schmecken",
    "schmeckend": "schmecken",
    "schmeckende": "schmeckend",
    "schmeckendem": "schmeckend",
    "schmeckenden": "schmeckend",
    "schmeckender": "schmeckend",
    "schmeckendes": "schmeckend",
    "schmeckest": "schmecken",
    "schmecket": "schmecken",
    "schmeckst": "schmecken",
    "schmeckt": "schmecken",
    "schmeckte": "schmecken",
    "schmeckten": "schmecken",
    "schmecktest": "schmecken",
    "schmecktet": "schmecken",
    "schmeichele": "schmeicheln",
    "schmeichelhaftem": "schmeichelhaft",
    "schmeichelhaften": "schmeichelhaft",
    "schmeichelhafter": "schmeichelhaft",
    "schmeichelhaftere": "schmeichelhaft",
    "schmeichelhafterem": "schmeichelhaft",
    "schmeichelhafteren": "schmeichelhaft",
    "schmeichelhafterer": "schmeichelhaft",
    "schmeichelhafteres": "schmeichelhaft",
    "schmeichelhaftes": "schmeichelhaft",
    "schmeichelhafteste": "schmeichelhaft",
    "schmeichelhaftestem": "schmeichelhaft",
    "schmeichelhaftesten": "schmeichelhaft",
    "schmeichelhaftester": "schmeichelhaft",
    "schmeichelhaftestes": "schmeichelhaft",
    "schmeichelnd": "schmeicheln",
    "schmeichelnde": "schmeichelnd",
    "schmeichelndem": "schmeichelnd",
    "schmeichelnden": "schmeichelnd",
    "schmeichelnder": "schmeichelnd",
    "schmeichelndere": "schmeichelnd",
    "schmeichelnderem": "schmeichelnd",
    "schmeichelnderen": "schmeichelnd",
    "schmeichelnderer": "schmeichelnd",
    "schmeichelnderes": "schmeichelnd",
    "schmeichelndes": "schmeichelnd",
    "schmeichelndste": "schmeichelnd",
    "schmeichelndstem": "schmeichelnd",
    "schmeichelndsten": "schmeichelnd",
    "schmeichelndster": "schmeichelnd",
    "schmeichelndstes": "schmeichelnd",
    "schmeichelst": "schmeicheln",
    "schmeichelt": "schmeicheln",
    "schmeichelte": "schmeicheln",
    "schmeichelten": "schmeicheln",
    "schmeicheltest": "schmeicheln",
    "schmeicheltet": "schmeicheln",
    "schmeichle": "schmeicheln",
    "schmeichlerische": "schmeichlerisch",
    "schmeichlerischem": "schmeichlerisch",
    "schmeichlerischen": "schmeichlerisch",
    "schmeichlerischer": "schmeichlerisch",
    "schmeichlerischere": "schmeichlerisch",
    "schmeichlerischerem": "schmeichlerisch",
    "schmeichlerischeren": "schmeichlerisch",
    "schmeichlerischerer": "schmeichlerisch",
    "schmeichlerischeres": "schmeichlerisch",
    "schmeichlerisches": "schmeichlerisch",
    "schmeichlerischste": "schmeichlerisch",
    "schmeichlerischstem": "schmeichlerisch",
    "schmeichlerischsten": "schmeichlerisch",
    "schmeichlerischster": "schmeichlerisch",
    "schmeichlerischstes": "schmeichlerisch",
    "schmeiße": "schmeißen",
    "schmeißend": "schmeißen",
    "schmeißende": "schmeißend",
    "schmeißendem": "schmeißend",
    "schmeißenden": "schmeißend",
    "schmeißender": "schmeißend",
    "schmeißendere": "schmeißend",
    "schmeißenderem": "schmeißend",
    "schmeißenderen": "schmeißend",
    "schmeißenderer": "schmeißend",
    "schmeißenderes": "schmeißend",
    "schmeißendes": "schmeißend",
    "schmeißendste": "schmeißend",
    "schmeißendstem": "schmeißend",
    "schmeißendsten": "schmeißend",
    "schmeißendster": "schmeißend",
    "schmeißendstes": "schmeißend",
    "schmeißest": "schmeißen",
    "schmeißet": "schmeißen",
    "schmeißt": "schmeißen",
    "schmelzbare": "schmelzbar",
    "schmelzbarem": "schmelzbar",
    "schmelzbaren": "schmelzbar",
    "schmelzbarer": "schmelzbar",
    "schmelzbares": "schmelzbar",
    "schmelze": "schmelzen",
    "schmelzend": "schmelzen",
    "schmelzende": "schmelzend",
    "schmelzendem": "schmelzend",
    "schmelzenden": "schmelzend",
    "schmelzender": "schmelzend",
    "schmelzendere": "schmelzend",
    "schmelzenderem": "schmelzend",
    "schmelzenderen": "schmelzend",
    "schmelzenderer": "schmelzend",
    "schmelzenderes": "schmelzend",
    "schmelzendes": "schmelzend",
    "schmelzendste": "schmelzend",
    "schmelzendstem": "schmelzend",
    "schmelzendsten": "schmelzend",
    "schmelzendster": "schmelzend",
    "schmelzendstes": "schmelzend",
    "schmelzest": "schmelzen",
    "schmelzet": "schmelzen",
    "schmelzt": "schmelzen",
    "schmerzempfindliche": "schmerzempfindlich",
    "schmerzempfindlichem": "schmerzempfindlich",
    "schmerzempfindlichen": "schmerzempfindlich",
    "schmerzempfindlicher": "schmerzempfindlich",
    "schmerzempfindlichere": "schmerzempfindlich",
    "schmerzempfindlicherem": "schmerzempfindlich",
    "schmerzempfindlicheren": "schmerzempfindlich",
    "schmerzempfindlicherer": "schmerzempfindlich",
    "schmerzempfindlicheres": "schmerzempfindlich",
    "schmerzempfindliches": "schmerzempfindlich",
    "schmerzempfindlichste": "schmerzempfindlich",
    "schmerzempfindlichstem": "schmerzempfindlich",
    "schmerzempfindlichsten": "schmerzempfindlich",
    "schmerzempfindlichster": "schmerzempfindlich",
    "schmerzempfindlichstes": "schmerzempfindlich",
    "schmerzend": "schmerzen",
    "schmerzende": "schmerzend",
    "schmerzendem": "schmerzend",
    "schmerzenden": "schmerzend",
    "schmerzender": "schmerzend",
    "schmerzendere": "schmerzend",
    "schmerzenderem": "schmerzend",
    "schmerzenderen": "schmerzend",
    "schmerzenderer": "schmerzend",
    "schmerzenderes": "schmerzend",
    "schmerzendes": "schmerzend",
    "schmerzendste": "schmerzend",
    "schmerzendstem": "schmerzend",
    "schmerzendsten": "schmerzend",
    "schmerzendster": "schmerzend",
    "schmerzendstes": "schmerzend",
    "schmerzensreichem": "schmerzensreich",
    "schmerzensreichen": "schmerzensreich",
    "schmerzensreicher": "schmerzensreich",
    "schmerzensreichere": "schmerzensreich",
    "schmerzensreicherem": "schmerzensreich",
    "schmerzensreicheren": "schmerzensreich",
    "schmerzensreicherer": "schmerzensreich",
    "schmerzensreicheres": "schmerzensreich",
    "schmerzensreiches": "schmerzensreich",
    "schmerzensreichste": "schmerzensreich",
    "schmerzensreichstem": "schmerzensreich",
    "schmerzensreichsten": "schmerzensreich",
    "schmerzensreichster": "schmerzensreich",
    "schmerzensreichstes": "schmerzensreich",
    "schmerzest": "schmerzen",
    "schmerzet": "schmerzen",
    "schmerzfreie": "schmerzfrei",
    "schmerzfreiem": "schmerzfrei",
    "schmerzfreien": "schmerzfrei",
    "schmerzfreier": "schmerzfrei",
    "schmerzfreies": "schmerzfrei",
    "schmerzhafte": "schmerzhaft",
    "schmerzhaftem": "schmerzhaft",
    "schmerzhaften": "schmerzhaft",
    "schmerzhafter": "schmerzhaft",
    "schmerzhaftere": "schmerzhaft",
    "schmerzhafterem": "schmerzhaft",
    "schmerzhafteren": "schmerzhaft",
    "schmerzhafterer": "schmerzhaft",
    "schmerzhafteres": "schmerzhaft",
    "schmerzhaftes": "schmerzhaft",
    "schmerzhafteste": "schmerzhaft",
    "schmerzhaftestem": "schmerzhaft",
    "schmerzhaftesten": "schmerzhaft",
    "schmerzhaftester": "schmerzhaft",
    "schmerzhaftestes": "schmerzhaft",
    "schmerzliche": "schmerzlich",
    "schmerzlichem": "schmerzlich",
    "schmerzlichen": "schmerzlich",
    "schmerzlicher": "schmerzlich",
    "schmerzlichere": "schmerzlich",
    "schmerzlicherem": "schmerzlich",
    "schmerzlicheren": "schmerzlich",
    "schmerzlicherer": "schmerzlich",
    "schmerzlicheres": "schmerzlich",
    "schmerzliches": "schmerzlich",
    "schmerzlichste": "schmerzlich",
    "schmerzlichstem": "schmerzlich",
    "schmerzlichsten": "schmerzlich",
    "schmerzlichster": "schmerzlich",
    "schmerzlichstes": "schmerzlich",
    "schmerzlose": "schmerzlos",
    "schmerzlosem": "schmerzlos",
    "schmerzlosen": "schmerzlos",
    "schmerzloser": "schmerzlos",
    "schmerzlosere": "schmerzlos",
    "schmerzloserem": "schmerzlos",
    "schmerzloseren": "schmerzlos",
    "schmerzloserer": "schmerzlos",
    "schmerzloseres": "schmerzlos",
    "schmerzloses": "schmerzlos",
    "schmerzloseste": "schmerzlos",
    "schmerzlosestem": "schmerzlos",
    "schmerzlosesten": "schmerzlos",
    "schmerzlosester": "schmerzlos",
    "schmerzlosestes": "schmerzlos",
    "schmerzstillende": "schmerzstillend",
    "schmerzstillendem": "schmerzstillend",
    "schmerzstillenden": "schmerzstillend",
    "schmerzstillender": "schmerzstillend",
    "schmerzstillendes": "schmerzstillend",
    "schmerzt": "schmerzen",
    "schmerzte": "schmerzen",
    "schmerzten": "schmerzen",
    "schmerztest": "schmerzen",
    "schmerztet": "schmerzen",
    "schmerzvolle": "schmerzvoll",
    "schmerzvollem": "schmerzvoll",
    "schmerzvollen": "schmerzvoll",
    "schmerzvoller": "schmerzvoll",
    "schmerzvollere": "schmerzvoll",
    "schmerzvollerem": "schmerzvoll",
    "schmerzvolleren": "schmerzvoll",
    "schmerzvollerer": "schmerzvoll",
    "schmerzvolleres": "schmerzvoll",
    "schmerzvolles": "schmerzvoll",
    "schmerzvollste": "schmerzvoll",
    "schmerzvollstem": "schmerzvoll",
    "schmerzvollsten": "schmerzvoll",
    "schmerzvollster": "schmerzvoll",
    "schmerzvollstes": "schmerzvoll",
    "schmettere": "schmettern",
    "schmetternd": "schmettern",
    "schmetternde": "schmetternd",
    "schmetterndem": "schmetternd",
    "schmetternden": "schmetternd",
    "schmetternder": "schmetternd",
    "schmetterndere": "schmetternd",
    "schmetternderem": "schmetternd",
    "schmetternderen": "schmetternd",
    "schmetternderer": "schmetternd",
    "schmetternderes": "schmetternd",
    "schmetterndes": "schmetternd",
    "schmetterndste": "schmetternd",
    "schmetterndstem": "schmetternd",
    "schmetterndsten": "schmetternd",
    "schmetterndster": "schmetternd",
    "schmetterndstes": "schmetternd",
    "schmetterst": "schmettern",
    "schmettert": "schmettern",
    "schmetterte": "schmettern",
    "schmetterten": "schmettern",
    "schmettertest": "schmettern",
    "schmettertet": "schmettern",
    "schmiedend": "schmieden",
    "schmiedende": "schmiedend",
    "schmiedendem": "schmiedend",
    "schmiedenden": "schmiedend",
    "schmiedender": "schmiedend",
    "schmiedendes": "schmiedend",
    "schmiedest": "schmieden",
    "schmiedet": "schmieden",
    "schmiedete": "schmieden",
    "schmiedeten": "schmieden",
    "schmiedetest": "schmieden",
    "schmiedetet": "schmieden",
    "schmiege": "schmiegen",
    "schmiegend": "schmiegen",
    "schmiegende": "schmiegend",
    "schmiegendem": "schmiegend",
    "schmiegenden": "schmiegend",
    "schmiegender": "schmiegend",
    "schmiegendere": "schmiegend",
    "schmiegenderem": "schmiegend",
    "schmiegenderen": "schmiegend",
    "schmiegenderer": "schmiegend",
    "schmiegenderes": "schmiegend",
    "schmiegendes": "schmiegend",
    "schmiegendste": "schmiegend",
    "schmiegendstem": "schmiegend",
    "schmiegendsten": "schmiegend",
    "schmiegendster": "schmiegend",
    "schmiegendstes": "schmiegend",
    "schmiegest": "schmiegen",
    "schmieget": "schmiegen",
    "schmiegsame": "schmiegsam",
    "schmiegsamem": "schmiegsam",
    "schmiegsamen": "schmiegsam",
    "schmiegsamer": "schmiegsam",
    "schmiegsamere": "schmiegsam",
    "schmiegsamerem": "schmiegsam",
    "schmiegsameren": "schmiegsam",
    "schmiegsamerer": "schmiegsam",
    "schmiegsameres": "schmiegsam",
    "schmiegsames": "schmiegsam",
    "schmiegsamste": "schmiegsam",
    "schmiegsamstem": "schmiegsam",
    "schmiegsamsten": "schmiegsam",
    "schmiegsamster": "schmiegsam",
    "schmiegsamstes": "schmiegsam",
    "schmiegst": "schmiegen",
    "schmiegt": "schmiegen",
    "schmiegte": "schmiegen",
    "schmiegten": "schmiegen",
    "schmiegtest": "schmiegen",
    "schmiegtet": "schmiegen",
    "schmiere": "schmieren",
    "schmierend": "schmieren",
    "schmierende": "schmierend",
    "schmierendem": "schmierend",
    "schmierenden": "schmierend",
    "schmierender": "schmierend",
    "schmierendere": "schmierend",
    "schmierenderem": "schmierend",
    "schmierenderen": "schmierend",
    "schmierenderer": "schmierend",
    "schmierenderes": "schmierend",
    "schmierendes": "schmierend",
    "schmierendste": "schmierend",
    "schmierendstem": "schmierend",
    "schmierendsten": "schmierend",
    "schmierendster": "schmierend",
    "schmierendstes": "schmierend",
    "schmierest": "schmieren",
    "schmieret": "schmieren",
    "schmierigem": "schmierig",
    "schmierigen": "schmierig",
    "schmieriger": "schmierig",
    "schmierigere": "schmierig",
    "schmierigerem": "schmierig",
    "schmierigeren": "schmierig",
    "schmierigerer": "schmierig",
    "schmierigeres": "schmierig",
    "schmieriges": "schmierig",
    "schmierigste": "schmierig",
    "schmierigstem": "schmierig",
    "schmierigsten": "schmierig",
    "schmierigster": "schmierig",
    "schmierigstes": "schmierig",
    "schmierst": "schmieren",
    "schmiert": "schmieren",
    "schmierte": "schmieren",
    "schmierten": "schmieren",
    "schmiertest": "schmieren",
    "schmiertet": "schmieren",
    "schmilz": "schmelzen",
    "schmilzt": "schmelzen",
    "schminke": "schminken",
    "schminkend": "schminken",
    "schminkende": "schminkend",
    "schminkendem": "schminkend",
    "schminkenden": "schminkend",
    "schminkender": "schminkend",
    "schminkendere": "schminkend",
    "schminkenderem": "schminkend",
    "schminkenderen": "schminkend",
    "schminkenderer": "schminkend",
    "schminkenderes": "schminkend",
    "schminkendes": "schminkend",
    "schminkendste": "schminkend",
    "schminkendstem": "schminkend",
    "schminkendsten": "schminkend",
    "schminkendster": "schminkend",
    "schminkendstes": "schminkend",
    "schminkest": "schminken",
    "schminket": "schminken",
    "schminkst": "schminken",
    "schminkt": "schminken",
    "schminkte": "schminken",
    "schminkten": "schminken",
    "schminktest": "schminken",
    "schminktet": "schminken",
    "schmirgele": "schmirgeln",
    "schmirgelnd": "schmirgeln",
    "schmirgelnde": "schmirgelnd",
    "schmirgelndem": "schmirgelnd",
    "schmirgelnden": "schmirgelnd",
    "schmirgelnder": "schmirgelnd",
    "schmirgelndere": "schmirgelnd",
    "schmirgelnderem": "schmirgelnd",
    "schmirgelnderen": "schmirgelnd",
    "schmirgelnderer": "schmirgelnd",
    "schmirgelnderes": "schmirgelnd",
    "schmirgelndes": "schmirgelnd",
    "schmirgelndste": "schmirgelnd",
    "schmirgelndstem": "schmirgelnd",
    "schmirgelndsten": "schmirgelnd",
    "schmirgelndster": "schmirgelnd",
    "schmirgelndstes": "schmirgelnd",
    "schmirgelst": "schmirgeln",
    "schmirgelt": "schmirgeln",
    "schmirgelte": "schmirgeln",
    "schmirgelten": "schmirgeln",
    "schmirgeltest": "schmirgeln",
    "schmirgeltet": "schmirgeln",
    "schmirgle": "schmirgeln",
    "schmisse": "schmeißen",
    "schmissen": "schmeißen",
    "schmissest": "schmeißen",
    "schmisset": "schmeißen",
    "schmissige": "schmissig",
    "schmissigem": "schmissig",
    "schmissigen": "schmissig",
    "schmissiger": "schmissig",
    "schmissigere": "schmissig",
    "schmissigerem": "schmissig",
    "schmissigeren": "schmissig",
    "schmissigerer": "schmissig",
    "schmissigeres": "schmissig",
    "schmissiges": "schmissig",
    "schmissigste": "schmissig",
    "schmissigstem": "schmissig",
    "schmissigsten": "schmissig",
    "schmissigster": "schmissig",
    "schmissigstes": "schmissig",
    "schmiß": "schmeißen",
    "schmißt": "schmeißen",
    "schmolle": "schmollen",
    "schmollend": "schmollen",
    "schmollende": "schmollend",
    "schmollendem": "schmollend",
    "schmollenden": "schmollend",
    "schmollender": "schmollend",
    "schmollendere": "schmollend",
    "schmollenderem": "schmollend",
    "schmollenderen": "schmollend",
    "schmollenderer": "schmollend",
    "schmollenderes": "schmollend",
    "schmollendes": "schmollend",
    "schmollendste": "schmollend",
    "schmollendstem": "schmollend",
    "schmollendsten": "schmollend",
    "schmollendster": "schmollend",
    "schmollendstes": "schmollend",
    "schmollest": "schmollen",
    "schmollet": "schmollen",
    "schmollst": "schmollen",
    "schmollt": "schmollen",
    "schmollte": "schmollen",
    "schmollten": "schmollen",
    "schmolltest": "schmollen",
    "schmolltet": "schmollen",
    "schmolz": "schmelzen",
    "schmolzen": "schmelzen",
    "schmolzst": "schmelzen",
    "schmolzt": "schmelzen",
    "schmore": "schmoren",
    "schmorend": "schmoren",
    "schmorende": "schmorend",
    "schmorendem": "schmorend",
    "schmorenden": "schmorend",
    "schmorender": "schmorend",
    "schmorendere": "schmorend",
    "schmorenderem": "schmorend",
    "schmorenderen": "schmorend",
    "schmorenderer": "schmorend",
    "schmorenderes": "schmorend",
    "schmorendes": "schmorend",
    "schmorendste": "schmorend",
    "schmorendstem": "schmorend",
    "schmorendsten": "schmorend",
    "schmorendster": "schmorend",
    "schmorendstes": "schmorend",
    "schmorest": "schmoren",
    "schmoret": "schmoren",
    "schmorst": "schmoren",
    "schmort": "schmoren",
    "schmorte": "schmoren",
    "schmorten": "schmoren",
    "schmortest": "schmoren",
    "schmortet": "schmoren",
    "schmucke": "schmuck",
    "schmuckem": "schmuck",
    "schmucken": "schmuck",
    "schmucker": "schmuck",
    "schmuckere": "schmuck",
    "schmuckerem": "schmuck",
    "schmuckeren": "schmuck",
    "schmuckerer": "schmuck",
    "schmuckeres": "schmuck",
    "schmuckes": "schmuck",
    "schmucklose": "schmucklos",
    "schmucklosem": "schmucklos",
    "schmucklosen": "schmucklos",
    "schmuckloser": "schmucklos",
    "schmucklosere": "schmucklos",
    "schmuckloserem": "schmucklos",
    "schmuckloseren": "schmucklos",
    "schmuckloserer": "schmucklos",
    "schmuckloseres": "schmucklos",
    "schmuckloses": "schmucklos",
    "schmuckloseste": "schmucklos",
    "schmucklosestem": "schmucklos",
    "schmucklosesten": "schmucklos",
    "schmucklosester": "schmucklos",
    "schmucklosestes": "schmucklos",
    "schmuckste": "schmuck",
    "schmuckstem": "schmuck",
    "schmucksten": "schmuck",
    "schmuckster": "schmuck",
    "schmuckstes": "schmuck",
    "schmuddele": "schmuddeln",
    "schmuddelige": "schmuddelig",
    "schmuddeligem": "schmuddelig",
    "schmuddeligen": "schmuddelig",
    "schmuddeliger": "schmuddelig",
    "schmuddeligere": "schmuddelig",
    "schmuddeligerem": "schmuddelig",
    "schmuddeligeren": "schmuddelig",
    "schmuddeligerer": "schmuddelig",
    "schmuddeligeres": "schmuddelig",
    "schmuddeliges": "schmuddelig",
    "schmuddeligste": "schmuddelig",
    "schmuddeligstem": "schmuddelig",
    "schmuddeligsten": "schmuddelig",
    "schmuddeligster": "schmuddelig",
    "schmuddeligstes": "schmuddelig",
    "schmuddelnd": "schmuddeln",
    "schmuddelnde": "schmuddelnd",
    "schmuddelndem": "schmuddelnd",
    "schmuddelnden": "schmuddelnd",
    "schmuddelnder": "schmuddelnd",
    "schmuddelndes": "schmuddelnd",
    "schmuddelst": "schmuddeln",
    "schmuddelt": "schmuddeln",
    "schmuddelte": "schmuddeln",
    "schmuddelten": "schmuddeln",
    "schmuddeltest": "schmuddeln",
    "schmuddeltet": "schmuddeln",
    "schmuddle": "schmuddeln",
    "schmuddlige": "schmuddlig",
    "schmuddligem": "schmuddlig",
    "schmuddligen": "schmuddlig",
    "schmuddliger": "schmuddlig",
    "schmuddligere": "schmuddlig",
    "schmuddligerem": "schmuddlig",
    "schmuddligeren": "schmuddlig",
    "schmuddligerer": "schmuddlig",
    "schmuddligeres": "schmuddlig",
    "schmuddliges": "schmuddlig",
    "schmuddligste": "schmuddlig",
    "schmuddligstem": "schmuddlig",
    "schmuddligsten": "schmuddlig",
    "schmuddligster": "schmuddlig",
    "schmuddligstes": "schmuddlig",
    "schmuggele": "schmuggeln",
    "schmuggelnd": "schmuggeln",
    "schmuggelnde": "schmuggelnd",
    "schmuggelndem": "schmuggelnd",
    "schmuggelnden": "schmuggelnd",
    "schmuggelnder": "schmuggelnd",
    "schmuggelndes": "schmuggelnd",
    "schmuggelst": "schmuggeln",
    "schmuggelt": "schmuggeln",
    "schmuggelte": "schmuggeln",
    "schmuggelten": "schmuggeln",
    "schmuggeltest": "schmuggeln",
    "schmuggeltet": "schmuggeln",
    "schmuggle": "schmuggeln",
    "schmunzele": "schmunzeln",
    "schmunzelnd": "schmunzeln",
    "schmunzelnde": "schmunzelnd",
    "schmunzelndem": "schmunzelnd",
    "schmunzelnden": "schmunzelnd",
    "schmunzelnder": "schmunzelnd",
    "schmunzelndere": "schmunzelnd",
    "schmunzelnderem": "schmunzelnd",
    "schmunzelnderen": "schmunzelnd",
    "schmunzelnderer": "schmunzelnd",
    "schmunzelnderes": "schmunzelnd",
    "schmunzelndes": "schmunzelnd",
    "schmunzelndste": "schmunzelnd",
    "schmunzelndstem": "schmunzelnd",
    "schmunzelndsten": "schmunzelnd",
    "schmunzelndster": "schmunzelnd",
    "schmunzelndstes": "schmunzelnd",
    "schmunzelst": "schmunzeln",
    "schmunzelt": "schmunzeln",
    "schmunzelte": "schmunzeln",
    "schmunzelten": "schmunzeln",
    "schmunzeltest": "schmunzeln",
    "schmunzeltet": "schmunzeln",
    "schmunzle": "schmunzeln",
    "schmuse": "schmusen",
    "schmusend": "schmusen",
    "schmusende": "schmusend",
    "schmusendem": "schmusend",
    "schmusenden": "schmusend",
    "schmusender": "schmusend",
    "schmusendere": "schmusend",
    "schmusenderem": "schmusend",
    "schmusenderen": "schmusend",
    "schmusenderer": "schmusend",
    "schmusenderes": "schmusend",
    "schmusendes": "schmusend",
    "schmusendste": "schmusend",
    "schmusendstem": "schmusend",
    "schmusendsten": "schmusend",
    "schmusendster": "schmusend",
    "schmusendstes": "schmusend",
    "schmusest": "schmusen",
    "schmuset": "schmusen",
    "schmust": "schmusen",
    "schmuste": "schmusen",
    "schmusten": "schmusen",
    "schmustest": "schmusen",
    "schmustet": "schmusen",
    "schmutzigem": "schmutzig",
    "schmutzigen": "schmutzig",
    "schmutziger": "schmutzig",
    "schmutzigere": "schmutzig",
    "schmutzigerem": "schmutzig",
    "schmutzigeren": "schmutzig",
    "schmutzigerer": "schmutzig",
    "schmutzigeres": "schmutzig",
    "schmutziges": "schmutzig",
    "schmutzigste": "schmutzig",
    "schmutzigstem": "schmutzig",
    "schmutzigsten": "schmutzig",
    "schmutzigster": "schmutzig",
    "schmutzigstes": "schmutzig",
    "schmächtige": "schmächtig",
    "schmächtigem": "schmächtig",
    "schmächtigen": "schmächtig",
    "schmächtiger": "schmächtig",
    "schmächtigere": "schmächtig",
    "schmächtigerem": "schmächtig",
    "schmächtigeren": "schmächtig",
    "schmächtigerer": "schmächtig",
    "schmächtigeres": "schmächtig",
    "schmächtiges": "schmächtig",
    "schmächtigste": "schmächtig",
    "schmächtigstem": "schmächtig",
    "schmächtigsten": "schmächtig",
    "schmächtigster": "schmächtig",
    "schmächtigstes": "schmächtig",
    "schmähliche": "schmählich",
    "schmählichem": "schmählich",
    "schmählichen": "schmählich",
    "schmählicher": "schmählich",
    "schmähliches": "schmählich",
    "schmälere": "schmälern",
    "schmälernd": "schmälern",
    "schmälernde": "schmälernd",
    "schmälerndem": "schmälernd",
    "schmälernden": "schmälernd",
    "schmälernder": "schmälernd",
    "schmälerndes": "schmälernd",
    "schmälerst": "schmälern",
    "schmälert": "schmälern",
    "schmälerte": "schmälern",
    "schmälerten": "schmälern",
    "schmälertest": "schmälern",
    "schmälertet": "schmälern",
    "schmökere": "schmökern",
    "schmökernd": "schmökern",
    "schmökernde": "schmökernd",
    "schmökerndem": "schmökernd",
    "schmökernden": "schmökernd",
    "schmökernder": "schmökernd",
    "schmökerndere": "schmökernd",
    "schmökernderem": "schmökernd",
    "schmökernderen": "schmökernd",
    "schmökernderer": "schmökernd",
    "schmökernderes": "schmökernd",
    "schmökerndes": "schmökernd",
    "schmökerndste": "schmökernd",
    "schmökerndstem": "schmökernd",
    "schmökerndsten": "schmökernd",
    "schmökerndster": "schmökernd",
    "schmökerndstes": "schmökernd",
    "schmökerst": "schmökern",
    "schmökert": "schmökern",
    "schmökerte": "schmökern",
    "schmökerten": "schmökern",
    "schmökertest": "schmökern",
    "schmökertet": "schmökern",
    "schmölze": "schmelzen",
    "schmölzen": "schmelzen",
    "schmölzest": "schmelzen",
    "schmölzet": "schmelzen",
    "schmücke": "schmücken",
    "schmückend": "schmücken",
    "schmückende": "schmückend",
    "schmückendem": "schmückend",
    "schmückenden": "schmückend",
    "schmückender": "schmückend",
    "schmückendes": "schmückend",
    "schmückest": "schmücken",
    "schmücket": "schmücken",
    "schmückst": "schmücken",
    "schmückt": "schmücken",
    "schmückte": "schmücken",
    "schmückten": "schmücken",
    "schmücktest": "schmücken",
    "schmücktet": "schmücken",
    "schnallend": "schnallen",
    "schnallende": "schnallend",
    "schnallendem": "schnallend",
    "schnallenden": "schnallend",
    "schnallender": "schnallend",
    "schnallendes": "schnallend",
    "schnallest": "schnallen",
    "schnallet": "schnallen",
    "schnallst": "schnallen",
    "schnallt": "schnallen",
    "schnallte": "schnallen",
    "schnallten": "schnallen",
    "schnalltest": "schnallen",
    "schnalltet": "schnallen",
    "schnalze": "schnalzen",
    "schnalzend": "schnalzen",
    "schnalzende": "schnalzend",
    "schnalzendem": "schnalzend",
    "schnalzenden": "schnalzend",
    "schnalzender": "schnalzend",
    "schnalzendere": "schnalzend",
    "schnalzenderem": "schnalzend",
    "schnalzenderen": "schnalzend",
    "schnalzenderer": "schnalzend",
    "schnalzenderes": "schnalzend",
    "schnalzendes": "schnalzend",
    "schnalzendste": "schnalzend",
    "schnalzendstem": "schnalzend",
    "schnalzendsten": "schnalzend",
    "schnalzendster": "schnalzend",
    "schnalzendstes": "schnalzend",
    "schnalzest": "schnalzen",
    "schnalzet": "schnalzen",
    "schnalzt": "schnalzen",
    "schnalzte": "schnalzen",
    "schnalzten": "schnalzen",
    "schnalztest": "schnalzen",
    "schnalztet": "schnalzen",
    "schnappe": "schnappen",
    "schnappend": "schnappen",
    "schnappende": "schnappend",
    "schnappendem": "schnappend",
    "schnappenden": "schnappend",
    "schnappender": "schnappend",
    "schnappendere": "schnappend",
    "schnappenderem": "schnappend",
    "schnappenderen": "schnappend",
    "schnappenderer": "schnappend",
    "schnappenderes": "schnappend",
    "schnappendes": "schnappend",
    "schnappendste": "schnappend",
    "schnappendstem": "schnappend",
    "schnappendsten": "schnappend",
    "schnappendster": "schnappend",
    "schnappendstes": "schnappend",
    "schnappest": "schnappen",
    "schnappet": "schnappen",
    "schnappst": "schnappen",
    "schnappt": "schnappen",
    "schnappte": "schnappen",
    "schnappten": "schnappen",
    "schnapptest": "schnappen",
    "schnapptet": "schnappen",
    "schnarche": "schnarchen",
    "schnarchend": "schnarchen",
    "schnarchende": "schnarchend",
    "schnarchendem": "schnarchend",
    "schnarchenden": "schnarchend",
    "schnarchender": "schnarchend",
    "schnarchendere": "schnarchend",
    "schnarchenderem": "schnarchend",
    "schnarchenderen": "schnarchend",
    "schnarchenderer": "schnarchend",
    "schnarchenderes": "schnarchend",
    "schnarchendes": "schnarchend",
    "schnarchendste": "schnarchend",
    "schnarchendstem": "schnarchend",
    "schnarchendsten": "schnarchend",
    "schnarchendster": "schnarchend",
    "schnarchendstes": "schnarchend",
    "schnarchest": "schnarchen",
    "schnarchet": "schnarchen",
    "schnarchst": "schnarchen",
    "schnarcht": "schnarchen",
    "schnarchte": "schnarchen",
    "schnarchten": "schnarchen",
    "schnarchtest": "schnarchen",
    "schnarchtet": "schnarchen",
    "schnattere": "schnattern",
    "schnatternd": "schnattern",
    "schnatternde": "schnatternd",
    "schnatterndem": "schnatternd",
    "schnatternden": "schnatternd",
    "schnatternder": "schnatternd",
    "schnatterndere": "schnatternd",
    "schnatternderem": "schnatternd",
    "schnatternderen": "schnatternd",
    "schnatternderer": "schnatternd",
    "schnatternderes": "schnatternd",
    "schnatterndes": "schnatternd",
    "schnatterndste": "schnatternd",
    "schnatterndstem": "schnatternd",
    "schnatterndsten": "schnatternd",
    "schnatterndster": "schnatternd",
    "schnatterndstes": "schnatternd",
    "schnatterst": "schnattern",
    "schnattert": "schnattern",
    "schnatterte": "schnattern",
    "schnatterten": "schnattern",
    "schnattertest": "schnattern",
    "schnattertet": "schnattern",
    "schnaube": "schnauben",
    "schnaubend": "schnauben",
    "schnaubende": "schnaubend",
    "schnaubendem": "schnaubend",
    "schnaubenden": "schnaubend",
    "schnaubender": "schnaubend",
    "schnaubendes": "schnaubend",
    "schnaubest": "schnauben",
    "schnaubet": "schnauben",
    "schnaubst": "schnauben",
    "schnaubt": "schnauben",
    "schnaubte": "schnauben",
    "schnaubten": "schnauben",
    "schnaubtest": "schnauben",
    "schnaubtet": "schnauben",
    "schnaufe": "schnaufen",
    "schnaufend": "schnaufen",
    "schnaufende": "schnaufend",
    "schnaufendem": "schnaufend",
    "schnaufenden": "schnaufend",
    "schnaufender": "schnaufend",
    "schnaufendere": "schnaufend",
    "schnaufenderem": "schnaufend",
    "schnaufenderen": "schnaufend",
    "schnaufenderer": "schnaufend",
    "schnaufenderes": "schnaufend",
    "schnaufendes": "schnaufend",
    "schnaufendste": "schnaufend",
    "schnaufendstem": "schnaufend",
    "schnaufendsten": "schnaufend",
    "schnaufendster": "schnaufend",
    "schnaufendstes": "schnaufend",
    "schnaufest": "schnaufen",
    "schnaufet": "schnaufen",
    "schnaufst": "schnaufen",
    "schnauft": "schnaufen",
    "schnaufte": "schnaufen",
    "schnauften": "schnaufen",
    "schnauftest": "schnaufen",
    "schnauftet": "schnaufen",
    "schnauzend": "schnauzen",
    "schnauzende": "schnauzend",
    "schnauzendem": "schnauzend",
    "schnauzenden": "schnauzend",
    "schnauzender": "schnauzend",
    "schnauzendes": "schnauzend",
    "schnauzest": "schnauzen",
    "schnauzet": "schnauzen",
    "schnauzt": "schnauzen",
    "schnauzte": "schnauzen",
    "schnauzten": "schnauzen",
    "schnauztest": "schnauzen",
    "schnauztet": "schnauzen",
    "schneefreie": "schneefrei",
    "schneefreiem": "schneefrei",
    "schneefreien": "schneefrei",
    "schneefreier": "schneefrei",
    "schneefreies": "schneefrei",
    "schneesicherem": "schneesicher",
    "schneesicheren": "schneesicher",
    "schneesicherer": "schneesicher",
    "schneesicheres": "schneesicher",
    "schneeweißem": "schneeweiß",
    "schneeweißen": "schneeweiß",
    "schneeweißer": "schneeweiß",
    "schneeweißes": "schneeweiß",
    "schneide": "schneiden",
    "schneidend": "schneiden",
    "schneidende": "schneidend",
    "schneidendem": "schneidend",
    "schneidenden": "schneidend",
    "schneidender": "schneidend",
    "schneidendes": "schneidend",
    "schneidere": "schneidern",
    "schneidernd": "schneidern",
    "schneidernde": "schneidernd",
    "schneiderndem": "schneidernd",
    "schneidernden": "schneidernd",
    "schneidernder": "schneidernd",
    "schneiderndes": "schneidernd",
    "schneiderst": "schneidern",
    "schneidert": "schneidern",
    "schneiderte": "schneidern",
    "schneiderten": "schneidern",
    "schneidertest": "schneidern",
    "schneidertet": "schneidern",
    "schneidest": "schneiden",
    "schneidet": "schneiden",
    "schneidige": "schneidig",
    "schneidigem": "schneidig",
    "schneidigen": "schneidig",
    "schneidiger": "schneidig",
    "schneidigere": "schneidig",
    "schneidigerem": "schneidig",
    "schneidigeren": "schneidig",
    "schneidigerer": "schneidig",
    "schneidigeres": "schneidig",
    "schneidiges": "schneidig",
    "schneidigste": "schneidig",
    "schneidigstem": "schneidig",
    "schneidigsten": "schneidig",
    "schneidigster": "schneidig",
    "schneidigstes": "schneidig",
    "schneie": "schneien",
    "schneiend": "schneien",
    "schneiende": "schneiend",
    "schneiendem": "schneiend",
    "schneienden": "schneiend",
    "schneiender": "schneiend",
    "schneiendere": "schneiend",
    "schneienderem": "schneiend",
    "schneienderen": "schneiend",
    "schneienderer": "schneiend",
    "schneienderes": "schneiend",
    "schneiendes": "schneiend",
    "schneiendste": "schneiend",
    "schneiendstem": "schneiend",
    "schneiendsten": "schneiend",
    "schneiendster": "schneiend",
    "schneiendstes": "schneiend",
    "schneiest": "schneien",
    "schneiet": "schneien",
    "schneist": "schneien",
    "schneit": "schneien",
    "schneite": "schneien",
    "schneiten": "schneien",
    "schneitest": "schneien",
    "schneitet": "schneien",
    "schnell": "schnellen",
    "schnelle": "schnellen",
    "schnellem": "schnell",
    "schnellen": "schnell",
    "schnellend": "schnellen",
    "schnellende": "schnellend",
    "schnellendem": "schnellend",
    "schnellenden": "schnellend",
    "schnellender": "schnellend",
    "schnellendes": "schnellend",
    "schneller": "schnell",
    "schnellere": "schnell",
    "schnellerem": "schnell",
    "schnelleren": "schnell",
    "schnellerer": "schnell",
    "schnelleres": "schnell",
    "schnelles": "schnell",
    "schnellest": "schnellen",
    "schnellet": "schnellen",
    "schnellfüßige": "schnellfüßig",
    "schnellfüßigem": "schnellfüßig",
    "schnellfüßigen": "schnellfüßig",
    "schnellfüßiger": "schnellfüßig",
    "schnellfüßigere": "schnellfüßig",
    "schnellfüßigerem": "schnellfüßig",
    "schnellfüßigeren": "schnellfüßig",
    "schnellfüßigerer": "schnellfüßig",
    "schnellfüßigeres": "schnellfüßig",
    "schnellfüßiges": "schnellfüßig",
    "schnellfüßigste": "schnellfüßig",
    "schnellfüßigstem": "schnellfüßig",
    "schnellfüßigsten": "schnellfüßig",
    "schnellfüßigster": "schnellfüßig",
    "schnellfüßigstes": "schnellfüßig",
    "schnellst": "schnellen",
    "schnellste": "schnell",
    "schnellstem": "schnell",
    "schnellsten": "schnell",
    "schnellster": "schnell",
    "schnellstes": "schnell",
    "schnellstmögliche": "schnellstmöglich",
    "schnellstmöglichem": "schnellstmöglich",
    "schnellstmöglichen": "schnellstmöglich",
    "schnellstmöglicher": "schnellstmöglich",
    "schnellstmöglichere": "schnellstmöglich",
    "schnellstmöglicherem": "schnellstmöglich",
    "schnellstmöglicheren": "schnellstmöglich",
    "schnellstmöglicherer": "schnellstmöglich",
    "schnellstmöglicheres": "schnellstmöglich",
    "schnellstmögliches": "schnellstmöglich",
    "schnellstmöglichste": "schnellstmöglich",
    "schnellstmöglichstem": "schnellstmöglich",
    "schnellstmöglichsten": "schnellstmöglich",
    "schnellstmöglichster": "schnellstmöglich",
    "schnellstmöglichstes": "schnellstmöglich",
    "schnellt": "schnellen",
    "schnellte": "schnellen",
    "schnellten": "schnellen",
    "schnelltest": "schnellen",
    "schnelltet": "schnellen",
    "schneuzend": "schneuzen",
    "schneuzende": "schneuzend",
    "schneuzendem": "schneuzend",
    "schneuzenden": "schneuzend",
    "schneuzender": "schneuzend",
    "schneuzendere": "schneuzend",
    "schneuzenderem": "schneuzend",
    "schneuzenderen": "schneuzend",
    "schneuzenderer": "schneuzend",
    "schneuzenderes": "schneuzend",
    "schneuzendes": "schneuzend",
    "schneuzendste": "schneuzend",
    "schneuzendstem": "schneuzend",
    "schneuzendsten": "schneuzend",
    "schneuzendster": "schneuzend",
    "schneuzendstes": "schneuzend",
    "schneuzest": "schneuzen",
    "schneuzet": "schneuzen",
    "schneuzt": "schneuzen",
    "schneuzte": "schneuzen",
    "schneuzten": "schneuzen",
    "schneuztest": "schneuzen",
    "schneuztet": "schneuzen",
    "schniefe": "schniefen",
    "schniefend": "schniefen",
    "schniefende": "schniefend",
    "schniefendem": "schniefend",
    "schniefenden": "schniefend",
    "schniefender": "schniefend",
    "schniefendere": "schniefend",
    "schniefenderem": "schniefend",
    "schniefenderen": "schniefend",
    "schniefenderer": "schniefend",
    "schniefenderes": "schniefend",
    "schniefendes": "schniefend",
    "schniefendste": "schniefend",
    "schniefendstem": "schniefend",
    "schniefendsten": "schniefend",
    "schniefendster": "schniefend",
    "schniefendstes": "schniefend",
    "schniefest": "schniefen",
    "schniefet": "schniefen",
    "schniefst": "schniefen",
    "schnieft": "schniefen",
    "schniefte": "schniefen",
    "schnieften": "schniefen",
    "schnieftest": "schniefen",
    "schnieftet": "schniefen",
    "schnippe": "schnippen",
    "schnippend": "schnippen",
    "schnippende": "schnippend",
    "schnippendem": "schnippend",
    "schnippenden": "schnippend",
    "schnippender": "schnippend",
    "schnippendes": "schnippend",
    "schnippest": "schnippen",
    "schnippet": "schnippen",
    "schnippische": "schnippisch",
    "schnippischem": "schnippisch",
    "schnippischen": "schnippisch",
    "schnippischer": "schnippisch",
    "schnippischere": "schnippisch",
    "schnippischerem": "schnippisch",
    "schnippischeren": "schnippisch",
    "schnippischerer": "schnippisch",
    "schnippischeres": "schnippisch",
    "schnippisches": "schnippisch",
    "schnippischste": "schnippisch",
    "schnippischstem": "schnippisch",
    "schnippischsten": "schnippisch",
    "schnippischster": "schnippisch",
    "schnippischstes": "schnippisch",
    "schnippst": "schnippen",
    "schnippt": "schnippen",
    "schnippte": "schnippen",
    "schnippten": "schnippen",
    "schnipptest": "schnippen",
    "schnipptet": "schnippen",
    "schnipsele": "schnipseln",
    "schnipselnd": "schnipseln",
    "schnipselnde": "schnipselnd",
    "schnipselndem": "schnipselnd",
    "schnipselnden": "schnipselnd",
    "schnipselnder": "schnipselnd",
    "schnipselndes": "schnipselnd",
    "schnipselst": "schnipseln",
    "schnipselt": "schnipseln",
    "schnipselte": "schnipseln",
    "schnipselten": "schnipseln",
    "schnipseltest": "schnipseln",
    "schnipseltet": "schnipseln",
    "schnipsle": "schnipseln",
    "schnitt": "schneiden",
    "schnittest": "schneiden",
    "schnittet": "schneiden",
    "schnittigem": "schnittig",
    "schnittigen": "schnittig",
    "schnittiger": "schnittig",
    "schnittigere": "schnittig",
    "schnittigerem": "schnittig",
    "schnittigeren": "schnittig",
    "schnittigerer": "schnittig",
    "schnittigeres": "schnittig",
    "schnittiges": "schnittig",
    "schnittigste": "schnittig",
    "schnittigstem": "schnittig",
    "schnittigsten": "schnittig",
    "schnittigster": "schnittig",
    "schnittigstes": "schnittig",
    "schnitze": "schnitzen",
    "schnitzend": "schnitzen",
    "schnitzende": "schnitzend",
    "schnitzendem": "schnitzend",
    "schnitzenden": "schnitzend",
    "schnitzender": "schnitzend",
    "schnitzendes": "schnitzend",
    "schnitzest": "schnitzen",
    "schnitzet": "schnitzen",
    "schnitzt": "schnitzen",
    "schnitzte": "schnitzen",
    "schnitzten": "schnitzen",
    "schnitztest": "schnitzen",
    "schnitztet": "schnitzen",
    "schnodderigem": "schnodderig",
    "schnodderigen": "schnodderig",
    "schnodderiger": "schnodderig",
    "schnodderigere": "schnodderig",
    "schnodderigerem": "schnodderig",
    "schnodderigeren": "schnodderig",
    "schnodderigerer": "schnodderig",
    "schnodderigeres": "schnodderig",
    "schnodderiges": "schnodderig",
    "schnodderigste": "schnodderig",
    "schnodderigstem": "schnodderig",
    "schnodderigsten": "schnodderig",
    "schnodderigster": "schnodderig",
    "schnodderigstes": "schnodderig",
    "schnoddrige": "schnoddrig",
    "schnoddrigem": "schnoddrig",
    "schnoddrigen": "schnoddrig",
    "schnoddriger": "schnoddrig",
    "schnoddrigere": "schnoddrig",
    "schnoddrigerem": "schnoddrig",
    "schnoddrigeren": "schnoddrig",
    "schnoddrigerer": "schnoddrig",
    "schnoddrigeres": "schnoddrig",
    "schnoddriges": "schnoddrig",
    "schnoddrigste": "schnoddrig",
    "schnoddrigstem": "schnoddrig",
    "schnoddrigsten": "schnoddrig",
    "schnoddrigster": "schnoddrig",
    "schnoddrigstes": "schnoddrig",
    "schnorchele": "schnorcheln",
    "schnorchelnd": "schnorcheln",
    "schnorchelnde": "schnorchelnd",
    "schnorchelndem": "schnorchelnd",
    "schnorchelnden": "schnorchelnd",
    "schnorchelnder": "schnorchelnd",
    "schnorchelndere": "schnorchelnd",
    "schnorchelnderem": "schnorchelnd",
    "schnorchelnderen": "schnorchelnd",
    "schnorchelnderer": "schnorchelnd",
    "schnorchelnderes": "schnorchelnd",
    "schnorchelndes": "schnorchelnd",
    "schnorchelndste": "schnorchelnd",
    "schnorchelndstem": "schnorchelnd",
    "schnorchelndsten": "schnorchelnd",
    "schnorchelndster": "schnorchelnd",
    "schnorchelndstes": "schnorchelnd",
    "schnorchelst": "schnorcheln",
    "schnorchelt": "schnorcheln",
    "schnorchelte": "schnorcheln",
    "schnorchelten": "schnorcheln",
    "schnorcheltest": "schnorcheln",
    "schnorcheltet": "schnorcheln",
    "schnorchle": "schnorcheln",
    "schnorre": "schnorren",
    "schnorrend": "schnorren",
    "schnorrende": "schnorrend",
    "schnorrendem": "schnorrend",
    "schnorrenden": "schnorrend",
    "schnorrender": "schnorrend",
    "schnorrendere": "schnorrend",
    "schnorrenderem": "schnorrend",
    "schnorrenderen": "schnorrend",
    "schnorrenderer": "schnorrend",
    "schnorrenderes": "schnorrend",
    "schnorrendes": "schnorrend",
    "schnorrendste": "schnorrend",
    "schnorrendstem": "schnorrend",
    "schnorrendsten": "schnorrend",
    "schnorrendster": "schnorrend",
    "schnorrendstes": "schnorrend",
    "schnorrest": "schnorren",
    "schnorret": "schnorren",
    "schnorrst": "schnorren",
    "schnorrt": "schnorren",
    "schnorrte": "schnorren",
    "schnorrten": "schnorren",
    "schnorrtest": "schnorren",
    "schnorrtet": "schnorren",
    "schnucklige": "schnucklig",
    "schnuckligem": "schnucklig",
    "schnuckligen": "schnucklig",
    "schnuckliger": "schnucklig",
    "schnuckligere": "schnucklig",
    "schnuckligerem": "schnucklig",
    "schnuckligeren": "schnucklig",
    "schnuckligerer": "schnucklig",
    "schnuckligeres": "schnucklig",
    "schnuckliges": "schnucklig",
    "schnuckligste": "schnucklig",
    "schnuckligstem": "schnucklig",
    "schnuckligsten": "schnucklig",
    "schnuckligster": "schnucklig",
    "schnuckligstes": "schnucklig",
    "schnuppere": "schnuppern",
    "schnuppernd": "schnuppern",
    "schnuppernde": "schnuppernd",
    "schnupperndem": "schnuppernd",
    "schnuppernden": "schnuppernd",
    "schnuppernder": "schnuppernd",
    "schnupperndes": "schnuppernd",
    "schnupperst": "schnuppern",
    "schnuppert": "schnuppern",
    "schnupperte": "schnuppern",
    "schnupperten": "schnuppern",
    "schnuppertest": "schnuppern",
    "schnuppertet": "schnuppern",
    "schnurre": "schnurren",
    "schnurrend": "schnurren",
    "schnurrende": "schnurrend",
    "schnurrendem": "schnurrend",
    "schnurrenden": "schnurrend",
    "schnurrender": "schnurrend",
    "schnurrendes": "schnurrend",
    "schnurrest": "schnurren",
    "schnurret": "schnurren",
    "schnurrigem": "schnurrig",
    "schnurrigen": "schnurrig",
    "schnurriger": "schnurrig",
    "schnurrigere": "schnurrig",
    "schnurrigerem": "schnurrig",
    "schnurrigeren": "schnurrig",
    "schnurrigerer": "schnurrig",
    "schnurrigeres": "schnurrig",
    "schnurriges": "schnurrig",
    "schnurrigste": "schnurrig",
    "schnurrigstem": "schnurrig",
    "schnurrigsten": "schnurrig",
    "schnurrigster": "schnurrig",
    "schnurrigstes": "schnurrig",
    "schnurrst": "schnurren",
    "schnurrt": "schnurren",
    "schnurrte": "schnurren",
    "schnurrten": "schnurren",
    "schnurrtest": "schnurren",
    "schnurrtet": "schnurren",
    "schnäuze": "schnäuzen",
    "schnäuzend": "schnäuzen",
    "schnäuzendem": "schnäuzend",
    "schnäuzender": "schnäuzend",
    "schnäuzendere": "schnäuzend",
    "schnäuzenderem": "schnäuzend",
    "schnäuzenderen": "schnäuzend",
    "schnäuzenderer": "schnäuzend",
    "schnäuzenderes": "schnäuzend",
    "schnäuzendes": "schnäuzend",
    "schnäuzendste": "schnäuzend",
    "schnäuzendstem": "schnäuzend",
    "schnäuzendsten": "schnäuzend",
    "schnäuzendster": "schnäuzend",
    "schnäuzendstes": "schnäuzend",
    "schnäuzest": "schnäuzen",
    "schnäuzet": "schnäuzen",
    "schnäuzt": "schnäuzen",
    "schnäuzte": "schnäuzen",
    "schnäuzten": "schnäuzen",
    "schnäuztest": "schnäuzen",
    "schnäuztet": "schnäuzen",
    "schnöde": "schnöd",
    "schnödem": "schnöd",
    "schnöden": "schnöd",
    "schnöder": "schnöd",
    "schnödere": "schnöd",
    "schnöderem": "schnöd",
    "schnöderen": "schnöd",
    "schnöderer": "schnöd",
    "schnöderes": "schnöd",
    "schnödes": "schnöd",
    "schnödeste": "schnöd",
    "schnödestem": "schnöd",
    "schnödesten": "schnöd",
    "schnödester": "schnöd",
    "schnödestes": "schnöd",
    "schnörkelige": "schnörkelig",
    "schnörkeligem": "schnörkelig",
    "schnörkeligen": "schnörkelig",
    "schnörkeliger": "schnörkelig",
    "schnörkeligere": "schnörkelig",
    "schnörkeligerem": "schnörkelig",
    "schnörkeligeren": "schnörkelig",
    "schnörkeligerer": "schnörkelig",
    "schnörkeligeres": "schnörkelig",
    "schnörkeliges": "schnörkelig",
    "schnörkeligste": "schnörkelig",
    "schnörkeligstem": "schnörkelig",
    "schnörkeligsten": "schnörkelig",
    "schnörkeligster": "schnörkelig",
    "schnörkeligstes": "schnörkelig",
    "schnöselige": "schnöselig",
    "schnöseligem": "schnöselig",
    "schnöseligen": "schnöselig",
    "schnöseliger": "schnöselig",
    "schnöseligere": "schnöselig",
    "schnöseligerem": "schnöselig",
    "schnöseligeren": "schnöselig",
    "schnöseligerer": "schnöselig",
    "schnöseligeres": "schnöselig",
    "schnöseliges": "schnöselig",
    "schnöseligste": "schnöselig",
    "schnöseligstem": "schnöselig",
    "schnöseligsten": "schnöselig",
    "schnöseligster": "schnöselig",
    "schnöseligstes": "schnöselig",
    "schnüffele": "schnüffeln",
    "schnüffelnd": "schnüffeln",
    "schnüffelnde": "schnüffelnd",
    "schnüffelndem": "schnüffelnd",
    "schnüffelnden": "schnüffelnd",
    "schnüffelnder": "schnüffelnd",
    "schnüffelndere": "schnüffelnd",
    "schnüffelnderem": "schnüffelnd",
    "schnüffelnderen": "schnüffelnd",
    "schnüffelnderer": "schnüffelnd",
    "schnüffelnderes": "schnüffelnd",
    "schnüffelndes": "schnüffelnd",
    "schnüffelndste": "schnüffelnd",
    "schnüffelndstem": "schnüffelnd",
    "schnüffelndsten": "schnüffelnd",
    "schnüffelndster": "schnüffelnd",
    "schnüffelndstes": "schnüffelnd",
    "schnüffelst": "schnüffeln",
    "schnüffelt": "schnüffeln",
    "schnüffelte": "schnüffeln",
    "schnüffelten": "schnüffeln",
    "schnüffeltest": "schnüffeln",
    "schnüffeltet": "schnüffeln",
    "schnüffle": "schnüffeln",
    "schnürend": "schnüren",
    "schnürende": "schnürend",
    "schnürendem": "schnürend",
    "schnürenden": "schnürend",
    "schnürender": "schnürend",
    "schnürendes": "schnürend",
    "schnürest": "schnüren",
    "schnüret": "schnüren",
    "schnürst": "schnüren",
    "schnürt": "schnüren",
    "schnürte": "schnüren",
    "schnürten": "schnüren",
    "schnürtest": "schnüren",
    "schnürtet": "schnüren",
    "schob": "schieben",
    "schoben": "schieben",
    "schobst": "schieben",
    "schobt": "schieben",
    "schocke": "schocken",
    "schockend": "schocken",
    "schockende": "schockend",
    "schockendem": "schockend",
    "schockenden": "schockend",
    "schockender": "schockend",
    "schockendere": "schockend",
    "schockenderem": "schockend",
    "schockenderen": "schockend",
    "schockenderer": "schockend",
    "schockenderes": "schockend",
    "schockendes": "schockend",
    "schockendste": "schockend",
    "schockendstem": "schockend",
    "schockendsten": "schockend",
    "schockendster": "schockend",
    "schockendstes": "schockend",
    "schockest": "schocken",
    "schocket": "schocken",
    "schockst": "schocken",
    "schockt": "schocken",
    "schockte": "schocken",
    "schockten": "schocken",
    "schocktest": "schocken",
    "schocktet": "schocken",
    "schokoladenem": "schokoladen",
    "schokoladenen": "schokoladen",
    "schokoladener": "schokoladen",
    "schokoladenes": "schokoladen",
    "schone": "schonen",
    "schonend": "schonen",
    "schonende": "schonend",
    "schonendem": "schonend",
    "schonenden": "schonend",
    "schonender": "schonend",
    "schonendere": "schonend",
    "schonenderem": "schonend",
    "schonenderen": "schonend",
    "schonenderer": "schonend",
    "schonenderes": "schonend",
    "schonendes": "schonend",
    "schonendste": "schonend",
    "schonendstem": "schonend",
    "schonendsten": "schonend",
    "schonendster": "schonend",
    "schonendstes": "schonend",
    "schonest": "schonen",
    "schonet": "schonen",
    "schonst": "schonen",
    "schont": "schonen",
    "schonte": "schonen",
    "schonten": "schonen",
    "schontest": "schonen",
    "schontet": "schonen",
    "schonungsbedürftigem": "schonungsbedürftig",
    "schonungsbedürftigen": "schonungsbedürftig",
    "schonungsbedürftiger": "schonungsbedürftig",
    "schonungsbedürftigere": "schonungsbedürftig",
    "schonungsbedürftigerem": "schonungsbedürftig",
    "schonungsbedürftigeren": "schonungsbedürftig",
    "schonungsbedürftigerer": "schonungsbedürftig",
    "schonungsbedürftigeres": "schonungsbedürftig",
    "schonungsbedürftiges": "schonungsbedürftig",
    "schonungsbedürftigste": "schonungsbedürftig",
    "schonungsbedürftigstem": "schonungsbedürftig",
    "schonungsbedürftigsten": "schonungsbedürftig",
    "schonungsbedürftigster": "schonungsbedürftig",
    "schonungsbedürftigstes": "schonungsbedürftig",
    "schonungslose": "schonungslos",
    "schonungslosem": "schonungslos",
    "schonungslosen": "schonungslos",
    "schonungsloser": "schonungslos",
    "schonungslosere": "schonungslos",
    "schonungsloserem": "schonungslos",
    "schonungsloseren": "schonungslos",
    "schonungsloserer": "schonungslos",
    "schonungsloseres": "schonungslos",
    "schonungsloses": "schonungslos",
    "schonungsloseste": "schonungslos",
    "schonungslosestem": "schonungslos",
    "schonungslosesten": "schonungslos",
    "schonungslosester": "schonungslos",
    "schonungslosestes": "schonungslos",
    "schoppe": "schoppen",
    "schoppend": "schoppen",
    "schoppende": "schoppend",
    "schoppendem": "schoppend",
    "schoppenden": "schoppend",
    "schoppender": "schoppend",
    "schoppendes": "schoppend",
    "schoppest": "schoppen",
    "schoppet": "schoppen",
    "schoppst": "schoppen",
    "schoppt": "schoppen",
    "schoppte": "schoppen",
    "schoppten": "schoppen",
    "schopptest": "schoppen",
    "schopptet": "schoppen",
    "schor": "scheren",
    "schoren": "scheren",
    "schorst": "scheren",
    "schort": "scheren",
    "schossen": "schießen",
    "schottere": "schottern",
    "schotternd": "schottern",
    "schotternde": "schotternd",
    "schotterndem": "schotternd",
    "schotternden": "schotternd",
    "schotternder": "schotternd",
    "schotterndere": "schotternd",
    "schotternderem": "schotternd",
    "schotternderen": "schotternd",
    "schotternderer": "schotternd",
    "schotternderes": "schotternd",
    "schotterndes": "schotternd",
    "schotterndste": "schotternd",
    "schotterndstem": "schotternd",
    "schotterndsten": "schotternd",
    "schotterndster": "schotternd",
    "schotterndstes": "schotternd",
    "schotterst": "schottern",
    "schottert": "schottern",
    "schotterte": "schottern",
    "schotterten": "schottern",
    "schottertest": "schottern",
    "schottertet": "schottern",
    "schottischem": "schottisch",
    "schottischen": "schottisch",
    "schottischer": "schottisch",
    "schottisches": "schottisch",
    "schoß": "schießen",
    "schoßt": "schießen",
    "schraffiere": "schraffieren",
    "schraffierend": "schraffieren",
    "schraffierende": "schraffierend",
    "schraffierendem": "schraffierend",
    "schraffierenden": "schraffierend",
    "schraffierender": "schraffierend",
    "schraffierendes": "schraffierend",
    "schraffierest": "schraffieren",
    "schraffieret": "schraffieren",
    "schraffierst": "schraffieren",
    "schraffiert": "schraffieren",
    "schraffierte": "schraffieren",
    "schraffiertem": "schraffiert",
    "schraffierten": "schraffieren",
    "schraffierter": "schraffiert",
    "schraffiertes": "schraffiert",
    "schraffiertest": "schraffieren",
    "schraffiertet": "schraffieren",
    "schrak": "schrecken",
    "schraken": "schrecken",
    "schrakst": "schrecken",
    "schrakt": "schrecken",
    "schramme": "schrammen",
    "schrammend": "schrammen",
    "schrammende": "schrammend",
    "schrammendem": "schrammend",
    "schrammenden": "schrammend",
    "schrammender": "schrammend",
    "schrammendes": "schrammend",
    "schrammest": "schrammen",
    "schrammet": "schrammen",
    "schrammige": "schrammig",
    "schrammigem": "schrammig",
    "schrammigen": "schrammig",
    "schrammiger": "schrammig",
    "schrammigere": "schrammig",
    "schrammigerem": "schrammig",
    "schrammigeren": "schrammig",
    "schrammigerer": "schrammig",
    "schrammigeres": "schrammig",
    "schrammiges": "schrammig",
    "schrammigste": "schrammig",
    "schrammigstem": "schrammig",
    "schrammigsten": "schrammig",
    "schrammigster": "schrammig",
    "schrammigstes": "schrammig",
    "schrammst": "schrammen",
    "schrammt": "schrammen",
    "schrammte": "schrammen",
    "schrammten": "schrammen",
    "schrammtest": "schrammen",
    "schrammtet": "schrammen",
    "schrankenlose": "schrankenlos",
    "schrankenlosem": "schrankenlos",
    "schrankenlosen": "schrankenlos",
    "schrankenloser": "schrankenlos",
    "schrankenloses": "schrankenlos",
    "schraube": "schrauben",
    "schraubend": "schrauben",
    "schraubende": "schraubend",
    "schraubendem": "schraubend",
    "schraubenden": "schraubend",
    "schraubender": "schraubend",
    "schraubendes": "schraubend",
    "schraubest": "schrauben",
    "schraubet": "schrauben",
    "schraubst": "schrauben",
    "schraubt": "schrauben",
    "schraubte": "schrauben",
    "schraubten": "schrauben",
    "schraubtest": "schrauben",
    "schraubtet": "schrauben",
    "schreckend": "schrecken",
    "schreckende": "schreckend",
    "schreckendem": "schreckend",
    "schreckenden": "schreckend",
    "schreckender": "schreckend",
    "schreckendes": "schreckend",
    "schreckest": "schrecken",
    "schrecket": "schrecken",
    "schreckhafte": "schreckhaft",
    "schreckhaftem": "schreckhaft",
    "schreckhaften": "schreckhaft",
    "schreckhafter": "schreckhaft",
    "schreckhaftere": "schreckhaft",
    "schreckhafterem": "schreckhaft",
    "schreckhafteren": "schreckhaft",
    "schreckhafterer": "schreckhaft",
    "schreckhafteres": "schreckhaft",
    "schreckhaftes": "schreckhaft",
    "schreckhafteste": "schreckhaft",
    "schreckhaftestem": "schreckhaft",
    "schreckhaftesten": "schreckhaft",
    "schreckhaftester": "schreckhaft",
    "schreckhaftestes": "schreckhaft",
    "schreckliche": "schrecklich",
    "schrecklichem": "schrecklich",
    "schrecklichen": "schrecklich",
    "schrecklicher": "schrecklich",
    "schrecklichere": "schrecklich",
    "schrecklicherem": "schrecklich",
    "schrecklicheren": "schrecklich",
    "schrecklicherer": "schrecklich",
    "schrecklicheres": "schrecklich",
    "schreckliches": "schrecklich",
    "schrecklichste": "schrecklich",
    "schrecklichstem": "schrecklich",
    "schrecklichsten": "schrecklich",
    "schrecklichster": "schrecklich",
    "schrecklichstes": "schrecklich",
    "schreckst": "schrecken",
    "schreckt": "schrecken",
    "schreckte": "schrecken",
    "schreckten": "schrecken",
    "schrecktest": "schrecken",
    "schrecktet": "schrecken",
    "schreibe": "schreiben",
    "schreibend": "schreiben",
    "schreibende": "schreibend",
    "schreibendem": "schreibend",
    "schreibenden": "schreibend",
    "schreibender": "schreibend",
    "schreibendes": "schreibend",
    "schreibest": "schreiben",
    "schreibet": "schreiben",
    "schreibfaule": "schreibfaul",
    "schreibfaulem": "schreibfaul",
    "schreibfaulen": "schreibfaul",
    "schreibfauler": "schreibfaul",
    "schreibfaulere": "schreibfaul",
    "schreibfaulerem": "schreibfaul",
    "schreibfauleren": "schreibfaul",
    "schreibfaulerer": "schreibfaul",
    "schreibfauleres": "schreibfaul",
    "schreibfaules": "schreibfaul",
    "schreibfaulste": "schreibfaul",
    "schreibfaulstem": "schreibfaul",
    "schreibfaulsten": "schreibfaul",
    "schreibfaulster": "schreibfaul",
    "schreibfaulstes": "schreibfaul",
    "schreibgewandtem": "schreibgewandt",
    "schreibgewandten": "schreibgewandt",
    "schreibgewandter": "schreibgewandt",
    "schreibgewandtes": "schreibgewandt",
    "schreibst": "schreiben",
    "schreibt": "schreiben",
    "schreie": "schreien",
    "schreiend": "schreien",
    "schreiende": "schreiend",
    "schreiendem": "schreiend",
    "schreienden": "schreiend",
    "schreiender": "schreiend",
    "schreiendere": "schreiend",
    "schreienderem": "schreiend",
    "schreienderen": "schreiend",
    "schreienderer": "schreiend",
    "schreienderes": "schreiend",
    "schreiendes": "schreiend",
    "schreiendste": "schreiend",
    "schreiendstem": "schreiend",
    "schreiendsten": "schreiend",
    "schreiendster": "schreiend",
    "schreiendstes": "schreiend",
    "schreiest": "schreien",
    "schreiet": "schreien",
    "schreinere": "schreinern",
    "schreinernd": "schreinern",
    "schreinernde": "schreinernd",
    "schreinerndem": "schreinernd",
    "schreinernden": "schreinernd",
    "schreinernder": "schreinernd",
    "schreinerndes": "schreinernd",
    "schreinerst": "schreinern",
    "schreinert": "schreinern",
    "schreinerte": "schreinern",
    "schreinerten": "schreinern",
    "schreinertest": "schreinern",
    "schreinertet": "schreinern",
    "schreist": "schreien",
    "schreit": "schreiten",
    "schreitend": "schreiten",
    "schreitende": "schreitend",
    "schreitendem": "schreitend",
    "schreitenden": "schreitend",
    "schreitender": "schreitend",
    "schreitendes": "schreitend",
    "schrick": "schrecken",
    "schrickst": "schrecken",
    "schrickt": "schrecken",
    "schrie": "schreien",
    "schrieb": "schreiben",
    "schriebe": "schreiben",
    "schrieben": "schreiben",
    "schriebest": "schreiben",
    "schriebet": "schreiben",
    "schriebst": "schreiben",
    "schriebt": "schreiben",
    "schriee": "schreien",
    "schrieen": "schreien",
    "schrieest": "schreien",
    "schrieet": "schreien",
    "schrien": "schreien",
    "schriest": "schreien",
    "schriet": "schreien",
    "schriftgläubigem": "schriftgläubig",
    "schriftgläubigen": "schriftgläubig",
    "schriftgläubiger": "schriftgläubig",
    "schriftgläubigere": "schriftgläubig",
    "schriftgläubigerem": "schriftgläubig",
    "schriftgläubigeren": "schriftgläubig",
    "schriftgläubigerer": "schriftgläubig",
    "schriftgläubigeres": "schriftgläubig",
    "schriftgläubiges": "schriftgläubig",
    "schriftgläubigste": "schriftgläubig",
    "schriftgläubigstem": "schriftgläubig",
    "schriftgläubigsten": "schriftgläubig",
    "schriftgläubigster": "schriftgläubig",
    "schriftgläubigstes": "schriftgläubig",
    "schriftliche": "schriftlich",
    "schriftlichem": "schriftlich",
    "schriftlichen": "schriftlich",
    "schriftlicher": "schriftlich",
    "schriftliches": "schriftlich",
    "schriftsprachliche": "schriftsprachlich",
    "schriftsprachlichem": "schriftsprachlich",
    "schriftsprachlichen": "schriftsprachlich",
    "schriftsprachlicher": "schriftsprachlich",
    "schriftsprachliches": "schriftsprachlich",
    "schriftstellerischem": "schriftstellerisch",
    "schriftstellerischen": "schriftstellerisch",
    "schriftstellerischer": "schriftstellerisch",
    "schriftstellerisches": "schriftstellerisch",
    "schrillem": "schrill",
    "schrillen": "schrill",
    "schriller": "schrill",
    "schrillere": "schrill",
    "schrillerem": "schrill",
    "schrilleren": "schrill",
    "schrillerer": "schrill",
    "schrilleres": "schrill",
    "schrilles": "schrill",
    "schrillste": "schrill",
    "schrillstem": "schrill",
    "schrillsten": "schrill",
    "schrillster": "schrill",
    "schrillstes": "schrill",
    "schrittweisem": "schrittweise",
    "schrittweisen": "schrittweise",
    "schrittweiser": "schrittweise",
    "schrittweises": "schrittweise",
    "schroffem": "schroff",
    "schroffen": "schroff",
    "schroffer": "schroff",
    "schroffere": "schroff",
    "schrofferem": "schroff",
    "schrofferen": "schroff",
    "schrofferer": "schroff",
    "schrofferes": "schroff",
    "schroffes": "schroff",
    "schroffste": "schroff",
    "schroffstem": "schroff",
    "schroffsten": "schroff",
    "schroffster": "schroff",
    "schroffstes": "schroff",
    "schrottreifem": "schrottreif",
    "schrottreifen": "schrottreif",
    "schrottreifer": "schrottreif",
    "schrottreifere": "schrottreif",
    "schrottreiferem": "schrottreif",
    "schrottreiferen": "schrottreif",
    "schrottreiferer": "schrottreif",
    "schrottreiferes": "schrottreif",
    "schrottreifes": "schrottreif",
    "schrottreifste": "schrottreif",
    "schrottreifstem": "schrottreif",
    "schrottreifsten": "schrottreif",
    "schrottreifster": "schrottreif",
    "schrottreifstes": "schrottreif",
    "schrubbe": "schrubben",
    "schrubbend": "schrubben",
    "schrubbende": "schrubbend",
    "schrubbendem": "schrubbend",
    "schrubbenden": "schrubbend",
    "schrubbender": "schrubbend",
    "schrubbendes": "schrubbend",
    "schrubbest": "schrubben",
    "schrubbet": "schrubben",
    "schrubbst": "schrubben",
    "schrubbt": "schrubben",
    "schrubbte": "schrubben",
    "schrubbten": "schrubben",
    "schrubbtest": "schrubben",
    "schrubbtet": "schrubben",
    "schrullenhafte": "schrullenhaft",
    "schrullenhaftem": "schrullenhaft",
    "schrullenhaften": "schrullenhaft",
    "schrullenhafter": "schrullenhaft",
    "schrullenhaftere": "schrullenhaft",
    "schrullenhafterem": "schrullenhaft",
    "schrullenhafteren": "schrullenhaft",
    "schrullenhafterer": "schrullenhaft",
    "schrullenhafteres": "schrullenhaft",
    "schrullenhaftes": "schrullenhaft",
    "schrullenhafteste": "schrullenhaft",
    "schrullenhaftestem": "schrullenhaft",
    "schrullenhaftesten": "schrullenhaft",
    "schrullenhaftester": "schrullenhaft",
    "schrullenhaftestes": "schrullenhaft",
    "schrullige": "schrullig",
    "schrulligem": "schrullig",
    "schrulligen": "schrullig",
    "schrulliger": "schrullig",
    "schrulligere": "schrullig",
    "schrulligerem": "schrullig",
    "schrulligeren": "schrullig",
    "schrulligerer": "schrullig",
    "schrulligeres": "schrullig",
    "schrulliges": "schrullig",
    "schrulligste": "schrullig",
    "schrulligstem": "schrullig",
    "schrulligsten": "schrullig",
    "schrulligster": "schrullig",
    "schrulligstes": "schrullig",
    "schrumpele": "schrumpeln",
    "schrumpelige": "schrumpelig",
    "schrumpeligem": "schrumpelig",
    "schrumpeligen": "schrumpelig",
    "schrumpeliger": "schrumpelig",
    "schrumpeligere": "schrumpelig",
    "schrumpeligerem": "schrumpelig",
    "schrumpeligeren": "schrumpelig",
    "schrumpeligerer": "schrumpelig",
    "schrumpeligeres": "schrumpelig",
    "schrumpeliges": "schrumpelig",
    "schrumpeligste": "schrumpelig",
    "schrumpeligstem": "schrumpelig",
    "schrumpeligsten": "schrumpelig",
    "schrumpeligster": "schrumpelig",
    "schrumpeligstes": "schrumpelig",
    "schrumpelnd": "schrumpeln",
    "schrumpelnde": "schrumpelnd",
    "schrumpelndem": "schrumpelnd",
    "schrumpelnden": "schrumpelnd",
    "schrumpelnder": "schrumpelnd",
    "schrumpelndere": "schrumpelnd",
    "schrumpelnderem": "schrumpelnd",
    "schrumpelnderen": "schrumpelnd",
    "schrumpelnderer": "schrumpelnd",
    "schrumpelnderes": "schrumpelnd",
    "schrumpelndes": "schrumpelnd",
    "schrumpelndste": "schrumpelnd",
    "schrumpelndstem": "schrumpelnd",
    "schrumpelndsten": "schrumpelnd",
    "schrumpelndster": "schrumpelnd",
    "schrumpelndstes": "schrumpelnd",
    "schrumpelst": "schrumpeln",
    "schrumpelt": "schrumpeln",
    "schrumpelte": "schrumpeln",
    "schrumpelten": "schrumpeln",
    "schrumpeltest": "schrumpeln",
    "schrumpeltet": "schrumpeln",
    "schrumpfe": "schrumpfen",
    "schrumpfend": "schrumpfen",
    "schrumpfende": "schrumpfend",
    "schrumpfendem": "schrumpfend",
    "schrumpfenden": "schrumpfend",
    "schrumpfender": "schrumpfend",
    "schrumpfendes": "schrumpfend",
    "schrumpfest": "schrumpfen",
    "schrumpfet": "schrumpfen",
    "schrumpfst": "schrumpfen",
    "schrumpft": "schrumpfen",
    "schrumpfte": "schrumpfen",
    "schrumpften": "schrumpfen",
    "schrumpftest": "schrumpfen",
    "schrumpftet": "schrumpfen",
    "schrumple": "schrumpeln",
    "schrumplige": "schrumplig",
    "schrumpligem": "schrumplig",
    "schrumpligen": "schrumplig",
    "schrumpliger": "schrumplig",
    "schrumpligere": "schrumplig",
    "schrumpligerem": "schrumplig",
    "schrumpligeren": "schrumplig",
    "schrumpligerer": "schrumplig",
    "schrumpligeres": "schrumplig",
    "schrumpliges": "schrumplig",
    "schrumpligste": "schrumplig",
    "schrumpligstem": "schrumplig",
    "schrumpligsten": "schrumplig",
    "schrumpligster": "schrumplig",
    "schrumpligstes": "schrumplig",
    "schräge": "schrägen",
    "schrägend": "schrägen",
    "schrägende": "schrägend",
    "schrägendem": "schrägend",
    "schrägenden": "schrägend",
    "schrägender": "schrägend",
    "schrägendes": "schrägend",
    "schrägest": "schrägen",
    "schräget": "schrägen",
    "schräglaufendem": "schräglaufend",
    "schräglaufenden": "schräglaufend",
    "schräglaufender": "schräglaufend",
    "schräglaufendes": "schräglaufend",
    "schrägst": "schrägen",
    "schrägt": "schrägen",
    "schrägte": "schrägen",
    "schrägten": "schrägen",
    "schrägtest": "schrägen",
    "schrägtet": "schrägen",
    "schräke": "schrecken",
    "schräken": "schrecken",
    "schräkest": "schrecken",
    "schräket": "schrecken",
    "schränkend": "schränken",
    "schränkende": "schränkend",
    "schränkendem": "schränkend",
    "schränkenden": "schränkend",
    "schränkender": "schränkend",
    "schränkendes": "schränkend",
    "schränkest": "schränken",
    "schränket": "schränken",
    "schränkst": "schränken",
    "schränkt": "schränken",
    "schränkte": "schränken",
    "schränkten": "schränken",
    "schränktest": "schränken",
    "schränktet": "schränken",
    "schröpfe": "schröpfen",
    "schröpfend": "schröpfen",
    "schröpfende": "schröpfend",
    "schröpfendem": "schröpfend",
    "schröpfenden": "schröpfend",
    "schröpfender": "schröpfend",
    "schröpfendere": "schröpfend",
    "schröpfenderem": "schröpfend",
    "schröpfenderen": "schröpfend",
    "schröpfenderer": "schröpfend",
    "schröpfenderes": "schröpfend",
    "schröpfendes": "schröpfend",
    "schröpfendste": "schröpfend",
    "schröpfendstem": "schröpfend",
    "schröpfendsten": "schröpfend",
    "schröpfendster": "schröpfend",
    "schröpfendstes": "schröpfend",
    "schröpfest": "schröpfen",
    "schröpfet": "schröpfen",
    "schröpfst": "schröpfen",
    "schröpft": "schröpfen",
    "schröpfte": "schröpfen",
    "schröpften": "schröpfen",
    "schröpftest": "schröpfen",
    "schröpftet": "schröpfen",
    "schubse": "schubsen",
    "schubsend": "schubsen",
    "schubsende": "schubsend",
    "schubsendem": "schubsend",
    "schubsenden": "schubsend",
    "schubsender": "schubsend",
    "schubsendes": "schubsend",
    "schubsest": "schubsen",
    "schubset": "schubsen",
    "schubst": "schubsen",
    "schubste": "schubsen",
    "schubsten": "schubsen",
    "schubstest": "schubsen",
    "schubstet": "schubsen",
    "schubweisem": "schubweise",
    "schubweisen": "schubweise",
    "schubweiser": "schubweise",
    "schubweises": "schubweise",
    "schuckele": "schuckeln",
    "schuckelnd": "schuckeln",
    "schuckelnde": "schuckelnd",
    "schuckelndem": "schuckelnd",
    "schuckelnden": "schuckelnd",
    "schuckelnder": "schuckelnd",
    "schuckelndes": "schuckelnd",
    "schuckelst": "schuckeln",
    "schuckelt": "schuckeln",
    "schuckelte": "schuckeln",
    "schuckelten": "schuckeln",
    "schuckeltest": "schuckeln",
    "schuckeltet": "schuckeln",
    "schuckle": "schuckeln",
    "schuf": "schaffen",
    "schufen": "schaffen",
    "schufst": "schaffen",
    "schuft": "schaffen",
    "schufte": "schuften",
    "schuftend": "schuften",
    "schuftende": "schuftend",
    "schuftendem": "schuftend",
    "schuftenden": "schuftend",
    "schuftender": "schuftend",
    "schuftendere": "schuftend",
    "schuftenderem": "schuftend",
    "schuftenderen": "schuftend",
    "schuftenderer": "schuftend",
    "schuftenderes": "schuftend",
    "schuftendes": "schuftend",
    "schuftendste": "schuftend",
    "schuftendstem": "schuftend",
    "schuftendsten": "schuftend",
    "schuftendster": "schuftend",
    "schuftendstes": "schuftend",
    "schuftest": "schuften",
    "schuftet": "schuften",
    "schuftete": "schuften",
    "schufteten": "schuften",
    "schuftetest": "schuften",
    "schuftetet": "schuften",
    "schuldbeladenem": "schuldbeladen",
    "schuldbeladenen": "schuldbeladen",
    "schuldbeladener": "schuldbeladen",
    "schuldbeladenes": "schuldbeladen",
    "schuldbewußte": "schuldbewußt",
    "schuldbewußtem": "schuldbewußt",
    "schuldbewußten": "schuldbewußt",
    "schuldbewußter": "schuldbewußt",
    "schuldbewußtere": "schuldbewußt",
    "schuldbewußterem": "schuldbewußt",
    "schuldbewußteren": "schuldbewußt",
    "schuldbewußterer": "schuldbewußt",
    "schuldbewußteres": "schuldbewußt",
    "schuldbewußtes": "schuldbewußt",
    "schuldbewußteste": "schuldbewußt",
    "schuldbewußtestem": "schuldbewußt",
    "schuldbewußtesten": "schuldbewußt",
    "schuldbewußtester": "schuldbewußt",
    "schuldbewußtestes": "schuldbewußt",
    "schulde": "schulden",
    "schuldend": "schulden",
    "schuldende": "schuldend",
    "schuldendem": "schuldend",
    "schuldenden": "schuldend",
    "schuldender": "schuldend",
    "schuldendes": "schuldend",
    "schuldenfreie": "schuldenfrei",
    "schuldenfreiem": "schuldenfrei",
    "schuldenfreien": "schuldenfrei",
    "schuldenfreier": "schuldenfrei",
    "schuldenfreies": "schuldenfrei",
    "schuldest": "schulden",
    "schuldet": "schulden",
    "schuldete": "schulden",
    "schuldeten": "schulden",
    "schuldetest": "schulden",
    "schuldetet": "schulden",
    "schuldfähige": "schuldfähig",
    "schuldfähigem": "schuldfähig",
    "schuldfähigen": "schuldfähig",
    "schuldfähiger": "schuldfähig",
    "schuldfähigere": "schuldfähig",
    "schuldfähigerem": "schuldfähig",
    "schuldfähigeren": "schuldfähig",
    "schuldfähigerer": "schuldfähig",
    "schuldfähigeres": "schuldfähig",
    "schuldfähiges": "schuldfähig",
    "schuldfähigste": "schuldfähig",
    "schuldfähigstem": "schuldfähig",
    "schuldfähigsten": "schuldfähig",
    "schuldfähigster": "schuldfähig",
    "schuldfähigstes": "schuldfähig",
    "schuldige": "schuldig",
    "schuldigem": "schuldig",
    "schuldigen": "schuldig",
    "schuldiger": "schuldig",
    "schuldigere": "schuldig",
    "schuldigerem": "schuldig",
    "schuldigeren": "schuldig",
    "schuldigerer": "schuldig",
    "schuldigeres": "schuldig",
    "schuldiges": "schuldig",
    "schuldigste": "schuldig",
    "schuldigstem": "schuldig",
    "schuldigsten": "schuldig",
    "schuldigster": "schuldig",
    "schuldigstes": "schuldig",
    "schuldlose": "schuldlos",
    "schuldlosem": "schuldlos",
    "schuldlosen": "schuldlos",
    "schuldloser": "schuldlos",
    "schuldloses": "schuldlos",
    "schuldunfähigem": "schuldunfähig",
    "schuldunfähigen": "schuldunfähig",
    "schuldunfähiger": "schuldunfähig",
    "schuldunfähigere": "schuldunfähig",
    "schuldunfähigerem": "schuldunfähig",
    "schuldunfähigeren": "schuldunfähig",
    "schuldunfähigerer": "schuldunfähig",
    "schuldunfähigeres": "schuldunfähig",
    "schuldunfähiges": "schuldunfähig",
    "schuldunfähigste": "schuldunfähig",
    "schuldunfähigstem": "schuldunfähig",
    "schuldunfähigsten": "schuldunfähig",
    "schuldunfähigster": "schuldunfähig",
    "schuldunfähigstes": "schuldunfähig",
    "schulend": "schulen",
    "schulende": "schulend",
    "schulendem": "schulend",
    "schulenden": "schulend",
    "schulender": "schulend",
    "schulendes": "schulend",
    "schulest": "schulen",
    "schulet": "schulen",
    "schulfreiem": "schulfrei",
    "schulfreien": "schulfrei",
    "schulfreier": "schulfrei",
    "schulfreies": "schulfrei",
    "schulfähigem": "schulfähig",
    "schulfähigen": "schulfähig",
    "schulfähiger": "schulfähig",
    "schulfähigere": "schulfähig",
    "schulfähigerem": "schulfähig",
    "schulfähigeren": "schulfähig",
    "schulfähigerer": "schulfähig",
    "schulfähigeres": "schulfähig",
    "schulfähiges": "schulfähig",
    "schulfähigste": "schulfähig",
    "schulfähigstem": "schulfähig",
    "schulfähigsten": "schulfähig",
    "schulfähigster": "schulfähig",
    "schulfähigstes": "schulfähig",
    "schulischem": "schulisch",
    "schulischen": "schulisch",
    "schulischer": "schulisch",
    "schulisches": "schulisch",
    "schulmeisterlichem": "schulmeisterlich",
    "schulmeisterlichen": "schulmeisterlich",
    "schulmeisterlicher": "schulmeisterlich",
    "schulmeisterlichere": "schulmeisterlich",
    "schulmeisterlicherem": "schulmeisterlich",
    "schulmeisterlicheren": "schulmeisterlich",
    "schulmeisterlicherer": "schulmeisterlich",
    "schulmeisterlicheres": "schulmeisterlich",
    "schulmeisterliches": "schulmeisterlich",
    "schulmeisterlichste": "schulmeisterlich",
    "schulmeisterlichstem": "schulmeisterlich",
    "schulmeisterlichsten": "schulmeisterlich",
    "schulmeisterlichster": "schulmeisterlich",
    "schulmeisterlichstes": "schulmeisterlich",
    "schulmäßigem": "schulmäßig",
    "schulmäßigen": "schulmäßig",
    "schulmäßiger": "schulmäßig",
    "schulmäßigere": "schulmäßig",
    "schulmäßigerem": "schulmäßig",
    "schulmäßigeren": "schulmäßig",
    "schulmäßigerer": "schulmäßig",
    "schulmäßigeres": "schulmäßig",
    "schulmäßiges": "schulmäßig",
    "schulmäßigste": "schulmäßig",
    "schulmäßigstem": "schulmäßig",
    "schulmäßigsten": "schulmäßig",
    "schulmäßigster": "schulmäßig",
    "schulmäßigstes": "schulmäßig",
    "schulpflichtigem": "schulpflichtig",
    "schulpflichtigen": "schulpflichtig",
    "schulpflichtiger": "schulpflichtig",
    "schulpflichtiges": "schulpflichtig",
    "schulreifem": "schulreif",
    "schulreifen": "schulreif",
    "schulreifer": "schulreif",
    "schulreifes": "schulreif",
    "schulst": "schulen",
    "schult": "schulen",
    "schulte": "schulen",
    "schulten": "schulen",
    "schultere": "schultern",
    "schulterfreie": "schulterfrei",
    "schulterfreiem": "schulterfrei",
    "schulterfreien": "schulterfrei",
    "schulterfreier": "schulterfrei",
    "schulterfreies": "schulterfrei",
    "schulterlange": "schulterlang",
    "schulterlangem": "schulterlang",
    "schulterlangen": "schulterlang",
    "schulterlanger": "schulterlang",
    "schulterlanges": "schulterlang",
    "schulternd": "schultern",
    "schulternde": "schulternd",
    "schulterndem": "schulternd",
    "schulternden": "schulternd",
    "schulternder": "schulternd",
    "schulterndes": "schulternd",
    "schulterst": "schultern",
    "schultert": "schultern",
    "schulterte": "schultern",
    "schulterten": "schultern",
    "schultertest": "schultern",
    "schultertet": "schultern",
    "schultest": "schulen",
    "schultet": "schulen",
    "schummele": "schummeln",
    "schummelnd": "schummeln",
    "schummelnde": "schummelnd",
    "schummelndem": "schummelnd",
    "schummelnden": "schummelnd",
    "schummelnder": "schummelnd",
    "schummelndere": "schummelnd",
    "schummelnderem": "schummelnd",
    "schummelnderen": "schummelnd",
    "schummelnderer": "schummelnd",
    "schummelnderes": "schummelnd",
    "schummelndes": "schummelnd",
    "schummelndste": "schummelnd",
    "schummelndstem": "schummelnd",
    "schummelndsten": "schummelnd",
    "schummelndster": "schummelnd",
    "schummelndstes": "schummelnd",
    "schummelst": "schummeln",
    "schummelt": "schummeln",
    "schummelte": "schummeln",
    "schummelten": "schummeln",
    "schummeltest": "schummeln",
    "schummeltet": "schummeln",
    "schummerige": "schummerig",
    "schummerigem": "schummerig",
    "schummerigen": "schummerig",
    "schummeriger": "schummerig",
    "schummerigere": "schummerig",
    "schummerigerem": "schummerig",
    "schummerigeren": "schummerig",
    "schummerigerer": "schummerig",
    "schummerigeres": "schummerig",
    "schummeriges": "schummerig",
    "schummerigste": "schummerig",
    "schummerigstem": "schummerig",
    "schummerigsten": "schummerig",
    "schummerigster": "schummerig",
    "schummerigstes": "schummerig",
    "schummle": "schummeln",
    "schummrige": "schummrig",
    "schummrigem": "schummrig",
    "schummrigen": "schummrig",
    "schummriger": "schummrig",
    "schummrigere": "schummrig",
    "schummrigerem": "schummrig",
    "schummrigeren": "schummrig",
    "schummrigerer": "schummrig",
    "schummrigeres": "schummrig",
    "schummriges": "schummrig",
    "schummrigste": "schummrig",
    "schummrigstem": "schummrig",
    "schummrigsten": "schummrig",
    "schummrigster": "schummrig",
    "schummrigstes": "schummrig",
    "schunkele": "schunkeln",
    "schunkelnd": "schunkeln",
    "schunkelnde": "schunkelnd",
    "schunkelndem": "schunkelnd",
    "schunkelnden": "schunkelnd",
    "schunkelnder": "schunkelnd",
    "schunkelndere": "schunkelnd",
    "schunkelnderem": "schunkelnd",
    "schunkelnderen": "schunkelnd",
    "schunkelnderer": "schunkelnd",
    "schunkelnderes": "schunkelnd",
    "schunkelndes": "schunkelnd",
    "schunkelndste": "schunkelnd",
    "schunkelndstem": "schunkelnd",
    "schunkelndsten": "schunkelnd",
    "schunkelndster": "schunkelnd",
    "schunkelndstes": "schunkelnd",
    "schunkelst": "schunkeln",
    "schunkelt": "schunkeln",
    "schunkelte": "schunkeln",
    "schunkelten": "schunkeln",
    "schunkeltest": "schunkeln",
    "schunkeltet": "schunkeln",
    "schunkle": "schunkeln",
    "schuppigem": "schuppig",
    "schuppigen": "schuppig",
    "schuppiger": "schuppig",
    "schuppigere": "schuppig",
    "schuppigerem": "schuppig",
    "schuppigeren": "schuppig",
    "schuppigerer": "schuppig",
    "schuppigeres": "schuppig",
    "schuppiges": "schuppig",
    "schuppigste": "schuppig",
    "schuppigstem": "schuppig",
    "schuppigsten": "schuppig",
    "schuppigster": "schuppig",
    "schuppigstes": "schuppig",
    "schurkischem": "schurkisch",
    "schurkischen": "schurkisch",
    "schurkischer": "schurkisch",
    "schurkisches": "schurkisch",
    "schusseligem": "schusselig",
    "schusseligen": "schusselig",
    "schusseliger": "schusselig",
    "schusseligere": "schusselig",
    "schusseligerem": "schusselig",
    "schusseligeren": "schusselig",
    "schusseligerer": "schusselig",
    "schusseligeres": "schusselig",
    "schusseliges": "schusselig",
    "schusseligste": "schusselig",
    "schusseligstem": "schusselig",
    "schusseligsten": "schusselig",
    "schusseligster": "schusselig",
    "schusseligstes": "schusselig",
    "schustere": "schustern",
    "schusternd": "schustern",
    "schusternde": "schusternd",
    "schusterndem": "schusternd",
    "schusternden": "schusternd",
    "schusternder": "schusternd",
    "schusterndes": "schusternd",
    "schusterst": "schustern",
    "schustert": "schustern",
    "schusterte": "schustern",
    "schusterten": "schustern",
    "schustertest": "schustern",
    "schustertet": "schustern",
    "schutzlosem": "schutzlos",
    "schutzlosen": "schutzlos",
    "schutzloser": "schutzlos",
    "schutzlosere": "schutzlos",
    "schutzloserem": "schutzlos",
    "schutzloseren": "schutzlos",
    "schutzloserer": "schutzlos",
    "schutzloseres": "schutzlos",
    "schutzloses": "schutzlos",
    "schutzloseste": "schutzlos",
    "schutzlosestem": "schutzlos",
    "schutzlosesten": "schutzlos",
    "schutzlosester": "schutzlos",
    "schutzlosestes": "schutzlos",
    "schußbereitem": "schußbereit",
    "schußbereiten": "schußbereit",
    "schußbereiter": "schußbereit",
    "schußbereites": "schußbereit",
    "schußfestem": "schußfest",
    "schußfesten": "schußfest",
    "schußfester": "schußfest",
    "schußfestere": "schußfest",
    "schußfesterem": "schußfest",
    "schußfesteren": "schußfest",
    "schußfesterer": "schußfest",
    "schußfesteres": "schußfest",
    "schußfestes": "schußfest",
    "schußfesteste": "schußfest",
    "schußfestestem": "schußfest",
    "schußfestesten": "schußfest",
    "schußfestester": "schußfest",
    "schußfestestes": "schußfest",
    "schußsichere": "schußsicher",
    "schußsicherem": "schußsicher",
    "schußsicheren": "schußsicher",
    "schußsicherer": "schußsicher",
    "schußsicherere": "schußsicher",
    "schußsichererem": "schußsicher",
    "schußsichereren": "schußsicher",
    "schußsichererer": "schußsicher",
    "schußsichereres": "schußsicher",
    "schußsicheres": "schußsicher",
    "schußsicherste": "schußsicher",
    "schußsicherstem": "schußsicher",
    "schußsichersten": "schußsicher",
    "schußsicherster": "schußsicher",
    "schußsicherstes": "schußsicher",
    "schwabbele": "schwabbeln",
    "schwabbelige": "schwabbelig",
    "schwabbeligem": "schwabbelig",
    "schwabbeligen": "schwabbelig",
    "schwabbeliger": "schwabbelig",
    "schwabbeligere": "schwabbelig",
    "schwabbeligerem": "schwabbelig",
    "schwabbeligeren": "schwabbelig",
    "schwabbeligerer": "schwabbelig",
    "schwabbeligeres": "schwabbelig",
    "schwabbeliges": "schwabbelig",
    "schwabbeligste": "schwabbelig",
    "schwabbeligstem": "schwabbelig",
    "schwabbeligsten": "schwabbelig",
    "schwabbeligster": "schwabbelig",
    "schwabbeligstes": "schwabbelig",
    "schwabbelnd": "schwabbeln",
    "schwabbelnde": "schwabbelnd",
    "schwabbelndem": "schwabbelnd",
    "schwabbelnden": "schwabbelnd",
    "schwabbelnder": "schwabbelnd",
    "schwabbelndere": "schwabbelnd",
    "schwabbelnderem": "schwabbelnd",
    "schwabbelnderen": "schwabbelnd",
    "schwabbelnderer": "schwabbelnd",
    "schwabbelnderes": "schwabbelnd",
    "schwabbelndes": "schwabbelnd",
    "schwabbelndste": "schwabbelnd",
    "schwabbelndstem": "schwabbelnd",
    "schwabbelndsten": "schwabbelnd",
    "schwabbelndster": "schwabbelnd",
    "schwabbelndstes": "schwabbelnd",
    "schwabbelst": "schwabbeln",
    "schwabbelt": "schwabbeln",
    "schwabbelte": "schwabbeln",
    "schwabbelten": "schwabbeln",
    "schwabbeltest": "schwabbeln",
    "schwabbeltet": "schwabbeln",
    "schwabble": "schwabbeln",
    "schwachem": "schwach",
    "schwachen": "schwach",
    "schwacher": "schwach",
    "schwaches": "schwach",
    "schwachköpfigem": "schwachköpfig",
    "schwachköpfigen": "schwachköpfig",
    "schwachköpfiger": "schwachköpfig",
    "schwachköpfigere": "schwachköpfig",
    "schwachköpfigerem": "schwachköpfig",
    "schwachköpfigeren": "schwachköpfig",
    "schwachköpfigerer": "schwachköpfig",
    "schwachköpfigeres": "schwachköpfig",
    "schwachköpfiges": "schwachköpfig",
    "schwachköpfigste": "schwachköpfig",
    "schwachköpfigstem": "schwachköpfig",
    "schwachköpfigsten": "schwachköpfig",
    "schwachköpfigster": "schwachköpfig",
    "schwachköpfigstes": "schwachköpfig",
    "schwachsinnigem": "schwachsinnig",
    "schwachsinnigen": "schwachsinnig",
    "schwachsinniger": "schwachsinnig",
    "schwachsinnigere": "schwachsinnig",
    "schwachsinnigerem": "schwachsinnig",
    "schwachsinnigeren": "schwachsinnig",
    "schwachsinnigerer": "schwachsinnig",
    "schwachsinnigeres": "schwachsinnig",
    "schwachsinniges": "schwachsinnig",
    "schwachsinnigste": "schwachsinnig",
    "schwachsinnigstem": "schwachsinnig",
    "schwachsinnigsten": "schwachsinnig",
    "schwachsinnigster": "schwachsinnig",
    "schwachsinnigstes": "schwachsinnig",
    "schwafele": "schwafeln",
    "schwafelnd": "schwafeln",
    "schwafelnde": "schwafelnd",
    "schwafelndem": "schwafelnd",
    "schwafelnden": "schwafelnd",
    "schwafelnder": "schwafelnd",
    "schwafelndere": "schwafelnd",
    "schwafelnderem": "schwafelnd",
    "schwafelnderen": "schwafelnd",
    "schwafelnderer": "schwafelnd",
    "schwafelnderes": "schwafelnd",
    "schwafelndes": "schwafelnd",
    "schwafelndste": "schwafelnd",
    "schwafelndstem": "schwafelnd",
    "schwafelndsten": "schwafelnd",
    "schwafelndster": "schwafelnd",
    "schwafelndstes": "schwafelnd",
    "schwafelst": "schwafeln",
    "schwafelt": "schwafeln",
    "schwafelte": "schwafeln",
    "schwafelten": "schwafeln",
    "schwafeltest": "schwafeln",
    "schwafeltet": "schwafeln",
    "schwafle": "schwafeln",
    "schwammen": "schwimmen",
    "schwammigem": "schwammig",
    "schwammigen": "schwammig",
    "schwammiger": "schwammig",
    "schwammigere": "schwammig",
    "schwammigerem": "schwammig",
    "schwammigeren": "schwammig",
    "schwammigerer": "schwammig",
    "schwammigeres": "schwammig",
    "schwammiges": "schwammig",
    "schwammigste": "schwammig",
    "schwammigstem": "schwammig",
    "schwammigsten": "schwammig",
    "schwammigster": "schwammig",
    "schwammigstes": "schwammig",
    "schwammst": "schwimmen",
    "schwammt": "schwimmen",
    "schwammähnliche": "schwammähnlich",
    "schwammähnlichem": "schwammähnlich",
    "schwammähnlichen": "schwammähnlich",
    "schwammähnlicher": "schwammähnlich",
    "schwammähnlichere": "schwammähnlich",
    "schwammähnlicherem": "schwammähnlich",
    "schwammähnlicheren": "schwammähnlich",
    "schwammähnlicherer": "schwammähnlich",
    "schwammähnlicheres": "schwammähnlich",
    "schwammähnliches": "schwammähnlich",
    "schwammähnlichste": "schwammähnlich",
    "schwammähnlichstem": "schwammähnlich",
    "schwammähnlichsten": "schwammähnlich",
    "schwammähnlichster": "schwammähnlich",
    "schwammähnlichstes": "schwammähnlich",
    "schwand": "schwinden",
    "schwanden": "schwinden",
    "schwandest": "schwinden",
    "schwandet": "schwinden",
    "schwanend": "schwanen",
    "schwanende": "schwanend",
    "schwanendem": "schwanend",
    "schwanenden": "schwanend",
    "schwanender": "schwanend",
    "schwanendes": "schwanend",
    "schwanest": "schwanen",
    "schwanet": "schwanen",
    "schwang": "schwingen",
    "schwangen": "schwingen",
    "schwangere": "schwanger",
    "schwangerem": "schwanger",
    "schwangeren": "schwanger",
    "schwangerer": "schwanger",
    "schwangeres": "schwanger",
    "schwangst": "schwingen",
    "schwangt": "schwingen",
    "schwanke": "schwanken",
    "schwankend": "schwanken",
    "schwankende": "schwankend",
    "schwankendem": "schwankend",
    "schwankenden": "schwankend",
    "schwankender": "schwankend",
    "schwankendere": "schwankend",
    "schwankenderem": "schwankend",
    "schwankenderen": "schwankend",
    "schwankenderer": "schwankend",
    "schwankenderes": "schwankend",
    "schwankendes": "schwankend",
    "schwankendste": "schwankend",
    "schwankendstem": "schwankend",
    "schwankendsten": "schwankend",
    "schwankendster": "schwankend",
    "schwankendstes": "schwankend",
    "schwankest": "schwanken",
    "schwanket": "schwanken",
    "schwankst": "schwanken",
    "schwankt": "schwanken",
    "schwankte": "schwanken",
    "schwankten": "schwanken",
    "schwanktest": "schwanken",
    "schwanktet": "schwanken",
    "schwanst": "schwanen",
    "schwant": "schwanen",
    "schwante": "schwanen",
    "schwanten": "schwanen",
    "schwantest": "schwanen",
    "schwantet": "schwanen",
    "schwanzlastigem": "schwanzlastig",
    "schwanzlastigen": "schwanzlastig",
    "schwanzlastiger": "schwanzlastig",
    "schwanzlastigere": "schwanzlastig",
    "schwanzlastigerem": "schwanzlastig",
    "schwanzlastigeren": "schwanzlastig",
    "schwanzlastigerer": "schwanzlastig",
    "schwanzlastigeres": "schwanzlastig",
    "schwanzlastiges": "schwanzlastig",
    "schwanzlastigste": "schwanzlastig",
    "schwanzlastigstem": "schwanzlastig",
    "schwanzlastigsten": "schwanzlastig",
    "schwanzlastigster": "schwanzlastig",
    "schwanzlastigstes": "schwanzlastig",
    "schwanzwedelndem": "schwanzwedelnd",
    "schwanzwedelnden": "schwanzwedelnd",
    "schwanzwedelnder": "schwanzwedelnd",
    "schwanzwedelndes": "schwanzwedelnd",
    "schwappe": "schwappen",
    "schwappend": "schwappen",
    "schwappende": "schwappend",
    "schwappendem": "schwappend",
    "schwappenden": "schwappend",
    "schwappender": "schwappend",
    "schwappendere": "schwappend",
    "schwappenderem": "schwappend",
    "schwappenderen": "schwappend",
    "schwappenderer": "schwappend",
    "schwappenderes": "schwappend",
    "schwappendes": "schwappend",
    "schwappendste": "schwappend",
    "schwappendstem": "schwappend",
    "schwappendsten": "schwappend",
    "schwappendster": "schwappend",
    "schwappendstes": "schwappend",
    "schwappest": "schwappen",
    "schwappet": "schwappen",
    "schwappst": "schwappen",
    "schwappt": "schwappen",
    "schwappte": "schwappen",
    "schwappten": "schwappen",
    "schwapptest": "schwappen",
    "schwapptet": "schwappen",
    "schwarzarbeite": "schwarzarbeiten",
    "schwarzarbeitend": "schwarzarbeiten",
    "schwarzarbeitende": "schwarzarbeitend",
    "schwarzarbeitendem": "schwarzarbeitend",
    "schwarzarbeitenden": "schwarzarbeitend",
    "schwarzarbeitender": "schwarzarbeitend",
    "schwarzarbeitendes": "schwarzarbeitend",
    "schwarzarbeitest": "schwarzarbeiten",
    "schwarzarbeitet": "schwarzarbeiten",
    "schwarzarbeitete": "schwarzarbeiten",
    "schwarzarbeiteten": "schwarzarbeiten",
    "schwarzarbeitetest": "schwarzarbeiten",
    "schwarzarbeitetet": "schwarzarbeiten",
    "schwarzem": "schwarz",
    "schwarzen": "schwarz",
    "schwarzer": "schwarz",
    "schwarzes": "schwarz",
    "schwarzgearbeitet": "schwarzarbeiten",
    "schwarzgearbeitete": "schwarzgearbeitet",
    "schwarzgearbeitetem": "schwarzgearbeitet",
    "schwarzgearbeiteten": "schwarzgearbeitet",
    "schwarzgearbeiteter": "schwarzgearbeitet",
    "schwarzgearbeitetes": "schwarzgearbeitet",
    "schwarzgehört": "schwarzhören",
    "schwarzgehörte": "schwarzgehört",
    "schwarzgehörtem": "schwarzgehört",
    "schwarzgehörten": "schwarzgehört",
    "schwarzgehörter": "schwarzgehört",
    "schwarzgehörtes": "schwarzgehört",
    "schwarzgemalt": "schwarzmalen",
    "schwarzgemalte": "schwarzgemalt",
    "schwarzgemaltem": "schwarzgemalt",
    "schwarzgemalten": "schwarzgemalt",
    "schwarzgemalter": "schwarzgemalt",
    "schwarzgemaltere": "schwarzgemalt",
    "schwarzgemalterem": "schwarzgemalt",
    "schwarzgemalteren": "schwarzgemalt",
    "schwarzgemalterer": "schwarzgemalt",
    "schwarzgemalteres": "schwarzgemalt",
    "schwarzgemaltes": "schwarzgemalt",
    "schwarzgemalteste": "schwarzgemalt",
    "schwarzgemaltestem": "schwarzgemalt",
    "schwarzgemaltesten": "schwarzgemalt",
    "schwarzgemaltester": "schwarzgemalt",
    "schwarzgemaltestes": "schwarzgemalt",
    "schwarzgeschlachtet": "schwarzschlachten",
    "schwarzgeschlachtete": "schwarzgeschlachtet",
    "schwarzgeschlachtetem": "schwarzgeschlachtet",
    "schwarzgeschlachteten": "schwarzgeschlachtet",
    "schwarzgeschlachteter": "schwarzgeschlachtet",
    "schwarzgeschlachtetes": "schwarzgeschlachtet",
    "schwarzgesehen": "schwarzsehen",
    "schwarzgesehene": "schwarzgesehen",
    "schwarzgesehenem": "schwarzgesehen",
    "schwarzgesehenen": "schwarzgesehen",
    "schwarzgesehener": "schwarzgesehen",
    "schwarzgesehenes": "schwarzgesehen",
    "schwarzhöre": "schwarzhören",
    "schwarzhörend": "schwarzhören",
    "schwarzhörende": "schwarzhörend",
    "schwarzhörendem": "schwarzhörend",
    "schwarzhörenden": "schwarzhörend",
    "schwarzhörender": "schwarzhörend",
    "schwarzhörendes": "schwarzhörend",
    "schwarzhörest": "schwarzhören",
    "schwarzhöret": "schwarzhören",
    "schwarzhörst": "schwarzhören",
    "schwarzhört": "schwarzhören",
    "schwarzhörte": "schwarzhören",
    "schwarzhörten": "schwarzhören",
    "schwarzhörtest": "schwarzhören",
    "schwarzhörtet": "schwarzhören",
    "schwarzmale": "schwarzmalen",
    "schwarzmalend": "schwarzmalen",
    "schwarzmalende": "schwarzmalend",
    "schwarzmalendem": "schwarzmalend",
    "schwarzmalenden": "schwarzmalend",
    "schwarzmalender": "schwarzmalend",
    "schwarzmalendere": "schwarzmalend",
    "schwarzmalenderem": "schwarzmalend",
    "schwarzmalenderen": "schwarzmalend",
    "schwarzmalenderer": "schwarzmalend",
    "schwarzmalenderes": "schwarzmalend",
    "schwarzmalendes": "schwarzmalend",
    "schwarzmalendste": "schwarzmalend",
    "schwarzmalendstem": "schwarzmalend",
    "schwarzmalendsten": "schwarzmalend",
    "schwarzmalendster": "schwarzmalend",
    "schwarzmalendstes": "schwarzmalend",
    "schwarzmalest": "schwarzmalen",
    "schwarzmalet": "schwarzmalen",
    "schwarzmalst": "schwarzmalen",
    "schwarzmalt": "schwarzmalen",
    "schwarzmalte": "schwarzmalen",
    "schwarzmalten": "schwarzmalen",
    "schwarzmaltest": "schwarzmalen",
    "schwarzmaltet": "schwarzmalen",
    "schwarzsah": "schwarzsehen",
    "schwarzsahen": "schwarzsehen",
    "schwarzsahst": "schwarzsehen",
    "schwarzsaht": "schwarzsehen",
    "schwarzschlachte": "schwarzschlachten",
    "schwarzschlachtend": "schwarzschlachten",
    "schwarzschlachtende": "schwarzschlachtend",
    "schwarzschlachtendem": "schwarzschlachtend",
    "schwarzschlachtenden": "schwarzschlachtend",
    "schwarzschlachtender": "schwarzschlachtend",
    "schwarzschlachtendes": "schwarzschlachtend",
    "schwarzschlachtest": "schwarzschlachten",
    "schwarzschlachtet": "schwarzschlachten",
    "schwarzschlachtete": "schwarzschlachten",
    "schwarzschlachteten": "schwarzschlachten",
    "schwarzschlachtetest": "schwarzschlachten",
    "schwarzschlachtetet": "schwarzschlachten",
    "schwarzsehe": "schwarzsehen",
    "schwarzsehend": "schwarzsehen",
    "schwarzsehende": "schwarzsehend",
    "schwarzsehendem": "schwarzsehend",
    "schwarzsehenden": "schwarzsehend",
    "schwarzsehender": "schwarzsehend",
    "schwarzsehendere": "schwarzsehend",
    "schwarzsehenderem": "schwarzsehend",
    "schwarzsehenderen": "schwarzsehend",
    "schwarzsehenderer": "schwarzsehend",
    "schwarzsehenderes": "schwarzsehend",
    "schwarzsehendes": "schwarzsehend",
    "schwarzsehendste": "schwarzsehend",
    "schwarzsehendstem": "schwarzsehend",
    "schwarzsehendsten": "schwarzsehend",
    "schwarzsehendster": "schwarzsehend",
    "schwarzsehendstes": "schwarzsehend",
    "schwarzsehest": "schwarzsehen",
    "schwarzsehet": "schwarzsehen",
    "schwarzseht": "schwarzsehen",
    "schwarzsiehst": "schwarzsehen",
    "schwarzsieht": "schwarzsehen",
    "schwarzsähe": "schwarzsehen",
    "schwarzsähen": "schwarzsehen",
    "schwarzsähest": "schwarzsehen",
    "schwarzsähet": "schwarzsehen",
    "schwarzzuarbeiten": "schwarzarbeiten",
    "schwarzzuhören": "schwarzhören",
    "schwarzzumalen": "schwarzmalen",
    "schwarzzuschlachten": "schwarzschlachten",
    "schwarzzusehen": "schwarzsehen",
    "schwatze": "schwatzen",
    "schwatzend": "schwatzen",
    "schwatzende": "schwatzend",
    "schwatzendem": "schwatzend",
    "schwatzenden": "schwatzend",
    "schwatzender": "schwatzend",
    "schwatzendere": "schwatzend",
    "schwatzenderem": "schwatzend",
    "schwatzenderen": "schwatzend",
    "schwatzenderer": "schwatzend",
    "schwatzenderes": "schwatzend",
    "schwatzendes": "schwatzend",
    "schwatzendste": "schwatzend",
    "schwatzendstem": "schwatzend",
    "schwatzendsten": "schwatzend",
    "schwatzendster": "schwatzend",
    "schwatzendstes": "schwatzend",
    "schwatzest": "schwatzen",
    "schwatzet": "schwatzen",
    "schwatzhafte": "schwatzhaft",
    "schwatzhaftem": "schwatzhaft",
    "schwatzhaften": "schwatzhaft",
    "schwatzhafter": "schwatzhaft",
    "schwatzhaftere": "schwatzhaft",
    "schwatzhafterem": "schwatzhaft",
    "schwatzhafteren": "schwatzhaft",
    "schwatzhafterer": "schwatzhaft",
    "schwatzhafteres": "schwatzhaft",
    "schwatzhaftes": "schwatzhaft",
    "schwatzhafteste": "schwatzhaft",
    "schwatzhaftestem": "schwatzhaft",
    "schwatzhaftesten": "schwatzhaft",
    "schwatzhaftester": "schwatzhaft",
    "schwatzhaftestes": "schwatzhaft",
    "schwatzt": "schwatzen",
    "schwatzte": "schwatzen",
    "schwatzten": "schwatzen",
    "schwatztest": "schwatzen",
    "schwatztet": "schwatzen",
    "schwebe": "schweben",
    "schwebend": "schweben",
    "schwebende": "schwebend",
    "schwebendem": "schwebend",
    "schwebenden": "schwebend",
    "schwebender": "schwebend",
    "schwebendes": "schwebend",
    "schwebest": "schweben",
    "schwebet": "schweben",
    "schwebst": "schweben",
    "schwebt": "schweben",
    "schwebte": "schweben",
    "schwebten": "schweben",
    "schwebtest": "schweben",
    "schwebtet": "schweben",
    "schwedischem": "schwedisch",
    "schwedischen": "schwedisch",
    "schwedischer": "schwedisch",
    "schwedischere": "schwedisch",
    "schwedischerem": "schwedisch",
    "schwedischeren": "schwedisch",
    "schwedischerer": "schwedisch",
    "schwedischeres": "schwedisch",
    "schwedisches": "schwedisch",
    "schwedischste": "schwedisch",
    "schwedischstem": "schwedisch",
    "schwedischsten": "schwedisch",
    "schwedischster": "schwedisch",
    "schwedischstes": "schwedisch",
    "schwefelartigem": "schwefelartig",
    "schwefelartigen": "schwefelartig",
    "schwefelartiger": "schwefelartig",
    "schwefelartiges": "schwefelartig",
    "schwefele": "schwefeln",
    "schwefelhaltige": "schwefelhaltig",
    "schwefelhaltigem": "schwefelhaltig",
    "schwefelhaltigen": "schwefelhaltig",
    "schwefelhaltiger": "schwefelhaltig",
    "schwefelhaltigere": "schwefelhaltig",
    "schwefelhaltigerem": "schwefelhaltig",
    "schwefelhaltigeren": "schwefelhaltig",
    "schwefelhaltigerer": "schwefelhaltig",
    "schwefelhaltigeres": "schwefelhaltig",
    "schwefelhaltiges": "schwefelhaltig",
    "schwefelhaltigste": "schwefelhaltig",
    "schwefelhaltigstem": "schwefelhaltig",
    "schwefelhaltigsten": "schwefelhaltig",
    "schwefelhaltigster": "schwefelhaltig",
    "schwefelhaltigstes": "schwefelhaltig",
    "schwefelige": "schwefelig",
    "schwefeligem": "schwefelig",
    "schwefeligen": "schwefelig",
    "schwefeliger": "schwefelig",
    "schwefeligere": "schwefelig",
    "schwefeligerem": "schwefelig",
    "schwefeligeren": "schwefelig",
    "schwefeligerer": "schwefelig",
    "schwefeligeres": "schwefelig",
    "schwefeliges": "schwefelig",
    "schwefeligste": "schwefelig",
    "schwefeligstem": "schwefelig",
    "schwefeligsten": "schwefelig",
    "schwefeligster": "schwefelig",
    "schwefeligstes": "schwefelig",
    "schwefelnd": "schwefeln",
    "schwefelnde": "schwefelnd",
    "schwefelndem": "schwefelnd",
    "schwefelnden": "schwefelnd",
    "schwefelnder": "schwefelnd",
    "schwefelndes": "schwefelnd",
    "schwefelst": "schwefeln",
    "schwefelt": "schwefeln",
    "schwefelte": "schwefeln",
    "schwefelten": "schwefeln",
    "schwefeltest": "schwefeln",
    "schwefeltet": "schwefeln",
    "schwefle": "schwefeln",
    "schweifend": "schweifen",
    "schweifende": "schweifend",
    "schweifendem": "schweifend",
    "schweifenden": "schweifend",
    "schweifender": "schweifend",
    "schweifendere": "schweifend",
    "schweifenderem": "schweifend",
    "schweifenderen": "schweifend",
    "schweifenderer": "schweifend",
    "schweifenderes": "schweifend",
    "schweifendes": "schweifend",
    "schweifendste": "schweifend",
    "schweifendstem": "schweifend",
    "schweifendsten": "schweifend",
    "schweifendster": "schweifend",
    "schweifendstes": "schweifend",
    "schweifest": "schweifen",
    "schweifet": "schweifen",
    "schweifst": "schweifen",
    "schweift": "schweifen",
    "schweifte": "schweifen",
    "schweiften": "schweifen",
    "schweiftest": "schweifen",
    "schweiftet": "schweifen",
    "schweige": "schweigen",
    "schweigend": "schweigen",
    "schweigende": "schweigend",
    "schweigendem": "schweigend",
    "schweigenden": "schweigend",
    "schweigender": "schweigend",
    "schweigendere": "schweigend",
    "schweigenderem": "schweigend",
    "schweigenderen": "schweigend",
    "schweigenderer": "schweigend",
    "schweigenderes": "schweigend",
    "schweigendes": "schweigend",
    "schweigendste": "schweigend",
    "schweigendstem": "schweigend",
    "schweigendsten": "schweigend",
    "schweigendster": "schweigend",
    "schweigendstes": "schweigend",
    "schweigest": "schweigen",
    "schweiget": "schweigen",
    "schweigsame": "schweigsam",
    "schweigsamem": "schweigsam",
    "schweigsamen": "schweigsam",
    "schweigsamer": "schweigsam",
    "schweigsamere": "schweigsam",
    "schweigsamerem": "schweigsam",
    "schweigsameren": "schweigsam",
    "schweigsamerer": "schweigsam",
    "schweigsameres": "schweigsam",
    "schweigsames": "schweigsam",
    "schweigsamste": "schweigsam",
    "schweigsamstem": "schweigsam",
    "schweigsamsten": "schweigsam",
    "schweigsamster": "schweigsam",
    "schweigsamstes": "schweigsam",
    "schweigst": "schweigen",
    "schweigt": "schweigen",
    "schweinischem": "schweinisch",
    "schweinischen": "schweinisch",
    "schweinischer": "schweinisch",
    "schweinischere": "schweinisch",
    "schweinischerem": "schweinisch",
    "schweinischeren": "schweinisch",
    "schweinischerer": "schweinisch",
    "schweinischeres": "schweinisch",
    "schweinisches": "schweinisch",
    "schweinischste": "schweinisch",
    "schweinischstem": "schweinisch",
    "schweinischsten": "schweinisch",
    "schweinischster": "schweinisch",
    "schweinischstes": "schweinisch",
    "schweizerischem": "schweizerisch",
    "schweizerischen": "schweizerisch",
    "schweizerischer": "schweizerisch",
    "schweizerischere": "schweizerisch",
    "schweizerischerem": "schweizerisch",
    "schweizerischeren": "schweizerisch",
    "schweizerischerer": "schweizerisch",
    "schweizerischeres": "schweizerisch",
    "schweizerisches": "schweizerisch",
    "schweizerischste": "schweizerisch",
    "schweizerischstem": "schweizerisch",
    "schweizerischsten": "schweizerisch",
    "schweizerischster": "schweizerisch",
    "schweizerischstes": "schweizerisch",
    "schweiße": "schweißen",
    "schweißend": "schweißen",
    "schweißende": "schweißend",
    "schweißendem": "schweißend",
    "schweißenden": "schweißend",
    "schweißender": "schweißend",
    "schweißendes": "schweißend",
    "schweißest": "schweißen",
    "schweißet": "schweißen",
    "schweißt": "schweißen",
    "schweißte": "schweißen",
    "schweißten": "schweißen",
    "schweißtest": "schweißen",
    "schweißtet": "schweißen",
    "schweißtreibende": "schweißtreibend",
    "schweißtreibendem": "schweißtreibend",
    "schweißtreibenden": "schweißtreibend",
    "schweißtreibender": "schweißtreibend",
    "schweißtreibendere": "schweißtreibend",
    "schweißtreibenderem": "schweißtreibend",
    "schweißtreibenderen": "schweißtreibend",
    "schweißtreibenderer": "schweißtreibend",
    "schweißtreibenderes": "schweißtreibend",
    "schweißtreibendes": "schweißtreibend",
    "schweißtreibendste": "schweißtreibend",
    "schweißtreibendstem": "schweißtreibend",
    "schweißtreibendsten": "schweißtreibend",
    "schweißtreibendster": "schweißtreibend",
    "schweißtreibendstes": "schweißtreibend",
    "schweißtriefende": "schweißtriefend",
    "schweißtriefendem": "schweißtriefend",
    "schweißtriefenden": "schweißtriefend",
    "schweißtriefender": "schweißtriefend",
    "schweißtriefendere": "schweißtriefend",
    "schweißtriefenderem": "schweißtriefend",
    "schweißtriefenderen": "schweißtriefend",
    "schweißtriefenderer": "schweißtriefend",
    "schweißtriefenderes": "schweißtriefend",
    "schweißtriefendes": "schweißtriefend",
    "schweißtriefendste": "schweißtriefend",
    "schweißtriefendstem": "schweißtriefend",
    "schweißtriefendsten": "schweißtriefend",
    "schweißtriefendster": "schweißtriefend",
    "schweißtriefendstes": "schweißtriefend",
    "schwele": "schwelen",
    "schwelend": "schwelen",
    "schwelende": "schwelend",
    "schwelendem": "schwelend",
    "schwelenden": "schwelend",
    "schwelender": "schwelend",
    "schwelendes": "schwelend",
    "schwelest": "schwelen",
    "schwelet": "schwelen",
    "schwelge": "schwelgen",
    "schwelgend": "schwelgen",
    "schwelgende": "schwelgend",
    "schwelgendem": "schwelgend",
    "schwelgenden": "schwelgend",
    "schwelgender": "schwelgend",
    "schwelgendes": "schwelgend",
    "schwelgest": "schwelgen",
    "schwelget": "schwelgen",
    "schwelgst": "schwelgen",
    "schwelgt": "schwelgen",
    "schwelgte": "schwelgen",
    "schwelgten": "schwelgen",
    "schwelgtest": "schwelgen",
    "schwelgtet": "schwelgen",
    "schwelle": "schwellen",
    "schwellend": "schwellen",
    "schwellende": "schwellend",
    "schwellendem": "schwellend",
    "schwellenden": "schwellend",
    "schwellender": "schwellend",
    "schwellendere": "schwellend",
    "schwellenderem": "schwellend",
    "schwellenderen": "schwellend",
    "schwellenderer": "schwellend",
    "schwellenderes": "schwellend",
    "schwellendes": "schwellend",
    "schwellendste": "schwellend",
    "schwellendstem": "schwellend",
    "schwellendsten": "schwellend",
    "schwellendster": "schwellend",
    "schwellendstes": "schwellend",
    "schwellest": "schwellen",
    "schwellet": "schwellen",
    "schwellst": "schwellen",
    "schwellt": "schwellen",
    "schwellte": "schwellen",
    "schwellten": "schwellen",
    "schwelltest": "schwellen",
    "schwelltet": "schwellen",
    "schwelst": "schwelen",
    "schwelt": "schwelen",
    "schwelte": "schwelen",
    "schwelten": "schwelen",
    "schweltest": "schwelen",
    "schweltet": "schwelen",
    "schwemme": "schwemmen",
    "schwemmend": "schwemmen",
    "schwemmende": "schwemmend",
    "schwemmendem": "schwemmend",
    "schwemmenden": "schwemmend",
    "schwemmender": "schwemmend",
    "schwemmendere": "schwemmend",
    "schwemmenderem": "schwemmend",
    "schwemmenderen": "schwemmend",
    "schwemmenderer": "schwemmend",
    "schwemmenderes": "schwemmend",
    "schwemmendes": "schwemmend",
    "schwemmendste": "schwemmend",
    "schwemmendstem": "schwemmend",
    "schwemmendsten": "schwemmend",
    "schwemmendster": "schwemmend",
    "schwemmendstes": "schwemmend",
    "schwemmest": "schwemmen",
    "schwemmet": "schwemmen",
    "schwemmst": "schwemmen",
    "schwemmt": "schwemmen",
    "schwemmte": "schwemmen",
    "schwemmten": "schwemmen",
    "schwemmtest": "schwemmen",
    "schwemmtet": "schwemmen",
    "schwenkend": "schwenken",
    "schwenkende": "schwenkend",
    "schwenkendem": "schwenkend",
    "schwenkenden": "schwenkend",
    "schwenkender": "schwenkend",
    "schwenkendes": "schwenkend",
    "schwenkest": "schwenken",
    "schwenket": "schwenken",
    "schwenkst": "schwenken",
    "schwenkt": "schwenken",
    "schwenkte": "schwenken",
    "schwenkten": "schwenken",
    "schwenktest": "schwenken",
    "schwenktet": "schwenken",
    "schwerbehindertem": "schwerbehindert",
    "schwerbehinderten": "schwerbehindert",
    "schwerbehinderter": "schwerbehindert",
    "schwerbehindertere": "schwerbehindert",
    "schwerbehinderterem": "schwerbehindert",
    "schwerbehinderteren": "schwerbehindert",
    "schwerbehinderterer": "schwerbehindert",
    "schwerbehinderteres": "schwerbehindert",
    "schwerbehindertes": "schwerbehindert",
    "schwerbehindertste": "schwerbehindert",
    "schwerbehindertstem": "schwerbehindert",
    "schwerbehindertsten": "schwerbehindert",
    "schwerbehindertster": "schwerbehindert",
    "schwerbehindertstes": "schwerbehindert",
    "schwerbeschädigtem": "schwerbeschädigt",
    "schwerbeschädigten": "schwerbeschädigt",
    "schwerbeschädigter": "schwerbeschädigt",
    "schwerbeschädigtes": "schwerbeschädigt",
    "schwerbewaffnete": "schwerbewaffnet",
    "schwerbewaffnetem": "schwerbewaffnet",
    "schwerbewaffneten": "schwerbewaffnet",
    "schwerbewaffneter": "schwerbewaffnet",
    "schwerbewaffnetes": "schwerbewaffnet",
    "schwere": "schwer",
    "schwerelosem": "schwerelos",
    "schwerelosen": "schwerelos",
    "schwereloser": "schwerelos",
    "schwereloses": "schwerelos",
    "schwerem": "schwer",
    "schweren": "schwer",
    "schwerer": "schwer",
    "schwerere": "schwer",
    "schwererem": "schwer",
    "schwereren": "schwer",
    "schwererer": "schwer",
    "schwereres": "schwer",
    "schwererziehbare": "schwererziehbar",
    "schwererziehbarem": "schwererziehbar",
    "schwererziehbaren": "schwererziehbar",
    "schwererziehbarer": "schwererziehbar",
    "schwererziehbares": "schwererziehbar",
    "schweres": "schwer",
    "schwerfalle": "schwerfallen",
    "schwerfallend": "schwerfallen",
    "schwerfallende": "schwerfallend",
    "schwerfallendem": "schwerfallend",
    "schwerfallenden": "schwerfallend",
    "schwerfallender": "schwerfallend",
    "schwerfallendere": "schwerfallend",
    "schwerfallenderem": "schwerfallend",
    "schwerfallenderen": "schwerfallend",
    "schwerfallenderer": "schwerfallend",
    "schwerfallenderes": "schwerfallend",
    "schwerfallendes": "schwerfallend",
    "schwerfallendste": "schwerfallend",
    "schwerfallendstem": "schwerfallend",
    "schwerfallendsten": "schwerfallend",
    "schwerfallendster": "schwerfallend",
    "schwerfallendstes": "schwerfallend",
    "schwerfallest": "schwerfallen",
    "schwerfallet": "schwerfallen",
    "schwerfallt": "schwerfallen",
    "schwerfiel": "schwerfallen",
    "schwerfiele": "schwerfallen",
    "schwerfielen": "schwerfallen",
    "schwerfielest": "schwerfallen",
    "schwerfielet": "schwerfallen",
    "schwerfielst": "schwerfallen",
    "schwerfielt": "schwerfallen",
    "schwerfällige": "schwerfällig",
    "schwerfälligem": "schwerfällig",
    "schwerfälligen": "schwerfällig",
    "schwerfälliger": "schwerfällig",
    "schwerfälligere": "schwerfällig",
    "schwerfälligerem": "schwerfällig",
    "schwerfälligeren": "schwerfällig",
    "schwerfälligerer": "schwerfällig",
    "schwerfälligeres": "schwerfällig",
    "schwerfälliges": "schwerfällig",
    "schwerfälligste": "schwerfällig",
    "schwerfälligstem": "schwerfällig",
    "schwerfälligsten": "schwerfällig",
    "schwerfälligster": "schwerfällig",
    "schwerfälligstes": "schwerfällig",
    "schwerfällst": "schwerfallen",
    "schwerfällt": "schwerfallen",
    "schwergefallen": "schwerfallen",
    "schwergefallene": "schwergefallen",
    "schwergefallenem": "schwergefallen",
    "schwergefallenen": "schwergefallen",
    "schwergefallener": "schwergefallen",
    "schwergefallenere": "schwergefallen",
    "schwergefallenerem": "schwergefallen",
    "schwergefalleneren": "schwergefallen",
    "schwergefallenerer": "schwergefallen",
    "schwergefalleneres": "schwergefallen",
    "schwergefallenes": "schwergefallen",
    "schwergefallenste": "schwergefallen",
    "schwergefallenstem": "schwergefallen",
    "schwergefallensten": "schwergefallen",
    "schwergefallenster": "schwergefallen",
    "schwergefallenstes": "schwergefallen",
    "schwerhörigem": "schwerhörig",
    "schwerhörigen": "schwerhörig",
    "schwerhöriger": "schwerhörig",
    "schwerhöriges": "schwerhörig",
    "schwerkrankem": "schwerkrank",
    "schwerkranken": "schwerkrank",
    "schwerkranker": "schwerkrank",
    "schwerkrankes": "schwerkrank",
    "schwermütigem": "schwermütig",
    "schwermütigen": "schwermütig",
    "schwermütiger": "schwermütig",
    "schwermütigere": "schwermütig",
    "schwermütigerem": "schwermütig",
    "schwermütigeren": "schwermütig",
    "schwermütigerer": "schwermütig",
    "schwermütigeres": "schwermütig",
    "schwermütiges": "schwermütig",
    "schwermütigste": "schwermütig",
    "schwermütigstem": "schwermütig",
    "schwermütigsten": "schwermütig",
    "schwermütigster": "schwermütig",
    "schwermütigstes": "schwermütig",
    "schwerreichem": "schwerreich",
    "schwerreichen": "schwerreich",
    "schwerreicher": "schwerreich",
    "schwerreiches": "schwerreich",
    "schwerste": "schwer",
    "schwerstem": "schwer",
    "schwersten": "schwer",
    "schwerster": "schwer",
    "schwerstes": "schwer",
    "schwerverdaulichem": "schwerverdaulich",
    "schwerverdaulichen": "schwerverdaulich",
    "schwerverdaulicher": "schwerverdaulich",
    "schwerverdauliches": "schwerverdaulich",
    "schwerverletzte": "schwerverletzt",
    "schwerverletztem": "schwerverletzt",
    "schwerverletzten": "schwerverletzt",
    "schwerverletzter": "schwerverletzt",
    "schwerverletztes": "schwerverletzt",
    "schwerverständliche": "schwerverständlich",
    "schwerverständlichem": "schwerverständlich",
    "schwerverständlichen": "schwerverständlich",
    "schwerverständlicher": "schwerverständlich",
    "schwerverständliches": "schwerverständlich",
    "schwerverwundete": "schwerverwundet",
    "schwerverwundetem": "schwerverwundet",
    "schwerverwundeten": "schwerverwundet",
    "schwerverwundeter": "schwerverwundet",
    "schwerverwundetes": "schwerverwundet",
    "schwerwiegende": "schwerwiegend",
    "schwerwiegendem": "schwerwiegend",
    "schwerwiegenden": "schwerwiegend",
    "schwerwiegender": "schwerwiegend",
    "schwerwiegendes": "schwerwiegend",
    "schwerzufallen": "schwerfallen",
    "schwesterliche": "schwesterlich",
    "schwesterlichem": "schwesterlich",
    "schwesterlichen": "schwesterlich",
    "schwesterlicher": "schwesterlich",
    "schwesterliches": "schwesterlich",
    "schwieg": "schweigen",
    "schwiege": "schweigen",
    "schwiegen": "schweigen",
    "schwiegest": "schweigen",
    "schwieget": "schweigen",
    "schwiegst": "schweigen",
    "schwiegt": "schweigen",
    "schwierigem": "schwierig",
    "schwierigen": "schwierig",
    "schwieriger": "schwierig",
    "schwierigere": "schwierig",
    "schwierigerem": "schwierig",
    "schwierigeren": "schwierig",
    "schwierigerer": "schwierig",
    "schwierigeres": "schwierig",
    "schwieriges": "schwierig",
    "schwierigstem": "schwierig",
    "schwierigsten": "schwierig",
    "schwierigster": "schwierig",
    "schwierigstes": "schwierig",
    "schwill": "schwellen",
    "schwillst": "schwellen",
    "schwillt": "schwellen",
    "schwimme": "schwimmen",
    "schwimmend": "schwimmen",
    "schwimmende": "schwimmend",
    "schwimmendem": "schwimmend",
    "schwimmenden": "schwimmend",
    "schwimmender": "schwimmend",
    "schwimmendes": "schwimmend",
    "schwimmest": "schwimmen",
    "schwimmet": "schwimmen",
    "schwimmfähige": "schwimmfähig",
    "schwimmfähigem": "schwimmfähig",
    "schwimmfähigen": "schwimmfähig",
    "schwimmfähiger": "schwimmfähig",
    "schwimmfähigere": "schwimmfähig",
    "schwimmfähigerem": "schwimmfähig",
    "schwimmfähigeren": "schwimmfähig",
    "schwimmfähigerer": "schwimmfähig",
    "schwimmfähigeres": "schwimmfähig",
    "schwimmfähiges": "schwimmfähig",
    "schwimmfähigste": "schwimmfähig",
    "schwimmfähigstem": "schwimmfähig",
    "schwimmfähigsten": "schwimmfähig",
    "schwimmfähigster": "schwimmfähig",
    "schwimmfähigstes": "schwimmfähig",
    "schwimmst": "schwimmen",
    "schwimmt": "schwimmen",
    "schwinde": "schwinden",
    "schwindele": "schwindeln",
    "schwindelerregendem": "schwindelerregend",
    "schwindelerregenden": "schwindelerregend",
    "schwindelerregender": "schwindelerregend",
    "schwindelerregendere": "schwindelerregend",
    "schwindelerregenderem": "schwindelerregend",
    "schwindelerregenderen": "schwindelerregend",
    "schwindelerregenderer": "schwindelerregend",
    "schwindelerregenderes": "schwindelerregend",
    "schwindelerregendes": "schwindelerregend",
    "schwindelerregendste": "schwindelerregend",
    "schwindelerregendstem": "schwindelerregend",
    "schwindelerregendsten": "schwindelerregend",
    "schwindelerregendster": "schwindelerregend",
    "schwindelerregendstes": "schwindelerregend",
    "schwindelfreie": "schwindelfrei",
    "schwindelfreiem": "schwindelfrei",
    "schwindelfreien": "schwindelfrei",
    "schwindelfreier": "schwindelfrei",
    "schwindelfreies": "schwindelfrei",
    "schwindelige": "schwindelig",
    "schwindeligem": "schwindelig",
    "schwindeligen": "schwindelig",
    "schwindeliger": "schwindelig",
    "schwindeligere": "schwindelig",
    "schwindeligerem": "schwindelig",
    "schwindeligeren": "schwindelig",
    "schwindeligerer": "schwindelig",
    "schwindeligeres": "schwindelig",
    "schwindeliges": "schwindelig",
    "schwindeligste": "schwindelig",
    "schwindeligstem": "schwindelig",
    "schwindeligsten": "schwindelig",
    "schwindeligster": "schwindelig",
    "schwindeligstes": "schwindelig",
    "schwindelnd": "schwindeln",
    "schwindelnde": "schwindelnd",
    "schwindelndem": "schwindelnd",
    "schwindelnden": "schwindelnd",
    "schwindelnder": "schwindelnd",
    "schwindelndere": "schwindelnd",
    "schwindelnderem": "schwindelnd",
    "schwindelnderen": "schwindelnd",
    "schwindelnderer": "schwindelnd",
    "schwindelnderes": "schwindelnd",
    "schwindelndes": "schwindelnd",
    "schwindelndste": "schwindelnd",
    "schwindelndstem": "schwindelnd",
    "schwindelndsten": "schwindelnd",
    "schwindelndster": "schwindelnd",
    "schwindelndstes": "schwindelnd",
    "schwindelst": "schwindeln",
    "schwindelt": "schwindeln",
    "schwindelte": "schwindeln",
    "schwindelten": "schwindeln",
    "schwindeltest": "schwindeln",
    "schwindeltet": "schwindeln",
    "schwindend": "schwinden",
    "schwindende": "schwindend",
    "schwindendem": "schwindend",
    "schwindenden": "schwindend",
    "schwindender": "schwindend",
    "schwindendere": "schwindend",
    "schwindenderem": "schwindend",
    "schwindenderen": "schwindend",
    "schwindenderer": "schwindend",
    "schwindenderes": "schwindend",
    "schwindendes": "schwindend",
    "schwindendste": "schwindend",
    "schwindendstem": "schwindend",
    "schwindendsten": "schwindend",
    "schwindendster": "schwindend",
    "schwindendstes": "schwindend",
    "schwindest": "schwinden",
    "schwindet": "schwinden",
    "schwindle": "schwindeln",
    "schwindligem": "schwindlig",
    "schwindligen": "schwindlig",
    "schwindliger": "schwindlig",
    "schwindligere": "schwindlig",
    "schwindligerem": "schwindlig",
    "schwindligeren": "schwindlig",
    "schwindligerer": "schwindlig",
    "schwindligeres": "schwindlig",
    "schwindliges": "schwindlig",
    "schwindligste": "schwindlig",
    "schwindligstem": "schwindlig",
    "schwindligsten": "schwindlig",
    "schwindligster": "schwindlig",
    "schwindligstes": "schwindlig",
    "schwinge": "schwingen",
    "schwingend": "schwingen",
    "schwingende": "schwingend",
    "schwingendem": "schwingend",
    "schwingenden": "schwingend",
    "schwingender": "schwingend",
    "schwingendere": "schwingend",
    "schwingenderem": "schwingend",
    "schwingenderen": "schwingend",
    "schwingenderer": "schwingend",
    "schwingenderes": "schwingend",
    "schwingendes": "schwingend",
    "schwingendste": "schwingend",
    "schwingendstem": "schwingend",
    "schwingendsten": "schwingend",
    "schwingendster": "schwingend",
    "schwingendstes": "schwingend",
    "schwingest": "schwingen",
    "schwinget": "schwingen",
    "schwingst": "schwingen",
    "schwingt": "schwingen",
    "schwirre": "schwirren",
    "schwirrend": "schwirren",
    "schwirrende": "schwirrend",
    "schwirrendem": "schwirrend",
    "schwirrenden": "schwirrend",
    "schwirrender": "schwirrend",
    "schwirrendere": "schwirrend",
    "schwirrenderem": "schwirrend",
    "schwirrenderen": "schwirrend",
    "schwirrenderer": "schwirrend",
    "schwirrenderes": "schwirrend",
    "schwirrendes": "schwirrend",
    "schwirrendste": "schwirrend",
    "schwirrendstem": "schwirrend",
    "schwirrendsten": "schwirrend",
    "schwirrendster": "schwirrend",
    "schwirrendstes": "schwirrend",
    "schwirrest": "schwirren",
    "schwirret": "schwirren",
    "schwirrst": "schwirren",
    "schwirrt": "schwirren",
    "schwirrte": "schwirren",
    "schwirrten": "schwirren",
    "schwirrtest": "schwirren",
    "schwirrtet": "schwirren",
    "schwitzend": "schwitzen",
    "schwitzende": "schwitzend",
    "schwitzendem": "schwitzend",
    "schwitzenden": "schwitzend",
    "schwitzender": "schwitzend",
    "schwitzendere": "schwitzend",
    "schwitzenderem": "schwitzend",
    "schwitzenderen": "schwitzend",
    "schwitzenderer": "schwitzend",
    "schwitzenderes": "schwitzend",
    "schwitzendes": "schwitzend",
    "schwitzendste": "schwitzend",
    "schwitzendstem": "schwitzend",
    "schwitzendsten": "schwitzend",
    "schwitzendster": "schwitzend",
    "schwitzendstes": "schwitzend",
    "schwitzest": "schwitzen",
    "schwitzet": "schwitzen",
    "schwitzige": "schwitzig",
    "schwitzigem": "schwitzig",
    "schwitzigen": "schwitzig",
    "schwitziger": "schwitzig",
    "schwitzigere": "schwitzig",
    "schwitzigerem": "schwitzig",
    "schwitzigeren": "schwitzig",
    "schwitzigerer": "schwitzig",
    "schwitzigeres": "schwitzig",
    "schwitziges": "schwitzig",
    "schwitzigste": "schwitzig",
    "schwitzigstem": "schwitzig",
    "schwitzigsten": "schwitzig",
    "schwitzigster": "schwitzig",
    "schwitzigstes": "schwitzig",
    "schwitzt": "schwitzen",
    "schwitzte": "schwitzen",
    "schwitzten": "schwitzen",
    "schwitztest": "schwitzen",
    "schwitztet": "schwitzen",
    "schwoll": "schwellen",
    "schwollen": "schwellen",
    "schwollst": "schwellen",
    "schwollt": "schwellen",
    "schwor": "schwören",
    "schwore": "schwären",
    "schworen": "schwören",
    "schworest": "schwären",
    "schworet": "schwären",
    "schworst": "schwören",
    "schwort": "schwören",
    "schwule": "schwul",
    "schwulem": "schwul",
    "schwulen": "schwul",
    "schwuler": "schwul",
    "schwulere": "schwul",
    "schwulerem": "schwul",
    "schwuleren": "schwul",
    "schwulerer": "schwul",
    "schwuleres": "schwul",
    "schwules": "schwul",
    "schwulstem": "schwul",
    "schwulsten": "schwul",
    "schwulster": "schwul",
    "schwulstes": "schwul",
    "schwunghaftem": "schwunghaft",
    "schwunghaften": "schwunghaft",
    "schwunghafter": "schwunghaft",
    "schwunghaftere": "schwunghaft",
    "schwunghafterem": "schwunghaft",
    "schwunghafteren": "schwunghaft",
    "schwunghafterer": "schwunghaft",
    "schwunghafteres": "schwunghaft",
    "schwunghaftes": "schwunghaft",
    "schwunghafteste": "schwunghaft",
    "schwunghaftestem": "schwunghaft",
    "schwunghaftesten": "schwunghaft",
    "schwunghaftester": "schwunghaft",
    "schwunghaftestes": "schwunghaft",
    "schwunglose": "schwunglos",
    "schwunglosem": "schwunglos",
    "schwunglosen": "schwunglos",
    "schwungloser": "schwunglos",
    "schwunglosere": "schwunglos",
    "schwungloserem": "schwunglos",
    "schwungloseren": "schwunglos",
    "schwungloserer": "schwunglos",
    "schwungloseres": "schwunglos",
    "schwungloses": "schwunglos",
    "schwungloseste": "schwunglos",
    "schwunglosestem": "schwunglos",
    "schwunglosesten": "schwunglos",
    "schwunglosester": "schwunglos",
    "schwunglosestes": "schwunglos",
    "schwungvollem": "schwungvoll",
    "schwungvollen": "schwungvoll",
    "schwungvoller": "schwungvoll",
    "schwungvollere": "schwungvoll",
    "schwungvollerem": "schwungvoll",
    "schwungvolleren": "schwungvoll",
    "schwungvollerer": "schwungvoll",
    "schwungvolleres": "schwungvoll",
    "schwungvolles": "schwungvoll",
    "schwungvollste": "schwungvoll",
    "schwungvollstem": "schwungvoll",
    "schwungvollsten": "schwungvoll",
    "schwungvollster": "schwungvoll",
    "schwungvollstes": "schwungvoll",
    "schwäbele": "schwäbeln",
    "schwäbelnd": "schwäbeln",
    "schwäbelnde": "schwäbelnd",
    "schwäbelndem": "schwäbelnd",
    "schwäbelnden": "schwäbelnd",
    "schwäbelnder": "schwäbelnd",
    "schwäbelndere": "schwäbelnd",
    "schwäbelnderem": "schwäbelnd",
    "schwäbelnderen": "schwäbelnd",
    "schwäbelnderer": "schwäbelnd",
    "schwäbelnderes": "schwäbelnd",
    "schwäbelndes": "schwäbelnd",
    "schwäbelndste": "schwäbelnd",
    "schwäbelndstem": "schwäbelnd",
    "schwäbelndsten": "schwäbelnd",
    "schwäbelndster": "schwäbelnd",
    "schwäbelndstes": "schwäbelnd",
    "schwäbelst": "schwäbeln",
    "schwäbelt": "schwäbeln",
    "schwäbelte": "schwäbeln",
    "schwäbelten": "schwäbeln",
    "schwäbeltest": "schwäbeln",
    "schwäbeltet": "schwäbeln",
    "schwäbischem": "schwäbisch",
    "schwäbischen": "schwäbisch",
    "schwäbischer": "schwäbisch",
    "schwäbisches": "schwäbisch",
    "schwäble": "schwäbeln",
    "schwächend": "schwächen",
    "schwächende": "schwächend",
    "schwächendem": "schwächend",
    "schwächenden": "schwächend",
    "schwächender": "schwächend",
    "schwächendere": "schwächend",
    "schwächenderem": "schwächend",
    "schwächenderen": "schwächend",
    "schwächenderer": "schwächend",
    "schwächenderes": "schwächend",
    "schwächendes": "schwächend",
    "schwächendste": "schwächend",
    "schwächendstem": "schwächend",
    "schwächendsten": "schwächend",
    "schwächendster": "schwächend",
    "schwächendstes": "schwächend",
    "schwächer": "schwach",
    "schwächere": "schwach",
    "schwächerem": "schwach",
    "schwächeren": "schwach",
    "schwächerer": "schwach",
    "schwächeres": "schwach",
    "schwächest": "schwächen",
    "schwächet": "schwächen",
    "schwächlichem": "schwächlich",
    "schwächlichen": "schwächlich",
    "schwächlicher": "schwächlich",
    "schwächlichere": "schwächlich",
    "schwächlicherem": "schwächlich",
    "schwächlicheren": "schwächlich",
    "schwächlicherer": "schwächlich",
    "schwächlicheres": "schwächlich",
    "schwächliches": "schwächlich",
    "schwächlichste": "schwächlich",
    "schwächlichstem": "schwächlich",
    "schwächlichsten": "schwächlich",
    "schwächlichster": "schwächlich",
    "schwächlichstes": "schwächlich",
    "schwächst": "schwächen",
    "schwächste": "schwach",
    "schwächstem": "schwach",
    "schwächsten": "schwach",
    "schwächster": "schwach",
    "schwächstes": "schwach",
    "schwächt": "schwächen",
    "schwächte": "schwächen",
    "schwächten": "schwächen",
    "schwächtest": "schwächen",
    "schwächtet": "schwächen",
    "schwämmest": "schwimmen",
    "schwämmet": "schwimmen",
    "schwände": "schwinden",
    "schwänden": "schwinden",
    "schwändest": "schwinden",
    "schwändet": "schwinden",
    "schwänge": "schwingen",
    "schwängen": "schwingen",
    "schwängere": "schwängern",
    "schwängernd": "schwängern",
    "schwängernde": "schwängernd",
    "schwängerndem": "schwängernd",
    "schwängernden": "schwängernd",
    "schwängernder": "schwängernd",
    "schwängerndes": "schwängernd",
    "schwängerst": "schwängern",
    "schwängert": "schwängern",
    "schwängerte": "schwängern",
    "schwängerten": "schwängern",
    "schwängertest": "schwängern",
    "schwängertet": "schwängern",
    "schwängest": "schwingen",
    "schwänget": "schwingen",
    "schwänzend": "schwänzen",
    "schwänzende": "schwänzend",
    "schwänzendem": "schwänzend",
    "schwänzenden": "schwänzend",
    "schwänzender": "schwänzend",
    "schwänzendere": "schwänzend",
    "schwänzenderem": "schwänzend",
    "schwänzenderen": "schwänzend",
    "schwänzenderer": "schwänzend",
    "schwänzenderes": "schwänzend",
    "schwänzendes": "schwänzend",
    "schwänzendste": "schwänzend",
    "schwänzendstem": "schwänzend",
    "schwänzendsten": "schwänzend",
    "schwänzendster": "schwänzend",
    "schwänzendstes": "schwänzend",
    "schwänzest": "schwänzen",
    "schwänzet": "schwänzen",
    "schwänzt": "schwänzen",
    "schwänzte": "schwänzen",
    "schwänzten": "schwänzen",
    "schwänztest": "schwänzen",
    "schwänztet": "schwänzen",
    "schwäre": "schwären",
    "schwärend": "schwären",
    "schwärende": "schwärend",
    "schwärendem": "schwärend",
    "schwärenden": "schwärend",
    "schwärender": "schwärend",
    "schwärendes": "schwärend",
    "schwärest": "schwären",
    "schwäret": "schwären",
    "schwärme": "schwärmen",
    "schwärmend": "schwärmen",
    "schwärmende": "schwärmend",
    "schwärmendem": "schwärmend",
    "schwärmenden": "schwärmend",
    "schwärmender": "schwärmend",
    "schwärmendes": "schwärmend",
    "schwärmerischem": "schwärmerisch",
    "schwärmerischen": "schwärmerisch",
    "schwärmerischer": "schwärmerisch",
    "schwärmerischere": "schwärmerisch",
    "schwärmerischerem": "schwärmerisch",
    "schwärmerischeren": "schwärmerisch",
    "schwärmerischerer": "schwärmerisch",
    "schwärmerischeres": "schwärmerisch",
    "schwärmerisches": "schwärmerisch",
    "schwärmerischste": "schwärmerisch",
    "schwärmerischstem": "schwärmerisch",
    "schwärmerischsten": "schwärmerisch",
    "schwärmerischster": "schwärmerisch",
    "schwärmerischstes": "schwärmerisch",
    "schwärmest": "schwärmen",
    "schwärmet": "schwärmen",
    "schwärmst": "schwärmen",
    "schwärmt": "schwärmen",
    "schwärmte": "schwärmen",
    "schwärmten": "schwärmen",
    "schwärmtest": "schwärmen",
    "schwärmtet": "schwärmen",
    "schwärst": "schwären",
    "schwärt": "schwären",
    "schwärzend": "schwärzen",
    "schwärzende": "schwärzend",
    "schwärzendem": "schwärzend",
    "schwärzenden": "schwärzend",
    "schwärzender": "schwärzend",
    "schwärzendere": "schwärzend",
    "schwärzenderem": "schwärzend",
    "schwärzenderen": "schwärzend",
    "schwärzenderer": "schwärzend",
    "schwärzenderes": "schwärzend",
    "schwärzendes": "schwärzend",
    "schwärzendste": "schwärzend",
    "schwärzendstem": "schwärzend",
    "schwärzendsten": "schwärzend",
    "schwärzendster": "schwärzend",
    "schwärzendstes": "schwärzend",
    "schwärzer": "schwarz",
    "schwärzere": "schwarz",
    "schwärzerem": "schwarz",
    "schwärzeren": "schwarz",
    "schwärzerer": "schwarz",
    "schwärzeres": "schwarz",
    "schwärzest": "schwärzen",
    "schwärzeste": "schwarz",
    "schwärzestem": "schwarz",
    "schwärzesten": "schwarz",
    "schwärzester": "schwarz",
    "schwärzestes": "schwarz",
    "schwärzet": "schwärzen",
    "schwärzt": "schwärzen",
    "schwärzte": "schwärzen",
    "schwärzten": "schwärzen",
    "schwärztest": "schwärzen",
    "schwärztet": "schwärzen",
    "schwölle": "schwellen",
    "schwöllen": "schwellen",
    "schwöllest": "schwellen",
    "schwöllet": "schwellen",
    "schwöre": "schwören",
    "schwörend": "schwören",
    "schwörende": "schwörend",
    "schwörendem": "schwörend",
    "schwörenden": "schwörend",
    "schwörender": "schwörend",
    "schwörendes": "schwörend",
    "schwörest": "schwören",
    "schwöret": "schwören",
    "schwörst": "schwören",
    "schwört": "schwören",
    "schwülem": "schwül",
    "schwüler": "schwül",
    "schwülerem": "schwül",
    "schwülerer": "schwül",
    "schwüleres": "schwül",
    "schwüles": "schwül",
    "schwülste": "schwül",
    "schwülstem": "schwül",
    "schwülster": "schwül",
    "schwülstes": "schwül",
    "schwülstige": "schwülstig",
    "schwülstigem": "schwülstig",
    "schwülstigen": "schwülstig",
    "schwülstiger": "schwülstig",
    "schwülstigere": "schwülstig",
    "schwülstigerem": "schwülstig",
    "schwülstigeren": "schwülstig",
    "schwülstigerer": "schwülstig",
    "schwülstigeres": "schwülstig",
    "schwülstiges": "schwülstig",
    "schwülstigste": "schwülstig",
    "schwülstigstem": "schwülstig",
    "schwülstigsten": "schwülstig",
    "schwülstigster": "schwülstig",
    "schwülstigstes": "schwülstig",
    "schäbigem": "schäbig",
    "schäbigen": "schäbig",
    "schäbiger": "schäbig",
    "schäbigere": "schäbig",
    "schäbigerem": "schäbig",
    "schäbigeren": "schäbig",
    "schäbigerer": "schäbig",
    "schäbigeres": "schäbig",
    "schäbiges": "schäbig",
    "schäbigste": "schäbig",
    "schäbigstem": "schäbig",
    "schäbigsten": "schäbig",
    "schäbigster": "schäbig",
    "schäbigstes": "schäbig",
    "schädige": "schädigen",
    "schädigend": "schädigen",
    "schädigende": "schädigend",
    "schädigendem": "schädigend",
    "schädigenden": "schädigend",
    "schädigender": "schädigend",
    "schädigendes": "schädigend",
    "schädigest": "schädigen",
    "schädiget": "schädigen",
    "schädigst": "schädigen",
    "schädigt": "schädigen",
    "schädigte": "schädigen",
    "schädigten": "schädigen",
    "schädigtest": "schädigen",
    "schädigtet": "schädigen",
    "schädlichem": "schädlich",
    "schädlichen": "schädlich",
    "schädlicher": "schädlich",
    "schädlichere": "schädlich",
    "schädlicherem": "schädlich",
    "schädlicheren": "schädlich",
    "schädlicherer": "schädlich",
    "schädlicheres": "schädlich",
    "schädliches": "schädlich",
    "schädlichste": "schädlich",
    "schädlichstem": "schädlich",
    "schädlichsten": "schädlich",
    "schädlichster": "schädlich",
    "schädlichstes": "schädlich",
    "schäle": "schälen",
    "schälend": "schälen",
    "schälendem": "schälend",
    "schälender": "schälend",
    "schälendes": "schälend",
    "schälest": "schälen",
    "schälet": "schälen",
    "schälst": "schälen",
    "schält": "schälen",
    "schälte": "schälen",
    "schälten": "schälen",
    "schältest": "schälen",
    "schältet": "schälen",
    "schäme": "schämen",
    "schämend": "schämen",
    "schämende": "schämend",
    "schämendem": "schämend",
    "schämenden": "schämend",
    "schämender": "schämend",
    "schämendere": "schämend",
    "schämenderem": "schämend",
    "schämenderen": "schämend",
    "schämenderer": "schämend",
    "schämenderes": "schämend",
    "schämendes": "schämend",
    "schämendste": "schämend",
    "schämendstem": "schämend",
    "schämendsten": "schämend",
    "schämendster": "schämend",
    "schämendstes": "schämend",
    "schämest": "schämen",
    "schämet": "schämen",
    "schämst": "schämen",
    "schämt": "schämen",
    "schämte": "schämen",
    "schämten": "schämen",
    "schämtest": "schämen",
    "schämtet": "schämen",
    "schände": "schänden",
    "schändend": "schänden",
    "schändende": "schändend",
    "schändendem": "schändend",
    "schändenden": "schändend",
    "schändender": "schändend",
    "schändendere": "schändend",
    "schändenderem": "schändend",
    "schändenderen": "schändend",
    "schändenderer": "schändend",
    "schändenderes": "schändend",
    "schändendes": "schändend",
    "schändendste": "schändend",
    "schändendstem": "schändend",
    "schändendsten": "schändend",
    "schändendster": "schändend",
    "schändendstes": "schändend",
    "schändest": "schänden",
    "schändet": "schänden",
    "schändete": "schänden",
    "schändeten": "schänden",
    "schändetest": "schänden",
    "schändetet": "schänden",
    "schändlichem": "schändlich",
    "schändlichen": "schändlich",
    "schändlicher": "schändlich",
    "schändlichere": "schändlich",
    "schändlicherem": "schändlich",
    "schändlicheren": "schändlich",
    "schändlicherer": "schändlich",
    "schändlicheres": "schändlich",
    "schändliches": "schändlich",
    "schändlichstem": "schändlich",
    "schändlichsten": "schändlich",
    "schändlichster": "schändlich",
    "schändlichstes": "schändlich",
    "schärfend": "schärfen",
    "schärfende": "schärfend",
    "schärfendem": "schärfend",
    "schärfenden": "schärfend",
    "schärfender": "schärfend",
    "schärfendere": "schärfend",
    "schärfenderem": "schärfend",
    "schärfenderen": "schärfend",
    "schärfenderer": "schärfend",
    "schärfenderes": "schärfend",
    "schärfendes": "schärfend",
    "schärfendste": "schärfend",
    "schärfendstem": "schärfend",
    "schärfendsten": "schärfend",
    "schärfendster": "schärfend",
    "schärfendstes": "schärfend",
    "schärfer": "scharf",
    "schärfere": "scharf",
    "schärferem": "scharf",
    "schärferen": "scharf",
    "schärferer": "scharf",
    "schärferes": "scharf",
    "schärfest": "schärfen",
    "schärfet": "schärfen",
    "schärfst": "schärfen",
    "schärfste": "scharf",
    "schärfstem": "scharf",
    "schärfsten": "scharf",
    "schärfster": "scharf",
    "schärfstes": "scharf",
    "schärft": "schärfen",
    "schärfte": "schärfen",
    "schärften": "schärfen",
    "schärftest": "schärfen",
    "schärftet": "schärfen",
    "schätzbarem": "schätzbar",
    "schätzbaren": "schätzbar",
    "schätzbarer": "schätzbar",
    "schätzbarere": "schätzbar",
    "schätzbarerem": "schätzbar",
    "schätzbareren": "schätzbar",
    "schätzbarerer": "schätzbar",
    "schätzbareres": "schätzbar",
    "schätzbares": "schätzbar",
    "schätzbarste": "schätzbar",
    "schätzbarstem": "schätzbar",
    "schätzbarsten": "schätzbar",
    "schätzbarster": "schätzbar",
    "schätzbarstes": "schätzbar",
    "schätzend": "schätzen",
    "schätzende": "schätzend",
    "schätzendem": "schätzend",
    "schätzenden": "schätzend",
    "schätzender": "schätzend",
    "schätzendes": "schätzend",
    "schätzenswertem": "schätzenswert",
    "schätzenswerten": "schätzenswert",
    "schätzenswerter": "schätzenswert",
    "schätzenswertere": "schätzenswert",
    "schätzenswerterem": "schätzenswert",
    "schätzenswerteren": "schätzenswert",
    "schätzenswerterer": "schätzenswert",
    "schätzenswerteres": "schätzenswert",
    "schätzenswertes": "schätzenswert",
    "schätzenswerteste": "schätzenswert",
    "schätzenswertestem": "schätzenswert",
    "schätzenswertesten": "schätzenswert",
    "schätzenswertester": "schätzenswert",
    "schätzenswertestes": "schätzenswert",
    "schätzest": "schätzen",
    "schätzet": "schätzen",
    "schätzt": "schätzen",
    "schätzte": "schätzen",
    "schätzten": "schätzen",
    "schätztest": "schätzen",
    "schätztet": "schätzen",
    "schäumend": "schäumen",
    "schäumende": "schäumend",
    "schäumendem": "schäumend",
    "schäumenden": "schäumend",
    "schäumender": "schäumend",
    "schäumendere": "schäumend",
    "schäumenderem": "schäumend",
    "schäumenderen": "schäumend",
    "schäumenderer": "schäumend",
    "schäumenderes": "schäumend",
    "schäumendes": "schäumend",
    "schäumendste": "schäumend",
    "schäumendstem": "schäumend",
    "schäumendsten": "schäumend",
    "schäumendster": "schäumend",
    "schäumendstes": "schäumend",
    "schäumest": "schäumen",
    "schäumet": "schäumen",
    "schäumst": "schäumen",
    "schäumt": "schäumen",
    "schäumte": "schäumen",
    "schäumten": "schäumen",
    "schäumtest": "schäumen",
    "schäumtet": "schäumen",
    "schöbe": "schieben",
    "schöben": "schieben",
    "schöbest": "schieben",
    "schöbet": "schieben",
    "schölte": "schelten",
    "schölten": "schelten",
    "schöltest": "schelten",
    "schöltet": "schelten",
    "schönem": "schön",
    "schönen": "schön",
    "schöner": "schön",
    "schönere": "schön",
    "schönerem": "schön",
    "schöneren": "schön",
    "schönerer": "schön",
    "schöneres": "schön",
    "schönes": "schön",
    "schönfärbe": "schönfärben",
    "schönfärbend": "schönfärben",
    "schönfärbende": "schönfärbend",
    "schönfärbendem": "schönfärbend",
    "schönfärbenden": "schönfärbend",
    "schönfärbender": "schönfärbend",
    "schönfärbendere": "schönfärbend",
    "schönfärbenderem": "schönfärbend",
    "schönfärbenderen": "schönfärbend",
    "schönfärbenderer": "schönfärbend",
    "schönfärbenderes": "schönfärbend",
    "schönfärbendes": "schönfärbend",
    "schönfärbendste": "schönfärbend",
    "schönfärbendstem": "schönfärbend",
    "schönfärbendsten": "schönfärbend",
    "schönfärbendster": "schönfärbend",
    "schönfärbendstes": "schönfärbend",
    "schönfärbest": "schönfärben",
    "schönfärbet": "schönfärben",
    "schönfärbst": "schönfärben",
    "schönfärbt": "schönfärben",
    "schönfärbte": "schönfärben",
    "schönfärbten": "schönfärben",
    "schönfärbtest": "schönfärben",
    "schönfärbtet": "schönfärben",
    "schöngefärbt": "schönfärben",
    "schöngefärbte": "schöngefärbt",
    "schöngefärbtem": "schöngefärbt",
    "schöngefärbten": "schöngefärbt",
    "schöngefärbter": "schöngefärbt",
    "schöngefärbtere": "schöngefärbt",
    "schöngefärbterem": "schöngefärbt",
    "schöngefärbteren": "schöngefärbt",
    "schöngefärbterer": "schöngefärbt",
    "schöngefärbteres": "schöngefärbt",
    "schöngefärbtes": "schöngefärbt",
    "schöngefärbteste": "schöngefärbt",
    "schöngefärbtestem": "schöngefärbt",
    "schöngefärbtesten": "schöngefärbt",
    "schöngefärbtester": "schöngefärbt",
    "schöngefärbtestes": "schöngefärbt",
    "schöngeistigem": "schöngeistig",
    "schöngeistigen": "schöngeistig",
    "schöngeistiger": "schöngeistig",
    "schöngeistigere": "schöngeistig",
    "schöngeistigerem": "schöngeistig",
    "schöngeistigeren": "schöngeistig",
    "schöngeistigerer": "schöngeistig",
    "schöngeistigeres": "schöngeistig",
    "schöngeistiges": "schöngeistig",
    "schöngeistigste": "schöngeistig",
    "schöngeistigstem": "schöngeistig",
    "schöngeistigsten": "schöngeistig",
    "schöngeistigster": "schöngeistig",
    "schöngeistigstes": "schöngeistig",
    "schönrednerischem": "schönrednerisch",
    "schönrednerischen": "schönrednerisch",
    "schönrednerischer": "schönrednerisch",
    "schönrednerisches": "schönrednerisch",
    "schönstem": "schön",
    "schönsten": "schön",
    "schönster": "schön",
    "schönstes": "schön",
    "schönzufärben": "schönfärben",
    "schöpfend": "schöpfen",
    "schöpfende": "schöpfend",
    "schöpfendem": "schöpfend",
    "schöpfenden": "schöpfend",
    "schöpfender": "schöpfend",
    "schöpfendere": "schöpfend",
    "schöpfenderem": "schöpfend",
    "schöpfenderen": "schöpfend",
    "schöpfenderer": "schöpfend",
    "schöpfenderes": "schöpfend",
    "schöpfendes": "schöpfend",
    "schöpfendste": "schöpfend",
    "schöpfendstem": "schöpfend",
    "schöpfendsten": "schöpfend",
    "schöpfendster": "schöpfend",
    "schöpfendstes": "schöpfend",
    "schöpferischem": "schöpferisch",
    "schöpferischen": "schöpferisch",
    "schöpferischer": "schöpferisch",
    "schöpferischere": "schöpferisch",
    "schöpferischerem": "schöpferisch",
    "schöpferischeren": "schöpferisch",
    "schöpferischerer": "schöpferisch",
    "schöpferischeres": "schöpferisch",
    "schöpferisches": "schöpferisch",
    "schöpferischste": "schöpferisch",
    "schöpferischstem": "schöpferisch",
    "schöpferischsten": "schöpferisch",
    "schöpferischster": "schöpferisch",
    "schöpferischstes": "schöpferisch",
    "schöpfest": "schöpfen",
    "schöpfet": "schöpfen",
    "schöpfst": "schöpfen",
    "schöpft": "schöpfen",
    "schöpfte": "schöpfen",
    "schöpften": "schöpfen",
    "schöpftest": "schöpfen",
    "schöpftet": "schöpfen",
    "schöre": "scheren",
    "schören": "scheren",
    "schörest": "scheren",
    "schöret": "scheren",
    "schösse": "schießen",
    "schössen": "schießen",
    "schössest": "schießen",
    "schösset": "schießen",
    "schüchternem": "schüchtern",
    "schüchternen": "schüchtern",
    "schüchterner": "schüchtern",
    "schüchternere": "schüchtern",
    "schüchternerem": "schüchtern",
    "schüchterneren": "schüchtern",
    "schüchternerer": "schüchtern",
    "schüchterneres": "schüchtern",
    "schüchternes": "schüchtern",
    "schüchternste": "schüchtern",
    "schüchternstem": "schüchtern",
    "schüchternsten": "schüchtern",
    "schüchternster": "schüchtern",
    "schüchternstes": "schüchtern",
    "schüfe": "schaffen",
    "schüfen": "schaffen",
    "schüfest": "schaffen",
    "schüfet": "schaffen",
    "schülerhaftem": "schülerhaft",
    "schülerhaften": "schülerhaft",
    "schülerhafter": "schülerhaft",
    "schülerhaftere": "schülerhaft",
    "schülerhafterem": "schülerhaft",
    "schülerhafteren": "schülerhaft",
    "schülerhafterer": "schülerhaft",
    "schülerhafteres": "schülerhaft",
    "schülerhaftes": "schülerhaft",
    "schülerhafteste": "schülerhaft",
    "schülerhaftestem": "schülerhaft",
    "schülerhaftesten": "schülerhaft",
    "schülerhaftester": "schülerhaft",
    "schülerhaftestes": "schülerhaft",
    "schüre": "schüren",
    "schürend": "schüren",
    "schürende": "schürend",
    "schürendem": "schürend",
    "schürenden": "schürend",
    "schürender": "schürend",
    "schürendes": "schürend",
    "schürest": "schüren",
    "schüret": "schüren",
    "schürfe": "schürfen",
    "schürfend": "schürfen",
    "schürfende": "schürfend",
    "schürfendem": "schürfend",
    "schürfenden": "schürfend",
    "schürfender": "schürfend",
    "schürfendes": "schürfend",
    "schürfest": "schürfen",
    "schürfet": "schürfen",
    "schürfst": "schürfen",
    "schürft": "schürfen",
    "schürfte": "schürfen",
    "schürften": "schürfen",
    "schürftest": "schürfen",
    "schürftet": "schürfen",
    "schürst": "schüren",
    "schürt": "schüren",
    "schürte": "schüren",
    "schürten": "schüren",
    "schürtest": "schüren",
    "schürtet": "schüren",
    "schüttele": "schütteln",
    "schüttelnd": "schütteln",
    "schüttelnde": "schüttelnd",
    "schüttelndem": "schüttelnd",
    "schüttelnden": "schüttelnd",
    "schüttelnder": "schüttelnd",
    "schüttelndere": "schüttelnd",
    "schüttelnderem": "schüttelnd",
    "schüttelnderen": "schüttelnd",
    "schüttelnderer": "schüttelnd",
    "schüttelnderes": "schüttelnd",
    "schüttelndes": "schüttelnd",
    "schüttelndste": "schüttelnd",
    "schüttelndstem": "schüttelnd",
    "schüttelndsten": "schüttelnd",
    "schüttelndster": "schüttelnd",
    "schüttelndstes": "schüttelnd",
    "schüttelst": "schütteln",
    "schüttelt": "schütteln",
    "schüttelte": "schütteln",
    "schüttelten": "schütteln",
    "schütteltest": "schütteln",
    "schütteltet": "schütteln",
    "schüttend": "schütten",
    "schüttende": "schüttend",
    "schüttendem": "schüttend",
    "schüttenden": "schüttend",
    "schüttender": "schüttend",
    "schüttendes": "schüttend",
    "schütter": "schüttern",
    "schüttere": "schütter",
    "schütterem": "schütter",
    "schütteren": "schütter",
    "schütterer": "schütter",
    "schütterere": "schütter",
    "schüttererem": "schütter",
    "schüttereren": "schütter",
    "schüttererer": "schütter",
    "schüttereres": "schütter",
    "schütteres": "schütter",
    "schütternd": "schüttern",
    "schütternde": "schütternd",
    "schütterndem": "schütternd",
    "schütternden": "schütternd",
    "schütternder": "schütternd",
    "schütterndes": "schütternd",
    "schütterst": "schüttern",
    "schütterste": "schütter",
    "schütterstem": "schütter",
    "schüttersten": "schütter",
    "schütterster": "schütter",
    "schütterstes": "schütter",
    "schüttert": "schüttern",
    "schütterte": "schüttern",
    "schütterten": "schüttern",
    "schüttertest": "schüttern",
    "schüttertet": "schüttern",
    "schüttest": "schütten",
    "schüttet": "schütten",
    "schüttete": "schütten",
    "schütteten": "schütten",
    "schüttetest": "schütten",
    "schüttetet": "schütten",
    "schüttle": "schütteln",
    "schützend": "schützen",
    "schützende": "schützend",
    "schützendem": "schützend",
    "schützenden": "schützend",
    "schützender": "schützend",
    "schützendere": "schützend",
    "schützenderem": "schützend",
    "schützenderen": "schützend",
    "schützenderer": "schützend",
    "schützenderes": "schützend",
    "schützendes": "schützend",
    "schützendste": "schützend",
    "schützendstem": "schützend",
    "schützendsten": "schützend",
    "schützendster": "schützend",
    "schützendstes": "schützend",
    "schützest": "schützen",
    "schützet": "schützen",
    "schützt": "schützen",
    "schützte": "schützen",
    "schützten": "schützen",
    "schütztest": "schützen",
    "schütztet": "schützen",
    "sechsmonatigem": "sechsmonatig",
    "sechsmonatigen": "sechsmonatig",
    "sechsmonatiger": "sechsmonatig",
    "sechsmonatiges": "sechsmonatig",
    "seefahrende": "seefahrend",
    "seefahrendem": "seefahrend",
    "seefahrenden": "seefahrend",
    "seefahrender": "seefahrend",
    "seefahrendes": "seefahrend",
    "seefähigem": "seefähig",
    "seefähigen": "seefähig",
    "seefähiger": "seefähig",
    "seefähigere": "seefähig",
    "seefähigerem": "seefähig",
    "seefähigeren": "seefähig",
    "seefähigerer": "seefähig",
    "seefähigeres": "seefähig",
    "seefähiges": "seefähig",
    "seefähigste": "seefähig",
    "seefähigstem": "seefähig",
    "seefähigsten": "seefähig",
    "seefähigster": "seefähig",
    "seefähigstes": "seefähig",
    "seekrankem": "seekrank",
    "seekranken": "seekrank",
    "seekranker": "seekrank",
    "seekrankes": "seekrank",
    "seelenlosem": "seelenlos",
    "seelenlosen": "seelenlos",
    "seelenloser": "seelenlos",
    "seelenlosere": "seelenlos",
    "seelenloserem": "seelenlos",
    "seelenloseren": "seelenlos",
    "seelenloserer": "seelenlos",
    "seelenloseres": "seelenlos",
    "seelenloses": "seelenlos",
    "seelenloseste": "seelenlos",
    "seelenlosestem": "seelenlos",
    "seelenlosesten": "seelenlos",
    "seelenlosester": "seelenlos",
    "seelenlosestes": "seelenlos",
    "seelenverwandte": "seelenverwandt",
    "seelenverwandtem": "seelenverwandt",
    "seelenverwandten": "seelenverwandt",
    "seelenverwandter": "seelenverwandt",
    "seelenverwandtes": "seelenverwandt",
    "seelische": "seelisch",
    "seelischem": "seelisch",
    "seelischen": "seelisch",
    "seelischer": "seelisch",
    "seelisches": "seelisch",
    "seelsorgerischem": "seelsorgerisch",
    "seelsorgerischen": "seelsorgerisch",
    "seelsorgerischer": "seelsorgerisch",
    "seelsorgerisches": "seelsorgerisch",
    "seemännischem": "seemännisch",
    "seemännischen": "seemännisch",
    "seemännischer": "seemännisch",
    "seemännisches": "seemännisch",
    "seetüchtigem": "seetüchtig",
    "seetüchtigen": "seetüchtig",
    "seetüchtiger": "seetüchtig",
    "seetüchtiges": "seetüchtig",
    "seeuntüchtige": "seeuntüchtig",
    "seeuntüchtigem": "seeuntüchtig",
    "seeuntüchtigen": "seeuntüchtig",
    "seeuntüchtiger": "seeuntüchtig",
    "seeuntüchtiges": "seeuntüchtig",
    "segele": "segeln",
    "segelfertige": "segelfertig",
    "segelfertigem": "segelfertig",
    "segelfertigen": "segelfertig",
    "segelfertiger": "segelfertig",
    "segelfertiges": "segelfertig",
    "segelnd": "segeln",
    "segelnde": "segelnd",
    "segelndem": "segelnd",
    "segelnden": "segelnd",
    "segelnder": "segelnd",
    "segelndes": "segelnd",
    "segelst": "segeln",
    "segelt": "segeln",
    "segelte": "segeln",
    "segelten": "segeln",
    "segeltest": "segeln",
    "segeltet": "segeln",
    "segenbringendem": "segenbringend",
    "segenbringenden": "segenbringend",
    "segenbringender": "segenbringend",
    "segenbringendes": "segenbringend",
    "segensreichem": "segensreich",
    "segensreichen": "segensreich",
    "segensreicher": "segensreich",
    "segensreichere": "segensreich",
    "segensreicherem": "segensreich",
    "segensreicheren": "segensreich",
    "segensreicherer": "segensreich",
    "segensreicheres": "segensreich",
    "segensreiches": "segensreich",
    "segensreichste": "segensreich",
    "segensreichstem": "segensreich",
    "segensreichsten": "segensreich",
    "segensreichster": "segensreich",
    "segensreichstes": "segensreich",
    "segle": "segeln",
    "segmentiere": "segmentieren",
    "segmentierend": "segmentieren",
    "segmentierende": "segmentierend",
    "segmentierendem": "segmentierend",
    "segmentierenden": "segmentierend",
    "segmentierender": "segmentierend",
    "segmentierendes": "segmentierend",
    "segmentierest": "segmentieren",
    "segmentieret": "segmentieren",
    "segmentierst": "segmentieren",
    "segmentiert": "segmentieren",
    "segmentierte": "segmentieren",
    "segmentiertem": "segmentiert",
    "segmentierten": "segmentieren",
    "segmentierter": "segmentiert",
    "segmentiertes": "segmentiert",
    "segmentiertest": "segmentieren",
    "segmentiertet": "segmentieren",
    "segne": "segnen",
    "segnend": "segnen",
    "segnende": "segnend",
    "segnendem": "segnend",
    "segnenden": "segnend",
    "segnender": "segnend",
    "segnendes": "segnend",
    "segnest": "segnen",
    "segnet": "segnen",
    "segnete": "segnen",
    "segneten": "segnen",
    "segnetest": "segnen",
    "segnetet": "segnen",
    "sehe": "sehen",
    "sehend": "sehen",
    "sehende": "sehend",
    "sehendem": "sehend",
    "sehenden": "sehend",
    "sehender": "sehend",
    "sehendes": "sehend",
    "sehenswertem": "sehenswert",
    "sehenswerten": "sehenswert",
    "sehenswerter": "sehenswert",
    "sehenswertere": "sehenswert",
    "sehenswerterem": "sehenswert",
    "sehenswerteren": "sehenswert",
    "sehenswerterer": "sehenswert",
    "sehenswerteres": "sehenswert",
    "sehenswertes": "sehenswert",
    "sehenswerteste": "sehenswert",
    "sehenswertestem": "sehenswert",
    "sehenswertesten": "sehenswert",
    "sehenswertester": "sehenswert",
    "sehenswertestes": "sehenswert",
    "sehenswürdige": "sehenswürdig",
    "sehenswürdigem": "sehenswürdig",
    "sehenswürdigen": "sehenswürdig",
    "sehenswürdiger": "sehenswürdig",
    "sehenswürdigere": "sehenswürdig",
    "sehenswürdigerem": "sehenswürdig",
    "sehenswürdigeren": "sehenswürdig",
    "sehenswürdigerer": "sehenswürdig",
    "sehenswürdigeres": "sehenswürdig",
    "sehenswürdiges": "sehenswürdig",
    "sehenswürdigste": "sehenswürdig",
    "sehenswürdigstem": "sehenswürdig",
    "sehenswürdigsten": "sehenswürdig",
    "sehenswürdigster": "sehenswürdig",
    "sehenswürdigstes": "sehenswürdig",
    "sehest": "sehen",
    "sehet": "sehen",
    "sehnend": "sehnen",
    "sehnende": "sehnend",
    "sehnendem": "sehnend",
    "sehnenden": "sehnend",
    "sehnender": "sehnend",
    "sehnendere": "sehnend",
    "sehnenderem": "sehnend",
    "sehnenderen": "sehnend",
    "sehnenderer": "sehnend",
    "sehnenderes": "sehnend",
    "sehnendes": "sehnend",
    "sehnendste": "sehnend",
    "sehnendstem": "sehnend",
    "sehnendsten": "sehnend",
    "sehnendster": "sehnend",
    "sehnendstes": "sehnend",
    "sehnest": "sehnen",
    "sehnet": "sehnen",
    "sehnige": "sehnig",
    "sehnigem": "sehnig",
    "sehnigen": "sehnig",
    "sehniger": "sehnig",
    "sehnigere": "sehnig",
    "sehnigerem": "sehnig",
    "sehnigeren": "sehnig",
    "sehnigerer": "sehnig",
    "sehnigeres": "sehnig",
    "sehniges": "sehnig",
    "sehnigste": "sehnig",
    "sehnigstem": "sehnig",
    "sehnigsten": "sehnig",
    "sehnigster": "sehnig",
    "sehnigstes": "sehnig",
    "sehnliche": "sehnlich",
    "sehnlichem": "sehnlich",
    "sehnlichen": "sehnlich",
    "sehnlicher": "sehnlich",
    "sehnlichere": "sehnlich",
    "sehnlicherem": "sehnlich",
    "sehnlicheren": "sehnlich",
    "sehnlicherer": "sehnlich",
    "sehnlicheres": "sehnlich",
    "sehnliches": "sehnlich",
    "sehnlichste": "sehnlich",
    "sehnlichstem": "sehnlich",
    "sehnlichsten": "sehnlich",
    "sehnlichster": "sehnlich",
    "sehnlichstes": "sehnlich",
    "sehnst": "sehnen",
    "sehnsuchtsvolle": "sehnsuchtsvoll",
    "sehnsuchtsvollem": "sehnsuchtsvoll",
    "sehnsuchtsvollen": "sehnsuchtsvoll",
    "sehnsuchtsvoller": "sehnsuchtsvoll",
    "sehnsuchtsvollere": "sehnsuchtsvoll",
    "sehnsuchtsvollerem": "sehnsuchtsvoll",
    "sehnsuchtsvolleren": "sehnsuchtsvoll",
    "sehnsuchtsvollerer": "sehnsuchtsvoll",
    "sehnsuchtsvolleres": "sehnsuchtsvoll",
    "sehnsuchtsvolles": "sehnsuchtsvoll",
    "sehnsuchtsvollste": "sehnsuchtsvoll",
    "sehnsuchtsvollstem": "sehnsuchtsvoll",
    "sehnsuchtsvollsten": "sehnsuchtsvoll",
    "sehnsuchtsvollster": "sehnsuchtsvoll",
    "sehnsuchtsvollstes": "sehnsuchtsvoll",
    "sehnsüchtigem": "sehnsüchtig",
    "sehnsüchtigen": "sehnsüchtig",
    "sehnsüchtiger": "sehnsüchtig",
    "sehnsüchtigere": "sehnsüchtig",
    "sehnsüchtigerem": "sehnsüchtig",
    "sehnsüchtigeren": "sehnsüchtig",
    "sehnsüchtigerer": "sehnsüchtig",
    "sehnsüchtigeres": "sehnsüchtig",
    "sehnsüchtiges": "sehnsüchtig",
    "sehnsüchtigste": "sehnsüchtig",
    "sehnsüchtigstem": "sehnsüchtig",
    "sehnsüchtigsten": "sehnsüchtig",
    "sehnsüchtigster": "sehnsüchtig",
    "sehnsüchtigstes": "sehnsüchtig",
    "sehnt": "sehnen",
    "sehnte": "sehnen",
    "sehnten": "sehnen",
    "sehntest": "sehnen",
    "sehntet": "sehnen",
    "seht": "sehen",
    "sei": "sein",
    "seichte": "seicht",
    "seichtem": "seicht",
    "seichten": "seicht",
    "seichter": "seicht",
    "seichtere": "seicht",
    "seichterem": "seicht",
    "seichteren": "seicht",
    "seichterer": "seicht",
    "seichteres": "seicht",
    "seichtes": "seicht",
    "seichteste": "seicht",
    "seichtestem": "seicht",
    "seichtesten": "seicht",
    "seichtester": "seicht",
    "seichtestes": "seicht",
    "seid": "sein",
    "seidenem": "seiden",
    "seidenen": "seiden",
    "seidener": "seiden",
    "seidenes": "seiden",
    "seidenmatte": "seidenmatt",
    "seidenmattem": "seidenmatt",
    "seidenmatten": "seidenmatt",
    "seidenmatter": "seidenmatt",
    "seidenmattes": "seidenmatt",
    "seien": "sein",
    "seiend": "sein",
    "seiest": "sein",
    "seiet": "sein",
    "seife": "seifen",
    "seifend": "seifen",
    "seifende": "seifend",
    "seifendem": "seifend",
    "seifenden": "seifend",
    "seifender": "seifend",
    "seifendes": "seifend",
    "seifest": "seifen",
    "seifet": "seifen",
    "seifige": "seifig",
    "seifigem": "seifig",
    "seifigen": "seifig",
    "seifiger": "seifig",
    "seifigere": "seifig",
    "seifigerem": "seifig",
    "seifigeren": "seifig",
    "seifigerer": "seifig",
    "seifigeres": "seifig",
    "seifiges": "seifig",
    "seifigste": "seifig",
    "seifigstem": "seifig",
    "seifigsten": "seifig",
    "seifigster": "seifig",
    "seifigstes": "seifig",
    "seifst": "seifen",
    "seift": "seifen",
    "seifte": "seifen",
    "seiften": "seifen",
    "seiftest": "seifen",
    "seiftet": "seifen",
    "seilend": "seilen",
    "seilende": "seilend",
    "seilendem": "seilend",
    "seilenden": "seilend",
    "seilender": "seilend",
    "seilendes": "seilend",
    "seilest": "seilen",
    "seilet": "seilen",
    "seilst": "seilen",
    "seilt": "seilen",
    "seilte": "seilen",
    "seilten": "seilen",
    "seiltest": "seilen",
    "seiltet": "seilen",
    "sein": "mein",
    "seine": "mein",
    "seinem": "mein",
    "seiner": "sich",
    "seines": "mein",
    "seinesgleichen": "meinesgleichen",
    "seismischem": "seismisch",
    "seismischen": "seismisch",
    "seismischer": "seismisch",
    "seismisches": "seismisch",
    "seismologischem": "seismologisch",
    "seismologischen": "seismologisch",
    "seismologischer": "seismologisch",
    "seismologisches": "seismologisch",
    "seist": "sein",
    "seitenlangem": "seitenlang",
    "seitenlangen": "seitenlang",
    "seitenlanger": "seitenlang",
    "seitenlanges": "seitenlang",
    "seitenverkehrtem": "seitenverkehrt",
    "seitenverkehrten": "seitenverkehrt",
    "seitenverkehrter": "seitenverkehrt",
    "seitenverkehrtes": "seitenverkehrt",
    "seitliche": "seitlich",
    "seitlichem": "seitlich",
    "seitlichen": "seitlich",
    "seitlicher": "seitlich",
    "seitliches": "seitlich",
    "sekretiere": "sekretieren",
    "sekretierend": "sekretieren",
    "sekretierende": "sekretierend",
    "sekretierendem": "sekretierend",
    "sekretierenden": "sekretierend",
    "sekretierender": "sekretierend",
    "sekretierendes": "sekretierend",
    "sekretierest": "sekretieren",
    "sekretieret": "sekretieren",
    "sekretierst": "sekretieren",
    "sekretiert": "sekretieren",
    "sekretierte": "sekretieren",
    "sekretiertem": "sekretiert",
    "sekretierten": "sekretieren",
    "sekretierter": "sekretiert",
    "sekretiertes": "sekretiert",
    "sekretiertest": "sekretieren",
    "sekretiertet": "sekretieren",
    "sekundenlangem": "sekundenlang",
    "sekundenlangen": "sekundenlang",
    "sekundenlanger": "sekundenlang",
    "sekundenlanges": "sekundenlang",
    "sekundärem": "sekundär",
    "sekundären": "sekundär",
    "sekundärer": "sekundär",
    "sekundäres": "sekundär",
    "selbstbewußtem": "selbstbewußt",
    "selbstbewußten": "selbstbewußt",
    "selbstbewußter": "selbstbewußt",
    "selbstbewußtere": "selbstbewußt",
    "selbstbewußterem": "selbstbewußt",
    "selbstbewußteren": "selbstbewußt",
    "selbstbewußterer": "selbstbewußt",
    "selbstbewußteres": "selbstbewußt",
    "selbstbewußtes": "selbstbewußt",
    "selbstbewußteste": "selbstbewußt",
    "selbstbewußtestem": "selbstbewußt",
    "selbstbewußtesten": "selbstbewußt",
    "selbstbewußtester": "selbstbewußt",
    "selbstbewußtestes": "selbstbewußt",
    "selbstgefälligem": "selbstgefällig",
    "selbstgefälligen": "selbstgefällig",
    "selbstgefälliger": "selbstgefällig",
    "selbstgefälligere": "selbstgefällig",
    "selbstgefälligerem": "selbstgefällig",
    "selbstgefälligeren": "selbstgefällig",
    "selbstgefälligerer": "selbstgefällig",
    "selbstgefälligeres": "selbstgefällig",
    "selbstgefälliges": "selbstgefällig",
    "selbstgefälligstem": "selbstgefällig",
    "selbstgefälligsten": "selbstgefällig",
    "selbstgefälligster": "selbstgefällig",
    "selbstgefälligstes": "selbstgefällig",
    "selbstgemachte": "selbstgemacht",
    "selbstgemachtem": "selbstgemacht",
    "selbstgemachten": "selbstgemacht",
    "selbstgemachter": "selbstgemacht",
    "selbstgemachtes": "selbstgemacht",
    "selbstgerechte": "selbstgerecht",
    "selbstgerechtem": "selbstgerecht",
    "selbstgerechten": "selbstgerecht",
    "selbstgerechter": "selbstgerecht",
    "selbstgerechtere": "selbstgerecht",
    "selbstgerechterem": "selbstgerecht",
    "selbstgerechteren": "selbstgerecht",
    "selbstgerechterer": "selbstgerecht",
    "selbstgerechteres": "selbstgerecht",
    "selbstgerechtes": "selbstgerecht",
    "selbstgerechteste": "selbstgerecht",
    "selbstgerechtestem": "selbstgerecht",
    "selbstgerechtesten": "selbstgerecht",
    "selbstgerechtester": "selbstgerecht",
    "selbstgerechtestes": "selbstgerecht",
    "selbstgeschriebene": "selbstgeschrieben",
    "selbstgeschriebenem": "selbstgeschrieben",
    "selbstgeschriebenen": "selbstgeschrieben",
    "selbstgeschriebener": "selbstgeschrieben",
    "selbstgeschriebenes": "selbstgeschrieben",
    "selbstherrlichem": "selbstherrlich",
    "selbstherrlichen": "selbstherrlich",
    "selbstherrlicher": "selbstherrlich",
    "selbstherrlichere": "selbstherrlich",
    "selbstherrlicherem": "selbstherrlich",
    "selbstherrlicheren": "selbstherrlich",
    "selbstherrlicherer": "selbstherrlich",
    "selbstherrlicheres": "selbstherrlich",
    "selbstherrliches": "selbstherrlich",
    "selbstherrlichste": "selbstherrlich",
    "selbstherrlichstem": "selbstherrlich",
    "selbstherrlichsten": "selbstherrlich",
    "selbstherrlichster": "selbstherrlich",
    "selbstherrlichstes": "selbstherrlich",
    "selbstklebendem": "selbstklebend",
    "selbstklebenden": "selbstklebend",
    "selbstklebender": "selbstklebend",
    "selbstklebendes": "selbstklebend",
    "selbstkritischem": "selbstkritisch",
    "selbstkritischen": "selbstkritisch",
    "selbstkritischer": "selbstkritisch",
    "selbstkritischere": "selbstkritisch",
    "selbstkritischerem": "selbstkritisch",
    "selbstkritischeren": "selbstkritisch",
    "selbstkritischerer": "selbstkritisch",
    "selbstkritischeres": "selbstkritisch",
    "selbstkritisches": "selbstkritisch",
    "selbstkritischste": "selbstkritisch",
    "selbstkritischstem": "selbstkritisch",
    "selbstkritischsten": "selbstkritisch",
    "selbstkritischster": "selbstkritisch",
    "selbstkritischstes": "selbstkritisch",
    "selbstlosem": "selbstlos",
    "selbstlosen": "selbstlos",
    "selbstloser": "selbstlos",
    "selbstlosere": "selbstlos",
    "selbstloserem": "selbstlos",
    "selbstloseren": "selbstlos",
    "selbstloserer": "selbstlos",
    "selbstloseres": "selbstlos",
    "selbstloses": "selbstlos",
    "selbstloseste": "selbstlos",
    "selbstlosestem": "selbstlos",
    "selbstlosesten": "selbstlos",
    "selbstlosester": "selbstlos",
    "selbstlosestes": "selbstlos",
    "selbstsicherem": "selbstsicher",
    "selbstsicheren": "selbstsicher",
    "selbstsicherer": "selbstsicher",
    "selbstsicherere": "selbstsicher",
    "selbstsichererem": "selbstsicher",
    "selbstsichereren": "selbstsicher",
    "selbstsichererer": "selbstsicher",
    "selbstsichereres": "selbstsicher",
    "selbstsicheres": "selbstsicher",
    "selbstsicherste": "selbstsicher",
    "selbstsicherstem": "selbstsicher",
    "selbstsichersten": "selbstsicher",
    "selbstsicherster": "selbstsicher",
    "selbstsicherstes": "selbstsicher",
    "selbsttätigem": "selbsttätig",
    "selbsttätigen": "selbsttätig",
    "selbsttätiger": "selbsttätig",
    "selbsttätiges": "selbsttätig",
    "selbstverständlichem": "selbstverständlich",
    "selbstverständlichen": "selbstverständlich",
    "selbstverständlicher": "selbstverständlich",
    "selbstverständlichere": "selbstverständlich",
    "selbstverständlicherem": "selbstverständlich",
    "selbstverständlicheren": "selbstverständlich",
    "selbstverständlicherer": "selbstverständlich",
    "selbstverständlicheres": "selbstverständlich",
    "selbstverständliches": "selbstverständlich",
    "selbstverständlichste": "selbstverständlich",
    "selbstverständlichstem": "selbstverständlich",
    "selbstverständlichsten": "selbstverständlich",
    "selbstverständlichster": "selbstverständlich",
    "selbstverständlichstes": "selbstverständlich",
    "selbstzufriedenem": "selbstzufrieden",
    "selbstzufriedenen": "selbstzufrieden",
    "selbstzufriedener": "selbstzufrieden",
    "selbstzufriedenere": "selbstzufrieden",
    "selbstzufriedenerem": "selbstzufrieden",
    "selbstzufriedeneren": "selbstzufrieden",
    "selbstzufriedenerer": "selbstzufrieden",
    "selbstzufriedeneres": "selbstzufrieden",
    "selbstzufriedenes": "selbstzufrieden",
    "selbstzufriedenste": "selbstzufrieden",
    "selbstzufriedenstem": "selbstzufrieden",
    "selbstzufriedensten": "selbstzufrieden",
    "selbstzufriedenster": "selbstzufrieden",
    "selbstzufriedenstes": "selbstzufrieden",
    "selbständigem": "selbständig",
    "selbständigen": "selbständig",
    "selbständiger": "selbständig",
    "selbständigere": "selbständig",
    "selbständigerem": "selbständig",
    "selbständigeren": "selbständig",
    "selbständigerer": "selbständig",
    "selbständigeres": "selbständig",
    "selbständiges": "selbständig",
    "selbständigste": "selbständig",
    "selbständigstem": "selbständig",
    "selbständigsten": "selbständig",
    "selbständigster": "selbständig",
    "selbständigstes": "selbständig",
    "selektiere": "selektieren",
    "selektierend": "selektieren",
    "selektierende": "selektierend",
    "selektierendem": "selektierend",
    "selektierenden": "selektierend",
    "selektierender": "selektierend",
    "selektierendes": "selektierend",
    "selektierest": "selektieren",
    "selektieret": "selektieren",
    "selektierst": "selektieren",
    "selektiert": "selektieren",
    "selektierte": "selektieren",
    "selektiertem": "selektiert",
    "selektierten": "selektieren",
    "selektierter": "selektiert",
    "selektiertes": "selektiert",
    "selektiertest": "selektieren",
    "selektiertet": "selektieren",
    "selektivem": "selektiv",
    "selektiven": "selektiv",
    "selektiver": "selektiv",
    "selektivere": "selektiv",
    "selektiverem": "selektiv",
    "selektiveren": "selektiv",
    "selektiverer": "selektiv",
    "selektiveres": "selektiv",
    "selektives": "selektiv",
    "selektivste": "selektiv",
    "selektivstem": "selektiv",
    "selektivsten": "selektiv",
    "selektivster": "selektiv",
    "selektivstes": "selektiv",
    "seliggepriesen": "seligpreisen",
    "seliggepriesene": "seliggepriesen",
    "seliggepriesenem": "seliggepriesen",
    "seliggepriesenen": "seliggepriesen",
    "seliggepriesener": "seliggepriesen",
    "seliggepriesenes": "seliggepriesen",
    "seliggesprochen": "seligsprechen",
    "seliggesprochene": "seliggesprochen",
    "seliggesprochenem": "seliggesprochen",
    "seliggesprochenen": "seliggesprochen",
    "seliggesprochener": "seliggesprochen",
    "seliggesprochenes": "seliggesprochen",
    "seligpreise": "seligpreisen",
    "seligpreisend": "seligpreisen",
    "seligpreisende": "seligpreisend",
    "seligpreisendem": "seligpreisend",
    "seligpreisenden": "seligpreisend",
    "seligpreisender": "seligpreisend",
    "seligpreisendes": "seligpreisend",
    "seligpreisest": "seligpreisen",
    "seligpreiset": "seligpreisen",
    "seligpreist": "seligpreisen",
    "seligpries": "seligpreisen",
    "seligpriese": "seligpreisen",
    "seligpriesen": "seligpreisen",
    "seligpriesest": "seligpreisen",
    "seligprieset": "seligpreisen",
    "seligpriest": "seligpreisen",
    "seligsprach": "seligsprechen",
    "seligsprachen": "seligsprechen",
    "seligsprachst": "seligsprechen",
    "seligspracht": "seligsprechen",
    "seligspreche": "seligsprechen",
    "seligsprechend": "seligsprechen",
    "seligsprechende": "seligsprechend",
    "seligsprechendem": "seligsprechend",
    "seligsprechenden": "seligsprechend",
    "seligsprechender": "seligsprechend",
    "seligsprechendes": "seligsprechend",
    "seligsprechest": "seligsprechen",
    "seligsprechet": "seligsprechen",
    "seligsprecht": "seligsprechen",
    "seligsprichst": "seligsprechen",
    "seligspricht": "seligsprechen",
    "seligspräche": "seligsprechen",
    "seligsprächen": "seligsprechen",
    "seligsprächest": "seligsprechen",
    "seligsprächet": "seligsprechen",
    "seligzupreisen": "seligpreisen",
    "seligzusprechen": "seligsprechen",
    "seltenem": "selten",
    "seltenen": "selten",
    "seltener": "selten",
    "seltenere": "selten",
    "seltenerem": "selten",
    "selteneren": "selten",
    "seltenerer": "selten",
    "selteneres": "selten",
    "seltenes": "selten",
    "seltenstem": "selten",
    "seltensten": "selten",
    "seltenster": "selten",
    "seltenstes": "selten",
    "seltsame": "seltsam",
    "seltsamem": "seltsam",
    "seltsamen": "seltsam",
    "seltsamer": "seltsam",
    "seltsamere": "seltsam",
    "seltsamerem": "seltsam",
    "seltsameren": "seltsam",
    "seltsamerer": "seltsam",
    "seltsameres": "seltsam",
    "seltsames": "seltsam",
    "seltsamste": "seltsam",
    "seltsamstem": "seltsam",
    "seltsamsten": "seltsam",
    "seltsamster": "seltsam",
    "seltsamstes": "seltsam",
    "semantische": "semantisch",
    "semantischem": "semantisch",
    "semantischen": "semantisch",
    "semantischer": "semantisch",
    "semantisches": "semantisch",
    "semaphorische": "semaphorisch",
    "semaphorischem": "semaphorisch",
    "semaphorischen": "semaphorisch",
    "semaphorischer": "semaphorisch",
    "semaphorisches": "semaphorisch",
    "semitischem": "semitisch",
    "semitischen": "semitisch",
    "semitischer": "semitisch",
    "semitisches": "semitisch",
    "senatorischem": "senatorisch",
    "senatorischen": "senatorisch",
    "senatorischer": "senatorisch",
    "senatorisches": "senatorisch",
    "sende": "senden",
    "sendend": "senden",
    "sendende": "sendend",
    "sendendem": "sendend",
    "sendenden": "sendend",
    "sendender": "sendend",
    "sendendes": "sendend",
    "sendest": "senden",
    "sendet": "senden",
    "sendete": "senden",
    "sendeten": "senden",
    "sendetest": "senden",
    "sendetet": "senden",
    "senegalesischem": "senegalesisch",
    "senegalesischen": "senegalesisch",
    "senegalesischer": "senegalesisch",
    "senegalesisches": "senegalesisch",
    "senge": "sengen",
    "sengend": "sengen",
    "sengende": "sengend",
    "sengendem": "sengend",
    "sengenden": "sengend",
    "sengender": "sengend",
    "sengendere": "sengend",
    "sengenderem": "sengend",
    "sengenderen": "sengend",
    "sengenderer": "sengend",
    "sengenderes": "sengend",
    "sengendes": "sengend",
    "sengendste": "sengend",
    "sengendstem": "sengend",
    "sengendsten": "sengend",
    "sengendster": "sengend",
    "sengendstes": "sengend",
    "sengest": "sengen",
    "senget": "sengen",
    "sengst": "sengen",
    "sengt": "sengen",
    "sengte": "sengen",
    "sengten": "sengen",
    "sengtest": "sengen",
    "sengtet": "sengen",
    "senile": "senil",
    "senilem": "senil",
    "senilen": "senil",
    "seniler": "senil",
    "senilere": "senil",
    "senilerem": "senil",
    "senileren": "senil",
    "senilerer": "senil",
    "senileres": "senil",
    "seniles": "senil",
    "senilste": "senil",
    "senilstem": "senil",
    "senilsten": "senil",
    "senilster": "senil",
    "senilstes": "senil",
    "senke": "senken",
    "senkend": "senken",
    "senkende": "senkend",
    "senkendem": "senkend",
    "senkenden": "senkend",
    "senkender": "senkend",
    "senkendes": "senkend",
    "senkest": "senken",
    "senket": "senken",
    "senkrechtem": "senkrecht",
    "senkrechten": "senkrecht",
    "senkrechter": "senkrecht",
    "senkrechtes": "senkrecht",
    "senkst": "senken",
    "senkt": "senken",
    "senkte": "senken",
    "senkten": "senken",
    "senktest": "senken",
    "senktet": "senken",
    "sensationellem": "sensationell",
    "sensationellen": "sensationell",
    "sensationeller": "sensationell",
    "sensationellere": "sensationell",
    "sensationellerem": "sensationell",
    "sensationelleren": "sensationell",
    "sensationellerer": "sensationell",
    "sensationelleres": "sensationell",
    "sensationelles": "sensationell",
    "sensationellste": "sensationell",
    "sensationellstem": "sensationell",
    "sensationellsten": "sensationell",
    "sensationellster": "sensationell",
    "sensationellstes": "sensationell",
    "sensationshungrigem": "sensationshungrig",
    "sensationshungrigen": "sensationshungrig",
    "sensationshungriger": "sensationshungrig",
    "sensationshungrigere": "sensationshungrig",
    "sensationshungrigerem": "sensationshungrig",
    "sensationshungrigeren": "sensationshungrig",
    "sensationshungrigerer": "sensationshungrig",
    "sensationshungrigeres": "sensationshungrig",
    "sensationshungriges": "sensationshungrig",
    "sensationshungrigste": "sensationshungrig",
    "sensationshungrigstem": "sensationshungrig",
    "sensationshungrigsten": "sensationshungrig",
    "sensationshungrigster": "sensationshungrig",
    "sensationshungrigstes": "sensationshungrig",
    "sensationslüsterne": "sensationslüstern",
    "sensationslüsternem": "sensationslüstern",
    "sensationslüsternen": "sensationslüstern",
    "sensationslüsterner": "sensationslüstern",
    "sensationslüsternere": "sensationslüstern",
    "sensationslüsternerem": "sensationslüstern",
    "sensationslüsterneren": "sensationslüstern",
    "sensationslüsternerer": "sensationslüstern",
    "sensationslüsterneres": "sensationslüstern",
    "sensationslüsternes": "sensationslüstern",
    "sensationslüsternste": "sensationslüstern",
    "sensationslüsternstem": "sensationslüstern",
    "sensationslüsternsten": "sensationslüstern",
    "sensationslüsternster": "sensationslüstern",
    "sensationslüsternstes": "sensationslüstern",
    "sensibelstem": "sensibel",
    "sensibelsten": "sensibel",
    "sensibelster": "sensibel",
    "sensibelstes": "sensibel",
    "sensibilisiere": "sensibilisieren",
    "sensibilisierend": "sensibilisieren",
    "sensibilisierende": "sensibilisierend",
    "sensibilisierendem": "sensibilisierend",
    "sensibilisierenden": "sensibilisierend",
    "sensibilisierender": "sensibilisierend",
    "sensibilisierendere": "sensibilisierend",
    "sensibilisierenderem": "sensibilisierend",
    "sensibilisierenderen": "sensibilisierend",
    "sensibilisierenderer": "sensibilisierend",
    "sensibilisierenderes": "sensibilisierend",
    "sensibilisierendes": "sensibilisierend",
    "sensibilisierendste": "sensibilisierend",
    "sensibilisierendstem": "sensibilisierend",
    "sensibilisierendsten": "sensibilisierend",
    "sensibilisierendster": "sensibilisierend",
    "sensibilisierendstes": "sensibilisierend",
    "sensibilisierest": "sensibilisieren",
    "sensibilisieret": "sensibilisieren",
    "sensibilisierst": "sensibilisieren",
    "sensibilisiert": "sensibilisieren",
    "sensibilisierte": "sensibilisieren",
    "sensibilisiertem": "sensibilisiert",
    "sensibilisierten": "sensibilisieren",
    "sensibilisierter": "sensibilisiert",
    "sensibilisiertere": "sensibilisiert",
    "sensibilisierterem": "sensibilisiert",
    "sensibilisierteren": "sensibilisiert",
    "sensibilisierterer": "sensibilisiert",
    "sensibilisierteres": "sensibilisiert",
    "sensibilisiertes": "sensibilisiert",
    "sensibilisiertest": "sensibilisieren",
    "sensibilisierteste": "sensibilisiert",
    "sensibilisiertestem": "sensibilisiert",
    "sensibilisiertesten": "sensibilisiert",
    "sensibilisiertester": "sensibilisiert",
    "sensibilisiertestes": "sensibilisiert",
    "sensibilisiertet": "sensibilisieren",
    "sensible": "sensibel",
    "sensiblem": "sensibel",
    "sensiblen": "sensibel",
    "sensibler": "sensibel",
    "sensiblere": "sensibel",
    "sensiblerem": "sensibel",
    "sensibleren": "sensibel",
    "sensiblerer": "sensibel",
    "sensibleres": "sensibel",
    "sensibles": "sensibel",
    "sensitive": "sensitiv",
    "sensitivem": "sensitiv",
    "sensitiven": "sensitiv",
    "sensitiver": "sensitiv",
    "sensitives": "sensitiv",
    "sentimentalem": "sentimental",
    "sentimentalen": "sentimental",
    "sentimentaler": "sentimental",
    "sentimentalere": "sentimental",
    "sentimentalerem": "sentimental",
    "sentimentaleren": "sentimental",
    "sentimentalerer": "sentimental",
    "sentimentaleres": "sentimental",
    "sentimentales": "sentimental",
    "sentimentalische": "sentimentalisch",
    "sentimentalischem": "sentimentalisch",
    "sentimentalischen": "sentimentalisch",
    "sentimentalischer": "sentimentalisch",
    "sentimentalischere": "sentimentalisch",
    "sentimentalischerem": "sentimentalisch",
    "sentimentalischeren": "sentimentalisch",
    "sentimentalischerer": "sentimentalisch",
    "sentimentalischeres": "sentimentalisch",
    "sentimentalisches": "sentimentalisch",
    "sentimentalischste": "sentimentalisch",
    "sentimentalischstem": "sentimentalisch",
    "sentimentalischsten": "sentimentalisch",
    "sentimentalischster": "sentimentalisch",
    "sentimentalischstes": "sentimentalisch",
    "sentimentalstem": "sentimental",
    "sentimentalsten": "sentimental",
    "sentimentalster": "sentimental",
    "sentimentalstes": "sentimental",
    "separatem": "separat",
    "separaten": "separat",
    "separater": "separat",
    "separatere": "separat",
    "separaterem": "separat",
    "separateren": "separat",
    "separaterer": "separat",
    "separateres": "separat",
    "separates": "separat",
    "separateste": "separat",
    "separatestem": "separat",
    "separatesten": "separat",
    "separatester": "separat",
    "separatestes": "separat",
    "separatistischem": "separatistisch",
    "separatistischen": "separatistisch",
    "separatistischer": "separatistisch",
    "separatistisches": "separatistisch",
    "separiere": "separieren",
    "separierend": "separieren",
    "separierende": "separierend",
    "separierendem": "separierend",
    "separierenden": "separierend",
    "separierender": "separierend",
    "separierendes": "separierend",
    "separierest": "separieren",
    "separieret": "separieren",
    "separierst": "separieren",
    "separiert": "separieren",
    "separierte": "separieren",
    "separiertem": "separiert",
    "separierten": "separieren",
    "separierter": "separiert",
    "separiertes": "separiert",
    "separiertest": "separieren",
    "separiertet": "separieren",
    "septischem": "septisch",
    "septischen": "septisch",
    "septischer": "septisch",
    "septisches": "septisch",
    "sequentiellem": "sequentiell",
    "sequentiellen": "sequentiell",
    "sequentieller": "sequentiell",
    "sequentielles": "sequentiell",
    "serbischem": "serbisch",
    "serbischen": "serbisch",
    "serbischer": "serbisch",
    "serbisches": "serbisch",
    "seriellem": "seriell",
    "seriellen": "seriell",
    "serieller": "seriell",
    "serielles": "seriell",
    "serienmäßigem": "serienmäßig",
    "serienmäßigen": "serienmäßig",
    "serienmäßiger": "serienmäßig",
    "serienmäßiges": "serienmäßig",
    "seriösem": "seriös",
    "seriösen": "seriös",
    "seriöser": "seriös",
    "seriösere": "seriös",
    "seriöserem": "seriös",
    "seriöseren": "seriös",
    "seriöserer": "seriös",
    "seriöseres": "seriös",
    "seriöses": "seriös",
    "seriöseste": "seriös",
    "seriösestem": "seriös",
    "seriösesten": "seriös",
    "seriösester": "seriös",
    "seriösestes": "seriös",
    "serviere": "servieren",
    "servierend": "servieren",
    "servierende": "servierend",
    "servierendem": "servierend",
    "servierenden": "servierend",
    "servierender": "servierend",
    "servierendes": "servierend",
    "servierest": "servieren",
    "servieret": "servieren",
    "servierst": "servieren",
    "serviert": "servieren",
    "servierte": "servieren",
    "serviertem": "serviert",
    "servierten": "servieren",
    "servierter": "serviert",
    "serviertes": "serviert",
    "serviertest": "servieren",
    "serviertet": "servieren",
    "setze": "setzen",
    "setzend": "setzen",
    "setzende": "setzend",
    "setzendem": "setzend",
    "setzenden": "setzend",
    "setzender": "setzend",
    "setzendes": "setzend",
    "setzest": "setzen",
    "setzet": "setzen",
    "setzt": "setzen",
    "setzte": "setzen",
    "setzten": "setzen",
    "setztest": "setzen",
    "setztet": "setzen",
    "seufze": "seufzen",
    "seufzend": "seufzen",
    "seufzende": "seufzend",
    "seufzendem": "seufzend",
    "seufzenden": "seufzend",
    "seufzender": "seufzend",
    "seufzendere": "seufzend",
    "seufzenderem": "seufzend",
    "seufzenderen": "seufzend",
    "seufzenderer": "seufzend",
    "seufzenderes": "seufzend",
    "seufzendes": "seufzend",
    "seufzendste": "seufzend",
    "seufzendstem": "seufzend",
    "seufzendsten": "seufzend",
    "seufzendster": "seufzend",
    "seufzendstes": "seufzend",
    "seufzest": "seufzen",
    "seufzet": "seufzen",
    "seufzt": "seufzen",
    "seufzte": "seufzen",
    "seufzten": "seufzen",
    "seufztest": "seufzen",
    "seufztet": "seufzen",
    "sexistischem": "sexistisch",
    "sexistischen": "sexistisch",
    "sexistischer": "sexistisch",
    "sexistischere": "sexistisch",
    "sexistischerem": "sexistisch",
    "sexistischeren": "sexistisch",
    "sexistischerer": "sexistisch",
    "sexistischeres": "sexistisch",
    "sexistisches": "sexistisch",
    "sexistischste": "sexistisch",
    "sexistischstem": "sexistisch",
    "sexistischsten": "sexistisch",
    "sexistischster": "sexistisch",
    "sexistischstes": "sexistisch",
    "sexuellem": "sexuell",
    "sexuellen": "sexuell",
    "sexueller": "sexuell",
    "sexuelles": "sexuell",
    "seziere": "sezieren",
    "sezierend": "sezieren",
    "sezierende": "sezierend",
    "sezierendem": "sezierend",
    "sezierenden": "sezierend",
    "sezierender": "sezierend",
    "sezierendes": "sezierend",
    "sezierest": "sezieren",
    "sezieret": "sezieren",
    "sezierst": "sezieren",
    "seziert": "sezieren",
    "sezierte": "sezieren",
    "seziertem": "seziert",
    "sezierten": "sezieren",
    "sezierter": "seziert",
    "seziertes": "seziert",
    "seziertest": "sezieren",
    "seziertet": "sezieren",
    "seßhaftem": "seßhaft",
    "seßhaften": "seßhaft",
    "seßhafter": "seßhaft",
    "seßhaftes": "seßhaft",
    "siamesischem": "siamesisch",
    "siamesischen": "siamesisch",
    "siamesischer": "siamesisch",
    "siamesisches": "siamesisch",
    "sibirische": "sibirisch",
    "sibirischem": "sibirisch",
    "sibirischen": "sibirisch",
    "sibirischer": "sibirisch",
    "sibirisches": "sibirisch",
    "sicher": "sichern",
    "sichere": "sicher",
    "sicherem": "sicher",
    "sicheren": "sicher",
    "sicherer": "sicher",
    "sicherere": "sicher",
    "sichererem": "sicher",
    "sichereren": "sicher",
    "sichererer": "sicher",
    "sichereres": "sicher",
    "sicheres": "sicher",
    "sichergestellt": "sicherstellen",
    "sichergestellte": "sichergestellt",
    "sichergestelltem": "sichergestellt",
    "sichergestellten": "sichergestellt",
    "sichergestellter": "sichergestellt",
    "sichergestelltes": "sichergestellt",
    "sicherheitsbewußtem": "sicherheitsbewußt",
    "sicherheitsbewußten": "sicherheitsbewußt",
    "sicherheitsbewußter": "sicherheitsbewußt",
    "sicherheitsbewußtere": "sicherheitsbewußt",
    "sicherheitsbewußterem": "sicherheitsbewußt",
    "sicherheitsbewußteren": "sicherheitsbewußt",
    "sicherheitsbewußterer": "sicherheitsbewußt",
    "sicherheitsbewußteres": "sicherheitsbewußt",
    "sicherheitsbewußtes": "sicherheitsbewußt",
    "sicherheitsbewußteste": "sicherheitsbewußt",
    "sicherheitsbewußtestem": "sicherheitsbewußt",
    "sicherheitsbewußtesten": "sicherheitsbewußt",
    "sicherheitsbewußtester": "sicherheitsbewußt",
    "sicherheitsbewußtestes": "sicherheitsbewußt",
    "sicherheitspolitische": "sicherheitspolitisch",
    "sicherheitspolitischem": "sicherheitspolitisch",
    "sicherheitspolitischen": "sicherheitspolitisch",
    "sicherheitspolitischer": "sicherheitspolitisch",
    "sicherheitspolitisches": "sicherheitspolitisch",
    "sicherheitsrelevante": "sicherheitsrelevant",
    "sicherheitsrelevantem": "sicherheitsrelevant",
    "sicherheitsrelevanten": "sicherheitsrelevant",
    "sicherheitsrelevanter": "sicherheitsrelevant",
    "sicherheitsrelevantere": "sicherheitsrelevant",
    "sicherheitsrelevanterem": "sicherheitsrelevant",
    "sicherheitsrelevanteren": "sicherheitsrelevant",
    "sicherheitsrelevanterer": "sicherheitsrelevant",
    "sicherheitsrelevanteres": "sicherheitsrelevant",
    "sicherheitsrelevantes": "sicherheitsrelevant",
    "sicherheitsrelevanteste": "sicherheitsrelevant",
    "sicherheitsrelevantestem": "sicherheitsrelevant",
    "sicherheitsrelevantesten": "sicherheitsrelevant",
    "sicherheitsrelevantester": "sicherheitsrelevant",
    "sicherheitsrelevantestes": "sicherheitsrelevant",
    "sichernd": "sichern",
    "sichernde": "sichernd",
    "sicherndem": "sichernd",
    "sichernden": "sichernd",
    "sichernder": "sichernd",
    "sicherndere": "sichernd",
    "sichernderem": "sichernd",
    "sichernderen": "sichernd",
    "sichernderer": "sichernd",
    "sichernderes": "sichernd",
    "sicherndes": "sichernd",
    "sicherndste": "sichernd",
    "sicherndstem": "sichernd",
    "sicherndsten": "sichernd",
    "sicherndster": "sichernd",
    "sicherndstes": "sichernd",
    "sicherst": "sichern",
    "sicherste": "sicher",
    "sicherstelle": "sicherstellen",
    "sicherstellend": "sicherstellen",
    "sicherstellende": "sicherstellend",
    "sicherstellendem": "sicherstellend",
    "sicherstellenden": "sicherstellend",
    "sicherstellender": "sicherstellend",
    "sicherstellendes": "sicherstellend",
    "sicherstellest": "sicherstellen",
    "sicherstellet": "sicherstellen",
    "sicherstellst": "sicherstellen",
    "sicherstellt": "sicherstellen",
    "sicherstellte": "sicherstellen",
    "sicherstellten": "sicherstellen",
    "sicherstelltest": "sicherstellen",
    "sicherstelltet": "sicherstellen",
    "sicherstem": "sicher",
    "sichersten": "sicher",
    "sicherster": "sicher",
    "sicherstes": "sicher",
    "sichert": "sichern",
    "sicherte": "sichern",
    "sicherten": "sichern",
    "sichertest": "sichern",
    "sichertet": "sichern",
    "sicherzustellen": "sicherstellen",
    "sichtbare": "sichtbar",
    "sichtbarem": "sichtbar",
    "sichtbaren": "sichtbar",
    "sichtbarer": "sichtbar",
    "sichtbarere": "sichtbar",
    "sichtbarerem": "sichtbar",
    "sichtbareren": "sichtbar",
    "sichtbarerer": "sichtbar",
    "sichtbareres": "sichtbar",
    "sichtbares": "sichtbar",
    "sichtbarste": "sichtbar",
    "sichtbarstem": "sichtbar",
    "sichtbarsten": "sichtbar",
    "sichtbarster": "sichtbar",
    "sichtbarstes": "sichtbar",
    "sichte": "sichten",
    "sichtend": "sichten",
    "sichtende": "sichtend",
    "sichtendem": "sichtend",
    "sichtenden": "sichtend",
    "sichtender": "sichtend",
    "sichtendes": "sichtend",
    "sichtest": "sichten",
    "sichtet": "sichten",
    "sichtete": "sichten",
    "sichteten": "sichten",
    "sichtetest": "sichten",
    "sichtetet": "sichten",
    "sichtlichem": "sichtlich",
    "sichtlichen": "sichtlich",
    "sichtlicher": "sichtlich",
    "sichtliches": "sichtlich",
    "sie": "ich",
    "siebend": "sieben",
    "siebende": "siebend",
    "siebendem": "siebend",
    "siebenden": "siebend",
    "siebender": "siebend",
    "siebendes": "siebend",
    "siebest": "sieben",
    "siebet": "sieben",
    "siebst": "sieben",
    "siebt": "sieben",
    "siebte": "sieben",
    "siebten": "sieben",
    "siebtest": "sieben",
    "siebtet": "sieben",
    "sieche": "siechen",
    "siechend": "siechen",
    "siechende": "siechend",
    "siechendem": "siechend",
    "siechenden": "siechend",
    "siechender": "siechend",
    "siechendere": "siechend",
    "siechenderem": "siechend",
    "siechenderen": "siechend",
    "siechenderer": "siechend",
    "siechenderes": "siechend",
    "siechendes": "siechend",
    "siechendste": "siechend",
    "siechendstem": "siechend",
    "siechendsten": "siechend",
    "siechendster": "siechend",
    "siechendstes": "siechend",
    "siechest": "siechen",
    "siechet": "siechen",
    "siechst": "siechen",
    "siecht": "siechen",
    "siechte": "siechen",
    "siechten": "siechen",
    "siechtest": "siechen",
    "siechtet": "siechen",
    "siede": "sieden",
    "siedele": "siedeln",
    "siedelnd": "siedeln",
    "siedelnde": "siedelnd",
    "siedelndem": "siedelnd",
    "siedelnden": "siedelnd",
    "siedelnder": "siedelnd",
    "siedelndes": "siedelnd",
    "siedelst": "siedeln",
    "siedelt": "siedeln",
    "siedelte": "siedeln",
    "siedelten": "siedeln",
    "siedeltest": "siedeln",
    "siedeltet": "siedeln",
    "siedend": "sieden",
    "siedende": "siedend",
    "siedendem": "siedend",
    "siedenden": "siedend",
    "siedender": "siedend",
    "siedendes": "siedend",
    "siedest": "sieden",
    "siedet": "sieden",
    "siedete": "sieden",
    "siedeten": "sieden",
    "siedetest": "sieden",
    "siedetet": "sieden",
    "siedle": "siedeln",
    "siegele": "siegeln",
    "siegelnd": "siegeln",
    "siegelnde": "siegelnd",
    "siegelndem": "siegelnd",
    "siegelnden": "siegelnd",
    "siegelnder": "siegelnd",
    "siegelndes": "siegelnd",
    "siegelst": "siegeln",
    "siegelt": "siegeln",
    "siegelte": "siegeln",
    "siegelten": "siegeln",
    "siegeltest": "siegeln",
    "siegeltet": "siegeln",
    "siegend": "siegen",
    "siegende": "siegend",
    "siegendem": "siegend",
    "siegenden": "siegend",
    "siegender": "siegend",
    "siegendes": "siegend",
    "siegesgewissem": "siegesgewiß",
    "siegesgewissen": "siegesgewiß",
    "siegesgewisser": "siegesgewiß",
    "siegesgewissere": "siegesgewiß",
    "siegesgewisserem": "siegesgewiß",
    "siegesgewisseren": "siegesgewiß",
    "siegesgewisserer": "siegesgewiß",
    "siegesgewisseres": "siegesgewiß",
    "siegesgewisses": "siegesgewiß",
    "siegesgewisseste": "siegesgewiß",
    "siegesgewissestem": "siegesgewiß",
    "siegesgewissesten": "siegesgewiß",
    "siegesgewissester": "siegesgewiß",
    "siegesgewissestes": "siegesgewiß",
    "siegessichere": "siegessicher",
    "siegessicherem": "siegessicher",
    "siegessicheren": "siegessicher",
    "siegessicherer": "siegessicher",
    "siegessicherere": "siegessicher",
    "siegessichererem": "siegessicher",
    "siegessichereren": "siegessicher",
    "siegessichererer": "siegessicher",
    "siegessichereres": "siegessicher",
    "siegessicheres": "siegessicher",
    "siegessicherste": "siegessicher",
    "siegessicherstem": "siegessicher",
    "siegessichersten": "siegessicher",
    "siegessicherster": "siegessicher",
    "siegessicherstes": "siegessicher",
    "siegest": "siegen",
    "sieget": "siegen",
    "siegle": "siegeln",
    "siegreiche": "siegreich",
    "siegreichem": "siegreich",
    "siegreichen": "siegreich",
    "siegreicher": "siegreich",
    "siegreichere": "siegreich",
    "siegreicherem": "siegreich",
    "siegreicheren": "siegreich",
    "siegreicherer": "siegreich",
    "siegreicheres": "siegreich",
    "siegreiches": "siegreich",
    "siegreichste": "siegreich",
    "siegreichstem": "siegreich",
    "siegreichsten": "siegreich",
    "siegreichster": "siegreich",
    "siegreichstes": "siegreich",
    "siegst": "siegen",
    "siegt": "siegen",
    "siegte": "siegen",
    "siegten": "siegen",
    "siegtest": "siegen",
    "siegtet": "siegen",
    "sieh": "sehen",
    "siehst": "sehen",
    "sieht": "sehen",
    "sieze": "siezen",
    "siezend": "siezen",
    "siezende": "siezend",
    "siezendem": "siezend",
    "siezenden": "siezend",
    "siezender": "siezend",
    "siezendes": "siezend",
    "siezest": "siezen",
    "siezet": "siezen",
    "siezt": "siezen",
    "siezte": "siezen",
    "siezten": "siezen",
    "sieztest": "siezen",
    "sieztet": "siezen",
    "signalisiere": "signalisieren",
    "signalisierend": "signalisieren",
    "signalisierende": "signalisierend",
    "signalisierendem": "signalisierend",
    "signalisierenden": "signalisierend",
    "signalisierender": "signalisierend",
    "signalisierendes": "signalisierend",
    "signalisierest": "signalisieren",
    "signalisieret": "signalisieren",
    "signalisierst": "signalisieren",
    "signalisiert": "signalisieren",
    "signalisierte": "signalisieren",
    "signalisiertem": "signalisiert",
    "signalisierten": "signalisieren",
    "signalisierter": "signalisiert",
    "signalisiertes": "signalisiert",
    "signalisiertest": "signalisieren",
    "signalisiertet": "signalisieren",
    "signifikantem": "signifikant",
    "signifikanten": "signifikant",
    "signifikanter": "signifikant",
    "signifikantere": "signifikant",
    "signifikanterem": "signifikant",
    "signifikanteren": "signifikant",
    "signifikanterer": "signifikant",
    "signifikanteres": "signifikant",
    "signifikantes": "signifikant",
    "signifikanteste": "signifikant",
    "signifikantestem": "signifikant",
    "signifikantesten": "signifikant",
    "signifikantester": "signifikant",
    "signifikantestes": "signifikant",
    "silbernem": "silbern",
    "silbernen": "silbern",
    "silberner": "silbern",
    "silbernes": "silbern",
    "simpelstem": "simpel",
    "simpelsten": "simpel",
    "simpelster": "simpel",
    "simpelstes": "simpel",
    "simple": "simpel",
    "simplem": "simpel",
    "simplen": "simpel",
    "simpler": "simpel",
    "simplere": "simpel",
    "simplerem": "simpel",
    "simpleren": "simpel",
    "simplerer": "simpel",
    "simpleres": "simpel",
    "simples": "simpel",
    "simuliere": "simulieren",
    "simulierend": "simulieren",
    "simulierende": "simulierend",
    "simulierendem": "simulierend",
    "simulierenden": "simulierend",
    "simulierender": "simulierend",
    "simulierendes": "simulierend",
    "simulierest": "simulieren",
    "simulieret": "simulieren",
    "simulierst": "simulieren",
    "simuliert": "simulieren",
    "simulierte": "simulieren",
    "simuliertem": "simuliert",
    "simulierten": "simulieren",
    "simulierter": "simuliert",
    "simuliertes": "simuliert",
    "simuliertest": "simulieren",
    "simuliertet": "simulieren",
    "simultane": "simultan",
    "simultanem": "simultan",
    "simultanen": "simultan",
    "simultaner": "simultan",
    "simultanes": "simultan",
    "sind": "sein",
    "singe": "singen",
    "singend": "singen",
    "singende": "singend",
    "singendem": "singend",
    "singenden": "singend",
    "singender": "singend",
    "singendes": "singend",
    "singest": "singen",
    "singet": "singen",
    "singst": "singen",
    "singt": "singen",
    "singuläre": "singulär",
    "singulärem": "singulär",
    "singulären": "singulär",
    "singulärer": "singulär",
    "singuläres": "singulär",
    "sinke": "sinken",
    "sinkend": "sinken",
    "sinkende": "sinkend",
    "sinkendem": "sinkend",
    "sinkenden": "sinkend",
    "sinkender": "sinkend",
    "sinkendere": "sinkend",
    "sinkenderem": "sinkend",
    "sinkenderen": "sinkend",
    "sinkenderer": "sinkend",
    "sinkenderes": "sinkend",
    "sinkendes": "sinkend",
    "sinkendste": "sinkend",
    "sinkendstem": "sinkend",
    "sinkendsten": "sinkend",
    "sinkendster": "sinkend",
    "sinkendstes": "sinkend",
    "sinkest": "sinken",
    "sinket": "sinken",
    "sinkst": "sinken",
    "sinkt": "sinken",
    "sinnbildhaftem": "sinnbildhaft",
    "sinnbildhaften": "sinnbildhaft",
    "sinnbildhafter": "sinnbildhaft",
    "sinnbildhaftere": "sinnbildhaft",
    "sinnbildhafterem": "sinnbildhaft",
    "sinnbildhafteren": "sinnbildhaft",
    "sinnbildhafterer": "sinnbildhaft",
    "sinnbildhafteres": "sinnbildhaft",
    "sinnbildhaftes": "sinnbildhaft",
    "sinnbildhafteste": "sinnbildhaft",
    "sinnbildhaftestem": "sinnbildhaft",
    "sinnbildhaftesten": "sinnbildhaft",
    "sinnbildhaftester": "sinnbildhaft",
    "sinnbildhaftestes": "sinnbildhaft",
    "sinnbildliche": "sinnbildlich",
    "sinnbildlichem": "sinnbildlich",
    "sinnbildlichen": "sinnbildlich",
    "sinnbildlicher": "sinnbildlich",
    "sinnbildliches": "sinnbildlich",
    "sinnend": "sinnen",
    "sinnende": "sinnend",
    "sinnendem": "sinnend",
    "sinnenden": "sinnend",
    "sinnender": "sinnend",
    "sinnendes": "sinnend",
    "sinnest": "sinnen",
    "sinnet": "sinnen",
    "sinngemäße": "sinngemäß",
    "sinngemäßem": "sinngemäß",
    "sinngemäßen": "sinngemäß",
    "sinngemäßer": "sinngemäß",
    "sinngemäßes": "sinngemäß",
    "sinniere": "sinnieren",
    "sinnierend": "sinnieren",
    "sinnierende": "sinnierend",
    "sinnierendem": "sinnierend",
    "sinnierenden": "sinnierend",
    "sinnierender": "sinnierend",
    "sinnierendes": "sinnierend",
    "sinnierest": "sinnieren",
    "sinnieret": "sinnieren",
    "sinnierst": "sinnieren",
    "sinniert": "sinnieren",
    "sinnierte": "sinnieren",
    "sinniertem": "sinniert",
    "sinnierten": "sinnieren",
    "sinnierter": "sinniert",
    "sinniertes": "sinniert",
    "sinniertest": "sinnieren",
    "sinniertet": "sinnieren",
    "sinnige": "sinnig",
    "sinnigem": "sinnig",
    "sinnigen": "sinnig",
    "sinniger": "sinnig",
    "sinniges": "sinnig",
    "sinnliche": "sinnlich",
    "sinnlichem": "sinnlich",
    "sinnlichen": "sinnlich",
    "sinnlicher": "sinnlich",
    "sinnlichere": "sinnlich",
    "sinnlicherem": "sinnlich",
    "sinnlicheren": "sinnlich",
    "sinnlicherer": "sinnlich",
    "sinnlicheres": "sinnlich",
    "sinnliches": "sinnlich",
    "sinnlichste": "sinnlich",
    "sinnlichstem": "sinnlich",
    "sinnlichsten": "sinnlich",
    "sinnlichster": "sinnlich",
    "sinnlichstes": "sinnlich",
    "sinnlose": "sinnlos",
    "sinnlosem": "sinnlos",
    "sinnlosen": "sinnlos",
    "sinnloser": "sinnlos",
    "sinnlosere": "sinnlos",
    "sinnloserem": "sinnlos",
    "sinnloseren": "sinnlos",
    "sinnloserer": "sinnlos",
    "sinnloseres": "sinnlos",
    "sinnloses": "sinnlos",
    "sinnloseste": "sinnlos",
    "sinnlosestem": "sinnlos",
    "sinnlosesten": "sinnlos",
    "sinnlosester": "sinnlos",
    "sinnlosestes": "sinnlos",
    "sinnst": "sinnen",
    "sinnt": "sinnen",
    "sinnvolle": "sinnvoll",
    "sinnvollem": "sinnvoll",
    "sinnvollen": "sinnvoll",
    "sinnvoller": "sinnvoll",
    "sinnvollere": "sinnvoll",
    "sinnvollerem": "sinnvoll",
    "sinnvolleren": "sinnvoll",
    "sinnvollerer": "sinnvoll",
    "sinnvolleres": "sinnvoll",
    "sinnvolles": "sinnvoll",
    "sinnvollste": "sinnvoll",
    "sinnvollstem": "sinnvoll",
    "sinnvollsten": "sinnvoll",
    "sinnvollster": "sinnvoll",
    "sinnvollstes": "sinnvoll",
    "sinnwidrige": "sinnwidrig",
    "sinnwidrigem": "sinnwidrig",
    "sinnwidrigen": "sinnwidrig",
    "sinnwidriger": "sinnwidrig",
    "sinnwidrigere": "sinnwidrig",
    "sinnwidrigerem": "sinnwidrig",
    "sinnwidrigeren": "sinnwidrig",
    "sinnwidrigerer": "sinnwidrig",
    "sinnwidrigeres": "sinnwidrig",
    "sinnwidriges": "sinnwidrig",
    "sinnwidrigste": "sinnwidrig",
    "sinnwidrigstem": "sinnwidrig",
    "sinnwidrigsten": "sinnwidrig",
    "sinnwidrigster": "sinnwidrig",
    "sinnwidrigstes": "sinnwidrig",
    "sittenlosem": "sittenlos",
    "sittenlosen": "sittenlos",
    "sittenloser": "sittenlos",
    "sittenlosere": "sittenlos",
    "sittenloserem": "sittenlos",
    "sittenloseren": "sittenlos",
    "sittenloserer": "sittenlos",
    "sittenloseres": "sittenlos",
    "sittenloses": "sittenlos",
    "sittenloseste": "sittenlos",
    "sittenlosestem": "sittenlos",
    "sittenlosesten": "sittenlos",
    "sittenlosester": "sittenlos",
    "sittenlosestes": "sittenlos",
    "sittenwidrige": "sittenwidrig",
    "sittenwidrigem": "sittenwidrig",
    "sittenwidrigen": "sittenwidrig",
    "sittenwidriger": "sittenwidrig",
    "sittenwidriges": "sittenwidrig",
    "sittsamem": "sittsam",
    "sittsamen": "sittsam",
    "sittsamer": "sittsam",
    "sittsamere": "sittsam",
    "sittsamerem": "sittsam",
    "sittsameren": "sittsam",
    "sittsamerer": "sittsam",
    "sittsameres": "sittsam",
    "sittsames": "sittsam",
    "sittsamste": "sittsam",
    "sittsamstem": "sittsam",
    "sittsamsten": "sittsam",
    "sittsamster": "sittsam",
    "sittsamstes": "sittsam",
    "situativem": "situativ",
    "situativen": "situativ",
    "situativer": "situativ",
    "situatives": "situativ",
    "sitz": "sitzen",
    "sitzend": "sitzen",
    "sitzende": "sitzend",
    "sitzendem": "sitzend",
    "sitzenden": "sitzend",
    "sitzender": "sitzend",
    "sitzendes": "sitzend",
    "sitzest": "sitzen",
    "sitzet": "sitzen",
    "sitzt": "sitzen",
    "skalarem": "skalar",
    "skalaren": "skalar",
    "skalarer": "skalar",
    "skalares": "skalar",
    "skalpiere": "skalpieren",
    "skalpierend": "skalpieren",
    "skalpierende": "skalpierend",
    "skalpierendem": "skalpierend",
    "skalpierenden": "skalpierend",
    "skalpierender": "skalpierend",
    "skalpierendes": "skalpierend",
    "skalpierest": "skalpieren",
    "skalpieret": "skalpieren",
    "skalpierst": "skalpieren",
    "skalpiert": "skalpieren",
    "skalpierte": "skalpieren",
    "skalpiertem": "skalpiert",
    "skalpierten": "skalpieren",
    "skalpierter": "skalpiert",
    "skalpiertes": "skalpiert",
    "skalpiertest": "skalpieren",
    "skalpiertet": "skalpieren",
    "skandalösem": "skandalös",
    "skandalösen": "skandalös",
    "skandalöser": "skandalös",
    "skandalösere": "skandalös",
    "skandalöserem": "skandalös",
    "skandalöseren": "skandalös",
    "skandalöserer": "skandalös",
    "skandalöseres": "skandalös",
    "skandalöses": "skandalös",
    "skandalöseste": "skandalös",
    "skandalösestem": "skandalös",
    "skandalösesten": "skandalös",
    "skandalösester": "skandalös",
    "skandalösestes": "skandalös",
    "skandiere": "skandieren",
    "skandierend": "skandieren",
    "skandierende": "skandierend",
    "skandierendem": "skandierend",
    "skandierenden": "skandierend",
    "skandierender": "skandierend",
    "skandierendes": "skandierend",
    "skandierest": "skandieren",
    "skandieret": "skandieren",
    "skandierst": "skandieren",
    "skandiert": "skandieren",
    "skandierte": "skandieren",
    "skandiertem": "skandiert",
    "skandierten": "skandieren",
    "skandierter": "skandiert",
    "skandiertes": "skandiert",
    "skandiertest": "skandieren",
    "skandiertet": "skandieren",
    "skandinavische": "skandinavisch",
    "skandinavischem": "skandinavisch",
    "skandinavischen": "skandinavisch",
    "skandinavischer": "skandinavisch",
    "skandinavisches": "skandinavisch",
    "skelettiere": "skelettieren",
    "skelettierend": "skelettieren",
    "skelettierende": "skelettierend",
    "skelettierendem": "skelettierend",
    "skelettierenden": "skelettierend",
    "skelettierender": "skelettierend",
    "skelettierendes": "skelettierend",
    "skelettierest": "skelettieren",
    "skelettieret": "skelettieren",
    "skelettierst": "skelettieren",
    "skelettiert": "skelettieren",
    "skelettierte": "skelettieren",
    "skelettiertem": "skelettiert",
    "skelettierten": "skelettieren",
    "skelettierter": "skelettiert",
    "skelettiertes": "skelettiert",
    "skelettiertest": "skelettieren",
    "skelettiertet": "skelettieren",
    "skeptischem": "skeptisch",
    "skeptischen": "skeptisch",
    "skeptischer": "skeptisch",
    "skeptischere": "skeptisch",
    "skeptischerem": "skeptisch",
    "skeptischeren": "skeptisch",
    "skeptischerer": "skeptisch",
    "skeptischeres": "skeptisch",
    "skeptisches": "skeptisch",
    "skeptischste": "skeptisch",
    "skeptischstem": "skeptisch",
    "skeptischsten": "skeptisch",
    "skeptischster": "skeptisch",
    "skeptischstes": "skeptisch",
    "skizzenhaftem": "skizzenhaft",
    "skizzenhaften": "skizzenhaft",
    "skizzenhafter": "skizzenhaft",
    "skizzenhaftere": "skizzenhaft",
    "skizzenhafterem": "skizzenhaft",
    "skizzenhafteren": "skizzenhaft",
    "skizzenhafterer": "skizzenhaft",
    "skizzenhafteres": "skizzenhaft",
    "skizzenhaftes": "skizzenhaft",
    "skizzenhafteste": "skizzenhaft",
    "skizzenhaftestem": "skizzenhaft",
    "skizzenhaftesten": "skizzenhaft",
    "skizzenhaftester": "skizzenhaft",
    "skizzenhaftestes": "skizzenhaft",
    "skizziere": "skizzieren",
    "skizzierend": "skizzieren",
    "skizzierende": "skizzierend",
    "skizzierendem": "skizzierend",
    "skizzierenden": "skizzierend",
    "skizzierender": "skizzierend",
    "skizzierendes": "skizzierend",
    "skizzierest": "skizzieren",
    "skizzieret": "skizzieren",
    "skizzierst": "skizzieren",
    "skizziert": "skizzieren",
    "skizzierte": "skizzieren",
    "skizziertem": "skizziert",
    "skizzierten": "skizzieren",
    "skizzierter": "skizziert",
    "skizziertes": "skizziert",
    "skizziertest": "skizzieren",
    "skizziertet": "skizzieren",
    "sklavischem": "sklavisch",
    "sklavischen": "sklavisch",
    "sklavischer": "sklavisch",
    "sklavisches": "sklavisch",
    "skrupellosem": "skrupellos",
    "skrupellosen": "skrupellos",
    "skrupelloser": "skrupellos",
    "skrupellosere": "skrupellos",
    "skrupelloserem": "skrupellos",
    "skrupelloseren": "skrupellos",
    "skrupelloserer": "skrupellos",
    "skrupelloseres": "skrupellos",
    "skrupelloses": "skrupellos",
    "skrupelloseste": "skrupellos",
    "skrupellosestem": "skrupellos",
    "skrupellosesten": "skrupellos",
    "skrupellosester": "skrupellos",
    "skrupellosestes": "skrupellos",
    "skurrilem": "skurril",
    "skurrilen": "skurril",
    "skurriler": "skurril",
    "skurrilere": "skurril",
    "skurrilerem": "skurril",
    "skurrileren": "skurril",
    "skurrilerer": "skurril",
    "skurrileres": "skurril",
    "skurriles": "skurril",
    "skurrilste": "skurril",
    "skurrilstem": "skurril",
    "skurrilsten": "skurril",
    "skurrilster": "skurril",
    "skurrilstes": "skurril",
    "slowenischem": "slowenisch",
    "slowenischen": "slowenisch",
    "slowenischer": "slowenisch",
    "slowenisches": "slowenisch",
    "smartem": "smart",
    "smarten": "smart",
    "smarter": "smart",
    "smartere": "smart",
    "smarterem": "smart",
    "smarteren": "smart",
    "smarterer": "smart",
    "smarteres": "smart",
    "smartes": "smart",
    "smarteste": "smart",
    "smartestem": "smart",
    "smartesten": "smart",
    "smartester": "smart",
    "smartestes": "smart",
    "soff": "saufen",
    "soffen": "saufen",
    "soffst": "saufen",
    "sofft": "saufen",
    "sofortige": "sofortig",
    "sofortigem": "sofortig",
    "sofortigen": "sofortig",
    "sofortiger": "sofortig",
    "sofortiges": "sofortig",
    "sogen": "saugen",
    "sogenannte": "sogenannt",
    "sogenanntem": "sogenannt",
    "sogenannten": "sogenannt",
    "sogenannter": "sogenannt",
    "sogenanntes": "sogenannt",
    "sogst": "saugen",
    "sogt": "saugen",
    "sohle": "sohlen",
    "sohlend": "sohlen",
    "sohlende": "sohlend",
    "sohlendem": "sohlend",
    "sohlenden": "sohlend",
    "sohlender": "sohlend",
    "sohlendes": "sohlend",
    "sohlest": "sohlen",
    "sohlet": "sohlen",
    "sohlst": "sohlen",
    "sohlt": "sohlen",
    "sohlte": "sohlen",
    "sohlten": "sohlen",
    "sohltest": "sohlen",
    "sohltet": "sohlen",
    "solchem": "solch",
    "solchen": "solch",
    "solcher": "solch",
    "solches": "solch",
    "solidarischem": "solidarisch",
    "solidarischen": "solidarisch",
    "solidarischer": "solidarisch",
    "solidarischere": "solidarisch",
    "solidarischerem": "solidarisch",
    "solidarischeren": "solidarisch",
    "solidarischerer": "solidarisch",
    "solidarischeres": "solidarisch",
    "solidarisches": "solidarisch",
    "solidarischste": "solidarisch",
    "solidarischstem": "solidarisch",
    "solidarischsten": "solidarisch",
    "solidarischster": "solidarisch",
    "solidarischstes": "solidarisch",
    "solidarisiere": "solidarisieren",
    "solidarisierend": "solidarisieren",
    "solidarisierende": "solidarisierend",
    "solidarisierendem": "solidarisierend",
    "solidarisierenden": "solidarisierend",
    "solidarisierender": "solidarisierend",
    "solidarisierendere": "solidarisierend",
    "solidarisierenderem": "solidarisierend",
    "solidarisierenderen": "solidarisierend",
    "solidarisierenderer": "solidarisierend",
    "solidarisierenderes": "solidarisierend",
    "solidarisierendes": "solidarisierend",
    "solidarisierendste": "solidarisierend",
    "solidarisierendstem": "solidarisierend",
    "solidarisierendsten": "solidarisierend",
    "solidarisierendster": "solidarisierend",
    "solidarisierendstes": "solidarisierend",
    "solidarisierest": "solidarisieren",
    "solidarisieret": "solidarisieren",
    "solidarisierst": "solidarisieren",
    "solidarisiert": "solidarisieren",
    "solidarisierte": "solidarisieren",
    "solidarisiertem": "solidarisiert",
    "solidarisierten": "solidarisieren",
    "solidarisierter": "solidarisiert",
    "solidarisiertere": "solidarisiert",
    "solidarisierterem": "solidarisiert",
    "solidarisierteren": "solidarisiert",
    "solidarisierterer": "solidarisiert",
    "solidarisierteres": "solidarisiert",
    "solidarisiertes": "solidarisiert",
    "solidarisiertest": "solidarisieren",
    "solidarisiertestem": "solidarisiert",
    "solidarisiertesten": "solidarisiert",
    "solidarisiertester": "solidarisiert",
    "solidarisiertestes": "solidarisiert",
    "solidarisiertet": "solidarisieren",
    "solidem": "solide",
    "soliden": "solide",
    "solider": "solide",
    "solidere": "solide",
    "soliderem": "solide",
    "solideren": "solide",
    "soliderer": "solide",
    "solideres": "solide",
    "solides": "solide",
    "solideste": "solide",
    "solidestem": "solide",
    "solidesten": "solide",
    "solidester": "solide",
    "solidestes": "solide",
    "solle": "sollen",
    "sollest": "sollen",
    "sollet": "sollen",
    "sollst": "sollen",
    "sollt": "sollen",
    "sollte": "sollen",
    "sollten": "sollen",
    "solltest": "sollen",
    "solltet": "sollen",
    "sommerlichem": "sommerlich",
    "sommerlichen": "sommerlich",
    "sommerlicher": "sommerlich",
    "sommerliches": "sommerlich",
    "sonderbarem": "sonderbar",
    "sonderbaren": "sonderbar",
    "sonderbarer": "sonderbar",
    "sonderbarere": "sonderbar",
    "sonderbarerem": "sonderbar",
    "sonderbareren": "sonderbar",
    "sonderbarerer": "sonderbar",
    "sonderbareres": "sonderbar",
    "sonderbares": "sonderbar",
    "sonderbarste": "sonderbar",
    "sonderbarstem": "sonderbar",
    "sonderbarsten": "sonderbar",
    "sonderbarster": "sonderbar",
    "sonderbarstes": "sonderbar",
    "sondere": "sondern",
    "sonderlichem": "sonderlich",
    "sonderlichen": "sonderlich",
    "sonderlicher": "sonderlich",
    "sonderlichere": "sonderlich",
    "sonderlicherem": "sonderlich",
    "sonderlicheren": "sonderlich",
    "sonderlicherer": "sonderlich",
    "sonderlicheres": "sonderlich",
    "sonderliches": "sonderlich",
    "sonderlichste": "sonderlich",
    "sonderlichstem": "sonderlich",
    "sonderlichsten": "sonderlich",
    "sonderlichster": "sonderlich",
    "sonderlichstes": "sonderlich",
    "sondernd": "sondern",
    "sondernde": "sondernd",
    "sonderndem": "sondernd",
    "sondernden": "sondernd",
    "sondernder": "sondernd",
    "sonderndes": "sondernd",
    "sonderst": "sondern",
    "sondert": "sondern",
    "sonderte": "sondern",
    "sonderten": "sondern",
    "sondertest": "sondern",
    "sondertet": "sondern",
    "sondiere": "sondieren",
    "sondierend": "sondieren",
    "sondierende": "sondierend",
    "sondierendem": "sondierend",
    "sondierenden": "sondierend",
    "sondierender": "sondierend",
    "sondierendes": "sondierend",
    "sondierest": "sondieren",
    "sondieret": "sondieren",
    "sondierst": "sondieren",
    "sondiert": "sondieren",
    "sondierte": "sondieren",
    "sondiertem": "sondiert",
    "sondierten": "sondieren",
    "sondierter": "sondiert",
    "sondiertes": "sondiert",
    "sondiertest": "sondieren",
    "sondiertet": "sondieren",
    "sonnenarmem": "sonnenarm",
    "sonnenarmen": "sonnenarm",
    "sonnenarmer": "sonnenarm",
    "sonnenarmes": "sonnenarm",
    "sonnend": "sonnen",
    "sonnende": "sonnend",
    "sonnendem": "sonnend",
    "sonnenden": "sonnend",
    "sonnender": "sonnend",
    "sonnendes": "sonnend",
    "sonnengebräunte": "sonnengebräunt",
    "sonnengebräuntem": "sonnengebräunt",
    "sonnengebräunten": "sonnengebräunt",
    "sonnengebräunter": "sonnengebräunt",
    "sonnengebräuntere": "sonnengebräunt",
    "sonnengebräunterem": "sonnengebräunt",
    "sonnengebräunteren": "sonnengebräunt",
    "sonnengebräunterer": "sonnengebräunt",
    "sonnengebräunteres": "sonnengebräunt",
    "sonnengebräuntes": "sonnengebräunt",
    "sonnengebräunteste": "sonnengebräunt",
    "sonnengebräuntestem": "sonnengebräunt",
    "sonnengebräuntesten": "sonnengebräunt",
    "sonnengebräuntester": "sonnengebräunt",
    "sonnengebräuntestes": "sonnengebräunt",
    "sonnenklare": "sonnenklar",
    "sonnenklarem": "sonnenklar",
    "sonnenklaren": "sonnenklar",
    "sonnenklarer": "sonnenklar",
    "sonnenklares": "sonnenklar",
    "sonnenärmer": "sonnenarm",
    "sonnenärmere": "sonnenarm",
    "sonnenärmerem": "sonnenarm",
    "sonnenärmeren": "sonnenarm",
    "sonnenärmerer": "sonnenarm",
    "sonnenärmeres": "sonnenarm",
    "sonnenärmsten": "sonnenarm",
    "sonnest": "sonnen",
    "sonnet": "sonnen",
    "sonnige": "sonnig",
    "sonnigem": "sonnig",
    "sonnigen": "sonnig",
    "sonniger": "sonnig",
    "sonnigere": "sonnig",
    "sonnigerem": "sonnig",
    "sonnigeren": "sonnig",
    "sonnigerer": "sonnig",
    "sonnigeres": "sonnig",
    "sonniges": "sonnig",
    "sonnigste": "sonnig",
    "sonnigstem": "sonnig",
    "sonnigsten": "sonnig",
    "sonnigster": "sonnig",
    "sonnigstes": "sonnig",
    "sonnst": "sonnen",
    "sonnt": "sonnen",
    "sonnte": "sonnen",
    "sonnten": "sonnen",
    "sonntest": "sonnen",
    "sonntet": "sonnen",
    "sonntäglichem": "sonntäglich",
    "sonntäglichen": "sonntäglich",
    "sonntäglicher": "sonntäglich",
    "sonntägliches": "sonntäglich",
    "sonstige": "sonstig",
    "sonstigem": "sonstig",
    "sonstigen": "sonstig",
    "sonstiger": "sonstig",
    "sonstiges": "sonstig",
    "sorgend": "sorgen",
    "sorgende": "sorgend",
    "sorgendem": "sorgend",
    "sorgenden": "sorgend",
    "sorgender": "sorgend",
    "sorgendes": "sorgend",
    "sorgenfreie": "sorgenfrei",
    "sorgenfreiem": "sorgenfrei",
    "sorgenfreien": "sorgenfrei",
    "sorgenfreier": "sorgenfrei",
    "sorgenfreiere": "sorgenfrei",
    "sorgenfreierem": "sorgenfrei",
    "sorgenfreieren": "sorgenfrei",
    "sorgenfreierer": "sorgenfrei",
    "sorgenfreieres": "sorgenfrei",
    "sorgenfreies": "sorgenfrei",
    "sorgenfreieste": "sorgenfrei",
    "sorgenfreiestem": "sorgenfrei",
    "sorgenfreiesten": "sorgenfrei",
    "sorgenfreiester": "sorgenfrei",
    "sorgenfreiestes": "sorgenfrei",
    "sorgenlose": "sorgenlos",
    "sorgenlosem": "sorgenlos",
    "sorgenlosen": "sorgenlos",
    "sorgenloser": "sorgenlos",
    "sorgenlosere": "sorgenlos",
    "sorgenloserem": "sorgenlos",
    "sorgenloseren": "sorgenlos",
    "sorgenloserer": "sorgenlos",
    "sorgenloseres": "sorgenlos",
    "sorgenloses": "sorgenlos",
    "sorgenloseste": "sorgenlos",
    "sorgenlosestem": "sorgenlos",
    "sorgenlosesten": "sorgenlos",
    "sorgenlosester": "sorgenlos",
    "sorgenlosestes": "sorgenlos",
    "sorgenvollem": "sorgenvoll",
    "sorgenvollen": "sorgenvoll",
    "sorgenvoller": "sorgenvoll",
    "sorgenvollere": "sorgenvoll",
    "sorgenvollerem": "sorgenvoll",
    "sorgenvolleren": "sorgenvoll",
    "sorgenvollerer": "sorgenvoll",
    "sorgenvolleres": "sorgenvoll",
    "sorgenvolles": "sorgenvoll",
    "sorgenvollste": "sorgenvoll",
    "sorgenvollstem": "sorgenvoll",
    "sorgenvollsten": "sorgenvoll",
    "sorgenvollster": "sorgenvoll",
    "sorgenvollstes": "sorgenvoll",
    "sorgest": "sorgen",
    "sorget": "sorgen",
    "sorgfältige": "sorgfältig",
    "sorgfältigem": "sorgfältig",
    "sorgfältigen": "sorgfältig",
    "sorgfältiger": "sorgfältig",
    "sorgfältigere": "sorgfältig",
    "sorgfältigerem": "sorgfältig",
    "sorgfältigeren": "sorgfältig",
    "sorgfältigerer": "sorgfältig",
    "sorgfältigeres": "sorgfältig",
    "sorgfältiges": "sorgfältig",
    "sorgfältigste": "sorgfältig",
    "sorgfältigstem": "sorgfältig",
    "sorgfältigsten": "sorgfältig",
    "sorgfältigster": "sorgfältig",
    "sorgfältigstes": "sorgfältig",
    "sorglose": "sorglos",
    "sorglosem": "sorglos",
    "sorglosen": "sorglos",
    "sorgloser": "sorglos",
    "sorglosere": "sorglos",
    "sorgloserem": "sorglos",
    "sorgloseren": "sorglos",
    "sorgloserer": "sorglos",
    "sorgloseres": "sorglos",
    "sorgloses": "sorglos",
    "sorgloseste": "sorglos",
    "sorglosestem": "sorglos",
    "sorglosesten": "sorglos",
    "sorglosester": "sorglos",
    "sorglosestes": "sorglos",
    "sorgsame": "sorgsam",
    "sorgsamem": "sorgsam",
    "sorgsamen": "sorgsam",
    "sorgsamer": "sorgsam",
    "sorgsamere": "sorgsam",
    "sorgsamerem": "sorgsam",
    "sorgsameren": "sorgsam",
    "sorgsamerer": "sorgsam",
    "sorgsameres": "sorgsam",
    "sorgsames": "sorgsam",
    "sorgsamste": "sorgsam",
    "sorgsamstem": "sorgsam",
    "sorgsamsten": "sorgsam",
    "sorgsamster": "sorgsam",
    "sorgsamstes": "sorgsam",
    "sorgst": "sorgen",
    "sorgt": "sorgen",
    "sorgte": "sorgen",
    "sorgten": "sorgen",
    "sorgtest": "sorgen",
    "sorgtet": "sorgen",
    "sortiere": "sortieren",
    "sortierend": "sortieren",
    "sortierende": "sortierend",
    "sortierendem": "sortierend",
    "sortierenden": "sortierend",
    "sortierender": "sortierend",
    "sortierendes": "sortierend",
    "sortierest": "sortieren",
    "sortieret": "sortieren",
    "sortierst": "sortieren",
    "sortiert": "sortieren",
    "sortierte": "sortieren",
    "sortiertem": "sortiert",
    "sortierten": "sortieren",
    "sortierter": "sortiert",
    "sortiertes": "sortiert",
    "sortiertest": "sortieren",
    "sortiertet": "sortieren",
    "sott": "sieden",
    "sotten": "sieden",
    "sottest": "sieden",
    "sottet": "sieden",
    "souveränem": "souverän",
    "souveränen": "souverän",
    "souveräner": "souverän",
    "souveränere": "souverän",
    "souveränerem": "souverän",
    "souveräneren": "souverän",
    "souveränerer": "souverän",
    "souveräneres": "souverän",
    "souveränes": "souverän",
    "souveränstem": "souverän",
    "souveränsten": "souverän",
    "souveränster": "souverän",
    "souveränstes": "souverän",
    "sowjetische": "sowjetisch",
    "sowjetischem": "sowjetisch",
    "sowjetischen": "sowjetisch",
    "sowjetischer": "sowjetisch",
    "sowjetisches": "sowjetisch",
    "sozialdemokratischem": "sozialdemokratisch",
    "sozialdemokratischen": "sozialdemokratisch",
    "sozialdemokratischer": "sozialdemokratisch",
    "sozialdemokratisches": "sozialdemokratisch",
    "sozialem": "sozial",
    "sozialen": "sozial",
    "sozialer": "sozial",
    "sozialere": "sozial",
    "sozialerem": "sozial",
    "sozialeren": "sozial",
    "sozialerer": "sozial",
    "sozialeres": "sozial",
    "soziales": "sozial",
    "sozialisierend": "sozialisieren",
    "sozialisierende": "sozialisierend",
    "sozialisierendem": "sozialisierend",
    "sozialisierenden": "sozialisierend",
    "sozialisierender": "sozialisierend",
    "sozialisierendere": "sozialisierend",
    "sozialisierenderem": "sozialisierend",
    "sozialisierenderen": "sozialisierend",
    "sozialisierenderer": "sozialisierend",
    "sozialisierenderes": "sozialisierend",
    "sozialisierendes": "sozialisierend",
    "sozialisierendste": "sozialisierend",
    "sozialisierendstem": "sozialisierend",
    "sozialisierendsten": "sozialisierend",
    "sozialisierendster": "sozialisierend",
    "sozialisierendstes": "sozialisierend",
    "sozialisierest": "sozialisieren",
    "sozialisieret": "sozialisieren",
    "sozialisierst": "sozialisieren",
    "sozialisiert": "sozialisieren",
    "sozialisierte": "sozialisieren",
    "sozialisiertem": "sozialisiert",
    "sozialisierten": "sozialisieren",
    "sozialisierter": "sozialisiert",
    "sozialisiertere": "sozialisiert",
    "sozialisierterem": "sozialisiert",
    "sozialisierteren": "sozialisiert",
    "sozialisierterer": "sozialisiert",
    "sozialisierteres": "sozialisiert",
    "sozialisiertes": "sozialisiert",
    "sozialisiertest": "sozialisieren",
    "sozialisierteste": "sozialisiert",
    "sozialisiertestem": "sozialisiert",
    "sozialisiertesten": "sozialisiert",
    "sozialisiertester": "sozialisiert",
    "sozialisiertestes": "sozialisiert",
    "sozialisiertet": "sozialisieren",
    "sozialistischem": "sozialistisch",
    "sozialistischen": "sozialistisch",
    "sozialistischer": "sozialistisch",
    "sozialistischere": "sozialistisch",
    "sozialistischerem": "sozialistisch",
    "sozialistischeren": "sozialistisch",
    "sozialistischerer": "sozialistisch",
    "sozialistischeres": "sozialistisch",
    "sozialistisches": "sozialistisch",
    "sozialistischste": "sozialistisch",
    "sozialistischstem": "sozialistisch",
    "sozialistischsten": "sozialistisch",
    "sozialistischster": "sozialistisch",
    "sozialistischstes": "sozialistisch",
    "sozialliberale": "sozialliberal",
    "sozialliberalem": "sozialliberal",
    "sozialliberalen": "sozialliberal",
    "sozialliberaler": "sozialliberal",
    "sozialliberales": "sozialliberal",
    "sozialpolitische": "sozialpolitisch",
    "sozialpolitischem": "sozialpolitisch",
    "sozialpolitischen": "sozialpolitisch",
    "sozialpolitischer": "sozialpolitisch",
    "sozialpolitisches": "sozialpolitisch",
    "sozialpädagogische": "sozialpädagogisch",
    "sozialpädagogischem": "sozialpädagogisch",
    "sozialpädagogischen": "sozialpädagogisch",
    "sozialpädagogischer": "sozialpädagogisch",
    "sozialpädagogisches": "sozialpädagogisch",
    "sozialreformerischem": "sozialreformerisch",
    "sozialreformerischen": "sozialreformerisch",
    "sozialreformerischer": "sozialreformerisch",
    "sozialreformerischere": "sozialreformerisch",
    "sozialreformerischerem": "sozialreformerisch",
    "sozialreformerischeren": "sozialreformerisch",
    "sozialreformerischerer": "sozialreformerisch",
    "sozialreformerischeres": "sozialreformerisch",
    "sozialreformerisches": "sozialreformerisch",
    "sozialreformerischste": "sozialreformerisch",
    "sozialreformerischstem": "sozialreformerisch",
    "sozialreformerischsten": "sozialreformerisch",
    "sozialreformerischster": "sozialreformerisch",
    "sozialreformerischstes": "sozialreformerisch",
    "sozialstem": "sozial",
    "sozialsten": "sozial",
    "sozialster": "sozial",
    "sozialstes": "sozial",
    "sozialverträglichem": "sozialverträglich",
    "sozialverträglichen": "sozialverträglich",
    "sozialverträglicher": "sozialverträglich",
    "sozialverträglichere": "sozialverträglich",
    "sozialverträglicherem": "sozialverträglich",
    "sozialverträglicheren": "sozialverträglich",
    "sozialverträglicherer": "sozialverträglich",
    "sozialverträglicheres": "sozialverträglich",
    "sozialverträgliches": "sozialverträglich",
    "sozialverträglichste": "sozialverträglich",
    "sozialverträglichstem": "sozialverträglich",
    "sozialverträglichsten": "sozialverträglich",
    "sozialverträglichster": "sozialverträglich",
    "sozialverträglichstes": "sozialverträglich",
    "soziokulturellem": "soziokulturell",
    "soziokulturellen": "soziokulturell",
    "soziokultureller": "soziokulturell",
    "soziokulturelles": "soziokulturell",
    "soziologischem": "soziologisch",
    "soziologischen": "soziologisch",
    "soziologischer": "soziologisch",
    "soziologisches": "soziologisch",
    "spachtele": "spachteln",
    "spachtelnd": "spachteln",
    "spachtelnde": "spachtelnd",
    "spachtelndem": "spachtelnd",
    "spachtelnden": "spachtelnd",
    "spachtelnder": "spachtelnd",
    "spachtelndes": "spachtelnd",
    "spachtelst": "spachteln",
    "spachtelt": "spachteln",
    "spachtelte": "spachteln",
    "spachtelten": "spachteln",
    "spachteltest": "spachteln",
    "spachteltet": "spachteln",
    "spachtle": "spachteln",
    "spaltbarem": "spaltbar",
    "spaltbaren": "spaltbar",
    "spaltbarer": "spaltbar",
    "spaltbares": "spaltbar",
    "spaltend": "spalten",
    "spaltende": "spaltend",
    "spaltendem": "spaltend",
    "spaltenden": "spaltend",
    "spaltender": "spaltend",
    "spaltendere": "spaltend",
    "spaltenderem": "spaltend",
    "spaltenderen": "spaltend",
    "spaltenderer": "spaltend",
    "spaltenderes": "spaltend",
    "spaltendes": "spaltend",
    "spaltendste": "spaltend",
    "spaltendstem": "spaltend",
    "spaltendsten": "spaltend",
    "spaltendster": "spaltend",
    "spaltendstes": "spaltend",
    "spaltest": "spalten",
    "spaltet": "spalten",
    "spaltete": "spalten",
    "spalteten": "spalten",
    "spaltetest": "spalten",
    "spaltetet": "spalten",
    "spanischem": "spanisch",
    "spanischen": "spanisch",
    "spanischer": "spanisch",
    "spanisches": "spanisch",
    "spann": "spinnen",
    "spanne": "spannen",
    "spannend": "spannen",
    "spannende": "spannend",
    "spannendem": "spannend",
    "spannenden": "spannend",
    "spannender": "spannend",
    "spannendere": "spannend",
    "spannenderem": "spannend",
    "spannenderen": "spannend",
    "spannenderer": "spannend",
    "spannenderes": "spannend",
    "spannendes": "spannend",
    "spannendste": "spannend",
    "spannendstem": "spannend",
    "spannendsten": "spannend",
    "spannendster": "spannend",
    "spannendstes": "spannend",
    "spannest": "spannen",
    "spannet": "spannen",
    "spannst": "spinnen",
    "spannt": "spinnen",
    "spannte": "spannen",
    "spannten": "spannen",
    "spanntest": "spannen",
    "spanntet": "spannen",
    "spare": "sparen",
    "sparend": "sparen",
    "sparende": "sparend",
    "sparendem": "sparend",
    "sparenden": "sparend",
    "sparender": "sparend",
    "sparendes": "sparend",
    "sparest": "sparen",
    "sparet": "sparen",
    "sparsamem": "sparsam",
    "sparsamen": "sparsam",
    "sparsamer": "sparsam",
    "sparsamere": "sparsam",
    "sparsamerem": "sparsam",
    "sparsameren": "sparsam",
    "sparsamerer": "sparsam",
    "sparsameres": "sparsam",
    "sparsames": "sparsam",
    "sparsamste": "sparsam",
    "sparsamstem": "sparsam",
    "sparsamsten": "sparsam",
    "sparsamster": "sparsam",
    "sparsamstes": "sparsam",
    "sparst": "sparen",
    "spart": "sparen",
    "spartanische": "spartanisch",
    "spartanischem": "spartanisch",
    "spartanischen": "spartanisch",
    "spartanischer": "spartanisch",
    "spartanischere": "spartanisch",
    "spartanischerem": "spartanisch",
    "spartanischeren": "spartanisch",
    "spartanischerer": "spartanisch",
    "spartanischeres": "spartanisch",
    "spartanisches": "spartanisch",
    "spartanischste": "spartanisch",
    "spartanischstem": "spartanisch",
    "spartanischsten": "spartanisch",
    "spartanischster": "spartanisch",
    "spartanischstes": "spartanisch",
    "sparte": "sparen",
    "sparten": "sparen",
    "spartest": "sparen",
    "spartet": "sparen",
    "spaziere": "spazieren",
    "spazierend": "spazieren",
    "spazierende": "spazierend",
    "spazierendem": "spazierend",
    "spazierenden": "spazierend",
    "spazierender": "spazierend",
    "spazierendere": "spazierend",
    "spazierenderem": "spazierend",
    "spazierenderen": "spazierend",
    "spazierenderer": "spazierend",
    "spazierenderes": "spazierend",
    "spazierendes": "spazierend",
    "spazierendste": "spazierend",
    "spazierendstem": "spazierend",
    "spazierendsten": "spazierend",
    "spazierendster": "spazierend",
    "spazierendstes": "spazierend",
    "spazierenführe": "spazierenführen",
    "spazierenführend": "spazierenführen",
    "spazierenführende": "spazierenführend",
    "spazierenführendem": "spazierenführend",
    "spazierenführenden": "spazierenführend",
    "spazierenführender": "spazierenführend",
    "spazierenführendes": "spazierenführend",
    "spazierenführest": "spazierenführen",
    "spazierenführet": "spazierenführen",
    "spazierenführst": "spazierenführen",
    "spazierenführt": "spazierenführen",
    "spazierenführte": "spazierenführen",
    "spazierenführten": "spazierenführen",
    "spazierenführtest": "spazierenführen",
    "spazierenführtet": "spazierenführen",
    "spazierengeführt": "spazierenführen",
    "spazierengeführte": "spazierengeführt",
    "spazierengeführtem": "spazierengeführt",
    "spazierengeführten": "spazierengeführt",
    "spazierengeführter": "spazierengeführt",
    "spazierengeführtes": "spazierengeführt",
    "spazierengegangen": "spazierengehen",
    "spazierengegangene": "spazierengegangen",
    "spazierengegangenem": "spazierengegangen",
    "spazierengegangenen": "spazierengegangen",
    "spazierengegangener": "spazierengegangen",
    "spazierengegangenes": "spazierengegangen",
    "spazierengehe": "spazierengehen",
    "spazierengehend": "spazierengehen",
    "spazierengehende": "spazierengehend",
    "spazierengehendem": "spazierengehend",
    "spazierengehenden": "spazierengehend",
    "spazierengehender": "spazierengehend",
    "spazierengehendes": "spazierengehend",
    "spazierengehest": "spazierengehen",
    "spazierengehet": "spazierengehen",
    "spazierengehst": "spazierengehen",
    "spazierengeht": "spazierengehen",
    "spazierenging": "spazierengehen",
    "spazierenginge": "spazierengehen",
    "spazierengingen": "spazierengehen",
    "spazierengingest": "spazierengehen",
    "spazierenginget": "spazierengehen",
    "spazierengingst": "spazierengehen",
    "spazierengingt": "spazierengehen",
    "spazierenzuführen": "spazierenführen",
    "spazierenzugehen": "spazierengehen",
    "spazierest": "spazieren",
    "spazieret": "spazieren",
    "spazierst": "spazieren",
    "spaziert": "spazieren",
    "spazierte": "spazieren",
    "spaziertem": "spaziert",
    "spazierten": "spazieren",
    "spazierter": "spaziert",
    "spaziertes": "spaziert",
    "spaziertest": "spazieren",
    "spaziertet": "spazieren",
    "spaßend": "spaßen",
    "spaßende": "spaßend",
    "spaßendem": "spaßend",
    "spaßenden": "spaßend",
    "spaßender": "spaßend",
    "spaßendere": "spaßend",
    "spaßenderem": "spaßend",
    "spaßenderen": "spaßend",
    "spaßenderer": "spaßend",
    "spaßenderes": "spaßend",
    "spaßendes": "spaßend",
    "spaßendste": "spaßend",
    "spaßendstem": "spaßend",
    "spaßendsten": "spaßend",
    "spaßendster": "spaßend",
    "spaßendstes": "spaßend",
    "spaßest": "spaßen",
    "spaßet": "spaßen",
    "spaßige": "spaßig",
    "spaßigem": "spaßig",
    "spaßigen": "spaßig",
    "spaßiger": "spaßig",
    "spaßigere": "spaßig",
    "spaßigerem": "spaßig",
    "spaßigeren": "spaßig",
    "spaßigerer": "spaßig",
    "spaßigeres": "spaßig",
    "spaßiges": "spaßig",
    "spaßigste": "spaßig",
    "spaßigstem": "spaßig",
    "spaßigsten": "spaßig",
    "spaßigster": "spaßig",
    "spaßigstes": "spaßig",
    "spaßt": "spaßen",
    "spaßte": "spaßen",
    "spaßten": "spaßen",
    "spaßtest": "spaßen",
    "spaßtet": "spaßen",
    "speichere": "speichern",
    "speichernd": "speichern",
    "speichernde": "speichernd",
    "speicherndem": "speichernd",
    "speichernden": "speichernd",
    "speichernder": "speichernd",
    "speicherndes": "speichernd",
    "speicherst": "speichern",
    "speichert": "speichern",
    "speicherte": "speichern",
    "speicherten": "speichern",
    "speichertest": "speichern",
    "speichertet": "speichern",
    "speie": "speien",
    "speiend": "speien",
    "speiende": "speiend",
    "speiendem": "speiend",
    "speienden": "speiend",
    "speiender": "speiend",
    "speiendes": "speiend",
    "speiest": "speien",
    "speiet": "speien",
    "speise": "speisen",
    "speisend": "speisen",
    "speisende": "speisend",
    "speisendem": "speisend",
    "speisenden": "speisend",
    "speisender": "speisend",
    "speisendes": "speisend",
    "speisest": "speisen",
    "speiset": "speisen",
    "speist": "speisen",
    "speiste": "speisen",
    "speisten": "speisen",
    "speistest": "speisen",
    "speistet": "speisen",
    "speit": "speien",
    "speiüble": "speiübel",
    "speiüblem": "speiübel",
    "speiüblen": "speiübel",
    "speiübler": "speiübel",
    "speiübles": "speiübel",
    "spektakulärem": "spektakulär",
    "spektakulären": "spektakulär",
    "spektakulärer": "spektakulär",
    "spektakulärere": "spektakulär",
    "spektakulärerem": "spektakulär",
    "spektakuläreren": "spektakulär",
    "spektakulärerer": "spektakulär",
    "spektakuläreres": "spektakulär",
    "spektakuläres": "spektakulär",
    "spektakulärste": "spektakulär",
    "spektakulärstem": "spektakulär",
    "spektakulärsten": "spektakulär",
    "spektakulärster": "spektakulär",
    "spektakulärstes": "spektakulär",
    "spektrographischem": "spektrographisch",
    "spektrographischen": "spektrographisch",
    "spektrographischer": "spektrographisch",
    "spektrographisches": "spektrographisch",
    "spekulativem": "spekulativ",
    "spekulativen": "spekulativ",
    "spekulativer": "spekulativ",
    "spekulatives": "spekulativ",
    "spekuliere": "spekulieren",
    "spekulierend": "spekulieren",
    "spekulierende": "spekulierend",
    "spekulierendem": "spekulierend",
    "spekulierenden": "spekulierend",
    "spekulierender": "spekulierend",
    "spekulierendere": "spekulierend",
    "spekulierenderem": "spekulierend",
    "spekulierenderen": "spekulierend",
    "spekulierenderer": "spekulierend",
    "spekulierenderes": "spekulierend",
    "spekulierendes": "spekulierend",
    "spekulierendste": "spekulierend",
    "spekulierendstem": "spekulierend",
    "spekulierendsten": "spekulierend",
    "spekulierendster": "spekulierend",
    "spekulierendstes": "spekulierend",
    "spekulierest": "spekulieren",
    "spekulieret": "spekulieren",
    "spekulierst": "spekulieren",
    "spekuliert": "spekulieren",
    "spekulierte": "spekulieren",
    "spekuliertem": "spekuliert",
    "spekulierten": "spekulieren",
    "spekulierter": "spekuliert",
    "spekuliertere": "spekuliert",
    "spekulierterem": "spekuliert",
    "spekulierteren": "spekuliert",
    "spekulierterer": "spekuliert",
    "spekulierteres": "spekuliert",
    "spekuliertes": "spekuliert",
    "spekuliertest": "spekulieren",
    "spekulierteste": "spekuliert",
    "spekuliertestem": "spekuliert",
    "spekuliertesten": "spekuliert",
    "spekuliertester": "spekuliert",
    "spekuliertestes": "spekuliert",
    "spekuliertet": "spekulieren",
    "spendabelste": "spendabel",
    "spendabelstem": "spendabel",
    "spendabelsten": "spendabel",
    "spendabelster": "spendabel",
    "spendabelstes": "spendabel",
    "spendable": "spendabel",
    "spendablem": "spendabel",
    "spendablen": "spendabel",
    "spendabler": "spendabel",
    "spendablere": "spendabel",
    "spendablerem": "spendabel",
    "spendableren": "spendabel",
    "spendablerer": "spendabel",
    "spendableres": "spendabel",
    "spendables": "spendabel",
    "spende": "spenden",
    "spendend": "spenden",
    "spendende": "spendend",
    "spendendem": "spendend",
    "spendenden": "spendend",
    "spendender": "spendend",
    "spendendes": "spendend",
    "spendest": "spenden",
    "spendet": "spenden",
    "spendete": "spenden",
    "spendeten": "spenden",
    "spendetest": "spenden",
    "spendetet": "spenden",
    "spendiere": "spendieren",
    "spendierend": "spendieren",
    "spendierende": "spendierend",
    "spendierendem": "spendierend",
    "spendierenden": "spendierend",
    "spendierender": "spendierend",
    "spendierendes": "spendierend",
    "spendierest": "spendieren",
    "spendieret": "spendieren",
    "spendierst": "spendieren",
    "spendiert": "spendieren",
    "spendierte": "spendieren",
    "spendiertem": "spendiert",
    "spendierten": "spendieren",
    "spendierter": "spendiert",
    "spendiertes": "spendiert",
    "spendiertest": "spendieren",
    "spendiertet": "spendieren",
    "spermizidem": "spermizid",
    "spermiziden": "spermizid",
    "spermizider": "spermizid",
    "spermizides": "spermizid",
    "sperrangelweitem": "sperrangelweit",
    "sperrangelweiten": "sperrangelweit",
    "sperrangelweiter": "sperrangelweit",
    "sperrangelweites": "sperrangelweit",
    "sperre": "sperren",
    "sperrend": "sperren",
    "sperrende": "sperrend",
    "sperrendem": "sperrend",
    "sperrenden": "sperrend",
    "sperrender": "sperrend",
    "sperrendere": "sperrend",
    "sperrenderem": "sperrend",
    "sperrenderen": "sperrend",
    "sperrenderer": "sperrend",
    "sperrenderes": "sperrend",
    "sperrendes": "sperrend",
    "sperrendste": "sperrend",
    "sperrendstem": "sperrend",
    "sperrendsten": "sperrend",
    "sperrendster": "sperrend",
    "sperrendstes": "sperrend",
    "sperrest": "sperren",
    "sperret": "sperren",
    "sperrigem": "sperrig",
    "sperrigen": "sperrig",
    "sperriger": "sperrig",
    "sperrigere": "sperrig",
    "sperrigerem": "sperrig",
    "sperrigeren": "sperrig",
    "sperrigerer": "sperrig",
    "sperrigeres": "sperrig",
    "sperriges": "sperrig",
    "sperrigste": "sperrig",
    "sperrigstem": "sperrig",
    "sperrigsten": "sperrig",
    "sperrigster": "sperrig",
    "sperrigstes": "sperrig",
    "sperrst": "sperren",
    "sperrt": "sperren",
    "sperrte": "sperren",
    "sperrten": "sperren",
    "sperrtest": "sperren",
    "sperrtet": "sperren",
    "spesenfreiem": "spesenfrei",
    "spesenfreien": "spesenfrei",
    "spesenfreier": "spesenfrei",
    "spesenfreies": "spesenfrei",
    "spezialisiere": "spezialisieren",
    "spezialisierend": "spezialisieren",
    "spezialisierende": "spezialisierend",
    "spezialisierendem": "spezialisierend",
    "spezialisierenden": "spezialisierend",
    "spezialisierender": "spezialisierend",
    "spezialisierendere": "spezialisierend",
    "spezialisierenderem": "spezialisierend",
    "spezialisierenderen": "spezialisierend",
    "spezialisierenderer": "spezialisierend",
    "spezialisierenderes": "spezialisierend",
    "spezialisierendes": "spezialisierend",
    "spezialisierendste": "spezialisierend",
    "spezialisierendstem": "spezialisierend",
    "spezialisierendsten": "spezialisierend",
    "spezialisierendster": "spezialisierend",
    "spezialisierendstes": "spezialisierend",
    "spezialisierest": "spezialisieren",
    "spezialisieret": "spezialisieren",
    "spezialisierst": "spezialisieren",
    "spezialisiert": "spezialisieren",
    "spezialisierte": "spezialisieren",
    "spezialisiertem": "spezialisiert",
    "spezialisierten": "spezialisieren",
    "spezialisierter": "spezialisiert",
    "spezialisiertere": "spezialisiert",
    "spezialisierterem": "spezialisiert",
    "spezialisierteren": "spezialisiert",
    "spezialisierterer": "spezialisiert",
    "spezialisierteres": "spezialisiert",
    "spezialisiertes": "spezialisiert",
    "spezialisiertest": "spezialisieren",
    "spezialisiertestem": "spezialisiert",
    "spezialisiertesten": "spezialisiert",
    "spezialisiertester": "spezialisiert",
    "spezialisiertestes": "spezialisiert",
    "spezialisiertet": "spezialisieren",
    "speziellem": "speziell",
    "speziellen": "speziell",
    "spezieller": "speziell",
    "speziellere": "speziell",
    "speziellerem": "speziell",
    "spezielleren": "speziell",
    "speziellerer": "speziell",
    "spezielleres": "speziell",
    "spezielles": "speziell",
    "speziellste": "speziell",
    "speziellstem": "speziell",
    "speziellsten": "speziell",
    "speziellster": "speziell",
    "speziellstes": "speziell",
    "spezifischem": "spezifisch",
    "spezifischen": "spezifisch",
    "spezifischer": "spezifisch",
    "spezifisches": "spezifisch",
    "spezifiziere": "spezifizieren",
    "spezifizierend": "spezifizieren",
    "spezifizierende": "spezifizierend",
    "spezifizierendem": "spezifizierend",
    "spezifizierenden": "spezifizierend",
    "spezifizierender": "spezifizierend",
    "spezifizierendes": "spezifizierend",
    "spezifizierest": "spezifizieren",
    "spezifizieret": "spezifizieren",
    "spezifizierst": "spezifizieren",
    "spezifiziert": "spezifizieren",
    "spezifizierte": "spezifizieren",
    "spezifiziertem": "spezifiziert",
    "spezifizierten": "spezifizieren",
    "spezifizierter": "spezifiziert",
    "spezifiziertes": "spezifiziert",
    "spezifiziertest": "spezifizieren",
    "spezifiziertet": "spezifizieren",
    "sphärischem": "sphärisch",
    "sphärischen": "sphärisch",
    "sphärischer": "sphärisch",
    "sphärisches": "sphärisch",
    "spicke": "spicken",
    "spickend": "spicken",
    "spickende": "spickend",
    "spickendem": "spickend",
    "spickenden": "spickend",
    "spickender": "spickend",
    "spickendes": "spickend",
    "spickest": "spicken",
    "spicket": "spicken",
    "spickst": "spicken",
    "spickt": "spicken",
    "spickte": "spicken",
    "spickten": "spicken",
    "spicktest": "spicken",
    "spicktet": "spicken",
    "spie": "speien",
    "spiee": "speien",
    "spieen": "speien",
    "spieest": "speien",
    "spieet": "speien",
    "spiegelbildlichem": "spiegelbildlich",
    "spiegelbildlichen": "spiegelbildlich",
    "spiegelbildlicher": "spiegelbildlich",
    "spiegelbildliches": "spiegelbildlich",
    "spiegelblanke": "spiegelblank",
    "spiegelblankem": "spiegelblank",
    "spiegelblanken": "spiegelblank",
    "spiegelblanker": "spiegelblank",
    "spiegelblankes": "spiegelblank",
    "spiegele": "spiegeln",
    "spiegelglatte": "spiegelglatt",
    "spiegelglattem": "spiegelglatt",
    "spiegelglatten": "spiegelglatt",
    "spiegelglatter": "spiegelglatt",
    "spiegelglattes": "spiegelglatt",
    "spiegelnd": "spiegeln",
    "spiegelnde": "spiegelnd",
    "spiegelndem": "spiegelnd",
    "spiegelnden": "spiegelnd",
    "spiegelnder": "spiegelnd",
    "spiegelndere": "spiegelnd",
    "spiegelnderem": "spiegelnd",
    "spiegelnderen": "spiegelnd",
    "spiegelnderer": "spiegelnd",
    "spiegelnderes": "spiegelnd",
    "spiegelndes": "spiegelnd",
    "spiegelndste": "spiegelnd",
    "spiegelndstem": "spiegelnd",
    "spiegelndsten": "spiegelnd",
    "spiegelndster": "spiegelnd",
    "spiegelndstes": "spiegelnd",
    "spiegelst": "spiegeln",
    "spiegelt": "spiegeln",
    "spiegelte": "spiegeln",
    "spiegelten": "spiegeln",
    "spiegeltest": "spiegeln",
    "spiegeltet": "spiegeln",
    "spiegle": "spiegeln",
    "spielend": "spielen",
    "spielende": "spielend",
    "spielendem": "spielend",
    "spielenden": "spielend",
    "spielender": "spielend",
    "spielendes": "spielend",
    "spielerischem": "spielerisch",
    "spielerischen": "spielerisch",
    "spielerischer": "spielerisch",
    "spielerischere": "spielerisch",
    "spielerischerem": "spielerisch",
    "spielerischeren": "spielerisch",
    "spielerischerer": "spielerisch",
    "spielerischeres": "spielerisch",
    "spielerisches": "spielerisch",
    "spielerischste": "spielerisch",
    "spielerischstem": "spielerisch",
    "spielerischsten": "spielerisch",
    "spielerischster": "spielerisch",
    "spielerischstes": "spielerisch",
    "spielest": "spielen",
    "spielet": "spielen",
    "spielfreie": "spielfrei",
    "spielfreiem": "spielfrei",
    "spielfreien": "spielfrei",
    "spielfreier": "spielfrei",
    "spielfreies": "spielfrei",
    "spielst": "spielen",
    "spielt": "spielen",
    "spielte": "spielen",
    "spielten": "spielen",
    "spieltest": "spielen",
    "spieltet": "spielen",
    "spien": "speien",
    "spiest": "speien",
    "spiet": "speien",
    "spießbürgerliche": "spießbürgerlich",
    "spießbürgerlichem": "spießbürgerlich",
    "spießbürgerlichen": "spießbürgerlich",
    "spießbürgerlicher": "spießbürgerlich",
    "spießbürgerlichere": "spießbürgerlich",
    "spießbürgerlicherem": "spießbürgerlich",
    "spießbürgerlicheren": "spießbürgerlich",
    "spießbürgerlicherer": "spießbürgerlich",
    "spießbürgerlicheres": "spießbürgerlich",
    "spießbürgerliches": "spießbürgerlich",
    "spießbürgerlichste": "spießbürgerlich",
    "spießbürgerlichstem": "spießbürgerlich",
    "spießbürgerlichsten": "spießbürgerlich",
    "spießbürgerlichster": "spießbürgerlich",
    "spießbürgerlichstes": "spießbürgerlich",
    "spieße": "spießen",
    "spießend": "spießen",
    "spießende": "spießend",
    "spießendem": "spießend",
    "spießenden": "spießend",
    "spießender": "spießend",
    "spießendes": "spießend",
    "spießest": "spießen",
    "spießet": "spießen",
    "spießige": "spießig",
    "spießigem": "spießig",
    "spießigen": "spießig",
    "spießiger": "spießig",
    "spießigere": "spießig",
    "spießigerem": "spießig",
    "spießigeren": "spießig",
    "spießigerer": "spießig",
    "spießigeres": "spießig",
    "spießiges": "spießig",
    "spießigste": "spießig",
    "spießigstem": "spießig",
    "spießigsten": "spießig",
    "spießigster": "spießig",
    "spießigstes": "spießig",
    "spießt": "spießen",
    "spießte": "spießen",
    "spießten": "spießen",
    "spießtest": "spießen",
    "spießtet": "spießen",
    "spindeldürrem": "spindeldürr",
    "spindeldürren": "spindeldürr",
    "spindeldürrer": "spindeldürr",
    "spindeldürrere": "spindeldürr",
    "spindeldürrerem": "spindeldürr",
    "spindeldürreren": "spindeldürr",
    "spindeldürrerer": "spindeldürr",
    "spindeldürreres": "spindeldürr",
    "spindeldürres": "spindeldürr",
    "spindeldürrste": "spindeldürr",
    "spindeldürrstem": "spindeldürr",
    "spindeldürrsten": "spindeldürr",
    "spindeldürrster": "spindeldürr",
    "spindeldürrstes": "spindeldürr",
    "spinnend": "spinnen",
    "spinnende": "spinnend",
    "spinnendem": "spinnend",
    "spinnenden": "spinnend",
    "spinnender": "spinnend",
    "spinnendes": "spinnend",
    "spinnest": "spinnen",
    "spinnet": "spinnen",
    "spinnst": "spinnen",
    "spinnt": "spinnen",
    "spioniere": "spionieren",
    "spionierend": "spionieren",
    "spionierende": "spionierend",
    "spionierendem": "spionierend",
    "spionierenden": "spionierend",
    "spionierender": "spionierend",
    "spionierendere": "spionierend",
    "spionierenderem": "spionierend",
    "spionierenderen": "spionierend",
    "spionierenderer": "spionierend",
    "spionierenderes": "spionierend",
    "spionierendes": "spionierend",
    "spionierendste": "spionierend",
    "spionierendstem": "spionierend",
    "spionierendsten": "spionierend",
    "spionierendster": "spionierend",
    "spionierendstes": "spionierend",
    "spionierest": "spionieren",
    "spionieret": "spionieren",
    "spionierst": "spionieren",
    "spioniert": "spionieren",
    "spionierte": "spionieren",
    "spioniertem": "spioniert",
    "spionierten": "spionieren",
    "spionierter": "spioniert",
    "spioniertes": "spioniert",
    "spioniertest": "spionieren",
    "spioniertet": "spionieren",
    "spiraligem": "spiralig",
    "spiraligen": "spiralig",
    "spiraliger": "spiralig",
    "spiraliges": "spiralig",
    "spiritistischem": "spiritistisch",
    "spiritistischen": "spiritistisch",
    "spiritistischer": "spiritistisch",
    "spiritistisches": "spiritistisch",
    "spirituale": "spiritual",
    "spiritualem": "spiritual",
    "spiritualen": "spiritual",
    "spiritualer": "spiritual",
    "spirituales": "spiritual",
    "spirituelle": "spirituell",
    "spirituellem": "spirituell",
    "spirituellen": "spirituell",
    "spiritueller": "spirituell",
    "spirituelles": "spirituell",
    "spitz": "spitzen",
    "spitzbekam": "spitzbekommen",
    "spitzbekamen": "spitzbekommen",
    "spitzbekamst": "spitzbekommen",
    "spitzbekamt": "spitzbekommen",
    "spitzbekomme": "spitzbekommen",
    "spitzbekommend": "spitzbekommen",
    "spitzbekommende": "spitzbekommend",
    "spitzbekommendem": "spitzbekommend",
    "spitzbekommenden": "spitzbekommend",
    "spitzbekommender": "spitzbekommend",
    "spitzbekommendes": "spitzbekommend",
    "spitzbekommene": "spitzbekommen",
    "spitzbekommenem": "spitzbekommen",
    "spitzbekommenen": "spitzbekommen",
    "spitzbekommener": "spitzbekommen",
    "spitzbekommenes": "spitzbekommen",
    "spitzbekommest": "spitzbekommen",
    "spitzbekommet": "spitzbekommen",
    "spitzbekommst": "spitzbekommen",
    "spitzbekommt": "spitzbekommen",
    "spitzbekäme": "spitzbekommen",
    "spitzbekämen": "spitzbekommen",
    "spitzbekämest": "spitzbekommen",
    "spitzbekämet": "spitzbekommen",
    "spitzbogigem": "spitzbogig",
    "spitzbogigen": "spitzbogig",
    "spitzbogiger": "spitzbogig",
    "spitzbogiges": "spitzbogig",
    "spitzbübischem": "spitzbübisch",
    "spitzbübischen": "spitzbübisch",
    "spitzbübischer": "spitzbübisch",
    "spitzbübischere": "spitzbübisch",
    "spitzbübischerem": "spitzbübisch",
    "spitzbübischeren": "spitzbübisch",
    "spitzbübischerer": "spitzbübisch",
    "spitzbübischeres": "spitzbübisch",
    "spitzbübisches": "spitzbübisch",
    "spitzbübischste": "spitzbübisch",
    "spitzbübischstem": "spitzbübisch",
    "spitzbübischsten": "spitzbübisch",
    "spitzbübischster": "spitzbübisch",
    "spitzbübischstes": "spitzbübisch",
    "spitze": "spitz",
    "spitzele": "spitzeln",
    "spitzelnd": "spitzeln",
    "spitzelnde": "spitzelnd",
    "spitzelndem": "spitzelnd",
    "spitzelnden": "spitzelnd",
    "spitzelnder": "spitzelnd",
    "spitzelndes": "spitzelnd",
    "spitzelst": "spitzeln",
    "spitzelt": "spitzeln",
    "spitzelte": "spitzeln",
    "spitzelten": "spitzeln",
    "spitzeltest": "spitzeln",
    "spitzeltet": "spitzeln",
    "spitzem": "spitz",
    "spitzen": "spitz",
    "spitzend": "spitzen",
    "spitzende": "spitzend",
    "spitzendem": "spitzend",
    "spitzenden": "spitzend",
    "spitzender": "spitzend",
    "spitzendere": "spitzend",
    "spitzenderem": "spitzend",
    "spitzenderen": "spitzend",
    "spitzenderer": "spitzend",
    "spitzenderes": "spitzend",
    "spitzendes": "spitzend",
    "spitzendste": "spitzend",
    "spitzendstem": "spitzend",
    "spitzendsten": "spitzend",
    "spitzendster": "spitzend",
    "spitzendstes": "spitzend",
    "spitzenmäßige": "spitzenmäßig",
    "spitzenmäßigem": "spitzenmäßig",
    "spitzenmäßigen": "spitzenmäßig",
    "spitzenmäßiger": "spitzenmäßig",
    "spitzenmäßiges": "spitzenmäßig",
    "spitzere": "spitz",
    "spitzerem": "spitz",
    "spitzeren": "spitz",
    "spitzerer": "spitz",
    "spitzeres": "spitz",
    "spitzes": "spitz",
    "spitzest": "spitzen",
    "spitzeste": "spitz",
    "spitzestem": "spitz",
    "spitzesten": "spitz",
    "spitzester": "spitz",
    "spitzestes": "spitz",
    "spitzet": "spitzen",
    "spitzfindigem": "spitzfindig",
    "spitzfindigen": "spitzfindig",
    "spitzfindiger": "spitzfindig",
    "spitzfindigere": "spitzfindig",
    "spitzfindigerem": "spitzfindig",
    "spitzfindigeren": "spitzfindig",
    "spitzfindigerer": "spitzfindig",
    "spitzfindigeres": "spitzfindig",
    "spitzfindiges": "spitzfindig",
    "spitzfindigstem": "spitzfindig",
    "spitzfindigsten": "spitzfindig",
    "spitzfindigster": "spitzfindig",
    "spitzfindigstes": "spitzfindig",
    "spitzgekriegt": "spitzkriegen",
    "spitzgekriegte": "spitzgekriegt",
    "spitzgekriegtem": "spitzgekriegt",
    "spitzgekriegten": "spitzgekriegt",
    "spitzgekriegter": "spitzgekriegt",
    "spitzgekriegtes": "spitzgekriegt",
    "spitzkriege": "spitzkriegen",
    "spitzkriegend": "spitzkriegen",
    "spitzkriegende": "spitzkriegend",
    "spitzkriegendem": "spitzkriegend",
    "spitzkriegenden": "spitzkriegend",
    "spitzkriegender": "spitzkriegend",
    "spitzkriegendes": "spitzkriegend",
    "spitzkriegest": "spitzkriegen",
    "spitzkrieget": "spitzkriegen",
    "spitzkriegst": "spitzkriegen",
    "spitzkriegt": "spitzkriegen",
    "spitzkriegte": "spitzkriegen",
    "spitzkriegten": "spitzkriegen",
    "spitzkriegtest": "spitzkriegen",
    "spitzkriegtet": "spitzkriegen",
    "spitzle": "spitzeln",
    "spitzt": "spitzen",
    "spitzte": "spitzen",
    "spitzten": "spitzen",
    "spitztest": "spitzen",
    "spitztet": "spitzen",
    "spitzzubekommen": "spitzbekommen",
    "spitzzukriegen": "spitzkriegen",
    "spleiße": "spleißen",
    "spleißend": "spleißen",
    "spleißende": "spleißend",
    "spleißendem": "spleißend",
    "spleißenden": "spleißend",
    "spleißender": "spleißend",
    "spleißendes": "spleißend",
    "spleißest": "spleißen",
    "spleißet": "spleißen",
    "spleißt": "spleißen",
    "splisse": "spleißen",
    "splissen": "spleißen",
    "splissest": "spleißen",
    "splisset": "spleißen",
    "splittere": "splittern",
    "splitterfasernackte": "splitterfasernackt",
    "splitterfasernacktem": "splitterfasernackt",
    "splitterfasernackten": "splitterfasernackt",
    "splitterfasernackter": "splitterfasernackt",
    "splitterfasernacktes": "splitterfasernackt",
    "splitterfreie": "splitterfrei",
    "splitterfreiem": "splitterfrei",
    "splitterfreien": "splitterfrei",
    "splitterfreier": "splitterfrei",
    "splitterfreies": "splitterfrei",
    "splitternackte": "splitternackt",
    "splitternacktem": "splitternackt",
    "splitternackten": "splitternackt",
    "splitternackter": "splitternackt",
    "splitternacktes": "splitternackt",
    "splitternd": "splittern",
    "splitternde": "splitternd",
    "splitterndem": "splitternd",
    "splitternden": "splitternd",
    "splitternder": "splitternd",
    "splitterndere": "splitternd",
    "splitternderem": "splitternd",
    "splitternderen": "splitternd",
    "splitternderer": "splitternd",
    "splitternderes": "splitternd",
    "splitterndes": "splitternd",
    "splitterndste": "splitternd",
    "splitterndstem": "splitternd",
    "splitterndsten": "splitternd",
    "splitterndster": "splitternd",
    "splitterndstes": "splitternd",
    "splitterst": "splittern",
    "splittert": "splittern",
    "splitterte": "splittern",
    "splitterten": "splittern",
    "splittertest": "splittern",
    "splittertet": "splittern",
    "spliß": "spleißen",
    "splißt": "spleißen",
    "sponsere": "sponsern",
    "sponsernd": "sponsern",
    "sponsernde": "sponsernd",
    "sponserndem": "sponsernd",
    "sponsernden": "sponsernd",
    "sponsernder": "sponsernd",
    "sponserndere": "sponsernd",
    "sponsernderem": "sponsernd",
    "sponsernderen": "sponsernd",
    "sponsernderer": "sponsernd",
    "sponsernderes": "sponsernd",
    "sponserndes": "sponsernd",
    "sponserndste": "sponsernd",
    "sponserndstem": "sponsernd",
    "sponserndsten": "sponsernd",
    "sponserndster": "sponsernd",
    "sponserndstes": "sponsernd",
    "sponserst": "sponsern",
    "sponsert": "sponsern",
    "sponserte": "sponsern",
    "sponserten": "sponsern",
    "sponsertest": "sponsern",
    "sponsertet": "sponsern",
    "spontanem": "spontan",
    "spontanen": "spontan",
    "spontaner": "spontan",
    "spontanere": "spontan",
    "spontanerem": "spontan",
    "spontaneren": "spontan",
    "spontanerer": "spontan",
    "spontaneres": "spontan",
    "spontanes": "spontan",
    "spontanste": "spontan",
    "spontanstem": "spontan",
    "spontansten": "spontan",
    "spontanster": "spontan",
    "spontanstes": "spontan",
    "sporadische": "sporadisch",
    "sporadischem": "sporadisch",
    "sporadischen": "sporadisch",
    "sporadischer": "sporadisch",
    "sporadisches": "sporadisch",
    "sporne": "spornen",
    "spornend": "spornen",
    "spornende": "spornend",
    "spornendem": "spornend",
    "spornenden": "spornend",
    "spornender": "spornend",
    "spornendes": "spornend",
    "spornest": "spornen",
    "spornet": "spornen",
    "spornst": "spornen",
    "spornt": "spornen",
    "spornte": "spornen",
    "spornten": "spornen",
    "sporntest": "spornen",
    "sporntet": "spornen",
    "sportivem": "sportiv",
    "sportiven": "sportiv",
    "sportiver": "sportiv",
    "sportivere": "sportiv",
    "sportiverem": "sportiv",
    "sportiveren": "sportiv",
    "sportiverer": "sportiv",
    "sportiveres": "sportiv",
    "sportives": "sportiv",
    "sportivste": "sportiv",
    "sportivstem": "sportiv",
    "sportivsten": "sportiv",
    "sportivster": "sportiv",
    "sportivstes": "sportiv",
    "sportlichem": "sportlich",
    "sportlichen": "sportlich",
    "sportlicher": "sportlich",
    "sportlichere": "sportlich",
    "sportlicherem": "sportlich",
    "sportlicheren": "sportlich",
    "sportlicherer": "sportlich",
    "sportlicheres": "sportlich",
    "sportliches": "sportlich",
    "sportlichste": "sportlich",
    "sportlichstem": "sportlich",
    "sportlichsten": "sportlich",
    "sportlichster": "sportlich",
    "sportlichstes": "sportlich",
    "spottbilligem": "spottbillig",
    "spottbilligen": "spottbillig",
    "spottbilliger": "spottbillig",
    "spottbilliges": "spottbillig",
    "spotte": "spotten",
    "spottend": "spotten",
    "spottende": "spottend",
    "spottendem": "spottend",
    "spottenden": "spottend",
    "spottender": "spottend",
    "spottendere": "spottend",
    "spottenderem": "spottend",
    "spottenderen": "spottend",
    "spottenderer": "spottend",
    "spottenderes": "spottend",
    "spottendes": "spottend",
    "spottendste": "spottend",
    "spottendstem": "spottend",
    "spottendsten": "spottend",
    "spottendster": "spottend",
    "spottendstes": "spottend",
    "spottest": "spotten",
    "spottet": "spotten",
    "spottete": "spotten",
    "spotteten": "spotten",
    "spottetest": "spotten",
    "spottetet": "spotten",
    "sprach": "sprechen",
    "sprachgewandte": "sprachgewandt",
    "sprachgewandtem": "sprachgewandt",
    "sprachgewandten": "sprachgewandt",
    "sprachgewandter": "sprachgewandt",
    "sprachgewandtere": "sprachgewandt",
    "sprachgewandterem": "sprachgewandt",
    "sprachgewandteren": "sprachgewandt",
    "sprachgewandterer": "sprachgewandt",
    "sprachgewandteres": "sprachgewandt",
    "sprachgewandtes": "sprachgewandt",
    "sprachgewandteste": "sprachgewandt",
    "sprachgewandtestem": "sprachgewandt",
    "sprachgewandtesten": "sprachgewandt",
    "sprachgewandtester": "sprachgewandt",
    "sprachgewandtestes": "sprachgewandt",
    "sprachlichem": "sprachlich",
    "sprachlichen": "sprachlich",
    "sprachlicher": "sprachlich",
    "sprachliches": "sprachlich",
    "sprachlose": "sprachlos",
    "sprachlosem": "sprachlos",
    "sprachlosen": "sprachlos",
    "sprachloser": "sprachlos",
    "sprachlosere": "sprachlos",
    "sprachloserem": "sprachlos",
    "sprachloseren": "sprachlos",
    "sprachloserer": "sprachlos",
    "sprachloseres": "sprachlos",
    "sprachloses": "sprachlos",
    "sprachloseste": "sprachlos",
    "sprachlosestem": "sprachlos",
    "sprachlosesten": "sprachlos",
    "sprachlosester": "sprachlos",
    "sprachlosestes": "sprachlos",
    "sprachst": "sprechen",
    "spracht": "sprechen",
    "sprachunbegabte": "sprachunbegabt",
    "sprachunbegabtem": "sprachunbegabt",
    "sprachunbegabten": "sprachunbegabt",
    "sprachunbegabter": "sprachunbegabt",
    "sprachunbegabtere": "sprachunbegabt",
    "sprachunbegabterem": "sprachunbegabt",
    "sprachunbegabteren": "sprachunbegabt",
    "sprachunbegabterer": "sprachunbegabt",
    "sprachunbegabteres": "sprachunbegabt",
    "sprachunbegabtes": "sprachunbegabt",
    "sprachunbegabteste": "sprachunbegabt",
    "sprachunbegabtestem": "sprachunbegabt",
    "sprachunbegabtesten": "sprachunbegabt",
    "sprachunbegabtester": "sprachunbegabt",
    "sprachunbegabtestes": "sprachunbegabt",
    "sprang": "springen",
    "sprangen": "springen",
    "sprangst": "springen",
    "sprangt": "springen",
    "spreche": "sprechen",
    "sprechend": "sprechen",
    "sprechende": "sprechend",
    "sprechendem": "sprechend",
    "sprechenden": "sprechend",
    "sprechender": "sprechend",
    "sprechendere": "sprechend",
    "sprechenderem": "sprechend",
    "sprechenderen": "sprechend",
    "sprechenderer": "sprechend",
    "sprechenderes": "sprechend",
    "sprechendes": "sprechend",
    "sprechendste": "sprechend",
    "sprechendstem": "sprechend",
    "sprechendsten": "sprechend",
    "sprechendster": "sprechend",
    "sprechendstes": "sprechend",
    "sprechest": "sprechen",
    "sprechet": "sprechen",
    "sprecht": "sprechen",
    "spreize": "spreizen",
    "spreizend": "spreizen",
    "spreizende": "spreizend",
    "spreizendem": "spreizend",
    "spreizenden": "spreizend",
    "spreizender": "spreizend",
    "spreizendes": "spreizend",
    "spreizest": "spreizen",
    "spreizet": "spreizen",
    "spreizt": "spreizen",
    "spreizte": "spreizen",
    "spreizten": "spreizen",
    "spreiztest": "spreizen",
    "spreiztet": "spreizen",
    "sprenge": "sprengen",
    "sprengend": "sprengen",
    "sprengende": "sprengend",
    "sprengendem": "sprengend",
    "sprengenden": "sprengend",
    "sprengender": "sprengend",
    "sprengendes": "sprengend",
    "sprengest": "sprengen",
    "sprenget": "sprengen",
    "sprengst": "sprengen",
    "sprengt": "sprengen",
    "sprengte": "sprengen",
    "sprengten": "sprengen",
    "sprengtest": "sprengen",
    "sprengtet": "sprengen",
    "sprenkele": "sprenkeln",
    "sprenkelnd": "sprenkeln",
    "sprenkelnde": "sprenkelnd",
    "sprenkelndem": "sprenkelnd",
    "sprenkelnden": "sprenkelnd",
    "sprenkelnder": "sprenkelnd",
    "sprenkelndere": "sprenkelnd",
    "sprenkelnderem": "sprenkelnd",
    "sprenkelnderen": "sprenkelnd",
    "sprenkelnderer": "sprenkelnd",
    "sprenkelnderes": "sprenkelnd",
    "sprenkelndes": "sprenkelnd",
    "sprenkelndste": "sprenkelnd",
    "sprenkelndstem": "sprenkelnd",
    "sprenkelndsten": "sprenkelnd",
    "sprenkelndster": "sprenkelnd",
    "sprenkelndstes": "sprenkelnd",
    "sprenkelst": "sprenkeln",
    "sprenkelt": "sprenkeln",
    "sprenkelte": "sprenkeln",
    "sprenkelten": "sprenkeln",
    "sprenkeltest": "sprenkeln",
    "sprenkeltet": "sprenkeln",
    "sprenkle": "sprenkeln",
    "sprich": "sprechen",
    "sprichst": "sprechen",
    "spricht": "sprechen",
    "sprichwörtlichem": "sprichwörtlich",
    "sprichwörtlichen": "sprichwörtlich",
    "sprichwörtlicher": "sprichwörtlich",
    "sprichwörtliches": "sprichwörtlich",
    "sprieße": "sprießen",
    "sprießend": "sprießen",
    "sprießende": "sprießend",
    "sprießendem": "sprießend",
    "sprießenden": "sprießend",
    "sprießender": "sprießend",
    "sprießendere": "sprießend",
    "sprießenderem": "sprießend",
    "sprießenderen": "sprießend",
    "sprießenderer": "sprießend",
    "sprießenderes": "sprießend",
    "sprießendes": "sprießend",
    "sprießendste": "sprießend",
    "sprießendstem": "sprießend",
    "sprießendsten": "sprießend",
    "sprießendster": "sprießend",
    "sprießendstes": "sprießend",
    "sprießest": "sprießen",
    "sprießet": "sprießen",
    "sprießt": "sprießen",
    "springe": "springen",
    "springend": "springen",
    "springende": "springend",
    "springendem": "springend",
    "springenden": "springend",
    "springender": "springend",
    "springendes": "springend",
    "springest": "springen",
    "springet": "springen",
    "springst": "springen",
    "springt": "springen",
    "sprintend": "sprinten",
    "sprintende": "sprintend",
    "sprintendem": "sprintend",
    "sprintenden": "sprintend",
    "sprintender": "sprintend",
    "sprintendere": "sprintend",
    "sprintenderem": "sprintend",
    "sprintenderen": "sprintend",
    "sprintenderer": "sprintend",
    "sprintenderes": "sprintend",
    "sprintendes": "sprintend",
    "sprintendste": "sprintend",
    "sprintendstem": "sprintend",
    "sprintendsten": "sprintend",
    "sprintendster": "sprintend",
    "sprintendstes": "sprintend",
    "sprintest": "sprinten",
    "sprintet": "sprinten",
    "sprintete": "sprinten",
    "sprinteten": "sprinten",
    "sprintetest": "sprinten",
    "sprintetet": "sprinten",
    "spritzend": "spritzen",
    "spritzende": "spritzend",
    "spritzendem": "spritzend",
    "spritzenden": "spritzend",
    "spritzender": "spritzend",
    "spritzendere": "spritzend",
    "spritzenderem": "spritzend",
    "spritzenderen": "spritzend",
    "spritzenderer": "spritzend",
    "spritzenderes": "spritzend",
    "spritzendes": "spritzend",
    "spritzendste": "spritzend",
    "spritzendstem": "spritzend",
    "spritzendsten": "spritzend",
    "spritzendster": "spritzend",
    "spritzendstes": "spritzend",
    "spritzest": "spritzen",
    "spritzet": "spritzen",
    "spritzigem": "spritzig",
    "spritzigen": "spritzig",
    "spritziger": "spritzig",
    "spritzigere": "spritzig",
    "spritzigerem": "spritzig",
    "spritzigeren": "spritzig",
    "spritzigerer": "spritzig",
    "spritzigeres": "spritzig",
    "spritziges": "spritzig",
    "spritzigste": "spritzig",
    "spritzigstem": "spritzig",
    "spritzigsten": "spritzig",
    "spritzigster": "spritzig",
    "spritzigstes": "spritzig",
    "spritzt": "spritzen",
    "spritzte": "spritzen",
    "spritzten": "spritzen",
    "spritztest": "spritzen",
    "spritztet": "spritzen",
    "sprossen": "sprießen",
    "sproß": "sprießen",
    "sproßt": "sprießen",
    "spruchreifem": "spruchreif",
    "spruchreifen": "spruchreif",
    "spruchreifer": "spruchreif",
    "spruchreifes": "spruchreif",
    "sprudele": "sprudeln",
    "sprudelnd": "sprudeln",
    "sprudelnde": "sprudelnd",
    "sprudelndem": "sprudelnd",
    "sprudelnden": "sprudelnd",
    "sprudelnder": "sprudelnd",
    "sprudelndere": "sprudelnd",
    "sprudelnderem": "sprudelnd",
    "sprudelnderen": "sprudelnd",
    "sprudelnderer": "sprudelnd",
    "sprudelnderes": "sprudelnd",
    "sprudelndes": "sprudelnd",
    "sprudelndste": "sprudelnd",
    "sprudelndstem": "sprudelnd",
    "sprudelndsten": "sprudelnd",
    "sprudelndster": "sprudelnd",
    "sprudelndstes": "sprudelnd",
    "sprudelst": "sprudeln",
    "sprudelt": "sprudeln",
    "sprudelte": "sprudeln",
    "sprudelten": "sprudeln",
    "sprudeltest": "sprudeln",
    "sprudeltet": "sprudeln",
    "sprudle": "sprudeln",
    "sprungbereitem": "sprungbereit",
    "sprungbereiten": "sprungbereit",
    "sprungbereiter": "sprungbereit",
    "sprungbereitere": "sprungbereit",
    "sprungbereiterem": "sprungbereit",
    "sprungbereiteren": "sprungbereit",
    "sprungbereiterer": "sprungbereit",
    "sprungbereiteres": "sprungbereit",
    "sprungbereites": "sprungbereit",
    "sprungbereiteste": "sprungbereit",
    "sprungbereitestem": "sprungbereit",
    "sprungbereitesten": "sprungbereit",
    "sprungbereitester": "sprungbereit",
    "sprungbereitestes": "sprungbereit",
    "sprunghaftem": "sprunghaft",
    "sprunghaften": "sprunghaft",
    "sprunghafter": "sprunghaft",
    "sprunghaftere": "sprunghaft",
    "sprunghafterem": "sprunghaft",
    "sprunghafteren": "sprunghaft",
    "sprunghafterer": "sprunghaft",
    "sprunghafteres": "sprunghaft",
    "sprunghaftes": "sprunghaft",
    "sprunghafteste": "sprunghaft",
    "sprunghaftestem": "sprunghaft",
    "sprunghaftesten": "sprunghaft",
    "sprunghaftester": "sprunghaft",
    "sprunghaftestes": "sprunghaft",
    "spräche": "sprechen",
    "sprächen": "sprechen",
    "sprächest": "sprechen",
    "sprächet": "sprechen",
    "spränge": "springen",
    "sprängen": "springen",
    "sprängest": "springen",
    "spränget": "springen",
    "sprödem": "spröde",
    "spröden": "spröde",
    "spröder": "spröde",
    "sprödere": "spröde",
    "spröderem": "spröde",
    "spröderen": "spröde",
    "spröderer": "spröde",
    "spröderes": "spröde",
    "sprödes": "spröde",
    "sprödeste": "spröde",
    "sprödestem": "spröde",
    "sprödesten": "spröde",
    "sprödester": "spröde",
    "sprödestes": "spröde",
    "sprösse": "sprießen",
    "sprössen": "sprießen",
    "sprössest": "sprießen",
    "sprösset": "sprießen",
    "sprühe": "sprühen",
    "sprühend": "sprühen",
    "sprühende": "sprühend",
    "sprühendem": "sprühend",
    "sprühenden": "sprühend",
    "sprühender": "sprühend",
    "sprühendes": "sprühend",
    "sprühest": "sprühen",
    "sprühet": "sprühen",
    "sprühst": "sprühen",
    "sprüht": "sprühen",
    "sprühte": "sprühen",
    "sprühten": "sprühen",
    "sprühtest": "sprühen",
    "sprühtet": "sprühen",
    "spucke": "spucken",
    "spuckend": "spucken",
    "spuckende": "spuckend",
    "spuckendem": "spuckend",
    "spuckenden": "spuckend",
    "spuckender": "spuckend",
    "spuckendere": "spuckend",
    "spuckenderem": "spuckend",
    "spuckenderen": "spuckend",
    "spuckenderer": "spuckend",
    "spuckenderes": "spuckend",
    "spuckendes": "spuckend",
    "spuckendste": "spuckend",
    "spuckendstem": "spuckend",
    "spuckendsten": "spuckend",
    "spuckendster": "spuckend",
    "spuckendstes": "spuckend",
    "spuckest": "spucken",
    "spucket": "spucken",
    "spuckst": "spucken",
    "spuckt": "spucken",
    "spuckte": "spucken",
    "spuckten": "spucken",
    "spucktest": "spucken",
    "spucktet": "spucken",
    "spuke": "spuken",
    "spukend": "spuken",
    "spukende": "spukend",
    "spukendem": "spukend",
    "spukenden": "spukend",
    "spukender": "spukend",
    "spukendere": "spukend",
    "spukenderem": "spukend",
    "spukenderen": "spukend",
    "spukenderer": "spukend",
    "spukenderes": "spukend",
    "spukendes": "spukend",
    "spukendste": "spukend",
    "spukendstem": "spukend",
    "spukendsten": "spukend",
    "spukendster": "spukend",
    "spukendstes": "spukend",
    "spukest": "spuken",
    "spuket": "spuken",
    "spukhaftem": "spukhaft",
    "spukhaften": "spukhaft",
    "spukhafter": "spukhaft",
    "spukhaftere": "spukhaft",
    "spukhafterem": "spukhaft",
    "spukhafteren": "spukhaft",
    "spukhafterer": "spukhaft",
    "spukhafteres": "spukhaft",
    "spukhaftes": "spukhaft",
    "spukhafteste": "spukhaft",
    "spukhaftestem": "spukhaft",
    "spukhaftesten": "spukhaft",
    "spukhaftester": "spukhaft",
    "spukhaftestes": "spukhaft",
    "spukst": "spuken",
    "spukt": "spuken",
    "spukte": "spuken",
    "spukten": "spuken",
    "spuktest": "spuken",
    "spuktet": "spuken",
    "spule": "spulen",
    "spulend": "spulen",
    "spulende": "spulend",
    "spulendem": "spulend",
    "spulenden": "spulend",
    "spulender": "spulend",
    "spulendes": "spulend",
    "spulest": "spulen",
    "spulet": "spulen",
    "spulst": "spulen",
    "spult": "spulen",
    "spulte": "spulen",
    "spulten": "spulen",
    "spultest": "spulen",
    "spultet": "spulen",
    "spure": "spuren",
    "spurend": "spuren",
    "spurende": "spurend",
    "spurendem": "spurend",
    "spurenden": "spurend",
    "spurender": "spurend",
    "spurendere": "spurend",
    "spurenderem": "spurend",
    "spurenderen": "spurend",
    "spurenderer": "spurend",
    "spurenderes": "spurend",
    "spurendes": "spurend",
    "spurendste": "spurend",
    "spurendstem": "spurend",
    "spurendsten": "spurend",
    "spurendster": "spurend",
    "spurendstes": "spurend",
    "spurest": "spuren",
    "spuret": "spuren",
    "spurlose": "spurlos",
    "spurlosem": "spurlos",
    "spurlosen": "spurlos",
    "spurloser": "spurlos",
    "spurloses": "spurlos",
    "spurst": "spuren",
    "spurt": "spuren",
    "spurte": "spurten",
    "spurten": "spuren",
    "spurtend": "spurten",
    "spurtende": "spurtend",
    "spurtendem": "spurtend",
    "spurtenden": "spurtend",
    "spurtender": "spurtend",
    "spurtendere": "spurtend",
    "spurtenderem": "spurtend",
    "spurtenderen": "spurtend",
    "spurtenderer": "spurtend",
    "spurtenderes": "spurtend",
    "spurtendes": "spurtend",
    "spurtendste": "spurtend",
    "spurtendstem": "spurtend",
    "spurtendsten": "spurtend",
    "spurtendster": "spurtend",
    "spurtendstes": "spurtend",
    "spurtest": "spurten",
    "spurtet": "spurten",
    "spurtete": "spurten",
    "spurteten": "spurten",
    "spurtetest": "spurten",
    "spurtetet": "spurten",
    "spute": "sputen",
    "sputend": "sputen",
    "sputende": "sputend",
    "sputendem": "sputend",
    "sputenden": "sputend",
    "sputender": "sputend",
    "sputendere": "sputend",
    "sputenderem": "sputend",
    "sputenderen": "sputend",
    "sputenderer": "sputend",
    "sputenderes": "sputend",
    "sputendes": "sputend",
    "sputendste": "sputend",
    "sputendstem": "sputend",
    "sputendsten": "sputend",
    "sputendster": "sputend",
    "sputendstes": "sputend",
    "sputest": "sputen",
    "sputet": "sputen",
    "sputete": "sputen",
    "sputeten": "sputen",
    "sputetest": "sputen",
    "sputetet": "sputen",
    "spähe": "spähen",
    "spähend": "spähen",
    "spähende": "spähend",
    "spähendem": "spähend",
    "spähenden": "spähend",
    "spähender": "spähend",
    "spähendes": "spähend",
    "spähest": "spähen",
    "spähet": "spähen",
    "spähst": "spähen",
    "späht": "spähen",
    "spähte": "spähen",
    "spähten": "spähen",
    "spähtest": "spähen",
    "spähtet": "spähen",
    "spänne": "spinnen",
    "spännen": "spinnen",
    "spännest": "spinnen",
    "spännet": "spinnen",
    "spärlichem": "spärlich",
    "spärlichen": "spärlich",
    "spärlicher": "spärlich",
    "spärlichere": "spärlich",
    "spärlicherem": "spärlich",
    "spärlicheren": "spärlich",
    "spärlicherer": "spärlich",
    "spärlicheres": "spärlich",
    "spärliches": "spärlich",
    "spärlichste": "spärlich",
    "spärlichstem": "spärlich",
    "spärlichsten": "spärlich",
    "spärlichster": "spärlich",
    "spärlichstes": "spärlich",
    "späte": "spät",
    "spätem": "spät",
    "späten": "spät",
    "später": "spät",
    "spätere": "spät",
    "späterem": "spät",
    "späteren": "spät",
    "späterer": "spät",
    "späteres": "spät",
    "spätes": "spät",
    "späteste": "spät",
    "spätestem": "spät",
    "spätesten": "spät",
    "spätester": "spät",
    "spätestes": "spät",
    "spätgotischem": "spätgotisch",
    "spätgotischen": "spätgotisch",
    "spätgotischer": "spätgotisch",
    "spätgotisches": "spätgotisch",
    "spöttische": "spöttisch",
    "spöttischem": "spöttisch",
    "spöttischen": "spöttisch",
    "spöttischer": "spöttisch",
    "spöttischere": "spöttisch",
    "spöttischerem": "spöttisch",
    "spöttischeren": "spöttisch",
    "spöttischerer": "spöttisch",
    "spöttischeres": "spöttisch",
    "spöttisches": "spöttisch",
    "spöttischste": "spöttisch",
    "spöttischstem": "spöttisch",
    "spöttischsten": "spöttisch",
    "spöttischster": "spöttisch",
    "spöttischstes": "spöttisch",
    "spülend": "spülen",
    "spülendem": "spülend",
    "spülender": "spülend",
    "spülendes": "spülend",
    "spülest": "spülen",
    "spület": "spülen",
    "spülmaschinenfestem": "spülmaschinenfest",
    "spülmaschinenfesten": "spülmaschinenfest",
    "spülmaschinenfester": "spülmaschinenfest",
    "spülmaschinenfestere": "spülmaschinenfest",
    "spülmaschinenfesterem": "spülmaschinenfest",
    "spülmaschinenfesteren": "spülmaschinenfest",
    "spülmaschinenfesterer": "spülmaschinenfest",
    "spülmaschinenfesteres": "spülmaschinenfest",
    "spülmaschinenfestes": "spülmaschinenfest",
    "spülmaschinenfesteste": "spülmaschinenfest",
    "spülmaschinenfestestem": "spülmaschinenfest",
    "spülmaschinenfestesten": "spülmaschinenfest",
    "spülmaschinenfestester": "spülmaschinenfest",
    "spülmaschinenfestestes": "spülmaschinenfest",
    "spülst": "spülen",
    "spült": "spülen",
    "spülte": "spülen",
    "spülten": "spülen",
    "spültest": "spülen",
    "spültet": "spülen",
    "spürbarem": "spürbar",
    "spürbaren": "spürbar",
    "spürbarer": "spürbar",
    "spürbarere": "spürbar",
    "spürbarerem": "spürbar",
    "spürbareren": "spürbar",
    "spürbarerer": "spürbar",
    "spürbareres": "spürbar",
    "spürbares": "spürbar",
    "spürbarste": "spürbar",
    "spürbarstem": "spürbar",
    "spürbarsten": "spürbar",
    "spürbarster": "spürbar",
    "spürbarstes": "spürbar",
    "spüre": "spüren",
    "spürend": "spüren",
    "spürendem": "spürend",
    "spürender": "spürend",
    "spürendes": "spürend",
    "spürest": "spüren",
    "spüret": "spüren",
    "spürst": "spüren",
    "spürt": "spüren",
    "spürte": "spüren",
    "spürten": "spüren",
    "spürtest": "spüren",
    "spürtet": "spüren",
    "staatenlosem": "staatenlos",
    "staatenlosen": "staatenlos",
    "staatenloser": "staatenlos",
    "staatenloses": "staatenlos",
    "staatlichem": "staatlich",
    "staatlichen": "staatlich",
    "staatlicher": "staatlich",
    "staatliches": "staatlich",
    "staatsbürgerlichem": "staatsbürgerlich",
    "staatsbürgerlichen": "staatsbürgerlich",
    "staatsbürgerlicher": "staatsbürgerlich",
    "staatsbürgerliches": "staatsbürgerlich",
    "staatseigene": "staatseigen",
    "staatseigenem": "staatseigen",
    "staatseigenen": "staatseigen",
    "staatseigener": "staatseigen",
    "staatseigenes": "staatseigen",
    "staatsfeindliche": "staatsfeindlich",
    "staatsfeindlichem": "staatsfeindlich",
    "staatsfeindlichen": "staatsfeindlich",
    "staatsfeindlicher": "staatsfeindlich",
    "staatsfeindliches": "staatsfeindlich",
    "staatsmännische": "staatsmännisch",
    "staatsmännischem": "staatsmännisch",
    "staatsmännischen": "staatsmännisch",
    "staatsmännischer": "staatsmännisch",
    "staatsmännisches": "staatsmännisch",
    "staatsrechtliche": "staatsrechtlich",
    "staatsrechtlichem": "staatsrechtlich",
    "staatsrechtlichen": "staatsrechtlich",
    "staatsrechtlicher": "staatsrechtlich",
    "staatsrechtliches": "staatsrechtlich",
    "stabilem": "stabil",
    "stabilen": "stabil",
    "stabiler": "stabil",
    "stabilere": "stabil",
    "stabilerem": "stabil",
    "stabileren": "stabil",
    "stabilerer": "stabil",
    "stabileres": "stabil",
    "stabiles": "stabil",
    "stabilisierend": "stabilisieren",
    "stabilisierende": "stabilisierend",
    "stabilisierendem": "stabilisierend",
    "stabilisierenden": "stabilisierend",
    "stabilisierender": "stabilisierend",
    "stabilisierendere": "stabilisierend",
    "stabilisierenderem": "stabilisierend",
    "stabilisierenderen": "stabilisierend",
    "stabilisierenderer": "stabilisierend",
    "stabilisierenderes": "stabilisierend",
    "stabilisierendes": "stabilisierend",
    "stabilisierendste": "stabilisierend",
    "stabilisierendstem": "stabilisierend",
    "stabilisierendsten": "stabilisierend",
    "stabilisierendster": "stabilisierend",
    "stabilisierendstes": "stabilisierend",
    "stabilisierest": "stabilisieren",
    "stabilisieret": "stabilisieren",
    "stabilisierst": "stabilisieren",
    "stabilisiert": "stabilisieren",
    "stabilisierte": "stabilisieren",
    "stabilisiertem": "stabilisiert",
    "stabilisierten": "stabilisieren",
    "stabilisierter": "stabilisiert",
    "stabilisiertere": "stabilisiert",
    "stabilisierterem": "stabilisiert",
    "stabilisierteren": "stabilisiert",
    "stabilisierterer": "stabilisiert",
    "stabilisierteres": "stabilisiert",
    "stabilisiertes": "stabilisiert",
    "stabilisiertest": "stabilisieren",
    "stabilisierteste": "stabilisiert",
    "stabilisiertestem": "stabilisiert",
    "stabilisiertesten": "stabilisiert",
    "stabilisiertester": "stabilisiert",
    "stabilisiertestes": "stabilisiert",
    "stabilisiertet": "stabilisieren",
    "stabilstem": "stabil",
    "stabilsten": "stabil",
    "stabilster": "stabil",
    "stabilstes": "stabil",
    "stach": "stechen",
    "stachele": "stacheln",
    "stachelige": "stachelig",
    "stacheligem": "stachelig",
    "stacheligen": "stachelig",
    "stacheliger": "stachelig",
    "stacheligere": "stachelig",
    "stacheligerem": "stachelig",
    "stacheligeren": "stachelig",
    "stacheligerer": "stachelig",
    "stacheligeres": "stachelig",
    "stacheliges": "stachelig",
    "stacheligste": "stachelig",
    "stacheligstem": "stachelig",
    "stacheligsten": "stachelig",
    "stacheligster": "stachelig",
    "stacheligstes": "stachelig",
    "stachelnd": "stacheln",
    "stachelnde": "stachelnd",
    "stachelndem": "stachelnd",
    "stachelnden": "stachelnd",
    "stachelnder": "stachelnd",
    "stachelndere": "stachelnd",
    "stachelnderem": "stachelnd",
    "stachelnderen": "stachelnd",
    "stachelnderer": "stachelnd",
    "stachelnderes": "stachelnd",
    "stachelndes": "stachelnd",
    "stachelndste": "stachelnd",
    "stachelndstem": "stachelnd",
    "stachelndsten": "stachelnd",
    "stachelndster": "stachelnd",
    "stachelndstes": "stachelnd",
    "stachelst": "stacheln",
    "stachelt": "stacheln",
    "stachelte": "stacheln",
    "stachelten": "stacheln",
    "stacheltest": "stacheln",
    "stacheltet": "stacheln",
    "stachen": "stechen",
    "stachle": "stacheln",
    "stachst": "stechen",
    "stacht": "stechen",
    "stadtbekanntem": "stadtbekannt",
    "stadtbekannten": "stadtbekannt",
    "stadtbekannter": "stadtbekannt",
    "stadtbekanntes": "stadtbekannt",
    "staffele": "staffeln",
    "staffelnd": "staffeln",
    "staffelnde": "staffelnd",
    "staffelndem": "staffelnd",
    "staffelnden": "staffelnd",
    "staffelnder": "staffelnd",
    "staffelndes": "staffelnd",
    "staffelst": "staffeln",
    "staffelt": "staffeln",
    "staffelte": "staffeln",
    "staffelten": "staffeln",
    "staffeltest": "staffeln",
    "staffeltet": "staffeln",
    "staffiere": "staffieren",
    "staffierend": "staffieren",
    "staffierende": "staffierend",
    "staffierendem": "staffierend",
    "staffierenden": "staffierend",
    "staffierender": "staffierend",
    "staffierendes": "staffierend",
    "staffierest": "staffieren",
    "staffieret": "staffieren",
    "staffierst": "staffieren",
    "staffiert": "staffieren",
    "staffierte": "staffieren",
    "staffiertem": "staffiert",
    "staffierten": "staffieren",
    "staffierter": "staffiert",
    "staffiertes": "staffiert",
    "staffiertest": "staffieren",
    "staffiertet": "staffieren",
    "staffle": "staffeln",
    "stagniere": "stagnieren",
    "stagnierend": "stagnieren",
    "stagnierende": "stagnierend",
    "stagnierendem": "stagnierend",
    "stagnierenden": "stagnierend",
    "stagnierender": "stagnierend",
    "stagnierendes": "stagnierend",
    "stagnierest": "stagnieren",
    "stagnieret": "stagnieren",
    "stagnierst": "stagnieren",
    "stagniert": "stagnieren",
    "stagnierte": "stagnieren",
    "stagniertem": "stagniert",
    "stagnierten": "stagnieren",
    "stagnierter": "stagniert",
    "stagniertes": "stagniert",
    "stagniertest": "stagnieren",
    "stagniertet": "stagnieren",
    "stahl": "stehlen",
    "stahlen": "stehlen",
    "stahlharte": "stahlhart",
    "stahlhartem": "stahlhart",
    "stahlharten": "stahlhart",
    "stahlharter": "stahlhart",
    "stahlhartes": "stahlhart",
    "stahlst": "stehlen",
    "stahlt": "stehlen",
    "staksige": "staksig",
    "staksigem": "staksig",
    "staksigen": "staksig",
    "staksiger": "staksig",
    "staksigere": "staksig",
    "staksigerem": "staksig",
    "staksigeren": "staksig",
    "staksigerer": "staksig",
    "staksigeres": "staksig",
    "staksiges": "staksig",
    "staksigste": "staksig",
    "staksigstem": "staksig",
    "staksigsten": "staksig",
    "staksigster": "staksig",
    "staksigstes": "staksig",
    "stalinistischem": "stalinistisch",
    "stalinistischen": "stalinistisch",
    "stalinistischer": "stalinistisch",
    "stalinistisches": "stalinistisch",
    "stammele": "stammeln",
    "stammelnd": "stammeln",
    "stammelnde": "stammelnd",
    "stammelndem": "stammelnd",
    "stammelnden": "stammelnd",
    "stammelnder": "stammelnd",
    "stammelndere": "stammelnd",
    "stammelnderem": "stammelnd",
    "stammelnderen": "stammelnd",
    "stammelnderer": "stammelnd",
    "stammelnderes": "stammelnd",
    "stammelndes": "stammelnd",
    "stammelndste": "stammelnd",
    "stammelndstem": "stammelnd",
    "stammelndsten": "stammelnd",
    "stammelndster": "stammelnd",
    "stammelndstes": "stammelnd",
    "stammelst": "stammeln",
    "stammelt": "stammeln",
    "stammelte": "stammeln",
    "stammelten": "stammeln",
    "stammeltest": "stammeln",
    "stammeltet": "stammeln",
    "stammend": "stammen",
    "stammende": "stammend",
    "stammendem": "stammend",
    "stammenden": "stammend",
    "stammender": "stammend",
    "stammendes": "stammend",
    "stammest": "stammen",
    "stammet": "stammen",
    "stammle": "stammeln",
    "stammst": "stammen",
    "stammt": "stammen",
    "stammte": "stammen",
    "stammten": "stammen",
    "stammtest": "stammen",
    "stammtet": "stammen",
    "stammverwandte": "stammverwandt",
    "stammverwandtem": "stammverwandt",
    "stammverwandten": "stammverwandt",
    "stammverwandter": "stammverwandt",
    "stammverwandtes": "stammverwandt",
    "stampfe": "stampfen",
    "stampfend": "stampfen",
    "stampfende": "stampfend",
    "stampfendem": "stampfend",
    "stampfenden": "stampfend",
    "stampfender": "stampfend",
    "stampfendere": "stampfend",
    "stampfenderem": "stampfend",
    "stampfenderen": "stampfend",
    "stampfenderer": "stampfend",
    "stampfenderes": "stampfend",
    "stampfendes": "stampfend",
    "stampfendste": "stampfend",
    "stampfendstem": "stampfend",
    "stampfendsten": "stampfend",
    "stampfendster": "stampfend",
    "stampfendstes": "stampfend",
    "stampfest": "stampfen",
    "stampfet": "stampfen",
    "stampfst": "stampfen",
    "stampft": "stampfen",
    "stampfte": "stampfen",
    "stampften": "stampfen",
    "stampftest": "stampfen",
    "stampftet": "stampfen",
    "stand": "stehen",
    "standardisiere": "standardisieren",
    "standardisierend": "standardisieren",
    "standardisierende": "standardisierend",
    "standardisierendem": "standardisierend",
    "standardisierenden": "standardisierend",
    "standardisierender": "standardisierend",
    "standardisierendes": "standardisierend",
    "standardisierest": "standardisieren",
    "standardisieret": "standardisieren",
    "standardisierst": "standardisieren",
    "standardisiert": "standardisieren",
    "standardisierte": "standardisieren",
    "standardisiertem": "standardisiert",
    "standardisierten": "standardisieren",
    "standardisierter": "standardisiert",
    "standardisiertere": "standardisiert",
    "standardisierterem": "standardisiert",
    "standardisierteren": "standardisiert",
    "standardisierterer": "standardisiert",
    "standardisierteres": "standardisiert",
    "standardisiertes": "standardisiert",
    "standardisiertest": "standardisieren",
    "standardisierteste": "standardisiert",
    "standardisiertestem": "standardisiert",
    "standardisiertesten": "standardisiert",
    "standardisiertester": "standardisiert",
    "standardisiertestes": "standardisiert",
    "standardisiertet": "standardisieren",
    "standen": "stehen",
    "standesamtlichem": "standesamtlich",
    "standesamtlichen": "standesamtlich",
    "standesamtlicher": "standesamtlich",
    "standesamtliches": "standesamtlich",
    "standesbewußte": "standesbewußt",
    "standesbewußtem": "standesbewußt",
    "standesbewußten": "standesbewußt",
    "standesbewußter": "standesbewußt",
    "standesbewußtere": "standesbewußt",
    "standesbewußterem": "standesbewußt",
    "standesbewußteren": "standesbewußt",
    "standesbewußterer": "standesbewußt",
    "standesbewußteres": "standesbewußt",
    "standesbewußtes": "standesbewußt",
    "standesbewußteste": "standesbewußt",
    "standesbewußtestem": "standesbewußt",
    "standesbewußtesten": "standesbewußt",
    "standesbewußtester": "standesbewußt",
    "standesbewußtestes": "standesbewußt",
    "standesgemäße": "standesgemäß",
    "standesgemäßem": "standesgemäß",
    "standesgemäßen": "standesgemäß",
    "standesgemäßer": "standesgemäß",
    "standesgemäßes": "standesgemäß",
    "standest": "stehen",
    "standet": "stehen",
    "standfeste": "standfest",
    "standfestem": "standfest",
    "standfesten": "standfest",
    "standfester": "standfest",
    "standfestere": "standfest",
    "standfesterem": "standfest",
    "standfesteren": "standfest",
    "standfesterer": "standfest",
    "standfesteres": "standfest",
    "standfestes": "standfest",
    "standfesteste": "standfest",
    "standfestestem": "standfest",
    "standfestesten": "standfest",
    "standfestester": "standfest",
    "standfestestes": "standfest",
    "standgehalten": "standhalten",
    "standgehaltene": "standgehalten",
    "standgehaltenem": "standgehalten",
    "standgehaltenen": "standgehalten",
    "standgehaltener": "standgehalten",
    "standgehaltenes": "standgehalten",
    "standhafte": "standhaft",
    "standhaftem": "standhaft",
    "standhaften": "standhaft",
    "standhafter": "standhaft",
    "standhaftere": "standhaft",
    "standhafterem": "standhaft",
    "standhafteren": "standhaft",
    "standhafterer": "standhaft",
    "standhafteres": "standhaft",
    "standhaftes": "standhaft",
    "standhafteste": "standhaft",
    "standhaftestem": "standhaft",
    "standhaftesten": "standhaft",
    "standhaftester": "standhaft",
    "standhaftestes": "standhaft",
    "standhalte": "standhalten",
    "standhaltend": "standhalten",
    "standhaltende": "standhaltend",
    "standhaltendem": "standhaltend",
    "standhaltenden": "standhaltend",
    "standhaltender": "standhaltend",
    "standhaltendere": "standhaltend",
    "standhaltenderem": "standhaltend",
    "standhaltenderen": "standhaltend",
    "standhaltenderer": "standhaltend",
    "standhaltenderes": "standhaltend",
    "standhaltendes": "standhaltend",
    "standhaltendste": "standhaltend",
    "standhaltendstem": "standhaltend",
    "standhaltendsten": "standhaltend",
    "standhaltendster": "standhaltend",
    "standhaltendstes": "standhaltend",
    "standhaltest": "standhalten",
    "standhaltet": "standhalten",
    "standhielt": "standhalten",
    "standhielte": "standhalten",
    "standhielten": "standhalten",
    "standhieltest": "standhalten",
    "standhieltet": "standhalten",
    "standhält": "standhalten",
    "standhältst": "standhalten",
    "standortfremdem": "standortfremd",
    "standortfremden": "standortfremd",
    "standortfremder": "standortfremd",
    "standortfremdes": "standortfremd",
    "standrechtlichem": "standrechtlich",
    "standrechtlichen": "standrechtlich",
    "standrechtlicher": "standrechtlich",
    "standrechtliches": "standrechtlich",
    "standsicherem": "standsicher",
    "standsicheren": "standsicher",
    "standsicherer": "standsicher",
    "standsicherere": "standsicher",
    "standsichererem": "standsicher",
    "standsichereren": "standsicher",
    "standsichererer": "standsicher",
    "standsichereres": "standsicher",
    "standsicheres": "standsicher",
    "standsicherste": "standsicher",
    "standsicherstem": "standsicher",
    "standsichersten": "standsicher",
    "standsicherster": "standsicher",
    "standsicherstes": "standsicher",
    "standzuhalten": "standhalten",
    "stank": "stinken",
    "stanken": "stinken",
    "stankst": "stinken",
    "stankt": "stinken",
    "stanze": "stanzen",
    "stanzend": "stanzen",
    "stanzende": "stanzend",
    "stanzendem": "stanzend",
    "stanzenden": "stanzend",
    "stanzender": "stanzend",
    "stanzendes": "stanzend",
    "stanzest": "stanzen",
    "stanzet": "stanzen",
    "stanzt": "stanzen",
    "stanzte": "stanzen",
    "stanzten": "stanzen",
    "stanztest": "stanzen",
    "stanztet": "stanzen",
    "stapele": "stapeln",
    "stapelnd": "stapeln",
    "stapelnde": "stapelnd",
    "stapelndem": "stapelnd",
    "stapelnden": "stapelnd",
    "stapelnder": "stapelnd",
    "stapelndes": "stapelnd",
    "stapelst": "stapeln",
    "stapelt": "stapeln",
    "stapelte": "stapeln",
    "stapelten": "stapeln",
    "stapeltest": "stapeln",
    "stapeltet": "stapeln",
    "stapfe": "stapfen",
    "stapfend": "stapfen",
    "stapfende": "stapfend",
    "stapfendem": "stapfend",
    "stapfenden": "stapfend",
    "stapfender": "stapfend",
    "stapfendes": "stapfend",
    "stapfest": "stapfen",
    "stapfet": "stapfen",
    "stapfst": "stapfen",
    "stapft": "stapfen",
    "stapfte": "stapfen",
    "stapften": "stapfen",
    "stapftest": "stapfen",
    "stapftet": "stapfen",
    "staple": "stapeln",
    "starb": "sterben",
    "starben": "sterben",
    "starbst": "sterben",
    "starbt": "sterben",
    "starkem": "stark",
    "starken": "stark",
    "starker": "stark",
    "starkes": "stark",
    "starre": "starren",
    "starrend": "starren",
    "starrende": "starrend",
    "starrendem": "starrend",
    "starrenden": "starrend",
    "starrender": "starrend",
    "starrendere": "starrend",
    "starrenderem": "starrend",
    "starrenderen": "starrend",
    "starrenderer": "starrend",
    "starrenderes": "starrend",
    "starrendes": "starrend",
    "starrendste": "starrend",
    "starrendstem": "starrend",
    "starrendsten": "starrend",
    "starrendster": "starrend",
    "starrendstes": "starrend",
    "starrest": "starren",
    "starret": "starren",
    "starrköpfige": "starrköpfig",
    "starrköpfigem": "starrköpfig",
    "starrköpfigen": "starrköpfig",
    "starrköpfiger": "starrköpfig",
    "starrköpfigere": "starrköpfig",
    "starrköpfigerem": "starrköpfig",
    "starrköpfigeren": "starrköpfig",
    "starrköpfigerer": "starrköpfig",
    "starrköpfigeres": "starrköpfig",
    "starrköpfiges": "starrköpfig",
    "starrköpfigste": "starrköpfig",
    "starrköpfigstem": "starrköpfig",
    "starrköpfigsten": "starrköpfig",
    "starrköpfigster": "starrköpfig",
    "starrköpfigstes": "starrköpfig",
    "starrsinnige": "starrsinnig",
    "starrsinnigem": "starrsinnig",
    "starrsinnigen": "starrsinnig",
    "starrsinniger": "starrsinnig",
    "starrsinnigere": "starrsinnig",
    "starrsinnigerem": "starrsinnig",
    "starrsinnigeren": "starrsinnig",
    "starrsinnigerer": "starrsinnig",
    "starrsinnigeres": "starrsinnig",
    "starrsinniges": "starrsinnig",
    "starrsinnigste": "starrsinnig",
    "starrsinnigstem": "starrsinnig",
    "starrsinnigsten": "starrsinnig",
    "starrsinnigster": "starrsinnig",
    "starrsinnigstes": "starrsinnig",
    "starrst": "starren",
    "starrsüchtige": "starrsüchtig",
    "starrsüchtigem": "starrsüchtig",
    "starrsüchtigen": "starrsüchtig",
    "starrsüchtiger": "starrsüchtig",
    "starrsüchtigere": "starrsüchtig",
    "starrsüchtigerem": "starrsüchtig",
    "starrsüchtigeren": "starrsüchtig",
    "starrsüchtigerer": "starrsüchtig",
    "starrsüchtigeres": "starrsüchtig",
    "starrsüchtiges": "starrsüchtig",
    "starrsüchtigste": "starrsüchtig",
    "starrsüchtigstem": "starrsüchtig",
    "starrsüchtigsten": "starrsüchtig",
    "starrsüchtigster": "starrsüchtig",
    "starrsüchtigstes": "starrsüchtig",
    "starrt": "starren",
    "starrte": "starren",
    "starrten": "starren",
    "starrtest": "starren",
    "starrtet": "starren",
    "startbereitem": "startbereit",
    "startbereiten": "startbereit",
    "startbereiter": "startbereit",
    "startbereites": "startbereit",
    "starte": "starten",
    "startend": "starten",
    "startende": "startend",
    "startendem": "startend",
    "startenden": "startend",
    "startender": "startend",
    "startendes": "startend",
    "startest": "starten",
    "startet": "starten",
    "startete": "starten",
    "starteten": "starten",
    "startetest": "starten",
    "startetet": "starten",
    "startklare": "startklar",
    "startklarem": "startklar",
    "startklaren": "startklar",
    "startklarer": "startklar",
    "startklares": "startklar",
    "stationiere": "stationieren",
    "stationierend": "stationieren",
    "stationierende": "stationierend",
    "stationierendem": "stationierend",
    "stationierenden": "stationierend",
    "stationierender": "stationierend",
    "stationierendes": "stationierend",
    "stationierest": "stationieren",
    "stationieret": "stationieren",
    "stationierst": "stationieren",
    "stationiert": "stationieren",
    "stationierte": "stationieren",
    "stationiertem": "stationiert",
    "stationierten": "stationieren",
    "stationierter": "stationiert",
    "stationiertes": "stationiert",
    "stationiertest": "stationieren",
    "stationiertet": "stationieren",
    "stationärem": "stationär",
    "stationären": "stationär",
    "stationärer": "stationär",
    "stationäres": "stationär",
    "statischem": "statisch",
    "statischen": "statisch",
    "statischer": "statisch",
    "statischere": "statisch",
    "statischerem": "statisch",
    "statischeren": "statisch",
    "statischerer": "statisch",
    "statischeres": "statisch",
    "statisches": "statisch",
    "statischste": "statisch",
    "statischstem": "statisch",
    "statischsten": "statisch",
    "statischster": "statisch",
    "statischstes": "statisch",
    "statistischem": "statistisch",
    "statistischen": "statistisch",
    "statistischer": "statistisch",
    "statistisches": "statistisch",
    "statte": "statten",
    "stattend": "statten",
    "stattende": "stattend",
    "stattendem": "stattend",
    "stattenden": "stattend",
    "stattender": "stattend",
    "stattendes": "stattend",
    "stattest": "statten",
    "stattet": "statten",
    "stattete": "statten",
    "statteten": "statten",
    "stattetest": "statten",
    "stattetet": "statten",
    "stattfand": "stattfinden",
    "stattfanden": "stattfinden",
    "stattfandest": "stattfinden",
    "stattfandet": "stattfinden",
    "stattfinde": "stattfinden",
    "stattfindend": "stattfinden",
    "stattfindende": "stattfindend",
    "stattfindendem": "stattfindend",
    "stattfindenden": "stattfindend",
    "stattfindender": "stattfindend",
    "stattfindendes": "stattfindend",
    "stattfindest": "stattfinden",
    "stattfindet": "stattfinden",
    "stattfände": "stattfinden",
    "stattfänden": "stattfinden",
    "stattfändest": "stattfinden",
    "stattfändet": "stattfinden",
    "stattgab": "stattgeben",
    "stattgaben": "stattgeben",
    "stattgabst": "stattgeben",
    "stattgabt": "stattgeben",
    "stattgebe": "stattgeben",
    "stattgebend": "stattgeben",
    "stattgebende": "stattgebend",
    "stattgebendem": "stattgebend",
    "stattgebenden": "stattgebend",
    "stattgebender": "stattgebend",
    "stattgebendes": "stattgebend",
    "stattgebest": "stattgeben",
    "stattgebet": "stattgeben",
    "stattgebt": "stattgeben",
    "stattgefunden": "stattfinden",
    "stattgefundene": "stattgefunden",
    "stattgefundenem": "stattgefunden",
    "stattgefundenen": "stattgefunden",
    "stattgefundener": "stattgefunden",
    "stattgefundenes": "stattgefunden",
    "stattgegeben": "stattgeben",
    "stattgegebene": "stattgegeben",
    "stattgegebenem": "stattgegeben",
    "stattgegebenen": "stattgegeben",
    "stattgegebener": "stattgegeben",
    "stattgegebenes": "stattgegeben",
    "stattgibst": "stattgeben",
    "stattgibt": "stattgeben",
    "stattgäbe": "stattgeben",
    "stattgäben": "stattgeben",
    "stattgäbest": "stattgeben",
    "stattgäbet": "stattgeben",
    "statthafte": "statthaft",
    "statthaftem": "statthaft",
    "statthaften": "statthaft",
    "statthafter": "statthaft",
    "statthaftere": "statthaft",
    "statthafterem": "statthaft",
    "statthafteren": "statthaft",
    "statthafterer": "statthaft",
    "statthafteres": "statthaft",
    "statthaftes": "statthaft",
    "statthafteste": "statthaft",
    "statthaftestem": "statthaft",
    "statthaftesten": "statthaft",
    "statthaftester": "statthaft",
    "statthaftestes": "statthaft",
    "stattliche": "stattlich",
    "stattlichem": "stattlich",
    "stattlichen": "stattlich",
    "stattlicher": "stattlich",
    "stattlichere": "stattlich",
    "stattlicherem": "stattlich",
    "stattlicheren": "stattlich",
    "stattlicherer": "stattlich",
    "stattlicheres": "stattlich",
    "stattliches": "stattlich",
    "stattlichste": "stattlich",
    "stattlichstem": "stattlich",
    "stattlichsten": "stattlich",
    "stattlichster": "stattlich",
    "stattlichstes": "stattlich",
    "stattzufinden": "stattfinden",
    "stattzugeben": "stattgeben",
    "staube": "stauben",
    "staubend": "stauben",
    "staubende": "staubend",
    "staubendem": "staubend",
    "staubenden": "staubend",
    "staubender": "staubend",
    "staubendere": "staubend",
    "staubenderem": "staubend",
    "staubenderen": "staubend",
    "staubenderer": "staubend",
    "staubenderes": "staubend",
    "staubendes": "staubend",
    "staubendste": "staubend",
    "staubendstem": "staubend",
    "staubendsten": "staubend",
    "staubendster": "staubend",
    "staubendstes": "staubend",
    "staubest": "stauben",
    "staubet": "stauben",
    "staubfreiem": "staubfrei",
    "staubfreien": "staubfrei",
    "staubfreier": "staubfrei",
    "staubfreies": "staubfrei",
    "staubgesaugt": "staubsaugen",
    "staubgesaugte": "staubgesaugt",
    "staubgesaugtem": "staubgesaugt",
    "staubgesaugten": "staubgesaugt",
    "staubgesaugter": "staubgesaugt",
    "staubgesaugtes": "staubgesaugt",
    "staubgesogen": "staubsaugen",
    "staubgesogene": "staubgesogen",
    "staubgesogenem": "staubgesogen",
    "staubgesogenen": "staubgesogen",
    "staubgesogener": "staubgesogen",
    "staubgesogenes": "staubgesogen",
    "staubige": "staubig",
    "staubigem": "staubig",
    "staubigen": "staubig",
    "staubiger": "staubig",
    "staubigere": "staubig",
    "staubigerem": "staubig",
    "staubigeren": "staubig",
    "staubigerer": "staubig",
    "staubigeres": "staubig",
    "staubiges": "staubig",
    "staubigste": "staubig",
    "staubigstem": "staubig",
    "staubigsten": "staubig",
    "staubigster": "staubig",
    "staubigstes": "staubig",
    "staubsauge": "staubsaugen",
    "staubsaugend": "staubsaugen",
    "staubsaugende": "staubsaugend",
    "staubsaugendem": "staubsaugend",
    "staubsaugenden": "staubsaugend",
    "staubsaugender": "staubsaugend",
    "staubsaugendere": "staubsaugend",
    "staubsaugenderem": "staubsaugend",
    "staubsaugenderen": "staubsaugend",
    "staubsaugenderer": "staubsaugend",
    "staubsaugenderes": "staubsaugend",
    "staubsaugendes": "staubsaugend",
    "staubsaugendste": "staubsaugend",
    "staubsaugendstem": "staubsaugend",
    "staubsaugendsten": "staubsaugend",
    "staubsaugendster": "staubsaugend",
    "staubsaugendstes": "staubsaugend",
    "staubsaugest": "staubsaugen",
    "staubsauget": "staubsaugen",
    "staubsaugst": "staubsaugen",
    "staubsaugt": "staubsaugen",
    "staubsaugte": "staubsaugen",
    "staubsaugten": "staubsaugen",
    "staubsaugtest": "staubsaugen",
    "staubsaugtet": "staubsaugen",
    "staubsog": "staubsaugen",
    "staubsogen": "staubsaugen",
    "staubsogst": "staubsaugen",
    "staubsogt": "staubsaugen",
    "staubst": "stauben",
    "staubsöge": "staubsaugen",
    "staubsögen": "staubsaugen",
    "staubsögest": "staubsaugen",
    "staubsöget": "staubsaugen",
    "staubt": "stauben",
    "staubte": "stauben",
    "staubten": "stauben",
    "staubtest": "stauben",
    "staubtet": "stauben",
    "staubzusaugen": "staubsaugen",
    "stauche": "stauchen",
    "stauchend": "stauchen",
    "stauchende": "stauchend",
    "stauchendem": "stauchend",
    "stauchenden": "stauchend",
    "stauchender": "stauchend",
    "stauchendere": "stauchend",
    "stauchenderem": "stauchend",
    "stauchenderen": "stauchend",
    "stauchenderer": "stauchend",
    "stauchenderes": "stauchend",
    "stauchendes": "stauchend",
    "stauchendste": "stauchend",
    "stauchendstem": "stauchend",
    "stauchendsten": "stauchend",
    "stauchendster": "stauchend",
    "stauchendstes": "stauchend",
    "stauchest": "stauchen",
    "stauchet": "stauchen",
    "stauchst": "stauchen",
    "staucht": "stauchen",
    "stauchte": "stauchen",
    "stauchten": "stauchen",
    "stauchtest": "stauchen",
    "stauchtet": "stauchen",
    "stauend": "stauen",
    "stauende": "stauend",
    "stauendem": "stauend",
    "stauenden": "stauend",
    "stauender": "stauend",
    "stauendere": "stauend",
    "stauenderem": "stauend",
    "stauenderen": "stauend",
    "stauenderer": "stauend",
    "stauenderes": "stauend",
    "stauendes": "stauend",
    "stauendste": "stauend",
    "stauendstem": "stauend",
    "stauendsten": "stauend",
    "stauendster": "stauend",
    "stauendstes": "stauend",
    "stauest": "stauen",
    "stauet": "stauen",
    "staune": "staunen",
    "staunend": "staunen",
    "staunende": "staunend",
    "staunendem": "staunend",
    "staunenden": "staunend",
    "staunender": "staunend",
    "staunendes": "staunend",
    "staunenswertem": "staunenswert",
    "staunenswerten": "staunenswert",
    "staunenswerter": "staunenswert",
    "staunenswertere": "staunenswert",
    "staunenswerterem": "staunenswert",
    "staunenswerteren": "staunenswert",
    "staunenswerterer": "staunenswert",
    "staunenswerteres": "staunenswert",
    "staunenswertes": "staunenswert",
    "staunenswerteste": "staunenswert",
    "staunenswertestem": "staunenswert",
    "staunenswertesten": "staunenswert",
    "staunenswertester": "staunenswert",
    "staunenswertestes": "staunenswert",
    "staunest": "staunen",
    "staunet": "staunen",
    "staunst": "staunen",
    "staunt": "staunen",
    "staunte": "staunen",
    "staunten": "staunen",
    "stauntest": "staunen",
    "stauntet": "staunen",
    "staust": "stauen",
    "staut": "stauen",
    "staute": "stauen",
    "stauten": "stauen",
    "stautest": "stauen",
    "stautet": "stauen",
    "steche": "stechen",
    "stechend": "stechen",
    "stechende": "stechend",
    "stechendem": "stechend",
    "stechenden": "stechend",
    "stechender": "stechend",
    "stechendere": "stechend",
    "stechenderem": "stechend",
    "stechenderen": "stechend",
    "stechenderer": "stechend",
    "stechenderes": "stechend",
    "stechendes": "stechend",
    "stechendste": "stechend",
    "stechendstem": "stechend",
    "stechendsten": "stechend",
    "stechendster": "stechend",
    "stechendstes": "stechend",
    "stechest": "stechen",
    "stechet": "stechen",
    "stecht": "stechen",
    "steckbrieflichem": "steckbrieflich",
    "steckbrieflichen": "steckbrieflich",
    "steckbrieflicher": "steckbrieflich",
    "steckbriefliches": "steckbrieflich",
    "stecke": "stecken",
    "steckend": "stecken",
    "steckende": "steckend",
    "steckendem": "steckend",
    "steckenden": "steckend",
    "steckender": "steckend",
    "steckendes": "steckend",
    "steckest": "stecken",
    "stecket": "stecken",
    "steckst": "stecken",
    "steckt": "stecken",
    "steckte": "stecken",
    "steckten": "stecken",
    "stecktest": "stecken",
    "stecktet": "stecken",
    "stehe": "stehen",
    "stehenbleibe": "stehenbleiben",
    "stehenbleibend": "stehenbleiben",
    "stehenbleibende": "stehenbleibend",
    "stehenbleibendem": "stehenbleibend",
    "stehenbleibenden": "stehenbleibend",
    "stehenbleibender": "stehenbleibend",
    "stehenbleibendes": "stehenbleibend",
    "stehenbleibest": "stehenbleiben",
    "stehenbleibet": "stehenbleiben",
    "stehenbleibst": "stehenbleiben",
    "stehenbleibt": "stehenbleiben",
    "stehenblieb": "stehenbleiben",
    "stehenbliebe": "stehenbleiben",
    "stehenblieben": "stehenbleiben",
    "stehenbliebest": "stehenbleiben",
    "stehenbliebet": "stehenbleiben",
    "stehenbliebst": "stehenbleiben",
    "stehenbliebt": "stehenbleiben",
    "stehend": "stehen",
    "stehende": "stehend",
    "stehendem": "stehend",
    "stehenden": "stehend",
    "stehender": "stehend",
    "stehendes": "stehend",
    "stehengeblieben": "stehenbleiben",
    "stehengebliebene": "stehengeblieben",
    "stehengebliebenem": "stehengeblieben",
    "stehengebliebenen": "stehengeblieben",
    "stehengebliebener": "stehengeblieben",
    "stehengebliebenes": "stehengeblieben",
    "stehenzubleiben": "stehenbleiben",
    "stehest": "stehen",
    "stehet": "stehen",
    "stehle": "stehlen",
    "stehlend": "stehlen",
    "stehlende": "stehlend",
    "stehlendem": "stehlend",
    "stehlenden": "stehlend",
    "stehlender": "stehlend",
    "stehlendes": "stehlend",
    "stehlest": "stehlen",
    "stehlet": "stehlen",
    "stehlt": "stehlen",
    "stehst": "stehen",
    "steht": "stehen",
    "steife": "steifen",
    "steifend": "steifen",
    "steifende": "steifend",
    "steifendem": "steifend",
    "steifenden": "steifend",
    "steifender": "steifend",
    "steifendere": "steifend",
    "steifenderem": "steifend",
    "steifenderen": "steifend",
    "steifenderer": "steifend",
    "steifenderes": "steifend",
    "steifendes": "steifend",
    "steifendste": "steifend",
    "steifendstem": "steifend",
    "steifendsten": "steifend",
    "steifendster": "steifend",
    "steifendstes": "steifend",
    "steifest": "steifen",
    "steifet": "steifen",
    "steifst": "steifen",
    "steift": "steifen",
    "steifte": "steifen",
    "steiften": "steifen",
    "steiftest": "steifen",
    "steiftet": "steifen",
    "steige": "steigen",
    "steigend": "steigen",
    "steigende": "steigend",
    "steigendem": "steigend",
    "steigenden": "steigend",
    "steigender": "steigend",
    "steigendes": "steigend",
    "steigere": "steigern",
    "steigernd": "steigern",
    "steigernde": "steigernd",
    "steigerndem": "steigernd",
    "steigernden": "steigernd",
    "steigernder": "steigernd",
    "steigerndes": "steigernd",
    "steigerst": "steigern",
    "steigert": "steigern",
    "steigerte": "steigern",
    "steigerten": "steigern",
    "steigertest": "steigern",
    "steigertet": "steigern",
    "steigest": "steigen",
    "steiget": "steigen",
    "steigst": "steigen",
    "steigt": "steigen",
    "steilem": "steil",
    "steilen": "steil",
    "steiler": "steil",
    "steilere": "steil",
    "steilerem": "steil",
    "steileren": "steil",
    "steilerer": "steil",
    "steileres": "steil",
    "steiles": "steil",
    "steilstem": "steil",
    "steilsten": "steil",
    "steilster": "steil",
    "steilstes": "steil",
    "steinalte": "steinalt",
    "steinaltem": "steinalt",
    "steinalten": "steinalt",
    "steinalter": "steinalt",
    "steinaltes": "steinalt",
    "steinernem": "steinern",
    "steinernen": "steinern",
    "steinerner": "steinern",
    "steinernere": "steinern",
    "steinernerem": "steinern",
    "steinerneren": "steinern",
    "steinernerer": "steinern",
    "steinerneres": "steinern",
    "steinernes": "steinern",
    "steinernste": "steinern",
    "steinernstem": "steinern",
    "steinernsten": "steinern",
    "steinernster": "steinern",
    "steinernstes": "steinern",
    "steinige": "steinigen",
    "steinigend": "steinigen",
    "steinigende": "steinigend",
    "steinigendem": "steinigend",
    "steinigenden": "steinigend",
    "steinigender": "steinigend",
    "steinigendes": "steinigend",
    "steinigest": "steinigen",
    "steiniget": "steinigen",
    "steinigst": "steinigen",
    "steinigt": "steinigen",
    "steinigte": "steinigen",
    "steinigten": "steinigen",
    "steinigtest": "steinigen",
    "steinigtet": "steinigen",
    "steinreichem": "steinreich",
    "steinreichen": "steinreich",
    "steinreicher": "steinreich",
    "steinreiches": "steinreich",
    "stellend": "stellen",
    "stellende": "stellend",
    "stellendem": "stellend",
    "stellenden": "stellend",
    "stellender": "stellend",
    "stellendes": "stellend",
    "stellest": "stellen",
    "stellet": "stellen",
    "stellst": "stellen",
    "stellt": "stellen",
    "stellte": "stellen",
    "stellten": "stellen",
    "stelltest": "stellen",
    "stelltet": "stellen",
    "stellvertretendem": "stellvertretend",
    "stellvertretenden": "stellvertretend",
    "stellvertretender": "stellvertretend",
    "stellvertretendes": "stellvertretend",
    "stemme": "stemmen",
    "stemmend": "stemmen",
    "stemmende": "stemmend",
    "stemmendem": "stemmend",
    "stemmenden": "stemmend",
    "stemmender": "stemmend",
    "stemmendes": "stemmend",
    "stemmest": "stemmen",
    "stemmet": "stemmen",
    "stemmst": "stemmen",
    "stemmt": "stemmen",
    "stemmte": "stemmen",
    "stemmten": "stemmen",
    "stemmtest": "stemmen",
    "stemmtet": "stemmen",
    "stempele": "stempeln",
    "stempelnd": "stempeln",
    "stempelnde": "stempelnd",
    "stempelndem": "stempelnd",
    "stempelnden": "stempelnd",
    "stempelnder": "stempelnd",
    "stempelndes": "stempelnd",
    "stempelst": "stempeln",
    "stempelt": "stempeln",
    "stempelte": "stempeln",
    "stempelten": "stempeln",
    "stempeltest": "stempeln",
    "stempeltet": "stempeln",
    "stemple": "stempeln",
    "steppend": "steppen",
    "steppende": "steppend",
    "steppendem": "steppend",
    "steppenden": "steppend",
    "steppender": "steppend",
    "steppendere": "steppend",
    "steppenderem": "steppend",
    "steppenderen": "steppend",
    "steppenderer": "steppend",
    "steppenderes": "steppend",
    "steppendes": "steppend",
    "steppendste": "steppend",
    "steppendstem": "steppend",
    "steppendsten": "steppend",
    "steppendster": "steppend",
    "steppendstes": "steppend",
    "steppest": "steppen",
    "steppet": "steppen",
    "steppst": "steppen",
    "steppt": "steppen",
    "steppte": "steppen",
    "steppten": "steppen",
    "stepptest": "steppen",
    "stepptet": "steppen",
    "sterbe": "sterben",
    "sterbend": "sterben",
    "sterbende": "sterbend",
    "sterbendem": "sterbend",
    "sterbenden": "sterbend",
    "sterbender": "sterbend",
    "sterbendes": "sterbend",
    "sterbenskrankem": "sterbenskrank",
    "sterbenskranken": "sterbenskrank",
    "sterbenskranker": "sterbenskrank",
    "sterbenskrankes": "sterbenskrank",
    "sterbest": "sterben",
    "sterbet": "sterben",
    "sterblichem": "sterblich",
    "sterblichen": "sterblich",
    "sterblicher": "sterblich",
    "sterblichere": "sterblich",
    "sterblicherem": "sterblich",
    "sterblicheren": "sterblich",
    "sterblicherer": "sterblich",
    "sterblicheres": "sterblich",
    "sterbliches": "sterblich",
    "sterblichste": "sterblich",
    "sterblichstem": "sterblich",
    "sterblichsten": "sterblich",
    "sterblichster": "sterblich",
    "sterblichstes": "sterblich",
    "sterbt": "sterben",
    "stereotypem": "stereotyp",
    "stereotypen": "stereotyp",
    "stereotyper": "stereotyp",
    "stereotypes": "stereotyp",
    "sterile": "steril",
    "sterilem": "steril",
    "sterilen": "steril",
    "steriler": "steril",
    "sterilere": "steril",
    "sterilerem": "steril",
    "sterileren": "steril",
    "sterilerer": "steril",
    "sterileres": "steril",
    "steriles": "steril",
    "sterilisierend": "sterilisieren",
    "sterilisierende": "sterilisierend",
    "sterilisierendem": "sterilisierend",
    "sterilisierenden": "sterilisierend",
    "sterilisierender": "sterilisierend",
    "sterilisierendere": "sterilisierend",
    "sterilisierenderem": "sterilisierend",
    "sterilisierenderen": "sterilisierend",
    "sterilisierenderer": "sterilisierend",
    "sterilisierenderes": "sterilisierend",
    "sterilisierendes": "sterilisierend",
    "sterilisierendste": "sterilisierend",
    "sterilisierendstem": "sterilisierend",
    "sterilisierendsten": "sterilisierend",
    "sterilisierendster": "sterilisierend",
    "sterilisierendstes": "sterilisierend",
    "sterilisierest": "sterilisieren",
    "sterilisieret": "sterilisieren",
    "sterilisierst": "sterilisieren",
    "sterilisiert": "sterilisieren",
    "sterilisierte": "sterilisieren",
    "sterilisiertem": "sterilisiert",
    "sterilisierten": "sterilisieren",
    "sterilisierter": "sterilisiert",
    "sterilisiertere": "sterilisiert",
    "sterilisierterem": "sterilisiert",
    "sterilisierteren": "sterilisiert",
    "sterilisierterer": "sterilisiert",
    "sterilisierteres": "sterilisiert",
    "sterilisiertes": "sterilisiert",
    "sterilisiertest": "sterilisieren",
    "sterilisierteste": "sterilisiert",
    "sterilisiertestem": "sterilisiert",
    "sterilisiertesten": "sterilisiert",
    "sterilisiertester": "sterilisiert",
    "sterilisiertestes": "sterilisiert",
    "sterilisiertet": "sterilisieren",
    "sterilstem": "steril",
    "sterilsten": "steril",
    "sterilster": "steril",
    "sterilstes": "steril",
    "stetigem": "stetig",
    "stetigen": "stetig",
    "stetiger": "stetig",
    "stetigere": "stetig",
    "stetigerem": "stetig",
    "stetigeren": "stetig",
    "stetigerer": "stetig",
    "stetigeres": "stetig",
    "stetiges": "stetig",
    "stetigste": "stetig",
    "stetigstem": "stetig",
    "stetigsten": "stetig",
    "stetigster": "stetig",
    "stetigstes": "stetig",
    "steuere": "steuern",
    "steuerfreie": "steuerfrei",
    "steuerfreiem": "steuerfrei",
    "steuerfreien": "steuerfrei",
    "steuerfreier": "steuerfrei",
    "steuerfreies": "steuerfrei",
    "steuerliche": "steuerlich",
    "steuerlichem": "steuerlich",
    "steuerlichen": "steuerlich",
    "steuerlicher": "steuerlich",
    "steuerliches": "steuerlich",
    "steuernd": "steuern",
    "steuernde": "steuernd",
    "steuerndem": "steuernd",
    "steuernden": "steuernd",
    "steuernder": "steuernd",
    "steuerndes": "steuernd",
    "steuerpflichtigem": "steuerpflichtig",
    "steuerpflichtigen": "steuerpflichtig",
    "steuerpflichtiger": "steuerpflichtig",
    "steuerpflichtiges": "steuerpflichtig",
    "steuerst": "steuern",
    "steuert": "steuern",
    "steuerte": "steuern",
    "steuerten": "steuern",
    "steuertest": "steuern",
    "steuertet": "steuern",
    "stibitze": "stibitzen",
    "stibitzend": "stibitzen",
    "stibitzende": "stibitzend",
    "stibitzendem": "stibitzend",
    "stibitzenden": "stibitzend",
    "stibitzender": "stibitzend",
    "stibitzendes": "stibitzend",
    "stibitzest": "stibitzen",
    "stibitzet": "stibitzen",
    "stibitzt": "stibitzen",
    "stibitzte": "stibitzen",
    "stibitztem": "stibitzt",
    "stibitzten": "stibitzen",
    "stibitzter": "stibitzt",
    "stibitztes": "stibitzt",
    "stibitztest": "stibitzen",
    "stibitztet": "stibitzen",
    "stich": "stechen",
    "stichele": "sticheln",
    "stichelnd": "sticheln",
    "stichelnde": "stichelnd",
    "stichelndem": "stichelnd",
    "stichelnden": "stichelnd",
    "stichelnder": "stichelnd",
    "stichelndere": "stichelnd",
    "stichelnderem": "stichelnd",
    "stichelnderen": "stichelnd",
    "stichelnderer": "stichelnd",
    "stichelnderes": "stichelnd",
    "stichelndes": "stichelnd",
    "stichelndste": "stichelnd",
    "stichelndstem": "stichelnd",
    "stichelndsten": "stichelnd",
    "stichelndster": "stichelnd",
    "stichelndstes": "stichelnd",
    "stichelst": "sticheln",
    "stichelt": "sticheln",
    "stichelte": "sticheln",
    "stichelten": "sticheln",
    "sticheltest": "sticheln",
    "sticheltet": "sticheln",
    "stichhaltigem": "stichhaltig",
    "stichhaltigen": "stichhaltig",
    "stichhaltiger": "stichhaltig",
    "stichhaltiges": "stichhaltig",
    "stichle": "sticheln",
    "stichst": "stechen",
    "sticht": "stechen",
    "stiebe": "stieben",
    "stiebend": "stieben",
    "stiebende": "stiebend",
    "stiebendem": "stiebend",
    "stiebenden": "stiebend",
    "stiebender": "stiebend",
    "stiebendere": "stiebend",
    "stiebenderem": "stiebend",
    "stiebenderen": "stiebend",
    "stiebenderer": "stiebend",
    "stiebenderes": "stiebend",
    "stiebendes": "stiebend",
    "stiebendste": "stiebend",
    "stiebendstem": "stiebend",
    "stiebendsten": "stiebend",
    "stiebendster": "stiebend",
    "stiebendstes": "stiebend",
    "stiebest": "stieben",
    "stiebet": "stieben",
    "stiebst": "stieben",
    "stiebt": "stieben",
    "stiefele": "stiefeln",
    "stiefelnd": "stiefeln",
    "stiefelnde": "stiefelnd",
    "stiefelndem": "stiefelnd",
    "stiefelnden": "stiefelnd",
    "stiefelnder": "stiefelnd",
    "stiefelndes": "stiefelnd",
    "stiefelst": "stiefeln",
    "stiefelt": "stiefeln",
    "stiefelte": "stiefeln",
    "stiefelten": "stiefeln",
    "stiefeltest": "stiefeln",
    "stiefeltet": "stiefeln",
    "stiefle": "stiefeln",
    "stiefmütterlichem": "stiefmütterlich",
    "stiefmütterlichen": "stiefmütterlich",
    "stiefmütterlicher": "stiefmütterlich",
    "stiefmütterliches": "stiefmütterlich",
    "stieg": "steigen",
    "stiege": "steigen",
    "stiegen": "steigen",
    "stiegest": "steigen",
    "stieget": "steigen",
    "stiegst": "steigen",
    "stiegt": "steigen",
    "stiehl": "stehlen",
    "stiehlst": "stehlen",
    "stiehlt": "stehlen",
    "stiele": "stielen",
    "stielend": "stielen",
    "stielende": "stielend",
    "stielendem": "stielend",
    "stielenden": "stielend",
    "stielender": "stielend",
    "stielendes": "stielend",
    "stielest": "stielen",
    "stielet": "stielen",
    "stielst": "stielen",
    "stielt": "stielen",
    "stielte": "stielen",
    "stielten": "stielen",
    "stieltest": "stielen",
    "stieltet": "stielen",
    "stierend": "stieren",
    "stierende": "stierend",
    "stierendem": "stierend",
    "stierenden": "stierend",
    "stierender": "stierend",
    "stierendere": "stierend",
    "stierenderem": "stierend",
    "stierenderen": "stierend",
    "stierenderer": "stierend",
    "stierenderes": "stierend",
    "stierendes": "stierend",
    "stierendste": "stierend",
    "stierendstem": "stierend",
    "stierendsten": "stierend",
    "stierendster": "stierend",
    "stierendstes": "stierend",
    "stierest": "stieren",
    "stieret": "stieren",
    "stierst": "stieren",
    "stiert": "stieren",
    "stierte": "stieren",
    "stierten": "stieren",
    "stiertest": "stieren",
    "stiertet": "stieren",
    "stieselige": "stieselig",
    "stieseligem": "stieselig",
    "stieseligen": "stieselig",
    "stieseliger": "stieselig",
    "stieseligere": "stieselig",
    "stieseligerem": "stieselig",
    "stieseligeren": "stieselig",
    "stieseligerer": "stieselig",
    "stieseligeres": "stieselig",
    "stieseliges": "stieselig",
    "stieseligste": "stieselig",
    "stieseligstem": "stieselig",
    "stieseligsten": "stieselig",
    "stieseligster": "stieselig",
    "stieseligstes": "stieselig",
    "stieß": "stoßen",
    "stieße": "stoßen",
    "stießen": "stoßen",
    "stießest": "stoßen",
    "stießet": "stoßen",
    "stießt": "stoßen",
    "stiftend": "stiften",
    "stiftende": "stiftend",
    "stiftendem": "stiftend",
    "stiftenden": "stiftend",
    "stiftender": "stiftend",
    "stiftendere": "stiftend",
    "stiftenderem": "stiftend",
    "stiftenderen": "stiftend",
    "stiftenderer": "stiftend",
    "stiftenderes": "stiftend",
    "stiftendes": "stiftend",
    "stiftendste": "stiftend",
    "stiftendstem": "stiftend",
    "stiftendsten": "stiftend",
    "stiftendster": "stiftend",
    "stiftendstes": "stiftend",
    "stiftest": "stiften",
    "stiftet": "stiften",
    "stiftete": "stiften",
    "stifteten": "stiften",
    "stiftetest": "stiften",
    "stiftetet": "stiften",
    "stigmatisiere": "stigmatisieren",
    "stigmatisierend": "stigmatisieren",
    "stigmatisierende": "stigmatisierend",
    "stigmatisierendem": "stigmatisierend",
    "stigmatisierenden": "stigmatisierend",
    "stigmatisierender": "stigmatisierend",
    "stigmatisierendere": "stigmatisierend",
    "stigmatisierenderem": "stigmatisierend",
    "stigmatisierenderen": "stigmatisierend",
    "stigmatisierenderer": "stigmatisierend",
    "stigmatisierenderes": "stigmatisierend",
    "stigmatisierendes": "stigmatisierend",
    "stigmatisierendste": "stigmatisierend",
    "stigmatisierendstem": "stigmatisierend",
    "stigmatisierendsten": "stigmatisierend",
    "stigmatisierendster": "stigmatisierend",
    "stigmatisierendstes": "stigmatisierend",
    "stigmatisierest": "stigmatisieren",
    "stigmatisieret": "stigmatisieren",
    "stigmatisierst": "stigmatisieren",
    "stigmatisiert": "stigmatisieren",
    "stigmatisierte": "stigmatisieren",
    "stigmatisiertem": "stigmatisiert",
    "stigmatisierten": "stigmatisieren",
    "stigmatisierter": "stigmatisiert",
    "stigmatisiertere": "stigmatisiert",
    "stigmatisierterem": "stigmatisiert",
    "stigmatisierteren": "stigmatisiert",
    "stigmatisierterer": "stigmatisiert",
    "stigmatisierteres": "stigmatisiert",
    "stigmatisiertes": "stigmatisiert",
    "stigmatisiertest": "stigmatisieren",
    "stigmatisiertestem": "stigmatisiert",
    "stigmatisiertesten": "stigmatisiert",
    "stigmatisiertester": "stigmatisiert",
    "stigmatisiertestes": "stigmatisiert",
    "stigmatisiertet": "stigmatisieren",
    "stilechtem": "stilecht",
    "stilechten": "stilecht",
    "stilechter": "stilecht",
    "stilechtes": "stilecht",
    "stilgerechtem": "stilgerecht",
    "stilgerechten": "stilgerecht",
    "stilgerechter": "stilgerecht",
    "stilgerechtes": "stilgerecht",
    "stilisiere": "stilisieren",
    "stilisierend": "stilisieren",
    "stilisierende": "stilisierend",
    "stilisierendem": "stilisierend",
    "stilisierenden": "stilisierend",
    "stilisierender": "stilisierend",
    "stilisierendere": "stilisierend",
    "stilisierenderem": "stilisierend",
    "stilisierenderen": "stilisierend",
    "stilisierenderer": "stilisierend",
    "stilisierenderes": "stilisierend",
    "stilisierendes": "stilisierend",
    "stilisierendste": "stilisierend",
    "stilisierendstem": "stilisierend",
    "stilisierendsten": "stilisierend",
    "stilisierendster": "stilisierend",
    "stilisierendstes": "stilisierend",
    "stilisierest": "stilisieren",
    "stilisieret": "stilisieren",
    "stilisierst": "stilisieren",
    "stilisiert": "stilisieren",
    "stilisierte": "stilisieren",
    "stilisiertem": "stilisiert",
    "stilisierten": "stilisieren",
    "stilisierter": "stilisiert",
    "stilisiertere": "stilisiert",
    "stilisierterem": "stilisiert",
    "stilisierteren": "stilisiert",
    "stilisierterer": "stilisiert",
    "stilisierteres": "stilisiert",
    "stilisiertes": "stilisiert",
    "stilisiertest": "stilisieren",
    "stilisierteste": "stilisiert",
    "stilisiertestem": "stilisiert",
    "stilisiertesten": "stilisiert",
    "stilisiertester": "stilisiert",
    "stilisiertestes": "stilisiert",
    "stilisiertet": "stilisieren",
    "stilistischem": "stilistisch",
    "stilistischen": "stilistisch",
    "stilistischer": "stilistisch",
    "stilistisches": "stilistisch",
    "still": "stillen",
    "stille": "still",
    "stillem": "still",
    "stillen": "still",
    "stillend": "stillen",
    "stillende": "stillend",
    "stillendem": "stillend",
    "stillenden": "stillend",
    "stillender": "stillend",
    "stillendes": "stillend",
    "stiller": "still",
    "stillere": "still",
    "stillerem": "still",
    "stilleren": "still",
    "stillerer": "still",
    "stilleres": "still",
    "stilles": "still",
    "stillest": "stillen",
    "stillet": "stillen",
    "stillgelegt": "stilllegen",
    "stillgelegte": "stillgelegt",
    "stillgelegtem": "stillgelegt",
    "stillgelegten": "stillgelegt",
    "stillgelegter": "stillgelegt",
    "stillgelegtes": "stillgelegt",
    "stillgeschwiegen": "stillschweigen",
    "stillgeschwiegene": "stillgeschwiegen",
    "stillgeschwiegenem": "stillgeschwiegen",
    "stillgeschwiegenen": "stillgeschwiegen",
    "stillgeschwiegener": "stillgeschwiegen",
    "stillgeschwiegenere": "stillgeschwiegen",
    "stillgeschwiegenerem": "stillgeschwiegen",
    "stillgeschwiegeneren": "stillgeschwiegen",
    "stillgeschwiegenerer": "stillgeschwiegen",
    "stillgeschwiegeneres": "stillgeschwiegen",
    "stillgeschwiegenes": "stillgeschwiegen",
    "stillgeschwiegenste": "stillgeschwiegen",
    "stillgeschwiegenstem": "stillgeschwiegen",
    "stillgeschwiegensten": "stillgeschwiegen",
    "stillgeschwiegenster": "stillgeschwiegen",
    "stillgeschwiegenstes": "stillgeschwiegen",
    "stilllege": "stilllegen",
    "stilllegend": "stilllegen",
    "stilllegende": "stilllegend",
    "stilllegendem": "stilllegend",
    "stilllegenden": "stilllegend",
    "stilllegender": "stilllegend",
    "stilllegendes": "stilllegend",
    "stilllegest": "stilllegen",
    "stillleget": "stilllegen",
    "stilllegst": "stilllegen",
    "stilllegt": "stilllegen",
    "stilllegte": "stilllegen",
    "stilllegten": "stilllegen",
    "stilllegtest": "stilllegen",
    "stilllegtet": "stilllegen",
    "stillose": "stillos",
    "stillosem": "stillos",
    "stillosen": "stillos",
    "stilloser": "stillos",
    "stillosere": "stillos",
    "stilloserem": "stillos",
    "stilloseren": "stillos",
    "stilloserer": "stillos",
    "stilloseres": "stillos",
    "stilloses": "stillos",
    "stilloseste": "stillos",
    "stillosestem": "stillos",
    "stillosesten": "stillos",
    "stillosester": "stillos",
    "stillosestes": "stillos",
    "stillschweige": "stillschweigen",
    "stillschweigend": "stillschweigen",
    "stillschweigende": "stillschweigend",
    "stillschweigendem": "stillschweigend",
    "stillschweigenden": "stillschweigend",
    "stillschweigender": "stillschweigend",
    "stillschweigendere": "stillschweigend",
    "stillschweigenderem": "stillschweigend",
    "stillschweigenderen": "stillschweigend",
    "stillschweigenderer": "stillschweigend",
    "stillschweigenderes": "stillschweigend",
    "stillschweigendes": "stillschweigend",
    "stillschweigendste": "stillschweigend",
    "stillschweigendstem": "stillschweigend",
    "stillschweigendsten": "stillschweigend",
    "stillschweigendster": "stillschweigend",
    "stillschweigendstes": "stillschweigend",
    "stillschweigest": "stillschweigen",
    "stillschweiget": "stillschweigen",
    "stillschweigst": "stillschweigen",
    "stillschweigt": "stillschweigen",
    "stillschwieg": "stillschweigen",
    "stillschwiege": "stillschweigen",
    "stillschwiegen": "stillschweigen",
    "stillschwiegest": "stillschweigen",
    "stillschwieget": "stillschweigen",
    "stillschwiegst": "stillschweigen",
    "stillschwiegt": "stillschweigen",
    "stillst": "stillen",
    "stillstem": "still",
    "stillsten": "still",
    "stillster": "still",
    "stillstes": "still",
    "stillt": "stillen",
    "stillte": "stillen",
    "stillten": "stillen",
    "stilltest": "stillen",
    "stilltet": "stillen",
    "stillzulegen": "stilllegen",
    "stillzuschweigen": "stillschweigen",
    "stilvollem": "stilvoll",
    "stilvollen": "stilvoll",
    "stilvoller": "stilvoll",
    "stilvollere": "stilvoll",
    "stilvollerem": "stilvoll",
    "stilvolleren": "stilvoll",
    "stilvollerer": "stilvoll",
    "stilvolleres": "stilvoll",
    "stilvolles": "stilvoll",
    "stilvollste": "stilvoll",
    "stilvollstem": "stilvoll",
    "stilvollsten": "stilvoll",
    "stilvollster": "stilvoll",
    "stilvollstes": "stilvoll",
    "stimmberechtigte": "stimmberechtigt",
    "stimmberechtigtem": "stimmberechtigt",
    "stimmberechtigten": "stimmberechtigt",
    "stimmberechtigter": "stimmberechtigt",
    "stimmberechtigtes": "stimmberechtigt",
    "stimmend": "stimmen",
    "stimmende": "stimmend",
    "stimmendem": "stimmend",
    "stimmenden": "stimmend",
    "stimmender": "stimmend",
    "stimmendes": "stimmend",
    "stimmest": "stimmen",
    "stimmet": "stimmen",
    "stimmgewaltigem": "stimmgewaltig",
    "stimmgewaltigen": "stimmgewaltig",
    "stimmgewaltiger": "stimmgewaltig",
    "stimmgewaltiges": "stimmgewaltig",
    "stimmige": "stimmig",
    "stimmigem": "stimmig",
    "stimmigen": "stimmig",
    "stimmiger": "stimmig",
    "stimmigere": "stimmig",
    "stimmigerem": "stimmig",
    "stimmigeren": "stimmig",
    "stimmigerer": "stimmig",
    "stimmigeres": "stimmig",
    "stimmiges": "stimmig",
    "stimmigste": "stimmig",
    "stimmigstem": "stimmig",
    "stimmigsten": "stimmig",
    "stimmigster": "stimmig",
    "stimmigstes": "stimmig",
    "stimmlichem": "stimmlich",
    "stimmlichen": "stimmlich",
    "stimmlicher": "stimmlich",
    "stimmliches": "stimmlich",
    "stimmst": "stimmen",
    "stimmt": "stimmen",
    "stimmte": "stimmen",
    "stimmten": "stimmen",
    "stimmtest": "stimmen",
    "stimmtet": "stimmen",
    "stimmungsvollem": "stimmungsvoll",
    "stimmungsvollen": "stimmungsvoll",
    "stimmungsvoller": "stimmungsvoll",
    "stimmungsvollere": "stimmungsvoll",
    "stimmungsvollerem": "stimmungsvoll",
    "stimmungsvolleren": "stimmungsvoll",
    "stimmungsvollerer": "stimmungsvoll",
    "stimmungsvolleres": "stimmungsvoll",
    "stimmungsvolles": "stimmungsvoll",
    "stimmungsvollste": "stimmungsvoll",
    "stimmungsvollstem": "stimmungsvoll",
    "stimmungsvollsten": "stimmungsvoll",
    "stimmungsvollster": "stimmungsvoll",
    "stimmungsvollstes": "stimmungsvoll",
    "stimuliere": "stimulieren",
    "stimulierend": "stimulieren",
    "stimulierende": "stimulierend",
    "stimulierendem": "stimulierend",
    "stimulierenden": "stimulierend",
    "stimulierender": "stimulierend",
    "stimulierendere": "stimulierend",
    "stimulierenderem": "stimulierend",
    "stimulierenderen": "stimulierend",
    "stimulierenderer": "stimulierend",
    "stimulierenderes": "stimulierend",
    "stimulierendes": "stimulierend",
    "stimulierendste": "stimulierend",
    "stimulierendstem": "stimulierend",
    "stimulierendsten": "stimulierend",
    "stimulierendster": "stimulierend",
    "stimulierendstes": "stimulierend",
    "stimulierest": "stimulieren",
    "stimulieret": "stimulieren",
    "stimulierst": "stimulieren",
    "stimuliert": "stimulieren",
    "stimulierte": "stimulieren",
    "stimuliertem": "stimuliert",
    "stimulierten": "stimulieren",
    "stimulierter": "stimuliert",
    "stimuliertere": "stimuliert",
    "stimulierterem": "stimuliert",
    "stimulierteren": "stimuliert",
    "stimulierterer": "stimuliert",
    "stimulierteres": "stimuliert",
    "stimuliertes": "stimuliert",
    "stimuliertest": "stimulieren",
    "stimulierteste": "stimuliert",
    "stimuliertestem": "stimuliert",
    "stimuliertesten": "stimuliert",
    "stimuliertester": "stimuliert",
    "stimuliertestes": "stimuliert",
    "stimuliertet": "stimulieren",
    "stinke": "stinken",
    "stinkend": "stinken",
    "stinkende": "stinkend",
    "stinkendem": "stinkend",
    "stinkenden": "stinkend",
    "stinkender": "stinkend",
    "stinkendere": "stinkend",
    "stinkenderem": "stinkend",
    "stinkenderen": "stinkend",
    "stinkenderer": "stinkend",
    "stinkenderes": "stinkend",
    "stinkendes": "stinkend",
    "stinkendste": "stinkend",
    "stinkendstem": "stinkend",
    "stinkendsten": "stinkend",
    "stinkendster": "stinkend",
    "stinkendstes": "stinkend",
    "stinkest": "stinken",
    "stinket": "stinken",
    "stinkfaule": "stinkfaul",
    "stinkfaulem": "stinkfaul",
    "stinkfaulen": "stinkfaul",
    "stinkfauler": "stinkfaul",
    "stinkfaules": "stinkfaul",
    "stinkige": "stinkig",
    "stinkigem": "stinkig",
    "stinkigen": "stinkig",
    "stinkiger": "stinkig",
    "stinkigere": "stinkig",
    "stinkigerem": "stinkig",
    "stinkigeren": "stinkig",
    "stinkigerer": "stinkig",
    "stinkigeres": "stinkig",
    "stinkiges": "stinkig",
    "stinkigste": "stinkig",
    "stinkigstem": "stinkig",
    "stinkigsten": "stinkig",
    "stinkigster": "stinkig",
    "stinkigstes": "stinkig",
    "stinklangweilige": "stinklangweilig",
    "stinklangweiligem": "stinklangweilig",
    "stinklangweiligen": "stinklangweilig",
    "stinklangweiliger": "stinklangweilig",
    "stinklangweiliges": "stinklangweilig",
    "stinkreichem": "stinkreich",
    "stinkreichen": "stinkreich",
    "stinkreicher": "stinkreich",
    "stinkreiches": "stinkreich",
    "stinkst": "stinken",
    "stinkt": "stinken",
    "stippe": "stippen",
    "stippend": "stippen",
    "stippende": "stippend",
    "stippendem": "stippend",
    "stippenden": "stippend",
    "stippender": "stippend",
    "stippendes": "stippend",
    "stippest": "stippen",
    "stippet": "stippen",
    "stippst": "stippen",
    "stippt": "stippen",
    "stippte": "stippen",
    "stippten": "stippen",
    "stipptest": "stippen",
    "stipptet": "stippen",
    "stirb": "sterben",
    "stirbst": "sterben",
    "stirbt": "sterben",
    "stob": "stieben",
    "stoben": "stieben",
    "stobst": "stieben",
    "stobt": "stieben",
    "stochere": "stochern",
    "stochernd": "stochern",
    "stochernde": "stochernd",
    "stocherndem": "stochernd",
    "stochernden": "stochernd",
    "stochernder": "stochernd",
    "stocherndes": "stochernd",
    "stocherst": "stochern",
    "stochert": "stochern",
    "stocherte": "stochern",
    "stocherten": "stochern",
    "stochertest": "stochern",
    "stochertet": "stochern",
    "stockend": "stocken",
    "stockende": "stockend",
    "stockendem": "stockend",
    "stockenden": "stockend",
    "stockender": "stockend",
    "stockendere": "stockend",
    "stockenderem": "stockend",
    "stockenderen": "stockend",
    "stockenderer": "stockend",
    "stockenderes": "stockend",
    "stockendes": "stockend",
    "stockendste": "stockend",
    "stockendstem": "stockend",
    "stockendsten": "stockend",
    "stockendster": "stockend",
    "stockendstes": "stockend",
    "stockest": "stocken",
    "stocket": "stocken",
    "stocknüchternem": "stocknüchtern",
    "stocknüchternen": "stocknüchtern",
    "stocknüchterner": "stocknüchtern",
    "stocknüchternes": "stocknüchtern",
    "stocksaurem": "stocksauer",
    "stocksauren": "stocksauer",
    "stocksaurer": "stocksauer",
    "stocksaures": "stocksauer",
    "stockst": "stocken",
    "stocksteife": "stocksteif",
    "stocksteifem": "stocksteif",
    "stocksteifen": "stocksteif",
    "stocksteifer": "stocksteif",
    "stocksteifes": "stocksteif",
    "stockt": "stocken",
    "stockte": "stocken",
    "stockten": "stocken",
    "stocktest": "stocken",
    "stocktet": "stocken",
    "stoffeligem": "stoffelig",
    "stoffeligen": "stoffelig",
    "stoffeliger": "stoffelig",
    "stoffeligere": "stoffelig",
    "stoffeligerem": "stoffelig",
    "stoffeligeren": "stoffelig",
    "stoffeligerer": "stoffelig",
    "stoffeligeres": "stoffelig",
    "stoffeliges": "stoffelig",
    "stoffeligste": "stoffelig",
    "stoffeligstem": "stoffelig",
    "stoffeligsten": "stoffelig",
    "stoffeligster": "stoffelig",
    "stoffeligstes": "stoffelig",
    "stofflichem": "stofflich",
    "stofflichen": "stofflich",
    "stofflicher": "stofflich",
    "stoffliches": "stofflich",
    "stolpere": "stolpern",
    "stolpernd": "stolpern",
    "stolpernde": "stolpernd",
    "stolperndem": "stolpernd",
    "stolpernden": "stolpernd",
    "stolpernder": "stolpernd",
    "stolperndes": "stolpernd",
    "stolperst": "stolpern",
    "stolpert": "stolpern",
    "stolperte": "stolpern",
    "stolperten": "stolpern",
    "stolpertest": "stolpern",
    "stolpertet": "stolpern",
    "stolzem": "stolz",
    "stolzen": "stolz",
    "stolzer": "stolz",
    "stolzere": "stolz",
    "stolzerem": "stolz",
    "stolzeren": "stolz",
    "stolzerer": "stolz",
    "stolzeres": "stolz",
    "stolzes": "stolz",
    "stolzestem": "stolz",
    "stolzesten": "stolz",
    "stolzester": "stolz",
    "stolzestes": "stolz",
    "stolziere": "stolzieren",
    "stolzierend": "stolzieren",
    "stolzierende": "stolzierend",
    "stolzierendem": "stolzierend",
    "stolzierenden": "stolzierend",
    "stolzierender": "stolzierend",
    "stolzierendes": "stolzierend",
    "stolzierest": "stolzieren",
    "stolzieret": "stolzieren",
    "stolzierst": "stolzieren",
    "stolziert": "stolzieren",
    "stolzierte": "stolzieren",
    "stolziertem": "stolziert",
    "stolzierten": "stolzieren",
    "stolzierter": "stolziert",
    "stolziertes": "stolziert",
    "stolziertest": "stolzieren",
    "stolziertet": "stolzieren",
    "stopfe": "stopfen",
    "stopfend": "stopfen",
    "stopfende": "stopfend",
    "stopfendem": "stopfend",
    "stopfenden": "stopfend",
    "stopfender": "stopfend",
    "stopfendere": "stopfend",
    "stopfenderem": "stopfend",
    "stopfenderen": "stopfend",
    "stopfenderer": "stopfend",
    "stopfenderes": "stopfend",
    "stopfendes": "stopfend",
    "stopfendste": "stopfend",
    "stopfendstem": "stopfend",
    "stopfendsten": "stopfend",
    "stopfendster": "stopfend",
    "stopfendstes": "stopfend",
    "stopfest": "stopfen",
    "stopfet": "stopfen",
    "stopfst": "stopfen",
    "stopft": "stopfen",
    "stopfte": "stopfen",
    "stopften": "stopfen",
    "stopftest": "stopfen",
    "stopftet": "stopfen",
    "stoppe": "stoppen",
    "stoppele": "stoppeln",
    "stoppelige": "stoppelig",
    "stoppeligem": "stoppelig",
    "stoppeligen": "stoppelig",
    "stoppeliger": "stoppelig",
    "stoppeligere": "stoppelig",
    "stoppeligerem": "stoppelig",
    "stoppeligeren": "stoppelig",
    "stoppeligerer": "stoppelig",
    "stoppeligeres": "stoppelig",
    "stoppeliges": "stoppelig",
    "stoppeligste": "stoppelig",
    "stoppeligstem": "stoppelig",
    "stoppeligsten": "stoppelig",
    "stoppeligster": "stoppelig",
    "stoppeligstes": "stoppelig",
    "stoppelnd": "stoppeln",
    "stoppelnde": "stoppelnd",
    "stoppelndem": "stoppelnd",
    "stoppelnden": "stoppelnd",
    "stoppelnder": "stoppelnd",
    "stoppelndes": "stoppelnd",
    "stoppelst": "stoppeln",
    "stoppelt": "stoppeln",
    "stoppelte": "stoppeln",
    "stoppelten": "stoppeln",
    "stoppeltest": "stoppeln",
    "stoppeltet": "stoppeln",
    "stoppend": "stoppen",
    "stoppende": "stoppend",
    "stoppendem": "stoppend",
    "stoppenden": "stoppend",
    "stoppender": "stoppend",
    "stoppendes": "stoppend",
    "stoppest": "stoppen",
    "stoppet": "stoppen",
    "stopple": "stoppeln",
    "stoppst": "stoppen",
    "stoppt": "stoppen",
    "stoppte": "stoppen",
    "stoppten": "stoppen",
    "stopptest": "stoppen",
    "stopptet": "stoppen",
    "storniere": "stornieren",
    "stornierend": "stornieren",
    "stornierende": "stornierend",
    "stornierendem": "stornierend",
    "stornierenden": "stornierend",
    "stornierender": "stornierend",
    "stornierendes": "stornierend",
    "stornierest": "stornieren",
    "stornieret": "stornieren",
    "stornierst": "stornieren",
    "storniert": "stornieren",
    "stornierte": "stornieren",
    "storniertem": "storniert",
    "stornierten": "stornieren",
    "stornierter": "storniert",
    "storniertes": "storniert",
    "storniertest": "stornieren",
    "storniertet": "stornieren",
    "stottere": "stottern",
    "stotternd": "stottern",
    "stotternde": "stotternd",
    "stotterndem": "stotternd",
    "stotternden": "stotternd",
    "stotternder": "stotternd",
    "stotterndere": "stotternd",
    "stotternderem": "stotternd",
    "stotternderen": "stotternd",
    "stotternderer": "stotternd",
    "stotternderes": "stotternd",
    "stotterndes": "stotternd",
    "stotterndste": "stotternd",
    "stotterndstem": "stotternd",
    "stotterndsten": "stotternd",
    "stotterndster": "stotternd",
    "stotterndstes": "stotternd",
    "stotterst": "stottern",
    "stottert": "stottern",
    "stotterte": "stottern",
    "stotterten": "stottern",
    "stottertest": "stottern",
    "stottertet": "stottern",
    "stoßempfindlichem": "stoßempfindlich",
    "stoßempfindlichen": "stoßempfindlich",
    "stoßempfindlicher": "stoßempfindlich",
    "stoßempfindliches": "stoßempfindlich",
    "stoßend": "stoßen",
    "stoßende": "stoßend",
    "stoßendem": "stoßend",
    "stoßenden": "stoßend",
    "stoßender": "stoßend",
    "stoßendes": "stoßend",
    "stoßest": "stoßen",
    "stoßet": "stoßen",
    "stoßfeste": "stoßfest",
    "stoßfestem": "stoßfest",
    "stoßfesten": "stoßfest",
    "stoßfester": "stoßfest",
    "stoßfestere": "stoßfest",
    "stoßfesterem": "stoßfest",
    "stoßfesteren": "stoßfest",
    "stoßfesterer": "stoßfest",
    "stoßfesteres": "stoßfest",
    "stoßfestes": "stoßfest",
    "stoßfesteste": "stoßfest",
    "stoßfestestem": "stoßfest",
    "stoßfestesten": "stoßfest",
    "stoßfestester": "stoßfest",
    "stoßfestestes": "stoßfest",
    "stoßsichere": "stoßsicher",
    "stoßsicherem": "stoßsicher",
    "stoßsicheren": "stoßsicher",
    "stoßsicherer": "stoßsicher",
    "stoßsicherere": "stoßsicher",
    "stoßsichererem": "stoßsicher",
    "stoßsichereren": "stoßsicher",
    "stoßsichererer": "stoßsicher",
    "stoßsichereres": "stoßsicher",
    "stoßsicheres": "stoßsicher",
    "stoßsicherste": "stoßsicher",
    "stoßsicherstem": "stoßsicher",
    "stoßsichersten": "stoßsicher",
    "stoßsicherster": "stoßsicher",
    "stoßsicherstes": "stoßsicher",
    "stoßt": "stoßen",
    "strafbarem": "strafbar",
    "strafbaren": "strafbar",
    "strafbarer": "strafbar",
    "strafbarere": "strafbar",
    "strafbarerem": "strafbar",
    "strafbareren": "strafbar",
    "strafbarerer": "strafbar",
    "strafbareres": "strafbar",
    "strafbares": "strafbar",
    "strafbarste": "strafbar",
    "strafbarstem": "strafbar",
    "strafbarsten": "strafbar",
    "strafbarster": "strafbar",
    "strafbarstes": "strafbar",
    "strafend": "strafen",
    "strafende": "strafend",
    "strafendem": "strafend",
    "strafenden": "strafend",
    "strafender": "strafend",
    "strafendere": "strafend",
    "strafenderem": "strafend",
    "strafenderen": "strafend",
    "strafenderer": "strafend",
    "strafenderes": "strafend",
    "strafendes": "strafend",
    "strafendste": "strafend",
    "strafendstem": "strafend",
    "strafendsten": "strafend",
    "strafendster": "strafend",
    "strafendstes": "strafend",
    "strafest": "strafen",
    "strafet": "strafen",
    "straffe": "straff",
    "straffem": "straff",
    "straffen": "straff",
    "straffer": "straff",
    "straffere": "straff",
    "strafferem": "straff",
    "strafferen": "straff",
    "strafferer": "straff",
    "strafferes": "straff",
    "straffes": "straff",
    "straffreie": "straffrei",
    "straffreiem": "straffrei",
    "straffreien": "straffrei",
    "straffreier": "straffrei",
    "straffreies": "straffrei",
    "straffste": "straff",
    "straffstem": "straff",
    "straffsten": "straff",
    "straffster": "straff",
    "straffstes": "straff",
    "straffällige": "straffällig",
    "straffälligem": "straffällig",
    "straffälligen": "straffällig",
    "straffälliger": "straffällig",
    "straffälliges": "straffällig",
    "strafmildernde": "strafmildernd",
    "strafmilderndem": "strafmildernd",
    "strafmildernden": "strafmildernd",
    "strafmildernder": "strafmildernd",
    "strafmilderndes": "strafmildernd",
    "strafmündige": "strafmündig",
    "strafmündigem": "strafmündig",
    "strafmündigen": "strafmündig",
    "strafmündiger": "strafmündig",
    "strafmündiges": "strafmündig",
    "strafrechtlichem": "strafrechtlich",
    "strafrechtlichen": "strafrechtlich",
    "strafrechtlicher": "strafrechtlich",
    "strafrechtliches": "strafrechtlich",
    "strafst": "strafen",
    "straft": "strafen",
    "strafte": "strafen",
    "straften": "strafen",
    "straftest": "strafen",
    "straftet": "strafen",
    "strafverschärfende": "strafverschärfend",
    "strafverschärfendem": "strafverschärfend",
    "strafverschärfenden": "strafverschärfend",
    "strafverschärfender": "strafverschärfend",
    "strafverschärfendes": "strafverschärfend",
    "strahlend": "strahlen",
    "strahlende": "strahlend",
    "strahlendem": "strahlend",
    "strahlenden": "strahlend",
    "strahlender": "strahlend",
    "strahlendere": "strahlend",
    "strahlenderem": "strahlend",
    "strahlenderen": "strahlend",
    "strahlenderer": "strahlend",
    "strahlenderes": "strahlend",
    "strahlendes": "strahlend",
    "strahlendste": "strahlend",
    "strahlendstem": "strahlend",
    "strahlendsten": "strahlend",
    "strahlendster": "strahlend",
    "strahlendstes": "strahlend",
    "strahlest": "strahlen",
    "strahlet": "strahlen",
    "strahlst": "strahlen",
    "strahlt": "strahlen",
    "strahlte": "strahlen",
    "strahlten": "strahlen",
    "strahltest": "strahlen",
    "strahltet": "strahlen",
    "strammgestanden": "strammstehen",
    "strammgestandene": "strammgestanden",
    "strammgestandenem": "strammgestanden",
    "strammgestandenen": "strammgestanden",
    "strammgestandener": "strammgestanden",
    "strammgestandenere": "strammgestanden",
    "strammgestandenerem": "strammgestanden",
    "strammgestandeneren": "strammgestanden",
    "strammgestandenerer": "strammgestanden",
    "strammgestandeneres": "strammgestanden",
    "strammgestandenes": "strammgestanden",
    "strammgestandenste": "strammgestanden",
    "strammgestandenstem": "strammgestanden",
    "strammgestandensten": "strammgestanden",
    "strammgestandenster": "strammgestanden",
    "strammgestandenstes": "strammgestanden",
    "strammstand": "strammstehen",
    "strammstanden": "strammstehen",
    "strammstandest": "strammstehen",
    "strammstandet": "strammstehen",
    "strammstehe": "strammstehen",
    "strammstehend": "strammstehen",
    "strammstehende": "strammstehend",
    "strammstehendem": "strammstehend",
    "strammstehenden": "strammstehend",
    "strammstehender": "strammstehend",
    "strammstehendere": "strammstehend",
    "strammstehenderem": "strammstehend",
    "strammstehenderen": "strammstehend",
    "strammstehenderer": "strammstehend",
    "strammstehenderes": "strammstehend",
    "strammstehendes": "strammstehend",
    "strammstehendste": "strammstehend",
    "strammstehendstem": "strammstehend",
    "strammstehendsten": "strammstehend",
    "strammstehendster": "strammstehend",
    "strammstehendstes": "strammstehend",
    "strammstehest": "strammstehen",
    "strammstehet": "strammstehen",
    "strammstehst": "strammstehen",
    "strammsteht": "strammstehen",
    "strammstünde": "strammstehen",
    "strammstünden": "strammstehen",
    "strammstündest": "strammstehen",
    "strammstündet": "strammstehen",
    "strammzustehen": "strammstehen",
    "strampele": "strampeln",
    "strampelnd": "strampeln",
    "strampelnde": "strampelnd",
    "strampelndem": "strampelnd",
    "strampelnden": "strampelnd",
    "strampelnder": "strampelnd",
    "strampelndes": "strampelnd",
    "strampelst": "strampeln",
    "strampelt": "strampeln",
    "strampelte": "strampeln",
    "strampelten": "strampeln",
    "strampeltest": "strampeln",
    "strampeltet": "strampeln",
    "strample": "strampeln",
    "strandend": "stranden",
    "strandende": "strandend",
    "strandendem": "strandend",
    "strandenden": "strandend",
    "strandender": "strandend",
    "strandendes": "strandend",
    "strandest": "stranden",
    "strandet": "stranden",
    "strandete": "stranden",
    "strandeten": "stranden",
    "strandetest": "stranden",
    "strandetet": "stranden",
    "stranguliere": "strangulieren",
    "strangulierend": "strangulieren",
    "strangulierende": "strangulierend",
    "strangulierendem": "strangulierend",
    "strangulierenden": "strangulierend",
    "strangulierender": "strangulierend",
    "strangulierendes": "strangulierend",
    "strangulierest": "strangulieren",
    "strangulieret": "strangulieren",
    "strangulierst": "strangulieren",
    "stranguliert": "strangulieren",
    "strangulierte": "strangulieren",
    "stranguliertem": "stranguliert",
    "strangulierten": "strangulieren",
    "strangulierter": "stranguliert",
    "stranguliertes": "stranguliert",
    "stranguliertest": "strangulieren",
    "stranguliertet": "strangulieren",
    "strapaziere": "strapazieren",
    "strapazierend": "strapazieren",
    "strapazierende": "strapazierend",
    "strapazierendem": "strapazierend",
    "strapazierenden": "strapazierend",
    "strapazierender": "strapazierend",
    "strapazierendere": "strapazierend",
    "strapazierenderem": "strapazierend",
    "strapazierenderen": "strapazierend",
    "strapazierenderer": "strapazierend",
    "strapazierenderes": "strapazierend",
    "strapazierendes": "strapazierend",
    "strapazierendste": "strapazierend",
    "strapazierendstem": "strapazierend",
    "strapazierendsten": "strapazierend",
    "strapazierendster": "strapazierend",
    "strapazierendstes": "strapazierend",
    "strapazierest": "strapazieren",
    "strapazieret": "strapazieren",
    "strapazierfähige": "strapazierfähig",
    "strapazierfähigem": "strapazierfähig",
    "strapazierfähigen": "strapazierfähig",
    "strapazierfähiger": "strapazierfähig",
    "strapazierfähigere": "strapazierfähig",
    "strapazierfähigerem": "strapazierfähig",
    "strapazierfähigeren": "strapazierfähig",
    "strapazierfähigerer": "strapazierfähig",
    "strapazierfähigeres": "strapazierfähig",
    "strapazierfähiges": "strapazierfähig",
    "strapazierfähigste": "strapazierfähig",
    "strapazierfähigstem": "strapazierfähig",
    "strapazierfähigsten": "strapazierfähig",
    "strapazierfähigster": "strapazierfähig",
    "strapazierfähigstes": "strapazierfähig",
    "strapazierst": "strapazieren",
    "strapaziert": "strapazieren",
    "strapazierte": "strapazieren",
    "strapaziertem": "strapaziert",
    "strapazierten": "strapazieren",
    "strapazierter": "strapaziert",
    "strapaziertere": "strapaziert",
    "strapazierterem": "strapaziert",
    "strapazierteren": "strapaziert",
    "strapazierterer": "strapaziert",
    "strapazierteres": "strapaziert",
    "strapaziertes": "strapaziert",
    "strapaziertest": "strapazieren",
    "strapazierteste": "strapaziert",
    "strapaziertestem": "strapaziert",
    "strapaziertesten": "strapaziert",
    "strapaziertester": "strapaziert",
    "strapaziertestes": "strapaziert",
    "strapaziertet": "strapazieren",
    "strapaziöse": "strapaziös",
    "strapaziösem": "strapaziös",
    "strapaziösen": "strapaziös",
    "strapaziöser": "strapaziös",
    "strapaziösere": "strapaziös",
    "strapaziöserem": "strapaziös",
    "strapaziöseren": "strapaziös",
    "strapaziöserer": "strapaziös",
    "strapaziöseres": "strapaziös",
    "strapaziöses": "strapaziös",
    "strapaziöseste": "strapaziös",
    "strapaziösestem": "strapaziös",
    "strapaziösesten": "strapaziös",
    "strapaziösester": "strapaziös",
    "strapaziösestes": "strapaziös",
    "strategischem": "strategisch",
    "strategischen": "strategisch",
    "strategischer": "strategisch",
    "strategisches": "strategisch",
    "strauchele": "straucheln",
    "strauchelnd": "straucheln",
    "strauchelnde": "strauchelnd",
    "strauchelndem": "strauchelnd",
    "strauchelnden": "strauchelnd",
    "strauchelnder": "strauchelnd",
    "strauchelndere": "strauchelnd",
    "strauchelnderem": "strauchelnd",
    "strauchelnderen": "strauchelnd",
    "strauchelnderer": "strauchelnd",
    "strauchelnderes": "strauchelnd",
    "strauchelndes": "strauchelnd",
    "strauchelndste": "strauchelnd",
    "strauchelndstem": "strauchelnd",
    "strauchelndsten": "strauchelnd",
    "strauchelndster": "strauchelnd",
    "strauchelndstes": "strauchelnd",
    "strauchelst": "straucheln",
    "strauchelt": "straucheln",
    "strauchelte": "straucheln",
    "strauchelten": "straucheln",
    "straucheltest": "straucheln",
    "straucheltet": "straucheln",
    "strauchle": "straucheln",
    "strebe": "streben",
    "strebend": "streben",
    "strebende": "strebend",
    "strebendem": "strebend",
    "strebenden": "strebend",
    "strebender": "strebend",
    "strebendere": "strebend",
    "strebenderem": "strebend",
    "strebenderen": "strebend",
    "strebenderer": "strebend",
    "strebenderes": "strebend",
    "strebendes": "strebend",
    "strebendste": "strebend",
    "strebendstem": "strebend",
    "strebendsten": "strebend",
    "strebendster": "strebend",
    "strebendstes": "strebend",
    "strebest": "streben",
    "strebet": "streben",
    "strebsame": "strebsam",
    "strebsamem": "strebsam",
    "strebsamen": "strebsam",
    "strebsamer": "strebsam",
    "strebsamere": "strebsam",
    "strebsamerem": "strebsam",
    "strebsameren": "strebsam",
    "strebsamerer": "strebsam",
    "strebsameres": "strebsam",
    "strebsames": "strebsam",
    "strebsamste": "strebsam",
    "strebsamstem": "strebsam",
    "strebsamsten": "strebsam",
    "strebsamster": "strebsam",
    "strebsamstes": "strebsam",
    "strebst": "streben",
    "strebt": "streben",
    "strebte": "streben",
    "strebten": "streben",
    "strebtest": "streben",
    "strebtet": "streben",
    "strecke": "strecken",
    "streckend": "strecken",
    "streckende": "streckend",
    "streckendem": "streckend",
    "streckenden": "streckend",
    "streckender": "streckend",
    "streckendere": "streckend",
    "streckenderem": "streckend",
    "streckenderen": "streckend",
    "streckenderer": "streckend",
    "streckenderes": "streckend",
    "streckendes": "streckend",
    "streckendste": "streckend",
    "streckendstem": "streckend",
    "streckendsten": "streckend",
    "streckendster": "streckend",
    "streckendstes": "streckend",
    "streckest": "strecken",
    "strecket": "strecken",
    "streckst": "strecken",
    "streckt": "strecken",
    "streckte": "strecken",
    "streckten": "strecken",
    "strecktest": "strecken",
    "strecktet": "strecken",
    "streichele": "streicheln",
    "streichelnd": "streicheln",
    "streichelnde": "streichelnd",
    "streichelndem": "streichelnd",
    "streichelnden": "streichelnd",
    "streichelnder": "streichelnd",
    "streichelndes": "streichelnd",
    "streichelst": "streicheln",
    "streichelt": "streicheln",
    "streichelte": "streicheln",
    "streichelten": "streicheln",
    "streicheltest": "streicheln",
    "streicheltet": "streicheln",
    "streichend": "streichen",
    "streichende": "streichend",
    "streichendem": "streichend",
    "streichenden": "streichend",
    "streichender": "streichend",
    "streichendes": "streichend",
    "streichest": "streichen",
    "streichet": "streichen",
    "streichle": "streicheln",
    "streichst": "streichen",
    "streicht": "streichen",
    "streifend": "streifen",
    "streifende": "streifend",
    "streifendem": "streifend",
    "streifenden": "streifend",
    "streifender": "streifend",
    "streifendes": "streifend",
    "streifest": "streifen",
    "streifet": "streifen",
    "streifst": "streifen",
    "streift": "streifen",
    "streifte": "streifen",
    "streiften": "streifen",
    "streiftest": "streifen",
    "streiftet": "streifen",
    "streike": "streiken",
    "streikend": "streiken",
    "streikende": "streikend",
    "streikendem": "streikend",
    "streikenden": "streikend",
    "streikender": "streikend",
    "streikendes": "streikend",
    "streikest": "streiken",
    "streiket": "streiken",
    "streikst": "streiken",
    "streikt": "streiken",
    "streikte": "streiken",
    "streikten": "streiken",
    "streiktest": "streiken",
    "streiktet": "streiken",
    "streitend": "streiten",
    "streitende": "streitend",
    "streitendem": "streitend",
    "streitenden": "streitend",
    "streitender": "streitend",
    "streitendere": "streitend",
    "streitenderem": "streitend",
    "streitenderen": "streitend",
    "streitenderer": "streitend",
    "streitenderes": "streitend",
    "streitendes": "streitend",
    "streitendste": "streitend",
    "streitendstem": "streitend",
    "streitendsten": "streitend",
    "streitendster": "streitend",
    "streitendstes": "streitend",
    "streitest": "streiten",
    "streitet": "streiten",
    "streitlustigem": "streitlustig",
    "streitlustigen": "streitlustig",
    "streitlustiger": "streitlustig",
    "streitlustigere": "streitlustig",
    "streitlustigerem": "streitlustig",
    "streitlustigeren": "streitlustig",
    "streitlustigerer": "streitlustig",
    "streitlustigeres": "streitlustig",
    "streitlustiges": "streitlustig",
    "streitlustigste": "streitlustig",
    "streitlustigstem": "streitlustig",
    "streitlustigsten": "streitlustig",
    "streitlustigster": "streitlustig",
    "streitlustigstes": "streitlustig",
    "streitsüchtigem": "streitsüchtig",
    "streitsüchtigen": "streitsüchtig",
    "streitsüchtiger": "streitsüchtig",
    "streitsüchtigere": "streitsüchtig",
    "streitsüchtigerem": "streitsüchtig",
    "streitsüchtigeren": "streitsüchtig",
    "streitsüchtigerer": "streitsüchtig",
    "streitsüchtigeres": "streitsüchtig",
    "streitsüchtiges": "streitsüchtig",
    "streitsüchtigste": "streitsüchtig",
    "streitsüchtigstem": "streitsüchtig",
    "streitsüchtigsten": "streitsüchtig",
    "streitsüchtigster": "streitsüchtig",
    "streitsüchtigstes": "streitsüchtig",
    "streng": "strengen",
    "strenge": "streng",
    "strengem": "streng",
    "strengen": "streng",
    "strengend": "strengen",
    "strenger": "streng",
    "strengere": "streng",
    "strengerem": "streng",
    "strengeren": "streng",
    "strengerer": "streng",
    "strengeres": "streng",
    "strenges": "streng",
    "strengest": "strengen",
    "strenget": "strengen",
    "strenggläubige": "strenggläubig",
    "strenggläubigem": "strenggläubig",
    "strenggläubigen": "strenggläubig",
    "strenggläubiger": "strenggläubig",
    "strenggläubiges": "strenggläubig",
    "strengst": "strengen",
    "strengste": "streng",
    "strengstem": "streng",
    "strengsten": "streng",
    "strengster": "streng",
    "strengstes": "streng",
    "strengt": "strengen",
    "strengte": "strengen",
    "strengten": "strengen",
    "strengtest": "strengen",
    "strengtet": "strengen",
    "stressend": "stressen",
    "stressende": "stressend",
    "stressendem": "stressend",
    "stressenden": "stressend",
    "stressender": "stressend",
    "stressendere": "stressend",
    "stressenderem": "stressend",
    "stressenderen": "stressend",
    "stressenderer": "stressend",
    "stressenderes": "stressend",
    "stressendes": "stressend",
    "stressendste": "stressend",
    "stressendstem": "stressend",
    "stressendsten": "stressend",
    "stressendster": "stressend",
    "stressendstes": "stressend",
    "stressest": "stressen",
    "stresset": "stressen",
    "streue": "streuen",
    "streuend": "streuen",
    "streuende": "streuend",
    "streuendem": "streuend",
    "streuenden": "streuend",
    "streuender": "streuend",
    "streuendes": "streuend",
    "streuest": "streuen",
    "streuet": "streuen",
    "streune": "streunen",
    "streunend": "streunen",
    "streunende": "streunend",
    "streunendem": "streunend",
    "streunenden": "streunend",
    "streunender": "streunend",
    "streunendere": "streunend",
    "streunenderem": "streunend",
    "streunenderen": "streunend",
    "streunenderer": "streunend",
    "streunenderes": "streunend",
    "streunendes": "streunend",
    "streunendste": "streunend",
    "streunendstem": "streunend",
    "streunendsten": "streunend",
    "streunendster": "streunend",
    "streunendstes": "streunend",
    "streunest": "streunen",
    "streunet": "streunen",
    "streunst": "streunen",
    "streunt": "streunen",
    "streunte": "streunen",
    "streunten": "streunen",
    "streuntest": "streunen",
    "streuntet": "streunen",
    "streusele": "streuseln",
    "streuselnd": "streuseln",
    "streuselnde": "streuselnd",
    "streuselndem": "streuselnd",
    "streuselnden": "streuselnd",
    "streuselnder": "streuselnd",
    "streuselndes": "streuselnd",
    "streuselst": "streuseln",
    "streuselt": "streuseln",
    "streuselte": "streuseln",
    "streuselten": "streuseln",
    "streuseltest": "streuseln",
    "streuseltet": "streuseln",
    "streusle": "streuseln",
    "streust": "streuen",
    "streut": "streuen",
    "streute": "streuen",
    "streuten": "streuen",
    "streutest": "streuen",
    "streutet": "streuen",
    "streßt": "stressen",
    "streßte": "stressen",
    "streßten": "stressen",
    "streßtest": "stressen",
    "streßtet": "stressen",
    "strich": "streichen",
    "strichest": "streichen",
    "strichet": "streichen",
    "strichst": "streichen",
    "stricht": "streichen",
    "striegele": "striegeln",
    "striegelnd": "striegeln",
    "striegelnde": "striegelnd",
    "striegelndem": "striegelnd",
    "striegelnden": "striegelnd",
    "striegelnder": "striegelnd",
    "striegelndere": "striegelnd",
    "striegelnderem": "striegelnd",
    "striegelnderen": "striegelnd",
    "striegelnderer": "striegelnd",
    "striegelnderes": "striegelnd",
    "striegelndes": "striegelnd",
    "striegelndste": "striegelnd",
    "striegelndstem": "striegelnd",
    "striegelndsten": "striegelnd",
    "striegelndster": "striegelnd",
    "striegelndstes": "striegelnd",
    "striegelst": "striegeln",
    "striegelt": "striegeln",
    "striegelte": "striegeln",
    "striegelten": "striegeln",
    "striegeltest": "striegeln",
    "striegeltet": "striegeln",
    "striegle": "striegeln",
    "striktem": "strikt",
    "strikten": "strikt",
    "strikter": "strikt",
    "striktere": "strikt",
    "strikterem": "strikt",
    "strikteren": "strikt",
    "strikterer": "strikt",
    "strikteres": "strikt",
    "striktes": "strikt",
    "strikteste": "strikt",
    "striktestem": "strikt",
    "striktesten": "strikt",
    "striktester": "strikt",
    "striktestes": "strikt",
    "stringentem": "stringent",
    "stringenten": "stringent",
    "stringenter": "stringent",
    "stringentes": "stringent",
    "strippend": "strippen",
    "strippende": "strippend",
    "strippendem": "strippend",
    "strippenden": "strippend",
    "strippender": "strippend",
    "strippendere": "strippend",
    "strippenderem": "strippend",
    "strippenderen": "strippend",
    "strippenderer": "strippend",
    "strippenderes": "strippend",
    "strippendes": "strippend",
    "strippendste": "strippend",
    "strippendstem": "strippend",
    "strippendsten": "strippend",
    "strippendster": "strippend",
    "strippendstes": "strippend",
    "strippest": "strippen",
    "strippet": "strippen",
    "strippst": "strippen",
    "strippt": "strippen",
    "strippte": "strippen",
    "strippten": "strippen",
    "stripptest": "strippen",
    "stripptet": "strippen",
    "stritt": "streiten",
    "stritte": "streiten",
    "stritten": "streiten",
    "strittest": "streiten",
    "strittet": "streiten",
    "strittige": "strittig",
    "strittigem": "strittig",
    "strittigen": "strittig",
    "strittiger": "strittig",
    "strittigere": "strittig",
    "strittigerem": "strittig",
    "strittigeren": "strittig",
    "strittigerer": "strittig",
    "strittigeres": "strittig",
    "strittiges": "strittig",
    "strittigste": "strittig",
    "strittigstem": "strittig",
    "strittigsten": "strittig",
    "strittigster": "strittig",
    "strittigstes": "strittig",
    "strohdumme": "strohdumm",
    "strohdummem": "strohdumm",
    "strohdummen": "strohdumm",
    "strohdummer": "strohdumm",
    "strohdummes": "strohdumm",
    "strohigem": "strohig",
    "strohigen": "strohig",
    "strohiger": "strohig",
    "strohigere": "strohig",
    "strohigerem": "strohig",
    "strohigeren": "strohig",
    "strohigerer": "strohig",
    "strohigeres": "strohig",
    "strohiges": "strohig",
    "strohigste": "strohig",
    "strohigstem": "strohig",
    "strohigsten": "strohig",
    "strohigster": "strohig",
    "strohigstes": "strohig",
    "strolchend": "strolchen",
    "strolchende": "strolchend",
    "strolchendem": "strolchend",
    "strolchenden": "strolchend",
    "strolchender": "strolchend",
    "strolchendere": "strolchend",
    "strolchenderem": "strolchend",
    "strolchenderen": "strolchend",
    "strolchenderer": "strolchend",
    "strolchenderes": "strolchend",
    "strolchendes": "strolchend",
    "strolchendste": "strolchend",
    "strolchendstem": "strolchend",
    "strolchendsten": "strolchend",
    "strolchendster": "strolchend",
    "strolchendstes": "strolchend",
    "strolchest": "strolchen",
    "strolchet": "strolchen",
    "strolchst": "strolchen",
    "strolcht": "strolchen",
    "strolchte": "strolchen",
    "strolchten": "strolchen",
    "strolchtest": "strolchen",
    "strolchtet": "strolchen",
    "stromere": "stromern",
    "stromernd": "stromern",
    "stromernde": "stromernd",
    "stromerndem": "stromernd",
    "stromernden": "stromernd",
    "stromernder": "stromernd",
    "stromerndere": "stromernd",
    "stromernderem": "stromernd",
    "stromernderen": "stromernd",
    "stromernderer": "stromernd",
    "stromernderes": "stromernd",
    "stromerndes": "stromernd",
    "stromerndste": "stromernd",
    "stromerndstem": "stromernd",
    "stromerndsten": "stromernd",
    "stromerndster": "stromernd",
    "stromerndstes": "stromernd",
    "stromerst": "stromern",
    "stromert": "stromern",
    "stromerte": "stromern",
    "stromerten": "stromern",
    "stromertest": "stromern",
    "stromertet": "stromern",
    "strotze": "strotzen",
    "strotzend": "strotzen",
    "strotzende": "strotzend",
    "strotzendem": "strotzend",
    "strotzenden": "strotzend",
    "strotzender": "strotzend",
    "strotzendere": "strotzend",
    "strotzenderem": "strotzend",
    "strotzenderen": "strotzend",
    "strotzenderer": "strotzend",
    "strotzenderes": "strotzend",
    "strotzendes": "strotzend",
    "strotzendste": "strotzend",
    "strotzendstem": "strotzend",
    "strotzendsten": "strotzend",
    "strotzendster": "strotzend",
    "strotzendstes": "strotzend",
    "strotzest": "strotzen",
    "strotzet": "strotzen",
    "strotzt": "strotzen",
    "strotzte": "strotzen",
    "strotzten": "strotzen",
    "strotztest": "strotzen",
    "strotztet": "strotzen",
    "strubbelige": "strubbelig",
    "strubbeligem": "strubbelig",
    "strubbeligen": "strubbelig",
    "strubbeliger": "strubbelig",
    "strubbeligere": "strubbelig",
    "strubbeligerem": "strubbelig",
    "strubbeligeren": "strubbelig",
    "strubbeligerer": "strubbelig",
    "strubbeligeres": "strubbelig",
    "strubbeliges": "strubbelig",
    "strubbeligste": "strubbelig",
    "strubbeligstem": "strubbelig",
    "strubbeligsten": "strubbelig",
    "strubbeligster": "strubbelig",
    "strubbeligstes": "strubbelig",
    "strudele": "strudeln",
    "strudelnd": "strudeln",
    "strudelnde": "strudelnd",
    "strudelndem": "strudelnd",
    "strudelnden": "strudelnd",
    "strudelnder": "strudelnd",
    "strudelndere": "strudelnd",
    "strudelnderem": "strudelnd",
    "strudelnderen": "strudelnd",
    "strudelnderer": "strudelnd",
    "strudelnderes": "strudelnd",
    "strudelndes": "strudelnd",
    "strudelndste": "strudelnd",
    "strudelndstem": "strudelnd",
    "strudelndsten": "strudelnd",
    "strudelndster": "strudelnd",
    "strudelndstes": "strudelnd",
    "strudelst": "strudeln",
    "strudelt": "strudeln",
    "strudelte": "strudeln",
    "strudelten": "strudeln",
    "strudeltest": "strudeln",
    "strudeltet": "strudeln",
    "strudle": "strudeln",
    "strukturelle": "strukturell",
    "strukturellem": "strukturell",
    "strukturellen": "strukturell",
    "struktureller": "strukturell",
    "strukturellere": "strukturell",
    "strukturellerem": "strukturell",
    "strukturelleren": "strukturell",
    "strukturellerer": "strukturell",
    "strukturelleres": "strukturell",
    "strukturelles": "strukturell",
    "strukturellste": "strukturell",
    "strukturellstem": "strukturell",
    "strukturellsten": "strukturell",
    "strukturellster": "strukturell",
    "strukturellstes": "strukturell",
    "strukturierend": "strukturieren",
    "strukturierende": "strukturierend",
    "strukturierendem": "strukturierend",
    "strukturierenden": "strukturierend",
    "strukturierender": "strukturierend",
    "strukturierendere": "strukturierend",
    "strukturierenderem": "strukturierend",
    "strukturierenderen": "strukturierend",
    "strukturierenderer": "strukturierend",
    "strukturierenderes": "strukturierend",
    "strukturierendes": "strukturierend",
    "strukturierendste": "strukturierend",
    "strukturierendstem": "strukturierend",
    "strukturierendsten": "strukturierend",
    "strukturierendster": "strukturierend",
    "strukturierendstes": "strukturierend",
    "strukturierest": "strukturieren",
    "strukturieret": "strukturieren",
    "strukturierst": "strukturieren",
    "strukturiert": "strukturieren",
    "strukturierte": "strukturieren",
    "strukturiertem": "strukturiert",
    "strukturierten": "strukturieren",
    "strukturierter": "strukturiert",
    "strukturiertere": "strukturiert",
    "strukturierterem": "strukturiert",
    "strukturierteren": "strukturiert",
    "strukturierterer": "strukturiert",
    "strukturierteres": "strukturiert",
    "strukturiertes": "strukturiert",
    "strukturiertest": "strukturieren",
    "strukturierteste": "strukturiert",
    "strukturiertestem": "strukturiert",
    "strukturiertesten": "strukturiert",
    "strukturiertester": "strukturiert",
    "strukturiertestes": "strukturiert",
    "strukturiertet": "strukturieren",
    "strukturschwache": "strukturschwach",
    "strukturschwachem": "strukturschwach",
    "strukturschwachen": "strukturschwach",
    "strukturschwacher": "strukturschwach",
    "strukturschwaches": "strukturschwach",
    "strukturschwächer": "strukturschwach",
    "strukturschwächere": "strukturschwach",
    "strukturschwächerem": "strukturschwach",
    "strukturschwächeren": "strukturschwach",
    "strukturschwächerer": "strukturschwach",
    "strukturschwächeres": "strukturschwach",
    "strukturschwächsten": "strukturschwach",
    "strulle": "strullen",
    "strullend": "strullen",
    "strullende": "strullend",
    "strullendem": "strullend",
    "strullenden": "strullend",
    "strullender": "strullend",
    "strullendes": "strullend",
    "strullest": "strullen",
    "strullet": "strullen",
    "strullst": "strullen",
    "strullt": "strullen",
    "strullte": "strullen",
    "strullten": "strullen",
    "strulltest": "strullen",
    "strulltet": "strullen",
    "struppigem": "struppig",
    "struppigen": "struppig",
    "struppiger": "struppig",
    "struppigere": "struppig",
    "struppigerem": "struppig",
    "struppigeren": "struppig",
    "struppigerer": "struppig",
    "struppigeres": "struppig",
    "struppiges": "struppig",
    "struppigste": "struppig",
    "struppigstem": "struppig",
    "struppigsten": "struppig",
    "struppigster": "struppig",
    "struppigstes": "struppig",
    "sträflichem": "sträflich",
    "sträflichen": "sträflich",
    "sträflicher": "sträflich",
    "sträfliches": "sträflich",
    "strähnigem": "strähnig",
    "strähnigen": "strähnig",
    "strähniger": "strähnig",
    "strähniges": "strähnig",
    "sträube": "sträuben",
    "sträubend": "sträuben",
    "sträubende": "sträubend",
    "sträubendem": "sträubend",
    "sträubenden": "sträubend",
    "sträubender": "sträubend",
    "sträubendere": "sträubend",
    "sträubenderem": "sträubend",
    "sträubenderen": "sträubend",
    "sträubenderer": "sträubend",
    "sträubenderes": "sträubend",
    "sträubendes": "sträubend",
    "sträubendste": "sträubend",
    "sträubendstem": "sträubend",
    "sträubendsten": "sträubend",
    "sträubendster": "sträubend",
    "sträubendstes": "sträubend",
    "sträubest": "sträuben",
    "sträubet": "sträuben",
    "sträubst": "sträuben",
    "sträubt": "sträuben",
    "sträubte": "sträuben",
    "sträubten": "sträuben",
    "sträubtest": "sträuben",
    "sträubtet": "sträuben",
    "strömend": "strömen",
    "strömende": "strömend",
    "strömendem": "strömend",
    "strömenden": "strömend",
    "strömender": "strömend",
    "strömendes": "strömend",
    "strömest": "strömen",
    "strömet": "strömen",
    "strömst": "strömen",
    "strömt": "strömen",
    "strömte": "strömen",
    "strömten": "strömen",
    "strömtest": "strömen",
    "strömtet": "strömen",
    "stubenreinem": "stubenrein",
    "stubenreinen": "stubenrein",
    "stubenreiner": "stubenrein",
    "stubenreines": "stubenrein",
    "studentischem": "studentisch",
    "studentischen": "studentisch",
    "studentischer": "studentisch",
    "studentisches": "studentisch",
    "studiere": "studieren",
    "studierend": "studieren",
    "studierende": "studierend",
    "studierendem": "studierend",
    "studierenden": "studierend",
    "studierender": "studierend",
    "studierendes": "studierend",
    "studierest": "studieren",
    "studieret": "studieren",
    "studierst": "studieren",
    "studiert": "studieren",
    "studierte": "studieren",
    "studiertem": "studiert",
    "studierten": "studieren",
    "studierter": "studiert",
    "studiertere": "studiert",
    "studierterem": "studiert",
    "studierteren": "studiert",
    "studierterer": "studiert",
    "studierteres": "studiert",
    "studiertes": "studiert",
    "studiertest": "studieren",
    "studierteste": "studiert",
    "studiertestem": "studiert",
    "studiertesten": "studiert",
    "studiertester": "studiert",
    "studiertestes": "studiert",
    "studiertet": "studieren",
    "stufend": "stufen",
    "stufende": "stufend",
    "stufendem": "stufend",
    "stufenden": "stufend",
    "stufender": "stufend",
    "stufendes": "stufend",
    "stufenlosem": "stufenlos",
    "stufenlosen": "stufenlos",
    "stufenloser": "stufenlos",
    "stufenlosere": "stufenlos",
    "stufenloserem": "stufenlos",
    "stufenloseren": "stufenlos",
    "stufenloserer": "stufenlos",
    "stufenloseres": "stufenlos",
    "stufenloses": "stufenlos",
    "stufenloseste": "stufenlos",
    "stufenlosestem": "stufenlos",
    "stufenlosesten": "stufenlos",
    "stufenlosester": "stufenlos",
    "stufenlosestes": "stufenlos",
    "stufest": "stufen",
    "stufet": "stufen",
    "stufige": "stufig",
    "stufigem": "stufig",
    "stufigen": "stufig",
    "stufiger": "stufig",
    "stufiges": "stufig",
    "stufst": "stufen",
    "stuft": "stufen",
    "stufte": "stufen",
    "stuften": "stufen",
    "stuftest": "stufen",
    "stuftet": "stufen",
    "stumme": "stumm",
    "stummem": "stumm",
    "stummen": "stumm",
    "stummer": "stumm",
    "stummere": "stumm",
    "stummerem": "stumm",
    "stummeren": "stumm",
    "stummerer": "stumm",
    "stummeres": "stumm",
    "stummes": "stumm",
    "stummste": "stumm",
    "stummstem": "stumm",
    "stummsten": "stumm",
    "stummster": "stumm",
    "stummstes": "stumm",
    "stumpfe": "stumpfen",
    "stumpfend": "stumpfen",
    "stumpfende": "stumpfend",
    "stumpfendem": "stumpfend",
    "stumpfenden": "stumpfend",
    "stumpfender": "stumpfend",
    "stumpfendes": "stumpfend",
    "stumpfest": "stumpfen",
    "stumpfet": "stumpfen",
    "stumpfsinnige": "stumpfsinnig",
    "stumpfsinnigem": "stumpfsinnig",
    "stumpfsinnigen": "stumpfsinnig",
    "stumpfsinniger": "stumpfsinnig",
    "stumpfsinnigere": "stumpfsinnig",
    "stumpfsinnigerem": "stumpfsinnig",
    "stumpfsinnigeren": "stumpfsinnig",
    "stumpfsinnigerer": "stumpfsinnig",
    "stumpfsinnigeres": "stumpfsinnig",
    "stumpfsinniges": "stumpfsinnig",
    "stumpfsinnigste": "stumpfsinnig",
    "stumpfsinnigstem": "stumpfsinnig",
    "stumpfsinnigsten": "stumpfsinnig",
    "stumpfsinnigster": "stumpfsinnig",
    "stumpfsinnigstes": "stumpfsinnig",
    "stumpfst": "stumpfen",
    "stumpft": "stumpfen",
    "stumpfte": "stumpfen",
    "stumpften": "stumpfen",
    "stumpftest": "stumpfen",
    "stumpftet": "stumpfen",
    "stumpfwinkelige": "stumpfwinkelig",
    "stumpfwinkeligem": "stumpfwinkelig",
    "stumpfwinkeligen": "stumpfwinkelig",
    "stumpfwinkeliger": "stumpfwinkelig",
    "stumpfwinkeliges": "stumpfwinkelig",
    "stunde": "stunden",
    "stundend": "stunden",
    "stundende": "stundend",
    "stundendem": "stundend",
    "stundenden": "stundend",
    "stundender": "stundend",
    "stundendes": "stundend",
    "stundenlangem": "stundenlang",
    "stundenlangen": "stundenlang",
    "stundenlanger": "stundenlang",
    "stundenlanges": "stundenlang",
    "stundest": "stunden",
    "stundet": "stunden",
    "stundete": "stunden",
    "stundeten": "stunden",
    "stundetest": "stunden",
    "stundetet": "stunden",
    "stupidem": "stupid",
    "stupiden": "stupid",
    "stupider": "stupid",
    "stupidere": "stupid",
    "stupiderem": "stupid",
    "stupideren": "stupid",
    "stupiderer": "stupid",
    "stupideres": "stupid",
    "stupides": "stupid",
    "stupideste": "stupid",
    "stupidestem": "stupid",
    "stupidesten": "stupid",
    "stupidester": "stupid",
    "stupidestes": "stupid",
    "sturem": "stur",
    "sturen": "stur",
    "sturer": "stur",
    "sturere": "stur",
    "sturerem": "stur",
    "stureren": "stur",
    "sturerer": "stur",
    "stureres": "stur",
    "stures": "stur",
    "sturmfreie": "sturmfrei",
    "sturmfreiem": "sturmfrei",
    "sturmfreien": "sturmfrei",
    "sturmfreier": "sturmfrei",
    "sturmfreies": "sturmfrei",
    "sturste": "stur",
    "sturstem": "stur",
    "stursten": "stur",
    "sturster": "stur",
    "sturstes": "stur",
    "stutze": "stutzen",
    "stutzend": "stutzen",
    "stutzende": "stutzend",
    "stutzendem": "stutzend",
    "stutzenden": "stutzend",
    "stutzender": "stutzend",
    "stutzendere": "stutzend",
    "stutzenderem": "stutzend",
    "stutzenderen": "stutzend",
    "stutzenderer": "stutzend",
    "stutzenderes": "stutzend",
    "stutzendes": "stutzend",
    "stutzendste": "stutzend",
    "stutzendstem": "stutzend",
    "stutzendsten": "stutzend",
    "stutzendster": "stutzend",
    "stutzendstes": "stutzend",
    "stutzest": "stutzen",
    "stutzet": "stutzen",
    "stutzigem": "stutzig",
    "stutzigen": "stutzig",
    "stutziger": "stutzig",
    "stutzigere": "stutzig",
    "stutzigerem": "stutzig",
    "stutzigeren": "stutzig",
    "stutzigerer": "stutzig",
    "stutzigeres": "stutzig",
    "stutziges": "stutzig",
    "stutzigste": "stutzig",
    "stutzigstem": "stutzig",
    "stutzigsten": "stutzig",
    "stutzigster": "stutzig",
    "stutzigstes": "stutzig",
    "stutzt": "stutzen",
    "stutzte": "stutzen",
    "stutzten": "stutzen",
    "stutztest": "stutzen",
    "stutztet": "stutzen",
    "stäche": "stechen",
    "stächen": "stechen",
    "stächest": "stechen",
    "stächet": "stechen",
    "städtebaulichem": "städtebaulich",
    "städtebaulichen": "städtebaulich",
    "städtebaulicher": "städtebaulich",
    "städtebauliches": "städtebaulich",
    "städtischem": "städtisch",
    "städtischen": "städtisch",
    "städtischer": "städtisch",
    "städtisches": "städtisch",
    "stähle": "stehlen",
    "stählen": "stehlen",
    "stählerne": "stählern",
    "stählernem": "stählern",
    "stählernen": "stählern",
    "stählerner": "stählern",
    "stählernere": "stählern",
    "stählernerem": "stählern",
    "stählerneren": "stählern",
    "stählernerer": "stählern",
    "stählerneres": "stählern",
    "stählernes": "stählern",
    "stählernste": "stählern",
    "stählernstem": "stählern",
    "stählernsten": "stählern",
    "stählernster": "stählern",
    "stählernstes": "stählern",
    "stählest": "stehlen",
    "stählet": "stehlen",
    "stämmigem": "stämmig",
    "stämmigen": "stämmig",
    "stämmiger": "stämmig",
    "stämmigere": "stämmig",
    "stämmigerem": "stämmig",
    "stämmigeren": "stämmig",
    "stämmigerer": "stämmig",
    "stämmigeres": "stämmig",
    "stämmiges": "stämmig",
    "stämmigste": "stämmig",
    "stämmigstem": "stämmig",
    "stämmigsten": "stämmig",
    "stämmigster": "stämmig",
    "stämmigstes": "stämmig",
    "ständige": "ständig",
    "ständigem": "ständig",
    "ständigen": "ständig",
    "ständiger": "ständig",
    "ständiges": "ständig",
    "stänke": "stinken",
    "stänken": "stinken",
    "stänkere": "stänkern",
    "stänkernd": "stänkern",
    "stänkernde": "stänkernd",
    "stänkerndem": "stänkernd",
    "stänkernden": "stänkernd",
    "stänkernder": "stänkernd",
    "stänkerndere": "stänkernd",
    "stänkernderem": "stänkernd",
    "stänkernderen": "stänkernd",
    "stänkernderer": "stänkernd",
    "stänkernderes": "stänkernd",
    "stänkerndes": "stänkernd",
    "stänkerndste": "stänkernd",
    "stänkerndstem": "stänkernd",
    "stänkerndsten": "stänkernd",
    "stänkerndster": "stänkernd",
    "stänkerndstes": "stänkernd",
    "stänkerst": "stänkern",
    "stänkert": "stänkern",
    "stänkerte": "stänkern",
    "stänkerten": "stänkern",
    "stänkertest": "stänkern",
    "stänkertet": "stänkern",
    "stänkest": "stinken",
    "stänket": "stinken",
    "stärbe": "sterben",
    "stärben": "sterben",
    "stärbest": "sterben",
    "stärbet": "sterben",
    "stärke": "stärken",
    "stärkend": "stärken",
    "stärkende": "stärkend",
    "stärkendem": "stärkend",
    "stärkenden": "stärkend",
    "stärkender": "stärkend",
    "stärkendere": "stärkend",
    "stärkenderem": "stärkend",
    "stärkenderen": "stärkend",
    "stärkenderer": "stärkend",
    "stärkenderes": "stärkend",
    "stärkendes": "stärkend",
    "stärkendste": "stärkend",
    "stärkendstem": "stärkend",
    "stärkendsten": "stärkend",
    "stärkendster": "stärkend",
    "stärkendstes": "stärkend",
    "stärker": "stark",
    "stärkere": "stark",
    "stärkerem": "stark",
    "stärkeren": "stark",
    "stärkerer": "stark",
    "stärkeres": "stark",
    "stärkest": "stärken",
    "stärket": "stärken",
    "stärkst": "stärken",
    "stärkste": "stark",
    "stärkstem": "stark",
    "stärksten": "stark",
    "stärkster": "stark",
    "stärkstes": "stark",
    "stärkt": "stärken",
    "stärkte": "stärken",
    "stärkten": "stärken",
    "stärktest": "stärken",
    "stärktet": "stärken",
    "stöbe": "stieben",
    "stöben": "stieben",
    "stöbere": "stöbern",
    "stöbernd": "stöbern",
    "stöbernde": "stöbernd",
    "stöberndem": "stöbernd",
    "stöbernden": "stöbernd",
    "stöbernder": "stöbernd",
    "stöberndes": "stöbernd",
    "stöberst": "stöbern",
    "stöbert": "stöbern",
    "stöberte": "stöbern",
    "stöberten": "stöbern",
    "stöbertest": "stöbern",
    "stöbertet": "stöbern",
    "stöbest": "stieben",
    "stöbet": "stieben",
    "stöhne": "stöhnen",
    "stöhnend": "stöhnen",
    "stöhnende": "stöhnend",
    "stöhnendem": "stöhnend",
    "stöhnenden": "stöhnend",
    "stöhnender": "stöhnend",
    "stöhnendere": "stöhnend",
    "stöhnenderem": "stöhnend",
    "stöhnenderen": "stöhnend",
    "stöhnenderer": "stöhnend",
    "stöhnenderes": "stöhnend",
    "stöhnendes": "stöhnend",
    "stöhnendste": "stöhnend",
    "stöhnendstem": "stöhnend",
    "stöhnendsten": "stöhnend",
    "stöhnendster": "stöhnend",
    "stöhnendstes": "stöhnend",
    "stöhnest": "stöhnen",
    "stöhnet": "stöhnen",
    "stöhnst": "stöhnen",
    "stöhnt": "stöhnen",
    "stöhnte": "stöhnen",
    "stöhnten": "stöhnen",
    "stöhntest": "stöhnen",
    "stöhntet": "stöhnen",
    "stöpsele": "stöpseln",
    "stöpselnd": "stöpseln",
    "stöpselnde": "stöpselnd",
    "stöpselndem": "stöpselnd",
    "stöpselnden": "stöpselnd",
    "stöpselnder": "stöpselnd",
    "stöpselndes": "stöpselnd",
    "stöpselst": "stöpseln",
    "stöpselt": "stöpseln",
    "stöpselte": "stöpseln",
    "stöpselten": "stöpseln",
    "stöpseltest": "stöpseln",
    "stöpseltet": "stöpseln",
    "stöpsle": "stöpseln",
    "störe": "stören",
    "störend": "stören",
    "störende": "störend",
    "störendem": "störend",
    "störenden": "störend",
    "störender": "störend",
    "störendere": "störend",
    "störenderem": "störend",
    "störenderen": "störend",
    "störenderer": "störend",
    "störenderes": "störend",
    "störendes": "störend",
    "störendste": "störend",
    "störendstem": "störend",
    "störendsten": "störend",
    "störendster": "störend",
    "störendstes": "störend",
    "störest": "stören",
    "störet": "stören",
    "störrische": "störrisch",
    "störrischem": "störrisch",
    "störrischen": "störrisch",
    "störrischer": "störrisch",
    "störrischere": "störrisch",
    "störrischerem": "störrisch",
    "störrischeren": "störrisch",
    "störrischerer": "störrisch",
    "störrischeres": "störrisch",
    "störrisches": "störrisch",
    "störrischste": "störrisch",
    "störrischstem": "störrisch",
    "störrischsten": "störrisch",
    "störrischster": "störrisch",
    "störrischstes": "störrisch",
    "störst": "stören",
    "stört": "stören",
    "störte": "stören",
    "störten": "stören",
    "störtest": "stören",
    "störtet": "stören",
    "störungsfreiem": "störungsfrei",
    "störungsfreien": "störungsfrei",
    "störungsfreier": "störungsfrei",
    "störungsfreies": "störungsfrei",
    "stößt": "stoßen",
    "stückele": "stückeln",
    "stückelnd": "stückeln",
    "stückelnde": "stückelnd",
    "stückelndem": "stückelnd",
    "stückelnden": "stückelnd",
    "stückelnder": "stückelnd",
    "stückelndes": "stückelnd",
    "stückelst": "stückeln",
    "stückelt": "stückeln",
    "stückelte": "stückeln",
    "stückelten": "stückeln",
    "stückeltest": "stückeln",
    "stückeltet": "stückeln",
    "stückle": "stückeln",
    "stückweisem": "stückweise",
    "stückweisen": "stückweise",
    "stückweiser": "stückweise",
    "stückweises": "stückweise",
    "stülpe": "stülpen",
    "stülpend": "stülpen",
    "stülpende": "stülpend",
    "stülpendem": "stülpend",
    "stülpenden": "stülpend",
    "stülpender": "stülpend",
    "stülpendes": "stülpend",
    "stülpest": "stülpen",
    "stülpet": "stülpen",
    "stülpst": "stülpen",
    "stülpt": "stülpen",
    "stülpte": "stülpen",
    "stülpten": "stülpen",
    "stülptest": "stülpen",
    "stülptet": "stülpen",
    "stümmele": "stümmeln",
    "stümmelnd": "stümmeln",
    "stümmelnde": "stümmelnd",
    "stümmelndem": "stümmelnd",
    "stümmelnden": "stümmelnd",
    "stümmelnder": "stümmelnd",
    "stümmelndes": "stümmelnd",
    "stümmelst": "stümmeln",
    "stümmelt": "stümmeln",
    "stümmelte": "stümmeln",
    "stümmelten": "stümmeln",
    "stümmeltest": "stümmeln",
    "stümmeltet": "stümmeln",
    "stümmle": "stümmeln",
    "stümpere": "stümpern",
    "stümperhafte": "stümperhaft",
    "stümperhaftem": "stümperhaft",
    "stümperhaften": "stümperhaft",
    "stümperhafter": "stümperhaft",
    "stümperhaftere": "stümperhaft",
    "stümperhafterem": "stümperhaft",
    "stümperhafteren": "stümperhaft",
    "stümperhafterer": "stümperhaft",
    "stümperhafteres": "stümperhaft",
    "stümperhaftes": "stümperhaft",
    "stümperhafteste": "stümperhaft",
    "stümperhaftestem": "stümperhaft",
    "stümperhaftesten": "stümperhaft",
    "stümperhaftester": "stümperhaft",
    "stümperhaftestes": "stümperhaft",
    "stümpernd": "stümpern",
    "stümpernde": "stümpernd",
    "stümperndem": "stümpernd",
    "stümpernden": "stümpernd",
    "stümpernder": "stümpernd",
    "stümperndere": "stümpernd",
    "stümpernderem": "stümpernd",
    "stümpernderen": "stümpernd",
    "stümpernderer": "stümpernd",
    "stümpernderes": "stümpernd",
    "stümperndes": "stümpernd",
    "stümperndste": "stümpernd",
    "stümperndstem": "stümpernd",
    "stümperndsten": "stümpernd",
    "stümperndster": "stümpernd",
    "stümperndstes": "stümpernd",
    "stümperst": "stümpern",
    "stümpert": "stümpern",
    "stümperte": "stümpern",
    "stümperten": "stümpern",
    "stümpertest": "stümpern",
    "stümpertet": "stümpern",
    "stünde": "stehen",
    "stünden": "stehen",
    "stündest": "stehen",
    "stündet": "stehen",
    "stündlichem": "stündlich",
    "stündlichen": "stündlich",
    "stündlicher": "stündlich",
    "stündliches": "stündlich",
    "stürmend": "stürmen",
    "stürmende": "stürmend",
    "stürmendem": "stürmend",
    "stürmenden": "stürmend",
    "stürmender": "stürmend",
    "stürmendes": "stürmend",
    "stürmest": "stürmen",
    "stürmet": "stürmen",
    "stürmische": "stürmisch",
    "stürmischem": "stürmisch",
    "stürmischen": "stürmisch",
    "stürmischer": "stürmisch",
    "stürmischere": "stürmisch",
    "stürmischerem": "stürmisch",
    "stürmischeren": "stürmisch",
    "stürmischerer": "stürmisch",
    "stürmischeres": "stürmisch",
    "stürmisches": "stürmisch",
    "stürmischste": "stürmisch",
    "stürmischstem": "stürmisch",
    "stürmischsten": "stürmisch",
    "stürmischster": "stürmisch",
    "stürmischstes": "stürmisch",
    "stürmst": "stürmen",
    "stürmt": "stürmen",
    "stürmte": "stürmen",
    "stürmten": "stürmen",
    "stürmtest": "stürmen",
    "stürmtet": "stürmen",
    "stürzend": "stürzen",
    "stürzende": "stürzend",
    "stürzendem": "stürzend",
    "stürzenden": "stürzend",
    "stürzender": "stürzend",
    "stürzendes": "stürzend",
    "stürzest": "stürzen",
    "stürzet": "stürzen",
    "stürzt": "stürzen",
    "stürzte": "stürzen",
    "stürzten": "stürzen",
    "stürztest": "stürzen",
    "stürztet": "stürzen",
    "stütze": "stützen",
    "stützend": "stützen",
    "stützendem": "stützend",
    "stützender": "stützend",
    "stützenderem": "stützend",
    "stützenderer": "stützend",
    "stützenderes": "stützend",
    "stützendes": "stützend",
    "stützendstem": "stützend",
    "stützendster": "stützend",
    "stützendstes": "stützend",
    "stützest": "stützen",
    "stützet": "stützen",
    "stützt": "stützen",
    "stützte": "stützen",
    "stützten": "stützen",
    "stütztest": "stützen",
    "stütztet": "stützen",
    "subatomarem": "subatomar",
    "subatomaren": "subatomar",
    "subatomarer": "subatomar",
    "subatomares": "subatomar",
    "subjektivem": "subjektiv",
    "subjektiven": "subjektiv",
    "subjektiver": "subjektiv",
    "subjektivere": "subjektiv",
    "subjektiverem": "subjektiv",
    "subjektiveren": "subjektiv",
    "subjektiverer": "subjektiv",
    "subjektiveres": "subjektiv",
    "subjektives": "subjektiv",
    "subjektivste": "subjektiv",
    "subjektivstem": "subjektiv",
    "subjektivsten": "subjektiv",
    "subjektivster": "subjektiv",
    "subjektivstes": "subjektiv",
    "substantiellem": "substantiell",
    "substantiellen": "substantiell",
    "substantieller": "substantiell",
    "substantielles": "substantiell",
    "substituiere": "substituieren",
    "substituierend": "substituieren",
    "substituierende": "substituierend",
    "substituierendem": "substituierend",
    "substituierenden": "substituierend",
    "substituierender": "substituierend",
    "substituierendes": "substituierend",
    "substituierest": "substituieren",
    "substituieret": "substituieren",
    "substituierst": "substituieren",
    "substituiert": "substituieren",
    "substituierte": "substituieren",
    "substituiertem": "substituiert",
    "substituierten": "substituieren",
    "substituierter": "substituiert",
    "substituiertes": "substituiert",
    "substituiertest": "substituieren",
    "substituiertet": "substituieren",
    "subsumiere": "subsumieren",
    "subsumierend": "subsumieren",
    "subsumierende": "subsumierend",
    "subsumierendem": "subsumierend",
    "subsumierenden": "subsumierend",
    "subsumierender": "subsumierend",
    "subsumierendes": "subsumierend",
    "subsumierest": "subsumieren",
    "subsumieret": "subsumieren",
    "subsumierst": "subsumieren",
    "subsumiert": "subsumieren",
    "subsumierte": "subsumieren",
    "subsumiertem": "subsumiert",
    "subsumierten": "subsumieren",
    "subsumierter": "subsumiert",
    "subsumiertes": "subsumiert",
    "subsumiertest": "subsumieren",
    "subsumiertet": "subsumieren",
    "subtilem": "subtil",
    "subtilen": "subtil",
    "subtiler": "subtil",
    "subtilere": "subtil",
    "subtilerem": "subtil",
    "subtileren": "subtil",
    "subtilerer": "subtil",
    "subtileres": "subtil",
    "subtiles": "subtil",
    "subtilste": "subtil",
    "subtilstem": "subtil",
    "subtilsten": "subtil",
    "subtilster": "subtil",
    "subtilstes": "subtil",
    "subtrahiere": "subtrahieren",
    "subtrahierend": "subtrahieren",
    "subtrahierende": "subtrahierend",
    "subtrahierendem": "subtrahierend",
    "subtrahierenden": "subtrahierend",
    "subtrahierender": "subtrahierend",
    "subtrahierendes": "subtrahierend",
    "subtrahierest": "subtrahieren",
    "subtrahieret": "subtrahieren",
    "subtrahierst": "subtrahieren",
    "subtrahiert": "subtrahieren",
    "subtrahierte": "subtrahieren",
    "subtrahiertem": "subtrahiert",
    "subtrahierten": "subtrahieren",
    "subtrahierter": "subtrahiert",
    "subtrahiertes": "subtrahiert",
    "subtrahiertest": "subtrahieren",
    "subtrahiertet": "subtrahieren",
    "subtropischem": "subtropisch",
    "subtropischen": "subtropisch",
    "subtropischer": "subtropisch",
    "subtropisches": "subtropisch",
    "suchend": "suchen",
    "suchende": "suchend",
    "suchendem": "suchend",
    "suchenden": "suchend",
    "suchender": "suchend",
    "suchendes": "suchend",
    "suchest": "suchen",
    "suchet": "suchen",
    "suchst": "suchen",
    "sucht": "suchen",
    "suchte": "suchen",
    "suchten": "suchen",
    "suchtest": "suchen",
    "suchtet": "suchen",
    "suchthafte": "suchthaft",
    "suchthaftem": "suchthaft",
    "suchthaften": "suchthaft",
    "suchthafter": "suchthaft",
    "suchthaftere": "suchthaft",
    "suchthafterem": "suchthaft",
    "suchthafteren": "suchthaft",
    "suchthafterer": "suchthaft",
    "suchthafteres": "suchthaft",
    "suchthaftes": "suchthaft",
    "suchthafteste": "suchthaft",
    "suchthaftestem": "suchthaft",
    "suchthaftesten": "suchthaft",
    "suchthaftester": "suchthaft",
    "suchthaftestes": "suchthaft",
    "suchtkranke": "suchtkrank",
    "suchtkrankem": "suchtkrank",
    "suchtkranken": "suchtkrank",
    "suchtkranker": "suchtkrank",
    "suchtkrankes": "suchtkrank",
    "sudele": "sudeln",
    "sudelnd": "sudeln",
    "sudelnde": "sudelnd",
    "sudelndem": "sudelnd",
    "sudelnden": "sudelnd",
    "sudelnder": "sudelnd",
    "sudelndere": "sudelnd",
    "sudelnderem": "sudelnd",
    "sudelnderen": "sudelnd",
    "sudelnderer": "sudelnd",
    "sudelnderes": "sudelnd",
    "sudelndes": "sudelnd",
    "sudelndste": "sudelnd",
    "sudelndstem": "sudelnd",
    "sudelndsten": "sudelnd",
    "sudelndster": "sudelnd",
    "sudelndstes": "sudelnd",
    "sudelst": "sudeln",
    "sudelt": "sudeln",
    "sudelte": "sudeln",
    "sudelten": "sudeln",
    "sudeltest": "sudeln",
    "sudeltet": "sudeln",
    "sudetischem": "sudetisch",
    "sudetischen": "sudetisch",
    "sudetischer": "sudetisch",
    "sudetisches": "sudetisch",
    "sudle": "sudeln",
    "suffigiere": "suffigieren",
    "suffigierend": "suffigieren",
    "suffigierende": "suffigierend",
    "suffigierendem": "suffigierend",
    "suffigierenden": "suffigierend",
    "suffigierender": "suffigierend",
    "suffigierendes": "suffigierend",
    "suffigierest": "suffigieren",
    "suffigieret": "suffigieren",
    "suffigierst": "suffigieren",
    "suffigiert": "suffigieren",
    "suffigierte": "suffigieren",
    "suffigiertem": "suffigiert",
    "suffigierten": "suffigieren",
    "suffigierter": "suffigiert",
    "suffigiertes": "suffigiert",
    "suffigiertest": "suffigieren",
    "suffigiertet": "suffigieren",
    "suggeriere": "suggerieren",
    "suggerierend": "suggerieren",
    "suggerierende": "suggerierend",
    "suggerierendem": "suggerierend",
    "suggerierenden": "suggerierend",
    "suggerierender": "suggerierend",
    "suggerierendes": "suggerierend",
    "suggerierest": "suggerieren",
    "suggerieret": "suggerieren",
    "suggerierst": "suggerieren",
    "suggeriert": "suggerieren",
    "suggerierte": "suggerieren",
    "suggeriertem": "suggeriert",
    "suggerierten": "suggerieren",
    "suggerierter": "suggeriert",
    "suggeriertes": "suggeriert",
    "suggeriertest": "suggerieren",
    "suggeriertet": "suggerieren",
    "suggestivem": "suggestiv",
    "suggestiven": "suggestiv",
    "suggestiver": "suggestiv",
    "suggestives": "suggestiv",
    "suhlend": "suhlen",
    "suhlende": "suhlend",
    "suhlendem": "suhlend",
    "suhlenden": "suhlend",
    "suhlender": "suhlend",
    "suhlendes": "suhlend",
    "suhlest": "suhlen",
    "suhlet": "suhlen",
    "suhlst": "suhlen",
    "suhlt": "suhlen",
    "suhlte": "suhlen",
    "suhlten": "suhlen",
    "suhltest": "suhlen",
    "suhltet": "suhlen",
    "sukzessivem": "sukzessiv",
    "sukzessiven": "sukzessiv",
    "sukzessiver": "sukzessiv",
    "sukzessives": "sukzessiv",
    "summarische": "summarisch",
    "summarischem": "summarisch",
    "summarischen": "summarisch",
    "summarischer": "summarisch",
    "summarisches": "summarisch",
    "summiere": "summieren",
    "summierend": "summieren",
    "summierende": "summierend",
    "summierendem": "summierend",
    "summierenden": "summierend",
    "summierender": "summierend",
    "summierendes": "summierend",
    "summierest": "summieren",
    "summieret": "summieren",
    "summierst": "summieren",
    "summiert": "summieren",
    "summierte": "summieren",
    "summiertem": "summiert",
    "summierten": "summieren",
    "summierter": "summiert",
    "summiertes": "summiert",
    "summiertest": "summieren",
    "summiertet": "summieren",
    "sumpfend": "sumpfen",
    "sumpfende": "sumpfend",
    "sumpfendem": "sumpfend",
    "sumpfenden": "sumpfend",
    "sumpfender": "sumpfend",
    "sumpfendere": "sumpfend",
    "sumpfenderem": "sumpfend",
    "sumpfenderen": "sumpfend",
    "sumpfenderer": "sumpfend",
    "sumpfenderes": "sumpfend",
    "sumpfendes": "sumpfend",
    "sumpfendste": "sumpfend",
    "sumpfendstem": "sumpfend",
    "sumpfendsten": "sumpfend",
    "sumpfendster": "sumpfend",
    "sumpfendstes": "sumpfend",
    "sumpfest": "sumpfen",
    "sumpfet": "sumpfen",
    "sumpfige": "sumpfig",
    "sumpfigem": "sumpfig",
    "sumpfigen": "sumpfig",
    "sumpfiger": "sumpfig",
    "sumpfigere": "sumpfig",
    "sumpfigerem": "sumpfig",
    "sumpfigeren": "sumpfig",
    "sumpfigerer": "sumpfig",
    "sumpfigeres": "sumpfig",
    "sumpfiges": "sumpfig",
    "sumpfigste": "sumpfig",
    "sumpfigstem": "sumpfig",
    "sumpfigsten": "sumpfig",
    "sumpfigster": "sumpfig",
    "sumpfigstes": "sumpfig",
    "sumpfst": "sumpfen",
    "sumpft": "sumpfen",
    "sumpfte": "sumpfen",
    "sumpften": "sumpfen",
    "sumpftest": "sumpfen",
    "sumpftet": "sumpfen",
    "supplementärem": "supplementär",
    "supplementären": "supplementär",
    "supplementärer": "supplementär",
    "supplementäres": "supplementär",
    "surjektivem": "surjektiv",
    "surjektiven": "surjektiv",
    "surjektiver": "surjektiv",
    "surjektives": "surjektiv",
    "surre": "surren",
    "surrend": "surren",
    "surrende": "surrend",
    "surrendem": "surrend",
    "surrenden": "surrend",
    "surrender": "surrend",
    "surrendere": "surrend",
    "surrenderem": "surrend",
    "surrenderen": "surrend",
    "surrenderer": "surrend",
    "surrenderes": "surrend",
    "surrendes": "surrend",
    "surrendste": "surrend",
    "surrendstem": "surrend",
    "surrendsten": "surrend",
    "surrendster": "surrend",
    "surrendstes": "surrend",
    "surrest": "surren",
    "surret": "surren",
    "surrst": "surren",
    "surrt": "surren",
    "surrte": "surren",
    "surrten": "surren",
    "surrtest": "surren",
    "surrtet": "surren",
    "suspendiere": "suspendieren",
    "suspendierend": "suspendieren",
    "suspendierende": "suspendierend",
    "suspendierendem": "suspendierend",
    "suspendierenden": "suspendierend",
    "suspendierender": "suspendierend",
    "suspendierendes": "suspendierend",
    "suspendierest": "suspendieren",
    "suspendieret": "suspendieren",
    "suspendierst": "suspendieren",
    "suspendiert": "suspendieren",
    "suspendierte": "suspendieren",
    "suspendiertem": "suspendiert",
    "suspendierten": "suspendieren",
    "suspendierter": "suspendiert",
    "suspendiertes": "suspendiert",
    "suspendiertest": "suspendieren",
    "suspendiertet": "suspendieren",
    "swinge": "swingen",
    "swingend": "swingen",
    "swingende": "swingend",
    "swingendem": "swingend",
    "swingenden": "swingend",
    "swingender": "swingend",
    "swingendere": "swingend",
    "swingenderem": "swingend",
    "swingenderen": "swingend",
    "swingenderer": "swingend",
    "swingenderes": "swingend",
    "swingendes": "swingend",
    "swingendste": "swingend",
    "swingendstem": "swingend",
    "swingendsten": "swingend",
    "swingendster": "swingend",
    "swingendstes": "swingend",
    "swingest": "swingen",
    "swinget": "swingen",
    "swingst": "swingen",
    "swingt": "swingen",
    "swingte": "swingen",
    "swingten": "swingen",
    "swingtest": "swingen",
    "swingtet": "swingen",
    "symbolischem": "symbolisch",
    "symbolischen": "symbolisch",
    "symbolischer": "symbolisch",
    "symbolisches": "symbolisch",
    "symbolisiere": "symbolisieren",
    "symbolisierend": "symbolisieren",
    "symbolisierende": "symbolisierend",
    "symbolisierendem": "symbolisierend",
    "symbolisierenden": "symbolisierend",
    "symbolisierender": "symbolisierend",
    "symbolisierendes": "symbolisierend",
    "symbolisierest": "symbolisieren",
    "symbolisieret": "symbolisieren",
    "symbolisierst": "symbolisieren",
    "symbolisiert": "symbolisieren",
    "symbolisierte": "symbolisieren",
    "symbolisiertem": "symbolisiert",
    "symbolisierten": "symbolisieren",
    "symbolisierter": "symbolisiert",
    "symbolisiertes": "symbolisiert",
    "symbolisiertest": "symbolisieren",
    "symbolisiertet": "symbolisieren",
    "symbolträchtigem": "symbolträchtig",
    "symbolträchtigen": "symbolträchtig",
    "symbolträchtiger": "symbolträchtig",
    "symbolträchtigere": "symbolträchtig",
    "symbolträchtigerem": "symbolträchtig",
    "symbolträchtigeren": "symbolträchtig",
    "symbolträchtigerer": "symbolträchtig",
    "symbolträchtigeres": "symbolträchtig",
    "symbolträchtiges": "symbolträchtig",
    "symbolträchtigste": "symbolträchtig",
    "symbolträchtigstem": "symbolträchtig",
    "symbolträchtigsten": "symbolträchtig",
    "symbolträchtigster": "symbolträchtig",
    "symbolträchtigstes": "symbolträchtig",
    "sympathischem": "sympathisch",
    "sympathischen": "sympathisch",
    "sympathischer": "sympathisch",
    "sympathischere": "sympathisch",
    "sympathischerem": "sympathisch",
    "sympathischeren": "sympathisch",
    "sympathischerer": "sympathisch",
    "sympathischeres": "sympathisch",
    "sympathisches": "sympathisch",
    "sympathischste": "sympathisch",
    "sympathischstem": "sympathisch",
    "sympathischsten": "sympathisch",
    "sympathischster": "sympathisch",
    "sympathischstes": "sympathisch",
    "sympathisiere": "sympathisieren",
    "sympathisierend": "sympathisieren",
    "sympathisierende": "sympathisierend",
    "sympathisierendem": "sympathisierend",
    "sympathisierenden": "sympathisierend",
    "sympathisierender": "sympathisierend",
    "sympathisierendere": "sympathisierend",
    "sympathisierenderem": "sympathisierend",
    "sympathisierenderen": "sympathisierend",
    "sympathisierenderer": "sympathisierend",
    "sympathisierenderes": "sympathisierend",
    "sympathisierendes": "sympathisierend",
    "sympathisierendste": "sympathisierend",
    "sympathisierendstem": "sympathisierend",
    "sympathisierendsten": "sympathisierend",
    "sympathisierendster": "sympathisierend",
    "sympathisierendstes": "sympathisierend",
    "sympathisierest": "sympathisieren",
    "sympathisieret": "sympathisieren",
    "sympathisierst": "sympathisieren",
    "sympathisiert": "sympathisieren",
    "sympathisierte": "sympathisieren",
    "sympathisiertem": "sympathisiert",
    "sympathisierten": "sympathisieren",
    "sympathisierter": "sympathisiert",
    "sympathisiertes": "sympathisiert",
    "sympathisiertest": "sympathisieren",
    "sympathisiertet": "sympathisieren",
    "syntagmatischem": "syntagmatisch",
    "syntagmatischen": "syntagmatisch",
    "syntagmatischer": "syntagmatisch",
    "syntagmatisches": "syntagmatisch",
    "syntaktische": "syntaktisch",
    "syntaktischem": "syntaktisch",
    "syntaktischen": "syntaktisch",
    "syntaktischer": "syntaktisch",
    "syntaktisches": "syntaktisch",
    "synthetischem": "synthetisch",
    "synthetischen": "synthetisch",
    "synthetischer": "synthetisch",
    "synthetisches": "synthetisch",
    "synthetisiere": "synthetisieren",
    "synthetisierend": "synthetisieren",
    "synthetisierende": "synthetisierend",
    "synthetisierendem": "synthetisierend",
    "synthetisierenden": "synthetisierend",
    "synthetisierender": "synthetisierend",
    "synthetisierendere": "synthetisierend",
    "synthetisierenderem": "synthetisierend",
    "synthetisierenderen": "synthetisierend",
    "synthetisierenderer": "synthetisierend",
    "synthetisierenderes": "synthetisierend",
    "synthetisierendes": "synthetisierend",
    "synthetisierendste": "synthetisierend",
    "synthetisierendstem": "synthetisierend",
    "synthetisierendsten": "synthetisierend",
    "synthetisierendster": "synthetisierend",
    "synthetisierendstes": "synthetisierend",
    "synthetisierest": "synthetisieren",
    "synthetisieret": "synthetisieren",
    "synthetisierst": "synthetisieren",
    "synthetisiert": "synthetisieren",
    "synthetisierte": "synthetisieren",
    "synthetisiertem": "synthetisiert",
    "synthetisierten": "synthetisieren",
    "synthetisierter": "synthetisiert",
    "synthetisiertere": "synthetisiert",
    "synthetisierterem": "synthetisiert",
    "synthetisierteren": "synthetisiert",
    "synthetisierterer": "synthetisiert",
    "synthetisierteres": "synthetisiert",
    "synthetisiertes": "synthetisiert",
    "synthetisiertest": "synthetisieren",
    "synthetisiertestem": "synthetisiert",
    "synthetisiertesten": "synthetisiert",
    "synthetisiertester": "synthetisiert",
    "synthetisiertestes": "synthetisiert",
    "synthetisiertet": "synthetisieren",
    "syrischem": "syrisch",
    "syrischen": "syrisch",
    "syrischer": "syrisch",
    "syrisches": "syrisch",
    "systematischem": "systematisch",
    "systematischen": "systematisch",
    "systematischer": "systematisch",
    "systematischere": "systematisch",
    "systematischerem": "systematisch",
    "systematischeren": "systematisch",
    "systematischerer": "systematisch",
    "systematischeres": "systematisch",
    "systematisches": "systematisch",
    "systematischste": "systematisch",
    "systematischstem": "systematisch",
    "systematischsten": "systematisch",
    "systematischster": "systematisch",
    "systematischstes": "systematisch",
    "systematisiere": "systematisieren",
    "systematisierend": "systematisieren",
    "systematisierende": "systematisierend",
    "systematisierendem": "systematisierend",
    "systematisierenden": "systematisierend",
    "systematisierender": "systematisierend",
    "systematisierendere": "systematisierend",
    "systematisierenderem": "systematisierend",
    "systematisierenderen": "systematisierend",
    "systematisierenderer": "systematisierend",
    "systematisierenderes": "systematisierend",
    "systematisierendes": "systematisierend",
    "systematisierendste": "systematisierend",
    "systematisierendstem": "systematisierend",
    "systematisierendsten": "systematisierend",
    "systematisierendster": "systematisierend",
    "systematisierendstes": "systematisierend",
    "systematisierest": "systematisieren",
    "systematisieret": "systematisieren",
    "systematisierst": "systematisieren",
    "systematisiert": "systematisieren",
    "systematisierte": "systematisieren",
    "systematisiertem": "systematisiert",
    "systematisierten": "systematisieren",
    "systematisierter": "systematisiert",
    "systematisiertere": "systematisiert",
    "systematisierterem": "systematisiert",
    "systematisierteren": "systematisiert",
    "systematisierterer": "systematisiert",
    "systematisierteres": "systematisiert",
    "systematisiertes": "systematisiert",
    "systematisiertest": "systematisieren",
    "systematisierteste": "systematisiert",
    "systematisiertestem": "systematisiert",
    "systematisiertesten": "systematisiert",
    "systematisiertester": "systematisiert",
    "systematisiertestes": "systematisiert",
    "systematisiertet": "systematisieren",
    "systemkonformem": "systemkonform",
    "systemkonformen": "systemkonform",
    "systemkonformer": "systemkonform",
    "systemkonformes": "systemkonform",
    "systemlose": "systemlos",
    "systemlosem": "systemlos",
    "systemlosen": "systemlos",
    "systemloser": "systemlos",
    "systemloses": "systemlos",
    "szenischem": "szenisch",
    "szenischen": "szenisch",
    "szenischer": "szenisch",
    "szenisches": "szenisch",
    "säbele": "säbeln",
    "säbelnd": "säbeln",
    "säbelnde": "säbelnd",
    "säbelndem": "säbelnd",
    "säbelnden": "säbelnd",
    "säbelnder": "säbelnd",
    "säbelndes": "säbelnd",
    "säbelst": "säbeln",
    "säbelt": "säbeln",
    "säbelte": "säbeln",
    "säbelten": "säbeln",
    "säbeltest": "säbeln",
    "säbeltet": "säbeln",
    "säble": "säbeln",
    "sächlichem": "sächlich",
    "sächlicher": "sächlich",
    "sächliches": "sächlich",
    "sächsischem": "sächsisch",
    "sächsischen": "sächsisch",
    "sächsischer": "sächsisch",
    "sächsisches": "sächsisch",
    "säe": "säen",
    "säend": "säen",
    "säende": "säend",
    "säendem": "säend",
    "säenden": "säend",
    "säender": "säend",
    "säendes": "säend",
    "säest": "säen",
    "säet": "säen",
    "sägend": "sägen",
    "sägendem": "sägend",
    "sägender": "sägend",
    "sägendes": "sägend",
    "sägest": "sägen",
    "säget": "sägen",
    "sägst": "sägen",
    "sägt": "sägen",
    "sägte": "sägen",
    "sägten": "sägen",
    "sägtest": "sägen",
    "sägtet": "sägen",
    "sähe": "sehen",
    "sähend": "sähen",
    "sähende": "sähend",
    "sähendem": "sähend",
    "sähenden": "sähend",
    "sähender": "sähend",
    "sähendes": "sähend",
    "sähest": "sehen",
    "sähet": "sehen",
    "sähst": "sähen",
    "säht": "sähen",
    "sähte": "sähen",
    "sähten": "sähen",
    "sähtest": "sähen",
    "sähtet": "sähen",
    "säkularem": "säkular",
    "säkularen": "säkular",
    "säkularer": "säkular",
    "säkulares": "säkular",
    "säkularisiere": "säkularisieren",
    "säkularisierend": "säkularisieren",
    "säkularisierende": "säkularisierend",
    "säkularisierendem": "säkularisierend",
    "säkularisierenden": "säkularisierend",
    "säkularisierender": "säkularisierend",
    "säkularisierendere": "säkularisierend",
    "säkularisierenderem": "säkularisierend",
    "säkularisierenderen": "säkularisierend",
    "säkularisierenderer": "säkularisierend",
    "säkularisierenderes": "säkularisierend",
    "säkularisierendes": "säkularisierend",
    "säkularisierendste": "säkularisierend",
    "säkularisierendstem": "säkularisierend",
    "säkularisierendsten": "säkularisierend",
    "säkularisierendster": "säkularisierend",
    "säkularisierendstes": "säkularisierend",
    "säkularisierest": "säkularisieren",
    "säkularisieret": "säkularisieren",
    "säkularisierst": "säkularisieren",
    "säkularisiert": "säkularisieren",
    "säkularisierte": "säkularisieren",
    "säkularisiertem": "säkularisiert",
    "säkularisierten": "säkularisieren",
    "säkularisierter": "säkularisiert",
    "säkularisiertere": "säkularisiert",
    "säkularisierterem": "säkularisiert",
    "säkularisierteren": "säkularisiert",
    "säkularisierterer": "säkularisiert",
    "säkularisierteres": "säkularisiert",
    "säkularisiertes": "säkularisiert",
    "säkularisiertest": "säkularisieren",
    "säkularisiertestem": "säkularisiert",
    "säkularisiertesten": "säkularisiert",
    "säkularisiertester": "säkularisiert",
    "säkularisiertestes": "säkularisiert",
    "säkularisiertet": "säkularisieren",
    "sämtlichem": "sämtlich",
    "sämtlichen": "sämtlich",
    "sämtlicher": "sämtlich",
    "sämtliches": "sämtlich",
    "sänftige": "sänftigen",
    "sänftigend": "sänftigen",
    "sänftigende": "sänftigend",
    "sänftigendem": "sänftigend",
    "sänftigenden": "sänftigend",
    "sänftigender": "sänftigend",
    "sänftigendere": "sänftigend",
    "sänftigenderem": "sänftigend",
    "sänftigenderen": "sänftigend",
    "sänftigenderer": "sänftigend",
    "sänftigenderes": "sänftigend",
    "sänftigendes": "sänftigend",
    "sänftigendste": "sänftigend",
    "sänftigendstem": "sänftigend",
    "sänftigendsten": "sänftigend",
    "sänftigendster": "sänftigend",
    "sänftigendstes": "sänftigend",
    "sänftigest": "sänftigen",
    "sänftiget": "sänftigen",
    "sänftigst": "sänftigen",
    "sänftigt": "sänftigen",
    "sänftigte": "sänftigen",
    "sänftigten": "sänftigen",
    "sänftigtest": "sänftigen",
    "sänftigtet": "sänftigen",
    "sänge": "singen",
    "sängen": "singen",
    "sängest": "singen",
    "sänget": "singen",
    "sänke": "sinken",
    "sänken": "sinken",
    "sänkest": "sinken",
    "sänket": "sinken",
    "sänne": "sinnen",
    "sännen": "sinnen",
    "sännest": "sinnen",
    "sännet": "sinnen",
    "säst": "säen",
    "sät": "säen",
    "säte": "säen",
    "säten": "säen",
    "sätest": "säen",
    "sätet": "säen",
    "sättige": "sättigen",
    "sättigend": "sättigen",
    "sättigende": "sättigend",
    "sättigendem": "sättigend",
    "sättigenden": "sättigend",
    "sättigender": "sättigend",
    "sättigendere": "sättigend",
    "sättigenderem": "sättigend",
    "sättigenderen": "sättigend",
    "sättigenderer": "sättigend",
    "sättigenderes": "sättigend",
    "sättigendes": "sättigend",
    "sättigendste": "sättigend",
    "sättigendstem": "sättigend",
    "sättigendsten": "sättigend",
    "sättigendster": "sättigend",
    "sättigendstes": "sättigend",
    "sättigest": "sättigen",
    "sättiget": "sättigen",
    "sättigst": "sättigen",
    "sättigt": "sättigen",
    "sättigte": "sättigen",
    "sättigten": "sättigen",
    "sättigtest": "sättigen",
    "sättigtet": "sättigen",
    "säubere": "säubern",
    "säuberlichem": "säuberlich",
    "säuberlichen": "säuberlich",
    "säuberlicher": "säuberlich",
    "säuberlichere": "säuberlich",
    "säuberlicherem": "säuberlich",
    "säuberlicheren": "säuberlich",
    "säuberlicherer": "säuberlich",
    "säuberlicheres": "säuberlich",
    "säuberliches": "säuberlich",
    "säuberlichste": "säuberlich",
    "säuberlichstem": "säuberlich",
    "säuberlichsten": "säuberlich",
    "säuberlichster": "säuberlich",
    "säuberlichstes": "säuberlich",
    "säubernd": "säubern",
    "säubernde": "säubernd",
    "säuberndem": "säubernd",
    "säubernden": "säubernd",
    "säubernder": "säubernd",
    "säuberndere": "säubernd",
    "säubernderem": "säubernd",
    "säubernderen": "säubernd",
    "säubernderer": "säubernd",
    "säubernderes": "säubernd",
    "säuberndes": "säubernd",
    "säuberndste": "säubernd",
    "säuberndstem": "säubernd",
    "säuberndsten": "säubernd",
    "säuberndster": "säubernd",
    "säuberndstes": "säubernd",
    "säuberst": "säubern",
    "säubert": "säubern",
    "säuberte": "säubern",
    "säuberten": "säubern",
    "säubertest": "säubern",
    "säubertet": "säubern",
    "säuere": "säuern",
    "säuerliche": "säuerlich",
    "säuerlichem": "säuerlich",
    "säuerlichen": "säuerlich",
    "säuerlicher": "säuerlich",
    "säuerlichere": "säuerlich",
    "säuerlicherem": "säuerlich",
    "säuerlicheren": "säuerlich",
    "säuerlicherer": "säuerlich",
    "säuerlicheres": "säuerlich",
    "säuerliches": "säuerlich",
    "säuerlichste": "säuerlich",
    "säuerlichstem": "säuerlich",
    "säuerlichsten": "säuerlich",
    "säuerlichster": "säuerlich",
    "säuerlichstes": "säuerlich",
    "säuernd": "säuern",
    "säuerndem": "säuernd",
    "säuernder": "säuernd",
    "säuernderem": "säuernd",
    "säuernderer": "säuernd",
    "säuernderes": "säuernd",
    "säuerndes": "säuernd",
    "säuerndstem": "säuernd",
    "säuerndster": "säuernd",
    "säuerndstes": "säuernd",
    "säuerst": "säuern",
    "säuert": "säuern",
    "säuerte": "säuern",
    "säuerten": "säuern",
    "säuertest": "säuern",
    "säuertet": "säuern",
    "säufst": "saufen",
    "säuft": "saufen",
    "säumend": "säumen",
    "säumende": "säumend",
    "säumendem": "säumend",
    "säumenden": "säumend",
    "säumender": "säumend",
    "säumendes": "säumend",
    "säumest": "säumen",
    "säumet": "säumen",
    "säumige": "säumig",
    "säumigem": "säumig",
    "säumigen": "säumig",
    "säumiger": "säumig",
    "säumigere": "säumig",
    "säumigerem": "säumig",
    "säumigeren": "säumig",
    "säumigerer": "säumig",
    "säumigeres": "säumig",
    "säumiges": "säumig",
    "säumigste": "säumig",
    "säumigstem": "säumig",
    "säumigsten": "säumig",
    "säumigster": "säumig",
    "säumigstes": "säumig",
    "säumst": "säumen",
    "säumt": "säumen",
    "säumte": "säumen",
    "säumten": "säumen",
    "säumtest": "säumen",
    "säumtet": "säumen",
    "säurebeständigem": "säurebeständig",
    "säurebeständigen": "säurebeständig",
    "säurebeständiger": "säurebeständig",
    "säurebeständigere": "säurebeständig",
    "säurebeständigerem": "säurebeständig",
    "säurebeständigeren": "säurebeständig",
    "säurebeständigerer": "säurebeständig",
    "säurebeständigeres": "säurebeständig",
    "säurebeständiges": "säurebeständig",
    "säurebeständigste": "säurebeständig",
    "säurebeständigstem": "säurebeständig",
    "säurebeständigsten": "säurebeständig",
    "säurebeständigster": "säurebeständig",
    "säurebeständigstes": "säurebeständig",
    "säurefeste": "säurefest",
    "säurefestem": "säurefest",
    "säurefesten": "säurefest",
    "säurefester": "säurefest",
    "säurefestere": "säurefest",
    "säurefesterem": "säurefest",
    "säurefesteren": "säurefest",
    "säurefesterer": "säurefest",
    "säurefesteres": "säurefest",
    "säurefestes": "säurefest",
    "säurefesteste": "säurefest",
    "säurefestestem": "säurefest",
    "säurefestesten": "säurefest",
    "säurefestester": "säurefest",
    "säurefestestes": "säurefest",
    "säurefreie": "säurefrei",
    "säurefreiem": "säurefrei",
    "säurefreien": "säurefrei",
    "säurefreier": "säurefrei",
    "säurefreies": "säurefrei",
    "säusele": "säuseln",
    "säuselnd": "säuseln",
    "säuselnde": "säuselnd",
    "säuselndem": "säuselnd",
    "säuselnden": "säuselnd",
    "säuselnder": "säuselnd",
    "säuselndere": "säuselnd",
    "säuselnderem": "säuselnd",
    "säuselnderen": "säuselnd",
    "säuselnderer": "säuselnd",
    "säuselnderes": "säuselnd",
    "säuselndes": "säuselnd",
    "säuselndste": "säuselnd",
    "säuselndstem": "säuselnd",
    "säuselndsten": "säuselnd",
    "säuselndster": "säuselnd",
    "säuselndstes": "säuselnd",
    "säuselst": "säuseln",
    "säuselt": "säuseln",
    "säuselte": "säuseln",
    "säuselten": "säuseln",
    "säuseltest": "säuseln",
    "säuseltet": "säuseln",
    "säusle": "säuseln",
    "säße": "sitzen",
    "säßen": "sitzen",
    "säßest": "sitzen",
    "säßet": "sitzen",
    "söffe": "saufen",
    "söffen": "saufen",
    "söffest": "saufen",
    "söffet": "saufen",
    "söge": "saugen",
    "sögen": "saugen",
    "sögest": "saugen",
    "söget": "saugen",
    "söhnend": "söhnen",
    "söhnende": "söhnend",
    "söhnendem": "söhnend",
    "söhnenden": "söhnend",
    "söhnender": "söhnend",
    "söhnendes": "söhnend",
    "söhnest": "söhnen",
    "söhnet": "söhnen",
    "söhnst": "söhnen",
    "söhnt": "söhnen",
    "söhnte": "söhnen",
    "söhnten": "söhnen",
    "söhntest": "söhnen",
    "söhntet": "söhnen",
    "sötte": "sieden",
    "sötten": "sieden",
    "söttest": "sieden",
    "söttet": "sieden",
    "süchtige": "süchtig",
    "süchtigem": "süchtig",
    "süchtigen": "süchtig",
    "süchtiger": "süchtig",
    "süchtigere": "süchtig",
    "süchtigerem": "süchtig",
    "süchtigeren": "süchtig",
    "süchtigerer": "süchtig",
    "süchtigeres": "süchtig",
    "süchtiges": "süchtig",
    "süchtigste": "süchtig",
    "süchtigstem": "süchtig",
    "süchtigsten": "süchtig",
    "süchtigster": "süchtig",
    "süchtigstes": "süchtig",
    "südafrikanische": "südafrikanisch",
    "südafrikanischem": "südafrikanisch",
    "südafrikanischen": "südafrikanisch",
    "südafrikanischer": "südafrikanisch",
    "südafrikanisches": "südafrikanisch",
    "süddeutschem": "süddeutsch",
    "süddeutschen": "süddeutsch",
    "süddeutscher": "süddeutsch",
    "süddeutsches": "süddeutsch",
    "südliche": "südlich",
    "südlichem": "südlich",
    "südlichen": "südlich",
    "südlicher": "südlich",
    "südlichere": "südlich",
    "südlicherem": "südlich",
    "südlicheren": "südlich",
    "südlicherer": "südlich",
    "südlicheres": "südlich",
    "südliches": "südlich",
    "südlichste": "südlich",
    "südlichstem": "südlich",
    "südlichsten": "südlich",
    "südlichster": "südlich",
    "südlichstes": "südlich",
    "südländischem": "südländisch",
    "südländischen": "südländisch",
    "südländischer": "südländisch",
    "südländisches": "südländisch",
    "südwestlichem": "südwestlich",
    "südwestlichen": "südwestlich",
    "südwestlicher": "südwestlich",
    "südwestliches": "südwestlich",
    "südöstlichem": "südöstlich",
    "südöstlichen": "südöstlich",
    "südöstlicher": "südöstlich",
    "südöstliches": "südöstlich",
    "süffele": "süffeln",
    "süffelnd": "süffeln",
    "süffelnde": "süffelnd",
    "süffelndem": "süffelnd",
    "süffelnden": "süffelnd",
    "süffelnder": "süffelnd",
    "süffelndes": "süffelnd",
    "süffelst": "süffeln",
    "süffelt": "süffeln",
    "süffelte": "süffeln",
    "süffelten": "süffeln",
    "süffeltest": "süffeln",
    "süffeltet": "süffeln",
    "süffige": "süffig",
    "süffigem": "süffig",
    "süffigen": "süffig",
    "süffiger": "süffig",
    "süffigere": "süffig",
    "süffigerem": "süffig",
    "süffigeren": "süffig",
    "süffigerer": "süffig",
    "süffigeres": "süffig",
    "süffiges": "süffig",
    "süffigste": "süffig",
    "süffigstem": "süffig",
    "süffigsten": "süffig",
    "süffigster": "süffig",
    "süffigstes": "süffig",
    "süffisante": "süffisant",
    "süffisantem": "süffisant",
    "süffisanten": "süffisant",
    "süffisanter": "süffisant",
    "süffisantere": "süffisant",
    "süffisanterem": "süffisant",
    "süffisanteren": "süffisant",
    "süffisanterer": "süffisant",
    "süffisanteres": "süffisant",
    "süffisantes": "süffisant",
    "süffisanteste": "süffisant",
    "süffisantestem": "süffisant",
    "süffisantesten": "süffisant",
    "süffisantester": "süffisant",
    "süffisantestes": "süffisant",
    "süffle": "süffeln",
    "sühne": "sühnen",
    "sühnend": "sühnen",
    "sühnende": "sühnend",
    "sühnendem": "sühnend",
    "sühnenden": "sühnend",
    "sühnender": "sühnend",
    "sühnendes": "sühnend",
    "sühnest": "sühnen",
    "sühnet": "sühnen",
    "sühnst": "sühnen",
    "sühnt": "sühnen",
    "sühnte": "sühnen",
    "sühnten": "sühnen",
    "sühntest": "sühnen",
    "sühntet": "sühnen",
    "sülzend": "sülzen",
    "sülzende": "sülzend",
    "sülzendem": "sülzend",
    "sülzenden": "sülzend",
    "sülzender": "sülzend",
    "sülzendere": "sülzend",
    "sülzenderem": "sülzend",
    "sülzenderen": "sülzend",
    "sülzenderer": "sülzend",
    "sülzenderes": "sülzend",
    "sülzendes": "sülzend",
    "sülzendste": "sülzend",
    "sülzendstem": "sülzend",
    "sülzendsten": "sülzend",
    "sülzendster": "sülzend",
    "sülzendstes": "sülzend",
    "sülzest": "sülzen",
    "sülzet": "sülzen",
    "sülzt": "sülzen",
    "sülzte": "sülzen",
    "sülzten": "sülzen",
    "sülztest": "sülzen",
    "sülztet": "sülzen",
    "sündhaftem": "sündhaft",
    "sündhaften": "sündhaft",
    "sündhafter": "sündhaft",
    "sündhaftere": "sündhaft",
    "sündhafterem": "sündhaft",
    "sündhafteren": "sündhaft",
    "sündhafterer": "sündhaft",
    "sündhafteres": "sündhaft",
    "sündhaftes": "sündhaft",
    "sündhafteste": "sündhaft",
    "sündhaftestem": "sündhaft",
    "sündhaftesten": "sündhaft",
    "sündhaftester": "sündhaft",
    "sündhaftestes": "sündhaft",
    "sündig": "sündigen",
    "sündige": "sündig",
    "sündigem": "sündig",
    "sündigen": "sündig",
    "sündigend": "sündigen",
    "sündigende": "sündigend",
    "sündigendem": "sündigend",
    "sündigenden": "sündigend",
    "sündigender": "sündigend",
    "sündigendere": "sündigend",
    "sündigenderem": "sündigend",
    "sündigenderen": "sündigend",
    "sündigenderer": "sündigend",
    "sündigenderes": "sündigend",
    "sündigendes": "sündigend",
    "sündigendste": "sündigend",
    "sündigendstem": "sündigend",
    "sündigendsten": "sündigend",
    "sündigendster": "sündigend",
    "sündigendstes": "sündigend",
    "sündiger": "sündig",
    "sündigere": "sündig",
    "sündigerem": "sündig",
    "sündigeren": "sündig",
    "sündigerer": "sündig",
    "sündigeres": "sündig",
    "sündiges": "sündig",
    "sündigest": "sündigen",
    "sündiget": "sündigen",
    "sündigst": "sündigen",
    "sündigste": "sündig",
    "sündigstem": "sündig",
    "sündigsten": "sündig",
    "sündigster": "sündig",
    "sündigstes": "sündig",
    "sündigt": "sündigen",
    "sündigte": "sündigen",
    "sündigten": "sündigen",
    "sündigtest": "sündigen",
    "sündigtet": "sündigen",
    "süß": "süßen",
    "süße": "süß",
    "süßem": "süß",
    "süßen": "süß",
    "süßend": "süßen",
    "süßende": "süßend",
    "süßendem": "süßend",
    "süßenden": "süßend",
    "süßender": "süßend",
    "süßendere": "süßend",
    "süßenderem": "süßend",
    "süßenderen": "süßend",
    "süßenderer": "süßend",
    "süßenderes": "süßend",
    "süßendes": "süßend",
    "süßendste": "süßend",
    "süßendstem": "süßend",
    "süßendsten": "süßend",
    "süßendster": "süßend",
    "süßendstes": "süßend",
    "süßer": "süß",
    "süßere": "süß",
    "süßerem": "süß",
    "süßeren": "süß",
    "süßerer": "süß",
    "süßeres": "süß",
    "süßes": "süß",
    "süßest": "süßen",
    "süßeste": "süß",
    "süßestem": "süß",
    "süßesten": "süß",
    "süßester": "süß",
    "süßestes": "süß",
    "süßet": "süßen",
    "süßlichem": "süßlich",
    "süßlichen": "süßlich",
    "süßlicher": "süßlich",
    "süßlichere": "süßlich",
    "süßlicherem": "süßlich",
    "süßlicheren": "süßlich",
    "süßlicherer": "süßlich",
    "süßlicheres": "süßlich",
    "süßliches": "süßlich",
    "süßlichste": "süßlich",
    "süßlichstem": "süßlich",
    "süßlichsten": "süßlich",
    "süßlichster": "süßlich",
    "süßlichstes": "süßlich",
    "süßsaurem": "süßsauer",
    "süßsauren": "süßsauer",
    "süßsaurer": "süßsauer",
    "süßsaures": "süßsauer",
    "süßt": "süßen",
    "süßte": "süßen",
    "süßten": "süßen",
    "süßtest": "süßen",
    "süßtet": "süßen",
    "tabellarischem": "tabellarisch",
    "tabellarischen": "tabellarisch",
    "tabellarischer": "tabellarisch",
    "tabellarisches": "tabellarisch",
    "tabellarisiere": "tabellarisieren",
    "tabellarisierend": "tabellarisieren",
    "tabellarisierende": "tabellarisierend",
    "tabellarisierendem": "tabellarisierend",
    "tabellarisierenden": "tabellarisierend",
    "tabellarisierender": "tabellarisierend",
    "tabellarisierendere": "tabellarisierend",
    "tabellarisierenderem": "tabellarisierend",
    "tabellarisierenderen": "tabellarisierend",
    "tabellarisierenderer": "tabellarisierend",
    "tabellarisierenderes": "tabellarisierend",
    "tabellarisierendes": "tabellarisierend",
    "tabellarisierendste": "tabellarisierend",
    "tabellarisierendstem": "tabellarisierend",
    "tabellarisierendsten": "tabellarisierend",
    "tabellarisierendster": "tabellarisierend",
    "tabellarisierendstes": "tabellarisierend",
    "tabellarisierest": "tabellarisieren",
    "tabellarisieret": "tabellarisieren",
    "tabellarisierst": "tabellarisieren",
    "tabellarisiert": "tabellarisieren",
    "tabellarisierte": "tabellarisieren",
    "tabellarisiertem": "tabellarisiert",
    "tabellarisierten": "tabellarisieren",
    "tabellarisierter": "tabellarisiert",
    "tabellarisiertere": "tabellarisiert",
    "tabellarisierterem": "tabellarisiert",
    "tabellarisierteren": "tabellarisiert",
    "tabellarisierterer": "tabellarisiert",
    "tabellarisierteres": "tabellarisiert",
    "tabellarisiertes": "tabellarisiert",
    "tabellarisiertest": "tabellarisieren",
    "tabellarisierteste": "tabellarisiert",
    "tabellarisiertestem": "tabellarisiert",
    "tabellarisiertesten": "tabellarisiert",
    "tabellarisiertester": "tabellarisiert",
    "tabellarisiertestes": "tabellarisiert",
    "tabellarisiertet": "tabellarisieren",
    "tabelliere": "tabellieren",
    "tabellierend": "tabellieren",
    "tabellierende": "tabellierend",
    "tabellierendem": "tabellierend",
    "tabellierenden": "tabellierend",
    "tabellierender": "tabellierend",
    "tabellierendere": "tabellierend",
    "tabellierenderem": "tabellierend",
    "tabellierenderen": "tabellierend",
    "tabellierenderer": "tabellierend",
    "tabellierenderes": "tabellierend",
    "tabellierendes": "tabellierend",
    "tabellierendste": "tabellierend",
    "tabellierendstem": "tabellierend",
    "tabellierendsten": "tabellierend",
    "tabellierendster": "tabellierend",
    "tabellierendstes": "tabellierend",
    "tabellierest": "tabellieren",
    "tabellieret": "tabellieren",
    "tabellierst": "tabellieren",
    "tabelliert": "tabellieren",
    "tabellierte": "tabellieren",
    "tabelliertem": "tabelliert",
    "tabellierten": "tabellieren",
    "tabellierter": "tabelliert",
    "tabelliertere": "tabelliert",
    "tabellierterem": "tabelliert",
    "tabellierteren": "tabelliert",
    "tabellierterer": "tabelliert",
    "tabellierteres": "tabelliert",
    "tabelliertes": "tabelliert",
    "tabelliertest": "tabellieren",
    "tabellierteste": "tabelliert",
    "tabelliertestem": "tabelliert",
    "tabelliertesten": "tabelliert",
    "tabelliertester": "tabelliert",
    "tabelliertestes": "tabelliert",
    "tabelliertet": "tabellieren",
    "tabuiere": "tabuieren",
    "tabuierend": "tabuieren",
    "tabuierende": "tabuierend",
    "tabuierendem": "tabuierend",
    "tabuierenden": "tabuierend",
    "tabuierender": "tabuierend",
    "tabuierendere": "tabuierend",
    "tabuierenderem": "tabuierend",
    "tabuierenderen": "tabuierend",
    "tabuierenderer": "tabuierend",
    "tabuierenderes": "tabuierend",
    "tabuierendes": "tabuierend",
    "tabuierendste": "tabuierend",
    "tabuierendstem": "tabuierend",
    "tabuierendsten": "tabuierend",
    "tabuierendster": "tabuierend",
    "tabuierendstes": "tabuierend",
    "tabuierest": "tabuieren",
    "tabuieret": "tabuieren",
    "tabuierst": "tabuieren",
    "tabuiert": "tabuieren",
    "tabuierte": "tabuieren",
    "tabuiertem": "tabuiert",
    "tabuierten": "tabuieren",
    "tabuierter": "tabuiert",
    "tabuiertere": "tabuiert",
    "tabuierterem": "tabuiert",
    "tabuierteren": "tabuiert",
    "tabuierterer": "tabuiert",
    "tabuierteres": "tabuiert",
    "tabuiertes": "tabuiert",
    "tabuiertest": "tabuieren",
    "tabuierteste": "tabuiert",
    "tabuiertestem": "tabuiert",
    "tabuiertesten": "tabuiert",
    "tabuiertester": "tabuiert",
    "tabuiertestes": "tabuiert",
    "tabuiertet": "tabuieren",
    "tadele": "tadeln",
    "tadellose": "tadellos",
    "tadellosem": "tadellos",
    "tadellosen": "tadellos",
    "tadelloser": "tadellos",
    "tadellosere": "tadellos",
    "tadelloserem": "tadellos",
    "tadelloseren": "tadellos",
    "tadelloserer": "tadellos",
    "tadelloseres": "tadellos",
    "tadelloses": "tadellos",
    "tadelloseste": "tadellos",
    "tadellosestem": "tadellos",
    "tadellosesten": "tadellos",
    "tadellosester": "tadellos",
    "tadellosestes": "tadellos",
    "tadelnd": "tadeln",
    "tadelnde": "tadelnd",
    "tadelndem": "tadelnd",
    "tadelnden": "tadelnd",
    "tadelnder": "tadelnd",
    "tadelndere": "tadelnd",
    "tadelnderem": "tadelnd",
    "tadelnderen": "tadelnd",
    "tadelnderer": "tadelnd",
    "tadelnderes": "tadelnd",
    "tadelndes": "tadelnd",
    "tadelndste": "tadelnd",
    "tadelndstem": "tadelnd",
    "tadelndsten": "tadelnd",
    "tadelndster": "tadelnd",
    "tadelndstes": "tadelnd",
    "tadelst": "tadeln",
    "tadelt": "tadeln",
    "tadelte": "tadeln",
    "tadelten": "tadeln",
    "tadeltest": "tadeln",
    "tadeltet": "tadeln",
    "tadle": "tadeln",
    "tagend": "tagen",
    "tagende": "tagend",
    "tagendem": "tagend",
    "tagenden": "tagend",
    "tagender": "tagend",
    "tagendere": "tagend",
    "tagenderem": "tagend",
    "tagenderen": "tagend",
    "tagenderer": "tagend",
    "tagenderes": "tagend",
    "tagendes": "tagend",
    "tagendste": "tagend",
    "tagendstem": "tagend",
    "tagendsten": "tagend",
    "tagendster": "tagend",
    "tagendstes": "tagend",
    "tagest": "tagen",
    "taget": "tagen",
    "tagst": "tagen",
    "tagt": "tagen",
    "tagte": "tagen",
    "tagten": "tagen",
    "tagtest": "tagen",
    "tagtet": "tagen",
    "tagtägliche": "tagtäglich",
    "tagtäglichem": "tagtäglich",
    "tagtäglichen": "tagtäglich",
    "tagtäglicher": "tagtäglich",
    "tagtägliches": "tagtäglich",
    "takele": "takeln",
    "takelnd": "takeln",
    "takelnde": "takelnd",
    "takelndem": "takelnd",
    "takelnden": "takelnd",
    "takelnder": "takelnd",
    "takelndes": "takelnd",
    "takelst": "takeln",
    "takelt": "takeln",
    "takelte": "takeln",
    "takelten": "takeln",
    "takeltest": "takeln",
    "takeltet": "takeln",
    "takle": "takeln",
    "taktiere": "taktieren",
    "taktierend": "taktieren",
    "taktierende": "taktierend",
    "taktierendem": "taktierend",
    "taktierenden": "taktierend",
    "taktierender": "taktierend",
    "taktierendere": "taktierend",
    "taktierenderem": "taktierend",
    "taktierenderen": "taktierend",
    "taktierenderer": "taktierend",
    "taktierenderes": "taktierend",
    "taktierendes": "taktierend",
    "taktierendste": "taktierend",
    "taktierendstem": "taktierend",
    "taktierendsten": "taktierend",
    "taktierendster": "taktierend",
    "taktierendstes": "taktierend",
    "taktierest": "taktieren",
    "taktieret": "taktieren",
    "taktierst": "taktieren",
    "taktiert": "taktieren",
    "taktierte": "taktieren",
    "taktiertem": "taktiert",
    "taktierten": "taktieren",
    "taktierter": "taktiert",
    "taktiertere": "taktiert",
    "taktierterem": "taktiert",
    "taktierteren": "taktiert",
    "taktierterer": "taktiert",
    "taktierteres": "taktiert",
    "taktiertes": "taktiert",
    "taktiertest": "taktieren",
    "taktierteste": "taktiert",
    "taktiertestem": "taktiert",
    "taktiertesten": "taktiert",
    "taktiertester": "taktiert",
    "taktiertestes": "taktiert",
    "taktiertet": "taktieren",
    "taktischem": "taktisch",
    "taktischen": "taktisch",
    "taktischer": "taktisch",
    "taktisches": "taktisch",
    "taktlose": "taktlos",
    "taktlosem": "taktlos",
    "taktlosen": "taktlos",
    "taktloser": "taktlos",
    "taktlosere": "taktlos",
    "taktloserem": "taktlos",
    "taktloseren": "taktlos",
    "taktloserer": "taktlos",
    "taktloseres": "taktlos",
    "taktloses": "taktlos",
    "taktloseste": "taktlos",
    "taktlosestem": "taktlos",
    "taktlosesten": "taktlos",
    "taktlosester": "taktlos",
    "taktlosestes": "taktlos",
    "talentiertem": "talentiert",
    "talentierten": "talentiert",
    "talentierter": "talentiert",
    "talentiertere": "talentiert",
    "talentierterem": "talentiert",
    "talentierteren": "talentiert",
    "talentierterer": "talentiert",
    "talentierteres": "talentiert",
    "talentiertes": "talentiert",
    "talentierteste": "talentiert",
    "talentiertestem": "talentiert",
    "talentiertesten": "talentiert",
    "talentiertester": "talentiert",
    "talentiertestes": "talentiert",
    "tamilischem": "tamilisch",
    "tamilischen": "tamilisch",
    "tamilischer": "tamilisch",
    "tamilisches": "tamilisch",
    "tamponiere": "tamponieren",
    "tamponierend": "tamponieren",
    "tamponierende": "tamponierend",
    "tamponierendem": "tamponierend",
    "tamponierenden": "tamponierend",
    "tamponierender": "tamponierend",
    "tamponierendes": "tamponierend",
    "tamponierest": "tamponieren",
    "tamponieret": "tamponieren",
    "tamponierst": "tamponieren",
    "tamponiert": "tamponieren",
    "tamponierte": "tamponieren",
    "tamponiertem": "tamponiert",
    "tamponierten": "tamponieren",
    "tamponierter": "tamponiert",
    "tamponiertes": "tamponiert",
    "tamponiertest": "tamponieren",
    "tamponiertet": "tamponieren",
    "tangentialem": "tangential",
    "tangentialen": "tangential",
    "tangentialer": "tangential",
    "tangentiales": "tangential",
    "tangiere": "tangieren",
    "tangierend": "tangieren",
    "tangierende": "tangierend",
    "tangierendem": "tangierend",
    "tangierenden": "tangierend",
    "tangierender": "tangierend",
    "tangierendes": "tangierend",
    "tangierest": "tangieren",
    "tangieret": "tangieren",
    "tangierst": "tangieren",
    "tangiert": "tangieren",
    "tangierte": "tangieren",
    "tangiertem": "tangiert",
    "tangierten": "tangieren",
    "tangierter": "tangiert",
    "tangiertes": "tangiert",
    "tangiertest": "tangieren",
    "tangiertet": "tangieren",
    "tanke": "tanken",
    "tankend": "tanken",
    "tankende": "tankend",
    "tankendem": "tankend",
    "tankenden": "tankend",
    "tankender": "tankend",
    "tankendes": "tankend",
    "tankest": "tanken",
    "tanket": "tanken",
    "tankst": "tanken",
    "tankt": "tanken",
    "tankte": "tanken",
    "tankten": "tanken",
    "tanktest": "tanken",
    "tanktet": "tanken",
    "tanzbegeistertem": "tanzbegeistert",
    "tanzbegeisterten": "tanzbegeistert",
    "tanzbegeisterter": "tanzbegeistert",
    "tanzbegeistertere": "tanzbegeistert",
    "tanzbegeisterterem": "tanzbegeistert",
    "tanzbegeisterteren": "tanzbegeistert",
    "tanzbegeisterterer": "tanzbegeistert",
    "tanzbegeisterteres": "tanzbegeistert",
    "tanzbegeistertes": "tanzbegeistert",
    "tanzbegeisterteste": "tanzbegeistert",
    "tanzbegeistertestem": "tanzbegeistert",
    "tanzbegeistertesten": "tanzbegeistert",
    "tanzbegeistertester": "tanzbegeistert",
    "tanzbegeistertestes": "tanzbegeistert",
    "tanzend": "tanzen",
    "tanzende": "tanzend",
    "tanzendem": "tanzend",
    "tanzenden": "tanzend",
    "tanzender": "tanzend",
    "tanzendes": "tanzend",
    "tanzest": "tanzen",
    "tanzet": "tanzen",
    "tanzlustigem": "tanzlustig",
    "tanzlustigen": "tanzlustig",
    "tanzlustiger": "tanzlustig",
    "tanzlustigere": "tanzlustig",
    "tanzlustigerem": "tanzlustig",
    "tanzlustigeren": "tanzlustig",
    "tanzlustigerer": "tanzlustig",
    "tanzlustigeres": "tanzlustig",
    "tanzlustiges": "tanzlustig",
    "tanzlustigste": "tanzlustig",
    "tanzlustigstem": "tanzlustig",
    "tanzlustigsten": "tanzlustig",
    "tanzlustigster": "tanzlustig",
    "tanzlustigstes": "tanzlustig",
    "tanzt": "tanzen",
    "tanzte": "tanzen",
    "tanzten": "tanzen",
    "tanztest": "tanzen",
    "tanztet": "tanzen",
    "tapere": "tapern",
    "tapernd": "tapern",
    "tapernde": "tapernd",
    "taperndem": "tapernd",
    "tapernden": "tapernd",
    "tapernder": "tapernd",
    "taperndere": "tapernd",
    "tapernderem": "tapernd",
    "tapernderen": "tapernd",
    "tapernderer": "tapernd",
    "tapernderes": "tapernd",
    "taperndes": "tapernd",
    "taperndste": "tapernd",
    "taperndstem": "tapernd",
    "taperndsten": "tapernd",
    "taperndster": "tapernd",
    "taperndstes": "tapernd",
    "taperst": "tapern",
    "tapert": "tapern",
    "taperte": "tapern",
    "taperten": "tapern",
    "tapertest": "tapern",
    "tapertet": "tapern",
    "tapeziere": "tapezieren",
    "tapezierend": "tapezieren",
    "tapezierende": "tapezierend",
    "tapezierendem": "tapezierend",
    "tapezierenden": "tapezierend",
    "tapezierender": "tapezierend",
    "tapezierendes": "tapezierend",
    "tapezierest": "tapezieren",
    "tapezieret": "tapezieren",
    "tapezierst": "tapezieren",
    "tapeziert": "tapezieren",
    "tapezierte": "tapezieren",
    "tapeziertem": "tapeziert",
    "tapezierten": "tapezieren",
    "tapezierter": "tapeziert",
    "tapeziertes": "tapeziert",
    "tapeziertest": "tapezieren",
    "tapeziertet": "tapezieren",
    "tapfere": "tapfer",
    "tapferem": "tapfer",
    "tapferen": "tapfer",
    "tapferer": "tapfer",
    "tapferere": "tapfer",
    "tapfererem": "tapfer",
    "tapfereren": "tapfer",
    "tapfererer": "tapfer",
    "tapfereres": "tapfer",
    "tapferes": "tapfer",
    "tapferste": "tapfer",
    "tapferstem": "tapfer",
    "tapfersten": "tapfer",
    "tapferster": "tapfer",
    "tapferstes": "tapfer",
    "tappe": "tappen",
    "tappend": "tappen",
    "tappende": "tappend",
    "tappendem": "tappend",
    "tappenden": "tappend",
    "tappender": "tappend",
    "tappendes": "tappend",
    "tappest": "tappen",
    "tappet": "tappen",
    "tappst": "tappen",
    "tappt": "tappen",
    "tappte": "tappen",
    "tappten": "tappen",
    "tapptest": "tappen",
    "tapptet": "tappen",
    "tapse": "tapsen",
    "tapsend": "tapsen",
    "tapsende": "tapsend",
    "tapsendem": "tapsend",
    "tapsenden": "tapsend",
    "tapsender": "tapsend",
    "tapsendere": "tapsend",
    "tapsenderem": "tapsend",
    "tapsenderen": "tapsend",
    "tapsenderer": "tapsend",
    "tapsenderes": "tapsend",
    "tapsendes": "tapsend",
    "tapsendste": "tapsend",
    "tapsendstem": "tapsend",
    "tapsendsten": "tapsend",
    "tapsendster": "tapsend",
    "tapsendstes": "tapsend",
    "tapsest": "tapsen",
    "tapset": "tapsen",
    "tapsige": "tapsig",
    "tapsigem": "tapsig",
    "tapsigen": "tapsig",
    "tapsiger": "tapsig",
    "tapsiges": "tapsig",
    "tapst": "tapsen",
    "tapste": "tapsen",
    "tapsten": "tapsen",
    "tapstest": "tapsen",
    "tapstet": "tapsen",
    "tariere": "tarieren",
    "tarierend": "tarieren",
    "tarierende": "tarierend",
    "tarierendem": "tarierend",
    "tarierenden": "tarierend",
    "tarierender": "tarierend",
    "tarierendes": "tarierend",
    "tarierest": "tarieren",
    "tarieret": "tarieren",
    "tarierst": "tarieren",
    "tariert": "tarieren",
    "tarierte": "tarieren",
    "tariertem": "tariert",
    "tarierten": "tarieren",
    "tarierter": "tariert",
    "tariertes": "tariert",
    "tariertest": "tarieren",
    "tariertet": "tarieren",
    "tariflichem": "tariflich",
    "tariflichen": "tariflich",
    "tariflicher": "tariflich",
    "tarifliches": "tariflich",
    "tarne": "tarnen",
    "tarnend": "tarnen",
    "tarnende": "tarnend",
    "tarnendem": "tarnend",
    "tarnenden": "tarnend",
    "tarnender": "tarnend",
    "tarnendere": "tarnend",
    "tarnenderem": "tarnend",
    "tarnenderen": "tarnend",
    "tarnenderer": "tarnend",
    "tarnenderes": "tarnend",
    "tarnendes": "tarnend",
    "tarnendste": "tarnend",
    "tarnendstem": "tarnend",
    "tarnendsten": "tarnend",
    "tarnendster": "tarnend",
    "tarnendstes": "tarnend",
    "tarnest": "tarnen",
    "tarnet": "tarnen",
    "tarnst": "tarnen",
    "tarnt": "tarnen",
    "tarnte": "tarnen",
    "tarnten": "tarnen",
    "tarntest": "tarnen",
    "tarntet": "tarnen",
    "tastend": "tasten",
    "tastende": "tastend",
    "tastendem": "tastend",
    "tastenden": "tastend",
    "tastender": "tastend",
    "tastendes": "tastend",
    "tastest": "tasten",
    "tastet": "tasten",
    "tastete": "tasten",
    "tasteten": "tasten",
    "tastetest": "tasten",
    "tastetet": "tasten",
    "tat": "tun",
    "tatendurstige": "tatendurstig",
    "tatendurstigem": "tatendurstig",
    "tatendurstigen": "tatendurstig",
    "tatendurstiger": "tatendurstig",
    "tatendurstigere": "tatendurstig",
    "tatendurstigerem": "tatendurstig",
    "tatendurstigeren": "tatendurstig",
    "tatendurstigerer": "tatendurstig",
    "tatendurstigeres": "tatendurstig",
    "tatendurstiges": "tatendurstig",
    "tatendurstigste": "tatendurstig",
    "tatendurstigstem": "tatendurstig",
    "tatendurstigsten": "tatendurstig",
    "tatendurstigster": "tatendurstig",
    "tatendurstigstes": "tatendurstig",
    "tatenlose": "tatenlos",
    "tatenlosem": "tatenlos",
    "tatenlosen": "tatenlos",
    "tatenloser": "tatenlos",
    "tatenloses": "tatenlos",
    "tatest": "tun",
    "tatet": "tun",
    "tatkräftige": "tatkräftig",
    "tatkräftigem": "tatkräftig",
    "tatkräftigen": "tatkräftig",
    "tatkräftiger": "tatkräftig",
    "tatkräftiges": "tatkräftig",
    "tatsche": "tatschen",
    "tatschend": "tatschen",
    "tatschende": "tatschend",
    "tatschendem": "tatschend",
    "tatschenden": "tatschend",
    "tatschender": "tatschend",
    "tatschendes": "tatschend",
    "tatschest": "tatschen",
    "tatschet": "tatschen",
    "tatschst": "tatschen",
    "tatscht": "tatschen",
    "tatschte": "tatschen",
    "tatschten": "tatschen",
    "tatschtest": "tatschen",
    "tatschtet": "tatschen",
    "tatsächlichem": "tatsächlich",
    "tatsächlichen": "tatsächlich",
    "tatsächlicher": "tatsächlich",
    "tatsächliches": "tatsächlich",
    "tatterigem": "tatterig",
    "tatterigen": "tatterig",
    "tatteriger": "tatterig",
    "tatterigere": "tatterig",
    "tatterigerem": "tatterig",
    "tatterigeren": "tatterig",
    "tatterigerer": "tatterig",
    "tatterigeres": "tatterig",
    "tatteriges": "tatterig",
    "tatterigste": "tatterig",
    "tatterigstem": "tatterig",
    "tatterigsten": "tatterig",
    "tatterigster": "tatterig",
    "tatterigstes": "tatterig",
    "taubem": "taub",
    "tauben": "taub",
    "taubes": "taub",
    "taubstumme": "taubstumm",
    "taubstummem": "taubstumm",
    "taubstummen": "taubstumm",
    "taubstummer": "taubstumm",
    "taubstummes": "taubstumm",
    "tauche": "tauchen",
    "tauchend": "tauchen",
    "tauchende": "tauchend",
    "tauchendem": "tauchend",
    "tauchenden": "tauchend",
    "tauchender": "tauchend",
    "tauchendes": "tauchend",
    "tauchest": "tauchen",
    "tauchet": "tauchen",
    "tauchst": "tauchen",
    "taucht": "tauchen",
    "tauchte": "tauchen",
    "tauchten": "tauchen",
    "tauchtest": "tauchen",
    "tauchtet": "tauchen",
    "taue": "tauen",
    "tauend": "tauen",
    "tauende": "tauend",
    "tauendem": "tauend",
    "tauenden": "tauend",
    "tauender": "tauend",
    "tauendes": "tauend",
    "tauest": "tauen",
    "tauet": "tauen",
    "taufe": "taufen",
    "taufend": "taufen",
    "taufende": "taufend",
    "taufendem": "taufend",
    "taufenden": "taufend",
    "taufender": "taufend",
    "taufendes": "taufend",
    "taufest": "taufen",
    "taufet": "taufen",
    "taufrischem": "taufrisch",
    "taufrischen": "taufrisch",
    "taufrischer": "taufrisch",
    "taufrisches": "taufrisch",
    "taufst": "taufen",
    "tauft": "taufen",
    "taufte": "taufen",
    "tauften": "taufen",
    "tauftest": "taufen",
    "tauftet": "taufen",
    "tauge": "taugen",
    "taugend": "taugen",
    "taugende": "taugend",
    "taugendem": "taugend",
    "taugenden": "taugend",
    "taugender": "taugend",
    "taugendere": "taugend",
    "taugenderem": "taugend",
    "taugenderen": "taugend",
    "taugenderer": "taugend",
    "taugenderes": "taugend",
    "taugendes": "taugend",
    "taugendste": "taugend",
    "taugendstem": "taugend",
    "taugendsten": "taugend",
    "taugendster": "taugend",
    "taugendstes": "taugend",
    "taugest": "taugen",
    "tauget": "taugen",
    "taugliche": "tauglich",
    "tauglichem": "tauglich",
    "tauglichen": "tauglich",
    "tauglicher": "tauglich",
    "tauglichere": "tauglich",
    "tauglicherem": "tauglich",
    "tauglicheren": "tauglich",
    "tauglicherer": "tauglich",
    "tauglicheres": "tauglich",
    "taugliches": "tauglich",
    "tauglichstem": "tauglich",
    "tauglichsten": "tauglich",
    "tauglichster": "tauglich",
    "tauglichstes": "tauglich",
    "taugst": "taugen",
    "taugt": "taugen",
    "taugte": "taugen",
    "taugten": "taugen",
    "taugtest": "taugen",
    "taugtet": "taugen",
    "taumele": "taumeln",
    "taumelige": "taumelig",
    "taumeligem": "taumelig",
    "taumeligen": "taumelig",
    "taumeliger": "taumelig",
    "taumeligere": "taumelig",
    "taumeligerem": "taumelig",
    "taumeligeren": "taumelig",
    "taumeligerer": "taumelig",
    "taumeligeres": "taumelig",
    "taumeliges": "taumelig",
    "taumeligste": "taumelig",
    "taumeligstem": "taumelig",
    "taumeligsten": "taumelig",
    "taumeligster": "taumelig",
    "taumeligstes": "taumelig",
    "taumelnd": "taumeln",
    "taumelnde": "taumelnd",
    "taumelndem": "taumelnd",
    "taumelnden": "taumelnd",
    "taumelnder": "taumelnd",
    "taumelndere": "taumelnd",
    "taumelnderem": "taumelnd",
    "taumelnderen": "taumelnd",
    "taumelnderer": "taumelnd",
    "taumelnderes": "taumelnd",
    "taumelndes": "taumelnd",
    "taumelndste": "taumelnd",
    "taumelndstem": "taumelnd",
    "taumelndsten": "taumelnd",
    "taumelndster": "taumelnd",
    "taumelndstes": "taumelnd",
    "taumelst": "taumeln",
    "taumelt": "taumeln",
    "taumelte": "taumeln",
    "taumelten": "taumeln",
    "taumeltest": "taumeln",
    "taumeltet": "taumeln",
    "taumle": "taumeln",
    "tauschend": "tauschen",
    "tauschende": "tauschend",
    "tauschendem": "tauschend",
    "tauschenden": "tauschend",
    "tauschender": "tauschend",
    "tauschendes": "tauschend",
    "tauschest": "tauschen",
    "tauschet": "tauschen",
    "tauschst": "tauschen",
    "tauscht": "tauschen",
    "tauschte": "tauschen",
    "tauschten": "tauschen",
    "tauschtest": "tauschen",
    "tauschtet": "tauschen",
    "tausendfachem": "tausendfach",
    "tausendfachen": "tausendfach",
    "tausendfacher": "tausendfach",
    "tausendfaches": "tausendfach",
    "tausendjährigem": "tausendjährig",
    "tausendjährigen": "tausendjährig",
    "tausendjähriger": "tausendjährig",
    "tausendjähriges": "tausendjährig",
    "taust": "tauen",
    "taut": "tauen",
    "taute": "tauen",
    "tauten": "tauen",
    "tautest": "tauen",
    "tautet": "tauen",
    "tautologischem": "tautologisch",
    "tautologischen": "tautologisch",
    "tautologischer": "tautologisch",
    "tautologisches": "tautologisch",
    "taxiere": "taxieren",
    "taxierend": "taxieren",
    "taxierende": "taxierend",
    "taxierendem": "taxierend",
    "taxierenden": "taxierend",
    "taxierender": "taxierend",
    "taxierendes": "taxierend",
    "taxierest": "taxieren",
    "taxieret": "taxieren",
    "taxierst": "taxieren",
    "taxiert": "taxieren",
    "taxierte": "taxieren",
    "taxiertem": "taxiert",
    "taxierten": "taxieren",
    "taxierter": "taxiert",
    "taxiertes": "taxiert",
    "taxiertest": "taxieren",
    "taxiertet": "taxieren",
    "taxonomischem": "taxonomisch",
    "taxonomischen": "taxonomisch",
    "taxonomischer": "taxonomisch",
    "taxonomisches": "taxonomisch",
    "technischem": "technisch",
    "technischen": "technisch",
    "technischer": "technisch",
    "technischere": "technisch",
    "technischerem": "technisch",
    "technischeren": "technisch",
    "technischerer": "technisch",
    "technischeres": "technisch",
    "technisches": "technisch",
    "technischste": "technisch",
    "technischstem": "technisch",
    "technischsten": "technisch",
    "technischster": "technisch",
    "technischstes": "technisch",
    "technisiere": "technisieren",
    "technisierend": "technisieren",
    "technisierende": "technisierend",
    "technisierendem": "technisierend",
    "technisierenden": "technisierend",
    "technisierender": "technisierend",
    "technisierendere": "technisierend",
    "technisierenderem": "technisierend",
    "technisierenderen": "technisierend",
    "technisierenderer": "technisierend",
    "technisierenderes": "technisierend",
    "technisierendes": "technisierend",
    "technisierendste": "technisierend",
    "technisierendstem": "technisierend",
    "technisierendsten": "technisierend",
    "technisierendster": "technisierend",
    "technisierendstes": "technisierend",
    "technisierest": "technisieren",
    "technisieret": "technisieren",
    "technisierst": "technisieren",
    "technisiert": "technisieren",
    "technisierte": "technisieren",
    "technisiertem": "technisiert",
    "technisierten": "technisieren",
    "technisierter": "technisiert",
    "technisiertere": "technisiert",
    "technisierterem": "technisiert",
    "technisierteren": "technisiert",
    "technisierterer": "technisiert",
    "technisierteres": "technisiert",
    "technisiertes": "technisiert",
    "technisiertest": "technisieren",
    "technisierteste": "technisiert",
    "technisiertestem": "technisiert",
    "technisiertesten": "technisiert",
    "technisiertester": "technisiert",
    "technisiertestes": "technisiert",
    "technisiertet": "technisieren",
    "technokratischem": "technokratisch",
    "technokratischen": "technokratisch",
    "technokratischer": "technokratisch",
    "technokratisches": "technokratisch",
    "technologischem": "technologisch",
    "technologischen": "technologisch",
    "technologischer": "technologisch",
    "technologisches": "technologisch",
    "teerend": "teeren",
    "teerende": "teerend",
    "teerendem": "teerend",
    "teerenden": "teerend",
    "teerender": "teerend",
    "teerendere": "teerend",
    "teerenderem": "teerend",
    "teerenderen": "teerend",
    "teerenderer": "teerend",
    "teerenderes": "teerend",
    "teerendes": "teerend",
    "teerendste": "teerend",
    "teerendstem": "teerend",
    "teerendsten": "teerend",
    "teerendster": "teerend",
    "teerendstes": "teerend",
    "teerest": "teeren",
    "teeret": "teeren",
    "teerst": "teeren",
    "teert": "teeren",
    "teerte": "teeren",
    "teerten": "teeren",
    "teertest": "teeren",
    "teertet": "teeren",
    "teilbarem": "teilbar",
    "teilbaren": "teilbar",
    "teilbarer": "teilbar",
    "teilbares": "teilbar",
    "teilend": "teilen",
    "teilende": "teilend",
    "teilendem": "teilend",
    "teilenden": "teilend",
    "teilender": "teilend",
    "teilendes": "teilend",
    "teilerfremdem": "teilerfremd",
    "teilerfremden": "teilerfremd",
    "teilerfremder": "teilerfremd",
    "teilerfremdes": "teilerfremd",
    "teilest": "teilen",
    "teilet": "teilen",
    "teilgenommen": "teilnehmen",
    "teilgenommene": "teilgenommen",
    "teilgenommenem": "teilgenommen",
    "teilgenommenen": "teilgenommen",
    "teilgenommener": "teilgenommen",
    "teilgenommenes": "teilgenommen",
    "teilhaftige": "teilhaftig",
    "teilhaftigem": "teilhaftig",
    "teilhaftigen": "teilhaftig",
    "teilhaftiger": "teilhaftig",
    "teilhaftiges": "teilhaftig",
    "teilnahm": "teilnehmen",
    "teilnahmslose": "teilnahmslos",
    "teilnahmslosem": "teilnahmslos",
    "teilnahmslosen": "teilnahmslos",
    "teilnahmsloser": "teilnahmslos",
    "teilnahmsloses": "teilnahmslos",
    "teilnahmst": "teilnehmen",
    "teilnahmt": "teilnehmen",
    "teilnehme": "teilnehmen",
    "teilnehmend": "teilnehmen",
    "teilnehmende": "teilnehmend",
    "teilnehmendem": "teilnehmend",
    "teilnehmenden": "teilnehmend",
    "teilnehmender": "teilnehmend",
    "teilnehmendere": "teilnehmend",
    "teilnehmenderem": "teilnehmend",
    "teilnehmenderen": "teilnehmend",
    "teilnehmenderer": "teilnehmend",
    "teilnehmenderes": "teilnehmend",
    "teilnehmendes": "teilnehmend",
    "teilnehmendste": "teilnehmend",
    "teilnehmendstem": "teilnehmend",
    "teilnehmendsten": "teilnehmend",
    "teilnehmendster": "teilnehmend",
    "teilnehmendstes": "teilnehmend",
    "teilnehmest": "teilnehmen",
    "teilnehmet": "teilnehmen",
    "teilnehmt": "teilnehmen",
    "teilnimmst": "teilnehmen",
    "teilnimmt": "teilnehmen",
    "teilnähme": "teilnehmen",
    "teilnähmen": "teilnehmen",
    "teilnähmest": "teilnehmen",
    "teilnähmet": "teilnehmen",
    "teilst": "teilen",
    "teilt": "teilen",
    "teilte": "teilen",
    "teilten": "teilen",
    "teiltest": "teilen",
    "teiltet": "teilen",
    "teilweisem": "teilweis",
    "teilweisen": "teilweis",
    "teilweiser": "teilweis",
    "teilweises": "teilweis",
    "teilzunehmen": "teilnehmen",
    "telefoniere": "telefonieren",
    "telefonierend": "telefonieren",
    "telefonierende": "telefonierend",
    "telefonierendem": "telefonierend",
    "telefonierenden": "telefonierend",
    "telefonierender": "telefonierend",
    "telefonierendes": "telefonierend",
    "telefonierest": "telefonieren",
    "telefonieret": "telefonieren",
    "telefonierst": "telefonieren",
    "telefoniert": "telefonieren",
    "telefonierte": "telefonieren",
    "telefoniertem": "telefoniert",
    "telefonierten": "telefonieren",
    "telefonierter": "telefoniert",
    "telefoniertes": "telefoniert",
    "telefoniertest": "telefonieren",
    "telefoniertet": "telefonieren",
    "telefonische": "telefonisch",
    "telefonischem": "telefonisch",
    "telefonischen": "telefonisch",
    "telefonischer": "telefonisch",
    "telefonisches": "telefonisch",
    "telegenem": "telegen",
    "telegenen": "telegen",
    "telegener": "telegen",
    "telegenere": "telegen",
    "telegenerem": "telegen",
    "telegeneren": "telegen",
    "telegenerer": "telegen",
    "telegeneres": "telegen",
    "telegenes": "telegen",
    "telegenste": "telegen",
    "telegenstem": "telegen",
    "telegensten": "telegen",
    "telegenster": "telegen",
    "telegenstes": "telegen",
    "temperamentlosem": "temperamentlos",
    "temperamentlosen": "temperamentlos",
    "temperamentloser": "temperamentlos",
    "temperamentlosere": "temperamentlos",
    "temperamentloserem": "temperamentlos",
    "temperamentloseren": "temperamentlos",
    "temperamentloserer": "temperamentlos",
    "temperamentloseres": "temperamentlos",
    "temperamentloses": "temperamentlos",
    "temperamentloseste": "temperamentlos",
    "temperamentlosestem": "temperamentlos",
    "temperamentlosesten": "temperamentlos",
    "temperamentlosester": "temperamentlos",
    "temperamentlosestes": "temperamentlos",
    "temperamentvollem": "temperamentvoll",
    "temperamentvollen": "temperamentvoll",
    "temperamentvoller": "temperamentvoll",
    "temperamentvollere": "temperamentvoll",
    "temperamentvollerem": "temperamentvoll",
    "temperamentvolleren": "temperamentvoll",
    "temperamentvollerer": "temperamentvoll",
    "temperamentvolleres": "temperamentvoll",
    "temperamentvolles": "temperamentvoll",
    "temperamentvollste": "temperamentvoll",
    "temperamentvollstem": "temperamentvoll",
    "temperamentvollsten": "temperamentvoll",
    "temperamentvollster": "temperamentvoll",
    "temperamentvollstes": "temperamentvoll",
    "temperaturbeständige": "temperaturbeständig",
    "temperaturbeständigem": "temperaturbeständig",
    "temperaturbeständigen": "temperaturbeständig",
    "temperaturbeständiger": "temperaturbeständig",
    "temperaturbeständigere": "temperaturbeständig",
    "temperaturbeständigerem": "temperaturbeständig",
    "temperaturbeständigeren": "temperaturbeständig",
    "temperaturbeständigerer": "temperaturbeständig",
    "temperaturbeständigeres": "temperaturbeständig",
    "temperaturbeständiges": "temperaturbeständig",
    "temperaturbeständigste": "temperaturbeständig",
    "temperaturbeständigstem": "temperaturbeständig",
    "temperaturbeständigsten": "temperaturbeständig",
    "temperaturbeständigster": "temperaturbeständig",
    "temperaturbeständigstes": "temperaturbeständig",
    "temperiere": "temperieren",
    "temperierend": "temperieren",
    "temperierende": "temperierend",
    "temperierendem": "temperierend",
    "temperierenden": "temperierend",
    "temperierender": "temperierend",
    "temperierendere": "temperierend",
    "temperierenderem": "temperierend",
    "temperierenderen": "temperierend",
    "temperierenderer": "temperierend",
    "temperierenderes": "temperierend",
    "temperierendes": "temperierend",
    "temperierendste": "temperierend",
    "temperierendstem": "temperierend",
    "temperierendsten": "temperierend",
    "temperierendster": "temperierend",
    "temperierendstes": "temperierend",
    "temperierest": "temperieren",
    "temperieret": "temperieren",
    "temperierst": "temperieren",
    "temperiert": "temperieren",
    "temperierte": "temperieren",
    "temperiertem": "temperiert",
    "temperierten": "temperieren",
    "temperierter": "temperiert",
    "temperiertere": "temperiert",
    "temperierterem": "temperiert",
    "temperierteren": "temperiert",
    "temperierterer": "temperiert",
    "temperierteres": "temperiert",
    "temperiertes": "temperiert",
    "temperiertest": "temperieren",
    "temperierteste": "temperiert",
    "temperiertestem": "temperiert",
    "temperiertesten": "temperiert",
    "temperiertester": "temperiert",
    "temperiertestes": "temperiert",
    "temperiertet": "temperieren",
    "temporalem": "temporal",
    "temporalen": "temporal",
    "temporaler": "temporal",
    "temporales": "temporal",
    "temporäre": "temporär",
    "temporärem": "temporär",
    "temporären": "temporär",
    "temporärer": "temporär",
    "temporäres": "temporär",
    "tendenziellem": "tendenziell",
    "tendenziellen": "tendenziell",
    "tendenzieller": "tendenziell",
    "tendenzielles": "tendenziell",
    "tendenziöse": "tendenziös",
    "tendenziösem": "tendenziös",
    "tendenziösen": "tendenziös",
    "tendenziöser": "tendenziös",
    "tendenziöses": "tendenziös",
    "tendiere": "tendieren",
    "tendierend": "tendieren",
    "tendierende": "tendierend",
    "tendierendem": "tendierend",
    "tendierenden": "tendierend",
    "tendierender": "tendierend",
    "tendierendes": "tendierend",
    "tendierest": "tendieren",
    "tendieret": "tendieren",
    "tendierst": "tendieren",
    "tendiert": "tendieren",
    "tendierte": "tendieren",
    "tendiertem": "tendiert",
    "tendierten": "tendieren",
    "tendierter": "tendiert",
    "tendiertes": "tendiert",
    "tendiertest": "tendieren",
    "tendiertet": "tendieren",
    "tenorale": "tenoral",
    "tenoralem": "tenoral",
    "tenoralen": "tenoral",
    "tenoraler": "tenoral",
    "tenorales": "tenoral",
    "terminalem": "terminal",
    "terminalen": "terminal",
    "terminaler": "terminal",
    "terminales": "terminal",
    "termingemäßem": "termingemäß",
    "termingemäßen": "termingemäß",
    "termingemäßer": "termingemäß",
    "termingemäßes": "termingemäß",
    "terminiere": "terminieren",
    "terminierend": "terminieren",
    "terminierende": "terminierend",
    "terminierendem": "terminierend",
    "terminierenden": "terminierend",
    "terminierender": "terminierend",
    "terminierendes": "terminierend",
    "terminierest": "terminieren",
    "terminieret": "terminieren",
    "terminierst": "terminieren",
    "terminiert": "terminieren",
    "terminierte": "terminieren",
    "terminiertem": "terminiert",
    "terminierten": "terminieren",
    "terminierter": "terminiert",
    "terminiertes": "terminiert",
    "terminiertest": "terminieren",
    "terminiertet": "terminieren",
    "terminologischem": "terminologisch",
    "terminologischen": "terminologisch",
    "terminologischer": "terminologisch",
    "terminologisches": "terminologisch",
    "territorialem": "territorial",
    "territorialen": "territorial",
    "territorialer": "territorial",
    "territoriales": "territorial",
    "terrorisierend": "terrorisieren",
    "terrorisierende": "terrorisierend",
    "terrorisierendem": "terrorisierend",
    "terrorisierenden": "terrorisierend",
    "terrorisierender": "terrorisierend",
    "terrorisierendere": "terrorisierend",
    "terrorisierenderem": "terrorisierend",
    "terrorisierenderen": "terrorisierend",
    "terrorisierenderer": "terrorisierend",
    "terrorisierenderes": "terrorisierend",
    "terrorisierendes": "terrorisierend",
    "terrorisierendste": "terrorisierend",
    "terrorisierendstem": "terrorisierend",
    "terrorisierendsten": "terrorisierend",
    "terrorisierendster": "terrorisierend",
    "terrorisierendstes": "terrorisierend",
    "terrorisierest": "terrorisieren",
    "terrorisieret": "terrorisieren",
    "terrorisierst": "terrorisieren",
    "terrorisiert": "terrorisieren",
    "terrorisierte": "terrorisieren",
    "terrorisiertem": "terrorisiert",
    "terrorisierten": "terrorisieren",
    "terrorisierter": "terrorisiert",
    "terrorisiertere": "terrorisiert",
    "terrorisierterem": "terrorisiert",
    "terrorisierteren": "terrorisiert",
    "terrorisierterer": "terrorisiert",
    "terrorisierteres": "terrorisiert",
    "terrorisiertes": "terrorisiert",
    "terrorisiertest": "terrorisieren",
    "terrorisierteste": "terrorisiert",
    "terrorisiertestem": "terrorisiert",
    "terrorisiertesten": "terrorisiert",
    "terrorisiertester": "terrorisiert",
    "terrorisiertestes": "terrorisiert",
    "terrorisiertet": "terrorisieren",
    "terroristischem": "terroristisch",
    "terroristischen": "terroristisch",
    "terroristischer": "terroristisch",
    "terroristisches": "terroristisch",
    "tertiärem": "tertiär",
    "tertiären": "tertiär",
    "tertiärer": "tertiär",
    "tertiäres": "tertiär",
    "testamentarischem": "testamentarisch",
    "testamentarischen": "testamentarisch",
    "testamentarischer": "testamentarisch",
    "testamentarisches": "testamentarisch",
    "teste": "testen",
    "testend": "testen",
    "testende": "testend",
    "testendem": "testend",
    "testenden": "testend",
    "testender": "testend",
    "testendes": "testend",
    "testest": "testen",
    "testet": "testen",
    "testete": "testen",
    "testeten": "testen",
    "testetest": "testen",
    "testetet": "testen",
    "testiere": "testieren",
    "testierend": "testieren",
    "testierende": "testierend",
    "testierendem": "testierend",
    "testierenden": "testierend",
    "testierender": "testierend",
    "testierendes": "testierend",
    "testierest": "testieren",
    "testieret": "testieren",
    "testierst": "testieren",
    "testiert": "testieren",
    "testierte": "testieren",
    "testiertem": "testiert",
    "testierten": "testieren",
    "testierter": "testiert",
    "testiertes": "testiert",
    "testiertest": "testieren",
    "testiertet": "testieren",
    "teuerstem": "teuer",
    "teuersten": "teuer",
    "teuerster": "teuer",
    "teuerstes": "teuer",
    "teuflischem": "teuflisch",
    "teuflischen": "teuflisch",
    "teuflischer": "teuflisch",
    "teuflischere": "teuflisch",
    "teuflischerem": "teuflisch",
    "teuflischeren": "teuflisch",
    "teuflischerer": "teuflisch",
    "teuflischeres": "teuflisch",
    "teuflisches": "teuflisch",
    "teuflischste": "teuflisch",
    "teuflischstem": "teuflisch",
    "teuflischsten": "teuflisch",
    "teuflischster": "teuflisch",
    "teuflischstes": "teuflisch",
    "teure": "teuer",
    "teurem": "teuer",
    "teuren": "teuer",
    "teurer": "teuer",
    "teurere": "teuer",
    "teurerem": "teuer",
    "teureren": "teuer",
    "teurerer": "teuer",
    "teureres": "teuer",
    "teures": "teuer",
    "teutonische": "teutonisch",
    "teutonischem": "teutonisch",
    "teutonischen": "teutonisch",
    "teutonischer": "teutonisch",
    "teutonisches": "teutonisch",
    "textend": "texten",
    "textende": "textend",
    "textendem": "textend",
    "textenden": "textend",
    "textender": "textend",
    "textendes": "textend",
    "textest": "texten",
    "textet": "texten",
    "textete": "texten",
    "texteten": "texten",
    "textetest": "texten",
    "textetet": "texten",
    "thematischem": "thematisch",
    "thematischen": "thematisch",
    "thematischer": "thematisch",
    "thematisches": "thematisch",
    "thematisiere": "thematisieren",
    "thematisierend": "thematisieren",
    "thematisierende": "thematisierend",
    "thematisierendem": "thematisierend",
    "thematisierenden": "thematisierend",
    "thematisierender": "thematisierend",
    "thematisierendes": "thematisierend",
    "thematisierest": "thematisieren",
    "thematisieret": "thematisieren",
    "thematisierst": "thematisieren",
    "thematisiert": "thematisieren",
    "thematisierte": "thematisieren",
    "thematisiertem": "thematisiert",
    "thematisierten": "thematisieren",
    "thematisierter": "thematisiert",
    "thematisiertes": "thematisiert",
    "thematisiertest": "thematisieren",
    "thematisiertet": "thematisieren",
    "theologischem": "theologisch",
    "theologischen": "theologisch",
    "theologischer": "theologisch",
    "theologisches": "theologisch",
    "theoretischem": "theoretisch",
    "theoretischen": "theoretisch",
    "theoretischer": "theoretisch",
    "theoretischere": "theoretisch",
    "theoretischerem": "theoretisch",
    "theoretischeren": "theoretisch",
    "theoretischerer": "theoretisch",
    "theoretischeres": "theoretisch",
    "theoretisches": "theoretisch",
    "theoretischste": "theoretisch",
    "theoretischstem": "theoretisch",
    "theoretischsten": "theoretisch",
    "theoretischster": "theoretisch",
    "theoretischstes": "theoretisch",
    "theoretisiere": "theoretisieren",
    "theoretisierend": "theoretisieren",
    "theoretisierende": "theoretisierend",
    "theoretisierendem": "theoretisierend",
    "theoretisierenden": "theoretisierend",
    "theoretisierender": "theoretisierend",
    "theoretisierendes": "theoretisierend",
    "theoretisierest": "theoretisieren",
    "theoretisieret": "theoretisieren",
    "theoretisierst": "theoretisieren",
    "theoretisiert": "theoretisieren",
    "theoretisierte": "theoretisieren",
    "theoretisiertem": "theoretisiert",
    "theoretisierten": "theoretisieren",
    "theoretisierter": "theoretisiert",
    "theoretisiertes": "theoretisiert",
    "theoretisiertest": "theoretisieren",
    "theoretisiertet": "theoretisieren",
    "therapeutischem": "therapeutisch",
    "therapeutischen": "therapeutisch",
    "therapeutischer": "therapeutisch",
    "therapeutisches": "therapeutisch",
    "therapiere": "therapieren",
    "therapierend": "therapieren",
    "therapierende": "therapierend",
    "therapierendem": "therapierend",
    "therapierenden": "therapierend",
    "therapierender": "therapierend",
    "therapierendere": "therapierend",
    "therapierenderem": "therapierend",
    "therapierenderen": "therapierend",
    "therapierenderer": "therapierend",
    "therapierenderes": "therapierend",
    "therapierendes": "therapierend",
    "therapierendste": "therapierend",
    "therapierendstem": "therapierend",
    "therapierendsten": "therapierend",
    "therapierendster": "therapierend",
    "therapierendstes": "therapierend",
    "therapierest": "therapieren",
    "therapieret": "therapieren",
    "therapierst": "therapieren",
    "therapiert": "therapieren",
    "therapierte": "therapieren",
    "therapiertem": "therapiert",
    "therapierten": "therapieren",
    "therapierter": "therapiert",
    "therapiertere": "therapiert",
    "therapierterem": "therapiert",
    "therapierteren": "therapiert",
    "therapierterer": "therapiert",
    "therapierteres": "therapiert",
    "therapiertes": "therapiert",
    "therapiertest": "therapieren",
    "therapierteste": "therapiert",
    "therapiertestem": "therapiert",
    "therapiertesten": "therapiert",
    "therapiertester": "therapiert",
    "therapiertestes": "therapiert",
    "therapiertet": "therapieren",
    "thermalem": "thermal",
    "thermalen": "thermal",
    "thermaler": "thermal",
    "thermales": "thermal",
    "thermischem": "thermisch",
    "thermischen": "thermisch",
    "thermischer": "thermisch",
    "thermisches": "thermisch",
    "thermodynamische": "thermodynamisch",
    "thermodynamischem": "thermodynamisch",
    "thermodynamischen": "thermodynamisch",
    "thermodynamischer": "thermodynamisch",
    "thermodynamisches": "thermodynamisch",
    "thesauriere": "thesaurieren",
    "thesaurierend": "thesaurieren",
    "thesaurierende": "thesaurierend",
    "thesaurierendem": "thesaurierend",
    "thesaurierenden": "thesaurierend",
    "thesaurierender": "thesaurierend",
    "thesaurierendes": "thesaurierend",
    "thesaurierest": "thesaurieren",
    "thesaurieret": "thesaurieren",
    "thesaurierst": "thesaurieren",
    "thesauriert": "thesaurieren",
    "thesaurierte": "thesaurieren",
    "thesauriertem": "thesauriert",
    "thesaurierten": "thesaurieren",
    "thesaurierter": "thesauriert",
    "thesauriertes": "thesauriert",
    "thesauriertest": "thesaurieren",
    "thesauriertet": "thesaurieren",
    "thrombotischem": "thrombotisch",
    "thrombotischen": "thrombotisch",
    "thrombotischer": "thrombotisch",
    "thrombotisches": "thrombotisch",
    "throne": "thronen",
    "thronend": "thronen",
    "thronende": "thronend",
    "thronendem": "thronend",
    "thronenden": "thronend",
    "thronender": "thronend",
    "thronendes": "thronend",
    "thronest": "thronen",
    "thronet": "thronen",
    "thronst": "thronen",
    "thront": "thronen",
    "thronte": "thronen",
    "thronten": "thronen",
    "throntest": "thronen",
    "throntet": "thronen",
    "thüringischem": "thüringisch",
    "thüringischen": "thüringisch",
    "thüringischer": "thüringisch",
    "thüringisches": "thüringisch",
    "tibetanischem": "tibetanisch",
    "tibetanischen": "tibetanisch",
    "tibetanischer": "tibetanisch",
    "tibetanisches": "tibetanisch",
    "tiefbetrübtem": "tiefbetrübt",
    "tiefbetrübten": "tiefbetrübt",
    "tiefbetrübter": "tiefbetrübt",
    "tiefbetrübtes": "tiefbetrübt",
    "tiefbewegte": "tiefbewegt",
    "tiefbewegtem": "tiefbewegt",
    "tiefbewegten": "tiefbewegt",
    "tiefbewegter": "tiefbewegt",
    "tiefbewegtes": "tiefbewegt",
    "tiefem": "tief",
    "tiefen": "tief",
    "tiefer": "tief",
    "tiefere": "tief",
    "tieferem": "tief",
    "tieferen": "tief",
    "tieferer": "tief",
    "tieferes": "tief",
    "tiefes": "tief",
    "tiefgefrorenem": "tiefgefroren",
    "tiefgefrorenen": "tiefgefroren",
    "tiefgefrorener": "tiefgefroren",
    "tiefgefrorenes": "tiefgefroren",
    "tiefgehende": "tiefgehend",
    "tiefgehendem": "tiefgehend",
    "tiefgehenden": "tiefgehend",
    "tiefgehender": "tiefgehend",
    "tiefgehendere": "tiefgehend",
    "tiefgehenderem": "tiefgehend",
    "tiefgehenderen": "tiefgehend",
    "tiefgehenderer": "tiefgehend",
    "tiefgehenderes": "tiefgehend",
    "tiefgehendes": "tiefgehend",
    "tiefgehendste": "tiefgehend",
    "tiefgehendstem": "tiefgehend",
    "tiefgehendsten": "tiefgehend",
    "tiefgehendster": "tiefgehend",
    "tiefgehendstes": "tiefgehend",
    "tiefgekühlte": "tiefgekühlt",
    "tiefgekühltem": "tiefgekühlt",
    "tiefgekühlten": "tiefgekühlt",
    "tiefgekühlter": "tiefgekühlt",
    "tiefgekühltes": "tiefgekühlt",
    "tiefgreifende": "tiefgreifend",
    "tiefgreifendem": "tiefgreifend",
    "tiefgreifenden": "tiefgreifend",
    "tiefgreifender": "tiefgreifend",
    "tiefgreifendere": "tiefgreifend",
    "tiefgreifenderem": "tiefgreifend",
    "tiefgreifenderen": "tiefgreifend",
    "tiefgreifenderer": "tiefgreifend",
    "tiefgreifenderes": "tiefgreifend",
    "tiefgreifendes": "tiefgreifend",
    "tiefgreifendste": "tiefgreifend",
    "tiefgreifendstem": "tiefgreifend",
    "tiefgreifendsten": "tiefgreifend",
    "tiefgreifendster": "tiefgreifend",
    "tiefgreifendstes": "tiefgreifend",
    "tiefgründige": "tiefgründig",
    "tiefgründigem": "tiefgründig",
    "tiefgründigen": "tiefgründig",
    "tiefgründiger": "tiefgründig",
    "tiefgründigere": "tiefgründig",
    "tiefgründigerem": "tiefgründig",
    "tiefgründigeren": "tiefgründig",
    "tiefgründigerer": "tiefgründig",
    "tiefgründigeres": "tiefgründig",
    "tiefgründiges": "tiefgründig",
    "tiefgründigste": "tiefgründig",
    "tiefgründigstem": "tiefgründig",
    "tiefgründigsten": "tiefgründig",
    "tiefgründigster": "tiefgründig",
    "tiefgründigstes": "tiefgründig",
    "tiefschwarze": "tiefschwarz",
    "tiefschwarzem": "tiefschwarz",
    "tiefschwarzen": "tiefschwarz",
    "tiefschwarzer": "tiefschwarz",
    "tiefschwarzes": "tiefschwarz",
    "tiefschürfendem": "tiefschürfend",
    "tiefschürfenden": "tiefschürfend",
    "tiefschürfender": "tiefschürfend",
    "tiefschürfendes": "tiefschürfend",
    "tiefsinnige": "tiefsinnig",
    "tiefsinnigem": "tiefsinnig",
    "tiefsinnigen": "tiefsinnig",
    "tiefsinniger": "tiefsinnig",
    "tiefsinnigere": "tiefsinnig",
    "tiefsinnigerem": "tiefsinnig",
    "tiefsinnigeren": "tiefsinnig",
    "tiefsinnigerer": "tiefsinnig",
    "tiefsinnigeres": "tiefsinnig",
    "tiefsinniges": "tiefsinnig",
    "tiefsinnigste": "tiefsinnig",
    "tiefsinnigstem": "tiefsinnig",
    "tiefsinnigsten": "tiefsinnig",
    "tiefsinnigster": "tiefsinnig",
    "tiefsinnigstes": "tiefsinnig",
    "tiefstem": "tief",
    "tiefsten": "tief",
    "tiefster": "tief",
    "tiefstes": "tief",
    "tieftraurigem": "tieftraurig",
    "tieftraurigen": "tieftraurig",
    "tieftrauriger": "tieftraurig",
    "tieftrauriges": "tieftraurig",
    "tierischem": "tierisch",
    "tierischen": "tierisch",
    "tierischer": "tierisch",
    "tierischere": "tierisch",
    "tierischerem": "tierisch",
    "tierischeren": "tierisch",
    "tierischerer": "tierisch",
    "tierischeres": "tierisch",
    "tierisches": "tierisch",
    "tierischste": "tierisch",
    "tierischstem": "tierisch",
    "tierischsten": "tierisch",
    "tierischster": "tierisch",
    "tierischstes": "tierisch",
    "tierliebende": "tierliebend",
    "tierliebendem": "tierliebend",
    "tierliebenden": "tierliebend",
    "tierliebender": "tierliebend",
    "tierliebendere": "tierliebend",
    "tierliebenderem": "tierliebend",
    "tierliebenderen": "tierliebend",
    "tierliebenderer": "tierliebend",
    "tierliebenderes": "tierliebend",
    "tierliebendes": "tierliebend",
    "tierliebendste": "tierliebend",
    "tierliebendstem": "tierliebend",
    "tierliebendsten": "tierliebend",
    "tierliebendster": "tierliebend",
    "tierliebendstes": "tierliebend",
    "tierärztlichem": "tierärztlich",
    "tierärztlichen": "tierärztlich",
    "tierärztlicher": "tierärztlich",
    "tierärztliches": "tierärztlich",
    "tigere": "tigern",
    "tigernd": "tigern",
    "tigernde": "tigernd",
    "tigerndem": "tigernd",
    "tigernden": "tigernd",
    "tigernder": "tigernd",
    "tigerndes": "tigernd",
    "tigerst": "tigern",
    "tigert": "tigern",
    "tigerte": "tigern",
    "tigerten": "tigern",
    "tigertest": "tigern",
    "tigertet": "tigern",
    "tilgbarem": "tilgbar",
    "tilgbaren": "tilgbar",
    "tilgbarer": "tilgbar",
    "tilgbares": "tilgbar",
    "tilge": "tilgen",
    "tilgend": "tilgen",
    "tilgende": "tilgend",
    "tilgendem": "tilgend",
    "tilgenden": "tilgend",
    "tilgender": "tilgend",
    "tilgendes": "tilgend",
    "tilgest": "tilgen",
    "tilget": "tilgen",
    "tilgst": "tilgen",
    "tilgt": "tilgen",
    "tilgte": "tilgen",
    "tilgten": "tilgen",
    "tilgtest": "tilgen",
    "tilgtet": "tilgen",
    "tingele": "tingeln",
    "tingelnd": "tingeln",
    "tingelnde": "tingelnd",
    "tingelndem": "tingelnd",
    "tingelnden": "tingelnd",
    "tingelnder": "tingelnd",
    "tingelndere": "tingelnd",
    "tingelnderem": "tingelnd",
    "tingelnderen": "tingelnd",
    "tingelnderer": "tingelnd",
    "tingelnderes": "tingelnd",
    "tingelndes": "tingelnd",
    "tingelndste": "tingelnd",
    "tingelndstem": "tingelnd",
    "tingelndsten": "tingelnd",
    "tingelndster": "tingelnd",
    "tingelndstes": "tingelnd",
    "tingelst": "tingeln",
    "tingelt": "tingeln",
    "tingelte": "tingeln",
    "tingelten": "tingeln",
    "tingeltest": "tingeln",
    "tingeltet": "tingeln",
    "tingle": "tingeln",
    "tippe": "tippen",
    "tippele": "tippeln",
    "tippelnd": "tippeln",
    "tippelnde": "tippelnd",
    "tippelndem": "tippelnd",
    "tippelnden": "tippelnd",
    "tippelnder": "tippelnd",
    "tippelndere": "tippelnd",
    "tippelnderem": "tippelnd",
    "tippelnderen": "tippelnd",
    "tippelnderer": "tippelnd",
    "tippelnderes": "tippelnd",
    "tippelndes": "tippelnd",
    "tippelndste": "tippelnd",
    "tippelndstem": "tippelnd",
    "tippelndsten": "tippelnd",
    "tippelndster": "tippelnd",
    "tippelndstes": "tippelnd",
    "tippelst": "tippeln",
    "tippelt": "tippeln",
    "tippelte": "tippeln",
    "tippelten": "tippeln",
    "tippeltest": "tippeln",
    "tippeltet": "tippeln",
    "tippend": "tippen",
    "tippende": "tippend",
    "tippendem": "tippend",
    "tippenden": "tippend",
    "tippender": "tippend",
    "tippendere": "tippend",
    "tippenderem": "tippend",
    "tippenderen": "tippend",
    "tippenderer": "tippend",
    "tippenderes": "tippend",
    "tippendes": "tippend",
    "tippendste": "tippend",
    "tippendstem": "tippend",
    "tippendsten": "tippend",
    "tippendster": "tippend",
    "tippendstes": "tippend",
    "tippest": "tippen",
    "tippet": "tippen",
    "tipple": "tippeln",
    "tippst": "tippen",
    "tippt": "tippen",
    "tippte": "tippen",
    "tippten": "tippen",
    "tipptest": "tippen",
    "tipptet": "tippen",
    "tischend": "tischen",
    "tischende": "tischend",
    "tischendem": "tischend",
    "tischenden": "tischend",
    "tischender": "tischend",
    "tischendes": "tischend",
    "tischest": "tischen",
    "tischet": "tischen",
    "tischfertige": "tischfertig",
    "tischfertigem": "tischfertig",
    "tischfertigen": "tischfertig",
    "tischfertiger": "tischfertig",
    "tischfertiges": "tischfertig",
    "tischlere": "tischlern",
    "tischlernd": "tischlern",
    "tischlernde": "tischlernd",
    "tischlerndem": "tischlernd",
    "tischlernden": "tischlernd",
    "tischlernder": "tischlernd",
    "tischlerndes": "tischlernd",
    "tischlerst": "tischlern",
    "tischlert": "tischlern",
    "tischlerte": "tischlern",
    "tischlerten": "tischlern",
    "tischlertest": "tischlern",
    "tischlertet": "tischlern",
    "tischst": "tischen",
    "tischt": "tischen",
    "tischte": "tischen",
    "tischten": "tischen",
    "tischtest": "tischen",
    "tischtet": "tischen",
    "titsche": "titschen",
    "titschend": "titschen",
    "titschende": "titschend",
    "titschendem": "titschend",
    "titschenden": "titschend",
    "titschender": "titschend",
    "titschendes": "titschend",
    "titschest": "titschen",
    "titschet": "titschen",
    "titschst": "titschen",
    "titscht": "titschen",
    "titschte": "titschen",
    "titschten": "titschen",
    "titschtest": "titschen",
    "titschtet": "titschen",
    "toaste": "toasten",
    "toastend": "toasten",
    "toastende": "toastend",
    "toastendem": "toastend",
    "toastenden": "toastend",
    "toastender": "toastend",
    "toastendes": "toastend",
    "toastest": "toasten",
    "toastet": "toasten",
    "toastete": "toasten",
    "toasteten": "toasten",
    "toastetest": "toasten",
    "toastetet": "toasten",
    "tobe": "toben",
    "tobend": "toben",
    "tobende": "tobend",
    "tobendem": "tobend",
    "tobenden": "tobend",
    "tobender": "tobend",
    "tobendere": "tobend",
    "tobenderem": "tobend",
    "tobenderen": "tobend",
    "tobenderer": "tobend",
    "tobenderes": "tobend",
    "tobendes": "tobend",
    "tobendste": "tobend",
    "tobendstem": "tobend",
    "tobendsten": "tobend",
    "tobendster": "tobend",
    "tobendstes": "tobend",
    "tobest": "toben",
    "tobet": "toben",
    "tobst": "toben",
    "tobsüchtige": "tobsüchtig",
    "tobsüchtigem": "tobsüchtig",
    "tobsüchtigen": "tobsüchtig",
    "tobsüchtiger": "tobsüchtig",
    "tobsüchtiges": "tobsüchtig",
    "tobt": "toben",
    "tobte": "toben",
    "tobten": "toben",
    "tobtest": "toben",
    "tobtet": "toben",
    "todesmutigem": "todesmutig",
    "todesmutigen": "todesmutig",
    "todesmutiger": "todesmutig",
    "todesmutigere": "todesmutig",
    "todesmutigerem": "todesmutig",
    "todesmutigeren": "todesmutig",
    "todesmutigerer": "todesmutig",
    "todesmutigeres": "todesmutig",
    "todesmutiges": "todesmutig",
    "todesmutigste": "todesmutig",
    "todesmutigstem": "todesmutig",
    "todesmutigsten": "todesmutig",
    "todesmutigster": "todesmutig",
    "todesmutigstes": "todesmutig",
    "todgeweihtem": "todgeweiht",
    "todgeweihten": "todgeweiht",
    "todgeweihter": "todgeweiht",
    "todgeweihtes": "todgeweiht",
    "todkranke": "todkrank",
    "todkrankem": "todkrank",
    "todkranken": "todkrank",
    "todkranker": "todkrank",
    "todkrankes": "todkrank",
    "todmüdem": "todmüde",
    "todmüden": "todmüde",
    "todmüder": "todmüde",
    "todmüdes": "todmüde",
    "todschickem": "todschick",
    "todschicken": "todschick",
    "todschicker": "todschick",
    "todschickes": "todschick",
    "todsichere": "todsicher",
    "todsicherem": "todsicher",
    "todsicheren": "todsicher",
    "todsicherer": "todsicher",
    "todsicheres": "todsicher",
    "todunglückliche": "todunglücklich",
    "todunglücklichem": "todunglücklich",
    "todunglücklichen": "todunglücklich",
    "todunglücklicher": "todunglücklich",
    "todunglückliches": "todunglücklich",
    "tolerantem": "tolerant",
    "toleranten": "tolerant",
    "toleranter": "tolerant",
    "tolerantere": "tolerant",
    "toleranterem": "tolerant",
    "toleranteren": "tolerant",
    "toleranterer": "tolerant",
    "toleranteres": "tolerant",
    "tolerantes": "tolerant",
    "toleranteste": "tolerant",
    "tolerantestem": "tolerant",
    "tolerantesten": "tolerant",
    "tolerantester": "tolerant",
    "tolerantestes": "tolerant",
    "toleriere": "tolerieren",
    "tolerierend": "tolerieren",
    "tolerierende": "tolerierend",
    "tolerierendem": "tolerierend",
    "tolerierenden": "tolerierend",
    "tolerierender": "tolerierend",
    "tolerierendes": "tolerierend",
    "tolerierest": "tolerieren",
    "tolerieret": "tolerieren",
    "tolerierst": "tolerieren",
    "toleriert": "tolerieren",
    "tolerierte": "tolerieren",
    "toleriertem": "toleriert",
    "tolerierten": "tolerieren",
    "tolerierter": "toleriert",
    "toleriertes": "toleriert",
    "toleriertest": "tolerieren",
    "toleriertet": "tolerieren",
    "toll": "tollen",
    "tolle": "toll",
    "tollem": "toll",
    "tollen": "toll",
    "tollend": "tollen",
    "tollende": "tollend",
    "tollendem": "tollend",
    "tollenden": "tollend",
    "tollender": "tollend",
    "tollendes": "tollend",
    "toller": "toll",
    "tollere": "toll",
    "tollerem": "toll",
    "tolleren": "toll",
    "tollerer": "toll",
    "tolleres": "toll",
    "tolles": "toll",
    "tollest": "tollen",
    "tollet": "tollen",
    "tollkühne": "tollkühn",
    "tollkühnem": "tollkühn",
    "tollkühnen": "tollkühn",
    "tollkühner": "tollkühn",
    "tollkühnere": "tollkühn",
    "tollkühnerem": "tollkühn",
    "tollkühneren": "tollkühn",
    "tollkühnerer": "tollkühn",
    "tollkühneres": "tollkühn",
    "tollkühnes": "tollkühn",
    "tollkühnste": "tollkühn",
    "tollkühnstem": "tollkühn",
    "tollkühnsten": "tollkühn",
    "tollkühnster": "tollkühn",
    "tollkühnstes": "tollkühn",
    "tollpatschige": "tollpatschig",
    "tollpatschigem": "tollpatschig",
    "tollpatschigen": "tollpatschig",
    "tollpatschiger": "tollpatschig",
    "tollpatschigere": "tollpatschig",
    "tollpatschigerem": "tollpatschig",
    "tollpatschigeren": "tollpatschig",
    "tollpatschigerer": "tollpatschig",
    "tollpatschigeres": "tollpatschig",
    "tollpatschiges": "tollpatschig",
    "tollpatschigste": "tollpatschig",
    "tollpatschigstem": "tollpatschig",
    "tollpatschigsten": "tollpatschig",
    "tollpatschigster": "tollpatschig",
    "tollpatschigstes": "tollpatschig",
    "tollst": "tollen",
    "tollste": "toll",
    "tollstem": "toll",
    "tollsten": "toll",
    "tollster": "toll",
    "tollstes": "toll",
    "tollt": "tollen",
    "tollte": "tollen",
    "tollten": "tollen",
    "tolltest": "tollen",
    "tolltet": "tollen",
    "tollwütige": "tollwütig",
    "tollwütigem": "tollwütig",
    "tollwütigen": "tollwütig",
    "tollwütiger": "tollwütig",
    "tollwütigere": "tollwütig",
    "tollwütigerem": "tollwütig",
    "tollwütigeren": "tollwütig",
    "tollwütigerer": "tollwütig",
    "tollwütigeres": "tollwütig",
    "tollwütiges": "tollwütig",
    "tollwütigste": "tollwütig",
    "tollwütigstem": "tollwütig",
    "tollwütigsten": "tollwütig",
    "tollwütigster": "tollwütig",
    "tollwütigstes": "tollwütig",
    "tolpatschige": "tolpatschig",
    "tolpatschigem": "tolpatschig",
    "tolpatschigen": "tolpatschig",
    "tolpatschiger": "tolpatschig",
    "tolpatschigere": "tolpatschig",
    "tolpatschigerem": "tolpatschig",
    "tolpatschigeren": "tolpatschig",
    "tolpatschigerer": "tolpatschig",
    "tolpatschigeres": "tolpatschig",
    "tolpatschiges": "tolpatschig",
    "tolpatschigste": "tolpatschig",
    "tolpatschigstem": "tolpatschig",
    "tolpatschigsten": "tolpatschig",
    "tolpatschigster": "tolpatschig",
    "tolpatschigstes": "tolpatschig",
    "tonangebendem": "tonangebend",
    "tonangebenden": "tonangebend",
    "tonangebender": "tonangebend",
    "tonangebendes": "tonangebend",
    "topfend": "topfen",
    "topfende": "topfend",
    "topfendem": "topfend",
    "topfenden": "topfend",
    "topfender": "topfend",
    "topfendes": "topfend",
    "topfest": "topfen",
    "topfet": "topfen",
    "topfst": "topfen",
    "topft": "topfen",
    "topfte": "topfen",
    "topften": "topfen",
    "topftest": "topfen",
    "topftet": "topfen",
    "toppe": "toppen",
    "toppend": "toppen",
    "toppende": "toppend",
    "toppendem": "toppend",
    "toppenden": "toppend",
    "toppender": "toppend",
    "toppendere": "toppend",
    "toppenderem": "toppend",
    "toppenderen": "toppend",
    "toppenderer": "toppend",
    "toppenderes": "toppend",
    "toppendes": "toppend",
    "toppendste": "toppend",
    "toppendstem": "toppend",
    "toppendsten": "toppend",
    "toppendster": "toppend",
    "toppendstes": "toppend",
    "toppest": "toppen",
    "toppet": "toppen",
    "toppst": "toppen",
    "toppt": "toppen",
    "toppte": "toppen",
    "toppten": "toppen",
    "topptest": "toppen",
    "topptet": "toppen",
    "torkele": "torkeln",
    "torkelnd": "torkeln",
    "torkelnde": "torkelnd",
    "torkelndem": "torkelnd",
    "torkelnden": "torkelnd",
    "torkelnder": "torkelnd",
    "torkelndere": "torkelnd",
    "torkelnderem": "torkelnd",
    "torkelnderen": "torkelnd",
    "torkelnderer": "torkelnd",
    "torkelnderes": "torkelnd",
    "torkelndes": "torkelnd",
    "torkelndste": "torkelnd",
    "torkelndstem": "torkelnd",
    "torkelndsten": "torkelnd",
    "torkelndster": "torkelnd",
    "torkelndstes": "torkelnd",
    "torkelst": "torkeln",
    "torkelt": "torkeln",
    "torkelte": "torkeln",
    "torkelten": "torkeln",
    "torkeltest": "torkeln",
    "torkeltet": "torkeln",
    "torkle": "torkeln",
    "torpediere": "torpedieren",
    "torpedierend": "torpedieren",
    "torpedierende": "torpedierend",
    "torpedierendem": "torpedierend",
    "torpedierenden": "torpedierend",
    "torpedierender": "torpedierend",
    "torpedierendere": "torpedierend",
    "torpedierenderem": "torpedierend",
    "torpedierenderen": "torpedierend",
    "torpedierenderer": "torpedierend",
    "torpedierenderes": "torpedierend",
    "torpedierendes": "torpedierend",
    "torpedierendste": "torpedierend",
    "torpedierendstem": "torpedierend",
    "torpedierendsten": "torpedierend",
    "torpedierendster": "torpedierend",
    "torpedierendstes": "torpedierend",
    "torpedierest": "torpedieren",
    "torpedieret": "torpedieren",
    "torpedierst": "torpedieren",
    "torpediert": "torpedieren",
    "torpedierte": "torpedieren",
    "torpediertem": "torpediert",
    "torpedierten": "torpedieren",
    "torpedierter": "torpediert",
    "torpediertere": "torpediert",
    "torpedierterem": "torpediert",
    "torpedierteren": "torpediert",
    "torpedierterer": "torpediert",
    "torpedierteres": "torpediert",
    "torpediertes": "torpediert",
    "torpediertest": "torpedieren",
    "torpedierteste": "torpediert",
    "torpediertestem": "torpediert",
    "torpediertesten": "torpediert",
    "torpediertester": "torpediert",
    "torpediertestes": "torpediert",
    "torpediertet": "torpedieren",
    "tose": "tosen",
    "tosend": "tosen",
    "tosende": "tosend",
    "tosendem": "tosend",
    "tosenden": "tosend",
    "tosender": "tosend",
    "tosendere": "tosend",
    "tosenderem": "tosend",
    "tosenderen": "tosend",
    "tosenderer": "tosend",
    "tosenderes": "tosend",
    "tosendes": "tosend",
    "tosendste": "tosend",
    "tosendstem": "tosend",
    "tosendsten": "tosend",
    "tosendster": "tosend",
    "tosendstes": "tosend",
    "tosest": "tosen",
    "toset": "tosen",
    "tost": "tosen",
    "toste": "tosen",
    "tosten": "tosen",
    "tostest": "tosen",
    "tostet": "tosen",
    "totalem": "total",
    "totalen": "total",
    "totaler": "total",
    "totales": "total",
    "totalisiere": "totalisieren",
    "totalisierend": "totalisieren",
    "totalisierende": "totalisierend",
    "totalisierendem": "totalisierend",
    "totalisierenden": "totalisierend",
    "totalisierender": "totalisierend",
    "totalisierendere": "totalisierend",
    "totalisierenderem": "totalisierend",
    "totalisierenderen": "totalisierend",
    "totalisierenderer": "totalisierend",
    "totalisierenderes": "totalisierend",
    "totalisierendes": "totalisierend",
    "totalisierendste": "totalisierend",
    "totalisierendstem": "totalisierend",
    "totalisierendsten": "totalisierend",
    "totalisierendster": "totalisierend",
    "totalisierendstes": "totalisierend",
    "totalisierest": "totalisieren",
    "totalisieret": "totalisieren",
    "totalisierst": "totalisieren",
    "totalisiert": "totalisieren",
    "totalisierte": "totalisieren",
    "totalisiertem": "totalisiert",
    "totalisierten": "totalisieren",
    "totalisierter": "totalisiert",
    "totalisiertere": "totalisiert",
    "totalisierterem": "totalisiert",
    "totalisierteren": "totalisiert",
    "totalisierterer": "totalisiert",
    "totalisierteres": "totalisiert",
    "totalisiertes": "totalisiert",
    "totalisiertest": "totalisieren",
    "totalisierteste": "totalisiert",
    "totalisiertestem": "totalisiert",
    "totalisiertesten": "totalisiert",
    "totalisiertester": "totalisiert",
    "totalisiertestes": "totalisiert",
    "totalisiertet": "totalisieren",
    "totalitäre": "totalitär",
    "totalitärem": "totalitär",
    "totalitären": "totalitär",
    "totalitärer": "totalitär",
    "totalitäres": "totalitär",
    "totarbeite": "totarbeiten",
    "totarbeitend": "totarbeiten",
    "totarbeitende": "totarbeitend",
    "totarbeitendem": "totarbeitend",
    "totarbeitenden": "totarbeitend",
    "totarbeitender": "totarbeitend",
    "totarbeitendere": "totarbeitend",
    "totarbeitenderem": "totarbeitend",
    "totarbeitenderen": "totarbeitend",
    "totarbeitenderer": "totarbeitend",
    "totarbeitenderes": "totarbeitend",
    "totarbeitendes": "totarbeitend",
    "totarbeitendste": "totarbeitend",
    "totarbeitendstem": "totarbeitend",
    "totarbeitendsten": "totarbeitend",
    "totarbeitendster": "totarbeitend",
    "totarbeitendstes": "totarbeitend",
    "totarbeitest": "totarbeiten",
    "totarbeitet": "totarbeiten",
    "totarbeitete": "totarbeiten",
    "totarbeiteten": "totarbeiten",
    "totarbeitetest": "totarbeiten",
    "totarbeitetet": "totarbeiten",
    "tote": "tot",
    "totem": "tot",
    "toten": "tot",
    "totenblassem": "totenblaß",
    "totenblassen": "totenblaß",
    "totenblasser": "totenblaß",
    "totenblasses": "totenblaß",
    "totenbleiche": "totenbleich",
    "totenbleichem": "totenbleich",
    "totenbleichen": "totenbleich",
    "totenbleicher": "totenbleich",
    "totenbleiches": "totenbleich",
    "toter": "tot",
    "totere": "tot",
    "toterem": "tot",
    "toteren": "tot",
    "toterer": "tot",
    "toteres": "tot",
    "totes": "tot",
    "toteste": "tot",
    "totestem": "tot",
    "totesten": "tot",
    "totester": "tot",
    "totestes": "tot",
    "totgearbeitet": "totarbeiten",
    "totgearbeitete": "totgearbeitet",
    "totgearbeitetem": "totgearbeitet",
    "totgearbeiteten": "totgearbeitet",
    "totgearbeiteter": "totgearbeitet",
    "totgearbeitetere": "totgearbeitet",
    "totgearbeiteterem": "totgearbeitet",
    "totgearbeiteteren": "totgearbeitet",
    "totgearbeiteterer": "totgearbeitet",
    "totgearbeiteteres": "totgearbeitet",
    "totgearbeitetes": "totgearbeitet",
    "totgearbeiteteste": "totgearbeitet",
    "totgearbeitetestem": "totgearbeitet",
    "totgearbeitetesten": "totgearbeitet",
    "totgearbeitetester": "totgearbeitet",
    "totgearbeitetestes": "totgearbeitet",
    "totgeborene": "totgeboren",
    "totgeborenem": "totgeboren",
    "totgeborenen": "totgeboren",
    "totgeborener": "totgeboren",
    "totgeborenes": "totgeboren",
    "totgelacht": "totlachen",
    "totgelachte": "totgelacht",
    "totgelachtem": "totgelacht",
    "totgelachten": "totgelacht",
    "totgelachter": "totgelacht",
    "totgelachtes": "totgelacht",
    "totgesagt": "totsagen",
    "totgesagte": "totgesagt",
    "totgesagtem": "totgesagt",
    "totgesagten": "totgesagt",
    "totgesagter": "totgesagt",
    "totgesagtes": "totgesagt",
    "totgeschlagen": "totschlagen",
    "totgeschlagene": "totgeschlagen",
    "totgeschlagenem": "totgeschlagen",
    "totgeschlagenen": "totgeschlagen",
    "totgeschlagener": "totgeschlagen",
    "totgeschlagenes": "totgeschlagen",
    "totgeschwiegen": "totschweigen",
    "totgeschwiegene": "totgeschwiegen",
    "totgeschwiegenem": "totgeschwiegen",
    "totgeschwiegenen": "totgeschwiegen",
    "totgeschwiegener": "totgeschwiegen",
    "totgeschwiegenere": "totgeschwiegen",
    "totgeschwiegenerem": "totgeschwiegen",
    "totgeschwiegeneren": "totgeschwiegen",
    "totgeschwiegenerer": "totgeschwiegen",
    "totgeschwiegeneres": "totgeschwiegen",
    "totgeschwiegenes": "totgeschwiegen",
    "totgeschwiegenste": "totgeschwiegen",
    "totgeschwiegenstem": "totgeschwiegen",
    "totgeschwiegensten": "totgeschwiegen",
    "totgeschwiegenster": "totgeschwiegen",
    "totgeschwiegenstes": "totgeschwiegen",
    "totgestellt": "totstellen",
    "totgestellte": "totgestellt",
    "totgestelltem": "totgestellt",
    "totgestellten": "totgestellt",
    "totgestellter": "totgestellt",
    "totgestelltes": "totgestellt",
    "totgestochen": "totstechen",
    "totgestochene": "totgestochen",
    "totgestochenem": "totgestochen",
    "totgestochenen": "totgestochen",
    "totgestochener": "totgestochen",
    "totgestochenes": "totgestochen",
    "totgetreten": "tottreten",
    "totgetretene": "totgetreten",
    "totgetretenem": "totgetreten",
    "totgetretenen": "totgetreten",
    "totgetretener": "totgetreten",
    "totgetretenes": "totgetreten",
    "totgeärgert": "totärgern",
    "totgeärgerte": "totgeärgert",
    "totgeärgertem": "totgeärgert",
    "totgeärgerten": "totgeärgert",
    "totgeärgerter": "totgeärgert",
    "totgeärgertes": "totgeärgert",
    "totlache": "totlachen",
    "totlachend": "totlachen",
    "totlachende": "totlachend",
    "totlachendem": "totlachend",
    "totlachenden": "totlachend",
    "totlachender": "totlachend",
    "totlachendere": "totlachend",
    "totlachenderem": "totlachend",
    "totlachenderen": "totlachend",
    "totlachenderer": "totlachend",
    "totlachenderes": "totlachend",
    "totlachendes": "totlachend",
    "totlachendste": "totlachend",
    "totlachendstem": "totlachend",
    "totlachendsten": "totlachend",
    "totlachendster": "totlachend",
    "totlachendstes": "totlachend",
    "totlachest": "totlachen",
    "totlachet": "totlachen",
    "totlachst": "totlachen",
    "totlacht": "totlachen",
    "totlachte": "totlachen",
    "totlachten": "totlachen",
    "totlachtest": "totlachen",
    "totlachtet": "totlachen",
    "totsage": "totsagen",
    "totsagend": "totsagen",
    "totsagende": "totsagend",
    "totsagendem": "totsagend",
    "totsagenden": "totsagend",
    "totsagender": "totsagend",
    "totsagendes": "totsagend",
    "totsagest": "totsagen",
    "totsaget": "totsagen",
    "totsagst": "totsagen",
    "totsagt": "totsagen",
    "totsagte": "totsagen",
    "totsagten": "totsagen",
    "totsagtest": "totsagen",
    "totsagtet": "totsagen",
    "totschlage": "totschlagen",
    "totschlagend": "totschlagen",
    "totschlagende": "totschlagend",
    "totschlagendem": "totschlagend",
    "totschlagenden": "totschlagend",
    "totschlagender": "totschlagend",
    "totschlagendes": "totschlagend",
    "totschlagest": "totschlagen",
    "totschlaget": "totschlagen",
    "totschlagt": "totschlagen",
    "totschlug": "totschlagen",
    "totschlugen": "totschlagen",
    "totschlugst": "totschlagen",
    "totschlugt": "totschlagen",
    "totschlägst": "totschlagen",
    "totschlägt": "totschlagen",
    "totschlüge": "totschlagen",
    "totschlügen": "totschlagen",
    "totschlügest": "totschlagen",
    "totschlüget": "totschlagen",
    "totschweige": "totschweigen",
    "totschweigend": "totschweigen",
    "totschweigende": "totschweigend",
    "totschweigendem": "totschweigend",
    "totschweigenden": "totschweigend",
    "totschweigender": "totschweigend",
    "totschweigendere": "totschweigend",
    "totschweigenderem": "totschweigend",
    "totschweigenderen": "totschweigend",
    "totschweigenderer": "totschweigend",
    "totschweigenderes": "totschweigend",
    "totschweigendes": "totschweigend",
    "totschweigendste": "totschweigend",
    "totschweigendstem": "totschweigend",
    "totschweigendsten": "totschweigend",
    "totschweigendster": "totschweigend",
    "totschweigendstes": "totschweigend",
    "totschweigest": "totschweigen",
    "totschweiget": "totschweigen",
    "totschweigst": "totschweigen",
    "totschweigt": "totschweigen",
    "totschwieg": "totschweigen",
    "totschwiege": "totschweigen",
    "totschwiegen": "totschweigen",
    "totschwiegest": "totschweigen",
    "totschwieget": "totschweigen",
    "totschwiegst": "totschweigen",
    "totschwiegt": "totschweigen",
    "totstach": "totstechen",
    "totstachen": "totstechen",
    "totstachst": "totstechen",
    "totstacht": "totstechen",
    "totsteche": "totstechen",
    "totstechend": "totstechen",
    "totstechende": "totstechend",
    "totstechendem": "totstechend",
    "totstechenden": "totstechend",
    "totstechender": "totstechend",
    "totstechendes": "totstechend",
    "totstechest": "totstechen",
    "totstechet": "totstechen",
    "totstecht": "totstechen",
    "totstelle": "totstellen",
    "totstellend": "totstellen",
    "totstellende": "totstellend",
    "totstellendem": "totstellend",
    "totstellenden": "totstellend",
    "totstellender": "totstellend",
    "totstellendes": "totstellend",
    "totstellest": "totstellen",
    "totstellet": "totstellen",
    "totstellst": "totstellen",
    "totstellt": "totstellen",
    "totstellte": "totstellen",
    "totstellten": "totstellen",
    "totstelltest": "totstellen",
    "totstelltet": "totstellen",
    "totstichst": "totstechen",
    "totsticht": "totstechen",
    "totstäche": "totstechen",
    "totstächen": "totstechen",
    "totstächest": "totstechen",
    "totstächet": "totstechen",
    "tottrat": "tottreten",
    "tottraten": "tottreten",
    "tottratest": "tottreten",
    "tottratet": "tottreten",
    "tottrete": "tottreten",
    "tottretend": "tottreten",
    "tottretende": "tottretend",
    "tottretendem": "tottretend",
    "tottretenden": "tottretend",
    "tottretender": "tottretend",
    "tottretendes": "tottretend",
    "tottretest": "tottreten",
    "tottretet": "tottreten",
    "tottritt": "tottreten",
    "tottrittst": "tottreten",
    "totträte": "tottreten",
    "totträten": "tottreten",
    "totträtest": "tottreten",
    "totträtet": "tottreten",
    "totzuarbeiten": "totarbeiten",
    "totzulachen": "totlachen",
    "totzusagen": "totsagen",
    "totzuschlagen": "totschlagen",
    "totzuschweigen": "totschweigen",
    "totzustechen": "totstechen",
    "totzustellen": "totstellen",
    "totzutreten": "tottreten",
    "totzuärgern": "totärgern",
    "totärgere": "totärgern",
    "totärgernd": "totärgern",
    "totärgernde": "totärgernd",
    "totärgerndem": "totärgernd",
    "totärgernden": "totärgernd",
    "totärgernder": "totärgernd",
    "totärgerndes": "totärgernd",
    "totärgerst": "totärgern",
    "totärgert": "totärgern",
    "totärgerte": "totärgern",
    "totärgerten": "totärgern",
    "totärgertest": "totärgern",
    "totärgertet": "totärgern",
    "toxikologischem": "toxikologisch",
    "toxikologischen": "toxikologisch",
    "toxikologischer": "toxikologisch",
    "toxikologisches": "toxikologisch",
    "toxische": "toxisch",
    "toxischem": "toxisch",
    "toxischen": "toxisch",
    "toxischer": "toxisch",
    "toxisches": "toxisch",
    "trabe": "traben",
    "trabend": "traben",
    "trabende": "trabend",
    "trabendem": "trabend",
    "trabenden": "trabend",
    "trabender": "trabend",
    "trabendere": "trabend",
    "trabenderem": "trabend",
    "trabenderen": "trabend",
    "trabenderer": "trabend",
    "trabenderes": "trabend",
    "trabendes": "trabend",
    "trabendste": "trabend",
    "trabendstem": "trabend",
    "trabendsten": "trabend",
    "trabendster": "trabend",
    "trabendstes": "trabend",
    "trabest": "traben",
    "trabet": "traben",
    "trabst": "traben",
    "trabt": "traben",
    "trabte": "traben",
    "trabten": "traben",
    "trabtest": "traben",
    "trabtet": "traben",
    "trachte": "trachten",
    "trachtend": "trachten",
    "trachtende": "trachtend",
    "trachtendem": "trachtend",
    "trachtenden": "trachtend",
    "trachtender": "trachtend",
    "trachtendere": "trachtend",
    "trachtenderem": "trachtend",
    "trachtenderen": "trachtend",
    "trachtenderer": "trachtend",
    "trachtenderes": "trachtend",
    "trachtendes": "trachtend",
    "trachtendste": "trachtend",
    "trachtendstem": "trachtend",
    "trachtendsten": "trachtend",
    "trachtendster": "trachtend",
    "trachtendstes": "trachtend",
    "trachtest": "trachten",
    "trachtet": "trachten",
    "trachtete": "trachten",
    "trachteten": "trachten",
    "trachtetest": "trachten",
    "trachtetet": "trachten",
    "tradiere": "tradieren",
    "tradierend": "tradieren",
    "tradierende": "tradierend",
    "tradierendem": "tradierend",
    "tradierenden": "tradierend",
    "tradierender": "tradierend",
    "tradierendes": "tradierend",
    "tradierest": "tradieren",
    "tradieret": "tradieren",
    "tradierst": "tradieren",
    "tradiert": "tradieren",
    "tradierte": "tradieren",
    "tradiertem": "tradiert",
    "tradierten": "tradieren",
    "tradierter": "tradiert",
    "tradiertes": "tradiert",
    "tradiertest": "tradieren",
    "tradiertet": "tradieren",
    "traditionelle": "traditionell",
    "traditionellem": "traditionell",
    "traditionellen": "traditionell",
    "traditioneller": "traditionell",
    "traditionellere": "traditionell",
    "traditionellerem": "traditionell",
    "traditionelleren": "traditionell",
    "traditionellerer": "traditionell",
    "traditionelleres": "traditionell",
    "traditionelles": "traditionell",
    "traditionellste": "traditionell",
    "traditionellstem": "traditionell",
    "traditionellsten": "traditionell",
    "traditionellster": "traditionell",
    "traditionellstes": "traditionell",
    "traditionsbewußtem": "traditionsbewußt",
    "traditionsbewußten": "traditionsbewußt",
    "traditionsbewußter": "traditionsbewußt",
    "traditionsbewußtere": "traditionsbewußt",
    "traditionsbewußterem": "traditionsbewußt",
    "traditionsbewußteren": "traditionsbewußt",
    "traditionsbewußterer": "traditionsbewußt",
    "traditionsbewußteres": "traditionsbewußt",
    "traditionsbewußtes": "traditionsbewußt",
    "traditionsbewußteste": "traditionsbewußt",
    "traditionsbewußtestem": "traditionsbewußt",
    "traditionsbewußtesten": "traditionsbewußt",
    "traditionsbewußtester": "traditionsbewußt",
    "traditionsbewußtestes": "traditionsbewußt",
    "traditionsreiche": "traditionsreich",
    "traditionsreichem": "traditionsreich",
    "traditionsreichen": "traditionsreich",
    "traditionsreicher": "traditionsreich",
    "traditionsreichere": "traditionsreich",
    "traditionsreicherem": "traditionsreich",
    "traditionsreicheren": "traditionsreich",
    "traditionsreicherer": "traditionsreich",
    "traditionsreicheres": "traditionsreich",
    "traditionsreiches": "traditionsreich",
    "traditionsreichste": "traditionsreich",
    "traditionsreichstem": "traditionsreich",
    "traditionsreichsten": "traditionsreich",
    "traditionsreichster": "traditionsreich",
    "traditionsreichstes": "traditionsreich",
    "traf": "treffen",
    "trafen": "treffen",
    "trafst": "treffen",
    "traft": "treffen",
    "tragbarem": "tragbar",
    "tragbaren": "tragbar",
    "tragbarer": "tragbar",
    "tragbarere": "tragbar",
    "tragbarerem": "tragbar",
    "tragbareren": "tragbar",
    "tragbarerer": "tragbar",
    "tragbareres": "tragbar",
    "tragbares": "tragbar",
    "tragbarste": "tragbar",
    "tragbarstem": "tragbar",
    "tragbarsten": "tragbar",
    "tragbarster": "tragbar",
    "tragbarstes": "tragbar",
    "trage": "tragen",
    "tragend": "tragen",
    "tragende": "tragend",
    "tragendem": "tragend",
    "tragenden": "tragend",
    "tragender": "tragend",
    "tragendes": "tragend",
    "tragest": "tragen",
    "traget": "tragen",
    "tragfähigem": "tragfähig",
    "tragfähigen": "tragfähig",
    "tragfähiger": "tragfähig",
    "tragfähiges": "tragfähig",
    "tragische": "tragisch",
    "tragischem": "tragisch",
    "tragischen": "tragisch",
    "tragischer": "tragisch",
    "tragischere": "tragisch",
    "tragischerem": "tragisch",
    "tragischeren": "tragisch",
    "tragischerer": "tragisch",
    "tragischeres": "tragisch",
    "tragisches": "tragisch",
    "tragischste": "tragisch",
    "tragischstem": "tragisch",
    "tragischsten": "tragisch",
    "tragischster": "tragisch",
    "tragischstes": "tragisch",
    "tragkräftigem": "tragkräftig",
    "tragkräftigen": "tragkräftig",
    "tragkräftiger": "tragkräftig",
    "tragkräftigere": "tragkräftig",
    "tragkräftigerem": "tragkräftig",
    "tragkräftigeren": "tragkräftig",
    "tragkräftigerer": "tragkräftig",
    "tragkräftigeres": "tragkräftig",
    "tragkräftiges": "tragkräftig",
    "tragkräftigste": "tragkräftig",
    "tragkräftigstem": "tragkräftig",
    "tragkräftigsten": "tragkräftig",
    "tragkräftigster": "tragkräftig",
    "tragkräftigstes": "tragkräftig",
    "tragt": "tragen",
    "trainiere": "trainieren",
    "trainierend": "trainieren",
    "trainierende": "trainierend",
    "trainierendem": "trainierend",
    "trainierenden": "trainierend",
    "trainierender": "trainierend",
    "trainierendere": "trainierend",
    "trainierenderem": "trainierend",
    "trainierenderen": "trainierend",
    "trainierenderer": "trainierend",
    "trainierenderes": "trainierend",
    "trainierendes": "trainierend",
    "trainierendste": "trainierend",
    "trainierendstem": "trainierend",
    "trainierendsten": "trainierend",
    "trainierendster": "trainierend",
    "trainierendstes": "trainierend",
    "trainierest": "trainieren",
    "trainieret": "trainieren",
    "trainierst": "trainieren",
    "trainiert": "trainieren",
    "trainierte": "trainieren",
    "trainiertem": "trainiert",
    "trainierten": "trainieren",
    "trainierter": "trainiert",
    "trainiertere": "trainiert",
    "trainierterem": "trainiert",
    "trainierteren": "trainiert",
    "trainierterer": "trainiert",
    "trainierteres": "trainiert",
    "trainiertes": "trainiert",
    "trainiertest": "trainieren",
    "trainierteste": "trainiert",
    "trainiertestem": "trainiert",
    "trainiertesten": "trainiert",
    "trainiertester": "trainiert",
    "trainiertestes": "trainiert",
    "trainiertet": "trainieren",
    "traktiere": "traktieren",
    "traktierend": "traktieren",
    "traktierende": "traktierend",
    "traktierendem": "traktierend",
    "traktierenden": "traktierend",
    "traktierender": "traktierend",
    "traktierendes": "traktierend",
    "traktierest": "traktieren",
    "traktieret": "traktieren",
    "traktierst": "traktieren",
    "traktiert": "traktieren",
    "traktierte": "traktieren",
    "traktiertem": "traktiert",
    "traktierten": "traktieren",
    "traktierter": "traktiert",
    "traktiertes": "traktiert",
    "traktiertest": "traktieren",
    "traktiertet": "traktieren",
    "trampele": "trampeln",
    "trampelnd": "trampeln",
    "trampelnde": "trampelnd",
    "trampelndem": "trampelnd",
    "trampelnden": "trampelnd",
    "trampelnder": "trampelnd",
    "trampelndere": "trampelnd",
    "trampelnderem": "trampelnd",
    "trampelnderen": "trampelnd",
    "trampelnderer": "trampelnd",
    "trampelnderes": "trampelnd",
    "trampelndes": "trampelnd",
    "trampelndste": "trampelnd",
    "trampelndstem": "trampelnd",
    "trampelndsten": "trampelnd",
    "trampelndster": "trampelnd",
    "trampelndstes": "trampelnd",
    "trampelst": "trampeln",
    "trampelt": "trampeln",
    "trampelte": "trampeln",
    "trampelten": "trampeln",
    "trampeltest": "trampeln",
    "trampeltet": "trampeln",
    "trample": "trampeln",
    "tranige": "tranig",
    "tranigem": "tranig",
    "tranigen": "tranig",
    "traniger": "tranig",
    "tranigere": "tranig",
    "tranigerem": "tranig",
    "tranigeren": "tranig",
    "tranigerer": "tranig",
    "tranigeres": "tranig",
    "traniges": "tranig",
    "tranigste": "tranig",
    "tranigstem": "tranig",
    "tranigsten": "tranig",
    "tranigster": "tranig",
    "tranigstes": "tranig",
    "trank": "trinken",
    "tranken": "trinken",
    "trankst": "trinken",
    "trankt": "trinken",
    "transalpinem": "transalpin",
    "transalpinen": "transalpin",
    "transalpiner": "transalpin",
    "transalpines": "transalpin",
    "transchiere": "transchieren",
    "transchierend": "transchieren",
    "transchierende": "transchierend",
    "transchierendem": "transchierend",
    "transchierenden": "transchierend",
    "transchierender": "transchierend",
    "transchierendere": "transchierend",
    "transchierenderem": "transchierend",
    "transchierenderen": "transchierend",
    "transchierenderer": "transchierend",
    "transchierenderes": "transchierend",
    "transchierendes": "transchierend",
    "transchierendste": "transchierend",
    "transchierendstem": "transchierend",
    "transchierendsten": "transchierend",
    "transchierendster": "transchierend",
    "transchierendstes": "transchierend",
    "transchierest": "transchieren",
    "transchieret": "transchieren",
    "transchierst": "transchieren",
    "transchiert": "transchieren",
    "transchierte": "transchieren",
    "transchiertem": "transchiert",
    "transchierten": "transchieren",
    "transchierter": "transchiert",
    "transchiertes": "transchiert",
    "transchiertest": "transchieren",
    "transchiertet": "transchieren",
    "transferiere": "transferieren",
    "transferierend": "transferieren",
    "transferierende": "transferierend",
    "transferierendem": "transferierend",
    "transferierenden": "transferierend",
    "transferierender": "transferierend",
    "transferierendes": "transferierend",
    "transferierest": "transferieren",
    "transferieret": "transferieren",
    "transferierst": "transferieren",
    "transferiert": "transferieren",
    "transferierte": "transferieren",
    "transferiertem": "transferiert",
    "transferierten": "transferieren",
    "transferierter": "transferiert",
    "transferiertes": "transferiert",
    "transferiertest": "transferieren",
    "transferiertet": "transferieren",
    "transformiere": "transformieren",
    "transformierend": "transformieren",
    "transformierende": "transformierend",
    "transformierendem": "transformierend",
    "transformierenden": "transformierend",
    "transformierender": "transformierend",
    "transformierendes": "transformierend",
    "transformierest": "transformieren",
    "transformieret": "transformieren",
    "transformierst": "transformieren",
    "transformiert": "transformieren",
    "transformierte": "transformieren",
    "transformiertem": "transformiert",
    "transformierten": "transformieren",
    "transformierter": "transformiert",
    "transformiertes": "transformiert",
    "transformiertest": "transformieren",
    "transformiertet": "transformieren",
    "transitivem": "transitiv",
    "transitiven": "transitiv",
    "transitiver": "transitiv",
    "transitives": "transitiv",
    "transkontinentale": "transkontinental",
    "transkontinentalem": "transkontinental",
    "transkontinentalen": "transkontinental",
    "transkontinentaler": "transkontinental",
    "transkontinentales": "transkontinental",
    "transparentem": "transparent",
    "transparenten": "transparent",
    "transparenter": "transparent",
    "transparentere": "transparent",
    "transparenterem": "transparent",
    "transparenteren": "transparent",
    "transparenterer": "transparent",
    "transparenteres": "transparent",
    "transparentes": "transparent",
    "transparenteste": "transparent",
    "transparentestem": "transparent",
    "transparentesten": "transparent",
    "transparentester": "transparent",
    "transparentestes": "transparent",
    "transplantiere": "transplantieren",
    "transplantierend": "transplantieren",
    "transplantierende": "transplantierend",
    "transplantierendem": "transplantierend",
    "transplantierenden": "transplantierend",
    "transplantierender": "transplantierend",
    "transplantierendes": "transplantierend",
    "transplantierest": "transplantieren",
    "transplantieret": "transplantieren",
    "transplantierst": "transplantieren",
    "transplantiert": "transplantieren",
    "transplantierte": "transplantieren",
    "transplantiertem": "transplantiert",
    "transplantierten": "transplantieren",
    "transplantierter": "transplantiert",
    "transplantiertes": "transplantiert",
    "transplantiertest": "transplantieren",
    "transplantiertet": "transplantieren",
    "transponiere": "transponieren",
    "transponierend": "transponieren",
    "transponierende": "transponierend",
    "transponierendem": "transponierend",
    "transponierenden": "transponierend",
    "transponierender": "transponierend",
    "transponierendes": "transponierend",
    "transponierest": "transponieren",
    "transponieret": "transponieren",
    "transponierst": "transponieren",
    "transponiert": "transponieren",
    "transponierte": "transponieren",
    "transponiertem": "transponiert",
    "transponierten": "transponieren",
    "transponierter": "transponiert",
    "transponiertes": "transponiert",
    "transponiertest": "transponieren",
    "transponiertet": "transponieren",
    "transportablem": "transportabel",
    "transportablen": "transportabel",
    "transportabler": "transportabel",
    "transportables": "transportabel",
    "transportfähigem": "transportfähig",
    "transportfähigen": "transportfähig",
    "transportfähiger": "transportfähig",
    "transportfähiges": "transportfähig",
    "transportiere": "transportieren",
    "transportierend": "transportieren",
    "transportierende": "transportierend",
    "transportierendem": "transportierend",
    "transportierenden": "transportierend",
    "transportierender": "transportierend",
    "transportierendes": "transportierend",
    "transportierest": "transportieren",
    "transportieret": "transportieren",
    "transportierst": "transportieren",
    "transportiert": "transportieren",
    "transportierte": "transportieren",
    "transportiertem": "transportiert",
    "transportierten": "transportieren",
    "transportierter": "transportiert",
    "transportiertes": "transportiert",
    "transportiertest": "transportieren",
    "transportiertet": "transportieren",
    "transsibirischem": "transsibirisch",
    "transsibirischen": "transsibirisch",
    "transsibirischer": "transsibirisch",
    "transsibirisches": "transsibirisch",
    "trappe": "trappen",
    "trappend": "trappen",
    "trappende": "trappend",
    "trappendem": "trappend",
    "trappenden": "trappend",
    "trappender": "trappend",
    "trappendes": "trappend",
    "trappest": "trappen",
    "trappet": "trappen",
    "trappst": "trappen",
    "trappt": "trappen",
    "trappte": "trappen",
    "trappten": "trappen",
    "trapptest": "trappen",
    "trapptet": "trappen",
    "trapse": "trapsen",
    "trapsend": "trapsen",
    "trapsende": "trapsend",
    "trapsendem": "trapsend",
    "trapsenden": "trapsend",
    "trapsender": "trapsend",
    "trapsendere": "trapsend",
    "trapsenderem": "trapsend",
    "trapsenderen": "trapsend",
    "trapsenderer": "trapsend",
    "trapsenderes": "trapsend",
    "trapsendes": "trapsend",
    "trapsendste": "trapsend",
    "trapsendstem": "trapsend",
    "trapsendsten": "trapsend",
    "trapsendster": "trapsend",
    "trapsendstes": "trapsend",
    "trapsest": "trapsen",
    "trapset": "trapsen",
    "trapst": "trapsen",
    "trapste": "trapsen",
    "trapsten": "trapsen",
    "trapstest": "trapsen",
    "trapstet": "trapsen",
    "trassiere": "trassieren",
    "trassierend": "trassieren",
    "trassierende": "trassierend",
    "trassierendem": "trassierend",
    "trassierenden": "trassierend",
    "trassierender": "trassierend",
    "trassierendes": "trassierend",
    "trassierest": "trassieren",
    "trassieret": "trassieren",
    "trassierst": "trassieren",
    "trassiert": "trassieren",
    "trassierte": "trassieren",
    "trassiertem": "trassiert",
    "trassierten": "trassieren",
    "trassierter": "trassiert",
    "trassiertes": "trassiert",
    "trassiertest": "trassieren",
    "trassiertet": "trassieren",
    "trat": "treten",
    "traten": "treten",
    "tratest": "treten",
    "tratet": "treten",
    "traue": "trauen",
    "trauend": "trauen",
    "trauende": "trauend",
    "trauendem": "trauend",
    "trauenden": "trauend",
    "trauender": "trauend",
    "trauendes": "trauend",
    "trauere": "trauern",
    "trauernd": "trauern",
    "trauernde": "trauernd",
    "trauerndem": "trauernd",
    "trauernden": "trauernd",
    "trauernder": "trauernd",
    "trauerndere": "trauernd",
    "trauernderem": "trauernd",
    "trauernderen": "trauernd",
    "trauernderer": "trauernd",
    "trauernderes": "trauernd",
    "trauerndes": "trauernd",
    "trauerndste": "trauernd",
    "trauerndstem": "trauernd",
    "trauerndsten": "trauernd",
    "trauerndster": "trauernd",
    "trauerndstes": "trauernd",
    "trauerst": "trauern",
    "trauert": "trauern",
    "trauerte": "trauern",
    "trauerten": "trauern",
    "trauertest": "trauern",
    "trauertet": "trauern",
    "trauest": "trauen",
    "trauet": "trauen",
    "traumatische": "traumatisch",
    "traumatischem": "traumatisch",
    "traumatischen": "traumatisch",
    "traumatischer": "traumatisch",
    "traumatischere": "traumatisch",
    "traumatischerem": "traumatisch",
    "traumatischeren": "traumatisch",
    "traumatischerer": "traumatisch",
    "traumatischeres": "traumatisch",
    "traumatisches": "traumatisch",
    "traumatischste": "traumatisch",
    "traumatischstem": "traumatisch",
    "traumatischsten": "traumatisch",
    "traumatischster": "traumatisch",
    "traumatischstes": "traumatisch",
    "traumhafte": "traumhaft",
    "traumhaftem": "traumhaft",
    "traumhaften": "traumhaft",
    "traumhafter": "traumhaft",
    "traumhaftere": "traumhaft",
    "traumhafterem": "traumhaft",
    "traumhafteren": "traumhaft",
    "traumhafterer": "traumhaft",
    "traumhafteres": "traumhaft",
    "traumhaftes": "traumhaft",
    "traumhafteste": "traumhaft",
    "traumhaftestem": "traumhaft",
    "traumhaftesten": "traumhaft",
    "traumhaftester": "traumhaft",
    "traumhaftestes": "traumhaft",
    "traumwandele": "traumwandeln",
    "traumwandelnd": "traumwandeln",
    "traumwandelnde": "traumwandelnd",
    "traumwandelndem": "traumwandelnd",
    "traumwandelnden": "traumwandelnd",
    "traumwandelnder": "traumwandelnd",
    "traumwandelndere": "traumwandelnd",
    "traumwandelnderem": "traumwandelnd",
    "traumwandelnderen": "traumwandelnd",
    "traumwandelnderer": "traumwandelnd",
    "traumwandelnderes": "traumwandelnd",
    "traumwandelndes": "traumwandelnd",
    "traumwandelndste": "traumwandelnd",
    "traumwandelndstem": "traumwandelnd",
    "traumwandelndsten": "traumwandelnd",
    "traumwandelndster": "traumwandelnd",
    "traumwandelndstes": "traumwandelnd",
    "traumwandelst": "traumwandeln",
    "traumwandelt": "traumwandeln",
    "traumwandelte": "traumwandeln",
    "traumwandelten": "traumwandeln",
    "traumwandeltest": "traumwandeln",
    "traumwandeltet": "traumwandeln",
    "traumwandle": "traumwandeln",
    "traurige": "traurig",
    "traurigem": "traurig",
    "traurigen": "traurig",
    "trauriger": "traurig",
    "traurigere": "traurig",
    "traurigerem": "traurig",
    "traurigeren": "traurig",
    "traurigerer": "traurig",
    "traurigeres": "traurig",
    "trauriges": "traurig",
    "traurigste": "traurig",
    "traurigstem": "traurig",
    "traurigsten": "traurig",
    "traurigster": "traurig",
    "traurigstes": "traurig",
    "traust": "trauen",
    "traut": "trauen",
    "traute": "trauen",
    "trauten": "trauen",
    "trautest": "trauen",
    "trautet": "trauen",
    "treffe": "treffen",
    "treffend": "treffen",
    "treffende": "treffend",
    "treffendem": "treffend",
    "treffenden": "treffend",
    "treffender": "treffend",
    "treffendere": "treffend",
    "treffenderem": "treffend",
    "treffenderen": "treffend",
    "treffenderer": "treffend",
    "treffenderes": "treffend",
    "treffendes": "treffend",
    "treffendste": "treffend",
    "treffendstem": "treffend",
    "treffendsten": "treffend",
    "treffendster": "treffend",
    "treffendstes": "treffend",
    "treffest": "treffen",
    "treffet": "treffen",
    "treffliche": "trefflich",
    "trefflichem": "trefflich",
    "trefflichen": "trefflich",
    "trefflicher": "trefflich",
    "treffliches": "trefflich",
    "treffsicherem": "treffsicher",
    "treffsicheren": "treffsicher",
    "treffsicherer": "treffsicher",
    "treffsicherere": "treffsicher",
    "treffsichererem": "treffsicher",
    "treffsichereren": "treffsicher",
    "treffsichererer": "treffsicher",
    "treffsichereres": "treffsicher",
    "treffsicheres": "treffsicher",
    "treffsicherste": "treffsicher",
    "treffsicherstem": "treffsicher",
    "treffsichersten": "treffsicher",
    "treffsicherster": "treffsicher",
    "treffsicherstes": "treffsicher",
    "trefft": "treffen",
    "treibe": "treiben",
    "treibend": "treiben",
    "treibende": "treibend",
    "treibendem": "treibend",
    "treibenden": "treibend",
    "treibender": "treibend",
    "treibendes": "treibend",
    "treibest": "treiben",
    "treibet": "treiben",
    "treibst": "treiben",
    "treibt": "treiben",
    "trennbarem": "trennbar",
    "trennbaren": "trennbar",
    "trennbarer": "trennbar",
    "trennbares": "trennbar",
    "trenne": "trennen",
    "trennend": "trennen",
    "trennende": "trennend",
    "trennendem": "trennend",
    "trennenden": "trennend",
    "trennender": "trennend",
    "trennendes": "trennend",
    "trennest": "trennen",
    "trennet": "trennen",
    "trennscharfem": "trennscharf",
    "trennscharfen": "trennscharf",
    "trennscharfer": "trennscharf",
    "trennscharfes": "trennscharf",
    "trennst": "trennen",
    "trennt": "trennen",
    "trennte": "trennen",
    "trennten": "trennen",
    "trenntest": "trennen",
    "trenntet": "trennen",
    "trete": "treten",
    "tretend": "treten",
    "tretende": "tretend",
    "tretendem": "tretend",
    "tretenden": "tretend",
    "tretender": "tretend",
    "tretendes": "tretend",
    "tretest": "treten",
    "tretet": "treten",
    "treuem": "treu",
    "treuen": "treu",
    "treuer": "treu",
    "treuere": "treu",
    "treuerem": "treu",
    "treueren": "treu",
    "treuerer": "treu",
    "treueres": "treu",
    "treues": "treu",
    "treuherzigem": "treuherzig",
    "treuherzigen": "treuherzig",
    "treuherziger": "treuherzig",
    "treuherzigere": "treuherzig",
    "treuherzigerem": "treuherzig",
    "treuherzigeren": "treuherzig",
    "treuherzigerer": "treuherzig",
    "treuherzigeres": "treuherzig",
    "treuherziges": "treuherzig",
    "treuherzigste": "treuherzig",
    "treuherzigstem": "treuherzig",
    "treuherzigsten": "treuherzig",
    "treuherzigster": "treuherzig",
    "treuherzigstes": "treuherzig",
    "treulose": "treulos",
    "treulosem": "treulos",
    "treulosen": "treulos",
    "treuloser": "treulos",
    "treulosere": "treulos",
    "treuloserem": "treulos",
    "treuloseren": "treulos",
    "treuloserer": "treulos",
    "treuloseres": "treulos",
    "treuloses": "treulos",
    "treuloseste": "treulos",
    "treulosestem": "treulos",
    "treulosesten": "treulos",
    "treulosester": "treulos",
    "treulosestes": "treulos",
    "treuste": "treu",
    "treustem": "treu",
    "treusten": "treu",
    "treuster": "treu",
    "treustes": "treu",
    "trichtere": "trichtern",
    "trichternd": "trichtern",
    "trichternde": "trichternd",
    "trichterndem": "trichternd",
    "trichternden": "trichternd",
    "trichternder": "trichternd",
    "trichterndes": "trichternd",
    "trichterst": "trichtern",
    "trichtert": "trichtern",
    "trichterte": "trichtern",
    "trichterten": "trichtern",
    "trichtertest": "trichtern",
    "trichtertet": "trichtern",
    "trickse": "tricksen",
    "tricksend": "tricksen",
    "tricksende": "tricksend",
    "tricksendem": "tricksend",
    "tricksenden": "tricksend",
    "tricksender": "tricksend",
    "tricksendere": "tricksend",
    "tricksenderem": "tricksend",
    "tricksenderen": "tricksend",
    "tricksenderer": "tricksend",
    "tricksenderes": "tricksend",
    "tricksendes": "tricksend",
    "tricksendste": "tricksend",
    "tricksendstem": "tricksend",
    "tricksendsten": "tricksend",
    "tricksendster": "tricksend",
    "tricksendstes": "tricksend",
    "tricksest": "tricksen",
    "trickset": "tricksen",
    "trickst": "tricksen",
    "trickste": "tricksen",
    "tricksten": "tricksen",
    "trickstest": "tricksen",
    "trickstet": "tricksen",
    "trieb": "treiben",
    "triebest": "treiben",
    "triebet": "treiben",
    "triebhaftem": "triebhaft",
    "triebhaften": "triebhaft",
    "triebhafter": "triebhaft",
    "triebhaftere": "triebhaft",
    "triebhafterem": "triebhaft",
    "triebhafteren": "triebhaft",
    "triebhafterer": "triebhaft",
    "triebhafteres": "triebhaft",
    "triebhaftes": "triebhaft",
    "triebhafteste": "triebhaft",
    "triebhaftestem": "triebhaft",
    "triebhaftesten": "triebhaft",
    "triebhaftester": "triebhaft",
    "triebhaftestes": "triebhaft",
    "triebst": "treiben",
    "triebt": "treiben",
    "triefe": "triefen",
    "triefend": "triefen",
    "triefende": "triefend",
    "triefendem": "triefend",
    "triefenden": "triefend",
    "triefender": "triefend",
    "triefendes": "triefend",
    "triefest": "triefen",
    "triefet": "triefen",
    "triefst": "triefen",
    "trieft": "triefen",
    "triefte": "triefen",
    "trieften": "triefen",
    "trieftest": "triefen",
    "trieftet": "triefen",
    "trieze": "triezen",
    "triezend": "triezen",
    "triezende": "triezend",
    "triezendem": "triezend",
    "triezenden": "triezend",
    "triezender": "triezend",
    "triezendere": "triezend",
    "triezenderem": "triezend",
    "triezenderen": "triezend",
    "triezenderer": "triezend",
    "triezenderes": "triezend",
    "triezendes": "triezend",
    "triezendste": "triezend",
    "triezendstem": "triezend",
    "triezendsten": "triezend",
    "triezendster": "triezend",
    "triezendstes": "triezend",
    "triezest": "triezen",
    "triezet": "triezen",
    "triezt": "triezen",
    "triezte": "triezen",
    "triezten": "triezen",
    "trieztest": "triezen",
    "trieztet": "triezen",
    "triff": "treffen",
    "triffst": "treffen",
    "trifft": "treffen",
    "triftige": "triftig",
    "triftigem": "triftig",
    "triftigen": "triftig",
    "triftiger": "triftig",
    "triftiges": "triftig",
    "trillere": "trillern",
    "trillernd": "trillern",
    "trillernde": "trillernd",
    "trillerndem": "trillernd",
    "trillernden": "trillernd",
    "trillernder": "trillernd",
    "trillerndere": "trillernd",
    "trillernderem": "trillernd",
    "trillernderen": "trillernd",
    "trillernderer": "trillernd",
    "trillernderes": "trillernd",
    "trillerndes": "trillernd",
    "trillerndste": "trillernd",
    "trillerndstem": "trillernd",
    "trillerndsten": "trillernd",
    "trillerndster": "trillernd",
    "trillerndstes": "trillernd",
    "trillerst": "trillern",
    "trillert": "trillern",
    "trillerte": "trillern",
    "trillerten": "trillern",
    "trillertest": "trillern",
    "trillertet": "trillern",
    "trimme": "trimmen",
    "trimmend": "trimmen",
    "trimmende": "trimmend",
    "trimmendem": "trimmend",
    "trimmenden": "trimmend",
    "trimmender": "trimmend",
    "trimmendere": "trimmend",
    "trimmenderem": "trimmend",
    "trimmenderen": "trimmend",
    "trimmenderer": "trimmend",
    "trimmenderes": "trimmend",
    "trimmendes": "trimmend",
    "trimmendste": "trimmend",
    "trimmendstem": "trimmend",
    "trimmendsten": "trimmend",
    "trimmendster": "trimmend",
    "trimmendstes": "trimmend",
    "trimmest": "trimmen",
    "trimmet": "trimmen",
    "trimmst": "trimmen",
    "trimmt": "trimmen",
    "trimmte": "trimmen",
    "trimmten": "trimmen",
    "trimmtest": "trimmen",
    "trimmtet": "trimmen",
    "trinke": "trinken",
    "trinkend": "trinken",
    "trinkende": "trinkend",
    "trinkendem": "trinkend",
    "trinkenden": "trinkend",
    "trinkender": "trinkend",
    "trinkendes": "trinkend",
    "trinkest": "trinken",
    "trinket": "trinken",
    "trinkfeste": "trinkfest",
    "trinkfestem": "trinkfest",
    "trinkfesten": "trinkfest",
    "trinkfester": "trinkfest",
    "trinkfestere": "trinkfest",
    "trinkfesterem": "trinkfest",
    "trinkfesteren": "trinkfest",
    "trinkfesterer": "trinkfest",
    "trinkfesteres": "trinkfest",
    "trinkfestes": "trinkfest",
    "trinkfesteste": "trinkfest",
    "trinkfestestem": "trinkfest",
    "trinkfestesten": "trinkfest",
    "trinkfestester": "trinkfest",
    "trinkfestestes": "trinkfest",
    "trinkst": "trinken",
    "trinkt": "trinken",
    "trippele": "trippeln",
    "trippelnd": "trippeln",
    "trippelnde": "trippelnd",
    "trippelndem": "trippelnd",
    "trippelnden": "trippelnd",
    "trippelnder": "trippelnd",
    "trippelndere": "trippelnd",
    "trippelnderem": "trippelnd",
    "trippelnderen": "trippelnd",
    "trippelnderer": "trippelnd",
    "trippelnderes": "trippelnd",
    "trippelndes": "trippelnd",
    "trippelndste": "trippelnd",
    "trippelndstem": "trippelnd",
    "trippelndsten": "trippelnd",
    "trippelndster": "trippelnd",
    "trippelndstes": "trippelnd",
    "trippelst": "trippeln",
    "trippelt": "trippeln",
    "trippelte": "trippeln",
    "trippelten": "trippeln",
    "trippeltest": "trippeln",
    "trippeltet": "trippeln",
    "tripple": "trippeln",
    "tristem": "trist",
    "tristen": "trist",
    "trister": "trist",
    "tristere": "trist",
    "tristerem": "trist",
    "tristeren": "trist",
    "tristerer": "trist",
    "tristeres": "trist",
    "tristes": "trist",
    "tristeste": "trist",
    "tristestem": "trist",
    "tristesten": "trist",
    "tristester": "trist",
    "tristestes": "trist",
    "trittst": "treten",
    "triumphale": "triumphal",
    "triumphalem": "triumphal",
    "triumphalen": "triumphal",
    "triumphaler": "triumphal",
    "triumphales": "triumphal",
    "triumphiere": "triumphieren",
    "triumphierend": "triumphieren",
    "triumphierende": "triumphierend",
    "triumphierendem": "triumphierend",
    "triumphierenden": "triumphierend",
    "triumphierender": "triumphierend",
    "triumphierendere": "triumphierend",
    "triumphierenderem": "triumphierend",
    "triumphierenderen": "triumphierend",
    "triumphierenderer": "triumphierend",
    "triumphierenderes": "triumphierend",
    "triumphierendes": "triumphierend",
    "triumphierendste": "triumphierend",
    "triumphierendstem": "triumphierend",
    "triumphierendsten": "triumphierend",
    "triumphierendster": "triumphierend",
    "triumphierendstes": "triumphierend",
    "triumphierest": "triumphieren",
    "triumphieret": "triumphieren",
    "triumphierst": "triumphieren",
    "triumphiert": "triumphieren",
    "triumphierte": "triumphieren",
    "triumphiertem": "triumphiert",
    "triumphierten": "triumphieren",
    "triumphierter": "triumphiert",
    "triumphiertes": "triumphiert",
    "triumphiertest": "triumphieren",
    "triumphiertet": "triumphieren",
    "trockenem": "trocken",
    "trockenen": "trocken",
    "trockener": "trocken",
    "trockenere": "trocken",
    "trockenerem": "trocken",
    "trockeneren": "trocken",
    "trockenerer": "trocken",
    "trockeneres": "trocken",
    "trockenes": "trocken",
    "trockenstem": "trocken",
    "trockensten": "trocken",
    "trockenster": "trocken",
    "trockenstes": "trocken",
    "trockne": "trocknen",
    "trocknend": "trocknen",
    "trocknende": "trocknend",
    "trocknendem": "trocknend",
    "trocknenden": "trocknend",
    "trocknender": "trocknend",
    "trocknendere": "trocknend",
    "trocknenderem": "trocknend",
    "trocknenderen": "trocknend",
    "trocknenderer": "trocknend",
    "trocknenderes": "trocknend",
    "trocknendes": "trocknend",
    "trocknendste": "trocknend",
    "trocknendstem": "trocknend",
    "trocknendsten": "trocknend",
    "trocknendster": "trocknend",
    "trocknendstes": "trocknend",
    "trocknest": "trocknen",
    "trocknet": "trocknen",
    "trocknete": "trocknen",
    "trockneten": "trocknen",
    "trocknetest": "trocknen",
    "trocknetet": "trocknen",
    "troff": "triefen",
    "troffen": "triefen",
    "troffst": "triefen",
    "trofft": "triefen",
    "trog": "trügen",
    "trogen": "trügen",
    "trogst": "trügen",
    "trogt": "trügen",
    "trojanischem": "trojanisch",
    "trojanischen": "trojanisch",
    "trojanischer": "trojanisch",
    "trojanisches": "trojanisch",
    "trommele": "trommeln",
    "trommelnd": "trommeln",
    "trommelnde": "trommelnd",
    "trommelndem": "trommelnd",
    "trommelnden": "trommelnd",
    "trommelnder": "trommelnd",
    "trommelndere": "trommelnd",
    "trommelnderem": "trommelnd",
    "trommelnderen": "trommelnd",
    "trommelnderer": "trommelnd",
    "trommelnderes": "trommelnd",
    "trommelndes": "trommelnd",
    "trommelndste": "trommelnd",
    "trommelndstem": "trommelnd",
    "trommelndsten": "trommelnd",
    "trommelndster": "trommelnd",
    "trommelndstes": "trommelnd",
    "trommelst": "trommeln",
    "trommelt": "trommeln",
    "trommelte": "trommeln",
    "trommelten": "trommeln",
    "trommeltest": "trommeln",
    "trommeltet": "trommeln",
    "trommle": "trommeln",
    "trompete": "trompeten",
    "trompetend": "trompeten",
    "trompetende": "trompetend",
    "trompetendem": "trompetend",
    "trompetenden": "trompetend",
    "trompetender": "trompetend",
    "trompetendes": "trompetend",
    "trompetest": "trompeten",
    "trompetet": "trompeten",
    "trompetete": "trompeten",
    "trompetetem": "trompetet",
    "trompeteten": "trompeten",
    "trompeteter": "trompetet",
    "trompetetes": "trompetet",
    "trompetetest": "trompeten",
    "trompetetet": "trompeten",
    "tropfend": "tropfen",
    "tropfende": "tropfend",
    "tropfendem": "tropfend",
    "tropfenden": "tropfend",
    "tropfender": "tropfend",
    "tropfendere": "tropfend",
    "tropfenderem": "tropfend",
    "tropfenderen": "tropfend",
    "tropfenderer": "tropfend",
    "tropfenderes": "tropfend",
    "tropfendes": "tropfend",
    "tropfendste": "tropfend",
    "tropfendstem": "tropfend",
    "tropfendsten": "tropfend",
    "tropfendster": "tropfend",
    "tropfendstes": "tropfend",
    "tropfest": "tropfen",
    "tropfet": "tropfen",
    "tropfst": "tropfen",
    "tropft": "tropfen",
    "tropfte": "tropfen",
    "tropften": "tropfen",
    "tropftest": "tropfen",
    "tropftet": "tropfen",
    "tropischem": "tropisch",
    "tropischen": "tropisch",
    "tropischer": "tropisch",
    "tropisches": "tropisch",
    "trostlose": "trostlos",
    "trostlosem": "trostlos",
    "trostlosen": "trostlos",
    "trostloser": "trostlos",
    "trostlosere": "trostlos",
    "trostloserem": "trostlos",
    "trostloseren": "trostlos",
    "trostloserer": "trostlos",
    "trostloseres": "trostlos",
    "trostloses": "trostlos",
    "trostloseste": "trostlos",
    "trostlosestem": "trostlos",
    "trostlosesten": "trostlos",
    "trostlosester": "trostlos",
    "trostlosestes": "trostlos",
    "trotte": "trotten",
    "trottelige": "trottelig",
    "trotteligem": "trottelig",
    "trotteligen": "trottelig",
    "trotteliger": "trottelig",
    "trotteligere": "trottelig",
    "trotteligerem": "trottelig",
    "trotteligeren": "trottelig",
    "trotteligerer": "trottelig",
    "trotteligeres": "trottelig",
    "trotteliges": "trottelig",
    "trotteligste": "trottelig",
    "trotteligstem": "trottelig",
    "trotteligsten": "trottelig",
    "trotteligster": "trottelig",
    "trotteligstes": "trottelig",
    "trottend": "trotten",
    "trottende": "trottend",
    "trottendem": "trottend",
    "trottenden": "trottend",
    "trottender": "trottend",
    "trottendere": "trottend",
    "trottenderem": "trottend",
    "trottenderen": "trottend",
    "trottenderer": "trottend",
    "trottenderes": "trottend",
    "trottendes": "trottend",
    "trottendste": "trottend",
    "trottendstem": "trottend",
    "trottendsten": "trottend",
    "trottendster": "trottend",
    "trottendstes": "trottend",
    "trottest": "trotten",
    "trottet": "trotten",
    "trottete": "trotten",
    "trotteten": "trotten",
    "trottetest": "trotten",
    "trottetet": "trotten",
    "trotz": "trotzen",
    "trotze": "trotzen",
    "trotzend": "trotzen",
    "trotzende": "trotzend",
    "trotzendem": "trotzend",
    "trotzenden": "trotzend",
    "trotzender": "trotzend",
    "trotzendere": "trotzend",
    "trotzenderem": "trotzend",
    "trotzenderen": "trotzend",
    "trotzenderer": "trotzend",
    "trotzenderes": "trotzend",
    "trotzendes": "trotzend",
    "trotzendste": "trotzend",
    "trotzendstem": "trotzend",
    "trotzendsten": "trotzend",
    "trotzendster": "trotzend",
    "trotzendstes": "trotzend",
    "trotzest": "trotzen",
    "trotzet": "trotzen",
    "trotzige": "trotzig",
    "trotzigem": "trotzig",
    "trotzigen": "trotzig",
    "trotziger": "trotzig",
    "trotzigere": "trotzig",
    "trotzigerem": "trotzig",
    "trotzigeren": "trotzig",
    "trotzigerer": "trotzig",
    "trotzigeres": "trotzig",
    "trotziges": "trotzig",
    "trotzigste": "trotzig",
    "trotzigstem": "trotzig",
    "trotzigsten": "trotzig",
    "trotzigster": "trotzig",
    "trotzigstes": "trotzig",
    "trotzt": "trotzen",
    "trotzte": "trotzen",
    "trotzten": "trotzen",
    "trotztest": "trotzen",
    "trotztet": "trotzen",
    "trudele": "trudeln",
    "trudelnd": "trudeln",
    "trudelnde": "trudelnd",
    "trudelndem": "trudelnd",
    "trudelnden": "trudelnd",
    "trudelnder": "trudelnd",
    "trudelndere": "trudelnd",
    "trudelnderem": "trudelnd",
    "trudelnderen": "trudelnd",
    "trudelnderer": "trudelnd",
    "trudelnderes": "trudelnd",
    "trudelndes": "trudelnd",
    "trudelndste": "trudelnd",
    "trudelndstem": "trudelnd",
    "trudelndsten": "trudelnd",
    "trudelndster": "trudelnd",
    "trudelndstes": "trudelnd",
    "trudelst": "trudeln",
    "trudelt": "trudeln",
    "trudelte": "trudeln",
    "trudelten": "trudeln",
    "trudeltest": "trudeln",
    "trudeltet": "trudeln",
    "trudle": "trudeln",
    "trug": "tragen",
    "trugen": "tragen",
    "trugst": "tragen",
    "trugt": "tragen",
    "trumpfend": "trumpfen",
    "trumpfende": "trumpfend",
    "trumpfendem": "trumpfend",
    "trumpfenden": "trumpfend",
    "trumpfender": "trumpfend",
    "trumpfendere": "trumpfend",
    "trumpfenderem": "trumpfend",
    "trumpfenderen": "trumpfend",
    "trumpfenderer": "trumpfend",
    "trumpfenderes": "trumpfend",
    "trumpfendes": "trumpfend",
    "trumpfendste": "trumpfend",
    "trumpfendstem": "trumpfend",
    "trumpfendsten": "trumpfend",
    "trumpfendster": "trumpfend",
    "trumpfendstes": "trumpfend",
    "trumpfest": "trumpfen",
    "trumpfet": "trumpfen",
    "trumpfst": "trumpfen",
    "trumpft": "trumpfen",
    "trumpfte": "trumpfen",
    "trumpften": "trumpfen",
    "trumpftest": "trumpfen",
    "trumpftet": "trumpfen",
    "trächtige": "trächtig",
    "trächtigem": "trächtig",
    "trächtigen": "trächtig",
    "trächtiger": "trächtig",
    "trächtigere": "trächtig",
    "trächtigerem": "trächtig",
    "trächtigeren": "trächtig",
    "trächtigerer": "trächtig",
    "trächtigeres": "trächtig",
    "trächtiges": "trächtig",
    "trächtigste": "trächtig",
    "trächtigstem": "trächtig",
    "trächtigsten": "trächtig",
    "trächtigster": "trächtig",
    "trächtigstes": "trächtig",
    "träfe": "treffen",
    "träfen": "treffen",
    "träfest": "treffen",
    "träfet": "treffen",
    "trägem": "träge",
    "trägere": "träge",
    "trägerem": "träge",
    "trägeren": "träge",
    "trägerer": "träge",
    "trägeres": "träge",
    "träges": "träge",
    "trägeste": "träge",
    "trägestem": "träge",
    "trägesten": "träge",
    "trägester": "träge",
    "trägestes": "träge",
    "trägst": "tragen",
    "trägt": "tragen",
    "trällere": "trällern",
    "trällernd": "trällern",
    "trällernde": "trällernd",
    "trällerndem": "trällernd",
    "trällernden": "trällernd",
    "trällernder": "trällernd",
    "trällerndere": "trällernd",
    "trällernderem": "trällernd",
    "trällernderen": "trällernd",
    "trällernderer": "trällernd",
    "trällernderes": "trällernd",
    "trällerndes": "trällernd",
    "trällerndste": "trällernd",
    "trällerndstem": "trällernd",
    "trällerndsten": "trällernd",
    "trällerndster": "trällernd",
    "trällerndstes": "trällernd",
    "trällerst": "trällern",
    "trällert": "trällern",
    "trällerte": "trällern",
    "trällerten": "trällern",
    "trällertest": "trällern",
    "trällertet": "trällern",
    "tränend": "tränen",
    "tränende": "tränend",
    "tränendem": "tränend",
    "tränenden": "tränend",
    "tränender": "tränend",
    "tränendere": "tränend",
    "tränenderem": "tränend",
    "tränenderen": "tränend",
    "tränenderer": "tränend",
    "tränenderes": "tränend",
    "tränendes": "tränend",
    "tränendste": "tränend",
    "tränendstem": "tränend",
    "tränendsten": "tränend",
    "tränendster": "tränend",
    "tränendstes": "tränend",
    "tränenreiche": "tränenreich",
    "tränenreichem": "tränenreich",
    "tränenreichen": "tränenreich",
    "tränenreicher": "tränenreich",
    "tränenreichere": "tränenreich",
    "tränenreicherem": "tränenreich",
    "tränenreicheren": "tränenreich",
    "tränenreicherer": "tränenreich",
    "tränenreicheres": "tränenreich",
    "tränenreiches": "tränenreich",
    "tränenreichste": "tränenreich",
    "tränenreichstem": "tränenreich",
    "tränenreichsten": "tränenreich",
    "tränenreichster": "tränenreich",
    "tränenreichstes": "tränenreich",
    "tränest": "tränen",
    "tränet": "tränen",
    "tränke": "trinken",
    "tränkest": "trinken",
    "tränket": "trinken",
    "tränst": "tränen",
    "tränt": "tränen",
    "tränte": "tränen",
    "tränten": "tränen",
    "träntest": "tränen",
    "träntet": "tränen",
    "träte": "treten",
    "träten": "treten",
    "trätest": "treten",
    "trätet": "treten",
    "träufe": "träufen",
    "träufele": "träufeln",
    "träufelnd": "träufeln",
    "träufelnde": "träufelnd",
    "träufelndem": "träufelnd",
    "träufelnden": "träufelnd",
    "träufelnder": "träufelnd",
    "träufelndere": "träufelnd",
    "träufelnderem": "träufelnd",
    "träufelnderen": "träufelnd",
    "träufelnderer": "träufelnd",
    "träufelnderes": "träufelnd",
    "träufelndes": "träufelnd",
    "träufelndste": "träufelnd",
    "träufelndstem": "träufelnd",
    "träufelndsten": "träufelnd",
    "träufelndster": "träufelnd",
    "träufelndstes": "träufelnd",
    "träufelst": "träufeln",
    "träufelt": "träufeln",
    "träufelte": "träufeln",
    "träufelten": "träufeln",
    "träufeltest": "träufeln",
    "träufeltet": "träufeln",
    "träufend": "träufen",
    "träufende": "träufend",
    "träufendem": "träufend",
    "träufenden": "träufend",
    "träufender": "träufend",
    "träufendere": "träufend",
    "träufenderem": "träufend",
    "träufenderen": "träufend",
    "träufenderer": "träufend",
    "träufenderes": "träufend",
    "träufendes": "träufend",
    "träufendste": "träufend",
    "träufendstem": "träufend",
    "träufendsten": "träufend",
    "träufendster": "träufend",
    "träufendstes": "träufend",
    "träufest": "träufen",
    "träufet": "träufen",
    "träufle": "träufeln",
    "träufst": "träufen",
    "träuft": "träufen",
    "träufte": "träufen",
    "träuften": "träufen",
    "träuftest": "träufen",
    "träuftet": "träufen",
    "träumend": "träumen",
    "träumende": "träumend",
    "träumendem": "träumend",
    "träumenden": "träumend",
    "träumender": "träumend",
    "träumendere": "träumend",
    "träumenderem": "träumend",
    "träumenderen": "träumend",
    "träumenderer": "träumend",
    "träumenderes": "träumend",
    "träumendes": "träumend",
    "träumendste": "träumend",
    "träumendstem": "träumend",
    "träumendsten": "träumend",
    "träumendster": "träumend",
    "träumendstes": "träumend",
    "träumerischem": "träumerisch",
    "träumerischen": "träumerisch",
    "träumerischer": "träumerisch",
    "träumerisches": "träumerisch",
    "träumest": "träumen",
    "träumet": "träumen",
    "träumst": "träumen",
    "träumt": "träumen",
    "träumte": "träumen",
    "träumten": "träumen",
    "träumtest": "träumen",
    "träumtet": "träumen",
    "trödele": "trödeln",
    "trödeligem": "trödelig",
    "trödeligen": "trödelig",
    "trödeliger": "trödelig",
    "trödeligere": "trödelig",
    "trödeligerem": "trödelig",
    "trödeligeren": "trödelig",
    "trödeligerer": "trödelig",
    "trödeligeres": "trödelig",
    "trödeliges": "trödelig",
    "trödeligste": "trödelig",
    "trödeligstem": "trödelig",
    "trödeligsten": "trödelig",
    "trödeligster": "trödelig",
    "trödeligstes": "trödelig",
    "trödelnd": "trödeln",
    "trödelnde": "trödelnd",
    "trödelndem": "trödelnd",
    "trödelnden": "trödelnd",
    "trödelnder": "trödelnd",
    "trödelndere": "trödelnd",
    "trödelnderem": "trödelnd",
    "trödelnderen": "trödelnd",
    "trödelnderer": "trödelnd",
    "trödelnderes": "trödelnd",
    "trödelndes": "trödelnd",
    "trödelndste": "trödelnd",
    "trödelndstem": "trödelnd",
    "trödelndsten": "trödelnd",
    "trödelndster": "trödelnd",
    "trödelndstes": "trödelnd",
    "trödelst": "trödeln",
    "trödelt": "trödeln",
    "trödelte": "trödeln",
    "trödelten": "trödeln",
    "trödeltest": "trödeln",
    "trödeltet": "trödeln",
    "trödle": "trödeln",
    "tröffe": "triefen",
    "tröffen": "triefen",
    "tröffest": "triefen",
    "tröffet": "triefen",
    "trögest": "trügen",
    "tröget": "trügen",
    "tröpfele": "tröpfeln",
    "tröpfelnd": "tröpfeln",
    "tröpfelnde": "tröpfelnd",
    "tröpfelndem": "tröpfelnd",
    "tröpfelnden": "tröpfelnd",
    "tröpfelnder": "tröpfelnd",
    "tröpfelndere": "tröpfelnd",
    "tröpfelnderem": "tröpfelnd",
    "tröpfelnderen": "tröpfelnd",
    "tröpfelnderer": "tröpfelnd",
    "tröpfelnderes": "tröpfelnd",
    "tröpfelndes": "tröpfelnd",
    "tröpfelndste": "tröpfelnd",
    "tröpfelndstem": "tröpfelnd",
    "tröpfelndsten": "tröpfelnd",
    "tröpfelndster": "tröpfelnd",
    "tröpfelndstes": "tröpfelnd",
    "tröpfelst": "tröpfeln",
    "tröpfelt": "tröpfeln",
    "tröpfelte": "tröpfeln",
    "tröpfelten": "tröpfeln",
    "tröpfeltest": "tröpfeln",
    "tröpfeltet": "tröpfeln",
    "tröpfle": "tröpfeln",
    "tröste": "trösten",
    "tröstend": "trösten",
    "tröstende": "tröstend",
    "tröstendem": "tröstend",
    "tröstenden": "tröstend",
    "tröstender": "tröstend",
    "tröstendere": "tröstend",
    "tröstenderem": "tröstend",
    "tröstenderen": "tröstend",
    "tröstenderer": "tröstend",
    "tröstenderes": "tröstend",
    "tröstendes": "tröstend",
    "tröstendste": "tröstend",
    "tröstendstem": "tröstend",
    "tröstendsten": "tröstend",
    "tröstendster": "tröstend",
    "tröstendstes": "tröstend",
    "tröstest": "trösten",
    "tröstet": "trösten",
    "tröstete": "trösten",
    "trösteten": "trösten",
    "tröstetest": "trösten",
    "tröstetet": "trösten",
    "tröstliche": "tröstlich",
    "tröstlichem": "tröstlich",
    "tröstlichen": "tröstlich",
    "tröstlicher": "tröstlich",
    "tröstlichere": "tröstlich",
    "tröstlicherem": "tröstlich",
    "tröstlicheren": "tröstlich",
    "tröstlicherer": "tröstlich",
    "tröstlicheres": "tröstlich",
    "tröstliches": "tröstlich",
    "tröstlichste": "tröstlich",
    "tröstlichstem": "tröstlich",
    "tröstlichsten": "tröstlich",
    "tröstlichster": "tröstlich",
    "tröstlichstes": "tröstlich",
    "trüb": "trüben",
    "trübe": "trüb",
    "trübem": "trüb",
    "trüben": "trüb",
    "trübend": "trüben",
    "trübende": "trübend",
    "trübendem": "trübend",
    "trübenden": "trübend",
    "trübender": "trübend",
    "trübendere": "trübend",
    "trübenderem": "trübend",
    "trübenderen": "trübend",
    "trübenderer": "trübend",
    "trübenderes": "trübend",
    "trübendes": "trübend",
    "trübendste": "trübend",
    "trübendstem": "trübend",
    "trübendsten": "trübend",
    "trübendster": "trübend",
    "trübendstes": "trübend",
    "trüber": "trüb",
    "trübere": "trüb",
    "trüberem": "trüb",
    "trüberen": "trüb",
    "trüberer": "trüb",
    "trüberes": "trüb",
    "trübes": "trüb",
    "trübest": "trüben",
    "trübet": "trüben",
    "trübseligem": "trübselig",
    "trübseligen": "trübselig",
    "trübseliger": "trübselig",
    "trübseligere": "trübselig",
    "trübseligerem": "trübselig",
    "trübseligeren": "trübselig",
    "trübseligerer": "trübselig",
    "trübseligeres": "trübselig",
    "trübseliges": "trübselig",
    "trübseligste": "trübselig",
    "trübseligstem": "trübselig",
    "trübseligsten": "trübselig",
    "trübseligster": "trübselig",
    "trübseligstes": "trübselig",
    "trübsinnige": "trübsinnig",
    "trübsinnigem": "trübsinnig",
    "trübsinnigen": "trübsinnig",
    "trübsinniger": "trübsinnig",
    "trübsinnigere": "trübsinnig",
    "trübsinnigerem": "trübsinnig",
    "trübsinnigeren": "trübsinnig",
    "trübsinnigerer": "trübsinnig",
    "trübsinnigeres": "trübsinnig",
    "trübsinniges": "trübsinnig",
    "trübsinnigste": "trübsinnig",
    "trübsinnigstem": "trübsinnig",
    "trübsinnigsten": "trübsinnig",
    "trübsinnigster": "trübsinnig",
    "trübsinnigstes": "trübsinnig",
    "trübst": "trüben",
    "trübste": "trüb",
    "trübstem": "trüb",
    "trübsten": "trüb",
    "trübster": "trüb",
    "trübstes": "trüb",
    "trübt": "trüben",
    "trübte": "trüben",
    "trübten": "trüben",
    "trübtest": "trüben",
    "trübtet": "trüben",
    "trüge": "trügen",
    "trügen": "tragen",
    "trügend": "trügen",
    "trügende": "trügend",
    "trügendem": "trügend",
    "trügenden": "trügend",
    "trügender": "trügend",
    "trügendere": "trügend",
    "trügenderem": "trügend",
    "trügenderen": "trügend",
    "trügenderer": "trügend",
    "trügenderes": "trügend",
    "trügendes": "trügend",
    "trügendste": "trügend",
    "trügendstem": "trügend",
    "trügendsten": "trügend",
    "trügendster": "trügend",
    "trügendstes": "trügend",
    "trügerischem": "trügerisch",
    "trügerischen": "trügerisch",
    "trügerischer": "trügerisch",
    "trügerischere": "trügerisch",
    "trügerischerem": "trügerisch",
    "trügerischeren": "trügerisch",
    "trügerischerer": "trügerisch",
    "trügerischeres": "trügerisch",
    "trügerisches": "trügerisch",
    "trügerischste": "trügerisch",
    "trügerischstem": "trügerisch",
    "trügerischsten": "trügerisch",
    "trügerischster": "trügerisch",
    "trügerischstes": "trügerisch",
    "trügest": "trügen",
    "trüget": "trügen",
    "trügst": "trügen",
    "trügt": "trügen",
    "tschechischem": "tschechisch",
    "tschechischen": "tschechisch",
    "tschechischer": "tschechisch",
    "tschechischere": "tschechisch",
    "tschechischerem": "tschechisch",
    "tschechischeren": "tschechisch",
    "tschechischerer": "tschechisch",
    "tschechischeres": "tschechisch",
    "tschechisches": "tschechisch",
    "tschechischste": "tschechisch",
    "tschechischstem": "tschechisch",
    "tschechischsten": "tschechisch",
    "tschechischster": "tschechisch",
    "tschechischstes": "tschechisch",
    "tuckere": "tuckern",
    "tuckernd": "tuckern",
    "tuckernde": "tuckernd",
    "tuckerndem": "tuckernd",
    "tuckernden": "tuckernd",
    "tuckernder": "tuckernd",
    "tuckerndere": "tuckernd",
    "tuckernderem": "tuckernd",
    "tuckernderen": "tuckernd",
    "tuckernderer": "tuckernd",
    "tuckernderes": "tuckernd",
    "tuckerndes": "tuckernd",
    "tuckerndste": "tuckernd",
    "tuckerndstem": "tuckernd",
    "tuckerndsten": "tuckernd",
    "tuckerndster": "tuckernd",
    "tuckerndstes": "tuckernd",
    "tuckerst": "tuckern",
    "tuckert": "tuckern",
    "tuckerte": "tuckern",
    "tuckertem": "tuckert",
    "tuckerten": "tuckern",
    "tuckerter": "tuckert",
    "tuckertes": "tuckert",
    "tuckertest": "tuckern",
    "tuckertet": "tuckern",
    "tue": "tun",
    "tuend": "tun",
    "tuende": "tuend",
    "tuendem": "tuend",
    "tuenden": "tuend",
    "tuender": "tuend",
    "tuendes": "tuend",
    "tuest": "tun",
    "tuet": "tun",
    "tugendhaftem": "tugendhaft",
    "tugendhaften": "tugendhaft",
    "tugendhafter": "tugendhaft",
    "tugendhaftere": "tugendhaft",
    "tugendhafterem": "tugendhaft",
    "tugendhafteren": "tugendhaft",
    "tugendhafterer": "tugendhaft",
    "tugendhafteres": "tugendhaft",
    "tugendhaftes": "tugendhaft",
    "tugendhafteste": "tugendhaft",
    "tugendhaftestem": "tugendhaft",
    "tugendhaftesten": "tugendhaft",
    "tugendhaftester": "tugendhaft",
    "tugendhaftestes": "tugendhaft",
    "tugendsame": "tugendsam",
    "tugendsamem": "tugendsam",
    "tugendsamen": "tugendsam",
    "tugendsamer": "tugendsam",
    "tugendsamere": "tugendsam",
    "tugendsamerem": "tugendsam",
    "tugendsameren": "tugendsam",
    "tugendsamerer": "tugendsam",
    "tugendsameres": "tugendsam",
    "tugendsames": "tugendsam",
    "tugendsamste": "tugendsam",
    "tugendsamstem": "tugendsam",
    "tugendsamsten": "tugendsam",
    "tugendsamster": "tugendsam",
    "tugendsamstes": "tugendsam",
    "tummele": "tummeln",
    "tummelnd": "tummeln",
    "tummelnde": "tummelnd",
    "tummelndem": "tummelnd",
    "tummelnden": "tummelnd",
    "tummelnder": "tummelnd",
    "tummelndere": "tummelnd",
    "tummelnderem": "tummelnd",
    "tummelnderen": "tummelnd",
    "tummelnderer": "tummelnd",
    "tummelnderes": "tummelnd",
    "tummelndes": "tummelnd",
    "tummelndste": "tummelnd",
    "tummelndstem": "tummelnd",
    "tummelndsten": "tummelnd",
    "tummelndster": "tummelnd",
    "tummelndstes": "tummelnd",
    "tummelst": "tummeln",
    "tummelt": "tummeln",
    "tummelte": "tummeln",
    "tummelten": "tummeln",
    "tummeltest": "tummeln",
    "tummeltet": "tummeln",
    "tummle": "tummeln",
    "tunke": "tunken",
    "tunkend": "tunken",
    "tunkende": "tunkend",
    "tunkendem": "tunkend",
    "tunkenden": "tunkend",
    "tunkender": "tunkend",
    "tunkendes": "tunkend",
    "tunkest": "tunken",
    "tunket": "tunken",
    "tunkst": "tunken",
    "tunkt": "tunken",
    "tunkte": "tunken",
    "tunkten": "tunken",
    "tunktest": "tunken",
    "tunktet": "tunken",
    "tuntigem": "tuntig",
    "tuntigen": "tuntig",
    "tuntiger": "tuntig",
    "tuntigere": "tuntig",
    "tuntigerem": "tuntig",
    "tuntigeren": "tuntig",
    "tuntigerer": "tuntig",
    "tuntigeres": "tuntig",
    "tuntiges": "tuntig",
    "tuntigste": "tuntig",
    "tuntigstem": "tuntig",
    "tuntigsten": "tuntig",
    "tuntigster": "tuntig",
    "tuntigstes": "tuntig",
    "tupfe": "tupfen",
    "tupfend": "tupfen",
    "tupfende": "tupfend",
    "tupfendem": "tupfend",
    "tupfenden": "tupfend",
    "tupfender": "tupfend",
    "tupfendes": "tupfend",
    "tupfest": "tupfen",
    "tupfet": "tupfen",
    "tupfst": "tupfen",
    "tupft": "tupfen",
    "tupfte": "tupfen",
    "tupften": "tupfen",
    "tupftest": "tupfen",
    "tupftet": "tupfen",
    "turbulentem": "turbulent",
    "turbulenten": "turbulent",
    "turbulenter": "turbulent",
    "turbulentere": "turbulent",
    "turbulenterem": "turbulent",
    "turbulenteren": "turbulent",
    "turbulenterer": "turbulent",
    "turbulenteres": "turbulent",
    "turbulentes": "turbulent",
    "turbulenteste": "turbulent",
    "turbulentestem": "turbulent",
    "turbulentesten": "turbulent",
    "turbulentester": "turbulent",
    "turbulentestes": "turbulent",
    "turne": "turnen",
    "turnend": "turnen",
    "turnende": "turnend",
    "turnendem": "turnend",
    "turnenden": "turnend",
    "turnender": "turnend",
    "turnendes": "turnend",
    "turnest": "turnen",
    "turnet": "turnen",
    "turnst": "turnen",
    "turnt": "turnen",
    "turnte": "turnen",
    "turnten": "turnen",
    "turntest": "turnen",
    "turntet": "turnen",
    "turtele": "turteln",
    "turtelnd": "turteln",
    "turtelnde": "turtelnd",
    "turtelndem": "turtelnd",
    "turtelnden": "turtelnd",
    "turtelnder": "turtelnd",
    "turtelndere": "turtelnd",
    "turtelnderem": "turtelnd",
    "turtelnderen": "turtelnd",
    "turtelnderer": "turtelnd",
    "turtelnderes": "turtelnd",
    "turtelndes": "turtelnd",
    "turtelndste": "turtelnd",
    "turtelndstem": "turtelnd",
    "turtelndsten": "turtelnd",
    "turtelndster": "turtelnd",
    "turtelndstes": "turtelnd",
    "turtelst": "turteln",
    "turtelt": "turteln",
    "turtelte": "turteln",
    "turtelten": "turteln",
    "turteltest": "turteln",
    "turteltet": "turteln",
    "turtle": "turteln",
    "tuschele": "tuscheln",
    "tuschelnd": "tuscheln",
    "tuschelnde": "tuschelnd",
    "tuschelndem": "tuschelnd",
    "tuschelnden": "tuschelnd",
    "tuschelnder": "tuschelnd",
    "tuschelndere": "tuschelnd",
    "tuschelnderem": "tuschelnd",
    "tuschelnderen": "tuschelnd",
    "tuschelnderer": "tuschelnd",
    "tuschelnderes": "tuschelnd",
    "tuschelndes": "tuschelnd",
    "tuschelndste": "tuschelnd",
    "tuschelndstem": "tuschelnd",
    "tuschelndsten": "tuschelnd",
    "tuschelndster": "tuschelnd",
    "tuschelndstes": "tuschelnd",
    "tuschelst": "tuscheln",
    "tuschelt": "tuscheln",
    "tuschelte": "tuscheln",
    "tuschelten": "tuscheln",
    "tuscheltest": "tuscheln",
    "tuscheltet": "tuscheln",
    "tuschiere": "tuschieren",
    "tuschierend": "tuschieren",
    "tuschierende": "tuschierend",
    "tuschierendem": "tuschierend",
    "tuschierenden": "tuschierend",
    "tuschierender": "tuschierend",
    "tuschierendes": "tuschierend",
    "tuschierest": "tuschieren",
    "tuschieret": "tuschieren",
    "tuschierst": "tuschieren",
    "tuschiert": "tuschieren",
    "tuschierte": "tuschieren",
    "tuschiertem": "tuschiert",
    "tuschierten": "tuschieren",
    "tuschierter": "tuschiert",
    "tuschiertes": "tuschiert",
    "tuschiertest": "tuschieren",
    "tuschiertet": "tuschieren",
    "tuschle": "tuscheln",
    "tust": "tun",
    "tut": "tun",
    "tutend": "tuten",
    "tutende": "tutend",
    "tutendem": "tutend",
    "tutenden": "tutend",
    "tutender": "tutend",
    "tutendere": "tutend",
    "tutenderem": "tutend",
    "tutenderen": "tutend",
    "tutenderer": "tutend",
    "tutenderes": "tutend",
    "tutendes": "tutend",
    "tutendste": "tutend",
    "tutendstem": "tutend",
    "tutendsten": "tutend",
    "tutendster": "tutend",
    "tutendstes": "tutend",
    "tutest": "tuten",
    "tutet": "tuten",
    "tutete": "tuten",
    "tuteten": "tuten",
    "tutetest": "tuten",
    "tutetet": "tuten",
    "typischem": "typisch",
    "typischen": "typisch",
    "typischer": "typisch",
    "typischere": "typisch",
    "typischerem": "typisch",
    "typischeren": "typisch",
    "typischerer": "typisch",
    "typischeres": "typisch",
    "typisches": "typisch",
    "typischste": "typisch",
    "typischstem": "typisch",
    "typischsten": "typisch",
    "typischster": "typisch",
    "typischstes": "typisch",
    "typisiere": "typisieren",
    "typisierend": "typisieren",
    "typisierende": "typisierend",
    "typisierendem": "typisierend",
    "typisierenden": "typisierend",
    "typisierender": "typisierend",
    "typisierendes": "typisierend",
    "typisierest": "typisieren",
    "typisieret": "typisieren",
    "typisierst": "typisieren",
    "typisiert": "typisieren",
    "typisierte": "typisieren",
    "typisiertem": "typisiert",
    "typisierten": "typisieren",
    "typisierter": "typisiert",
    "typisiertes": "typisiert",
    "typisiertest": "typisieren",
    "typisiertet": "typisieren",
    "typographischem": "typographisch",
    "typographischen": "typographisch",
    "typographischer": "typographisch",
    "typographisches": "typographisch",
    "typologischem": "typologisch",
    "typologischen": "typologisch",
    "typologischer": "typologisch",
    "typologisches": "typologisch",
    "tyrannischem": "tyrannisch",
    "tyrannischen": "tyrannisch",
    "tyrannischer": "tyrannisch",
    "tyrannischere": "tyrannisch",
    "tyrannischerem": "tyrannisch",
    "tyrannischeren": "tyrannisch",
    "tyrannischerer": "tyrannisch",
    "tyrannischeres": "tyrannisch",
    "tyrannisches": "tyrannisch",
    "tyrannischste": "tyrannisch",
    "tyrannischstem": "tyrannisch",
    "tyrannischsten": "tyrannisch",
    "tyrannischster": "tyrannisch",
    "tyrannischstes": "tyrannisch",
    "tyrannisiere": "tyrannisieren",
    "tyrannisierend": "tyrannisieren",
    "tyrannisierende": "tyrannisierend",
    "tyrannisierendem": "tyrannisierend",
    "tyrannisierenden": "tyrannisierend",
    "tyrannisierender": "tyrannisierend",
    "tyrannisierendere": "tyrannisierend",
    "tyrannisierenderem": "tyrannisierend",
    "tyrannisierenderen": "tyrannisierend",
    "tyrannisierenderer": "tyrannisierend",
    "tyrannisierenderes": "tyrannisierend",
    "tyrannisierendes": "tyrannisierend",
    "tyrannisierendste": "tyrannisierend",
    "tyrannisierendstem": "tyrannisierend",
    "tyrannisierendsten": "tyrannisierend",
    "tyrannisierendster": "tyrannisierend",
    "tyrannisierendstes": "tyrannisierend",
    "tyrannisierest": "tyrannisieren",
    "tyrannisieret": "tyrannisieren",
    "tyrannisierst": "tyrannisieren",
    "tyrannisiert": "tyrannisieren",
    "tyrannisierte": "tyrannisieren",
    "tyrannisiertem": "tyrannisiert",
    "tyrannisierten": "tyrannisieren",
    "tyrannisierter": "tyrannisiert",
    "tyrannisiertere": "tyrannisiert",
    "tyrannisierterem": "tyrannisiert",
    "tyrannisierteren": "tyrannisiert",
    "tyrannisierterer": "tyrannisiert",
    "tyrannisierteres": "tyrannisiert",
    "tyrannisiertes": "tyrannisiert",
    "tyrannisiertest": "tyrannisieren",
    "tyrannisierteste": "tyrannisiert",
    "tyrannisiertestem": "tyrannisiert",
    "tyrannisiertesten": "tyrannisiert",
    "tyrannisiertester": "tyrannisiert",
    "tyrannisiertestes": "tyrannisiert",
    "tyrannisiertet": "tyrannisieren",
    "täfele": "täfeln",
    "täfelnd": "täfeln",
    "täfelnde": "täfelnd",
    "täfelndem": "täfelnd",
    "täfelnden": "täfelnd",
    "täfelnder": "täfelnd",
    "täfelndes": "täfelnd",
    "täfelst": "täfeln",
    "täfelt": "täfeln",
    "täfelte": "täfeln",
    "täfelten": "täfeln",
    "täfeltest": "täfeln",
    "täfeltet": "täfeln",
    "täfle": "täfeln",
    "täglichem": "täglich",
    "täglichen": "täglich",
    "täglicher": "täglich",
    "tägliches": "täglich",
    "tändele": "tändeln",
    "tändelnd": "tändeln",
    "tändelnde": "tändelnd",
    "tändelndem": "tändelnd",
    "tändelnden": "tändelnd",
    "tändelnder": "tändelnd",
    "tändelndere": "tändelnd",
    "tändelnderem": "tändelnd",
    "tändelnderen": "tändelnd",
    "tändelnderer": "tändelnd",
    "tändelnderes": "tändelnd",
    "tändelndes": "tändelnd",
    "tändelndste": "tändelnd",
    "tändelndstem": "tändelnd",
    "tändelndsten": "tändelnd",
    "tändelndster": "tändelnd",
    "tändelndstes": "tändelnd",
    "tändelst": "tändeln",
    "tändelt": "tändeln",
    "tändelte": "tändeln",
    "tändelten": "tändeln",
    "tändeltest": "tändeln",
    "tändeltet": "tändeln",
    "tändle": "tändeln",
    "tänzele": "tänzeln",
    "tänzelnd": "tänzeln",
    "tänzelnde": "tänzelnd",
    "tänzelndem": "tänzelnd",
    "tänzelnden": "tänzelnd",
    "tänzelnder": "tänzelnd",
    "tänzelndere": "tänzelnd",
    "tänzelnderem": "tänzelnd",
    "tänzelnderen": "tänzelnd",
    "tänzelnderer": "tänzelnd",
    "tänzelnderes": "tänzelnd",
    "tänzelndes": "tänzelnd",
    "tänzelndste": "tänzelnd",
    "tänzelndstem": "tänzelnd",
    "tänzelndsten": "tänzelnd",
    "tänzelndster": "tänzelnd",
    "tänzelndstes": "tänzelnd",
    "tänzelst": "tänzeln",
    "tänzelt": "tänzeln",
    "tänzelte": "tänzeln",
    "tänzelten": "tänzeln",
    "tänzeltest": "tänzeln",
    "tänzeltet": "tänzeln",
    "tänzerischem": "tänzerisch",
    "tänzerischen": "tänzerisch",
    "tänzerischer": "tänzerisch",
    "tänzerisches": "tänzerisch",
    "tänzle": "tänzeln",
    "täte": "tun",
    "täten": "tun",
    "tätest": "tun",
    "tätet": "tun",
    "tätig": "tätigen",
    "tätige": "tätig",
    "tätigem": "tätig",
    "tätigen": "tätig",
    "tätigend": "tätigen",
    "tätigende": "tätigend",
    "tätigendem": "tätigend",
    "tätigenden": "tätigend",
    "tätigender": "tätigend",
    "tätigendes": "tätigend",
    "tätiger": "tätig",
    "tätiges": "tätig",
    "tätigest": "tätigen",
    "tätiget": "tätigen",
    "tätigst": "tätigen",
    "tätigt": "tätigen",
    "tätigte": "tätigen",
    "tätigten": "tätigen",
    "tätigtest": "tätigen",
    "tätigtet": "tätigen",
    "tätliche": "tätlich",
    "tätlichem": "tätlich",
    "tätlichen": "tätlich",
    "tätlicher": "tätlich",
    "tätliches": "tätlich",
    "tätowiere": "tätowieren",
    "tätowierend": "tätowieren",
    "tätowierende": "tätowierend",
    "tätowierendem": "tätowierend",
    "tätowierenden": "tätowierend",
    "tätowierender": "tätowierend",
    "tätowierendere": "tätowierend",
    "tätowierenderem": "tätowierend",
    "tätowierenderen": "tätowierend",
    "tätowierenderer": "tätowierend",
    "tätowierenderes": "tätowierend",
    "tätowierendes": "tätowierend",
    "tätowierendste": "tätowierend",
    "tätowierendstem": "tätowierend",
    "tätowierendsten": "tätowierend",
    "tätowierendster": "tätowierend",
    "tätowierendstes": "tätowierend",
    "tätowierest": "tätowieren",
    "tätowieret": "tätowieren",
    "tätowierst": "tätowieren",
    "tätowiert": "tätowieren",
    "tätowierte": "tätowieren",
    "tätowiertem": "tätowiert",
    "tätowierten": "tätowieren",
    "tätowierter": "tätowiert",
    "tätowiertere": "tätowiert",
    "tätowierterem": "tätowiert",
    "tätowierteren": "tätowiert",
    "tätowierterer": "tätowiert",
    "tätowierteres": "tätowiert",
    "tätowiertes": "tätowiert",
    "tätowiertest": "tätowieren",
    "tätowierteste": "tätowiert",
    "tätowiertestem": "tätowiert",
    "tätowiertesten": "tätowiert",
    "tätowiertester": "tätowiert",
    "tätowiertestes": "tätowiert",
    "tätowiertet": "tätowieren",
    "tätschele": "tätscheln",
    "tätschelnd": "tätscheln",
    "tätschelnde": "tätschelnd",
    "tätschelndem": "tätschelnd",
    "tätschelnden": "tätschelnd",
    "tätschelnder": "tätschelnd",
    "tätschelndes": "tätschelnd",
    "tätschelst": "tätscheln",
    "tätschelt": "tätscheln",
    "tätschelte": "tätscheln",
    "tätschelten": "tätscheln",
    "tätscheltest": "tätscheln",
    "tätscheltet": "tätscheln",
    "tätschle": "tätscheln",
    "täusche": "täuschen",
    "täuschend": "täuschen",
    "täuschendem": "täuschend",
    "täuschender": "täuschend",
    "täuschendere": "täuschend",
    "täuschenderem": "täuschend",
    "täuschenderen": "täuschend",
    "täuschenderer": "täuschend",
    "täuschenderes": "täuschend",
    "täuschendes": "täuschend",
    "täuschendste": "täuschend",
    "täuschendstem": "täuschend",
    "täuschendsten": "täuschend",
    "täuschendster": "täuschend",
    "täuschendstes": "täuschend",
    "täuschest": "täuschen",
    "täuschet": "täuschen",
    "täuschst": "täuschen",
    "täuscht": "täuschen",
    "täuschte": "täuschen",
    "täuschten": "täuschen",
    "täuschtest": "täuschen",
    "täuschtet": "täuschen",
    "tödliche": "tödlich",
    "tödlichem": "tödlich",
    "tödlichen": "tödlich",
    "tödlicher": "tödlich",
    "tödlichere": "tödlich",
    "tödlicherem": "tödlich",
    "tödlicheren": "tödlich",
    "tödlicherer": "tödlich",
    "tödlicheres": "tödlich",
    "tödliches": "tödlich",
    "tödlichste": "tödlich",
    "tödlichstem": "tödlich",
    "tödlichsten": "tödlich",
    "tödlichster": "tödlich",
    "tödlichstes": "tödlich",
    "tölpelhafte": "tölpelhaft",
    "tölpelhaftem": "tölpelhaft",
    "tölpelhaften": "tölpelhaft",
    "tölpelhafter": "tölpelhaft",
    "tölpelhaftere": "tölpelhaft",
    "tölpelhafterem": "tölpelhaft",
    "tölpelhafteren": "tölpelhaft",
    "tölpelhafterer": "tölpelhaft",
    "tölpelhafteres": "tölpelhaft",
    "tölpelhaftes": "tölpelhaft",
    "tölpelhafteste": "tölpelhaft",
    "tölpelhaftestem": "tölpelhaft",
    "tölpelhaftesten": "tölpelhaft",
    "tölpelhaftester": "tölpelhaft",
    "tölpelhaftestes": "tölpelhaft",
    "tönend": "tönen",
    "tönende": "tönend",
    "tönendem": "tönend",
    "tönenden": "tönend",
    "tönender": "tönend",
    "tönendere": "tönend",
    "tönenderem": "tönend",
    "tönenderen": "tönend",
    "tönenderer": "tönend",
    "tönenderes": "tönend",
    "tönendes": "tönend",
    "tönendste": "tönend",
    "tönendstem": "tönend",
    "tönendsten": "tönend",
    "tönendster": "tönend",
    "tönendstes": "tönend",
    "tönernem": "tönern",
    "tönernen": "tönern",
    "tönerner": "tönern",
    "tönernes": "tönern",
    "tönest": "tönen",
    "tönet": "tönen",
    "tönst": "tönen",
    "tönt": "tönen",
    "tönte": "tönen",
    "tönten": "tönen",
    "töntest": "tönen",
    "töntet": "tönen",
    "töpfere": "töpfern",
    "töpfernd": "töpfern",
    "töpfernde": "töpfernd",
    "töpferndem": "töpfernd",
    "töpfernden": "töpfernd",
    "töpfernder": "töpfernd",
    "töpferndes": "töpfernd",
    "töpferst": "töpfern",
    "töpfert": "töpfern",
    "töpferte": "töpfern",
    "töpferten": "töpfern",
    "töpfertest": "töpfern",
    "töpfertet": "töpfern",
    "törichtem": "töricht",
    "törichten": "töricht",
    "törichter": "töricht",
    "törichtere": "töricht",
    "törichterem": "töricht",
    "törichteren": "töricht",
    "törichterer": "töricht",
    "törichteres": "töricht",
    "törichtes": "töricht",
    "törichteste": "töricht",
    "törichtestem": "töricht",
    "törichtesten": "töricht",
    "törichtester": "töricht",
    "törichtestes": "töricht",
    "törne": "törnen",
    "törnend": "törnen",
    "törnende": "törnend",
    "törnendem": "törnend",
    "törnenden": "törnend",
    "törnender": "törnend",
    "törnendes": "törnend",
    "törnest": "törnen",
    "törnet": "törnen",
    "törnst": "törnen",
    "törnt": "törnen",
    "törnte": "törnen",
    "törnten": "törnen",
    "törntest": "törnen",
    "törntet": "törnen",
    "töte": "töten",
    "tötend": "töten",
    "tötende": "tötend",
    "tötendem": "tötend",
    "tötenden": "tötend",
    "tötender": "tötend",
    "tötendere": "tötend",
    "tötenderem": "tötend",
    "tötenderen": "tötend",
    "tötenderer": "tötend",
    "tötenderes": "tötend",
    "tötendes": "tötend",
    "tötendste": "tötend",
    "tötendstem": "tötend",
    "tötendsten": "tötend",
    "tötendster": "tötend",
    "tötendstes": "tötend",
    "tötest": "töten",
    "tötet": "töten",
    "tötete": "töten",
    "töteten": "töten",
    "tötetest": "töten",
    "tötetet": "töten",
    "tüchtigem": "tüchtig",
    "tüchtigen": "tüchtig",
    "tüchtiger": "tüchtig",
    "tüchtigere": "tüchtig",
    "tüchtigerem": "tüchtig",
    "tüchtigeren": "tüchtig",
    "tüchtigerer": "tüchtig",
    "tüchtigeres": "tüchtig",
    "tüchtiges": "tüchtig",
    "tüchtigste": "tüchtig",
    "tüchtigstem": "tüchtig",
    "tüchtigsten": "tüchtig",
    "tüchtigster": "tüchtig",
    "tüchtigstes": "tüchtig",
    "tückische": "tückisch",
    "tückischem": "tückisch",
    "tückischen": "tückisch",
    "tückischer": "tückisch",
    "tückischere": "tückisch",
    "tückischerem": "tückisch",
    "tückischeren": "tückisch",
    "tückischerer": "tückisch",
    "tückischeres": "tückisch",
    "tückisches": "tückisch",
    "tückischste": "tückisch",
    "tückischstem": "tückisch",
    "tückischsten": "tückisch",
    "tückischster": "tückisch",
    "tückischstes": "tückisch",
    "tüdelige": "tüdelig",
    "tüdeligem": "tüdelig",
    "tüdeligen": "tüdelig",
    "tüdeliger": "tüdelig",
    "tüdeligere": "tüdelig",
    "tüdeligerem": "tüdelig",
    "tüdeligeren": "tüdelig",
    "tüdeligerer": "tüdelig",
    "tüdeligeres": "tüdelig",
    "tüdeliges": "tüdelig",
    "tüdeligste": "tüdelig",
    "tüdeligstem": "tüdelig",
    "tüdeligsten": "tüdelig",
    "tüdeligster": "tüdelig",
    "tüdeligstes": "tüdelig",
    "tüftele": "tüfteln",
    "tüfteligem": "tüftelig",
    "tüfteligen": "tüftelig",
    "tüfteliger": "tüftelig",
    "tüfteligere": "tüftelig",
    "tüfteligerem": "tüftelig",
    "tüfteligeren": "tüftelig",
    "tüfteligerer": "tüftelig",
    "tüfteligeres": "tüftelig",
    "tüfteliges": "tüftelig",
    "tüfteligste": "tüftelig",
    "tüfteligstem": "tüftelig",
    "tüfteligsten": "tüftelig",
    "tüfteligster": "tüftelig",
    "tüfteligstes": "tüftelig",
    "tüftelnd": "tüfteln",
    "tüftelnde": "tüftelnd",
    "tüftelndem": "tüftelnd",
    "tüftelnden": "tüftelnd",
    "tüftelnder": "tüftelnd",
    "tüftelndere": "tüftelnd",
    "tüftelnderem": "tüftelnd",
    "tüftelnderen": "tüftelnd",
    "tüftelnderer": "tüftelnd",
    "tüftelnderes": "tüftelnd",
    "tüftelndes": "tüftelnd",
    "tüftelndste": "tüftelnd",
    "tüftelndstem": "tüftelnd",
    "tüftelndsten": "tüftelnd",
    "tüftelndster": "tüftelnd",
    "tüftelndstes": "tüftelnd",
    "tüftelst": "tüfteln",
    "tüftelt": "tüfteln",
    "tüftelte": "tüfteln",
    "tüftelten": "tüfteln",
    "tüfteltest": "tüfteln",
    "tüfteltet": "tüfteln",
    "tüftle": "tüfteln",
    "tünchend": "tünchen",
    "tünchende": "tünchend",
    "tünchendem": "tünchend",
    "tünchenden": "tünchend",
    "tünchender": "tünchend",
    "tünchendere": "tünchend",
    "tünchenderem": "tünchend",
    "tünchenderen": "tünchend",
    "tünchenderer": "tünchend",
    "tünchenderes": "tünchend",
    "tünchendes": "tünchend",
    "tünchendste": "tünchend",
    "tünchendstem": "tünchend",
    "tünchendsten": "tünchend",
    "tünchendster": "tünchend",
    "tünchendstes": "tünchend",
    "tünchest": "tünchen",
    "tünchet": "tünchen",
    "tünchst": "tünchen",
    "tüncht": "tünchen",
    "tünchte": "tünchen",
    "tünchten": "tünchen",
    "tünchtest": "tünchen",
    "tünchtet": "tünchen",
    "türkend": "türken",
    "türkende": "türkend",
    "türkendem": "türkend",
    "türkenden": "türkend",
    "türkender": "türkend",
    "türkendere": "türkend",
    "türkenderem": "türkend",
    "türkenderen": "türkend",
    "türkenderer": "türkend",
    "türkenderes": "türkend",
    "türkendes": "türkend",
    "türkendste": "türkend",
    "türkendstem": "türkend",
    "türkendsten": "türkend",
    "türkendster": "türkend",
    "türkendstes": "türkend",
    "türkest": "türken",
    "türket": "türken",
    "türkische": "türkisch",
    "türkischem": "türkisch",
    "türkischen": "türkisch",
    "türkischer": "türkisch",
    "türkisches": "türkisch",
    "türkst": "türken",
    "türkt": "türken",
    "türkte": "türken",
    "türkten": "türken",
    "türktest": "türken",
    "türktet": "türken",
    "türmend": "türmen",
    "türmende": "türmend",
    "türmendem": "türmend",
    "türmenden": "türmend",
    "türmender": "türmend",
    "türmendere": "türmend",
    "türmenderem": "türmend",
    "türmenderen": "türmend",
    "türmenderer": "türmend",
    "türmenderes": "türmend",
    "türmendes": "türmend",
    "türmendste": "türmend",
    "türmendstem": "türmend",
    "türmendsten": "türmend",
    "türmendster": "türmend",
    "türmendstes": "türmend",
    "türmest": "türmen",
    "türmet": "türmen",
    "türmst": "türmen",
    "türmt": "türmen",
    "türmte": "türmen",
    "türmten": "türmen",
    "türmtest": "türmen",
    "türmtet": "türmen",
    "tüte": "tüten",
    "tütend": "tüten",
    "tütendem": "tütend",
    "tütender": "tütend",
    "tütendes": "tütend",
    "tütest": "tüten",
    "tütet": "tüten",
    "tütete": "tüten",
    "tüteten": "tüten",
    "tütetest": "tüten",
    "tütetet": "tüten",
    "ufere": "ufern",
    "uferlose": "uferlos",
    "uferlosem": "uferlos",
    "uferlosen": "uferlos",
    "uferloser": "uferlos",
    "uferloses": "uferlos",
    "ufernd": "ufern",
    "ufernde": "ufernd",
    "uferndem": "ufernd",
    "ufernden": "ufernd",
    "ufernder": "ufernd",
    "uferndes": "ufernd",
    "uferst": "ufern",
    "ufert": "ufern",
    "uferte": "ufern",
    "uferten": "ufern",
    "ufertest": "ufern",
    "ufertet": "ufern",
    "ukrainischem": "ukrainisch",
    "ukrainischen": "ukrainisch",
    "ukrainischer": "ukrainisch",
    "ukrainisches": "ukrainisch",
    "ulke": "ulken",
    "ulkend": "ulken",
    "ulkende": "ulkend",
    "ulkendem": "ulkend",
    "ulkenden": "ulkend",
    "ulkender": "ulkend",
    "ulkendere": "ulkend",
    "ulkenderem": "ulkend",
    "ulkenderen": "ulkend",
    "ulkenderer": "ulkend",
    "ulkenderes": "ulkend",
    "ulkendes": "ulkend",
    "ulkendste": "ulkend",
    "ulkendstem": "ulkend",
    "ulkendsten": "ulkend",
    "ulkendster": "ulkend",
    "ulkendstes": "ulkend",
    "ulkest": "ulken",
    "ulket": "ulken",
    "ulkige": "ulkig",
    "ulkigem": "ulkig",
    "ulkigen": "ulkig",
    "ulkiger": "ulkig",
    "ulkigere": "ulkig",
    "ulkigerem": "ulkig",
    "ulkigeren": "ulkig",
    "ulkigerer": "ulkig",
    "ulkigeres": "ulkig",
    "ulkiges": "ulkig",
    "ulkigste": "ulkig",
    "ulkigstem": "ulkig",
    "ulkigsten": "ulkig",
    "ulkigster": "ulkig",
    "ulkigstes": "ulkig",
    "ulkst": "ulken",
    "ulkt": "ulken",
    "ulkte": "ulken",
    "ulkten": "ulken",
    "ulktest": "ulken",
    "ulktet": "ulken",
    "ultimativem": "ultimativ",
    "ultimativen": "ultimativ",
    "ultimativer": "ultimativ",
    "ultimatives": "ultimativ",
    "umarbeite": "umarbeiten",
    "umarbeitend": "umarbeiten",
    "umarbeitende": "umarbeitend",
    "umarbeitendem": "umarbeitend",
    "umarbeitenden": "umarbeitend",
    "umarbeitender": "umarbeitend",
    "umarbeitendes": "umarbeitend",
    "umarbeitest": "umarbeiten",
    "umarbeitet": "umarbeiten",
    "umarbeitete": "umarbeiten",
    "umarbeiteten": "umarbeiten",
    "umarbeitetest": "umarbeiten",
    "umarbeitetet": "umarbeiten",
    "umarme": "umarmen",
    "umarmend": "umarmen",
    "umarmende": "umarmend",
    "umarmendem": "umarmend",
    "umarmenden": "umarmend",
    "umarmender": "umarmend",
    "umarmendes": "umarmend",
    "umarmest": "umarmen",
    "umarmet": "umarmen",
    "umarmst": "umarmen",
    "umarmt": "umarmen",
    "umarmte": "umarmen",
    "umarmtem": "umarmt",
    "umarmten": "umarmen",
    "umarmter": "umarmt",
    "umarmtes": "umarmt",
    "umarmtest": "umarmen",
    "umarmtet": "umarmen",
    "umband": "umbinden",
    "umbanden": "umbinden",
    "umbandest": "umbinden",
    "umbandet": "umbinden",
    "umbaue": "umbauen",
    "umbauend": "umbauen",
    "umbauende": "umbauend",
    "umbauendem": "umbauend",
    "umbauenden": "umbauend",
    "umbauender": "umbauend",
    "umbauendes": "umbauend",
    "umbauest": "umbauen",
    "umbauet": "umbauen",
    "umbaust": "umbauen",
    "umbaut": "umbauen",
    "umbaute": "umbauen",
    "umbautest": "umbauen",
    "umbautet": "umbauen",
    "umbehalte": "umbehalten",
    "umbehaltend": "umbehalten",
    "umbehaltende": "umbehaltend",
    "umbehaltendem": "umbehaltend",
    "umbehaltenden": "umbehaltend",
    "umbehaltender": "umbehaltend",
    "umbehaltendes": "umbehaltend",
    "umbehaltene": "umbehalten",
    "umbehaltenem": "umbehalten",
    "umbehaltenen": "umbehalten",
    "umbehaltener": "umbehalten",
    "umbehaltenes": "umbehalten",
    "umbehaltest": "umbehalten",
    "umbehaltet": "umbehalten",
    "umbehielt": "umbehalten",
    "umbehielte": "umbehalten",
    "umbehielten": "umbehalten",
    "umbehieltest": "umbehalten",
    "umbehieltet": "umbehalten",
    "umbehält": "umbehalten",
    "umbehältst": "umbehalten",
    "umbesetze": "umbesetzen",
    "umbesetzend": "umbesetzen",
    "umbesetzende": "umbesetzend",
    "umbesetzendem": "umbesetzend",
    "umbesetzenden": "umbesetzend",
    "umbesetzender": "umbesetzend",
    "umbesetzendes": "umbesetzend",
    "umbesetzest": "umbesetzen",
    "umbesetzet": "umbesetzen",
    "umbesetzt": "umbesetzen",
    "umbesetzte": "umbesetzen",
    "umbesetztem": "umbesetzt",
    "umbesetzten": "umbesetzen",
    "umbesetzter": "umbesetzt",
    "umbesetztes": "umbesetzt",
    "umbesetztest": "umbesetzen",
    "umbesetztet": "umbesetzen",
    "umbette": "umbetten",
    "umbettend": "umbetten",
    "umbettende": "umbettend",
    "umbettendem": "umbettend",
    "umbettenden": "umbettend",
    "umbettender": "umbettend",
    "umbettendes": "umbettend",
    "umbettest": "umbetten",
    "umbettet": "umbetten",
    "umbettete": "umbetten",
    "umbetteten": "umbetten",
    "umbettetest": "umbetten",
    "umbettetet": "umbetten",
    "umbiege": "umbiegen",
    "umbiegend": "umbiegen",
    "umbiegende": "umbiegend",
    "umbiegendem": "umbiegend",
    "umbiegenden": "umbiegend",
    "umbiegender": "umbiegend",
    "umbiegendes": "umbiegend",
    "umbiegest": "umbiegen",
    "umbieget": "umbiegen",
    "umbiegst": "umbiegen",
    "umbiegt": "umbiegen",
    "umbilde": "umbilden",
    "umbildend": "umbilden",
    "umbildende": "umbildend",
    "umbildendem": "umbildend",
    "umbildenden": "umbildend",
    "umbildender": "umbildend",
    "umbildendes": "umbildend",
    "umbildest": "umbilden",
    "umbildet": "umbilden",
    "umbildete": "umbilden",
    "umbildeten": "umbilden",
    "umbildetest": "umbilden",
    "umbildetet": "umbilden",
    "umbinde": "umbinden",
    "umbindend": "umbinden",
    "umbindende": "umbindend",
    "umbindendem": "umbindend",
    "umbindenden": "umbindend",
    "umbindender": "umbindend",
    "umbindendes": "umbindend",
    "umbindest": "umbinden",
    "umbindet": "umbinden",
    "umblase": "umblasen",
    "umblasend": "umblasen",
    "umblasende": "umblasend",
    "umblasendem": "umblasend",
    "umblasenden": "umblasend",
    "umblasender": "umblasend",
    "umblasendes": "umblasend",
    "umblasest": "umblasen",
    "umblaset": "umblasen",
    "umblast": "umblasen",
    "umblies": "umblasen",
    "umbliese": "umblasen",
    "umbliesen": "umblasen",
    "umbliesest": "umblasen",
    "umblieset": "umblasen",
    "umbliest": "umblasen",
    "umbläst": "umblasen",
    "umblättere": "umblättern",
    "umblätternd": "umblättern",
    "umblätternde": "umblätternd",
    "umblätterndem": "umblätternd",
    "umblätternden": "umblätternd",
    "umblätternder": "umblätternd",
    "umblätterndes": "umblätternd",
    "umblätterst": "umblättern",
    "umblättert": "umblättern",
    "umblätterte": "umblättern",
    "umblätterten": "umblättern",
    "umblättertest": "umblättern",
    "umblättertet": "umblättern",
    "umbog": "umbiegen",
    "umbogen": "umbiegen",
    "umbogst": "umbiegen",
    "umbogt": "umbiegen",
    "umbrach": "umbrechen",
    "umbrachen": "umbrechen",
    "umbrachst": "umbrechen",
    "umbracht": "umbrechen",
    "umbrachte": "umbringen",
    "umbrachten": "umbringen",
    "umbrachtest": "umbringen",
    "umbrachtet": "umbringen",
    "umbreche": "umbrechen",
    "umbrechend": "umbrechen",
    "umbrechende": "umbrechend",
    "umbrechendem": "umbrechend",
    "umbrechenden": "umbrechend",
    "umbrechender": "umbrechend",
    "umbrechendes": "umbrechend",
    "umbrechest": "umbrechen",
    "umbrechet": "umbrechen",
    "umbrecht": "umbrechen",
    "umbrichst": "umbrechen",
    "umbricht": "umbrechen",
    "umbringe": "umbringen",
    "umbringend": "umbringen",
    "umbringende": "umbringend",
    "umbringendem": "umbringend",
    "umbringenden": "umbringend",
    "umbringender": "umbringend",
    "umbringendes": "umbringend",
    "umbringest": "umbringen",
    "umbringet": "umbringen",
    "umbringst": "umbringen",
    "umbringt": "umbringen",
    "umbräche": "umbrechen",
    "umbrächen": "umbrechen",
    "umbrächest": "umbrechen",
    "umbrächet": "umbrechen",
    "umbrächte": "umbringen",
    "umbrächten": "umbringen",
    "umbrächtest": "umbringen",
    "umbrächtet": "umbringen",
    "umbuche": "umbuchen",
    "umbuchend": "umbuchen",
    "umbuchende": "umbuchend",
    "umbuchendem": "umbuchend",
    "umbuchenden": "umbuchend",
    "umbuchender": "umbuchend",
    "umbuchendes": "umbuchend",
    "umbuchest": "umbuchen",
    "umbuchet": "umbuchen",
    "umbuchst": "umbuchen",
    "umbucht": "umbuchen",
    "umbuchte": "umbuchen",
    "umbuchten": "umbuchen",
    "umbuchtest": "umbuchen",
    "umbuchtet": "umbuchen",
    "umbände": "umbinden",
    "umbänden": "umbinden",
    "umbändest": "umbinden",
    "umbändet": "umbinden",
    "umböge": "umbiegen",
    "umbögen": "umbiegen",
    "umbögest": "umbiegen",
    "umböget": "umbiegen",
    "umdachte": "umdenken",
    "umdachten": "umdenken",
    "umdachtest": "umdenken",
    "umdachtet": "umdenken",
    "umdenke": "umdenken",
    "umdenkend": "umdenken",
    "umdenkende": "umdenkend",
    "umdenkendem": "umdenkend",
    "umdenkenden": "umdenkend",
    "umdenkender": "umdenkend",
    "umdenkendes": "umdenkend",
    "umdenkest": "umdenken",
    "umdenket": "umdenken",
    "umdenkst": "umdenken",
    "umdenkt": "umdenken",
    "umdeute": "umdeuten",
    "umdeutend": "umdeuten",
    "umdeutende": "umdeutend",
    "umdeutendem": "umdeutend",
    "umdeutenden": "umdeutend",
    "umdeutender": "umdeutend",
    "umdeutendes": "umdeutend",
    "umdeutest": "umdeuten",
    "umdeutet": "umdeuten",
    "umdeutete": "umdeuten",
    "umdeuteten": "umdeuten",
    "umdeutetest": "umdeuten",
    "umdeutetet": "umdeuten",
    "umdichte": "umdichten",
    "umdichtend": "umdichten",
    "umdichtende": "umdichtend",
    "umdichtendem": "umdichtend",
    "umdichtenden": "umdichtend",
    "umdichtender": "umdichtend",
    "umdichtendes": "umdichtend",
    "umdichtest": "umdichten",
    "umdichtet": "umdichten",
    "umdichtete": "umdichten",
    "umdichteten": "umdichten",
    "umdichtetest": "umdichten",
    "umdichtetet": "umdichten",
    "umdisponiere": "umdisponieren",
    "umdisponierend": "umdisponieren",
    "umdisponierende": "umdisponierend",
    "umdisponierendem": "umdisponierend",
    "umdisponierenden": "umdisponierend",
    "umdisponierender": "umdisponierend",
    "umdisponierendes": "umdisponierend",
    "umdisponierest": "umdisponieren",
    "umdisponieret": "umdisponieren",
    "umdisponierst": "umdisponieren",
    "umdisponiert": "umdisponieren",
    "umdisponierte": "umdisponieren",
    "umdisponiertem": "umdisponiert",
    "umdisponierten": "umdisponieren",
    "umdisponierter": "umdisponiert",
    "umdisponiertes": "umdisponiert",
    "umdisponiertest": "umdisponieren",
    "umdisponiertet": "umdisponieren",
    "umdrehe": "umdrehen",
    "umdrehend": "umdrehen",
    "umdrehende": "umdrehend",
    "umdrehendem": "umdrehend",
    "umdrehenden": "umdrehend",
    "umdrehender": "umdrehend",
    "umdrehendes": "umdrehend",
    "umdrehest": "umdrehen",
    "umdrehet": "umdrehen",
    "umdrehst": "umdrehen",
    "umdreht": "umdrehen",
    "umdrehte": "umdrehen",
    "umdrehten": "umdrehen",
    "umdrehtest": "umdrehen",
    "umdrehtet": "umdrehen",
    "umdächte": "umdenken",
    "umdächten": "umdenken",
    "umdächtest": "umdenken",
    "umdächtet": "umdenken",
    "umerziehe": "umerziehen",
    "umerziehend": "umerziehen",
    "umerziehende": "umerziehend",
    "umerziehendem": "umerziehend",
    "umerziehenden": "umerziehend",
    "umerziehender": "umerziehend",
    "umerziehendes": "umerziehend",
    "umerziehest": "umerziehen",
    "umerziehet": "umerziehen",
    "umerziehst": "umerziehen",
    "umerzieht": "umerziehen",
    "umerzog": "umerziehen",
    "umerzogen": "umerziehen",
    "umerzogene": "umerzogen",
    "umerzogenem": "umerzogen",
    "umerzogenen": "umerzogen",
    "umerzogener": "umerzogen",
    "umerzogenes": "umerzogen",
    "umerzogst": "umerziehen",
    "umerzogt": "umerziehen",
    "umerzöge": "umerziehen",
    "umerzögen": "umerziehen",
    "umerzögest": "umerziehen",
    "umerzöget": "umerziehen",
    "umfahre": "umfahren",
    "umfahrend": "umfahren",
    "umfahrende": "umfahrend",
    "umfahrendem": "umfahrend",
    "umfahrenden": "umfahrend",
    "umfahrender": "umfahrend",
    "umfahrendes": "umfahrend",
    "umfahrene": "umfahren",
    "umfahrenem": "umfahren",
    "umfahrenen": "umfahren",
    "umfahrener": "umfahren",
    "umfahrenes": "umfahren",
    "umfahrest": "umfahren",
    "umfahret": "umfahren",
    "umfahrt": "umfahren",
    "umfalle": "umfallen",
    "umfallend": "umfallen",
    "umfallende": "umfallend",
    "umfallendem": "umfallend",
    "umfallenden": "umfallend",
    "umfallender": "umfallend",
    "umfallendes": "umfallend",
    "umfallest": "umfallen",
    "umfallet": "umfallen",
    "umfallt": "umfallen",
    "umfangreichem": "umfangreich",
    "umfangreichen": "umfangreich",
    "umfangreicher": "umfangreich",
    "umfangreichere": "umfangreich",
    "umfangreicherem": "umfangreich",
    "umfangreicheren": "umfangreich",
    "umfangreicherer": "umfangreich",
    "umfangreicheres": "umfangreich",
    "umfangreiches": "umfangreich",
    "umfangreichste": "umfangreich",
    "umfangreichstem": "umfangreich",
    "umfangreichsten": "umfangreich",
    "umfangreichster": "umfangreich",
    "umfangreichstes": "umfangreich",
    "umfasse": "umfassen",
    "umfassend": "umfassen",
    "umfassende": "umfassend",
    "umfassendem": "umfassend",
    "umfassenden": "umfassend",
    "umfassender": "umfassend",
    "umfassendere": "umfassend",
    "umfassenderem": "umfassend",
    "umfassenderen": "umfassend",
    "umfassenderer": "umfassend",
    "umfassenderes": "umfassend",
    "umfassendes": "umfassend",
    "umfassendste": "umfassend",
    "umfassendstem": "umfassend",
    "umfassendsten": "umfassend",
    "umfassendster": "umfassend",
    "umfassendstes": "umfassend",
    "umfassest": "umfassen",
    "umfasset": "umfassen",
    "umfaßt": "umfassen",
    "umfaßte": "umfassen",
    "umfaßtem": "umfaßt",
    "umfaßten": "umfassen",
    "umfaßter": "umfaßt",
    "umfaßtes": "umfaßt",
    "umfaßtest": "umfassen",
    "umfaßtet": "umfassen",
    "umfiel": "umfallen",
    "umfiele": "umfallen",
    "umfielen": "umfallen",
    "umfielest": "umfallen",
    "umfielet": "umfallen",
    "umfielst": "umfallen",
    "umfielt": "umfallen",
    "umfliege": "umfliegen",
    "umfliegend": "umfliegen",
    "umfliegende": "umfliegend",
    "umfliegendem": "umfliegend",
    "umfliegenden": "umfliegend",
    "umfliegender": "umfliegend",
    "umfliegendes": "umfliegend",
    "umfliegest": "umfliegen",
    "umflieget": "umfliegen",
    "umfliegst": "umfliegen",
    "umfliegt": "umfliegen",
    "umfließe": "umfließen",
    "umfließend": "umfließen",
    "umfließende": "umfließend",
    "umfließendem": "umfließend",
    "umfließenden": "umfließend",
    "umfließender": "umfließend",
    "umfließendes": "umfließend",
    "umfließest": "umfließen",
    "umfließet": "umfließen",
    "umfließt": "umfließen",
    "umflog": "umfliegen",
    "umflogen": "umfliegen",
    "umflogene": "umflogen",
    "umflogenem": "umflogen",
    "umflogenen": "umflogen",
    "umflogener": "umflogen",
    "umflogenes": "umflogen",
    "umflogst": "umfliegen",
    "umflogt": "umfliegen",
    "umflossen": "umfließen",
    "umflossene": "umflossen",
    "umflossenem": "umflossen",
    "umflossenen": "umflossen",
    "umflossener": "umflossen",
    "umflossenes": "umflossen",
    "umfloß": "umfließen",
    "umfloßt": "umfließen",
    "umflöge": "umfliegen",
    "umflögen": "umfliegen",
    "umflögest": "umfliegen",
    "umflöget": "umfliegen",
    "umflöße": "umfließen",
    "umflößen": "umfließen",
    "umflößest": "umfließen",
    "umflößet": "umfließen",
    "umforme": "umformen",
    "umformend": "umformen",
    "umformende": "umformend",
    "umformendem": "umformend",
    "umformenden": "umformend",
    "umformender": "umformend",
    "umformendes": "umformend",
    "umformest": "umformen",
    "umformet": "umformen",
    "umformst": "umformen",
    "umformt": "umformen",
    "umformte": "umformen",
    "umformten": "umformen",
    "umformtest": "umformen",
    "umformtet": "umformen",
    "umfragend": "umfragen",
    "umfragende": "umfragend",
    "umfragendem": "umfragend",
    "umfragenden": "umfragend",
    "umfragender": "umfragend",
    "umfragendes": "umfragend",
    "umfragest": "umfragen",
    "umfraget": "umfragen",
    "umfragst": "umfragen",
    "umfragt": "umfragen",
    "umfragte": "umfragen",
    "umfragten": "umfragen",
    "umfragtest": "umfragen",
    "umfragtet": "umfragen",
    "umfuhr": "umfahren",
    "umfuhren": "umfahren",
    "umfuhrst": "umfahren",
    "umfuhrt": "umfahren",
    "umfunktioniere": "umfunktionieren",
    "umfunktionierend": "umfunktionieren",
    "umfunktionierende": "umfunktionierend",
    "umfunktionierendem": "umfunktionierend",
    "umfunktionierenden": "umfunktionierend",
    "umfunktionierender": "umfunktionierend",
    "umfunktionierendes": "umfunktionierend",
    "umfunktionierest": "umfunktionieren",
    "umfunktionieret": "umfunktionieren",
    "umfunktionierst": "umfunktionieren",
    "umfunktioniert": "umfunktionieren",
    "umfunktionierte": "umfunktionieren",
    "umfunktioniertem": "umfunktioniert",
    "umfunktionierten": "umfunktionieren",
    "umfunktionierter": "umfunktioniert",
    "umfunktioniertes": "umfunktioniert",
    "umfunktioniertest": "umfunktionieren",
    "umfunktioniertet": "umfunktionieren",
    "umfährst": "umfahren",
    "umfährt": "umfahren",
    "umfällst": "umfallen",
    "umfällt": "umfallen",
    "umfärbe": "umfärben",
    "umfärbend": "umfärben",
    "umfärbende": "umfärbend",
    "umfärbendem": "umfärbend",
    "umfärbenden": "umfärbend",
    "umfärbender": "umfärbend",
    "umfärbendes": "umfärbend",
    "umfärbest": "umfärben",
    "umfärbet": "umfärben",
    "umfärbst": "umfärben",
    "umfärbt": "umfärben",
    "umfärbte": "umfärben",
    "umfärbten": "umfärben",
    "umfärbtest": "umfärben",
    "umfärbtet": "umfärben",
    "umführe": "umfahren",
    "umführen": "umfahren",
    "umführest": "umfahren",
    "umführet": "umfahren",
    "umfülle": "umfüllen",
    "umfüllend": "umfüllen",
    "umfüllende": "umfüllend",
    "umfüllendem": "umfüllend",
    "umfüllenden": "umfüllend",
    "umfüllender": "umfüllend",
    "umfüllendes": "umfüllend",
    "umfüllest": "umfüllen",
    "umfüllet": "umfüllen",
    "umfüllst": "umfüllen",
    "umfüllt": "umfüllen",
    "umfüllte": "umfüllen",
    "umfüllten": "umfüllen",
    "umfülltest": "umfüllen",
    "umfülltet": "umfüllen",
    "umgab": "umgeben",
    "umgaben": "umgeben",
    "umgabst": "umgeben",
    "umgabt": "umgeben",
    "umgangssprachlichem": "umgangssprachlich",
    "umgangssprachlichen": "umgangssprachlich",
    "umgangssprachlicher": "umgangssprachlich",
    "umgangssprachliches": "umgangssprachlich",
    "umgarne": "umgarnen",
    "umgarnend": "umgarnen",
    "umgarnende": "umgarnend",
    "umgarnendem": "umgarnend",
    "umgarnenden": "umgarnend",
    "umgarnender": "umgarnend",
    "umgarnendere": "umgarnend",
    "umgarnenderem": "umgarnend",
    "umgarnenderen": "umgarnend",
    "umgarnenderer": "umgarnend",
    "umgarnenderes": "umgarnend",
    "umgarnendes": "umgarnend",
    "umgarnendste": "umgarnend",
    "umgarnendstem": "umgarnend",
    "umgarnendsten": "umgarnend",
    "umgarnendster": "umgarnend",
    "umgarnendstes": "umgarnend",
    "umgarnest": "umgarnen",
    "umgarnet": "umgarnen",
    "umgarnst": "umgarnen",
    "umgarnt": "umgarnen",
    "umgarnte": "umgarnen",
    "umgarntem": "umgarnt",
    "umgarnten": "umgarnen",
    "umgarnter": "umgarnt",
    "umgarntere": "umgarnt",
    "umgarnterem": "umgarnt",
    "umgarnteren": "umgarnt",
    "umgarnterer": "umgarnt",
    "umgarnteres": "umgarnt",
    "umgarntes": "umgarnt",
    "umgarntest": "umgarnen",
    "umgarnteste": "umgarnt",
    "umgarntestem": "umgarnt",
    "umgarntesten": "umgarnt",
    "umgarntester": "umgarnt",
    "umgarntestes": "umgarnt",
    "umgarntet": "umgarnen",
    "umgearbeitet": "umarbeiten",
    "umgearbeitete": "umgearbeitet",
    "umgearbeitetem": "umgearbeitet",
    "umgearbeiteten": "umgearbeitet",
    "umgearbeiteter": "umgearbeitet",
    "umgearbeitetes": "umgearbeitet",
    "umgebaut": "umbauen",
    "umgebaute": "umgebaut",
    "umgebautem": "umgebaut",
    "umgebauten": "umgebaut",
    "umgebauter": "umgebaut",
    "umgebautes": "umgebaut",
    "umgebe": "umgeben",
    "umgebend": "umgeben",
    "umgebende": "umgebend",
    "umgebendem": "umgebend",
    "umgebenden": "umgebend",
    "umgebender": "umgebend",
    "umgebendes": "umgebend",
    "umgebene": "umgeben",
    "umgebenem": "umgeben",
    "umgebenen": "umgeben",
    "umgebener": "umgeben",
    "umgebenes": "umgeben",
    "umgebest": "umgeben",
    "umgebet": "umgeben",
    "umgebettet": "umbetten",
    "umgebettete": "umgebettet",
    "umgebettetem": "umgebettet",
    "umgebetteten": "umgebettet",
    "umgebetteter": "umgebettet",
    "umgebettetes": "umgebettet",
    "umgebildet": "umbilden",
    "umgebildete": "umgebildet",
    "umgebildetem": "umgebildet",
    "umgebildeten": "umgebildet",
    "umgebildeter": "umgebildet",
    "umgebildetes": "umgebildet",
    "umgeblasen": "umblasen",
    "umgeblasene": "umgeblasen",
    "umgeblasenem": "umgeblasen",
    "umgeblasenen": "umgeblasen",
    "umgeblasener": "umgeblasen",
    "umgeblasenes": "umgeblasen",
    "umgeblättert": "umblättern",
    "umgeblätterte": "umgeblättert",
    "umgeblättertem": "umgeblättert",
    "umgeblätterten": "umgeblättert",
    "umgeblätterter": "umgeblättert",
    "umgeblättertes": "umgeblättert",
    "umgebogen": "umbiegen",
    "umgebogene": "umgebogen",
    "umgebogenem": "umgebogen",
    "umgebogenen": "umgebogen",
    "umgebogener": "umgebogen",
    "umgebogenere": "umgebogen",
    "umgebogenerem": "umgebogen",
    "umgebogeneren": "umgebogen",
    "umgebogenerer": "umgebogen",
    "umgebogeneres": "umgebogen",
    "umgebogenes": "umgebogen",
    "umgebogenste": "umgebogen",
    "umgebogenstem": "umgebogen",
    "umgebogensten": "umgebogen",
    "umgebogenster": "umgebogen",
    "umgebogenstes": "umgebogen",
    "umgebracht": "umbringen",
    "umgebrachte": "umgebracht",
    "umgebrachtem": "umgebracht",
    "umgebrachten": "umgebracht",
    "umgebrachter": "umgebracht",
    "umgebrachtes": "umgebracht",
    "umgebrochen": "umbrechen",
    "umgebrochene": "umgebrochen",
    "umgebrochenem": "umgebrochen",
    "umgebrochenen": "umgebrochen",
    "umgebrochener": "umgebrochen",
    "umgebrochenes": "umgebrochen",
    "umgebt": "umgeben",
    "umgebucht": "umbuchen",
    "umgebuchte": "umgebucht",
    "umgebuchtem": "umgebucht",
    "umgebuchten": "umgebucht",
    "umgebuchter": "umgebucht",
    "umgebuchtes": "umgebucht",
    "umgebunden": "umbinden",
    "umgebundene": "umgebunden",
    "umgebundenem": "umgebunden",
    "umgebundenen": "umgebunden",
    "umgebundener": "umgebunden",
    "umgebundenes": "umgebunden",
    "umgedacht": "umdenken",
    "umgedachte": "umgedacht",
    "umgedachtem": "umgedacht",
    "umgedachten": "umgedacht",
    "umgedachter": "umgedacht",
    "umgedachtes": "umgedacht",
    "umgedeutet": "umdeuten",
    "umgedeutete": "umgedeutet",
    "umgedeutetem": "umgedeutet",
    "umgedeuteten": "umgedeutet",
    "umgedeuteter": "umgedeutet",
    "umgedeutetes": "umgedeutet",
    "umgedichtet": "umdichten",
    "umgedichtete": "umgedichtet",
    "umgedichtetem": "umgedichtet",
    "umgedichteten": "umgedichtet",
    "umgedichteter": "umgedichtet",
    "umgedichtetes": "umgedichtet",
    "umgedreht": "umdrehen",
    "umgedrehte": "umgedreht",
    "umgedrehtem": "umgedreht",
    "umgedrehten": "umgedreht",
    "umgedrehter": "umgedreht",
    "umgedrehtes": "umgedreht",
    "umgefahren": "umfahren",
    "umgefahrene": "umgefahren",
    "umgefahrenem": "umgefahren",
    "umgefahrenen": "umgefahren",
    "umgefahrener": "umgefahren",
    "umgefahrenes": "umgefahren",
    "umgefallen": "umfallen",
    "umgefallene": "umgefallen",
    "umgefallenem": "umgefallen",
    "umgefallenen": "umgefallen",
    "umgefallener": "umgefallen",
    "umgefallenes": "umgefallen",
    "umgeflogen": "umfliegen",
    "umgeflogene": "umgeflogen",
    "umgeflogenem": "umgeflogen",
    "umgeflogenen": "umgeflogen",
    "umgeflogener": "umgeflogen",
    "umgeflogenes": "umgeflogen",
    "umgeformt": "umformen",
    "umgeformte": "umgeformt",
    "umgeformtem": "umgeformt",
    "umgeformten": "umgeformt",
    "umgeformter": "umgeformt",
    "umgeformtes": "umgeformt",
    "umgefragt": "umfragen",
    "umgefragte": "umgefragt",
    "umgefragtem": "umgefragt",
    "umgefragten": "umgefragt",
    "umgefragter": "umgefragt",
    "umgefragtes": "umgefragt",
    "umgefärbt": "umfärben",
    "umgefärbte": "umgefärbt",
    "umgefärbtem": "umgefärbt",
    "umgefärbten": "umgefärbt",
    "umgefärbter": "umgefärbt",
    "umgefärbtes": "umgefärbt",
    "umgefüllt": "umfüllen",
    "umgefüllte": "umgefüllt",
    "umgefülltem": "umgefüllt",
    "umgefüllten": "umgefüllt",
    "umgefüllter": "umgefüllt",
    "umgefülltes": "umgefüllt",
    "umgegangen": "umgehen",
    "umgegangene": "umgegangen",
    "umgegangenem": "umgegangen",
    "umgegangenen": "umgegangen",
    "umgegangener": "umgegangen",
    "umgegangenes": "umgegangen",
    "umgegossen": "umgießen",
    "umgegossene": "umgegossen",
    "umgegossenem": "umgegossen",
    "umgegossenen": "umgegossen",
    "umgegossener": "umgegossen",
    "umgegossenes": "umgegossen",
    "umgegraben": "umgraben",
    "umgegrabene": "umgegraben",
    "umgegrabenem": "umgegraben",
    "umgegrabenen": "umgegraben",
    "umgegrabener": "umgegraben",
    "umgegrabenes": "umgegraben",
    "umgegrätscht": "umgrätschen",
    "umgegrätschte": "umgegrätscht",
    "umgegrätschtem": "umgegrätscht",
    "umgegrätschten": "umgegrätscht",
    "umgegrätschter": "umgegrätscht",
    "umgegrätschtere": "umgegrätscht",
    "umgegrätschterem": "umgegrätscht",
    "umgegrätschteren": "umgegrätscht",
    "umgegrätschterer": "umgegrätscht",
    "umgegrätschteres": "umgegrätscht",
    "umgegrätschtes": "umgegrätscht",
    "umgegrätschteste": "umgegrätscht",
    "umgegrätschtestem": "umgegrätscht",
    "umgegrätschtesten": "umgegrätscht",
    "umgegrätschtester": "umgegrätscht",
    "umgegrätschtestes": "umgegrätscht",
    "umgehangen": "umhängen",
    "umgehangene": "umgehangen",
    "umgehangenem": "umgehangen",
    "umgehangenen": "umgehangen",
    "umgehangener": "umgehangen",
    "umgehangenes": "umgehangen",
    "umgehauen": "umhauen",
    "umgehauene": "umgehauen",
    "umgehauenem": "umgehauen",
    "umgehauenen": "umgehauen",
    "umgehauener": "umgehauen",
    "umgehauenes": "umgehauen",
    "umgehe": "umgehen",
    "umgehend": "umgehen",
    "umgehende": "umgehend",
    "umgehendem": "umgehend",
    "umgehenden": "umgehend",
    "umgehender": "umgehend",
    "umgehendes": "umgehend",
    "umgehest": "umgehen",
    "umgehet": "umgehen",
    "umgehst": "umgehen",
    "umgeht": "umgehen",
    "umgehängt": "umhängen",
    "umgehängte": "umgehängt",
    "umgehängtem": "umgehängt",
    "umgehängten": "umgehängt",
    "umgehängter": "umgehängt",
    "umgehängtes": "umgehängt",
    "umgehört": "umhören",
    "umgehörte": "umgehört",
    "umgehörtem": "umgehört",
    "umgehörten": "umgehört",
    "umgehörter": "umgehört",
    "umgehörtes": "umgehört",
    "umgekehrt": "umkehren",
    "umgekehrte": "umgekehrt",
    "umgekehrtem": "umgekehrt",
    "umgekehrten": "umgekehrt",
    "umgekehrter": "umgekehrt",
    "umgekehrtes": "umgekehrt",
    "umgekippt": "umkippen",
    "umgekippte": "umgekippt",
    "umgekipptem": "umgekippt",
    "umgekippten": "umgekippt",
    "umgekippter": "umgekippt",
    "umgekipptes": "umgekippt",
    "umgeklappt": "umklappen",
    "umgeklappte": "umgeklappt",
    "umgeklapptem": "umgeklappt",
    "umgeklappten": "umgeklappt",
    "umgeklappter": "umgeklappt",
    "umgeklapptes": "umgeklappt",
    "umgekleidet": "umkleiden",
    "umgekleidete": "umgekleidet",
    "umgekleidetem": "umgekleidet",
    "umgekleideten": "umgekleidet",
    "umgekleideter": "umgekleidet",
    "umgekleidetes": "umgekleidet",
    "umgeknickt": "umknicken",
    "umgeknickte": "umgeknickt",
    "umgeknicktem": "umgeknickt",
    "umgeknickten": "umgeknickt",
    "umgeknickter": "umgeknickt",
    "umgeknicktes": "umgeknickt",
    "umgekommen": "umkommen",
    "umgekommene": "umgekommen",
    "umgekommenem": "umgekommen",
    "umgekommenen": "umgekommen",
    "umgekommener": "umgekommen",
    "umgekommenes": "umgekommen",
    "umgekreist": "umkreisen",
    "umgekreiste": "umgekreist",
    "umgekreistem": "umgekreist",
    "umgekreisten": "umgekreist",
    "umgekreister": "umgekreist",
    "umgekreistes": "umgekreist",
    "umgekrempelt": "umkrempeln",
    "umgekrempelte": "umgekrempelt",
    "umgekrempeltem": "umgekrempelt",
    "umgekrempelten": "umgekrempelt",
    "umgekrempelter": "umgekrempelt",
    "umgekrempeltere": "umgekrempelt",
    "umgekrempelterem": "umgekrempelt",
    "umgekrempelteren": "umgekrempelt",
    "umgekrempelterer": "umgekrempelt",
    "umgekrempelteres": "umgekrempelt",
    "umgekrempeltes": "umgekrempelt",
    "umgekrempelteste": "umgekrempelt",
    "umgekrempeltestem": "umgekrempelt",
    "umgekrempeltesten": "umgekrempelt",
    "umgekrempeltester": "umgekrempelt",
    "umgekrempeltestes": "umgekrempelt",
    "umgeladen": "umladen",
    "umgeladene": "umgeladen",
    "umgeladenem": "umgeladen",
    "umgeladenen": "umgeladen",
    "umgeladener": "umgeladen",
    "umgeladenes": "umgeladen",
    "umgelagert": "umlagern",
    "umgelagerte": "umgelagert",
    "umgelagertem": "umgelagert",
    "umgelagerten": "umgelagert",
    "umgelagerter": "umgelagert",
    "umgelagertes": "umgelagert",
    "umgelaufen": "umlaufen",
    "umgelaufene": "umgelaufen",
    "umgelaufenem": "umgelaufen",
    "umgelaufenen": "umgelaufen",
    "umgelaufener": "umgelaufen",
    "umgelaufenes": "umgelaufen",
    "umgelautet": "umlauten",
    "umgelautete": "umgelautet",
    "umgelautetem": "umgelautet",
    "umgelauteten": "umgelautet",
    "umgelauteter": "umgelautet",
    "umgelautetes": "umgelautet",
    "umgelegt": "umlegen",
    "umgelegte": "umgelegt",
    "umgelegtem": "umgelegt",
    "umgelegten": "umgelegt",
    "umgelegter": "umgelegt",
    "umgelegtes": "umgelegt",
    "umgeleitet": "umleiten",
    "umgeleitete": "umgeleitet",
    "umgeleitetem": "umgeleitet",
    "umgeleiteten": "umgeleitet",
    "umgeleiteter": "umgeleitet",
    "umgeleitetes": "umgeleitet",
    "umgelenkt": "umlenken",
    "umgelenkte": "umgelenkt",
    "umgelenktem": "umgelenkt",
    "umgelenkten": "umgelenkt",
    "umgelenkter": "umgelenkt",
    "umgelenktes": "umgelenkt",
    "umgelernt": "umlernen",
    "umgelernte": "umgelernt",
    "umgelerntem": "umgelernt",
    "umgelernten": "umgelernt",
    "umgelernter": "umgelernt",
    "umgelerntes": "umgelernt",
    "umgemeldet": "ummelden",
    "umgemeldete": "umgemeldet",
    "umgemeldetem": "umgemeldet",
    "umgemeldeten": "umgemeldet",
    "umgemeldeter": "umgemeldet",
    "umgemeldetes": "umgemeldet",
    "umgemodelt": "ummodeln",
    "umgemodelte": "umgemodelt",
    "umgemodeltem": "umgemodelt",
    "umgemodelten": "umgemodelt",
    "umgemodelter": "umgemodelt",
    "umgemodeltere": "umgemodelt",
    "umgemodelterem": "umgemodelt",
    "umgemodelteren": "umgemodelt",
    "umgemodelterer": "umgemodelt",
    "umgemodelteres": "umgemodelt",
    "umgemodeltes": "umgemodelt",
    "umgemodelteste": "umgemodelt",
    "umgemodeltestem": "umgemodelt",
    "umgemodeltesten": "umgemodelt",
    "umgemodeltester": "umgemodelt",
    "umgemodeltestes": "umgemodelt",
    "umgenäht": "umnähen",
    "umgenähte": "umgenäht",
    "umgenähtem": "umgenäht",
    "umgenähten": "umgenäht",
    "umgenähter": "umgenäht",
    "umgenähtes": "umgenäht",
    "umgepflanzt": "umpflanzen",
    "umgepflanzte": "umgepflanzt",
    "umgepflanztem": "umgepflanzt",
    "umgepflanzten": "umgepflanzt",
    "umgepflanzter": "umgepflanzt",
    "umgepflanztes": "umgepflanzt",
    "umgepflügt": "umpflügen",
    "umgepflügte": "umgepflügt",
    "umgepflügtem": "umgepflügt",
    "umgepflügten": "umgepflügt",
    "umgepflügter": "umgepflügt",
    "umgepflügtes": "umgepflügt",
    "umgepolt": "umpolen",
    "umgepolte": "umgepolt",
    "umgepoltem": "umgepolt",
    "umgepolten": "umgepolt",
    "umgepolter": "umgepolt",
    "umgepoltes": "umgepolt",
    "umgerannt": "umrennen",
    "umgerannte": "umgerannt",
    "umgeranntem": "umgerannt",
    "umgerannten": "umgerannt",
    "umgerannter": "umgerannt",
    "umgeranntes": "umgerannt",
    "umgerechnet": "umrechnen",
    "umgerechnete": "umgerechnet",
    "umgerechnetem": "umgerechnet",
    "umgerechneten": "umgerechnet",
    "umgerechneter": "umgerechnet",
    "umgerechnetes": "umgerechnet",
    "umgerissen": "umreißen",
    "umgerissene": "umgerissen",
    "umgerissenem": "umgerissen",
    "umgerissenen": "umgerissen",
    "umgerissener": "umgerissen",
    "umgerissenes": "umgerissen",
    "umgeritten": "umreiten",
    "umgerittene": "umgeritten",
    "umgerittenem": "umgeritten",
    "umgerittenen": "umgeritten",
    "umgerittener": "umgeritten",
    "umgerittenes": "umgeritten",
    "umgeräumt": "umräumen",
    "umgeräumte": "umgeräumt",
    "umgeräumtem": "umgeräumt",
    "umgeräumten": "umgeräumt",
    "umgeräumter": "umgeräumt",
    "umgeräumtes": "umgeräumt",
    "umgerührt": "umrühren",
    "umgerührte": "umgerührt",
    "umgerührtem": "umgerührt",
    "umgerührten": "umgerührt",
    "umgerührter": "umgerührt",
    "umgerührtes": "umgerührt",
    "umgerüstet": "umrüsten",
    "umgerüstete": "umgerüstet",
    "umgerüstetem": "umgerüstet",
    "umgerüsteten": "umgerüstet",
    "umgerüsteter": "umgerüstet",
    "umgerüstetes": "umgerüstet",
    "umgesattelt": "umsatteln",
    "umgesattelte": "umgesattelt",
    "umgesatteltem": "umgesattelt",
    "umgesattelten": "umgesattelt",
    "umgesattelter": "umgesattelt",
    "umgesatteltes": "umgesattelt",
    "umgeschaltet": "umschalten",
    "umgeschaltete": "umgeschaltet",
    "umgeschaltetem": "umgeschaltet",
    "umgeschalteten": "umgeschaltet",
    "umgeschalteter": "umgeschaltet",
    "umgeschaltetes": "umgeschaltet",
    "umgeschaut": "umschauen",
    "umgeschaute": "umgeschaut",
    "umgeschautem": "umgeschaut",
    "umgeschauten": "umgeschaut",
    "umgeschauter": "umgeschaut",
    "umgeschautes": "umgeschaut",
    "umgeschichtet": "umschichten",
    "umgeschichtete": "umgeschichtet",
    "umgeschichtetem": "umgeschichtet",
    "umgeschichteten": "umgeschichtet",
    "umgeschichteter": "umgeschichtet",
    "umgeschichtetes": "umgeschichtet",
    "umgeschlagen": "umschlagen",
    "umgeschlagene": "umgeschlagen",
    "umgeschlagenem": "umgeschlagen",
    "umgeschlagenen": "umgeschlagen",
    "umgeschlagener": "umgeschlagen",
    "umgeschlagenes": "umgeschlagen",
    "umgeschmissen": "umschmeißen",
    "umgeschmissene": "umgeschmissen",
    "umgeschmissenem": "umgeschmissen",
    "umgeschmissenen": "umgeschmissen",
    "umgeschmissener": "umgeschmissen",
    "umgeschmissenes": "umgeschmissen",
    "umgeschnallt": "umschnallen",
    "umgeschnallte": "umgeschnallt",
    "umgeschnalltem": "umgeschnallt",
    "umgeschnallten": "umgeschnallt",
    "umgeschnallter": "umgeschnallt",
    "umgeschnalltes": "umgeschnallt",
    "umgeschrieben": "umschreiben",
    "umgeschriebene": "umgeschrieben",
    "umgeschriebenem": "umgeschrieben",
    "umgeschriebenen": "umgeschrieben",
    "umgeschriebener": "umgeschrieben",
    "umgeschriebenes": "umgeschrieben",
    "umgeschuldet": "umschulden",
    "umgeschuldete": "umgeschuldet",
    "umgeschuldetem": "umgeschuldet",
    "umgeschuldeten": "umgeschuldet",
    "umgeschuldeter": "umgeschuldet",
    "umgeschuldetes": "umgeschuldet",
    "umgeschult": "umschulen",
    "umgeschulte": "umgeschult",
    "umgeschultem": "umgeschult",
    "umgeschulten": "umgeschult",
    "umgeschulter": "umgeschult",
    "umgeschultes": "umgeschult",
    "umgeschwenkt": "umschwenken",
    "umgeschwenkte": "umgeschwenkt",
    "umgeschwenktem": "umgeschwenkt",
    "umgeschwenkten": "umgeschwenkt",
    "umgeschwenkter": "umgeschwenkt",
    "umgeschwenktes": "umgeschwenkt",
    "umgeschüttet": "umschütten",
    "umgeschüttete": "umgeschüttet",
    "umgeschüttetem": "umgeschüttet",
    "umgeschütteten": "umgeschüttet",
    "umgeschütteter": "umgeschüttet",
    "umgeschüttetes": "umgeschüttet",
    "umgesehen": "umsehen",
    "umgesehene": "umgesehen",
    "umgesehenem": "umgesehen",
    "umgesehenen": "umgesehen",
    "umgesehener": "umgesehen",
    "umgesehenes": "umgesehen",
    "umgesetzt": "umsetzen",
    "umgesetzte": "umgesetzt",
    "umgesetztem": "umgesetzt",
    "umgesetzten": "umgesetzt",
    "umgesetzter": "umgesetzt",
    "umgesetztes": "umgesetzt",
    "umgesiedelt": "umsiedeln",
    "umgesiedelte": "umgesiedelt",
    "umgesiedeltem": "umgesiedelt",
    "umgesiedelten": "umgesiedelt",
    "umgesiedelter": "umgesiedelt",
    "umgesiedeltes": "umgesiedelt",
    "umgespannt": "umspannen",
    "umgespannte": "umgespannt",
    "umgespanntem": "umgespannt",
    "umgespannten": "umgespannt",
    "umgespannter": "umgespannt",
    "umgespanntes": "umgespannt",
    "umgesprungen": "umspringen",
    "umgesprungene": "umgesprungen",
    "umgesprungenem": "umgesprungen",
    "umgesprungenen": "umgesprungen",
    "umgesprungener": "umgesprungen",
    "umgesprungenes": "umgesprungen",
    "umgespult": "umspulen",
    "umgespulte": "umgespult",
    "umgespultem": "umgespult",
    "umgespulten": "umgespult",
    "umgespulter": "umgespult",
    "umgespultes": "umgespult",
    "umgestalte": "umgestalten",
    "umgestaltend": "umgestalten",
    "umgestaltende": "umgestaltend",
    "umgestaltendem": "umgestaltend",
    "umgestaltenden": "umgestaltend",
    "umgestaltender": "umgestaltend",
    "umgestaltendes": "umgestaltend",
    "umgestaltest": "umgestalten",
    "umgestaltet": "umgestalten",
    "umgestaltete": "umgestalten",
    "umgestaltetem": "umgestaltet",
    "umgestalteten": "umgestalten",
    "umgestalteter": "umgestaltet",
    "umgestaltetes": "umgestaltet",
    "umgestaltetest": "umgestalten",
    "umgestaltetet": "umgestalten",
    "umgestellt": "umstellen",
    "umgestellte": "umgestellt",
    "umgestelltem": "umgestellt",
    "umgestellten": "umgestellt",
    "umgestellter": "umgestellt",
    "umgestelltes": "umgestellt",
    "umgestiegen": "umsteigen",
    "umgestiegene": "umgestiegen",
    "umgestiegenem": "umgestiegen",
    "umgestiegenen": "umgestiegen",
    "umgestiegener": "umgestiegen",
    "umgestiegenes": "umgestiegen",
    "umgestimmt": "umstimmen",
    "umgestimmte": "umgestimmt",
    "umgestimmtem": "umgestimmt",
    "umgestimmten": "umgestimmt",
    "umgestimmter": "umgestimmt",
    "umgestimmtes": "umgestimmt",
    "umgestochen": "umstechen",
    "umgestochene": "umgestochen",
    "umgestochenem": "umgestochen",
    "umgestochenen": "umgestochen",
    "umgestochener": "umgestochen",
    "umgestochenes": "umgestochen",
    "umgestoßen": "umstoßen",
    "umgestoßene": "umgestoßen",
    "umgestoßenem": "umgestoßen",
    "umgestoßenen": "umgestoßen",
    "umgestoßener": "umgestoßen",
    "umgestoßenes": "umgestoßen",
    "umgestülpt": "umstülpen",
    "umgestülpte": "umgestülpt",
    "umgestülptem": "umgestülpt",
    "umgestülpten": "umgestülpt",
    "umgestülpter": "umgestülpt",
    "umgestülptes": "umgestülpt",
    "umgestürzt": "umstürzen",
    "umgestürzte": "umgestürzt",
    "umgestürztem": "umgestürzt",
    "umgestürzten": "umgestürzt",
    "umgestürzter": "umgestürzt",
    "umgestürztes": "umgestürzt",
    "umgesunken": "umsinken",
    "umgesunkene": "umgesunken",
    "umgesunkenem": "umgesunken",
    "umgesunkenen": "umgesunken",
    "umgesunkener": "umgesunken",
    "umgesunkenes": "umgesunken",
    "umgesäumt": "umsäumen",
    "umgesäumte": "umgesäumt",
    "umgesäumtem": "umgesäumt",
    "umgesäumten": "umgesäumt",
    "umgesäumter": "umgesäumt",
    "umgesäumtes": "umgesäumt",
    "umgetankte": "umgetankt",
    "umgetanktem": "umgetankt",
    "umgetankten": "umgetankt",
    "umgetankter": "umgetankt",
    "umgetanktes": "umgetankt",
    "umgetauft": "umtaufen",
    "umgetaufte": "umgetauft",
    "umgetauftem": "umgetauft",
    "umgetauften": "umgetauft",
    "umgetaufter": "umgetauft",
    "umgetauftes": "umgetauft",
    "umgetauscht": "umtauschen",
    "umgetauschte": "umgetauscht",
    "umgetauschtem": "umgetauscht",
    "umgetauschten": "umgetauscht",
    "umgetauschter": "umgetauscht",
    "umgetauschtes": "umgetauscht",
    "umgetopft": "umtopfen",
    "umgetopfte": "umgetopft",
    "umgetopftem": "umgetopft",
    "umgetopften": "umgetopft",
    "umgetopfter": "umgetopft",
    "umgetopftes": "umgetopft",
    "umgetrieben": "umtreiben",
    "umgetriebene": "umgetrieben",
    "umgetriebenem": "umgetrieben",
    "umgetriebenen": "umgetrieben",
    "umgetriebener": "umgetrieben",
    "umgetriebenes": "umgetrieben",
    "umgewandelt": "umwandeln",
    "umgewandelte": "umgewandelt",
    "umgewandeltem": "umgewandelt",
    "umgewandelten": "umgewandelt",
    "umgewandelter": "umgewandelt",
    "umgewandeltere": "umgewandelt",
    "umgewandelterem": "umgewandelt",
    "umgewandelteren": "umgewandelt",
    "umgewandelterer": "umgewandelt",
    "umgewandelteres": "umgewandelt",
    "umgewandeltes": "umgewandelt",
    "umgewandelteste": "umgewandelt",
    "umgewandeltestem": "umgewandelt",
    "umgewandeltesten": "umgewandelt",
    "umgewandeltester": "umgewandelt",
    "umgewandeltestes": "umgewandelt",
    "umgewandt": "umwenden",
    "umgewandte": "umgewandt",
    "umgewandtem": "umgewandt",
    "umgewandten": "umgewandt",
    "umgewandter": "umgewandt",
    "umgewandtes": "umgewandt",
    "umgewendet": "umwenden",
    "umgewendete": "umgewendet",
    "umgewendetem": "umgewendet",
    "umgewendeten": "umgewendet",
    "umgewendeter": "umgewendet",
    "umgewendetes": "umgewendet",
    "umgewertet": "umwerten",
    "umgewertete": "umgewertet",
    "umgewertetem": "umgewertet",
    "umgewerteten": "umgewertet",
    "umgewerteter": "umgewertet",
    "umgewertetes": "umgewertet",
    "umgeworfen": "umwerfen",
    "umgeworfene": "umgeworfen",
    "umgeworfenem": "umgeworfen",
    "umgeworfenen": "umgeworfen",
    "umgeworfener": "umgeworfen",
    "umgeworfenes": "umgeworfen",
    "umgewälzt": "umwälzen",
    "umgewälzte": "umgewälzt",
    "umgewälztem": "umgewälzt",
    "umgewälzten": "umgewälzt",
    "umgewälzter": "umgewälzt",
    "umgewälztere": "umgewälzt",
    "umgewälzterem": "umgewälzt",
    "umgewälzteren": "umgewälzt",
    "umgewälzterer": "umgewälzt",
    "umgewälzteres": "umgewälzt",
    "umgewälztes": "umgewälzt",
    "umgewälzteste": "umgewälzt",
    "umgewälztestem": "umgewälzt",
    "umgewälztesten": "umgewälzt",
    "umgewälztester": "umgewälzt",
    "umgewälztestes": "umgewälzt",
    "umgewühlt": "umwühlen",
    "umgewühlte": "umgewühlt",
    "umgewühltem": "umgewühlt",
    "umgewühlten": "umgewühlt",
    "umgewühlter": "umgewühlt",
    "umgewühltes": "umgewühlt",
    "umgezeichnet": "umzeichnen",
    "umgezeichnete": "umgezeichnet",
    "umgezeichnetem": "umgezeichnet",
    "umgezeichneten": "umgezeichnet",
    "umgezeichneter": "umgezeichnet",
    "umgezeichnetes": "umgezeichnet",
    "umgezogen": "umziehen",
    "umgezogene": "umgezogen",
    "umgezogenem": "umgezogen",
    "umgezogenen": "umgezogen",
    "umgezogener": "umgezogen",
    "umgezogenes": "umgezogen",
    "umgeändert": "umändern",
    "umgeänderte": "umgeändert",
    "umgeändertem": "umgeändert",
    "umgeänderten": "umgeändert",
    "umgeänderter": "umgeändert",
    "umgeändertere": "umgeändert",
    "umgeänderterem": "umgeändert",
    "umgeänderteren": "umgeändert",
    "umgeänderterer": "umgeändert",
    "umgeänderteres": "umgeändert",
    "umgeändertes": "umgeändert",
    "umgeänderteste": "umgeändert",
    "umgeändertestem": "umgeändert",
    "umgeändertesten": "umgeändert",
    "umgeändertester": "umgeändert",
    "umgeändertestes": "umgeändert",
    "umgib": "umgeben",
    "umgibst": "umgeben",
    "umgibt": "umgeben",
    "umgieße": "umgießen",
    "umgießend": "umgießen",
    "umgießende": "umgießend",
    "umgießendem": "umgießend",
    "umgießenden": "umgießend",
    "umgießender": "umgießend",
    "umgießendes": "umgießend",
    "umgießest": "umgießen",
    "umgießet": "umgießen",
    "umgießt": "umgießen",
    "umging": "umgehen",
    "umginge": "umgehen",
    "umgingen": "umgehen",
    "umgingest": "umgehen",
    "umginget": "umgehen",
    "umgingst": "umgehen",
    "umgingt": "umgehen",
    "umgossen": "umgießen",
    "umgoß": "umgießen",
    "umgoßt": "umgießen",
    "umgrabe": "umgraben",
    "umgrabend": "umgraben",
    "umgrabende": "umgrabend",
    "umgrabendem": "umgrabend",
    "umgrabenden": "umgrabend",
    "umgrabender": "umgrabend",
    "umgrabendes": "umgrabend",
    "umgrabest": "umgraben",
    "umgrabet": "umgraben",
    "umgrabt": "umgraben",
    "umgrub": "umgraben",
    "umgruben": "umgraben",
    "umgrubst": "umgraben",
    "umgrubt": "umgraben",
    "umgruppiere": "umgruppieren",
    "umgruppierend": "umgruppieren",
    "umgruppierende": "umgruppierend",
    "umgruppierendem": "umgruppierend",
    "umgruppierenden": "umgruppierend",
    "umgruppierender": "umgruppierend",
    "umgruppierendes": "umgruppierend",
    "umgruppierest": "umgruppieren",
    "umgruppieret": "umgruppieren",
    "umgruppierst": "umgruppieren",
    "umgruppiert": "umgruppieren",
    "umgruppierte": "umgruppieren",
    "umgruppiertem": "umgruppiert",
    "umgruppierten": "umgruppieren",
    "umgruppierter": "umgruppiert",
    "umgruppiertes": "umgruppiert",
    "umgruppiertest": "umgruppieren",
    "umgruppiertet": "umgruppieren",
    "umgräbst": "umgraben",
    "umgräbt": "umgraben",
    "umgrätsche": "umgrätschen",
    "umgrätschend": "umgrätschen",
    "umgrätschende": "umgrätschend",
    "umgrätschendem": "umgrätschend",
    "umgrätschenden": "umgrätschend",
    "umgrätschender": "umgrätschend",
    "umgrätschendere": "umgrätschend",
    "umgrätschenderem": "umgrätschend",
    "umgrätschenderen": "umgrätschend",
    "umgrätschenderer": "umgrätschend",
    "umgrätschenderes": "umgrätschend",
    "umgrätschendes": "umgrätschend",
    "umgrätschendste": "umgrätschend",
    "umgrätschendstem": "umgrätschend",
    "umgrätschendsten": "umgrätschend",
    "umgrätschendster": "umgrätschend",
    "umgrätschendstes": "umgrätschend",
    "umgrätschest": "umgrätschen",
    "umgrätschet": "umgrätschen",
    "umgrätschst": "umgrätschen",
    "umgrätscht": "umgrätschen",
    "umgrätschte": "umgrätschen",
    "umgrätschten": "umgrätschen",
    "umgrätschtest": "umgrätschen",
    "umgrätschtet": "umgrätschen",
    "umgrübe": "umgraben",
    "umgrüben": "umgraben",
    "umgrübest": "umgraben",
    "umgrübet": "umgraben",
    "umgäbe": "umgeben",
    "umgäben": "umgeben",
    "umgäbest": "umgeben",
    "umgäbet": "umgeben",
    "umgänglichem": "umgänglich",
    "umgänglichen": "umgänglich",
    "umgänglicher": "umgänglich",
    "umgänglichere": "umgänglich",
    "umgänglicherem": "umgänglich",
    "umgänglicheren": "umgänglich",
    "umgänglicherer": "umgänglich",
    "umgänglicheres": "umgänglich",
    "umgängliches": "umgänglich",
    "umgänglichste": "umgänglich",
    "umgänglichstem": "umgänglich",
    "umgänglichsten": "umgänglich",
    "umgänglichster": "umgänglich",
    "umgänglichstes": "umgänglich",
    "umgösse": "umgießen",
    "umgössen": "umgießen",
    "umgössest": "umgießen",
    "umgösset": "umgießen",
    "umhaue": "umhauen",
    "umhauend": "umhauen",
    "umhauende": "umhauend",
    "umhauendem": "umhauend",
    "umhauenden": "umhauend",
    "umhauender": "umhauend",
    "umhauendes": "umhauend",
    "umhauest": "umhauen",
    "umhauet": "umhauen",
    "umhaust": "umhauen",
    "umhaut": "umhauen",
    "umhaute": "umhauen",
    "umhauten": "umhauen",
    "umhautest": "umhauen",
    "umhautet": "umhauen",
    "umherfahre": "umherfahren",
    "umherfahrend": "umherfahren",
    "umherfahrende": "umherfahrend",
    "umherfahrendem": "umherfahrend",
    "umherfahrenden": "umherfahrend",
    "umherfahrender": "umherfahrend",
    "umherfahrendere": "umherfahrend",
    "umherfahrenderem": "umherfahrend",
    "umherfahrenderen": "umherfahrend",
    "umherfahrenderer": "umherfahrend",
    "umherfahrenderes": "umherfahrend",
    "umherfahrendes": "umherfahrend",
    "umherfahrendste": "umherfahrend",
    "umherfahrendstem": "umherfahrend",
    "umherfahrendsten": "umherfahrend",
    "umherfahrendster": "umherfahrend",
    "umherfahrendstes": "umherfahrend",
    "umherfahrest": "umherfahren",
    "umherfahret": "umherfahren",
    "umherfahrt": "umherfahren",
    "umherflattere": "umherflattern",
    "umherflatternd": "umherflattern",
    "umherflatternde": "umherflatternd",
    "umherflatterndem": "umherflatternd",
    "umherflatternden": "umherflatternd",
    "umherflatternder": "umherflatternd",
    "umherflatterndes": "umherflatternd",
    "umherflatterst": "umherflattern",
    "umherflattert": "umherflattern",
    "umherflatterte": "umherflattern",
    "umherflatterten": "umherflattern",
    "umherflattertest": "umherflattern",
    "umherflattertet": "umherflattern",
    "umherfliege": "umherfliegen",
    "umherfliegend": "umherfliegen",
    "umherfliegende": "umherfliegend",
    "umherfliegendem": "umherfliegend",
    "umherfliegenden": "umherfliegend",
    "umherfliegender": "umherfliegend",
    "umherfliegendes": "umherfliegend",
    "umherfliegest": "umherfliegen",
    "umherflieget": "umherfliegen",
    "umherfliegst": "umherfliegen",
    "umherfliegt": "umherfliegen",
    "umherflog": "umherfliegen",
    "umherflogen": "umherfliegen",
    "umherflogst": "umherfliegen",
    "umherflogt": "umherfliegen",
    "umherflöge": "umherfliegen",
    "umherflögen": "umherfliegen",
    "umherflögest": "umherfliegen",
    "umherflöget": "umherfliegen",
    "umherfuhr": "umherfahren",
    "umherfuhren": "umherfahren",
    "umherfuhrst": "umherfahren",
    "umherfuhrt": "umherfahren",
    "umherfährst": "umherfahren",
    "umherfährt": "umherfahren",
    "umherführe": "umherfahren",
    "umherführen": "umherfahren",
    "umherführest": "umherfahren",
    "umherführet": "umherfahren",
    "umhergefahren": "umherfahren",
    "umhergefahrene": "umhergefahren",
    "umhergefahrenem": "umhergefahren",
    "umhergefahrenen": "umhergefahren",
    "umhergefahrener": "umhergefahren",
    "umhergefahrenes": "umhergefahren",
    "umhergeflattert": "umherflattern",
    "umhergeflatterte": "umhergeflattert",
    "umhergeflattertem": "umhergeflattert",
    "umhergeflatterten": "umhergeflattert",
    "umhergeflatterter": "umhergeflattert",
    "umhergeflattertes": "umhergeflattert",
    "umhergeflogen": "umherfliegen",
    "umhergeflogene": "umhergeflogen",
    "umhergeflogenem": "umhergeflogen",
    "umhergeflogenen": "umhergeflogen",
    "umhergeflogener": "umhergeflogen",
    "umhergeflogenes": "umhergeflogen",
    "umhergeirrt": "umherirren",
    "umhergeirrte": "umhergeirrt",
    "umhergeirrtem": "umhergeirrt",
    "umhergeirrten": "umhergeirrt",
    "umhergeirrter": "umhergeirrt",
    "umhergeirrtere": "umhergeirrt",
    "umhergeirrterem": "umhergeirrt",
    "umhergeirrteren": "umhergeirrt",
    "umhergeirrterer": "umhergeirrt",
    "umhergeirrteres": "umhergeirrt",
    "umhergeirrtes": "umhergeirrt",
    "umhergeirrteste": "umhergeirrt",
    "umhergeirrtestem": "umhergeirrt",
    "umhergeirrtesten": "umhergeirrt",
    "umhergeirrtester": "umhergeirrt",
    "umhergeirrtestes": "umhergeirrt",
    "umhergejagt": "umherjagen",
    "umhergejagte": "umhergejagt",
    "umhergejagtem": "umhergejagt",
    "umhergejagten": "umhergejagt",
    "umhergejagter": "umhergejagt",
    "umhergejagtes": "umhergejagt",
    "umhergekrochen": "umherkriechen",
    "umhergekrochene": "umhergekrochen",
    "umhergekrochenem": "umhergekrochen",
    "umhergekrochenen": "umhergekrochen",
    "umhergekrochener": "umhergekrochen",
    "umhergekrochenes": "umhergekrochen",
    "umhergereist": "umherreisen",
    "umhergereiste": "umhergereist",
    "umhergereistem": "umhergereist",
    "umhergereisten": "umhergereist",
    "umhergereister": "umhergereist",
    "umhergereistes": "umhergereist",
    "umhergeritten": "umherreiten",
    "umhergerittene": "umhergeritten",
    "umhergerittenem": "umhergeritten",
    "umhergerittenen": "umhergeritten",
    "umhergerittener": "umhergeritten",
    "umhergerittenes": "umhergeritten",
    "umhergeschaut": "umherschauen",
    "umhergeschaute": "umhergeschaut",
    "umhergeschautem": "umhergeschaut",
    "umhergeschauten": "umhergeschaut",
    "umhergeschauter": "umhergeschaut",
    "umhergeschautes": "umhergeschaut",
    "umhergeschlendert": "umherschlendern",
    "umhergeschlenderte": "umhergeschlendert",
    "umhergeschlendertem": "umhergeschlendert",
    "umhergeschlenderten": "umhergeschlendert",
    "umhergeschlenderter": "umhergeschlendert",
    "umhergeschlendertes": "umhergeschlendert",
    "umhergeschlichen": "umherschleichen",
    "umhergeschlichene": "umhergeschlichen",
    "umhergeschlichenem": "umhergeschlichen",
    "umhergeschlichenen": "umhergeschlichen",
    "umhergeschlichener": "umhergeschlichen",
    "umhergeschlichenes": "umhergeschlichen",
    "umhergestreift": "umherstreifen",
    "umhergestreifte": "umhergestreift",
    "umhergestreiftem": "umhergestreift",
    "umhergestreiften": "umhergestreift",
    "umhergestreifter": "umhergestreift",
    "umhergestreiftere": "umhergestreift",
    "umhergestreifterem": "umhergestreift",
    "umhergestreifteren": "umhergestreift",
    "umhergestreifterer": "umhergestreift",
    "umhergestreifteres": "umhergestreift",
    "umhergestreiftes": "umhergestreift",
    "umhergestreifteste": "umhergestreift",
    "umhergestreiftestem": "umhergestreift",
    "umhergestreiftesten": "umhergestreift",
    "umhergestreiftester": "umhergestreift",
    "umhergestreiftestes": "umhergestreift",
    "umhergetappt": "umhertappen",
    "umhergetappte": "umhergetappt",
    "umhergetapptem": "umhergetappt",
    "umhergetappten": "umhergetappt",
    "umhergetappter": "umhergetappt",
    "umhergetapptes": "umhergetappt",
    "umhergetastet": "umhertasten",
    "umhergetastete": "umhergetastet",
    "umhergetastetem": "umhergetastet",
    "umhergetasteten": "umhergetastet",
    "umhergetasteter": "umhergetastet",
    "umhergetastetes": "umhergetastet",
    "umhergetrieben": "umhertreiben",
    "umhergetriebene": "umhergetrieben",
    "umhergetriebenem": "umhergetrieben",
    "umhergetriebenen": "umhergetrieben",
    "umhergetriebener": "umhergetrieben",
    "umhergetriebenes": "umhergetrieben",
    "umhergewandert": "umherwandern",
    "umhergewanderte": "umhergewandert",
    "umhergewandertem": "umhergewandert",
    "umhergewanderten": "umhergewandert",
    "umhergewanderter": "umhergewandert",
    "umhergewandertes": "umhergewandert",
    "umhergewimmelt": "umherwimmeln",
    "umhergewimmelte": "umhergewimmelt",
    "umhergewimmeltem": "umhergewimmelt",
    "umhergewimmelten": "umhergewimmelt",
    "umhergewimmelter": "umhergewimmelt",
    "umhergewimmeltes": "umhergewimmelt",
    "umhergezogen": "umherziehen",
    "umhergezogene": "umhergezogen",
    "umhergezogenem": "umhergezogen",
    "umhergezogenen": "umhergezogen",
    "umhergezogener": "umhergezogen",
    "umhergezogenes": "umhergezogen",
    "umherirre": "umherirren",
    "umherirrend": "umherirren",
    "umherirrende": "umherirrend",
    "umherirrendem": "umherirrend",
    "umherirrenden": "umherirrend",
    "umherirrender": "umherirrend",
    "umherirrendere": "umherirrend",
    "umherirrenderem": "umherirrend",
    "umherirrenderen": "umherirrend",
    "umherirrenderer": "umherirrend",
    "umherirrenderes": "umherirrend",
    "umherirrendes": "umherirrend",
    "umherirrendste": "umherirrend",
    "umherirrendstem": "umherirrend",
    "umherirrendsten": "umherirrend",
    "umherirrendster": "umherirrend",
    "umherirrendstes": "umherirrend",
    "umherirrest": "umherirren",
    "umherirret": "umherirren",
    "umherirrst": "umherirren",
    "umherirrt": "umherirren",
    "umherirrte": "umherirren",
    "umherirrten": "umherirren",
    "umherirrtest": "umherirren",
    "umherirrtet": "umherirren",
    "umherjage": "umherjagen",
    "umherjagend": "umherjagen",
    "umherjagende": "umherjagend",
    "umherjagendem": "umherjagend",
    "umherjagenden": "umherjagend",
    "umherjagender": "umherjagend",
    "umherjagendes": "umherjagend",
    "umherjagest": "umherjagen",
    "umherjaget": "umherjagen",
    "umherjagst": "umherjagen",
    "umherjagt": "umherjagen",
    "umherjagte": "umherjagen",
    "umherjagten": "umherjagen",
    "umherjagtest": "umherjagen",
    "umherjagtet": "umherjagen",
    "umherkrieche": "umherkriechen",
    "umherkriechend": "umherkriechen",
    "umherkriechende": "umherkriechend",
    "umherkriechendem": "umherkriechend",
    "umherkriechenden": "umherkriechend",
    "umherkriechender": "umherkriechend",
    "umherkriechendes": "umherkriechend",
    "umherkriechest": "umherkriechen",
    "umherkriechet": "umherkriechen",
    "umherkriechst": "umherkriechen",
    "umherkriecht": "umherkriechen",
    "umherkroch": "umherkriechen",
    "umherkrochen": "umherkriechen",
    "umherkrochst": "umherkriechen",
    "umherkrocht": "umherkriechen",
    "umherkröche": "umherkriechen",
    "umherkröchen": "umherkriechen",
    "umherkröchest": "umherkriechen",
    "umherkröchet": "umherkriechen",
    "umherreise": "umherreisen",
    "umherreisend": "umherreisen",
    "umherreisende": "umherreisend",
    "umherreisendem": "umherreisend",
    "umherreisenden": "umherreisend",
    "umherreisender": "umherreisend",
    "umherreisendes": "umherreisend",
    "umherreisest": "umherreisen",
    "umherreiset": "umherreisen",
    "umherreist": "umherreisen",
    "umherreiste": "umherreisen",
    "umherreisten": "umherreisen",
    "umherreistest": "umherreisen",
    "umherreistet": "umherreisen",
    "umherreite": "umherreiten",
    "umherreitend": "umherreiten",
    "umherreitende": "umherreitend",
    "umherreitendem": "umherreitend",
    "umherreitenden": "umherreitend",
    "umherreitender": "umherreitend",
    "umherreitendes": "umherreitend",
    "umherreitest": "umherreiten",
    "umherreitet": "umherreiten",
    "umherritt": "umherreiten",
    "umherritte": "umherreiten",
    "umherritten": "umherreiten",
    "umherrittest": "umherreiten",
    "umherrittet": "umherreiten",
    "umherschaue": "umherschauen",
    "umherschauend": "umherschauen",
    "umherschauende": "umherschauend",
    "umherschauendem": "umherschauend",
    "umherschauenden": "umherschauend",
    "umherschauender": "umherschauend",
    "umherschauendes": "umherschauend",
    "umherschauest": "umherschauen",
    "umherschauet": "umherschauen",
    "umherschaust": "umherschauen",
    "umherschaut": "umherschauen",
    "umherschaute": "umherschauen",
    "umherschauten": "umherschauen",
    "umherschautest": "umherschauen",
    "umherschautet": "umherschauen",
    "umherschleiche": "umherschleichen",
    "umherschleichend": "umherschleichen",
    "umherschleichende": "umherschleichend",
    "umherschleichendem": "umherschleichend",
    "umherschleichenden": "umherschleichend",
    "umherschleichender": "umherschleichend",
    "umherschleichendes": "umherschleichend",
    "umherschleichest": "umherschleichen",
    "umherschleichet": "umherschleichen",
    "umherschleichst": "umherschleichen",
    "umherschleicht": "umherschleichen",
    "umherschlendere": "umherschlendern",
    "umherschlendernd": "umherschlendern",
    "umherschlendernde": "umherschlendernd",
    "umherschlenderndem": "umherschlendernd",
    "umherschlendernden": "umherschlendernd",
    "umherschlendernder": "umherschlendernd",
    "umherschlenderndes": "umherschlendernd",
    "umherschlenderst": "umherschlendern",
    "umherschlendert": "umherschlendern",
    "umherschlenderte": "umherschlendern",
    "umherschlenderten": "umherschlendern",
    "umherschlendertest": "umherschlendern",
    "umherschlendertet": "umherschlendern",
    "umherschlich": "umherschleichen",
    "umherschliche": "umherschleichen",
    "umherschlichen": "umherschleichen",
    "umherschlichest": "umherschleichen",
    "umherschlichet": "umherschleichen",
    "umherschlichst": "umherschleichen",
    "umherschlicht": "umherschleichen",
    "umherstreife": "umherstreifen",
    "umherstreifend": "umherstreifen",
    "umherstreifende": "umherstreifend",
    "umherstreifendem": "umherstreifend",
    "umherstreifenden": "umherstreifend",
    "umherstreifender": "umherstreifend",
    "umherstreifendere": "umherstreifend",
    "umherstreifenderem": "umherstreifend",
    "umherstreifenderen": "umherstreifend",
    "umherstreifenderer": "umherstreifend",
    "umherstreifenderes": "umherstreifend",
    "umherstreifendes": "umherstreifend",
    "umherstreifendste": "umherstreifend",
    "umherstreifendstem": "umherstreifend",
    "umherstreifendsten": "umherstreifend",
    "umherstreifendster": "umherstreifend",
    "umherstreifendstes": "umherstreifend",
    "umherstreifest": "umherstreifen",
    "umherstreifet": "umherstreifen",
    "umherstreifst": "umherstreifen",
    "umherstreift": "umherstreifen",
    "umherstreifte": "umherstreifen",
    "umherstreiften": "umherstreifen",
    "umherstreiftest": "umherstreifen",
    "umherstreiftet": "umherstreifen",
    "umhertappe": "umhertappen",
    "umhertappend": "umhertappen",
    "umhertappende": "umhertappend",
    "umhertappendem": "umhertappend",
    "umhertappenden": "umhertappend",
    "umhertappender": "umhertappend",
    "umhertappendes": "umhertappend",
    "umhertappest": "umhertappen",
    "umhertappet": "umhertappen",
    "umhertappst": "umhertappen",
    "umhertappt": "umhertappen",
    "umhertappte": "umhertappen",
    "umhertappten": "umhertappen",
    "umhertapptest": "umhertappen",
    "umhertapptet": "umhertappen",
    "umhertaste": "umhertasten",
    "umhertastend": "umhertasten",
    "umhertastende": "umhertastend",
    "umhertastendem": "umhertastend",
    "umhertastenden": "umhertastend",
    "umhertastender": "umhertastend",
    "umhertastendes": "umhertastend",
    "umhertastest": "umhertasten",
    "umhertastet": "umhertasten",
    "umhertastete": "umhertasten",
    "umhertasteten": "umhertasten",
    "umhertastetest": "umhertasten",
    "umhertastetet": "umhertasten",
    "umhertreibe": "umhertreiben",
    "umhertreibend": "umhertreiben",
    "umhertreibende": "umhertreibend",
    "umhertreibendem": "umhertreibend",
    "umhertreibenden": "umhertreibend",
    "umhertreibender": "umhertreibend",
    "umhertreibendes": "umhertreibend",
    "umhertreibest": "umhertreiben",
    "umhertreibet": "umhertreiben",
    "umhertreibst": "umhertreiben",
    "umhertreibt": "umhertreiben",
    "umhertrieb": "umhertreiben",
    "umhertriebe": "umhertreiben",
    "umhertrieben": "umhertreiben",
    "umhertriebest": "umhertreiben",
    "umhertriebet": "umhertreiben",
    "umhertriebst": "umhertreiben",
    "umhertriebt": "umhertreiben",
    "umherwandere": "umherwandern",
    "umherwandernd": "umherwandern",
    "umherwandernde": "umherwandernd",
    "umherwanderndem": "umherwandernd",
    "umherwandernden": "umherwandernd",
    "umherwandernder": "umherwandernd",
    "umherwanderndes": "umherwandernd",
    "umherwanderst": "umherwandern",
    "umherwandert": "umherwandern",
    "umherwanderte": "umherwandern",
    "umherwanderten": "umherwandern",
    "umherwandertest": "umherwandern",
    "umherwandertet": "umherwandern",
    "umherwimmele": "umherwimmeln",
    "umherwimmelnd": "umherwimmeln",
    "umherwimmelnde": "umherwimmelnd",
    "umherwimmelndem": "umherwimmelnd",
    "umherwimmelnden": "umherwimmelnd",
    "umherwimmelnder": "umherwimmelnd",
    "umherwimmelndes": "umherwimmelnd",
    "umherwimmelst": "umherwimmeln",
    "umherwimmelt": "umherwimmeln",
    "umherwimmelte": "umherwimmeln",
    "umherwimmelten": "umherwimmeln",
    "umherwimmeltest": "umherwimmeln",
    "umherwimmeltet": "umherwimmeln",
    "umherwimmle": "umherwimmeln",
    "umherziehe": "umherziehen",
    "umherziehend": "umherziehen",
    "umherziehende": "umherziehend",
    "umherziehendem": "umherziehend",
    "umherziehenden": "umherziehend",
    "umherziehender": "umherziehend",
    "umherziehendes": "umherziehend",
    "umherziehest": "umherziehen",
    "umherziehet": "umherziehen",
    "umherziehst": "umherziehen",
    "umherzieht": "umherziehen",
    "umherzog": "umherziehen",
    "umherzogen": "umherziehen",
    "umherzogst": "umherziehen",
    "umherzogt": "umherziehen",
    "umherzufahren": "umherfahren",
    "umherzuflattern": "umherflattern",
    "umherzufliegen": "umherfliegen",
    "umherzuirren": "umherirren",
    "umherzujagen": "umherjagen",
    "umherzukriechen": "umherkriechen",
    "umherzureisen": "umherreisen",
    "umherzureiten": "umherreiten",
    "umherzuschauen": "umherschauen",
    "umherzuschleichen": "umherschleichen",
    "umherzuschlendern": "umherschlendern",
    "umherzustreifen": "umherstreifen",
    "umherzutappen": "umhertappen",
    "umherzutasten": "umhertasten",
    "umherzutreiben": "umhertreiben",
    "umherzuwandern": "umherwandern",
    "umherzuwimmeln": "umherwimmeln",
    "umherzuziehen": "umherziehen",
    "umherzöge": "umherziehen",
    "umherzögen": "umherziehen",
    "umherzögest": "umherziehen",
    "umherzöget": "umherziehen",
    "umhing": "umhängen",
    "umhinge": "umhängen",
    "umhingen": "umhängen",
    "umhingest": "umhängen",
    "umhinget": "umhängen",
    "umhingst": "umhängen",
    "umhingt": "umhängen",
    "umhängend": "umhängen",
    "umhängende": "umhängend",
    "umhängendem": "umhängend",
    "umhängenden": "umhängend",
    "umhängender": "umhängend",
    "umhängendes": "umhängend",
    "umhängest": "umhängen",
    "umhänget": "umhängen",
    "umhängst": "umhängen",
    "umhängt": "umhängen",
    "umhängte": "umhängen",
    "umhängten": "umhängen",
    "umhängtest": "umhängen",
    "umhängtet": "umhängen",
    "umhöre": "umhören",
    "umhörend": "umhören",
    "umhörende": "umhörend",
    "umhörendem": "umhörend",
    "umhörenden": "umhörend",
    "umhörender": "umhörend",
    "umhörendes": "umhörend",
    "umhörest": "umhören",
    "umhöret": "umhören",
    "umhörst": "umhören",
    "umhört": "umhören",
    "umhörte": "umhören",
    "umhörten": "umhören",
    "umhörtest": "umhören",
    "umhörtet": "umhören",
    "umhülle": "umhüllen",
    "umhüllend": "umhüllen",
    "umhüllende": "umhüllend",
    "umhüllendem": "umhüllend",
    "umhüllenden": "umhüllend",
    "umhüllender": "umhüllend",
    "umhüllendere": "umhüllend",
    "umhüllenderem": "umhüllend",
    "umhüllenderen": "umhüllend",
    "umhüllenderer": "umhüllend",
    "umhüllenderes": "umhüllend",
    "umhüllendes": "umhüllend",
    "umhüllendste": "umhüllend",
    "umhüllendstem": "umhüllend",
    "umhüllendsten": "umhüllend",
    "umhüllendster": "umhüllend",
    "umhüllendstes": "umhüllend",
    "umhüllest": "umhüllen",
    "umhüllet": "umhüllen",
    "umhüllst": "umhüllen",
    "umhüllt": "umhüllen",
    "umhüllte": "umhüllen",
    "umhülltem": "umhüllt",
    "umhüllten": "umhüllen",
    "umhüllter": "umhüllt",
    "umhülltere": "umhüllt",
    "umhüllterem": "umhüllt",
    "umhüllteren": "umhüllt",
    "umhüllterer": "umhüllt",
    "umhüllteres": "umhüllt",
    "umhülltes": "umhüllt",
    "umhülltest": "umhüllen",
    "umhüllteste": "umhüllt",
    "umhülltestem": "umhüllt",
    "umhülltesten": "umhüllt",
    "umhülltester": "umhüllt",
    "umhülltestes": "umhüllt",
    "umhülltet": "umhüllen",
    "uminterpretiere": "uminterpretieren",
    "uminterpretierend": "uminterpretieren",
    "uminterpretierende": "uminterpretierend",
    "uminterpretierendem": "uminterpretierend",
    "uminterpretierenden": "uminterpretierend",
    "uminterpretierender": "uminterpretierend",
    "uminterpretierendes": "uminterpretierend",
    "uminterpretierest": "uminterpretieren",
    "uminterpretieret": "uminterpretieren",
    "uminterpretierst": "uminterpretieren",
    "uminterpretiert": "uminterpretieren",
    "uminterpretierte": "uminterpretieren",
    "uminterpretiertem": "uminterpretiert",
    "uminterpretierten": "uminterpretieren",
    "uminterpretierter": "uminterpretiert",
    "uminterpretiertes": "uminterpretiert",
    "uminterpretiertest": "uminterpretieren",
    "uminterpretiertet": "uminterpretieren",
    "umkam": "umkommen",
    "umkamen": "umkommen",
    "umkamst": "umkommen",
    "umkamt": "umkommen",
    "umkehrbare": "umkehrbar",
    "umkehrbarem": "umkehrbar",
    "umkehrbaren": "umkehrbar",
    "umkehrbarer": "umkehrbar",
    "umkehrbares": "umkehrbar",
    "umkehre": "umkehren",
    "umkehrend": "umkehren",
    "umkehrende": "umkehrend",
    "umkehrendem": "umkehrend",
    "umkehrenden": "umkehrend",
    "umkehrender": "umkehrend",
    "umkehrendes": "umkehrend",
    "umkehrest": "umkehren",
    "umkehret": "umkehren",
    "umkehrst": "umkehren",
    "umkehrt": "umkehren",
    "umkehrte": "umkehren",
    "umkehrten": "umkehren",
    "umkehrtest": "umkehren",
    "umkehrtet": "umkehren",
    "umkippe": "umkippen",
    "umkippend": "umkippen",
    "umkippende": "umkippend",
    "umkippendem": "umkippend",
    "umkippenden": "umkippend",
    "umkippender": "umkippend",
    "umkippendes": "umkippend",
    "umkippest": "umkippen",
    "umkippet": "umkippen",
    "umkippst": "umkippen",
    "umkippt": "umkippen",
    "umkippte": "umkippen",
    "umkippten": "umkippen",
    "umkipptest": "umkippen",
    "umkipptet": "umkippen",
    "umklammere": "umklammern",
    "umklammernd": "umklammern",
    "umklammernde": "umklammernd",
    "umklammerndem": "umklammernd",
    "umklammernden": "umklammernd",
    "umklammernder": "umklammernd",
    "umklammerndere": "umklammernd",
    "umklammernderem": "umklammernd",
    "umklammernderen": "umklammernd",
    "umklammernderer": "umklammernd",
    "umklammernderes": "umklammernd",
    "umklammerndes": "umklammernd",
    "umklammerndste": "umklammernd",
    "umklammerndstem": "umklammernd",
    "umklammerndsten": "umklammernd",
    "umklammerndster": "umklammernd",
    "umklammerndstes": "umklammernd",
    "umklammerst": "umklammern",
    "umklammert": "umklammern",
    "umklammerte": "umklammern",
    "umklammertem": "umklammert",
    "umklammerten": "umklammern",
    "umklammerter": "umklammert",
    "umklammertere": "umklammert",
    "umklammerterem": "umklammert",
    "umklammerteren": "umklammert",
    "umklammerterer": "umklammert",
    "umklammerteres": "umklammert",
    "umklammertes": "umklammert",
    "umklammertest": "umklammern",
    "umklammerteste": "umklammert",
    "umklammertestem": "umklammert",
    "umklammertesten": "umklammert",
    "umklammertester": "umklammert",
    "umklammertestes": "umklammert",
    "umklammertet": "umklammern",
    "umklappe": "umklappen",
    "umklappend": "umklappen",
    "umklappende": "umklappend",
    "umklappendem": "umklappend",
    "umklappenden": "umklappend",
    "umklappender": "umklappend",
    "umklappendes": "umklappend",
    "umklappest": "umklappen",
    "umklappet": "umklappen",
    "umklappst": "umklappen",
    "umklappt": "umklappen",
    "umklappte": "umklappen",
    "umklappten": "umklappen",
    "umklapptest": "umklappen",
    "umklapptet": "umklappen",
    "umkleide": "umkleiden",
    "umkleidend": "umkleiden",
    "umkleidende": "umkleidend",
    "umkleidendem": "umkleidend",
    "umkleidenden": "umkleidend",
    "umkleidender": "umkleidend",
    "umkleidendes": "umkleidend",
    "umkleidest": "umkleiden",
    "umkleidet": "umkleiden",
    "umkleidete": "umkleiden",
    "umkleideten": "umkleiden",
    "umkleidetest": "umkleiden",
    "umkleidetet": "umkleiden",
    "umknicke": "umknicken",
    "umknickend": "umknicken",
    "umknickende": "umknickend",
    "umknickendem": "umknickend",
    "umknickenden": "umknickend",
    "umknickender": "umknickend",
    "umknickendes": "umknickend",
    "umknickest": "umknicken",
    "umknicket": "umknicken",
    "umknickst": "umknicken",
    "umknickt": "umknicken",
    "umknickte": "umknicken",
    "umknickten": "umknicken",
    "umknicktest": "umknicken",
    "umknicktet": "umknicken",
    "umkomme": "umkommen",
    "umkommend": "umkommen",
    "umkommende": "umkommend",
    "umkommendem": "umkommend",
    "umkommenden": "umkommend",
    "umkommender": "umkommend",
    "umkommendes": "umkommend",
    "umkommest": "umkommen",
    "umkommet": "umkommen",
    "umkommst": "umkommen",
    "umkommt": "umkommen",
    "umkreisend": "umkreisen",
    "umkreisende": "umkreisend",
    "umkreisendem": "umkreisend",
    "umkreisenden": "umkreisend",
    "umkreisender": "umkreisend",
    "umkreisendes": "umkreisend",
    "umkreisest": "umkreisen",
    "umkreiset": "umkreisen",
    "umkreist": "umkreisen",
    "umkreiste": "umkreisen",
    "umkreisten": "umkreisen",
    "umkreistest": "umkreisen",
    "umkreistet": "umkreisen",
    "umkrempele": "umkrempeln",
    "umkrempelnd": "umkrempeln",
    "umkrempelnde": "umkrempelnd",
    "umkrempelndem": "umkrempelnd",
    "umkrempelnden": "umkrempelnd",
    "umkrempelnder": "umkrempelnd",
    "umkrempelndere": "umkrempelnd",
    "umkrempelnderem": "umkrempelnd",
    "umkrempelnderen": "umkrempelnd",
    "umkrempelnderer": "umkrempelnd",
    "umkrempelnderes": "umkrempelnd",
    "umkrempelndes": "umkrempelnd",
    "umkrempelndste": "umkrempelnd",
    "umkrempelndstem": "umkrempelnd",
    "umkrempelndsten": "umkrempelnd",
    "umkrempelndster": "umkrempelnd",
    "umkrempelndstes": "umkrempelnd",
    "umkrempelst": "umkrempeln",
    "umkrempelt": "umkrempeln",
    "umkrempelte": "umkrempeln",
    "umkrempelten": "umkrempeln",
    "umkrempeltest": "umkrempeln",
    "umkrempeltet": "umkrempeln",
    "umkremple": "umkrempeln",
    "umkäme": "umkommen",
    "umkämen": "umkommen",
    "umkämest": "umkommen",
    "umkämet": "umkommen",
    "umkämpfte": "umkämpft",
    "umkämpftem": "umkämpft",
    "umkämpften": "umkämpft",
    "umkämpfter": "umkämpft",
    "umkämpftere": "umkämpft",
    "umkämpfterem": "umkämpft",
    "umkämpfteren": "umkämpft",
    "umkämpfterer": "umkämpft",
    "umkämpfteres": "umkämpft",
    "umkämpftes": "umkämpft",
    "umkämpfteste": "umkämpft",
    "umkämpftestem": "umkämpft",
    "umkämpftesten": "umkämpft",
    "umkämpftester": "umkämpft",
    "umkämpftestes": "umkämpft",
    "umlade": "umladen",
    "umladend": "umladen",
    "umladende": "umladend",
    "umladendem": "umladend",
    "umladenden": "umladend",
    "umladender": "umladend",
    "umladendes": "umladend",
    "umladest": "umladen",
    "umladet": "umladen",
    "umlagere": "umlagern",
    "umlagernd": "umlagern",
    "umlagernde": "umlagernd",
    "umlagerndem": "umlagernd",
    "umlagernden": "umlagernd",
    "umlagernder": "umlagernd",
    "umlagerndere": "umlagernd",
    "umlagernderem": "umlagernd",
    "umlagernderen": "umlagernd",
    "umlagernderer": "umlagernd",
    "umlagernderes": "umlagernd",
    "umlagerndes": "umlagernd",
    "umlagerndste": "umlagernd",
    "umlagerndstem": "umlagernd",
    "umlagerndsten": "umlagernd",
    "umlagerndster": "umlagernd",
    "umlagerndstes": "umlagernd",
    "umlagerst": "umlagern",
    "umlagert": "umlagern",
    "umlagerte": "umlagern",
    "umlagertem": "umlagert",
    "umlagerten": "umlagern",
    "umlagerter": "umlagert",
    "umlagertere": "umlagert",
    "umlagerterem": "umlagert",
    "umlagerteren": "umlagert",
    "umlagerterer": "umlagert",
    "umlagerteres": "umlagert",
    "umlagertes": "umlagert",
    "umlagertest": "umlagern",
    "umlagerteste": "umlagert",
    "umlagertestem": "umlagert",
    "umlagertesten": "umlagert",
    "umlagertester": "umlagert",
    "umlagertestes": "umlagert",
    "umlagertet": "umlagern",
    "umlaufend": "umlaufen",
    "umlaufende": "umlaufend",
    "umlaufendem": "umlaufend",
    "umlaufenden": "umlaufend",
    "umlaufender": "umlaufend",
    "umlaufendes": "umlaufend",
    "umlaufest": "umlaufen",
    "umlaufet": "umlaufen",
    "umlauft": "umlaufen",
    "umlautend": "umlauten",
    "umlautende": "umlautend",
    "umlautendem": "umlautend",
    "umlautenden": "umlautend",
    "umlautender": "umlautend",
    "umlautendes": "umlautend",
    "umlautest": "umlauten",
    "umlautet": "umlauten",
    "umlautete": "umlauten",
    "umlauteten": "umlauten",
    "umlautetest": "umlauten",
    "umlautetet": "umlauten",
    "umlege": "umlegen",
    "umlegend": "umlegen",
    "umlegende": "umlegend",
    "umlegendem": "umlegend",
    "umlegenden": "umlegend",
    "umlegender": "umlegend",
    "umlegendes": "umlegend",
    "umlegest": "umlegen",
    "umleget": "umlegen",
    "umlegst": "umlegen",
    "umlegt": "umlegen",
    "umlegte": "umlegen",
    "umlegten": "umlegen",
    "umlegtest": "umlegen",
    "umlegtet": "umlegen",
    "umleite": "umleiten",
    "umleitend": "umleiten",
    "umleitende": "umleitend",
    "umleitendem": "umleitend",
    "umleitenden": "umleitend",
    "umleitender": "umleitend",
    "umleitendes": "umleitend",
    "umleitest": "umleiten",
    "umleitet": "umleiten",
    "umleitete": "umleiten",
    "umleiteten": "umleiten",
    "umleitetest": "umleiten",
    "umleitetet": "umleiten",
    "umlenke": "umlenken",
    "umlenkend": "umlenken",
    "umlenkende": "umlenkend",
    "umlenkendem": "umlenkend",
    "umlenkenden": "umlenkend",
    "umlenkender": "umlenkend",
    "umlenkendes": "umlenkend",
    "umlenkest": "umlenken",
    "umlenket": "umlenken",
    "umlenkst": "umlenken",
    "umlenkt": "umlenken",
    "umlenkte": "umlenken",
    "umlenkten": "umlenken",
    "umlenktest": "umlenken",
    "umlenktet": "umlenken",
    "umlerne": "umlernen",
    "umlernend": "umlernen",
    "umlernende": "umlernend",
    "umlernendem": "umlernend",
    "umlernenden": "umlernend",
    "umlernender": "umlernend",
    "umlernendes": "umlernend",
    "umlernest": "umlernen",
    "umlernet": "umlernen",
    "umlernst": "umlernen",
    "umlernt": "umlernen",
    "umlernte": "umlernen",
    "umlernten": "umlernen",
    "umlerntest": "umlernen",
    "umlerntet": "umlernen",
    "umlief": "umlaufen",
    "umliefe": "umlaufen",
    "umliefen": "umlaufen",
    "umliefest": "umlaufen",
    "umliefet": "umlaufen",
    "umliefst": "umlaufen",
    "umlieft": "umlaufen",
    "umliegende": "umliegend",
    "umliegendem": "umliegend",
    "umliegenden": "umliegend",
    "umliegender": "umliegend",
    "umliegendes": "umliegend",
    "umlud": "umladen",
    "umluden": "umladen",
    "umludest": "umladen",
    "umludet": "umladen",
    "umlädst": "umladen",
    "umlädt": "umladen",
    "umläufst": "umlaufen",
    "umläuft": "umlaufen",
    "umlüde": "umladen",
    "umlüden": "umladen",
    "umlüdest": "umladen",
    "umlüdet": "umladen",
    "ummelde": "ummelden",
    "ummeldend": "ummelden",
    "ummeldende": "ummeldend",
    "ummeldendem": "ummeldend",
    "ummeldenden": "ummeldend",
    "ummeldender": "ummeldend",
    "ummeldendes": "ummeldend",
    "ummeldest": "ummelden",
    "ummeldet": "ummelden",
    "ummeldete": "ummelden",
    "ummeldeten": "ummelden",
    "ummeldetest": "ummelden",
    "ummeldetet": "ummelden",
    "ummodele": "ummodeln",
    "ummodelnd": "ummodeln",
    "ummodelnde": "ummodelnd",
    "ummodelndem": "ummodelnd",
    "ummodelnden": "ummodelnd",
    "ummodelnder": "ummodelnd",
    "ummodelndere": "ummodelnd",
    "ummodelnderem": "ummodelnd",
    "ummodelnderen": "ummodelnd",
    "ummodelnderer": "ummodelnd",
    "ummodelnderes": "ummodelnd",
    "ummodelndes": "ummodelnd",
    "ummodelndste": "ummodelnd",
    "ummodelndstem": "ummodelnd",
    "ummodelndsten": "ummodelnd",
    "ummodelndster": "ummodelnd",
    "ummodelndstes": "ummodelnd",
    "ummodelst": "ummodeln",
    "ummodelt": "ummodeln",
    "ummodelte": "ummodeln",
    "ummodelten": "ummodeln",
    "ummodeltest": "ummodeln",
    "ummodeltet": "ummodeln",
    "ummodle": "ummodeln",
    "umnachtete": "umnachtet",
    "umnachtetem": "umnachtet",
    "umnachteten": "umnachtet",
    "umnachteter": "umnachtet",
    "umnachtetes": "umnachtet",
    "umnähe": "umnähen",
    "umnähend": "umnähen",
    "umnähende": "umnähend",
    "umnähendem": "umnähend",
    "umnähenden": "umnähend",
    "umnähender": "umnähend",
    "umnähendes": "umnähend",
    "umnähest": "umnähen",
    "umnähet": "umnähen",
    "umnähst": "umnähen",
    "umnäht": "umnähen",
    "umnähte": "umnähen",
    "umnähten": "umnähen",
    "umnähtest": "umnähen",
    "umnähtet": "umnähen",
    "umorganisiere": "umorganisieren",
    "umorganisierend": "umorganisieren",
    "umorganisierende": "umorganisierend",
    "umorganisierendem": "umorganisierend",
    "umorganisierenden": "umorganisierend",
    "umorganisierender": "umorganisierend",
    "umorganisierendes": "umorganisierend",
    "umorganisierest": "umorganisieren",
    "umorganisieret": "umorganisieren",
    "umorganisierst": "umorganisieren",
    "umorganisiert": "umorganisieren",
    "umorganisierte": "umorganisieren",
    "umorganisiertem": "umorganisiert",
    "umorganisierten": "umorganisieren",
    "umorganisierter": "umorganisiert",
    "umorganisiertes": "umorganisiert",
    "umorganisiertest": "umorganisieren",
    "umorganisiertet": "umorganisieren",
    "umpflanze": "umpflanzen",
    "umpflanzend": "umpflanzen",
    "umpflanzende": "umpflanzend",
    "umpflanzendem": "umpflanzend",
    "umpflanzenden": "umpflanzend",
    "umpflanzender": "umpflanzend",
    "umpflanzendes": "umpflanzend",
    "umpflanzest": "umpflanzen",
    "umpflanzet": "umpflanzen",
    "umpflanzt": "umpflanzen",
    "umpflanzte": "umpflanzen",
    "umpflanzten": "umpflanzen",
    "umpflanztest": "umpflanzen",
    "umpflanztet": "umpflanzen",
    "umpflüge": "umpflügen",
    "umpflügend": "umpflügen",
    "umpflügende": "umpflügend",
    "umpflügendem": "umpflügend",
    "umpflügenden": "umpflügend",
    "umpflügender": "umpflügend",
    "umpflügendes": "umpflügend",
    "umpflügest": "umpflügen",
    "umpflüget": "umpflügen",
    "umpflügst": "umpflügen",
    "umpflügt": "umpflügen",
    "umpflügte": "umpflügen",
    "umpflügten": "umpflügen",
    "umpflügtest": "umpflügen",
    "umpflügtet": "umpflügen",
    "umpole": "umpolen",
    "umpolend": "umpolen",
    "umpolende": "umpolend",
    "umpolendem": "umpolend",
    "umpolenden": "umpolend",
    "umpolender": "umpolend",
    "umpolendes": "umpolend",
    "umpolest": "umpolen",
    "umpolet": "umpolen",
    "umpolst": "umpolen",
    "umpolt": "umpolen",
    "umpolte": "umpolen",
    "umpolten": "umpolen",
    "umpoltest": "umpolen",
    "umpoltet": "umpolen",
    "umprogrammiere": "umprogrammieren",
    "umprogrammierend": "umprogrammieren",
    "umprogrammierende": "umprogrammierend",
    "umprogrammierendem": "umprogrammierend",
    "umprogrammierenden": "umprogrammierend",
    "umprogrammierender": "umprogrammierend",
    "umprogrammierendes": "umprogrammierend",
    "umprogrammierest": "umprogrammieren",
    "umprogrammieret": "umprogrammieren",
    "umprogrammierst": "umprogrammieren",
    "umprogrammiert": "umprogrammieren",
    "umprogrammierte": "umprogrammieren",
    "umprogrammiertem": "umprogrammiert",
    "umprogrammierten": "umprogrammieren",
    "umprogrammierter": "umprogrammiert",
    "umprogrammiertes": "umprogrammiert",
    "umprogrammiertest": "umprogrammieren",
    "umprogrammiertet": "umprogrammieren",
    "umquartiere": "umquartieren",
    "umquartierend": "umquartieren",
    "umquartierende": "umquartierend",
    "umquartierendem": "umquartierend",
    "umquartierenden": "umquartierend",
    "umquartierender": "umquartierend",
    "umquartierendes": "umquartierend",
    "umquartierest": "umquartieren",
    "umquartieret": "umquartieren",
    "umquartierst": "umquartieren",
    "umquartiert": "umquartieren",
    "umquartierte": "umquartieren",
    "umquartiertem": "umquartiert",
    "umquartierten": "umquartieren",
    "umquartierter": "umquartiert",
    "umquartiertes": "umquartiert",
    "umquartiertest": "umquartieren",
    "umquartiertet": "umquartieren",
    "umrahme": "umrahmen",
    "umrahmend": "umrahmen",
    "umrahmende": "umrahmend",
    "umrahmendem": "umrahmend",
    "umrahmenden": "umrahmend",
    "umrahmender": "umrahmend",
    "umrahmendes": "umrahmend",
    "umrahmest": "umrahmen",
    "umrahmet": "umrahmen",
    "umrahmst": "umrahmen",
    "umrahmt": "umrahmen",
    "umrahmte": "umrahmen",
    "umrahmtem": "umrahmt",
    "umrahmten": "umrahmen",
    "umrahmter": "umrahmt",
    "umrahmtes": "umrahmt",
    "umrahmtest": "umrahmen",
    "umrahmtet": "umrahmen",
    "umrande": "umranden",
    "umrandend": "umranden",
    "umrandende": "umrandend",
    "umrandendem": "umrandend",
    "umrandenden": "umrandend",
    "umrandender": "umrandend",
    "umrandendes": "umrandend",
    "umrandest": "umranden",
    "umrandet": "umranden",
    "umrandete": "umranden",
    "umrandetem": "umrandet",
    "umrandeten": "umranden",
    "umrandeter": "umrandet",
    "umrandetes": "umrandet",
    "umrandetest": "umranden",
    "umrandetet": "umranden",
    "umranke": "umranken",
    "umrankend": "umranken",
    "umrankende": "umrankend",
    "umrankendem": "umrankend",
    "umrankenden": "umrankend",
    "umrankender": "umrankend",
    "umrankendes": "umrankend",
    "umrankest": "umranken",
    "umranket": "umranken",
    "umrankst": "umranken",
    "umrankt": "umranken",
    "umrankte": "umranken",
    "umranktem": "umrankt",
    "umrankten": "umranken",
    "umrankter": "umrankt",
    "umranktes": "umrankt",
    "umranktest": "umranken",
    "umranktet": "umranken",
    "umrannte": "umrennen",
    "umrannten": "umrennen",
    "umranntest": "umrennen",
    "umranntet": "umrennen",
    "umrechne": "umrechnen",
    "umrechnend": "umrechnen",
    "umrechnende": "umrechnend",
    "umrechnendem": "umrechnend",
    "umrechnenden": "umrechnend",
    "umrechnender": "umrechnend",
    "umrechnendes": "umrechnend",
    "umrechnest": "umrechnen",
    "umrechnet": "umrechnen",
    "umrechnete": "umrechnen",
    "umrechneten": "umrechnen",
    "umrechnetest": "umrechnen",
    "umrechnetet": "umrechnen",
    "umreite": "umreiten",
    "umreitend": "umreiten",
    "umreitende": "umreitend",
    "umreitendem": "umreitend",
    "umreitenden": "umreitend",
    "umreitender": "umreitend",
    "umreitendes": "umreitend",
    "umreitest": "umreiten",
    "umreitet": "umreiten",
    "umreiße": "umreißen",
    "umreißend": "umreißen",
    "umreißende": "umreißend",
    "umreißendem": "umreißend",
    "umreißenden": "umreißend",
    "umreißender": "umreißend",
    "umreißendes": "umreißend",
    "umreißest": "umreißen",
    "umreißet": "umreißen",
    "umreißt": "umreißen",
    "umrenne": "umrennen",
    "umrennend": "umrennen",
    "umrennende": "umrennend",
    "umrennendem": "umrennend",
    "umrennenden": "umrennend",
    "umrennender": "umrennend",
    "umrennendes": "umrennend",
    "umrennest": "umrennen",
    "umrennet": "umrennen",
    "umrennst": "umrennen",
    "umrennt": "umrennen",
    "umrissest": "umreißen",
    "umrisset": "umreißen",
    "umritt": "umreiten",
    "umritte": "umreiten",
    "umritten": "umreiten",
    "umrittest": "umreiten",
    "umrittet": "umreiten",
    "umriß": "umreißen",
    "umrißt": "umreißen",
    "umräume": "umräumen",
    "umräumend": "umräumen",
    "umräumende": "umräumend",
    "umräumendem": "umräumend",
    "umräumenden": "umräumend",
    "umräumender": "umräumend",
    "umräumendes": "umräumend",
    "umräumest": "umräumen",
    "umräumet": "umräumen",
    "umräumst": "umräumen",
    "umräumt": "umräumen",
    "umräumte": "umräumen",
    "umräumten": "umräumen",
    "umräumtest": "umräumen",
    "umräumtet": "umräumen",
    "umrühre": "umrühren",
    "umrührend": "umrühren",
    "umrührende": "umrührend",
    "umrührendem": "umrührend",
    "umrührenden": "umrührend",
    "umrührender": "umrührend",
    "umrührendes": "umrührend",
    "umrührest": "umrühren",
    "umrühret": "umrühren",
    "umrührst": "umrühren",
    "umrührt": "umrühren",
    "umrührte": "umrühren",
    "umrührten": "umrühren",
    "umrührtest": "umrühren",
    "umrührtet": "umrühren",
    "umrüste": "umrüsten",
    "umrüstend": "umrüsten",
    "umrüstende": "umrüstend",
    "umrüstendem": "umrüstend",
    "umrüstenden": "umrüstend",
    "umrüstender": "umrüstend",
    "umrüstendes": "umrüstend",
    "umrüstest": "umrüsten",
    "umrüstet": "umrüsten",
    "umrüstete": "umrüsten",
    "umrüsteten": "umrüsten",
    "umrüstetest": "umrüsten",
    "umrüstetet": "umrüsten",
    "umsah": "umsehen",
    "umsahen": "umsehen",
    "umsahst": "umsehen",
    "umsaht": "umsehen",
    "umsank": "umsinken",
    "umsanken": "umsinken",
    "umsankst": "umsinken",
    "umsankt": "umsinken",
    "umsattele": "umsatteln",
    "umsattelnd": "umsatteln",
    "umsattelnde": "umsattelnd",
    "umsattelndem": "umsattelnd",
    "umsattelnden": "umsattelnd",
    "umsattelnder": "umsattelnd",
    "umsattelndes": "umsattelnd",
    "umsattelst": "umsatteln",
    "umsattelt": "umsatteln",
    "umsattelte": "umsatteln",
    "umsattelten": "umsatteln",
    "umsatteltest": "umsatteln",
    "umsatteltet": "umsatteln",
    "umsattle": "umsatteln",
    "umschalte": "umschalten",
    "umschaltend": "umschalten",
    "umschaltende": "umschaltend",
    "umschaltendem": "umschaltend",
    "umschaltenden": "umschaltend",
    "umschaltender": "umschaltend",
    "umschaltendes": "umschaltend",
    "umschaltest": "umschalten",
    "umschaltet": "umschalten",
    "umschaltete": "umschalten",
    "umschalteten": "umschalten",
    "umschaltetest": "umschalten",
    "umschaltetet": "umschalten",
    "umschaue": "umschauen",
    "umschauend": "umschauen",
    "umschauende": "umschauend",
    "umschauendem": "umschauend",
    "umschauenden": "umschauend",
    "umschauender": "umschauend",
    "umschauendes": "umschauend",
    "umschauest": "umschauen",
    "umschauet": "umschauen",
    "umschaust": "umschauen",
    "umschaut": "umschauen",
    "umschaute": "umschauen",
    "umschauten": "umschauen",
    "umschautest": "umschauen",
    "umschautet": "umschauen",
    "umschichte": "umschichten",
    "umschichtend": "umschichten",
    "umschichtende": "umschichtend",
    "umschichtendem": "umschichtend",
    "umschichtenden": "umschichtend",
    "umschichtender": "umschichtend",
    "umschichtendes": "umschichtend",
    "umschichtest": "umschichten",
    "umschichtet": "umschichten",
    "umschichtete": "umschichten",
    "umschichteten": "umschichten",
    "umschichtetest": "umschichten",
    "umschichtetet": "umschichten",
    "umschiffe": "umschiffen",
    "umschiffend": "umschiffen",
    "umschiffende": "umschiffend",
    "umschiffendem": "umschiffend",
    "umschiffenden": "umschiffend",
    "umschiffender": "umschiffend",
    "umschiffendes": "umschiffend",
    "umschiffest": "umschiffen",
    "umschiffet": "umschiffen",
    "umschiffst": "umschiffen",
    "umschifft": "umschiffen",
    "umschiffte": "umschiffen",
    "umschifftem": "umschifft",
    "umschifften": "umschiffen",
    "umschiffter": "umschifft",
    "umschifftes": "umschifft",
    "umschifftest": "umschiffen",
    "umschifftet": "umschiffen",
    "umschlagend": "umschlagen",
    "umschlagende": "umschlagend",
    "umschlagendem": "umschlagend",
    "umschlagenden": "umschlagend",
    "umschlagender": "umschlagend",
    "umschlagendes": "umschlagend",
    "umschlagest": "umschlagen",
    "umschlaget": "umschlagen",
    "umschlagt": "umschlagen",
    "umschlug": "umschlagen",
    "umschlugen": "umschlagen",
    "umschlugst": "umschlagen",
    "umschlugt": "umschlagen",
    "umschlägst": "umschlagen",
    "umschlägt": "umschlagen",
    "umschlüge": "umschlagen",
    "umschlügen": "umschlagen",
    "umschlügest": "umschlagen",
    "umschlüget": "umschlagen",
    "umschmeiße": "umschmeißen",
    "umschmeißend": "umschmeißen",
    "umschmeißende": "umschmeißend",
    "umschmeißendem": "umschmeißend",
    "umschmeißenden": "umschmeißend",
    "umschmeißender": "umschmeißend",
    "umschmeißendes": "umschmeißend",
    "umschmeißest": "umschmeißen",
    "umschmeißet": "umschmeißen",
    "umschmeißt": "umschmeißen",
    "umschmisse": "umschmeißen",
    "umschmissen": "umschmeißen",
    "umschmissest": "umschmeißen",
    "umschmisset": "umschmeißen",
    "umschmiß": "umschmeißen",
    "umschmißt": "umschmeißen",
    "umschnalle": "umschnallen",
    "umschnallend": "umschnallen",
    "umschnallende": "umschnallend",
    "umschnallendem": "umschnallend",
    "umschnallenden": "umschnallend",
    "umschnallender": "umschnallend",
    "umschnallendes": "umschnallend",
    "umschnallest": "umschnallen",
    "umschnallet": "umschnallen",
    "umschnallst": "umschnallen",
    "umschnallt": "umschnallen",
    "umschnallte": "umschnallen",
    "umschnallten": "umschnallen",
    "umschnalltest": "umschnallen",
    "umschnalltet": "umschnallen",
    "umschreibe": "umschreiben",
    "umschreibend": "umschreiben",
    "umschreibende": "umschreibend",
    "umschreibendem": "umschreibend",
    "umschreibenden": "umschreibend",
    "umschreibender": "umschreibend",
    "umschreibendes": "umschreibend",
    "umschreibest": "umschreiben",
    "umschreibet": "umschreiben",
    "umschreibst": "umschreiben",
    "umschreibt": "umschreiben",
    "umschrieb": "umschreiben",
    "umschriebe": "umschreiben",
    "umschrieben": "umschreiben",
    "umschriebest": "umschreiben",
    "umschriebet": "umschreiben",
    "umschriebst": "umschreiben",
    "umschriebt": "umschreiben",
    "umschulde": "umschulden",
    "umschuldend": "umschulden",
    "umschuldende": "umschuldend",
    "umschuldendem": "umschuldend",
    "umschuldenden": "umschuldend",
    "umschuldender": "umschuldend",
    "umschuldendes": "umschuldend",
    "umschuldest": "umschulden",
    "umschuldet": "umschulden",
    "umschuldete": "umschulden",
    "umschuldeten": "umschulden",
    "umschuldetest": "umschulden",
    "umschuldetet": "umschulden",
    "umschule": "umschulen",
    "umschulend": "umschulen",
    "umschulende": "umschulend",
    "umschulendem": "umschulend",
    "umschulenden": "umschulend",
    "umschulender": "umschulend",
    "umschulendes": "umschulend",
    "umschulest": "umschulen",
    "umschulet": "umschulen",
    "umschulst": "umschulen",
    "umschult": "umschulen",
    "umschulte": "umschulen",
    "umschulten": "umschulen",
    "umschultest": "umschulen",
    "umschultet": "umschulen",
    "umschwenke": "umschwenken",
    "umschwenkend": "umschwenken",
    "umschwenkende": "umschwenkend",
    "umschwenkendem": "umschwenkend",
    "umschwenkenden": "umschwenkend",
    "umschwenkender": "umschwenkend",
    "umschwenkendes": "umschwenkend",
    "umschwenkest": "umschwenken",
    "umschwenket": "umschwenken",
    "umschwenkst": "umschwenken",
    "umschwenkt": "umschwenken",
    "umschwenkte": "umschwenken",
    "umschwenkten": "umschwenken",
    "umschwenktest": "umschwenken",
    "umschwenktet": "umschwenken",
    "umschwärme": "umschwärmen",
    "umschwärmend": "umschwärmen",
    "umschwärmende": "umschwärmend",
    "umschwärmendem": "umschwärmend",
    "umschwärmenden": "umschwärmend",
    "umschwärmender": "umschwärmend",
    "umschwärmendere": "umschwärmend",
    "umschwärmenderem": "umschwärmend",
    "umschwärmenderen": "umschwärmend",
    "umschwärmenderer": "umschwärmend",
    "umschwärmenderes": "umschwärmend",
    "umschwärmendes": "umschwärmend",
    "umschwärmendste": "umschwärmend",
    "umschwärmendstem": "umschwärmend",
    "umschwärmendsten": "umschwärmend",
    "umschwärmendster": "umschwärmend",
    "umschwärmendstes": "umschwärmend",
    "umschwärmest": "umschwärmen",
    "umschwärmet": "umschwärmen",
    "umschwärmst": "umschwärmen",
    "umschwärmt": "umschwärmen",
    "umschwärmte": "umschwärmen",
    "umschwärmtem": "umschwärmt",
    "umschwärmten": "umschwärmen",
    "umschwärmter": "umschwärmt",
    "umschwärmtere": "umschwärmt",
    "umschwärmterem": "umschwärmt",
    "umschwärmteren": "umschwärmt",
    "umschwärmterer": "umschwärmt",
    "umschwärmteres": "umschwärmt",
    "umschwärmtes": "umschwärmt",
    "umschwärmtest": "umschwärmen",
    "umschwärmteste": "umschwärmt",
    "umschwärmtestem": "umschwärmt",
    "umschwärmtesten": "umschwärmt",
    "umschwärmtester": "umschwärmt",
    "umschwärmtestes": "umschwärmt",
    "umschwärmtet": "umschwärmen",
    "umschütte": "umschütten",
    "umschüttend": "umschütten",
    "umschüttende": "umschüttend",
    "umschüttendem": "umschüttend",
    "umschüttenden": "umschüttend",
    "umschüttender": "umschüttend",
    "umschüttendes": "umschüttend",
    "umschüttest": "umschütten",
    "umschüttet": "umschütten",
    "umschüttete": "umschütten",
    "umschütteten": "umschütten",
    "umschüttetest": "umschütten",
    "umschüttetet": "umschütten",
    "umsegele": "umsegeln",
    "umsegelnd": "umsegeln",
    "umsegelnde": "umsegelnd",
    "umsegelndem": "umsegelnd",
    "umsegelnden": "umsegelnd",
    "umsegelnder": "umsegelnd",
    "umsegelndes": "umsegelnd",
    "umsegelst": "umsegeln",
    "umsegelt": "umsegeln",
    "umsegelte": "umsegeln",
    "umsegeltem": "umsegelt",
    "umsegelten": "umsegeln",
    "umsegelter": "umsegelt",
    "umsegeltes": "umsegelt",
    "umsegeltest": "umsegeln",
    "umsegeltet": "umsegeln",
    "umsegle": "umsegeln",
    "umsehe": "umsehen",
    "umsehend": "umsehen",
    "umsehende": "umsehend",
    "umsehendem": "umsehend",
    "umsehenden": "umsehend",
    "umsehender": "umsehend",
    "umsehendes": "umsehend",
    "umsehest": "umsehen",
    "umsehet": "umsehen",
    "umseht": "umsehen",
    "umseitige": "umseitig",
    "umseitigem": "umseitig",
    "umseitigen": "umseitig",
    "umseitiger": "umseitig",
    "umseitiges": "umseitig",
    "umsetze": "umsetzen",
    "umsetzend": "umsetzen",
    "umsetzende": "umsetzend",
    "umsetzendem": "umsetzend",
    "umsetzenden": "umsetzend",
    "umsetzender": "umsetzend",
    "umsetzendes": "umsetzend",
    "umsetzest": "umsetzen",
    "umsetzet": "umsetzen",
    "umsetzt": "umsetzen",
    "umsetzte": "umsetzen",
    "umsetzten": "umsetzen",
    "umsetztest": "umsetzen",
    "umsetztet": "umsetzen",
    "umsichtigem": "umsichtig",
    "umsichtigen": "umsichtig",
    "umsichtiger": "umsichtig",
    "umsichtigere": "umsichtig",
    "umsichtigerem": "umsichtig",
    "umsichtigeren": "umsichtig",
    "umsichtigerer": "umsichtig",
    "umsichtigeres": "umsichtig",
    "umsichtiges": "umsichtig",
    "umsichtigste": "umsichtig",
    "umsichtigstem": "umsichtig",
    "umsichtigsten": "umsichtig",
    "umsichtigster": "umsichtig",
    "umsichtigstes": "umsichtig",
    "umsiedele": "umsiedeln",
    "umsiedelnd": "umsiedeln",
    "umsiedelnde": "umsiedelnd",
    "umsiedelndem": "umsiedelnd",
    "umsiedelnden": "umsiedelnd",
    "umsiedelnder": "umsiedelnd",
    "umsiedelndes": "umsiedelnd",
    "umsiedelst": "umsiedeln",
    "umsiedelt": "umsiedeln",
    "umsiedelte": "umsiedeln",
    "umsiedelten": "umsiedeln",
    "umsiedeltest": "umsiedeln",
    "umsiedeltet": "umsiedeln",
    "umsiedle": "umsiedeln",
    "umsiehst": "umsehen",
    "umsieht": "umsehen",
    "umsinke": "umsinken",
    "umsinkend": "umsinken",
    "umsinkende": "umsinkend",
    "umsinkendem": "umsinkend",
    "umsinkenden": "umsinkend",
    "umsinkender": "umsinkend",
    "umsinkendes": "umsinkend",
    "umsinkest": "umsinken",
    "umsinket": "umsinken",
    "umsinkst": "umsinken",
    "umsinkt": "umsinken",
    "umsorge": "umsorgen",
    "umsorgend": "umsorgen",
    "umsorgende": "umsorgend",
    "umsorgendem": "umsorgend",
    "umsorgenden": "umsorgend",
    "umsorgender": "umsorgend",
    "umsorgendere": "umsorgend",
    "umsorgenderem": "umsorgend",
    "umsorgenderen": "umsorgend",
    "umsorgenderer": "umsorgend",
    "umsorgenderes": "umsorgend",
    "umsorgendes": "umsorgend",
    "umsorgendste": "umsorgend",
    "umsorgendstem": "umsorgend",
    "umsorgendsten": "umsorgend",
    "umsorgendster": "umsorgend",
    "umsorgendstes": "umsorgend",
    "umsorgest": "umsorgen",
    "umsorget": "umsorgen",
    "umsorgst": "umsorgen",
    "umsorgt": "umsorgen",
    "umsorgte": "umsorgen",
    "umsorgtem": "umsorgt",
    "umsorgten": "umsorgen",
    "umsorgter": "umsorgt",
    "umsorgtere": "umsorgt",
    "umsorgterem": "umsorgt",
    "umsorgteren": "umsorgt",
    "umsorgterer": "umsorgt",
    "umsorgteres": "umsorgt",
    "umsorgtes": "umsorgt",
    "umsorgtest": "umsorgen",
    "umsorgteste": "umsorgt",
    "umsorgtestem": "umsorgt",
    "umsorgtesten": "umsorgt",
    "umsorgtester": "umsorgt",
    "umsorgtestes": "umsorgt",
    "umsorgtet": "umsorgen",
    "umspanne": "umspannen",
    "umspannend": "umspannen",
    "umspannende": "umspannend",
    "umspannendem": "umspannend",
    "umspannenden": "umspannend",
    "umspannender": "umspannend",
    "umspannendes": "umspannend",
    "umspannest": "umspannen",
    "umspannet": "umspannen",
    "umspannst": "umspannen",
    "umspannt": "umspannen",
    "umspannte": "umspannen",
    "umspanntem": "umspannt",
    "umspannten": "umspannen",
    "umspannter": "umspannt",
    "umspanntes": "umspannt",
    "umspanntest": "umspannen",
    "umspanntet": "umspannen",
    "umspiele": "umspielen",
    "umspielend": "umspielen",
    "umspielende": "umspielend",
    "umspielendem": "umspielend",
    "umspielenden": "umspielend",
    "umspielender": "umspielend",
    "umspielendes": "umspielend",
    "umspielest": "umspielen",
    "umspielet": "umspielen",
    "umspielst": "umspielen",
    "umspielt": "umspielen",
    "umspielte": "umspielen",
    "umspieltem": "umspielt",
    "umspielten": "umspielen",
    "umspielter": "umspielt",
    "umspieltes": "umspielt",
    "umspieltest": "umspielen",
    "umspieltet": "umspielen",
    "umsprang": "umspringen",
    "umsprangen": "umspringen",
    "umsprangst": "umspringen",
    "umsprangt": "umspringen",
    "umspringe": "umspringen",
    "umspringend": "umspringen",
    "umspringende": "umspringend",
    "umspringendem": "umspringend",
    "umspringenden": "umspringend",
    "umspringender": "umspringend",
    "umspringendes": "umspringend",
    "umspringest": "umspringen",
    "umspringet": "umspringen",
    "umspringst": "umspringen",
    "umspringt": "umspringen",
    "umspränge": "umspringen",
    "umsprängen": "umspringen",
    "umsprängest": "umspringen",
    "umspränget": "umspringen",
    "umspule": "umspulen",
    "umspulend": "umspulen",
    "umspulende": "umspulend",
    "umspulendem": "umspulend",
    "umspulenden": "umspulend",
    "umspulender": "umspulend",
    "umspulendes": "umspulend",
    "umspulest": "umspulen",
    "umspulet": "umspulen",
    "umspulst": "umspulen",
    "umspult": "umspulen",
    "umspulte": "umspulen",
    "umspulten": "umspulen",
    "umspultest": "umspulen",
    "umspultet": "umspulen",
    "umstach": "umstechen",
    "umstachen": "umstechen",
    "umstachst": "umstechen",
    "umstacht": "umstechen",
    "umsteche": "umstechen",
    "umstechend": "umstechen",
    "umstechende": "umstechend",
    "umstechendem": "umstechend",
    "umstechenden": "umstechend",
    "umstechender": "umstechend",
    "umstechendes": "umstechend",
    "umstechest": "umstechen",
    "umstechet": "umstechen",
    "umstecht": "umstechen",
    "umstehende": "umstehend",
    "umstehendem": "umstehend",
    "umstehenden": "umstehend",
    "umstehender": "umstehend",
    "umstehendes": "umstehend",
    "umsteige": "umsteigen",
    "umsteigend": "umsteigen",
    "umsteigende": "umsteigend",
    "umsteigendem": "umsteigend",
    "umsteigenden": "umsteigend",
    "umsteigender": "umsteigend",
    "umsteigendes": "umsteigend",
    "umsteigest": "umsteigen",
    "umsteiget": "umsteigen",
    "umsteigst": "umsteigen",
    "umsteigt": "umsteigen",
    "umstelle": "umstellen",
    "umstellend": "umstellen",
    "umstellende": "umstellend",
    "umstellendem": "umstellend",
    "umstellenden": "umstellend",
    "umstellender": "umstellend",
    "umstellendes": "umstellend",
    "umstellest": "umstellen",
    "umstellet": "umstellen",
    "umstellst": "umstellen",
    "umstellt": "umstellen",
    "umstellte": "umstellen",
    "umstelltem": "umstellt",
    "umstellten": "umstellen",
    "umstellter": "umstellt",
    "umstelltes": "umstellt",
    "umstelltest": "umstellen",
    "umstelltet": "umstellen",
    "umstichst": "umstechen",
    "umsticht": "umstechen",
    "umstieg": "umsteigen",
    "umstiege": "umsteigen",
    "umstiegen": "umsteigen",
    "umstiegest": "umsteigen",
    "umstieget": "umsteigen",
    "umstiegst": "umsteigen",
    "umstiegt": "umsteigen",
    "umstieß": "umstoßen",
    "umstieße": "umstoßen",
    "umstießen": "umstoßen",
    "umstießest": "umstoßen",
    "umstießet": "umstoßen",
    "umstießt": "umstoßen",
    "umstimme": "umstimmen",
    "umstimmend": "umstimmen",
    "umstimmende": "umstimmend",
    "umstimmendem": "umstimmend",
    "umstimmenden": "umstimmend",
    "umstimmender": "umstimmend",
    "umstimmendes": "umstimmend",
    "umstimmest": "umstimmen",
    "umstimmet": "umstimmen",
    "umstimmst": "umstimmen",
    "umstimmt": "umstimmen",
    "umstimmte": "umstimmen",
    "umstimmten": "umstimmen",
    "umstimmtest": "umstimmen",
    "umstimmtet": "umstimmen",
    "umstoße": "umstoßen",
    "umstoßend": "umstoßen",
    "umstoßende": "umstoßend",
    "umstoßendem": "umstoßend",
    "umstoßenden": "umstoßend",
    "umstoßender": "umstoßend",
    "umstoßendes": "umstoßend",
    "umstoßest": "umstoßen",
    "umstoßet": "umstoßen",
    "umstoßt": "umstoßen",
    "umstrittene": "umstritten",
    "umstrittenem": "umstritten",
    "umstrittenen": "umstritten",
    "umstrittener": "umstritten",
    "umstrittenere": "umstritten",
    "umstrittenerem": "umstritten",
    "umstritteneren": "umstritten",
    "umstrittenerer": "umstritten",
    "umstritteneres": "umstritten",
    "umstrittenes": "umstritten",
    "umstrittenste": "umstritten",
    "umstrittenstem": "umstritten",
    "umstrittensten": "umstritten",
    "umstrittenster": "umstritten",
    "umstrittenstes": "umstritten",
    "umstrukturiere": "umstrukturieren",
    "umstrukturierend": "umstrukturieren",
    "umstrukturierende": "umstrukturierend",
    "umstrukturierendem": "umstrukturierend",
    "umstrukturierenden": "umstrukturierend",
    "umstrukturierender": "umstrukturierend",
    "umstrukturierendere": "umstrukturierend",
    "umstrukturierenderem": "umstrukturierend",
    "umstrukturierenderen": "umstrukturierend",
    "umstrukturierenderer": "umstrukturierend",
    "umstrukturierenderes": "umstrukturierend",
    "umstrukturierendes": "umstrukturierend",
    "umstrukturierendste": "umstrukturierend",
    "umstrukturierendstem": "umstrukturierend",
    "umstrukturierendsten": "umstrukturierend",
    "umstrukturierendster": "umstrukturierend",
    "umstrukturierendstes": "umstrukturierend",
    "umstrukturierest": "umstrukturieren",
    "umstrukturieret": "umstrukturieren",
    "umstrukturierst": "umstrukturieren",
    "umstrukturiert": "umstrukturieren",
    "umstrukturierte": "umstrukturieren",
    "umstrukturiertem": "umstrukturiert",
    "umstrukturierten": "umstrukturieren",
    "umstrukturierter": "umstrukturiert",
    "umstrukturiertere": "umstrukturiert",
    "umstrukturierterem": "umstrukturiert",
    "umstrukturierteren": "umstrukturiert",
    "umstrukturierterer": "umstrukturiert",
    "umstrukturierteres": "umstrukturiert",
    "umstrukturiertes": "umstrukturiert",
    "umstrukturiertest": "umstrukturieren",
    "umstrukturierteste": "umstrukturiert",
    "umstrukturiertestem": "umstrukturiert",
    "umstrukturiertesten": "umstrukturiert",
    "umstrukturiertester": "umstrukturiert",
    "umstrukturiertestes": "umstrukturiert",
    "umstrukturiertet": "umstrukturieren",
    "umstäche": "umstechen",
    "umstächen": "umstechen",
    "umstächest": "umstechen",
    "umstächet": "umstechen",
    "umständlichem": "umständlich",
    "umständlichen": "umständlich",
    "umständlicher": "umständlich",
    "umständlichere": "umständlich",
    "umständlicherem": "umständlich",
    "umständlicheren": "umständlich",
    "umständlicherer": "umständlich",
    "umständlicheres": "umständlich",
    "umständliches": "umständlich",
    "umständlichste": "umständlich",
    "umständlichstem": "umständlich",
    "umständlichsten": "umständlich",
    "umständlichster": "umständlich",
    "umständlichstes": "umständlich",
    "umstößt": "umstoßen",
    "umstülpe": "umstülpen",
    "umstülpend": "umstülpen",
    "umstülpende": "umstülpend",
    "umstülpendem": "umstülpend",
    "umstülpenden": "umstülpend",
    "umstülpender": "umstülpend",
    "umstülpendes": "umstülpend",
    "umstülpest": "umstülpen",
    "umstülpet": "umstülpen",
    "umstülpst": "umstülpen",
    "umstülpt": "umstülpen",
    "umstülpte": "umstülpen",
    "umstülpten": "umstülpen",
    "umstülptest": "umstülpen",
    "umstülptet": "umstülpen",
    "umstürzend": "umstürzen",
    "umstürzende": "umstürzend",
    "umstürzendem": "umstürzend",
    "umstürzenden": "umstürzend",
    "umstürzender": "umstürzend",
    "umstürzendes": "umstürzend",
    "umstürzest": "umstürzen",
    "umstürzet": "umstürzen",
    "umstürzlerische": "umstürzlerisch",
    "umstürzlerischem": "umstürzlerisch",
    "umstürzlerischen": "umstürzlerisch",
    "umstürzlerischer": "umstürzlerisch",
    "umstürzlerisches": "umstürzlerisch",
    "umstürzt": "umstürzen",
    "umstürzte": "umstürzen",
    "umstürzten": "umstürzen",
    "umstürztest": "umstürzen",
    "umstürztet": "umstürzen",
    "umsähe": "umsehen",
    "umsähen": "umsehen",
    "umsähest": "umsehen",
    "umsähet": "umsehen",
    "umsänke": "umsinken",
    "umsänken": "umsinken",
    "umsänkest": "umsinken",
    "umsänket": "umsinken",
    "umsäume": "umsäumen",
    "umsäumend": "umsäumen",
    "umsäumende": "umsäumend",
    "umsäumendem": "umsäumend",
    "umsäumenden": "umsäumend",
    "umsäumender": "umsäumend",
    "umsäumendes": "umsäumend",
    "umsäumest": "umsäumen",
    "umsäumet": "umsäumen",
    "umsäumst": "umsäumen",
    "umsäumt": "umsäumen",
    "umsäumte": "umsäumen",
    "umsäumten": "umsäumen",
    "umsäumtest": "umsäumen",
    "umsäumtet": "umsäumen",
    "umtankende": "umtankend",
    "umtankendem": "umtankend",
    "umtankenden": "umtankend",
    "umtankender": "umtankend",
    "umtankendes": "umtankend",
    "umtaufe": "umtaufen",
    "umtaufend": "umtaufen",
    "umtaufende": "umtaufend",
    "umtaufendem": "umtaufend",
    "umtaufenden": "umtaufend",
    "umtaufender": "umtaufend",
    "umtaufendes": "umtaufend",
    "umtaufest": "umtaufen",
    "umtaufet": "umtaufen",
    "umtaufst": "umtaufen",
    "umtauft": "umtaufen",
    "umtaufte": "umtaufen",
    "umtauften": "umtaufen",
    "umtauftest": "umtaufen",
    "umtauftet": "umtaufen",
    "umtausche": "umtauschen",
    "umtauschend": "umtauschen",
    "umtauschende": "umtauschend",
    "umtauschendem": "umtauschend",
    "umtauschenden": "umtauschend",
    "umtauschender": "umtauschend",
    "umtauschendes": "umtauschend",
    "umtauschest": "umtauschen",
    "umtauschet": "umtauschen",
    "umtauschst": "umtauschen",
    "umtauscht": "umtauschen",
    "umtauschte": "umtauschen",
    "umtauschten": "umtauschen",
    "umtauschtest": "umtauschen",
    "umtauschtet": "umtauschen",
    "umtopfe": "umtopfen",
    "umtopfend": "umtopfen",
    "umtopfende": "umtopfend",
    "umtopfendem": "umtopfend",
    "umtopfenden": "umtopfend",
    "umtopfender": "umtopfend",
    "umtopfendes": "umtopfend",
    "umtopfest": "umtopfen",
    "umtopfet": "umtopfen",
    "umtopfst": "umtopfen",
    "umtopft": "umtopfen",
    "umtopfte": "umtopfen",
    "umtopften": "umtopfen",
    "umtopftest": "umtopfen",
    "umtopftet": "umtopfen",
    "umtreibe": "umtreiben",
    "umtreibend": "umtreiben",
    "umtreibende": "umtreibend",
    "umtreibendem": "umtreibend",
    "umtreibenden": "umtreibend",
    "umtreibender": "umtreibend",
    "umtreibendes": "umtreibend",
    "umtreibest": "umtreiben",
    "umtreibet": "umtreiben",
    "umtreibst": "umtreiben",
    "umtreibt": "umtreiben",
    "umtrieb": "umtreiben",
    "umtriebe": "umtreiben",
    "umtrieben": "umtreiben",
    "umtriebest": "umtreiben",
    "umtriebet": "umtreiben",
    "umtriebst": "umtreiben",
    "umtriebt": "umtreiben",
    "umwandele": "umwandeln",
    "umwandelnd": "umwandeln",
    "umwandelnde": "umwandelnd",
    "umwandelndem": "umwandelnd",
    "umwandelnden": "umwandelnd",
    "umwandelnder": "umwandelnd",
    "umwandelndes": "umwandelnd",
    "umwandelst": "umwandeln",
    "umwandelt": "umwandeln",
    "umwandelte": "umwandeln",
    "umwandelten": "umwandeln",
    "umwandeltest": "umwandeln",
    "umwandeltet": "umwandeln",
    "umwandle": "umwandeln",
    "umwandte": "umwenden",
    "umwandten": "umwenden",
    "umwandtest": "umwenden",
    "umwandtet": "umwenden",
    "umwarb": "umwerben",
    "umwarben": "umwerben",
    "umwarbst": "umwerben",
    "umwarbt": "umwerben",
    "umwarf": "umwerfen",
    "umwarfen": "umwerfen",
    "umwarfst": "umwerfen",
    "umwarft": "umwerfen",
    "umweltbewußtem": "umweltbewußt",
    "umweltbewußten": "umweltbewußt",
    "umweltbewußter": "umweltbewußt",
    "umweltbewußtere": "umweltbewußt",
    "umweltbewußterem": "umweltbewußt",
    "umweltbewußteren": "umweltbewußt",
    "umweltbewußterer": "umweltbewußt",
    "umweltbewußteres": "umweltbewußt",
    "umweltbewußtes": "umweltbewußt",
    "umweltbewußteste": "umweltbewußt",
    "umweltbewußtestem": "umweltbewußt",
    "umweltbewußtesten": "umweltbewußt",
    "umweltbewußtester": "umweltbewußt",
    "umweltbewußtestes": "umweltbewußt",
    "umweltfeindliche": "umweltfeindlich",
    "umweltfeindlichem": "umweltfeindlich",
    "umweltfeindlichen": "umweltfeindlich",
    "umweltfeindlicher": "umweltfeindlich",
    "umweltfeindlichere": "umweltfeindlich",
    "umweltfeindlicherem": "umweltfeindlich",
    "umweltfeindlicheren": "umweltfeindlich",
    "umweltfeindlicherer": "umweltfeindlich",
    "umweltfeindlicheres": "umweltfeindlich",
    "umweltfeindliches": "umweltfeindlich",
    "umweltfeindlichste": "umweltfeindlich",
    "umweltfeindlichstem": "umweltfeindlich",
    "umweltfeindlichsten": "umweltfeindlich",
    "umweltfeindlichster": "umweltfeindlich",
    "umweltfeindlichstes": "umweltfeindlich",
    "umweltfreundliche": "umweltfreundlich",
    "umweltfreundlichem": "umweltfreundlich",
    "umweltfreundlichen": "umweltfreundlich",
    "umweltfreundlicher": "umweltfreundlich",
    "umweltfreundlichere": "umweltfreundlich",
    "umweltfreundlicherem": "umweltfreundlich",
    "umweltfreundlicheren": "umweltfreundlich",
    "umweltfreundlicherer": "umweltfreundlich",
    "umweltfreundlicheres": "umweltfreundlich",
    "umweltfreundliches": "umweltfreundlich",
    "umweltfreundlichste": "umweltfreundlich",
    "umweltfreundlichstem": "umweltfreundlich",
    "umweltfreundlichsten": "umweltfreundlich",
    "umweltfreundlichster": "umweltfreundlich",
    "umweltfreundlichstes": "umweltfreundlich",
    "umweltschädliche": "umweltschädlich",
    "umweltschädlichem": "umweltschädlich",
    "umweltschädlichen": "umweltschädlich",
    "umweltschädlicher": "umweltschädlich",
    "umweltschädlichere": "umweltschädlich",
    "umweltschädlicherem": "umweltschädlich",
    "umweltschädlicheren": "umweltschädlich",
    "umweltschädlicherer": "umweltschädlich",
    "umweltschädlicheres": "umweltschädlich",
    "umweltschädliches": "umweltschädlich",
    "umweltschädlichste": "umweltschädlich",
    "umweltschädlichstem": "umweltschädlich",
    "umweltschädlichsten": "umweltschädlich",
    "umweltschädlichster": "umweltschädlich",
    "umweltschädlichstes": "umweltschädlich",
    "umwende": "umwenden",
    "umwendend": "umwenden",
    "umwendende": "umwendend",
    "umwendendem": "umwendend",
    "umwendenden": "umwendend",
    "umwendender": "umwendend",
    "umwendendes": "umwendend",
    "umwendest": "umwenden",
    "umwendet": "umwenden",
    "umwendete": "umwenden",
    "umwendeten": "umwenden",
    "umwendetest": "umwenden",
    "umwendetet": "umwenden",
    "umwerbe": "umwerben",
    "umwerbend": "umwerben",
    "umwerbende": "umwerbend",
    "umwerbendem": "umwerbend",
    "umwerbenden": "umwerbend",
    "umwerbender": "umwerbend",
    "umwerbendere": "umwerbend",
    "umwerbenderem": "umwerbend",
    "umwerbenderen": "umwerbend",
    "umwerbenderer": "umwerbend",
    "umwerbenderes": "umwerbend",
    "umwerbendes": "umwerbend",
    "umwerbendste": "umwerbend",
    "umwerbendstem": "umwerbend",
    "umwerbendsten": "umwerbend",
    "umwerbendster": "umwerbend",
    "umwerbendstes": "umwerbend",
    "umwerbest": "umwerben",
    "umwerbet": "umwerben",
    "umwerbt": "umwerben",
    "umwerfe": "umwerfen",
    "umwerfend": "umwerfen",
    "umwerfende": "umwerfend",
    "umwerfendem": "umwerfend",
    "umwerfenden": "umwerfend",
    "umwerfender": "umwerfend",
    "umwerfendere": "umwerfend",
    "umwerfenderem": "umwerfend",
    "umwerfenderen": "umwerfend",
    "umwerfenderer": "umwerfend",
    "umwerfenderes": "umwerfend",
    "umwerfendes": "umwerfend",
    "umwerfendste": "umwerfend",
    "umwerfendstem": "umwerfend",
    "umwerfendsten": "umwerfend",
    "umwerfendster": "umwerfend",
    "umwerfendstes": "umwerfend",
    "umwerfest": "umwerfen",
    "umwerfet": "umwerfen",
    "umwerft": "umwerfen",
    "umwerte": "umwerten",
    "umwertend": "umwerten",
    "umwertende": "umwertend",
    "umwertendem": "umwertend",
    "umwertenden": "umwertend",
    "umwertender": "umwertend",
    "umwertendes": "umwertend",
    "umwertest": "umwerten",
    "umwertet": "umwerten",
    "umwertete": "umwerten",
    "umwerteten": "umwerten",
    "umwertetest": "umwerten",
    "umwertetet": "umwerten",
    "umwirb": "umwerben",
    "umwirbst": "umwerben",
    "umwirbt": "umwerben",
    "umwirfst": "umwerfen",
    "umwirft": "umwerfen",
    "umworben": "umwerben",
    "umworbene": "umworben",
    "umworbenem": "umworben",
    "umworbenen": "umworben",
    "umworbener": "umworben",
    "umworbenere": "umworben",
    "umworbenerem": "umworben",
    "umworbeneren": "umworben",
    "umworbenerer": "umworben",
    "umworbeneres": "umworben",
    "umworbenes": "umworben",
    "umworbenste": "umworben",
    "umworbenstem": "umworben",
    "umworbensten": "umworben",
    "umworbenster": "umworben",
    "umworbenstes": "umworben",
    "umwälze": "umwälzen",
    "umwälzend": "umwälzen",
    "umwälzende": "umwälzend",
    "umwälzendem": "umwälzend",
    "umwälzenden": "umwälzend",
    "umwälzender": "umwälzend",
    "umwälzendere": "umwälzend",
    "umwälzenderem": "umwälzend",
    "umwälzenderen": "umwälzend",
    "umwälzenderer": "umwälzend",
    "umwälzenderes": "umwälzend",
    "umwälzendes": "umwälzend",
    "umwälzendste": "umwälzend",
    "umwälzendstem": "umwälzend",
    "umwälzendsten": "umwälzend",
    "umwälzendster": "umwälzend",
    "umwälzendstes": "umwälzend",
    "umwälzest": "umwälzen",
    "umwälzet": "umwälzen",
    "umwälzt": "umwälzen",
    "umwälzte": "umwälzen",
    "umwälzten": "umwälzen",
    "umwälztest": "umwälzen",
    "umwälztet": "umwälzen",
    "umwärbe": "umwerben",
    "umwärben": "umwerben",
    "umwärbest": "umwerben",
    "umwärbet": "umwerben",
    "umwärfe": "umwerfen",
    "umwärfen": "umwerfen",
    "umwärfest": "umwerfen",
    "umwärfet": "umwerfen",
    "umwühle": "umwühlen",
    "umwühlend": "umwühlen",
    "umwühlende": "umwühlend",
    "umwühlendem": "umwühlend",
    "umwühlenden": "umwühlend",
    "umwühlender": "umwühlend",
    "umwühlendes": "umwühlend",
    "umwühlest": "umwühlen",
    "umwühlet": "umwühlen",
    "umwühlst": "umwühlen",
    "umwühlt": "umwühlen",
    "umwühlte": "umwühlen",
    "umwühlten": "umwühlen",
    "umwühltest": "umwühlen",
    "umwühltet": "umwühlen",
    "umzeichne": "umzeichnen",
    "umzeichnend": "umzeichnen",
    "umzeichnende": "umzeichnend",
    "umzeichnendem": "umzeichnend",
    "umzeichnenden": "umzeichnend",
    "umzeichnender": "umzeichnend",
    "umzeichnendes": "umzeichnend",
    "umzeichnest": "umzeichnen",
    "umzeichnet": "umzeichnen",
    "umzeichnete": "umzeichnen",
    "umzeichneten": "umzeichnen",
    "umzeichnetest": "umzeichnen",
    "umzeichnetet": "umzeichnen",
    "umziehe": "umziehen",
    "umziehend": "umziehen",
    "umziehende": "umziehend",
    "umziehendem": "umziehend",
    "umziehenden": "umziehend",
    "umziehender": "umziehend",
    "umziehendes": "umziehend",
    "umziehest": "umziehen",
    "umziehet": "umziehen",
    "umziehst": "umziehen",
    "umzieht": "umziehen",
    "umzingele": "umzingeln",
    "umzingelnd": "umzingeln",
    "umzingelnde": "umzingelnd",
    "umzingelndem": "umzingelnd",
    "umzingelnden": "umzingelnd",
    "umzingelnder": "umzingelnd",
    "umzingelndes": "umzingelnd",
    "umzingelst": "umzingeln",
    "umzingelt": "umzingeln",
    "umzingelte": "umzingeln",
    "umzingeltem": "umzingelt",
    "umzingelten": "umzingeln",
    "umzingelter": "umzingelt",
    "umzingeltes": "umzingelt",
    "umzingeltest": "umzingeln",
    "umzingeltet": "umzingeln",
    "umzingle": "umzingeln",
    "umzog": "umziehen",
    "umzogen": "umziehen",
    "umzogst": "umziehen",
    "umzogt": "umziehen",
    "umzuarbeiten": "umarbeiten",
    "umzubauen": "umbauen",
    "umzubehalten": "umbehalten",
    "umzubesetzen": "umbesetzen",
    "umzubetten": "umbetten",
    "umzubiegen": "umbiegen",
    "umzubilden": "umbilden",
    "umzubinden": "umbinden",
    "umzublasen": "umblasen",
    "umzublättern": "umblättern",
    "umzubrechen": "umbrechen",
    "umzubringen": "umbringen",
    "umzubuchen": "umbuchen",
    "umzudenken": "umdenken",
    "umzudeuten": "umdeuten",
    "umzudichten": "umdichten",
    "umzudisponieren": "umdisponieren",
    "umzudrehen": "umdrehen",
    "umzuerziehen": "umerziehen",
    "umzufahren": "umfahren",
    "umzufallen": "umfallen",
    "umzufliegen": "umfliegen",
    "umzuformen": "umformen",
    "umzufragen": "umfragen",
    "umzufunktionieren": "umfunktionieren",
    "umzufärben": "umfärben",
    "umzufüllen": "umfüllen",
    "umzugehen": "umgehen",
    "umzugestalten": "umgestalten",
    "umzugießen": "umgießen",
    "umzugraben": "umgraben",
    "umzugruppieren": "umgruppieren",
    "umzugrätschen": "umgrätschen",
    "umzuhauen": "umhauen",
    "umzuhängen": "umhängen",
    "umzuhören": "umhören",
    "umzuinterpretieren": "uminterpretieren",
    "umzukehren": "umkehren",
    "umzukippen": "umkippen",
    "umzuklappen": "umklappen",
    "umzukleiden": "umkleiden",
    "umzuknicken": "umknicken",
    "umzukommen": "umkommen",
    "umzukreisen": "umkreisen",
    "umzukrempeln": "umkrempeln",
    "umzuladen": "umladen",
    "umzulagern": "umlagern",
    "umzulaufen": "umlaufen",
    "umzulauten": "umlauten",
    "umzulegen": "umlegen",
    "umzuleiten": "umleiten",
    "umzulenken": "umlenken",
    "umzulernen": "umlernen",
    "umzumelden": "ummelden",
    "umzumodeln": "ummodeln",
    "umzunähen": "umnähen",
    "umzuorganisieren": "umorganisieren",
    "umzupflanzen": "umpflanzen",
    "umzupflügen": "umpflügen",
    "umzupolen": "umpolen",
    "umzuprogrammieren": "umprogrammieren",
    "umzuquartieren": "umquartieren",
    "umzurechnen": "umrechnen",
    "umzureiten": "umreiten",
    "umzureißen": "umreißen",
    "umzurennen": "umrennen",
    "umzuräumen": "umräumen",
    "umzurühren": "umrühren",
    "umzurüsten": "umrüsten",
    "umzusatteln": "umsatteln",
    "umzuschalten": "umschalten",
    "umzuschauen": "umschauen",
    "umzuschichten": "umschichten",
    "umzuschlagen": "umschlagen",
    "umzuschmeißen": "umschmeißen",
    "umzuschnallen": "umschnallen",
    "umzuschreiben": "umschreiben",
    "umzuschulden": "umschulden",
    "umzuschulen": "umschulen",
    "umzuschwenken": "umschwenken",
    "umzuschütten": "umschütten",
    "umzusehen": "umsehen",
    "umzusetzen": "umsetzen",
    "umzusiedeln": "umsiedeln",
    "umzusinken": "umsinken",
    "umzuspannen": "umspannen",
    "umzuspringen": "umspringen",
    "umzuspulen": "umspulen",
    "umzustechen": "umstechen",
    "umzusteigen": "umsteigen",
    "umzustellen": "umstellen",
    "umzustimmen": "umstimmen",
    "umzustoßen": "umstoßen",
    "umzustrukturieren": "umstrukturieren",
    "umzustülpen": "umstülpen",
    "umzustürzen": "umstürzen",
    "umzusäumen": "umsäumen",
    "umzutaufen": "umtaufen",
    "umzutauschen": "umtauschen",
    "umzutopfen": "umtopfen",
    "umzutreiben": "umtreiben",
    "umzuwandeln": "umwandeln",
    "umzuwenden": "umwenden",
    "umzuwerfen": "umwerfen",
    "umzuwerten": "umwerten",
    "umzuwälzen": "umwälzen",
    "umzuwühlen": "umwühlen",
    "umzuzeichnen": "umzeichnen",
    "umzuziehen": "umziehen",
    "umzuändern": "umändern",
    "umzäune": "umzäunen",
    "umzäunend": "umzäunen",
    "umzäunende": "umzäunend",
    "umzäunendem": "umzäunend",
    "umzäunenden": "umzäunend",
    "umzäunender": "umzäunend",
    "umzäunendes": "umzäunend",
    "umzäunest": "umzäunen",
    "umzäunet": "umzäunen",
    "umzäunst": "umzäunen",
    "umzäunt": "umzäunen",
    "umzäunte": "umzäunen",
    "umzäuntem": "umzäunt",
    "umzäunten": "umzäunen",
    "umzäunter": "umzäunt",
    "umzäuntes": "umzäunt",
    "umzäuntest": "umzäunen",
    "umzäuntet": "umzäunen",
    "umzöge": "umziehen",
    "umzögen": "umziehen",
    "umzögest": "umziehen",
    "umzöget": "umziehen",
    "umändere": "umändern",
    "umändernd": "umändern",
    "umändernde": "umändernd",
    "umänderndem": "umändernd",
    "umändernden": "umändernd",
    "umändernder": "umändernd",
    "umänderndere": "umändernd",
    "umändernderem": "umändernd",
    "umändernderen": "umändernd",
    "umändernderer": "umändernd",
    "umändernderes": "umändernd",
    "umänderndes": "umändernd",
    "umänderndste": "umändernd",
    "umänderndstem": "umändernd",
    "umänderndsten": "umändernd",
    "umänderndster": "umändernd",
    "umänderndstes": "umändernd",
    "umänderst": "umändern",
    "umändert": "umändern",
    "umänderte": "umändern",
    "umänderten": "umändern",
    "umändertest": "umändern",
    "umändertet": "umändern",
    "unabdingbare": "unabdingbar",
    "unabdingbarem": "unabdingbar",
    "unabdingbaren": "unabdingbar",
    "unabdingbarer": "unabdingbar",
    "unabdingbarere": "unabdingbar",
    "unabdingbarerem": "unabdingbar",
    "unabdingbareren": "unabdingbar",
    "unabdingbarerer": "unabdingbar",
    "unabdingbareres": "unabdingbar",
    "unabdingbares": "unabdingbar",
    "unabdingbarste": "unabdingbar",
    "unabdingbarstem": "unabdingbar",
    "unabdingbarsten": "unabdingbar",
    "unabdingbarster": "unabdingbar",
    "unabdingbarstes": "unabdingbar",
    "unabgegoltene": "unabgegolten",
    "unabgegoltenem": "unabgegolten",
    "unabgegoltenen": "unabgegolten",
    "unabgegoltener": "unabgegolten",
    "unabgegoltenere": "unabgegolten",
    "unabgegoltenerem": "unabgegolten",
    "unabgegolteneren": "unabgegolten",
    "unabgegoltenerer": "unabgegolten",
    "unabgegolteneres": "unabgegolten",
    "unabgegoltenes": "unabgegolten",
    "unabgegoltenste": "unabgegolten",
    "unabgegoltenstem": "unabgegolten",
    "unabgegoltensten": "unabgegolten",
    "unabgegoltenster": "unabgegolten",
    "unabgegoltenstes": "unabgegolten",
    "unabhängige": "unabhängig",
    "unabhängigem": "unabhängig",
    "unabhängigen": "unabhängig",
    "unabhängiger": "unabhängig",
    "unabhängigere": "unabhängig",
    "unabhängigerem": "unabhängig",
    "unabhängigeren": "unabhängig",
    "unabhängigerer": "unabhängig",
    "unabhängigeres": "unabhängig",
    "unabhängiges": "unabhängig",
    "unabhängigstem": "unabhängig",
    "unabhängigsten": "unabhängig",
    "unabhängigster": "unabhängig",
    "unabhängigstes": "unabhängig",
    "unabkömmliche": "unabkömmlich",
    "unabkömmlichem": "unabkömmlich",
    "unabkömmlichen": "unabkömmlich",
    "unabkömmlicher": "unabkömmlich",
    "unabkömmliches": "unabkömmlich",
    "unabsehbare": "unabsehbar",
    "unabsehbarem": "unabsehbar",
    "unabsehbaren": "unabsehbar",
    "unabsehbarer": "unabsehbar",
    "unabsehbares": "unabsehbar",
    "unabsichtliche": "unabsichtlich",
    "unabsichtlichem": "unabsichtlich",
    "unabsichtlichen": "unabsichtlich",
    "unabsichtlicher": "unabsichtlich",
    "unabsichtliches": "unabsichtlich",
    "unachtsame": "unachtsam",
    "unachtsamem": "unachtsam",
    "unachtsamen": "unachtsam",
    "unachtsamer": "unachtsam",
    "unachtsamere": "unachtsam",
    "unachtsamerem": "unachtsam",
    "unachtsameren": "unachtsam",
    "unachtsamerer": "unachtsam",
    "unachtsameres": "unachtsam",
    "unachtsames": "unachtsam",
    "unachtsamste": "unachtsam",
    "unachtsamstem": "unachtsam",
    "unachtsamsten": "unachtsam",
    "unachtsamster": "unachtsam",
    "unachtsamstes": "unachtsam",
    "unangebrachte": "unangebracht",
    "unangebrachtem": "unangebracht",
    "unangebrachten": "unangebracht",
    "unangebrachter": "unangebracht",
    "unangebrachtere": "unangebracht",
    "unangebrachterem": "unangebracht",
    "unangebrachteren": "unangebracht",
    "unangebrachterer": "unangebracht",
    "unangebrachteres": "unangebracht",
    "unangebrachtes": "unangebracht",
    "unangebrachteste": "unangebracht",
    "unangebrachtestem": "unangebracht",
    "unangebrachtesten": "unangebracht",
    "unangebrachtester": "unangebracht",
    "unangebrachtestes": "unangebracht",
    "unangefochtene": "unangefochten",
    "unangefochtenem": "unangefochten",
    "unangefochtenen": "unangefochten",
    "unangefochtener": "unangefochten",
    "unangefochtenes": "unangefochten",
    "unangemeldete": "unangemeldet",
    "unangemeldetem": "unangemeldet",
    "unangemeldeten": "unangemeldet",
    "unangemeldeter": "unangemeldet",
    "unangemeldetes": "unangemeldet",
    "unangemessene": "unangemessen",
    "unangemessenem": "unangemessen",
    "unangemessenen": "unangemessen",
    "unangemessener": "unangemessen",
    "unangemessenere": "unangemessen",
    "unangemessenerem": "unangemessen",
    "unangemesseneren": "unangemessen",
    "unangemessenerer": "unangemessen",
    "unangemesseneres": "unangemessen",
    "unangemessenes": "unangemessen",
    "unangemessenste": "unangemessen",
    "unangemessenstem": "unangemessen",
    "unangemessensten": "unangemessen",
    "unangemessenster": "unangemessen",
    "unangemessenstes": "unangemessen",
    "unangenehme": "unangenehm",
    "unangenehmem": "unangenehm",
    "unangenehmen": "unangenehm",
    "unangenehmer": "unangenehm",
    "unangenehmere": "unangenehm",
    "unangenehmerem": "unangenehm",
    "unangenehmeren": "unangenehm",
    "unangenehmerer": "unangenehm",
    "unangenehmeres": "unangenehm",
    "unangenehmes": "unangenehm",
    "unangenehmste": "unangenehm",
    "unangenehmstem": "unangenehm",
    "unangenehmsten": "unangenehm",
    "unangenehmster": "unangenehm",
    "unangenehmstes": "unangenehm",
    "unangetastete": "unangetastet",
    "unangetastetem": "unangetastet",
    "unangetasteten": "unangetastet",
    "unangetasteter": "unangetastet",
    "unangetastetes": "unangetastet",
    "unansehnlichem": "unansehnlich",
    "unansehnlichen": "unansehnlich",
    "unansehnlicher": "unansehnlich",
    "unansehnliches": "unansehnlich",
    "unanständige": "unanständig",
    "unanständigem": "unanständig",
    "unanständigen": "unanständig",
    "unanständiger": "unanständig",
    "unanständigere": "unanständig",
    "unanständigerem": "unanständig",
    "unanständigeren": "unanständig",
    "unanständigerer": "unanständig",
    "unanständigeres": "unanständig",
    "unanständiges": "unanständig",
    "unanständigste": "unanständig",
    "unanständigstem": "unanständig",
    "unanständigsten": "unanständig",
    "unanständigster": "unanständig",
    "unanständigstes": "unanständig",
    "unappetitliche": "unappetitlich",
    "unappetitlichem": "unappetitlich",
    "unappetitlichen": "unappetitlich",
    "unappetitlicher": "unappetitlich",
    "unappetitlichere": "unappetitlich",
    "unappetitlicherem": "unappetitlich",
    "unappetitlicheren": "unappetitlich",
    "unappetitlicherer": "unappetitlich",
    "unappetitlicheres": "unappetitlich",
    "unappetitliches": "unappetitlich",
    "unappetitlichste": "unappetitlich",
    "unappetitlichstem": "unappetitlich",
    "unappetitlichsten": "unappetitlich",
    "unappetitlichster": "unappetitlich",
    "unappetitlichstes": "unappetitlich",
    "unartige": "unartig",
    "unartigem": "unartig",
    "unartigen": "unartig",
    "unartiger": "unartig",
    "unartiges": "unartig",
    "unaufdringliche": "unaufdringlich",
    "unaufdringlichem": "unaufdringlich",
    "unaufdringlichen": "unaufdringlich",
    "unaufdringlicher": "unaufdringlich",
    "unaufdringlichere": "unaufdringlich",
    "unaufdringlicherem": "unaufdringlich",
    "unaufdringlicheren": "unaufdringlich",
    "unaufdringlicherer": "unaufdringlich",
    "unaufdringlicheres": "unaufdringlich",
    "unaufdringliches": "unaufdringlich",
    "unaufdringlichste": "unaufdringlich",
    "unaufdringlichstem": "unaufdringlich",
    "unaufdringlichsten": "unaufdringlich",
    "unaufdringlichster": "unaufdringlich",
    "unaufdringlichstes": "unaufdringlich",
    "unauffällige": "unauffällig",
    "unauffälligem": "unauffällig",
    "unauffälligen": "unauffällig",
    "unauffälliger": "unauffällig",
    "unauffälligere": "unauffällig",
    "unauffälligerem": "unauffällig",
    "unauffälligeren": "unauffällig",
    "unauffälligerer": "unauffällig",
    "unauffälligeres": "unauffällig",
    "unauffälliges": "unauffällig",
    "unauffälligste": "unauffällig",
    "unauffälligstem": "unauffällig",
    "unauffälligsten": "unauffällig",
    "unauffälligster": "unauffällig",
    "unauffälligstes": "unauffällig",
    "unaufgeforderte": "unaufgefordert",
    "unaufgefordertem": "unaufgefordert",
    "unaufgeforderten": "unaufgefordert",
    "unaufgeforderter": "unaufgefordert",
    "unaufgefordertes": "unaufgefordert",
    "unaufhaltsame": "unaufhaltsam",
    "unaufhaltsamem": "unaufhaltsam",
    "unaufhaltsamen": "unaufhaltsam",
    "unaufhaltsamer": "unaufhaltsam",
    "unaufhaltsamere": "unaufhaltsam",
    "unaufhaltsamerem": "unaufhaltsam",
    "unaufhaltsameren": "unaufhaltsam",
    "unaufhaltsamerer": "unaufhaltsam",
    "unaufhaltsameres": "unaufhaltsam",
    "unaufhaltsames": "unaufhaltsam",
    "unaufhaltsamste": "unaufhaltsam",
    "unaufhaltsamstem": "unaufhaltsam",
    "unaufhaltsamsten": "unaufhaltsam",
    "unaufhaltsamster": "unaufhaltsam",
    "unaufhaltsamstes": "unaufhaltsam",
    "unaufmerksame": "unaufmerksam",
    "unaufmerksamem": "unaufmerksam",
    "unaufmerksamen": "unaufmerksam",
    "unaufmerksamer": "unaufmerksam",
    "unaufmerksamere": "unaufmerksam",
    "unaufmerksamerem": "unaufmerksam",
    "unaufmerksameren": "unaufmerksam",
    "unaufmerksamerer": "unaufmerksam",
    "unaufmerksameres": "unaufmerksam",
    "unaufmerksames": "unaufmerksam",
    "unaufmerksamste": "unaufmerksam",
    "unaufmerksamstem": "unaufmerksam",
    "unaufmerksamsten": "unaufmerksam",
    "unaufmerksamster": "unaufmerksam",
    "unaufmerksamstes": "unaufmerksam",
    "unaufrichtige": "unaufrichtig",
    "unaufrichtigem": "unaufrichtig",
    "unaufrichtigen": "unaufrichtig",
    "unaufrichtiger": "unaufrichtig",
    "unaufrichtigere": "unaufrichtig",
    "unaufrichtigerem": "unaufrichtig",
    "unaufrichtigeren": "unaufrichtig",
    "unaufrichtigerer": "unaufrichtig",
    "unaufrichtigeres": "unaufrichtig",
    "unaufrichtiges": "unaufrichtig",
    "unaufrichtigste": "unaufrichtig",
    "unaufrichtigstem": "unaufrichtig",
    "unaufrichtigsten": "unaufrichtig",
    "unaufrichtigster": "unaufrichtig",
    "unaufrichtigstes": "unaufrichtig",
    "unaufschiebliche": "unaufschieblich",
    "unaufschieblichem": "unaufschieblich",
    "unaufschieblichen": "unaufschieblich",
    "unaufschieblicher": "unaufschieblich",
    "unaufschiebliches": "unaufschieblich",
    "unausgeglichene": "unausgeglichen",
    "unausgeglichenem": "unausgeglichen",
    "unausgeglichenen": "unausgeglichen",
    "unausgeglichener": "unausgeglichen",
    "unausgeglichenere": "unausgeglichen",
    "unausgeglichenerem": "unausgeglichen",
    "unausgeglicheneren": "unausgeglichen",
    "unausgeglichenerer": "unausgeglichen",
    "unausgeglicheneres": "unausgeglichen",
    "unausgeglichenes": "unausgeglichen",
    "unausgeglichenste": "unausgeglichen",
    "unausgeglichenstem": "unausgeglichen",
    "unausgeglichensten": "unausgeglichen",
    "unausgeglichenster": "unausgeglichen",
    "unausgeglichenstes": "unausgeglichen",
    "unausgegorene": "unausgegoren",
    "unausgegorenem": "unausgegoren",
    "unausgegorenen": "unausgegoren",
    "unausgegorener": "unausgegoren",
    "unausgegorenere": "unausgegoren",
    "unausgegorenerem": "unausgegoren",
    "unausgegoreneren": "unausgegoren",
    "unausgegorenerer": "unausgegoren",
    "unausgegoreneres": "unausgegoren",
    "unausgegorenes": "unausgegoren",
    "unausgegorenste": "unausgegoren",
    "unausgegorenstem": "unausgegoren",
    "unausgegorensten": "unausgegoren",
    "unausgegorenster": "unausgegoren",
    "unausgegorenstes": "unausgegoren",
    "unbarmherzige": "unbarmherzig",
    "unbarmherzigem": "unbarmherzig",
    "unbarmherzigen": "unbarmherzig",
    "unbarmherziger": "unbarmherzig",
    "unbarmherzigere": "unbarmherzig",
    "unbarmherzigerem": "unbarmherzig",
    "unbarmherzigeren": "unbarmherzig",
    "unbarmherzigerer": "unbarmherzig",
    "unbarmherzigeres": "unbarmherzig",
    "unbarmherziges": "unbarmherzig",
    "unbarmherzigste": "unbarmherzig",
    "unbarmherzigstem": "unbarmherzig",
    "unbarmherzigsten": "unbarmherzig",
    "unbarmherzigster": "unbarmherzig",
    "unbarmherzigstes": "unbarmherzig",
    "unbeabsichtigte": "unbeabsichtigt",
    "unbeabsichtigtem": "unbeabsichtigt",
    "unbeabsichtigten": "unbeabsichtigt",
    "unbeabsichtigter": "unbeabsichtigt",
    "unbeabsichtigtes": "unbeabsichtigt",
    "unbeachtete": "unbeachtet",
    "unbeachtetem": "unbeachtet",
    "unbeachteten": "unbeachtet",
    "unbeachteter": "unbeachtet",
    "unbeachtetere": "unbeachtet",
    "unbeachteterem": "unbeachtet",
    "unbeachteteren": "unbeachtet",
    "unbeachteterer": "unbeachtet",
    "unbeachteteres": "unbeachtet",
    "unbeachtetes": "unbeachtet",
    "unbeachteteste": "unbeachtet",
    "unbeachtetestem": "unbeachtet",
    "unbeachtetesten": "unbeachtet",
    "unbeachtetester": "unbeachtet",
    "unbeachtetestes": "unbeachtet",
    "unbedenkliche": "unbedenklich",
    "unbedenklichem": "unbedenklich",
    "unbedenklichen": "unbedenklich",
    "unbedenklicher": "unbedenklich",
    "unbedenklichere": "unbedenklich",
    "unbedenklicherem": "unbedenklich",
    "unbedenklicheren": "unbedenklich",
    "unbedenklicherer": "unbedenklich",
    "unbedenklicheres": "unbedenklich",
    "unbedenkliches": "unbedenklich",
    "unbedenklichstem": "unbedenklich",
    "unbedenklichsten": "unbedenklich",
    "unbedenklichster": "unbedenklich",
    "unbedenklichstes": "unbedenklich",
    "unbedeutende": "unbedeutend",
    "unbedeutendem": "unbedeutend",
    "unbedeutenden": "unbedeutend",
    "unbedeutender": "unbedeutend",
    "unbedeutendere": "unbedeutend",
    "unbedeutenderem": "unbedeutend",
    "unbedeutenderen": "unbedeutend",
    "unbedeutenderer": "unbedeutend",
    "unbedeutenderes": "unbedeutend",
    "unbedeutendes": "unbedeutend",
    "unbedeutendste": "unbedeutend",
    "unbedeutendstem": "unbedeutend",
    "unbedeutendsten": "unbedeutend",
    "unbedeutendster": "unbedeutend",
    "unbedeutendstes": "unbedeutend",
    "unbedingte": "unbedingt",
    "unbedingtem": "unbedingt",
    "unbedingten": "unbedingt",
    "unbedingter": "unbedingt",
    "unbedingtes": "unbedingt",
    "unbefangene": "unbefangen",
    "unbefangenem": "unbefangen",
    "unbefangenen": "unbefangen",
    "unbefangener": "unbefangen",
    "unbefangenere": "unbefangen",
    "unbefangenerem": "unbefangen",
    "unbefangeneren": "unbefangen",
    "unbefangenerer": "unbefangen",
    "unbefangeneres": "unbefangen",
    "unbefangenes": "unbefangen",
    "unbefangenste": "unbefangen",
    "unbefangenstem": "unbefangen",
    "unbefangensten": "unbefangen",
    "unbefangenster": "unbefangen",
    "unbefangenstes": "unbefangen",
    "unbefleckte": "unbefleckt",
    "unbeflecktem": "unbefleckt",
    "unbefleckten": "unbefleckt",
    "unbefleckter": "unbefleckt",
    "unbeflecktere": "unbefleckt",
    "unbefleckterem": "unbefleckt",
    "unbefleckteren": "unbefleckt",
    "unbefleckterer": "unbefleckt",
    "unbefleckteres": "unbefleckt",
    "unbeflecktes": "unbefleckt",
    "unbefleckteste": "unbefleckt",
    "unbeflecktestem": "unbefleckt",
    "unbeflecktesten": "unbefleckt",
    "unbeflecktester": "unbefleckt",
    "unbeflecktestes": "unbefleckt",
    "unbefriedigende": "unbefriedigend",
    "unbefriedigendem": "unbefriedigend",
    "unbefriedigenden": "unbefriedigend",
    "unbefriedigender": "unbefriedigend",
    "unbefriedigendere": "unbefriedigend",
    "unbefriedigenderem": "unbefriedigend",
    "unbefriedigenderen": "unbefriedigend",
    "unbefriedigenderer": "unbefriedigend",
    "unbefriedigenderes": "unbefriedigend",
    "unbefriedigendes": "unbefriedigend",
    "unbefriedigendste": "unbefriedigend",
    "unbefriedigendstem": "unbefriedigend",
    "unbefriedigendsten": "unbefriedigend",
    "unbefriedigendster": "unbefriedigend",
    "unbefriedigendstes": "unbefriedigend",
    "unbefriedigte": "unbefriedigt",
    "unbefriedigtem": "unbefriedigt",
    "unbefriedigten": "unbefriedigt",
    "unbefriedigter": "unbefriedigt",
    "unbefriedigtere": "unbefriedigt",
    "unbefriedigterem": "unbefriedigt",
    "unbefriedigteren": "unbefriedigt",
    "unbefriedigterer": "unbefriedigt",
    "unbefriedigteres": "unbefriedigt",
    "unbefriedigtes": "unbefriedigt",
    "unbefriedigteste": "unbefriedigt",
    "unbefriedigtestem": "unbefriedigt",
    "unbefriedigtesten": "unbefriedigt",
    "unbefriedigtester": "unbefriedigt",
    "unbefriedigtestes": "unbefriedigt",
    "unbefristete": "unbefristet",
    "unbefristetem": "unbefristet",
    "unbefristeten": "unbefristet",
    "unbefristeter": "unbefristet",
    "unbefristetes": "unbefristet",
    "unbegabte": "unbegabt",
    "unbegabtem": "unbegabt",
    "unbegabten": "unbegabt",
    "unbegabter": "unbegabt",
    "unbegabtere": "unbegabt",
    "unbegabterem": "unbegabt",
    "unbegabteren": "unbegabt",
    "unbegabterer": "unbegabt",
    "unbegabteres": "unbegabt",
    "unbegabtes": "unbegabt",
    "unbegabteste": "unbegabt",
    "unbegabtestem": "unbegabt",
    "unbegabtesten": "unbegabt",
    "unbegabtester": "unbegabt",
    "unbegabtestes": "unbegabt",
    "unbegleitete": "unbegleitet",
    "unbegleitetem": "unbegleitet",
    "unbegleiteten": "unbegleitet",
    "unbegleiteter": "unbegleitet",
    "unbegleitetes": "unbegleitet",
    "unbegrenzte": "unbegrenzt",
    "unbegrenztem": "unbegrenzt",
    "unbegrenzten": "unbegrenzt",
    "unbegrenzter": "unbegrenzt",
    "unbegrenztere": "unbegrenzt",
    "unbegrenzterem": "unbegrenzt",
    "unbegrenzteren": "unbegrenzt",
    "unbegrenzterer": "unbegrenzt",
    "unbegrenzteres": "unbegrenzt",
    "unbegrenztes": "unbegrenzt",
    "unbegrenzteste": "unbegrenzt",
    "unbegrenztestem": "unbegrenzt",
    "unbegrenztesten": "unbegrenzt",
    "unbegrenztester": "unbegrenzt",
    "unbegrenztestes": "unbegrenzt",
    "unbegründete": "unbegründet",
    "unbegründetem": "unbegründet",
    "unbegründeten": "unbegründet",
    "unbegründeter": "unbegründet",
    "unbegründetere": "unbegründet",
    "unbegründeterem": "unbegründet",
    "unbegründeteren": "unbegründet",
    "unbegründeterer": "unbegründet",
    "unbegründeteres": "unbegründet",
    "unbegründetes": "unbegründet",
    "unbegründeteste": "unbegründet",
    "unbegründetestem": "unbegründet",
    "unbegründetesten": "unbegründet",
    "unbegründetester": "unbegründet",
    "unbegründetestes": "unbegründet",
    "unbehaglichem": "unbehaglich",
    "unbehaglichen": "unbehaglich",
    "unbehaglicher": "unbehaglich",
    "unbehaglichere": "unbehaglich",
    "unbehaglicherem": "unbehaglich",
    "unbehaglicheren": "unbehaglich",
    "unbehaglicherer": "unbehaglich",
    "unbehaglicheres": "unbehaglich",
    "unbehagliches": "unbehaglich",
    "unbehaglichste": "unbehaglich",
    "unbehaglichstem": "unbehaglich",
    "unbehaglichsten": "unbehaglich",
    "unbehaglichster": "unbehaglich",
    "unbehaglichstes": "unbehaglich",
    "unbehelligte": "unbehelligt",
    "unbehelligtem": "unbehelligt",
    "unbehelligten": "unbehelligt",
    "unbehelligter": "unbehelligt",
    "unbehelligtes": "unbehelligt",
    "unbeherrschte": "unbeherrscht",
    "unbeherrschtem": "unbeherrscht",
    "unbeherrschten": "unbeherrscht",
    "unbeherrschter": "unbeherrscht",
    "unbeherrschtere": "unbeherrscht",
    "unbeherrschterem": "unbeherrscht",
    "unbeherrschteren": "unbeherrscht",
    "unbeherrschterer": "unbeherrscht",
    "unbeherrschteres": "unbeherrscht",
    "unbeherrschtes": "unbeherrscht",
    "unbeherrschteste": "unbeherrscht",
    "unbeherrschtestem": "unbeherrscht",
    "unbeherrschtesten": "unbeherrscht",
    "unbeherrschtester": "unbeherrscht",
    "unbeherrschtestes": "unbeherrscht",
    "unbeholfene": "unbeholfen",
    "unbeholfenem": "unbeholfen",
    "unbeholfenen": "unbeholfen",
    "unbeholfener": "unbeholfen",
    "unbeholfenere": "unbeholfen",
    "unbeholfenerem": "unbeholfen",
    "unbeholfeneren": "unbeholfen",
    "unbeholfenerer": "unbeholfen",
    "unbeholfeneres": "unbeholfen",
    "unbeholfenes": "unbeholfen",
    "unbeholfenste": "unbeholfen",
    "unbeholfenstem": "unbeholfen",
    "unbeholfensten": "unbeholfen",
    "unbeholfenster": "unbeholfen",
    "unbeholfenstes": "unbeholfen",
    "unbekannte": "unbekannt",
    "unbekanntem": "unbekannt",
    "unbekannten": "unbekannt",
    "unbekannter": "unbekannt",
    "unbekanntere": "unbekannt",
    "unbekannterem": "unbekannt",
    "unbekannteren": "unbekannt",
    "unbekannterer": "unbekannt",
    "unbekannteres": "unbekannt",
    "unbekanntes": "unbekannt",
    "unbekannteste": "unbekannt",
    "unbekanntestem": "unbekannt",
    "unbekanntesten": "unbekannt",
    "unbekanntester": "unbekannt",
    "unbekanntestes": "unbekannt",
    "unbekleidete": "unbekleidet",
    "unbekleidetem": "unbekleidet",
    "unbekleideten": "unbekleidet",
    "unbekleideter": "unbekleidet",
    "unbekleidetes": "unbekleidet",
    "unbekümmerte": "unbekümmert",
    "unbekümmertem": "unbekümmert",
    "unbekümmerten": "unbekümmert",
    "unbekümmerter": "unbekümmert",
    "unbekümmertere": "unbekümmert",
    "unbekümmerterem": "unbekümmert",
    "unbekümmerteren": "unbekümmert",
    "unbekümmerterer": "unbekümmert",
    "unbekümmerteres": "unbekümmert",
    "unbekümmertes": "unbekümmert",
    "unbekümmerteste": "unbekümmert",
    "unbekümmertestem": "unbekümmert",
    "unbekümmertesten": "unbekümmert",
    "unbekümmertester": "unbekümmert",
    "unbekümmertestes": "unbekümmert",
    "unbelastete": "unbelastet",
    "unbelastetem": "unbelastet",
    "unbelasteten": "unbelastet",
    "unbelasteter": "unbelastet",
    "unbelastetere": "unbelastet",
    "unbelasteterem": "unbelastet",
    "unbelasteteren": "unbelastet",
    "unbelasteterer": "unbelastet",
    "unbelasteteres": "unbelastet",
    "unbelastetes": "unbelastet",
    "unbelastetste": "unbelastet",
    "unbelastetstem": "unbelastet",
    "unbelastetsten": "unbelastet",
    "unbelastetster": "unbelastet",
    "unbelastetstes": "unbelastet",
    "unbeliebte": "unbeliebt",
    "unbeliebtem": "unbeliebt",
    "unbeliebten": "unbeliebt",
    "unbeliebter": "unbeliebt",
    "unbeliebtere": "unbeliebt",
    "unbeliebterem": "unbeliebt",
    "unbeliebteren": "unbeliebt",
    "unbeliebterer": "unbeliebt",
    "unbeliebteres": "unbeliebt",
    "unbeliebtes": "unbeliebt",
    "unbeliebteste": "unbeliebt",
    "unbeliebtestem": "unbeliebt",
    "unbeliebtesten": "unbeliebt",
    "unbeliebtester": "unbeliebt",
    "unbeliebtestes": "unbeliebt",
    "unbemannte": "unbemannt",
    "unbemanntem": "unbemannt",
    "unbemannten": "unbemannt",
    "unbemannter": "unbemannt",
    "unbemanntes": "unbemannt",
    "unbemerkte": "unbemerkt",
    "unbemerktem": "unbemerkt",
    "unbemerkten": "unbemerkt",
    "unbemerkter": "unbemerkt",
    "unbemerktes": "unbemerkt",
    "unbenutzte": "unbenutzt",
    "unbenutztem": "unbenutzt",
    "unbenutzten": "unbenutzt",
    "unbenutzter": "unbenutzt",
    "unbenutztes": "unbenutzt",
    "unbequeme": "unbequem",
    "unbequemem": "unbequem",
    "unbequemen": "unbequem",
    "unbequemer": "unbequem",
    "unbequemere": "unbequem",
    "unbequemerem": "unbequem",
    "unbequemeren": "unbequem",
    "unbequemerer": "unbequem",
    "unbequemeres": "unbequem",
    "unbequemes": "unbequem",
    "unbequemste": "unbequem",
    "unbequemstem": "unbequem",
    "unbequemsten": "unbequem",
    "unbequemster": "unbequem",
    "unbequemstes": "unbequem",
    "unberechtigte": "unberechtigt",
    "unberechtigtem": "unberechtigt",
    "unberechtigten": "unberechtigt",
    "unberechtigter": "unberechtigt",
    "unberechtigtes": "unberechtigt",
    "unberücksichtigte": "unberücksichtigt",
    "unberücksichtigtem": "unberücksichtigt",
    "unberücksichtigten": "unberücksichtigt",
    "unberücksichtigter": "unberücksichtigt",
    "unberücksichtigtes": "unberücksichtigt",
    "unberührte": "unberührt",
    "unberührtem": "unberührt",
    "unberührten": "unberührt",
    "unberührter": "unberührt",
    "unberührtere": "unberührt",
    "unberührterem": "unberührt",
    "unberührteren": "unberührt",
    "unberührterer": "unberührt",
    "unberührteres": "unberührt",
    "unberührtes": "unberührt",
    "unberührteste": "unberührt",
    "unberührtestem": "unberührt",
    "unberührtesten": "unberührt",
    "unberührtester": "unberührt",
    "unberührtestes": "unberührt",
    "unbescheidene": "unbescheiden",
    "unbescheidenem": "unbescheiden",
    "unbescheidenen": "unbescheiden",
    "unbescheidener": "unbescheiden",
    "unbescheidenere": "unbescheiden",
    "unbescheidenerem": "unbescheiden",
    "unbescheideneren": "unbescheiden",
    "unbescheidenerer": "unbescheiden",
    "unbescheideneres": "unbescheiden",
    "unbescheidenes": "unbescheiden",
    "unbescheidenste": "unbescheiden",
    "unbescheidenstem": "unbescheiden",
    "unbescheidensten": "unbescheiden",
    "unbescheidenster": "unbescheiden",
    "unbescheidenstes": "unbescheiden",
    "unbescholtene": "unbescholten",
    "unbescholtenem": "unbescholten",
    "unbescholtenen": "unbescholten",
    "unbescholtener": "unbescholten",
    "unbescholtenes": "unbescholten",
    "unbeschwerte": "unbeschwert",
    "unbeschwertem": "unbeschwert",
    "unbeschwerten": "unbeschwert",
    "unbeschwerter": "unbeschwert",
    "unbeschwertere": "unbeschwert",
    "unbeschwerterem": "unbeschwert",
    "unbeschwerteren": "unbeschwert",
    "unbeschwerterer": "unbeschwert",
    "unbeschwerteres": "unbeschwert",
    "unbeschwertes": "unbeschwert",
    "unbeschwerteste": "unbeschwert",
    "unbeschwertestem": "unbeschwert",
    "unbeschwertesten": "unbeschwert",
    "unbeschwertester": "unbeschwert",
    "unbeschwertestes": "unbeschwert",
    "unbeschädigte": "unbeschädigt",
    "unbeschädigtem": "unbeschädigt",
    "unbeschädigten": "unbeschädigt",
    "unbeschädigter": "unbeschädigt",
    "unbeschädigtes": "unbeschädigt",
    "unbesonnene": "unbesonnen",
    "unbesonnenem": "unbesonnen",
    "unbesonnenen": "unbesonnen",
    "unbesonnener": "unbesonnen",
    "unbesonnenes": "unbesonnen",
    "unbespielte": "unbespielt",
    "unbespieltem": "unbespielt",
    "unbespielten": "unbespielt",
    "unbespielter": "unbespielt",
    "unbespieltes": "unbespielt",
    "unbestimmte": "unbestimmt",
    "unbestimmtem": "unbestimmt",
    "unbestimmten": "unbestimmt",
    "unbestimmter": "unbestimmt",
    "unbestimmtes": "unbestimmt",
    "unbeständige": "unbeständig",
    "unbeständigem": "unbeständig",
    "unbeständigen": "unbeständig",
    "unbeständiger": "unbeständig",
    "unbeständigere": "unbeständig",
    "unbeständigerem": "unbeständig",
    "unbeständigeren": "unbeständig",
    "unbeständigerer": "unbeständig",
    "unbeständigeres": "unbeständig",
    "unbeständiges": "unbeständig",
    "unbeständigste": "unbeständig",
    "unbeständigstem": "unbeständig",
    "unbeständigsten": "unbeständig",
    "unbeständigster": "unbeständig",
    "unbeständigstes": "unbeständig",
    "unbestätigte": "unbestätigt",
    "unbestätigtem": "unbestätigt",
    "unbestätigten": "unbestätigt",
    "unbestätigter": "unbestätigt",
    "unbestätigtes": "unbestätigt",
    "unbeteiligte": "unbeteiligt",
    "unbeteiligtem": "unbeteiligt",
    "unbeteiligten": "unbeteiligt",
    "unbeteiligter": "unbeteiligt",
    "unbeteiligtes": "unbeteiligt",
    "unbewachte": "unbewacht",
    "unbewachtem": "unbewacht",
    "unbewachten": "unbewacht",
    "unbewachter": "unbewacht",
    "unbewachtes": "unbewacht",
    "unbewaffnete": "unbewaffnet",
    "unbewaffnetem": "unbewaffnet",
    "unbewaffneten": "unbewaffnet",
    "unbewaffneter": "unbewaffnet",
    "unbewaffnetes": "unbewaffnet",
    "unbewohnte": "unbewohnt",
    "unbewohntem": "unbewohnt",
    "unbewohnten": "unbewohnt",
    "unbewohnter": "unbewohnt",
    "unbewohntes": "unbewohnt",
    "unbewußte": "unbewußt",
    "unbewußtem": "unbewußt",
    "unbewußten": "unbewußt",
    "unbewußter": "unbewußt",
    "unbewußtere": "unbewußt",
    "unbewußterem": "unbewußt",
    "unbewußteren": "unbewußt",
    "unbewußterer": "unbewußt",
    "unbewußteres": "unbewußt",
    "unbewußtes": "unbewußt",
    "unbewußteste": "unbewußt",
    "unbewußtestem": "unbewußt",
    "unbewußtesten": "unbewußt",
    "unbewußtester": "unbewußt",
    "unbewußtestes": "unbewußt",
    "unbezahlbare": "unbezahlbar",
    "unbezahlbarem": "unbezahlbar",
    "unbezahlbaren": "unbezahlbar",
    "unbezahlbarer": "unbezahlbar",
    "unbezahlbarere": "unbezahlbar",
    "unbezahlbarerem": "unbezahlbar",
    "unbezahlbareren": "unbezahlbar",
    "unbezahlbarerer": "unbezahlbar",
    "unbezahlbareres": "unbezahlbar",
    "unbezahlbares": "unbezahlbar",
    "unbezahlbarste": "unbezahlbar",
    "unbezahlbarstem": "unbezahlbar",
    "unbezahlbarsten": "unbezahlbar",
    "unbezahlbarster": "unbezahlbar",
    "unbezahlbarstes": "unbezahlbar",
    "unbezahlte": "unbezahlt",
    "unbezahltem": "unbezahlt",
    "unbezahlten": "unbezahlt",
    "unbezahlter": "unbezahlt",
    "unbezahltes": "unbezahlt",
    "unblutige": "unblutig",
    "unblutigem": "unblutig",
    "unblutigen": "unblutig",
    "unblutiger": "unblutig",
    "unblutiges": "unblutig",
    "unbürokratische": "unbürokratisch",
    "unbürokratischem": "unbürokratisch",
    "unbürokratischen": "unbürokratisch",
    "unbürokratischer": "unbürokratisch",
    "unbürokratisches": "unbürokratisch",
    "uncharakteristische": "uncharakteristisch",
    "uncharakteristischem": "uncharakteristisch",
    "uncharakteristischen": "uncharakteristisch",
    "uncharakteristischer": "uncharakteristisch",
    "uncharakteristisches": "uncharakteristisch",
    "undankbare": "undankbar",
    "undankbarem": "undankbar",
    "undankbaren": "undankbar",
    "undankbarer": "undankbar",
    "undankbarere": "undankbar",
    "undankbarerem": "undankbar",
    "undankbareren": "undankbar",
    "undankbarerer": "undankbar",
    "undankbareres": "undankbar",
    "undankbares": "undankbar",
    "undankbarste": "undankbar",
    "undankbarstem": "undankbar",
    "undankbarsten": "undankbar",
    "undankbarster": "undankbar",
    "undankbarstes": "undankbar",
    "undenkbarem": "undenkbar",
    "undenkbaren": "undenkbar",
    "undenkbarer": "undenkbar",
    "undenkbares": "undenkbar",
    "undeutlichem": "undeutlich",
    "undeutlichen": "undeutlich",
    "undeutlicher": "undeutlich",
    "undeutlichere": "undeutlich",
    "undeutlicherem": "undeutlich",
    "undeutlicheren": "undeutlich",
    "undeutlicherer": "undeutlich",
    "undeutlicheres": "undeutlich",
    "undeutliches": "undeutlich",
    "undeutlichste": "undeutlich",
    "undeutlichstem": "undeutlich",
    "undeutlichsten": "undeutlich",
    "undeutlichster": "undeutlich",
    "undeutlichstes": "undeutlich",
    "undichte": "undicht",
    "undichtem": "undicht",
    "undichten": "undicht",
    "undichter": "undicht",
    "undichtere": "undicht",
    "undichterem": "undicht",
    "undichteren": "undicht",
    "undichterer": "undicht",
    "undichteres": "undicht",
    "undichtes": "undicht",
    "undichteste": "undicht",
    "undichtestem": "undicht",
    "undichtesten": "undicht",
    "undichtester": "undicht",
    "undichtestes": "undicht",
    "undurchführbarem": "undurchführbar",
    "undurchführbaren": "undurchführbar",
    "undurchführbarer": "undurchführbar",
    "undurchführbarere": "undurchführbar",
    "undurchführbarerem": "undurchführbar",
    "undurchführbareren": "undurchführbar",
    "undurchführbarerer": "undurchführbar",
    "undurchführbareres": "undurchführbar",
    "undurchführbares": "undurchführbar",
    "undurchführbarste": "undurchführbar",
    "undurchführbarstem": "undurchführbar",
    "undurchführbarsten": "undurchführbar",
    "undurchführbarster": "undurchführbar",
    "undurchführbarstes": "undurchführbar",
    "undurchlässige": "undurchlässig",
    "undurchlässigem": "undurchlässig",
    "undurchlässigen": "undurchlässig",
    "undurchlässiger": "undurchlässig",
    "undurchlässigere": "undurchlässig",
    "undurchlässigerem": "undurchlässig",
    "undurchlässigeren": "undurchlässig",
    "undurchlässigerer": "undurchlässig",
    "undurchlässigeres": "undurchlässig",
    "undurchlässiges": "undurchlässig",
    "undurchlässigste": "undurchlässig",
    "undurchlässigstem": "undurchlässig",
    "undurchlässigsten": "undurchlässig",
    "undurchlässigster": "undurchlässig",
    "undurchlässigstes": "undurchlässig",
    "undurchschaubare": "undurchschaubar",
    "undurchschaubarem": "undurchschaubar",
    "undurchschaubaren": "undurchschaubar",
    "undurchschaubarer": "undurchschaubar",
    "undurchschaubarere": "undurchschaubar",
    "undurchschaubarerem": "undurchschaubar",
    "undurchschaubareren": "undurchschaubar",
    "undurchschaubarerer": "undurchschaubar",
    "undurchschaubareres": "undurchschaubar",
    "undurchschaubares": "undurchschaubar",
    "undurchschaubarste": "undurchschaubar",
    "undurchschaubarstem": "undurchschaubar",
    "undurchschaubarsten": "undurchschaubar",
    "undurchschaubarster": "undurchschaubar",
    "undurchschaubarstes": "undurchschaubar",
    "undurchsichtige": "undurchsichtig",
    "undurchsichtigem": "undurchsichtig",
    "undurchsichtigen": "undurchsichtig",
    "undurchsichtiger": "undurchsichtig",
    "undurchsichtigere": "undurchsichtig",
    "undurchsichtigerem": "undurchsichtig",
    "undurchsichtigeren": "undurchsichtig",
    "undurchsichtigerer": "undurchsichtig",
    "undurchsichtigeres": "undurchsichtig",
    "undurchsichtiges": "undurchsichtig",
    "undurchsichtigste": "undurchsichtig",
    "undurchsichtigstem": "undurchsichtig",
    "undurchsichtigsten": "undurchsichtig",
    "undurchsichtigster": "undurchsichtig",
    "undurchsichtigstes": "undurchsichtig",
    "unebene": "uneben",
    "unebenem": "uneben",
    "unebenen": "uneben",
    "unebener": "uneben",
    "unebenere": "uneben",
    "unebenerem": "uneben",
    "unebeneren": "uneben",
    "unebenerer": "uneben",
    "unebeneres": "uneben",
    "unebenes": "uneben",
    "unebenstem": "uneben",
    "unebensten": "uneben",
    "unebenster": "uneben",
    "unebenstes": "uneben",
    "unechte": "unecht",
    "unechtem": "unecht",
    "unechten": "unecht",
    "unechter": "unecht",
    "unechtes": "unecht",
    "uneheliche": "unehelich",
    "unehelichem": "unehelich",
    "unehelichen": "unehelich",
    "unehelicher": "unehelich",
    "uneheliches": "unehelich",
    "unehrenhafte": "unehrenhaft",
    "unehrenhaftem": "unehrenhaft",
    "unehrenhaften": "unehrenhaft",
    "unehrenhafter": "unehrenhaft",
    "unehrenhaftes": "unehrenhaft",
    "unehrliche": "unehrlich",
    "unehrlichem": "unehrlich",
    "unehrlichen": "unehrlich",
    "unehrlicher": "unehrlich",
    "unehrliches": "unehrlich",
    "uneigennützige": "uneigennützig",
    "uneigennützigem": "uneigennützig",
    "uneigennützigen": "uneigennützig",
    "uneigennütziger": "uneigennützig",
    "uneigennütziges": "uneigennützig",
    "uneingeschränkte": "uneingeschränkt",
    "uneingeschränktem": "uneingeschränkt",
    "uneingeschränkten": "uneingeschränkt",
    "uneingeschränkter": "uneingeschränkt",
    "uneingeschränktes": "uneingeschränkt",
    "unempfindliche": "unempfindlich",
    "unempfindlichem": "unempfindlich",
    "unempfindlichen": "unempfindlich",
    "unempfindlicher": "unempfindlich",
    "unempfindlichere": "unempfindlich",
    "unempfindlicherem": "unempfindlich",
    "unempfindlicheren": "unempfindlich",
    "unempfindlicherer": "unempfindlich",
    "unempfindlicheres": "unempfindlich",
    "unempfindliches": "unempfindlich",
    "unempfindlichste": "unempfindlich",
    "unempfindlichstem": "unempfindlich",
    "unempfindlichsten": "unempfindlich",
    "unempfindlichster": "unempfindlich",
    "unempfindlichstes": "unempfindlich",
    "unentbehrliche": "unentbehrlich",
    "unentbehrlichem": "unentbehrlich",
    "unentbehrlichen": "unentbehrlich",
    "unentbehrlicher": "unentbehrlich",
    "unentbehrlichere": "unentbehrlich",
    "unentbehrlicherem": "unentbehrlich",
    "unentbehrlicheren": "unentbehrlich",
    "unentbehrlicherer": "unentbehrlich",
    "unentbehrlicheres": "unentbehrlich",
    "unentbehrliches": "unentbehrlich",
    "unentbehrlichste": "unentbehrlich",
    "unentbehrlichstem": "unentbehrlich",
    "unentbehrlichsten": "unentbehrlich",
    "unentbehrlichster": "unentbehrlich",
    "unentbehrlichstes": "unentbehrlich",
    "unentschiedene": "unentschieden",
    "unentschiedenem": "unentschieden",
    "unentschiedenen": "unentschieden",
    "unentschiedener": "unentschieden",
    "unentschiedenere": "unentschieden",
    "unentschiedenerem": "unentschieden",
    "unentschiedeneren": "unentschieden",
    "unentschiedenerer": "unentschieden",
    "unentschiedeneres": "unentschieden",
    "unentschiedenes": "unentschieden",
    "unentschiedenste": "unentschieden",
    "unentschiedenstem": "unentschieden",
    "unentschiedensten": "unentschieden",
    "unentschiedenster": "unentschieden",
    "unentschiedenstes": "unentschieden",
    "unentschlossene": "unentschlossen",
    "unentschlossenem": "unentschlossen",
    "unentschlossenen": "unentschlossen",
    "unentschlossener": "unentschlossen",
    "unentschlossenere": "unentschlossen",
    "unentschlossenerem": "unentschlossen",
    "unentschlosseneren": "unentschlossen",
    "unentschlossenerer": "unentschlossen",
    "unentschlosseneres": "unentschlossen",
    "unentschlossenes": "unentschlossen",
    "unentschlossenste": "unentschlossen",
    "unentschlossenstem": "unentschlossen",
    "unentschlossensten": "unentschlossen",
    "unentschlossenster": "unentschlossen",
    "unentschlossenstes": "unentschlossen",
    "unentschuldigte": "unentschuldigt",
    "unentschuldigtem": "unentschuldigt",
    "unentschuldigten": "unentschuldigt",
    "unentschuldigter": "unentschuldigt",
    "unentschuldigtes": "unentschuldigt",
    "unerfahrene": "unerfahren",
    "unerfahrenem": "unerfahren",
    "unerfahrenen": "unerfahren",
    "unerfahrener": "unerfahren",
    "unerfahrenere": "unerfahren",
    "unerfahrenerem": "unerfahren",
    "unerfahreneren": "unerfahren",
    "unerfahrenerer": "unerfahren",
    "unerfahreneres": "unerfahren",
    "unerfahrenes": "unerfahren",
    "unerfahrenste": "unerfahren",
    "unerfahrenstem": "unerfahren",
    "unerfahrensten": "unerfahren",
    "unerfahrenster": "unerfahren",
    "unerfahrenstes": "unerfahren",
    "unerfreuliche": "unerfreulich",
    "unerfreulichem": "unerfreulich",
    "unerfreulichen": "unerfreulich",
    "unerfreulicher": "unerfreulich",
    "unerfreulichere": "unerfreulich",
    "unerfreulicherem": "unerfreulich",
    "unerfreulicheren": "unerfreulich",
    "unerfreulicherer": "unerfreulich",
    "unerfreulicheres": "unerfreulich",
    "unerfreuliches": "unerfreulich",
    "unerfreulichste": "unerfreulich",
    "unerfreulichstem": "unerfreulich",
    "unerfreulichsten": "unerfreulich",
    "unerfreulichster": "unerfreulich",
    "unerfreulichstes": "unerfreulich",
    "unerfüllte": "unerfüllt",
    "unerfülltem": "unerfüllt",
    "unerfüllten": "unerfüllt",
    "unerfüllter": "unerfüllt",
    "unerfülltere": "unerfüllt",
    "unerfüllterem": "unerfüllt",
    "unerfüllteren": "unerfüllt",
    "unerfüllterer": "unerfüllt",
    "unerfüllteres": "unerfüllt",
    "unerfülltes": "unerfüllt",
    "unerfüllteste": "unerfüllt",
    "unerfülltestem": "unerfüllt",
    "unerfülltesten": "unerfüllt",
    "unerfülltester": "unerfüllt",
    "unerfülltestes": "unerfüllt",
    "unergiebige": "unergiebig",
    "unergiebigem": "unergiebig",
    "unergiebigen": "unergiebig",
    "unergiebiger": "unergiebig",
    "unergiebigere": "unergiebig",
    "unergiebigerem": "unergiebig",
    "unergiebigeren": "unergiebig",
    "unergiebigerer": "unergiebig",
    "unergiebigeres": "unergiebig",
    "unergiebiges": "unergiebig",
    "unergiebigste": "unergiebig",
    "unergiebigstem": "unergiebig",
    "unergiebigsten": "unergiebig",
    "unergiebigster": "unergiebig",
    "unergiebigstes": "unergiebig",
    "unerhebliche": "unerheblich",
    "unerheblichem": "unerheblich",
    "unerheblichen": "unerheblich",
    "unerheblicher": "unerheblich",
    "unerhebliches": "unerheblich",
    "unerhörte": "unerhört",
    "unerhörtem": "unerhört",
    "unerhörten": "unerhört",
    "unerhörter": "unerhört",
    "unerhörtes": "unerhört",
    "unerkannte": "unerkannt",
    "unerkanntem": "unerkannt",
    "unerkannten": "unerkannt",
    "unerkannter": "unerkannt",
    "unerkanntes": "unerkannt",
    "unerledigte": "unerledigt",
    "unerledigtem": "unerledigt",
    "unerledigten": "unerledigt",
    "unerledigter": "unerledigt",
    "unerledigtes": "unerledigt",
    "unerläßliche": "unerläßlich",
    "unerläßlichem": "unerläßlich",
    "unerläßlichen": "unerläßlich",
    "unerläßlicher": "unerläßlich",
    "unerläßliches": "unerläßlich",
    "unermeßliche": "unermeßlich",
    "unermeßlichem": "unermeßlich",
    "unermeßlichen": "unermeßlich",
    "unermeßlicher": "unermeßlich",
    "unermeßliches": "unermeßlich",
    "unermüdliche": "unermüdlich",
    "unermüdlichem": "unermüdlich",
    "unermüdlichen": "unermüdlich",
    "unermüdlicher": "unermüdlich",
    "unermüdliches": "unermüdlich",
    "unerschrockene": "unerschrocken",
    "unerschrockenem": "unerschrocken",
    "unerschrockenen": "unerschrocken",
    "unerschrockener": "unerschrocken",
    "unerschrockenere": "unerschrocken",
    "unerschrockenerem": "unerschrocken",
    "unerschrockeneren": "unerschrocken",
    "unerschrockenerer": "unerschrocken",
    "unerschrockeneres": "unerschrocken",
    "unerschrockenes": "unerschrocken",
    "unerschrockenste": "unerschrocken",
    "unerschrockenstem": "unerschrocken",
    "unerschrockensten": "unerschrocken",
    "unerschrockenster": "unerschrocken",
    "unerschrockenstes": "unerschrocken",
    "unerschütterliche": "unerschütterlich",
    "unerschütterlichem": "unerschütterlich",
    "unerschütterlichen": "unerschütterlich",
    "unerschütterlicher": "unerschütterlich",
    "unerschütterlichere": "unerschütterlich",
    "unerschütterlicherem": "unerschütterlich",
    "unerschütterlicheren": "unerschütterlich",
    "unerschütterlicherer": "unerschütterlich",
    "unerschütterlicheres": "unerschütterlich",
    "unerschütterliches": "unerschütterlich",
    "unerschütterlichste": "unerschütterlich",
    "unerschütterlichstem": "unerschütterlich",
    "unerschütterlichsten": "unerschütterlich",
    "unerschütterlichster": "unerschütterlich",
    "unerschütterlichstes": "unerschütterlich",
    "unersetzliche": "unersetzlich",
    "unersetzlichem": "unersetzlich",
    "unersetzlichen": "unersetzlich",
    "unersetzlicher": "unersetzlich",
    "unersetzlichere": "unersetzlich",
    "unersetzlicherem": "unersetzlich",
    "unersetzlicheren": "unersetzlich",
    "unersetzlicherer": "unersetzlich",
    "unersetzlicheres": "unersetzlich",
    "unersetzliches": "unersetzlich",
    "unersetzlichste": "unersetzlich",
    "unersetzlichstem": "unersetzlich",
    "unersetzlichsten": "unersetzlich",
    "unersetzlichster": "unersetzlich",
    "unersetzlichstes": "unersetzlich",
    "unerträgliche": "unerträglich",
    "unerträglichem": "unerträglich",
    "unerträglichen": "unerträglich",
    "unerträglicher": "unerträglich",
    "unerträglichere": "unerträglich",
    "unerträglicherem": "unerträglich",
    "unerträglicheren": "unerträglich",
    "unerträglicherer": "unerträglich",
    "unerträglicheres": "unerträglich",
    "unerträgliches": "unerträglich",
    "unerträglichste": "unerträglich",
    "unerträglichstem": "unerträglich",
    "unerträglichsten": "unerträglich",
    "unerträglichster": "unerträglich",
    "unerträglichstes": "unerträglich",
    "unerwartete": "unerwartet",
    "unerwartetem": "unerwartet",
    "unerwarteten": "unerwartet",
    "unerwarteter": "unerwartet",
    "unerwartetere": "unerwartet",
    "unerwarteterem": "unerwartet",
    "unerwarteteren": "unerwartet",
    "unerwarteterer": "unerwartet",
    "unerwarteteres": "unerwartet",
    "unerwartetes": "unerwartet",
    "unerwarteteste": "unerwartet",
    "unerwartetestem": "unerwartet",
    "unerwartetesten": "unerwartet",
    "unerwartetester": "unerwartet",
    "unerwartetestes": "unerwartet",
    "unerwünschte": "unerwünscht",
    "unerwünschtem": "unerwünscht",
    "unerwünschten": "unerwünscht",
    "unerwünschter": "unerwünscht",
    "unerwünschtere": "unerwünscht",
    "unerwünschterem": "unerwünscht",
    "unerwünschteren": "unerwünscht",
    "unerwünschterer": "unerwünscht",
    "unerwünschteres": "unerwünscht",
    "unerwünschtes": "unerwünscht",
    "unerwünschteste": "unerwünscht",
    "unerwünschtestem": "unerwünscht",
    "unerwünschtesten": "unerwünscht",
    "unerwünschtester": "unerwünscht",
    "unerwünschtestes": "unerwünscht",
    "unfaire": "unfair",
    "unfairem": "unfair",
    "unfairen": "unfair",
    "unfairer": "unfair",
    "unfairere": "unfair",
    "unfairerem": "unfair",
    "unfaireren": "unfair",
    "unfairerer": "unfair",
    "unfaireres": "unfair",
    "unfaires": "unfair",
    "unfairste": "unfair",
    "unfairstem": "unfair",
    "unfairsten": "unfair",
    "unfairster": "unfair",
    "unfairstes": "unfair",
    "unfallfreiem": "unfallfrei",
    "unfallfreien": "unfallfrei",
    "unfallfreier": "unfallfrei",
    "unfallfreies": "unfallfrei",
    "unfallträchtigem": "unfallträchtig",
    "unfallträchtigen": "unfallträchtig",
    "unfallträchtiger": "unfallträchtig",
    "unfallträchtigere": "unfallträchtig",
    "unfallträchtigerem": "unfallträchtig",
    "unfallträchtigeren": "unfallträchtig",
    "unfallträchtigerer": "unfallträchtig",
    "unfallträchtigeres": "unfallträchtig",
    "unfallträchtiges": "unfallträchtig",
    "unfallträchtigste": "unfallträchtig",
    "unfallträchtigstem": "unfallträchtig",
    "unfallträchtigsten": "unfallträchtig",
    "unfallträchtigster": "unfallträchtig",
    "unfallträchtigstes": "unfallträchtig",
    "unfehlbare": "unfehlbar",
    "unfehlbarem": "unfehlbar",
    "unfehlbaren": "unfehlbar",
    "unfehlbarer": "unfehlbar",
    "unfehlbarere": "unfehlbar",
    "unfehlbarerem": "unfehlbar",
    "unfehlbareren": "unfehlbar",
    "unfehlbarerer": "unfehlbar",
    "unfehlbareres": "unfehlbar",
    "unfehlbares": "unfehlbar",
    "unfehlbarste": "unfehlbar",
    "unfehlbarstem": "unfehlbar",
    "unfehlbarsten": "unfehlbar",
    "unfehlbarster": "unfehlbar",
    "unfehlbarstes": "unfehlbar",
    "unfeine": "unfein",
    "unfeinem": "unfein",
    "unfeinen": "unfein",
    "unfeiner": "unfein",
    "unfeines": "unfein",
    "unfertige": "unfertig",
    "unfertigem": "unfertig",
    "unfertigen": "unfertig",
    "unfertiger": "unfertig",
    "unfertiges": "unfertig",
    "unflätige": "unflätig",
    "unflätigem": "unflätig",
    "unflätigen": "unflätig",
    "unflätiger": "unflätig",
    "unflätigere": "unflätig",
    "unflätigerem": "unflätig",
    "unflätigeren": "unflätig",
    "unflätigerer": "unflätig",
    "unflätigeres": "unflätig",
    "unflätiges": "unflätig",
    "unflätigste": "unflätig",
    "unflätigstem": "unflätig",
    "unflätigsten": "unflätig",
    "unflätigster": "unflätig",
    "unflätigstes": "unflätig",
    "unfreiwillige": "unfreiwillig",
    "unfreiwilligem": "unfreiwillig",
    "unfreiwilligen": "unfreiwillig",
    "unfreiwilliger": "unfreiwillig",
    "unfreiwilliges": "unfreiwillig",
    "unfreundliche": "unfreundlich",
    "unfreundlichem": "unfreundlich",
    "unfreundlichen": "unfreundlich",
    "unfreundlicher": "unfreundlich",
    "unfreundlichere": "unfreundlich",
    "unfreundlicherem": "unfreundlich",
    "unfreundlicheren": "unfreundlich",
    "unfreundlicherer": "unfreundlich",
    "unfreundlicheres": "unfreundlich",
    "unfreundliches": "unfreundlich",
    "unfreundlichstem": "unfreundlich",
    "unfreundlichsten": "unfreundlich",
    "unfreundlichster": "unfreundlich",
    "unfreundlichstes": "unfreundlich",
    "unfrommem": "unfromm",
    "unfrommen": "unfromm",
    "unfrommer": "unfromm",
    "unfrommere": "unfromm",
    "unfrommerem": "unfromm",
    "unfrommeren": "unfromm",
    "unfrommerer": "unfromm",
    "unfrommeres": "unfromm",
    "unfrommes": "unfromm",
    "unfrommste": "unfromm",
    "unfrommstem": "unfromm",
    "unfrommsten": "unfromm",
    "unfrommster": "unfromm",
    "unfrommstes": "unfromm",
    "unfruchtbare": "unfruchtbar",
    "unfruchtbarem": "unfruchtbar",
    "unfruchtbaren": "unfruchtbar",
    "unfruchtbarer": "unfruchtbar",
    "unfruchtbarere": "unfruchtbar",
    "unfruchtbarerem": "unfruchtbar",
    "unfruchtbareren": "unfruchtbar",
    "unfruchtbarerer": "unfruchtbar",
    "unfruchtbareres": "unfruchtbar",
    "unfruchtbares": "unfruchtbar",
    "unfruchtbarstem": "unfruchtbar",
    "unfruchtbarsten": "unfruchtbar",
    "unfruchtbarster": "unfruchtbar",
    "unfruchtbarstes": "unfruchtbar",
    "unfähige": "unfähig",
    "unfähigem": "unfähig",
    "unfähigen": "unfähig",
    "unfähiger": "unfähig",
    "unfähigere": "unfähig",
    "unfähigerem": "unfähig",
    "unfähigeren": "unfähig",
    "unfähigerer": "unfähig",
    "unfähigeres": "unfähig",
    "unfähiges": "unfähig",
    "unfähigste": "unfähig",
    "unfähigstem": "unfähig",
    "unfähigsten": "unfähig",
    "unfähigster": "unfähig",
    "unfähigstes": "unfähig",
    "ungarischem": "ungarisch",
    "ungarischen": "ungarisch",
    "ungarischer": "ungarisch",
    "ungarisches": "ungarisch",
    "ungebetenem": "ungebeten",
    "ungebetenen": "ungebeten",
    "ungebetener": "ungebeten",
    "ungebetenes": "ungebeten",
    "ungebildete": "ungebildet",
    "ungebildetem": "ungebildet",
    "ungebildeten": "ungebildet",
    "ungebildeter": "ungebildet",
    "ungebildetere": "ungebildet",
    "ungebildeterem": "ungebildet",
    "ungebildeteren": "ungebildet",
    "ungebildeterer": "ungebildet",
    "ungebildeteres": "ungebildet",
    "ungebildetes": "ungebildet",
    "ungebildeteste": "ungebildet",
    "ungebildetestem": "ungebildet",
    "ungebildetesten": "ungebildet",
    "ungebildetester": "ungebildet",
    "ungebildetestes": "ungebildet",
    "ungeborene": "ungeboren",
    "ungeborenem": "ungeboren",
    "ungeborenen": "ungeboren",
    "ungeborener": "ungeboren",
    "ungeborenes": "ungeboren",
    "ungebrauchte": "ungebraucht",
    "ungebrauchtem": "ungebraucht",
    "ungebrauchten": "ungebraucht",
    "ungebrauchter": "ungebraucht",
    "ungebrauchtes": "ungebraucht",
    "ungebrochene": "ungebrochen",
    "ungebrochenem": "ungebrochen",
    "ungebrochenen": "ungebrochen",
    "ungebrochener": "ungebrochen",
    "ungebrochenere": "ungebrochen",
    "ungebrochenerem": "ungebrochen",
    "ungebrocheneren": "ungebrochen",
    "ungebrochenerer": "ungebrochen",
    "ungebrocheneres": "ungebrochen",
    "ungebrochenes": "ungebrochen",
    "ungebrochenste": "ungebrochen",
    "ungebrochenstem": "ungebrochen",
    "ungebrochensten": "ungebrochen",
    "ungebrochenster": "ungebrochen",
    "ungebrochenstes": "ungebrochen",
    "ungebräuchliche": "ungebräuchlich",
    "ungebräuchlichem": "ungebräuchlich",
    "ungebräuchlichen": "ungebräuchlich",
    "ungebräuchlicher": "ungebräuchlich",
    "ungebräuchlichere": "ungebräuchlich",
    "ungebräuchlicherem": "ungebräuchlich",
    "ungebräuchlicheren": "ungebräuchlich",
    "ungebräuchlicherer": "ungebräuchlich",
    "ungebräuchlicheres": "ungebräuchlich",
    "ungebräuchliches": "ungebräuchlich",
    "ungebräuchlichste": "ungebräuchlich",
    "ungebräuchlichstem": "ungebräuchlich",
    "ungebräuchlichsten": "ungebräuchlich",
    "ungebräuchlichster": "ungebräuchlich",
    "ungebräuchlichstes": "ungebräuchlich",
    "ungebundene": "ungebunden",
    "ungebundenem": "ungebunden",
    "ungebundenen": "ungebunden",
    "ungebundener": "ungebunden",
    "ungebundenere": "ungebunden",
    "ungebundenerem": "ungebunden",
    "ungebundeneren": "ungebunden",
    "ungebundenerer": "ungebunden",
    "ungebundeneres": "ungebunden",
    "ungebundenes": "ungebunden",
    "ungebundenste": "ungebunden",
    "ungebundenstem": "ungebunden",
    "ungebundensten": "ungebunden",
    "ungebundenster": "ungebunden",
    "ungebundenstes": "ungebunden",
    "ungedeckte": "ungedeckt",
    "ungedecktem": "ungedeckt",
    "ungedeckten": "ungedeckt",
    "ungedeckter": "ungedeckt",
    "ungedecktes": "ungedeckt",
    "ungeduldige": "ungeduldig",
    "ungeduldigem": "ungeduldig",
    "ungeduldigen": "ungeduldig",
    "ungeduldiger": "ungeduldig",
    "ungeduldigere": "ungeduldig",
    "ungeduldigerem": "ungeduldig",
    "ungeduldigeren": "ungeduldig",
    "ungeduldigerer": "ungeduldig",
    "ungeduldigeres": "ungeduldig",
    "ungeduldiges": "ungeduldig",
    "ungeduldigste": "ungeduldig",
    "ungeduldigstem": "ungeduldig",
    "ungeduldigsten": "ungeduldig",
    "ungeduldigster": "ungeduldig",
    "ungeduldigstes": "ungeduldig",
    "ungeeignete": "ungeeignet",
    "ungeeignetem": "ungeeignet",
    "ungeeigneten": "ungeeignet",
    "ungeeigneter": "ungeeignet",
    "ungeeignetere": "ungeeignet",
    "ungeeigneterem": "ungeeignet",
    "ungeeigneteren": "ungeeignet",
    "ungeeigneterer": "ungeeignet",
    "ungeeigneteres": "ungeeignet",
    "ungeeignetes": "ungeeignet",
    "ungeeigneteste": "ungeeignet",
    "ungeeignetestem": "ungeeignet",
    "ungeeignetesten": "ungeeignet",
    "ungeeignetester": "ungeeignet",
    "ungeeignetestes": "ungeeignet",
    "ungefragte": "ungefragt",
    "ungefragtem": "ungefragt",
    "ungefragten": "ungefragt",
    "ungefragter": "ungefragt",
    "ungefragtere": "ungefragt",
    "ungefragterem": "ungefragt",
    "ungefragteren": "ungefragt",
    "ungefragterer": "ungefragt",
    "ungefragteres": "ungefragt",
    "ungefragtes": "ungefragt",
    "ungefragteste": "ungefragt",
    "ungefragtestem": "ungefragt",
    "ungefragtesten": "ungefragt",
    "ungefragtester": "ungefragt",
    "ungefragtestes": "ungefragt",
    "ungefährdete": "ungefährdet",
    "ungefährdetem": "ungefährdet",
    "ungefährdeten": "ungefährdet",
    "ungefährdeter": "ungefährdet",
    "ungefährdetere": "ungefährdet",
    "ungefährdeterem": "ungefährdet",
    "ungefährdeteren": "ungefährdet",
    "ungefährdeterer": "ungefährdet",
    "ungefährdeteres": "ungefährdet",
    "ungefährdetes": "ungefährdet",
    "ungefährdeteste": "ungefährdet",
    "ungefährdetestem": "ungefährdet",
    "ungefährdetesten": "ungefährdet",
    "ungefährdetester": "ungefährdet",
    "ungefährdetestes": "ungefährdet",
    "ungefähre": "ungefähr",
    "ungefährem": "ungefähr",
    "ungefähren": "ungefähr",
    "ungefährer": "ungefähr",
    "ungefähres": "ungefähr",
    "ungefährliche": "ungefährlich",
    "ungefährlichem": "ungefährlich",
    "ungefährlichen": "ungefährlich",
    "ungefährlicher": "ungefährlich",
    "ungefährlichere": "ungefährlich",
    "ungefährlicherem": "ungefährlich",
    "ungefährlicheren": "ungefährlich",
    "ungefährlicherer": "ungefährlich",
    "ungefährlicheres": "ungefährlich",
    "ungefährliches": "ungefährlich",
    "ungefährlichste": "ungefährlich",
    "ungefährlichstem": "ungefährlich",
    "ungefährlichsten": "ungefährlich",
    "ungefährlichster": "ungefährlich",
    "ungefährlichstes": "ungefährlich",
    "ungefällige": "ungefällig",
    "ungefälligem": "ungefällig",
    "ungefälligen": "ungefällig",
    "ungefälliger": "ungefällig",
    "ungefälligere": "ungefällig",
    "ungefälligerem": "ungefällig",
    "ungefälligeren": "ungefällig",
    "ungefälligerer": "ungefällig",
    "ungefälligeres": "ungefällig",
    "ungefälliges": "ungefällig",
    "ungefälligste": "ungefällig",
    "ungefälligstem": "ungefällig",
    "ungefälligsten": "ungefällig",
    "ungefälligster": "ungefällig",
    "ungefälligstes": "ungefällig",
    "ungehaltene": "ungehalten",
    "ungehaltenem": "ungehalten",
    "ungehaltenen": "ungehalten",
    "ungehaltener": "ungehalten",
    "ungehaltenere": "ungehalten",
    "ungehaltenerem": "ungehalten",
    "ungehalteneren": "ungehalten",
    "ungehaltenerer": "ungehalten",
    "ungehalteneres": "ungehalten",
    "ungehaltenes": "ungehalten",
    "ungehaltenste": "ungehalten",
    "ungehaltenstem": "ungehalten",
    "ungehaltensten": "ungehalten",
    "ungehaltenster": "ungehalten",
    "ungehaltenstes": "ungehalten",
    "ungeheizte": "ungeheizt",
    "ungeheiztem": "ungeheizt",
    "ungeheizten": "ungeheizt",
    "ungeheizter": "ungeheizt",
    "ungeheiztes": "ungeheizt",
    "ungehemmte": "ungehemmt",
    "ungehemmtem": "ungehemmt",
    "ungehemmten": "ungehemmt",
    "ungehemmter": "ungehemmt",
    "ungehemmtere": "ungehemmt",
    "ungehemmterem": "ungehemmt",
    "ungehemmteren": "ungehemmt",
    "ungehemmterer": "ungehemmt",
    "ungehemmteres": "ungehemmt",
    "ungehemmtes": "ungehemmt",
    "ungehemmteste": "ungehemmt",
    "ungehemmtestem": "ungehemmt",
    "ungehemmtesten": "ungehemmt",
    "ungehemmtester": "ungehemmt",
    "ungehemmtestes": "ungehemmt",
    "ungehindertem": "ungehindert",
    "ungehinderten": "ungehindert",
    "ungehinderter": "ungehindert",
    "ungehindertes": "ungehindert",
    "ungehobelte": "ungehobelt",
    "ungehobeltem": "ungehobelt",
    "ungehobelten": "ungehobelt",
    "ungehobelter": "ungehobelt",
    "ungehobeltere": "ungehobelt",
    "ungehobelterem": "ungehobelt",
    "ungehobelteren": "ungehobelt",
    "ungehobelterer": "ungehobelt",
    "ungehobelteres": "ungehobelt",
    "ungehobeltes": "ungehobelt",
    "ungehobelteste": "ungehobelt",
    "ungehobeltestem": "ungehobelt",
    "ungehobeltesten": "ungehobelt",
    "ungehobeltester": "ungehobelt",
    "ungehobeltestes": "ungehobelt",
    "ungehorsamem": "ungehorsam",
    "ungehorsamen": "ungehorsam",
    "ungehorsamer": "ungehorsam",
    "ungehorsames": "ungehorsam",
    "ungehörtem": "ungehört",
    "ungehörten": "ungehört",
    "ungehörter": "ungehört",
    "ungehörtes": "ungehört",
    "ungeklärte": "ungeklärt",
    "ungeklärtem": "ungeklärt",
    "ungeklärten": "ungeklärt",
    "ungeklärter": "ungeklärt",
    "ungeklärtere": "ungeklärt",
    "ungeklärterem": "ungeklärt",
    "ungeklärteren": "ungeklärt",
    "ungeklärterer": "ungeklärt",
    "ungeklärteres": "ungeklärt",
    "ungeklärtes": "ungeklärt",
    "ungeklärteste": "ungeklärt",
    "ungeklärtestem": "ungeklärt",
    "ungeklärtesten": "ungeklärt",
    "ungeklärtester": "ungeklärt",
    "ungeklärtestes": "ungeklärt",
    "ungekürzte": "ungekürzt",
    "ungekürztem": "ungekürzt",
    "ungekürzten": "ungekürzt",
    "ungekürzter": "ungekürzt",
    "ungekürztes": "ungekürzt",
    "ungelegene": "ungelegen",
    "ungelegenem": "ungelegen",
    "ungelegenen": "ungelegen",
    "ungelegener": "ungelegen",
    "ungelegenes": "ungelegen",
    "ungelenkige": "ungelenkig",
    "ungelenkigem": "ungelenkig",
    "ungelenkigen": "ungelenkig",
    "ungelenkiger": "ungelenkig",
    "ungelenkigere": "ungelenkig",
    "ungelenkigerem": "ungelenkig",
    "ungelenkigeren": "ungelenkig",
    "ungelenkigerer": "ungelenkig",
    "ungelenkigeres": "ungelenkig",
    "ungelenkiges": "ungelenkig",
    "ungelenkigste": "ungelenkig",
    "ungelenkigstem": "ungelenkig",
    "ungelenkigsten": "ungelenkig",
    "ungelenkigster": "ungelenkig",
    "ungelenkigstes": "ungelenkig",
    "ungelernte": "ungelernt",
    "ungelerntem": "ungelernt",
    "ungelernten": "ungelernt",
    "ungelernter": "ungelernt",
    "ungelerntes": "ungelernt",
    "ungemütliche": "ungemütlich",
    "ungemütlichem": "ungemütlich",
    "ungemütlichen": "ungemütlich",
    "ungemütlicher": "ungemütlich",
    "ungemütlichere": "ungemütlich",
    "ungemütlicherem": "ungemütlich",
    "ungemütlicheren": "ungemütlich",
    "ungemütlicherer": "ungemütlich",
    "ungemütlicheres": "ungemütlich",
    "ungemütliches": "ungemütlich",
    "ungemütlichste": "ungemütlich",
    "ungemütlichstem": "ungemütlich",
    "ungemütlichsten": "ungemütlich",
    "ungemütlichster": "ungemütlich",
    "ungemütlichstes": "ungemütlich",
    "ungenaue": "ungenau",
    "ungenauem": "ungenau",
    "ungenauen": "ungenau",
    "ungenauer": "ungenau",
    "ungenauere": "ungenau",
    "ungenauerem": "ungenau",
    "ungenaueren": "ungenau",
    "ungenauerer": "ungenau",
    "ungenaueres": "ungenau",
    "ungenaues": "ungenau",
    "ungenaustem": "ungenau",
    "ungenausten": "ungenau",
    "ungenauster": "ungenau",
    "ungenaustes": "ungenau",
    "ungenierte": "ungeniert",
    "ungeniertem": "ungeniert",
    "ungenierten": "ungeniert",
    "ungenierter": "ungeniert",
    "ungeniertere": "ungeniert",
    "ungenierterem": "ungeniert",
    "ungenierteren": "ungeniert",
    "ungenierterer": "ungeniert",
    "ungenierteres": "ungeniert",
    "ungeniertes": "ungeniert",
    "ungenierteste": "ungeniert",
    "ungeniertestem": "ungeniert",
    "ungeniertesten": "ungeniert",
    "ungeniertester": "ungeniert",
    "ungeniertestes": "ungeniert",
    "ungenießbare": "ungenießbar",
    "ungenießbarem": "ungenießbar",
    "ungenießbaren": "ungenießbar",
    "ungenießbarer": "ungenießbar",
    "ungenießbarere": "ungenießbar",
    "ungenießbarerem": "ungenießbar",
    "ungenießbareren": "ungenießbar",
    "ungenießbarerer": "ungenießbar",
    "ungenießbareres": "ungenießbar",
    "ungenießbares": "ungenießbar",
    "ungenießbarste": "ungenießbar",
    "ungenießbarstem": "ungenießbar",
    "ungenießbarsten": "ungenießbar",
    "ungenießbarster": "ungenießbar",
    "ungenießbarstes": "ungenießbar",
    "ungenutzte": "ungenutzt",
    "ungenutztem": "ungenutzt",
    "ungenutzten": "ungenutzt",
    "ungenutzter": "ungenutzt",
    "ungenutztes": "ungenutzt",
    "ungenügende": "ungenügend",
    "ungenügendem": "ungenügend",
    "ungenügenden": "ungenügend",
    "ungenügender": "ungenügend",
    "ungenügendes": "ungenügend",
    "ungeordnete": "ungeordnet",
    "ungeordnetem": "ungeordnet",
    "ungeordneten": "ungeordnet",
    "ungeordneter": "ungeordnet",
    "ungeordnetes": "ungeordnet",
    "ungepflegte": "ungepflegt",
    "ungepflegtem": "ungepflegt",
    "ungepflegten": "ungepflegt",
    "ungepflegter": "ungepflegt",
    "ungepflegtere": "ungepflegt",
    "ungepflegterem": "ungepflegt",
    "ungepflegteren": "ungepflegt",
    "ungepflegterer": "ungepflegt",
    "ungepflegteres": "ungepflegt",
    "ungepflegtes": "ungepflegt",
    "ungepflegteste": "ungepflegt",
    "ungepflegtestem": "ungepflegt",
    "ungepflegtesten": "ungepflegt",
    "ungepflegtester": "ungepflegt",
    "ungepflegtestes": "ungepflegt",
    "ungeradem": "ungerade",
    "ungeraden": "ungerade",
    "ungerader": "ungerade",
    "ungerades": "ungerade",
    "ungerechte": "ungerecht",
    "ungerechtem": "ungerecht",
    "ungerechten": "ungerecht",
    "ungerechter": "ungerecht",
    "ungerechtere": "ungerecht",
    "ungerechterem": "ungerecht",
    "ungerechteren": "ungerecht",
    "ungerechterer": "ungerecht",
    "ungerechteres": "ungerecht",
    "ungerechtes": "ungerecht",
    "ungerechteste": "ungerecht",
    "ungerechtestem": "ungerecht",
    "ungerechtesten": "ungerecht",
    "ungerechtester": "ungerecht",
    "ungerechtestes": "ungerecht",
    "ungeregeltem": "ungeregelt",
    "ungeregelten": "ungeregelt",
    "ungeregelter": "ungeregelt",
    "ungeregeltes": "ungeregelt",
    "ungereimte": "ungereimt",
    "ungereimtem": "ungereimt",
    "ungereimten": "ungereimt",
    "ungereimter": "ungereimt",
    "ungereimtes": "ungereimt",
    "ungeschicktem": "ungeschickt",
    "ungeschickten": "ungeschickt",
    "ungeschickter": "ungeschickt",
    "ungeschicktere": "ungeschickt",
    "ungeschickterem": "ungeschickt",
    "ungeschickteren": "ungeschickt",
    "ungeschickterer": "ungeschickt",
    "ungeschickteres": "ungeschickt",
    "ungeschicktes": "ungeschickt",
    "ungeschickteste": "ungeschickt",
    "ungeschicktestem": "ungeschickt",
    "ungeschicktesten": "ungeschickt",
    "ungeschicktester": "ungeschickt",
    "ungeschicktestes": "ungeschickt",
    "ungeschminkte": "ungeschminkt",
    "ungeschminktem": "ungeschminkt",
    "ungeschminkten": "ungeschminkt",
    "ungeschminkter": "ungeschminkt",
    "ungeschminktes": "ungeschminkt",
    "ungeschorene": "ungeschoren",
    "ungeschorenem": "ungeschoren",
    "ungeschorenen": "ungeschoren",
    "ungeschorener": "ungeschoren",
    "ungeschorenes": "ungeschoren",
    "ungeschützte": "ungeschützt",
    "ungeschütztem": "ungeschützt",
    "ungeschützten": "ungeschützt",
    "ungeschützter": "ungeschützt",
    "ungeschütztes": "ungeschützt",
    "ungesetzliche": "ungesetzlich",
    "ungesetzlichem": "ungesetzlich",
    "ungesetzlichen": "ungesetzlich",
    "ungesetzlicher": "ungesetzlich",
    "ungesetzlichere": "ungesetzlich",
    "ungesetzlicherem": "ungesetzlich",
    "ungesetzlicheren": "ungesetzlich",
    "ungesetzlicherer": "ungesetzlich",
    "ungesetzlicheres": "ungesetzlich",
    "ungesetzliches": "ungesetzlich",
    "ungesetzlichste": "ungesetzlich",
    "ungesetzlichstem": "ungesetzlich",
    "ungesetzlichsten": "ungesetzlich",
    "ungesetzlichster": "ungesetzlich",
    "ungesetzlichstes": "ungesetzlich",
    "ungesittete": "ungesittet",
    "ungesittetem": "ungesittet",
    "ungesitteten": "ungesittet",
    "ungesitteter": "ungesittet",
    "ungesittetere": "ungesittet",
    "ungesitteterem": "ungesittet",
    "ungesitteteren": "ungesittet",
    "ungesitteterer": "ungesittet",
    "ungesitteteres": "ungesittet",
    "ungesittetes": "ungesittet",
    "ungesitteteste": "ungesittet",
    "ungesittetestem": "ungesittet",
    "ungesittetesten": "ungesittet",
    "ungesittetester": "ungesittet",
    "ungesittetestes": "ungesittet",
    "ungestrafte": "ungestraft",
    "ungestraftem": "ungestraft",
    "ungestraften": "ungestraft",
    "ungestrafter": "ungestraft",
    "ungestraftes": "ungestraft",
    "ungestörte": "ungestört",
    "ungestörtem": "ungestört",
    "ungestörten": "ungestört",
    "ungestörter": "ungestört",
    "ungestörtere": "ungestört",
    "ungestörterem": "ungestört",
    "ungestörteren": "ungestört",
    "ungestörterer": "ungestört",
    "ungestörteres": "ungestört",
    "ungestörtes": "ungestört",
    "ungestörteste": "ungestört",
    "ungestörtestem": "ungestört",
    "ungestörtesten": "ungestört",
    "ungestörtester": "ungestört",
    "ungestörtestes": "ungestört",
    "ungestüme": "ungestüm",
    "ungestümem": "ungestüm",
    "ungestümen": "ungestüm",
    "ungestümer": "ungestüm",
    "ungestümere": "ungestüm",
    "ungestümerem": "ungestüm",
    "ungestümeren": "ungestüm",
    "ungestümerer": "ungestüm",
    "ungestümeres": "ungestüm",
    "ungestümes": "ungestüm",
    "ungestümstem": "ungestüm",
    "ungestümsten": "ungestüm",
    "ungestümster": "ungestüm",
    "ungestümstes": "ungestüm",
    "ungesunde": "ungesund",
    "ungesundem": "ungesund",
    "ungesunden": "ungesund",
    "ungesunder": "ungesund",
    "ungesundere": "ungesund",
    "ungesunderem": "ungesund",
    "ungesunderen": "ungesund",
    "ungesunderer": "ungesund",
    "ungesunderes": "ungesund",
    "ungesundes": "ungesund",
    "ungesundeste": "ungesund",
    "ungesundestem": "ungesund",
    "ungesundesten": "ungesund",
    "ungesundester": "ungesund",
    "ungesundestes": "ungesund",
    "ungeteilte": "ungeteilt",
    "ungeteiltem": "ungeteilt",
    "ungeteilten": "ungeteilt",
    "ungeteilter": "ungeteilt",
    "ungeteiltes": "ungeteilt",
    "ungetröstete": "ungetröstet",
    "ungetröstetem": "ungetröstet",
    "ungetrösteten": "ungetröstet",
    "ungetrösteter": "ungetröstet",
    "ungetröstetes": "ungetröstet",
    "ungetrübte": "ungetrübt",
    "ungetrübtem": "ungetrübt",
    "ungetrübten": "ungetrübt",
    "ungetrübter": "ungetrübt",
    "ungetrübtere": "ungetrübt",
    "ungetrübterem": "ungetrübt",
    "ungetrübteren": "ungetrübt",
    "ungetrübterer": "ungetrübt",
    "ungetrübteres": "ungetrübt",
    "ungetrübtes": "ungetrübt",
    "ungetrübteste": "ungetrübt",
    "ungetrübtestem": "ungetrübt",
    "ungetrübtesten": "ungetrübt",
    "ungetrübtester": "ungetrübt",
    "ungetrübtestes": "ungetrübt",
    "ungewaschenem": "ungewaschen",
    "ungewaschenen": "ungewaschen",
    "ungewaschener": "ungewaschen",
    "ungewaschenes": "ungewaschen",
    "ungeweihte": "ungeweiht",
    "ungeweihtem": "ungeweiht",
    "ungeweihten": "ungeweiht",
    "ungeweihter": "ungeweiht",
    "ungeweihtes": "ungeweiht",
    "ungewisse": "ungewiß",
    "ungewissem": "ungewiß",
    "ungewissen": "ungewiß",
    "ungewisser": "ungewiß",
    "ungewisses": "ungewiß",
    "ungewollte": "ungewollt",
    "ungewolltem": "ungewollt",
    "ungewollten": "ungewollt",
    "ungewollter": "ungewollt",
    "ungewolltere": "ungewollt",
    "ungewollterem": "ungewollt",
    "ungewollteren": "ungewollt",
    "ungewollterer": "ungewollt",
    "ungewollteres": "ungewollt",
    "ungewolltes": "ungewollt",
    "ungewollteste": "ungewollt",
    "ungewolltestem": "ungewollt",
    "ungewolltesten": "ungewollt",
    "ungewolltester": "ungewollt",
    "ungewolltestes": "ungewollt",
    "ungewöhnlichem": "ungewöhnlich",
    "ungewöhnlichen": "ungewöhnlich",
    "ungewöhnlicher": "ungewöhnlich",
    "ungewöhnlichere": "ungewöhnlich",
    "ungewöhnlicherem": "ungewöhnlich",
    "ungewöhnlicheren": "ungewöhnlich",
    "ungewöhnlicherer": "ungewöhnlich",
    "ungewöhnlicheres": "ungewöhnlich",
    "ungewöhnliches": "ungewöhnlich",
    "ungewöhnlichste": "ungewöhnlich",
    "ungewöhnlichstem": "ungewöhnlich",
    "ungewöhnlichsten": "ungewöhnlich",
    "ungewöhnlichster": "ungewöhnlich",
    "ungewöhnlichstes": "ungewöhnlich",
    "ungezogenem": "ungezogen",
    "ungezogenen": "ungezogen",
    "ungezogener": "ungezogen",
    "ungezogenere": "ungezogen",
    "ungezogenerem": "ungezogen",
    "ungezogeneren": "ungezogen",
    "ungezogenerer": "ungezogen",
    "ungezogeneres": "ungezogen",
    "ungezogenes": "ungezogen",
    "ungezogenstem": "ungezogen",
    "ungezogensten": "ungezogen",
    "ungezogenster": "ungezogen",
    "ungezogenstes": "ungezogen",
    "ungezwungene": "ungezwungen",
    "ungezwungenem": "ungezwungen",
    "ungezwungenen": "ungezwungen",
    "ungezwungener": "ungezwungen",
    "ungezwungenere": "ungezwungen",
    "ungezwungenerem": "ungezwungen",
    "ungezwungeneren": "ungezwungen",
    "ungezwungenerer": "ungezwungen",
    "ungezwungeneres": "ungezwungen",
    "ungezwungenes": "ungezwungen",
    "ungezwungenste": "ungezwungen",
    "ungezwungenstem": "ungezwungen",
    "ungezwungensten": "ungezwungen",
    "ungezwungenster": "ungezwungen",
    "ungezwungenstes": "ungezwungen",
    "ungezählte": "ungezählt",
    "ungezähltem": "ungezählt",
    "ungezählten": "ungezählt",
    "ungezählter": "ungezählt",
    "ungezähltes": "ungezählt",
    "ungezähmte": "ungezähmt",
    "ungezähmtem": "ungezähmt",
    "ungezähmten": "ungezähmt",
    "ungezähmter": "ungezähmt",
    "ungezähmtes": "ungezähmt",
    "ungezügelte": "ungezügelt",
    "ungezügeltem": "ungezügelt",
    "ungezügelten": "ungezügelt",
    "ungezügelter": "ungezügelt",
    "ungezügeltere": "ungezügelt",
    "ungezügelterem": "ungezügelt",
    "ungezügelteren": "ungezügelt",
    "ungezügelterer": "ungezügelt",
    "ungezügelteres": "ungezügelt",
    "ungezügeltes": "ungezügelt",
    "ungezügelteste": "ungezügelt",
    "ungezügeltestem": "ungezügelt",
    "ungezügeltesten": "ungezügelt",
    "ungezügeltester": "ungezügelt",
    "ungezügeltestes": "ungezügelt",
    "unglaubliche": "unglaublich",
    "unglaublichem": "unglaublich",
    "unglaublichen": "unglaublich",
    "unglaublicher": "unglaublich",
    "unglaublichere": "unglaublich",
    "unglaublicherem": "unglaublich",
    "unglaublicheren": "unglaublich",
    "unglaublicherer": "unglaublich",
    "unglaublicheres": "unglaublich",
    "unglaubliches": "unglaublich",
    "unglaublichste": "unglaublich",
    "unglaublichstem": "unglaublich",
    "unglaublichsten": "unglaublich",
    "unglaublichster": "unglaublich",
    "unglaublichstes": "unglaublich",
    "unglaubwürdige": "unglaubwürdig",
    "unglaubwürdigem": "unglaubwürdig",
    "unglaubwürdigen": "unglaubwürdig",
    "unglaubwürdiger": "unglaubwürdig",
    "unglaubwürdigere": "unglaubwürdig",
    "unglaubwürdigerem": "unglaubwürdig",
    "unglaubwürdigeren": "unglaubwürdig",
    "unglaubwürdigerer": "unglaubwürdig",
    "unglaubwürdigeres": "unglaubwürdig",
    "unglaubwürdiges": "unglaubwürdig",
    "unglaubwürdigste": "unglaubwürdig",
    "unglaubwürdigstem": "unglaubwürdig",
    "unglaubwürdigsten": "unglaubwürdig",
    "unglaubwürdigster": "unglaubwürdig",
    "unglaubwürdigstes": "unglaubwürdig",
    "ungleiche": "ungleich",
    "ungleichem": "ungleich",
    "ungleichen": "ungleich",
    "ungleicher": "ungleich",
    "ungleichere": "ungleich",
    "ungleicherem": "ungleich",
    "ungleicheren": "ungleich",
    "ungleicherer": "ungleich",
    "ungleicheres": "ungleich",
    "ungleiches": "ungleich",
    "ungleichmäßigem": "ungleichmäßig",
    "ungleichmäßigen": "ungleichmäßig",
    "ungleichmäßiger": "ungleichmäßig",
    "ungleichmäßigere": "ungleichmäßig",
    "ungleichmäßigerem": "ungleichmäßig",
    "ungleichmäßigeren": "ungleichmäßig",
    "ungleichmäßigerer": "ungleichmäßig",
    "ungleichmäßigeres": "ungleichmäßig",
    "ungleichmäßiges": "ungleichmäßig",
    "ungleichmäßigstem": "ungleichmäßig",
    "ungleichmäßigsten": "ungleichmäßig",
    "ungleichmäßigster": "ungleichmäßig",
    "ungleichmäßigstes": "ungleichmäßig",
    "ungleichste": "ungleich",
    "ungleichstem": "ungleich",
    "ungleichsten": "ungleich",
    "ungleichster": "ungleich",
    "ungleichstes": "ungleich",
    "ungläubigem": "ungläubig",
    "ungläubigen": "ungläubig",
    "ungläubiger": "ungläubig",
    "ungläubigere": "ungläubig",
    "ungläubigerem": "ungläubig",
    "ungläubigeren": "ungläubig",
    "ungläubigerer": "ungläubig",
    "ungläubigeres": "ungläubig",
    "ungläubiges": "ungläubig",
    "ungläubigste": "ungläubig",
    "ungläubigstem": "ungläubig",
    "ungläubigsten": "ungläubig",
    "ungläubigster": "ungläubig",
    "ungläubigstes": "ungläubig",
    "unglücklichem": "unglücklich",
    "unglücklichen": "unglücklich",
    "unglücklicher": "unglücklich",
    "unglücklichere": "unglücklich",
    "unglücklicherem": "unglücklich",
    "unglücklicheren": "unglücklich",
    "unglücklicherer": "unglücklich",
    "unglücklicheres": "unglücklich",
    "unglückliches": "unglücklich",
    "unglücklichste": "unglücklich",
    "unglücklichstem": "unglücklich",
    "unglücklichsten": "unglücklich",
    "unglücklichster": "unglücklich",
    "unglücklichstes": "unglücklich",
    "ungute": "ungut",
    "ungutem": "ungut",
    "unguten": "ungut",
    "unguter": "ungut",
    "ungutes": "ungut",
    "ungültigem": "ungültig",
    "ungültigen": "ungültig",
    "ungültiger": "ungültig",
    "ungültiges": "ungültig",
    "ungünstige": "ungünstig",
    "ungünstigem": "ungünstig",
    "ungünstigen": "ungünstig",
    "ungünstiger": "ungünstig",
    "ungünstigere": "ungünstig",
    "ungünstigerem": "ungünstig",
    "ungünstigeren": "ungünstig",
    "ungünstigerer": "ungünstig",
    "ungünstigeres": "ungünstig",
    "ungünstiges": "ungünstig",
    "ungünstigste": "ungünstig",
    "ungünstigstem": "ungünstig",
    "ungünstigsten": "ungünstig",
    "ungünstigster": "ungünstig",
    "ungünstigstes": "ungünstig",
    "unhandliche": "unhandlich",
    "unhandlichem": "unhandlich",
    "unhandlichen": "unhandlich",
    "unhandlicher": "unhandlich",
    "unhandlichere": "unhandlich",
    "unhandlicherem": "unhandlich",
    "unhandlicheren": "unhandlich",
    "unhandlicherer": "unhandlich",
    "unhandlicheres": "unhandlich",
    "unhandliches": "unhandlich",
    "unhandlichste": "unhandlich",
    "unhandlichstem": "unhandlich",
    "unhandlichsten": "unhandlich",
    "unhandlichster": "unhandlich",
    "unhandlichstes": "unhandlich",
    "unheilvollem": "unheilvoll",
    "unheilvollen": "unheilvoll",
    "unheilvoller": "unheilvoll",
    "unheilvollere": "unheilvoll",
    "unheilvollerem": "unheilvoll",
    "unheilvolleren": "unheilvoll",
    "unheilvollerer": "unheilvoll",
    "unheilvolleres": "unheilvoll",
    "unheilvolles": "unheilvoll",
    "unheilvollste": "unheilvoll",
    "unheilvollstem": "unheilvoll",
    "unheilvollsten": "unheilvoll",
    "unheilvollster": "unheilvoll",
    "unheilvollstes": "unheilvoll",
    "unheimliche": "unheimlich",
    "unheimlichem": "unheimlich",
    "unheimlichen": "unheimlich",
    "unheimlicher": "unheimlich",
    "unheimlichere": "unheimlich",
    "unheimlicherem": "unheimlich",
    "unheimlicheren": "unheimlich",
    "unheimlicherer": "unheimlich",
    "unheimlicheres": "unheimlich",
    "unheimliches": "unheimlich",
    "unheimlichste": "unheimlich",
    "unheimlichstem": "unheimlich",
    "unheimlichsten": "unheimlich",
    "unheimlichster": "unheimlich",
    "unheimlichstes": "unheimlich",
    "unhöfliche": "unhöflich",
    "unhöflichem": "unhöflich",
    "unhöflichen": "unhöflich",
    "unhöflicher": "unhöflich",
    "unhöflichere": "unhöflich",
    "unhöflicherem": "unhöflich",
    "unhöflicheren": "unhöflich",
    "unhöflicherer": "unhöflich",
    "unhöflicheres": "unhöflich",
    "unhöfliches": "unhöflich",
    "unhöflichste": "unhöflich",
    "unhöflichstem": "unhöflich",
    "unhöflichsten": "unhöflich",
    "unhöflichster": "unhöflich",
    "unhöflichstes": "unhöflich",
    "unifiziere": "unifizieren",
    "unifizierend": "unifizieren",
    "unifizierende": "unifizierend",
    "unifizierendem": "unifizierend",
    "unifizierenden": "unifizierend",
    "unifizierender": "unifizierend",
    "unifizierendes": "unifizierend",
    "unifizierest": "unifizieren",
    "unifizieret": "unifizieren",
    "unifizierst": "unifizieren",
    "unifiziert": "unifizieren",
    "unifizierte": "unifizieren",
    "unifiziertem": "unifiziert",
    "unifizierten": "unifizieren",
    "unifizierter": "unifiziert",
    "unifiziertes": "unifiziert",
    "unifiziertest": "unifizieren",
    "unifiziertet": "unifizieren",
    "uniformiere": "uniformieren",
    "uniformierend": "uniformieren",
    "uniformierende": "uniformierend",
    "uniformierendem": "uniformierend",
    "uniformierenden": "uniformierend",
    "uniformierender": "uniformierend",
    "uniformierendes": "uniformierend",
    "uniformierest": "uniformieren",
    "uniformieret": "uniformieren",
    "uniformierst": "uniformieren",
    "uniformiert": "uniformieren",
    "uniformierte": "uniformieren",
    "uniformiertem": "uniformiert",
    "uniformierten": "uniformieren",
    "uniformierter": "uniformiert",
    "uniformiertes": "uniformiert",
    "uniformiertest": "uniformieren",
    "uniformiertet": "uniformieren",
    "universitärem": "universitär",
    "universitären": "universitär",
    "universitärer": "universitär",
    "universitärere": "universitär",
    "universitärerem": "universitär",
    "universitäreren": "universitär",
    "universitärerer": "universitär",
    "universitäreres": "universitär",
    "universitäres": "universitär",
    "universitärste": "universitär",
    "universitärstem": "universitär",
    "universitärsten": "universitär",
    "universitärster": "universitär",
    "universitärstes": "universitär",
    "unkameradschaftlichem": "unkameradschaftlich",
    "unkameradschaftlichen": "unkameradschaftlich",
    "unkameradschaftlicher": "unkameradschaftlich",
    "unkameradschaftlichere": "unkameradschaftlich",
    "unkameradschaftlicherem": "unkameradschaftlich",
    "unkameradschaftlicheren": "unkameradschaftlich",
    "unkameradschaftlicherer": "unkameradschaftlich",
    "unkameradschaftlicheres": "unkameradschaftlich",
    "unkameradschaftliches": "unkameradschaftlich",
    "unkameradschaftlichste": "unkameradschaftlich",
    "unkameradschaftlichstem": "unkameradschaftlich",
    "unkameradschaftlichsten": "unkameradschaftlich",
    "unkameradschaftlichster": "unkameradschaftlich",
    "unkameradschaftlichstes": "unkameradschaftlich",
    "unke": "unken",
    "unkend": "unken",
    "unkende": "unkend",
    "unkendem": "unkend",
    "unkenden": "unkend",
    "unkender": "unkend",
    "unkendere": "unkend",
    "unkenderem": "unkend",
    "unkenderen": "unkend",
    "unkenderer": "unkend",
    "unkenderes": "unkend",
    "unkendes": "unkend",
    "unkendste": "unkend",
    "unkendstem": "unkend",
    "unkendsten": "unkend",
    "unkendster": "unkend",
    "unkendstes": "unkend",
    "unkenntliche": "unkenntlich",
    "unkenntlichem": "unkenntlich",
    "unkenntlichen": "unkenntlich",
    "unkenntlicher": "unkenntlich",
    "unkenntlichere": "unkenntlich",
    "unkenntlicherem": "unkenntlich",
    "unkenntlicheren": "unkenntlich",
    "unkenntlicherer": "unkenntlich",
    "unkenntlicheres": "unkenntlich",
    "unkenntliches": "unkenntlich",
    "unkenntlichste": "unkenntlich",
    "unkenntlichstem": "unkenntlich",
    "unkenntlichsten": "unkenntlich",
    "unkenntlichster": "unkenntlich",
    "unkenntlichstes": "unkenntlich",
    "unkest": "unken",
    "unket": "unken",
    "unklare": "unklar",
    "unklarem": "unklar",
    "unklaren": "unklar",
    "unklarer": "unklar",
    "unklarere": "unklar",
    "unklarerem": "unklar",
    "unklareren": "unklar",
    "unklarerer": "unklar",
    "unklareres": "unklar",
    "unklares": "unklar",
    "unklarstem": "unklar",
    "unklarsten": "unklar",
    "unklarster": "unklar",
    "unklarstes": "unklar",
    "unkluge": "unklug",
    "unklugem": "unklug",
    "unklugen": "unklug",
    "unkluger": "unklug",
    "unkluges": "unklug",
    "unkollegiale": "unkollegial",
    "unkollegialem": "unkollegial",
    "unkollegialen": "unkollegial",
    "unkollegialer": "unkollegial",
    "unkollegialere": "unkollegial",
    "unkollegialerem": "unkollegial",
    "unkollegialeren": "unkollegial",
    "unkollegialerer": "unkollegial",
    "unkollegialeres": "unkollegial",
    "unkollegiales": "unkollegial",
    "unkollegialste": "unkollegial",
    "unkollegialstem": "unkollegial",
    "unkollegialsten": "unkollegial",
    "unkollegialster": "unkollegial",
    "unkollegialstes": "unkollegial",
    "unkomfortabelste": "unkomfortabel",
    "unkomfortabelstem": "unkomfortabel",
    "unkomfortabelsten": "unkomfortabel",
    "unkomfortabelster": "unkomfortabel",
    "unkomfortabelstes": "unkomfortabel",
    "unkomfortable": "unkomfortabel",
    "unkomfortablem": "unkomfortabel",
    "unkomfortablen": "unkomfortabel",
    "unkomfortabler": "unkomfortabel",
    "unkomfortablere": "unkomfortabel",
    "unkomfortablerem": "unkomfortabel",
    "unkomfortableren": "unkomfortabel",
    "unkomfortablerer": "unkomfortabel",
    "unkomfortableres": "unkomfortabel",
    "unkomfortables": "unkomfortabel",
    "unkonzentrierte": "unkonzentriert",
    "unkonzentriertem": "unkonzentriert",
    "unkonzentrierten": "unkonzentriert",
    "unkonzentrierter": "unkonzentriert",
    "unkonzentriertere": "unkonzentriert",
    "unkonzentrierterem": "unkonzentriert",
    "unkonzentrierteren": "unkonzentriert",
    "unkonzentrierterer": "unkonzentriert",
    "unkonzentrierteres": "unkonzentriert",
    "unkonzentriertes": "unkonzentriert",
    "unkonzentrierteste": "unkonzentriert",
    "unkonzentriertestem": "unkonzentriert",
    "unkonzentriertesten": "unkonzentriert",
    "unkonzentriertester": "unkonzentriert",
    "unkonzentriertestes": "unkonzentriert",
    "unkorrekte": "unkorrekt",
    "unkorrektem": "unkorrekt",
    "unkorrekten": "unkorrekt",
    "unkorrekter": "unkorrekt",
    "unkorrektere": "unkorrekt",
    "unkorrekterem": "unkorrekt",
    "unkorrekteren": "unkorrekt",
    "unkorrekterer": "unkorrekt",
    "unkorrekteres": "unkorrekt",
    "unkorrektes": "unkorrekt",
    "unkorrekteste": "unkorrekt",
    "unkorrektestem": "unkorrekt",
    "unkorrektesten": "unkorrekt",
    "unkorrektester": "unkorrekt",
    "unkorrektestes": "unkorrekt",
    "unkorruptem": "unkorrupt",
    "unkorrupten": "unkorrupt",
    "unkorrupter": "unkorrupt",
    "unkorruptere": "unkorrupt",
    "unkorrupterem": "unkorrupt",
    "unkorrupteren": "unkorrupt",
    "unkorrupterer": "unkorrupt",
    "unkorrupteres": "unkorrupt",
    "unkorruptes": "unkorrupt",
    "unkorrupteste": "unkorrupt",
    "unkorruptestem": "unkorrupt",
    "unkorruptesten": "unkorrupt",
    "unkorruptester": "unkorrupt",
    "unkorruptestes": "unkorrupt",
    "unkritischem": "unkritisch",
    "unkritischen": "unkritisch",
    "unkritischer": "unkritisch",
    "unkritischere": "unkritisch",
    "unkritischerem": "unkritisch",
    "unkritischeren": "unkritisch",
    "unkritischerer": "unkritisch",
    "unkritischeres": "unkritisch",
    "unkritisches": "unkritisch",
    "unkritischste": "unkritisch",
    "unkritischstem": "unkritisch",
    "unkritischsten": "unkritisch",
    "unkritischster": "unkritisch",
    "unkritischstes": "unkritisch",
    "unkst": "unken",
    "unkt": "unken",
    "unkte": "unken",
    "unkten": "unken",
    "unktest": "unken",
    "unktet": "unken",
    "unkundige": "unkundig",
    "unkundigem": "unkundig",
    "unkundigen": "unkundig",
    "unkundiger": "unkundig",
    "unkundigere": "unkundig",
    "unkundigerem": "unkundig",
    "unkundigeren": "unkundig",
    "unkundigerer": "unkundig",
    "unkundigeres": "unkundig",
    "unkundiges": "unkundig",
    "unkundigste": "unkundig",
    "unkundigstem": "unkundig",
    "unkundigsten": "unkundig",
    "unkundigster": "unkundig",
    "unkundigstes": "unkundig",
    "unlauterem": "unlauter",
    "unlauteren": "unlauter",
    "unlauterer": "unlauter",
    "unlauteres": "unlauter",
    "unleserliche": "unleserlich",
    "unleserlichem": "unleserlich",
    "unleserlichen": "unleserlich",
    "unleserlicher": "unleserlich",
    "unleserlichere": "unleserlich",
    "unleserlicherem": "unleserlich",
    "unleserlicheren": "unleserlich",
    "unleserlicherer": "unleserlich",
    "unleserlicheres": "unleserlich",
    "unleserliches": "unleserlich",
    "unleserlichste": "unleserlich",
    "unleserlichstem": "unleserlich",
    "unleserlichsten": "unleserlich",
    "unleserlichster": "unleserlich",
    "unleserlichstes": "unleserlich",
    "unliebe": "unlieb",
    "unliebem": "unlieb",
    "unlieben": "unlieb",
    "unlieber": "unlieb",
    "unliebes": "unlieb",
    "unliebsame": "unliebsam",
    "unliebsamem": "unliebsam",
    "unliebsamen": "unliebsam",
    "unliebsamer": "unliebsam",
    "unliebsamere": "unliebsam",
    "unliebsamerem": "unliebsam",
    "unliebsameren": "unliebsam",
    "unliebsamerer": "unliebsam",
    "unliebsameres": "unliebsam",
    "unliebsames": "unliebsam",
    "unliebsamste": "unliebsam",
    "unliebsamstem": "unliebsam",
    "unliebsamsten": "unliebsam",
    "unliebsamster": "unliebsam",
    "unliebsamstes": "unliebsam",
    "unlimitierte": "unlimitiert",
    "unlimitiertem": "unlimitiert",
    "unlimitierten": "unlimitiert",
    "unlimitierter": "unlimitiert",
    "unlimitiertes": "unlimitiert",
    "unlösliche": "unlöslich",
    "unlöslichem": "unlöslich",
    "unlöslichen": "unlöslich",
    "unlöslicher": "unlöslich",
    "unlösliches": "unlöslich",
    "unmaßgebliche": "unmaßgeblich",
    "unmaßgeblichem": "unmaßgeblich",
    "unmaßgeblichen": "unmaßgeblich",
    "unmaßgeblicher": "unmaßgeblich",
    "unmaßgebliches": "unmaßgeblich",
    "unmittelbare": "unmittelbar",
    "unmittelbarem": "unmittelbar",
    "unmittelbaren": "unmittelbar",
    "unmittelbarer": "unmittelbar",
    "unmittelbarere": "unmittelbar",
    "unmittelbarerem": "unmittelbar",
    "unmittelbareren": "unmittelbar",
    "unmittelbarerer": "unmittelbar",
    "unmittelbareres": "unmittelbar",
    "unmittelbares": "unmittelbar",
    "unmittelbarste": "unmittelbar",
    "unmittelbarstem": "unmittelbar",
    "unmittelbarsten": "unmittelbar",
    "unmittelbarster": "unmittelbar",
    "unmittelbarstes": "unmittelbar",
    "unmißverständlichem": "unmißverständlich",
    "unmißverständlichen": "unmißverständlich",
    "unmißverständlicher": "unmißverständlich",
    "unmißverständliches": "unmißverständlich",
    "unmoderne": "unmodern",
    "unmodernem": "unmodern",
    "unmodernen": "unmodern",
    "unmoderner": "unmodern",
    "unmodernere": "unmodern",
    "unmodernerem": "unmodern",
    "unmoderneren": "unmodern",
    "unmodernerer": "unmodern",
    "unmoderneres": "unmodern",
    "unmodernes": "unmodern",
    "unmodernste": "unmodern",
    "unmodernstem": "unmodern",
    "unmodernsten": "unmodern",
    "unmodernster": "unmodern",
    "unmodernstes": "unmodern",
    "unmoralische": "unmoralisch",
    "unmoralischem": "unmoralisch",
    "unmoralischen": "unmoralisch",
    "unmoralischer": "unmoralisch",
    "unmoralischere": "unmoralisch",
    "unmoralischerem": "unmoralisch",
    "unmoralischeren": "unmoralisch",
    "unmoralischerer": "unmoralisch",
    "unmoralischeres": "unmoralisch",
    "unmoralisches": "unmoralisch",
    "unmoralischste": "unmoralisch",
    "unmoralischstem": "unmoralisch",
    "unmoralischsten": "unmoralisch",
    "unmoralischster": "unmoralisch",
    "unmoralischstes": "unmoralisch",
    "unmusikalische": "unmusikalisch",
    "unmusikalischem": "unmusikalisch",
    "unmusikalischen": "unmusikalisch",
    "unmusikalischer": "unmusikalisch",
    "unmusikalischere": "unmusikalisch",
    "unmusikalischerem": "unmusikalisch",
    "unmusikalischeren": "unmusikalisch",
    "unmusikalischerer": "unmusikalisch",
    "unmusikalischeres": "unmusikalisch",
    "unmusikalisches": "unmusikalisch",
    "unmusikalischste": "unmusikalisch",
    "unmusikalischstem": "unmusikalisch",
    "unmusikalischsten": "unmusikalisch",
    "unmusikalischster": "unmusikalisch",
    "unmusikalischstes": "unmusikalisch",
    "unmännlichem": "unmännlich",
    "unmännlichen": "unmännlich",
    "unmännlicher": "unmännlich",
    "unmännlichere": "unmännlich",
    "unmännlicherem": "unmännlich",
    "unmännlicheren": "unmännlich",
    "unmännlicherer": "unmännlich",
    "unmännlicheres": "unmännlich",
    "unmännliches": "unmännlich",
    "unmännlichste": "unmännlich",
    "unmännlichstem": "unmännlich",
    "unmännlichsten": "unmännlich",
    "unmännlichster": "unmännlich",
    "unmännlichstes": "unmännlich",
    "unmögliche": "unmöglich",
    "unmöglichem": "unmöglich",
    "unmöglichen": "unmöglich",
    "unmöglicher": "unmöglich",
    "unmöglichere": "unmöglich",
    "unmöglicherem": "unmöglich",
    "unmöglicheren": "unmöglich",
    "unmöglicherer": "unmöglich",
    "unmöglicheres": "unmöglich",
    "unmögliches": "unmöglich",
    "unmöglichstem": "unmöglich",
    "unmöglichsten": "unmöglich",
    "unmöglichster": "unmöglich",
    "unmöglichstes": "unmöglich",
    "unmündige": "unmündig",
    "unmündigem": "unmündig",
    "unmündigen": "unmündig",
    "unmündiger": "unmündig",
    "unmündiges": "unmündig",
    "unnachgiebigem": "unnachgiebig",
    "unnachgiebigen": "unnachgiebig",
    "unnachgiebiger": "unnachgiebig",
    "unnachgiebigere": "unnachgiebig",
    "unnachgiebigerem": "unnachgiebig",
    "unnachgiebigeren": "unnachgiebig",
    "unnachgiebigerer": "unnachgiebig",
    "unnachgiebigeres": "unnachgiebig",
    "unnachgiebiges": "unnachgiebig",
    "unnachgiebigste": "unnachgiebig",
    "unnachgiebigstem": "unnachgiebig",
    "unnachgiebigsten": "unnachgiebig",
    "unnachgiebigster": "unnachgiebig",
    "unnachgiebigstes": "unnachgiebig",
    "unnachsichtige": "unnachsichtig",
    "unnachsichtigem": "unnachsichtig",
    "unnachsichtigen": "unnachsichtig",
    "unnachsichtiger": "unnachsichtig",
    "unnachsichtigere": "unnachsichtig",
    "unnachsichtigerem": "unnachsichtig",
    "unnachsichtigeren": "unnachsichtig",
    "unnachsichtigerer": "unnachsichtig",
    "unnachsichtigeres": "unnachsichtig",
    "unnachsichtiges": "unnachsichtig",
    "unnachsichtigste": "unnachsichtig",
    "unnachsichtigstem": "unnachsichtig",
    "unnachsichtigsten": "unnachsichtig",
    "unnachsichtigster": "unnachsichtig",
    "unnachsichtigstes": "unnachsichtig",
    "unnahbare": "unnahbar",
    "unnahbarem": "unnahbar",
    "unnahbaren": "unnahbar",
    "unnahbarer": "unnahbar",
    "unnahbarere": "unnahbar",
    "unnahbarerem": "unnahbar",
    "unnahbareren": "unnahbar",
    "unnahbarerer": "unnahbar",
    "unnahbareres": "unnahbar",
    "unnahbares": "unnahbar",
    "unnahbarste": "unnahbar",
    "unnahbarstem": "unnahbar",
    "unnahbarsten": "unnahbar",
    "unnahbarster": "unnahbar",
    "unnahbarstes": "unnahbar",
    "unnatürliche": "unnatürlich",
    "unnatürlichem": "unnatürlich",
    "unnatürlichen": "unnatürlich",
    "unnatürlicher": "unnatürlich",
    "unnatürlichere": "unnatürlich",
    "unnatürlicherem": "unnatürlich",
    "unnatürlicheren": "unnatürlich",
    "unnatürlicherer": "unnatürlich",
    "unnatürlicheres": "unnatürlich",
    "unnatürliches": "unnatürlich",
    "unnatürlichste": "unnatürlich",
    "unnatürlichstem": "unnatürlich",
    "unnatürlichsten": "unnatürlich",
    "unnatürlichster": "unnatürlich",
    "unnatürlichstes": "unnatürlich",
    "unnormale": "unnormal",
    "unnormalem": "unnormal",
    "unnormalen": "unnormal",
    "unnormaler": "unnormal",
    "unnormales": "unnormal",
    "unnötige": "unnötig",
    "unnötigem": "unnötig",
    "unnötigen": "unnötig",
    "unnötiger": "unnötig",
    "unnötigere": "unnötig",
    "unnötigerem": "unnötig",
    "unnötigeren": "unnötig",
    "unnötigerer": "unnötig",
    "unnötigeres": "unnötig",
    "unnötiges": "unnötig",
    "unnötigste": "unnötig",
    "unnötigstem": "unnötig",
    "unnötigsten": "unnötig",
    "unnötigster": "unnötig",
    "unnötigstes": "unnötig",
    "unnütze": "unnütz",
    "unnützem": "unnütz",
    "unnützen": "unnütz",
    "unnützer": "unnütz",
    "unnützes": "unnütz",
    "unordentliche": "unordentlich",
    "unordentlichem": "unordentlich",
    "unordentlichen": "unordentlich",
    "unordentlicher": "unordentlich",
    "unordentlichere": "unordentlich",
    "unordentlicherem": "unordentlich",
    "unordentlicheren": "unordentlich",
    "unordentlicherer": "unordentlich",
    "unordentlicheres": "unordentlich",
    "unordentliches": "unordentlich",
    "unordentlichste": "unordentlich",
    "unordentlichstem": "unordentlich",
    "unordentlichsten": "unordentlich",
    "unordentlichster": "unordentlich",
    "unordentlichstes": "unordentlich",
    "unorthodoxem": "unorthodox",
    "unorthodoxen": "unorthodox",
    "unorthodoxer": "unorthodox",
    "unorthodoxere": "unorthodox",
    "unorthodoxerem": "unorthodox",
    "unorthodoxeren": "unorthodox",
    "unorthodoxerer": "unorthodox",
    "unorthodoxeres": "unorthodox",
    "unorthodoxes": "unorthodox",
    "unorthodoxeste": "unorthodox",
    "unorthodoxestem": "unorthodox",
    "unorthodoxesten": "unorthodox",
    "unorthodoxester": "unorthodox",
    "unorthodoxestes": "unorthodox",
    "unparteiische": "unparteiisch",
    "unparteiischem": "unparteiisch",
    "unparteiischen": "unparteiisch",
    "unparteiischer": "unparteiisch",
    "unparteiischere": "unparteiisch",
    "unparteiischerem": "unparteiisch",
    "unparteiischeren": "unparteiisch",
    "unparteiischerer": "unparteiisch",
    "unparteiischeres": "unparteiisch",
    "unparteiisches": "unparteiisch",
    "unparteiischste": "unparteiisch",
    "unparteiischstem": "unparteiisch",
    "unparteiischsten": "unparteiisch",
    "unparteiischster": "unparteiisch",
    "unparteiischstes": "unparteiisch",
    "unpassende": "unpassend",
    "unpassendem": "unpassend",
    "unpassenden": "unpassend",
    "unpassender": "unpassend",
    "unpassendere": "unpassend",
    "unpassenderem": "unpassend",
    "unpassenderen": "unpassend",
    "unpassenderer": "unpassend",
    "unpassenderes": "unpassend",
    "unpassendes": "unpassend",
    "unpassendste": "unpassend",
    "unpassendstem": "unpassend",
    "unpassendsten": "unpassend",
    "unpassendster": "unpassend",
    "unpassendstes": "unpassend",
    "unpersönlichem": "unpersönlich",
    "unpersönlichen": "unpersönlich",
    "unpersönlicher": "unpersönlich",
    "unpersönlichere": "unpersönlich",
    "unpersönlicherem": "unpersönlich",
    "unpersönlicheren": "unpersönlich",
    "unpersönlicherer": "unpersönlich",
    "unpersönlicheres": "unpersönlich",
    "unpersönliches": "unpersönlich",
    "unpersönlichste": "unpersönlich",
    "unpersönlichstem": "unpersönlich",
    "unpersönlichsten": "unpersönlich",
    "unpersönlichster": "unpersönlich",
    "unpersönlichstes": "unpersönlich",
    "unpolitische": "unpolitisch",
    "unpolitischem": "unpolitisch",
    "unpolitischen": "unpolitisch",
    "unpolitischer": "unpolitisch",
    "unpolitischere": "unpolitisch",
    "unpolitischerem": "unpolitisch",
    "unpolitischeren": "unpolitisch",
    "unpolitischerer": "unpolitisch",
    "unpolitischeres": "unpolitisch",
    "unpolitisches": "unpolitisch",
    "unpolitischste": "unpolitisch",
    "unpolitischstem": "unpolitisch",
    "unpolitischsten": "unpolitisch",
    "unpolitischster": "unpolitisch",
    "unpolitischstes": "unpolitisch",
    "unpopuläre": "unpopulär",
    "unpopulärem": "unpopulär",
    "unpopulären": "unpopulär",
    "unpopulärer": "unpopulär",
    "unpopulärere": "unpopulär",
    "unpopulärerem": "unpopulär",
    "unpopuläreren": "unpopulär",
    "unpopulärerer": "unpopulär",
    "unpopuläreres": "unpopulär",
    "unpopuläres": "unpopulär",
    "unpopulärste": "unpopulär",
    "unpopulärstem": "unpopulär",
    "unpopulärsten": "unpopulär",
    "unpopulärster": "unpopulär",
    "unpopulärstes": "unpopulär",
    "unpraktikabelste": "unpraktikabel",
    "unpraktikabelstem": "unpraktikabel",
    "unpraktikabelsten": "unpraktikabel",
    "unpraktikabelster": "unpraktikabel",
    "unpraktikabelstes": "unpraktikabel",
    "unpraktikable": "unpraktikabel",
    "unpraktikablem": "unpraktikabel",
    "unpraktikablen": "unpraktikabel",
    "unpraktikabler": "unpraktikabel",
    "unpraktikablere": "unpraktikabel",
    "unpraktikablerem": "unpraktikabel",
    "unpraktikableren": "unpraktikabel",
    "unpraktikablerer": "unpraktikabel",
    "unpraktikableres": "unpraktikabel",
    "unpraktikables": "unpraktikabel",
    "unpraktische": "unpraktisch",
    "unpraktischem": "unpraktisch",
    "unpraktischen": "unpraktisch",
    "unpraktischer": "unpraktisch",
    "unpraktischere": "unpraktisch",
    "unpraktischerem": "unpraktisch",
    "unpraktischeren": "unpraktisch",
    "unpraktischerer": "unpraktisch",
    "unpraktischeres": "unpraktisch",
    "unpraktisches": "unpraktisch",
    "unpraktischste": "unpraktisch",
    "unpraktischstem": "unpraktisch",
    "unpraktischsten": "unpraktisch",
    "unpraktischster": "unpraktisch",
    "unpraktischstes": "unpraktisch",
    "unproblematische": "unproblematisch",
    "unproblematischem": "unproblematisch",
    "unproblematischen": "unproblematisch",
    "unproblematischer": "unproblematisch",
    "unproblematischere": "unproblematisch",
    "unproblematischerem": "unproblematisch",
    "unproblematischeren": "unproblematisch",
    "unproblematischerer": "unproblematisch",
    "unproblematischeres": "unproblematisch",
    "unproblematisches": "unproblematisch",
    "unproblematischste": "unproblematisch",
    "unproblematischstem": "unproblematisch",
    "unproblematischsten": "unproblematisch",
    "unproblematischster": "unproblematisch",
    "unproblematischstes": "unproblematisch",
    "unproduktive": "unproduktiv",
    "unproduktivem": "unproduktiv",
    "unproduktiven": "unproduktiv",
    "unproduktiver": "unproduktiv",
    "unproduktivere": "unproduktiv",
    "unproduktiverem": "unproduktiv",
    "unproduktiveren": "unproduktiv",
    "unproduktiverer": "unproduktiv",
    "unproduktiveres": "unproduktiv",
    "unproduktives": "unproduktiv",
    "unproduktivste": "unproduktiv",
    "unproduktivstem": "unproduktiv",
    "unproduktivsten": "unproduktiv",
    "unproduktivster": "unproduktiv",
    "unproduktivstes": "unproduktiv",
    "unpräzise": "unpräzis",
    "unpräzisem": "unpräzis",
    "unpräzisen": "unpräzis",
    "unpräziser": "unpräzis",
    "unpräzisere": "unpräzis",
    "unpräziserem": "unpräzis",
    "unpräziseren": "unpräzis",
    "unpräziserer": "unpräzis",
    "unpräziseres": "unpräzis",
    "unpräzises": "unpräzis",
    "unpräziseste": "unpräzis",
    "unpräzisestem": "unpräzis",
    "unpräzisesten": "unpräzis",
    "unpräzisester": "unpräzis",
    "unpräzisestes": "unpräzis",
    "unpäßliche": "unpäßlich",
    "unpäßlichem": "unpäßlich",
    "unpäßlichen": "unpäßlich",
    "unpäßlicher": "unpäßlich",
    "unpäßliches": "unpäßlich",
    "unpünktliche": "unpünktlich",
    "unpünktlichem": "unpünktlich",
    "unpünktlichen": "unpünktlich",
    "unpünktlicher": "unpünktlich",
    "unpünktlichere": "unpünktlich",
    "unpünktlicherem": "unpünktlich",
    "unpünktlicheren": "unpünktlich",
    "unpünktlicherer": "unpünktlich",
    "unpünktlicheres": "unpünktlich",
    "unpünktliches": "unpünktlich",
    "unpünktlichste": "unpünktlich",
    "unpünktlichstem": "unpünktlich",
    "unpünktlichsten": "unpünktlich",
    "unpünktlichster": "unpünktlich",
    "unpünktlichstes": "unpünktlich",
    "unqualifizierte": "unqualifiziert",
    "unqualifiziertem": "unqualifiziert",
    "unqualifizierten": "unqualifiziert",
    "unqualifizierter": "unqualifiziert",
    "unqualifiziertere": "unqualifiziert",
    "unqualifizierterem": "unqualifiziert",
    "unqualifizierteren": "unqualifiziert",
    "unqualifizierterer": "unqualifiziert",
    "unqualifizierteres": "unqualifiziert",
    "unqualifiziertes": "unqualifiziert",
    "unqualifizierteste": "unqualifiziert",
    "unqualifiziertestem": "unqualifiziert",
    "unqualifiziertesten": "unqualifiziert",
    "unqualifiziertester": "unqualifiziert",
    "unqualifiziertestes": "unqualifiziert",
    "unrasierte": "unrasiert",
    "unrasiertem": "unrasiert",
    "unrasierten": "unrasiert",
    "unrasierter": "unrasiert",
    "unrasiertere": "unrasiert",
    "unrasierterem": "unrasiert",
    "unrasierteren": "unrasiert",
    "unrasierterer": "unrasiert",
    "unrasierteres": "unrasiert",
    "unrasiertes": "unrasiert",
    "unrasierteste": "unrasiert",
    "unrasiertestem": "unrasiert",
    "unrasiertesten": "unrasiert",
    "unrasiertester": "unrasiert",
    "unrasiertestes": "unrasiert",
    "unrealistischem": "unrealistisch",
    "unrealistischen": "unrealistisch",
    "unrealistischer": "unrealistisch",
    "unrealistischere": "unrealistisch",
    "unrealistischerem": "unrealistisch",
    "unrealistischeren": "unrealistisch",
    "unrealistischerer": "unrealistisch",
    "unrealistischeres": "unrealistisch",
    "unrealistisches": "unrealistisch",
    "unrealistischste": "unrealistisch",
    "unrealistischstem": "unrealistisch",
    "unrealistischsten": "unrealistisch",
    "unrealistischster": "unrealistisch",
    "unrealistischstes": "unrealistisch",
    "unrechte": "unrecht",
    "unrechtem": "unrecht",
    "unrechten": "unrecht",
    "unrechter": "unrecht",
    "unrechtere": "unrecht",
    "unrechterem": "unrecht",
    "unrechteren": "unrecht",
    "unrechterer": "unrecht",
    "unrechteres": "unrecht",
    "unrechtes": "unrecht",
    "unrechtestem": "unrecht",
    "unrechtesten": "unrecht",
    "unrechtester": "unrecht",
    "unrechtestes": "unrecht",
    "unrechtmäßige": "unrechtmäßig",
    "unrechtmäßigem": "unrechtmäßig",
    "unrechtmäßigen": "unrechtmäßig",
    "unrechtmäßiger": "unrechtmäßig",
    "unrechtmäßiges": "unrechtmäßig",
    "unreflektiertem": "unreflektiert",
    "unreflektierten": "unreflektiert",
    "unreflektierter": "unreflektiert",
    "unreflektiertere": "unreflektiert",
    "unreflektierterem": "unreflektiert",
    "unreflektierteren": "unreflektiert",
    "unreflektierterer": "unreflektiert",
    "unreflektierteres": "unreflektiert",
    "unreflektiertes": "unreflektiert",
    "unreflektierteste": "unreflektiert",
    "unreflektiertestem": "unreflektiert",
    "unreflektiertesten": "unreflektiert",
    "unreflektiertester": "unreflektiert",
    "unreflektiertestes": "unreflektiert",
    "unregelmäßige": "unregelmäßig",
    "unregelmäßigem": "unregelmäßig",
    "unregelmäßigen": "unregelmäßig",
    "unregelmäßiger": "unregelmäßig",
    "unregelmäßigere": "unregelmäßig",
    "unregelmäßigerem": "unregelmäßig",
    "unregelmäßigeren": "unregelmäßig",
    "unregelmäßigerer": "unregelmäßig",
    "unregelmäßigeres": "unregelmäßig",
    "unregelmäßiges": "unregelmäßig",
    "unregelmäßigstem": "unregelmäßig",
    "unregelmäßigsten": "unregelmäßig",
    "unregelmäßigster": "unregelmäßig",
    "unregelmäßigstes": "unregelmäßig",
    "unreife": "unreif",
    "unreifem": "unreif",
    "unreifen": "unreif",
    "unreifer": "unreif",
    "unreifere": "unreif",
    "unreiferem": "unreif",
    "unreiferen": "unreif",
    "unreiferer": "unreif",
    "unreiferes": "unreif",
    "unreifes": "unreif",
    "unreifste": "unreif",
    "unreifstem": "unreif",
    "unreifsten": "unreif",
    "unreifster": "unreif",
    "unreifstes": "unreif",
    "unreine": "unrein",
    "unreinem": "unrein",
    "unreinen": "unrein",
    "unreiner": "unrein",
    "unreinere": "unrein",
    "unreinerem": "unrein",
    "unreineren": "unrein",
    "unreinerer": "unrein",
    "unreineres": "unrein",
    "unreines": "unrein",
    "unreinste": "unrein",
    "unreinstem": "unrein",
    "unreinsten": "unrein",
    "unreinster": "unrein",
    "unreinstes": "unrein",
    "unrentable": "unrentabel",
    "unrentablem": "unrentabel",
    "unrentablen": "unrentabel",
    "unrentabler": "unrentabel",
    "unrentables": "unrentabel",
    "unruhigem": "unruhig",
    "unruhigen": "unruhig",
    "unruhiger": "unruhig",
    "unruhigere": "unruhig",
    "unruhigerem": "unruhig",
    "unruhigeren": "unruhig",
    "unruhigerer": "unruhig",
    "unruhigeres": "unruhig",
    "unruhiges": "unruhig",
    "unruhigste": "unruhig",
    "unruhigstem": "unruhig",
    "unruhigsten": "unruhig",
    "unruhigster": "unruhig",
    "unruhigstes": "unruhig",
    "unrunde": "unrund",
    "unrundem": "unrund",
    "unrunden": "unrund",
    "unrunder": "unrund",
    "unrundere": "unrund",
    "unrunderem": "unrund",
    "unrunderen": "unrund",
    "unrunderer": "unrund",
    "unrunderes": "unrund",
    "unrundes": "unrund",
    "unrundeste": "unrund",
    "unrundestem": "unrund",
    "unrundesten": "unrund",
    "unrundester": "unrund",
    "unrundestes": "unrund",
    "unrühmliche": "unrühmlich",
    "unrühmlichem": "unrühmlich",
    "unrühmlichen": "unrühmlich",
    "unrühmlicher": "unrühmlich",
    "unrühmlichere": "unrühmlich",
    "unrühmlicherem": "unrühmlich",
    "unrühmlicheren": "unrühmlich",
    "unrühmlicherer": "unrühmlich",
    "unrühmlicheres": "unrühmlich",
    "unrühmliches": "unrühmlich",
    "unrühmlichste": "unrühmlich",
    "unrühmlichstem": "unrühmlich",
    "unrühmlichsten": "unrühmlich",
    "unrühmlichster": "unrühmlich",
    "unrühmlichstes": "unrühmlich",
    "uns": "sich",
    "unsachgemäße": "unsachgemäß",
    "unsachgemäßem": "unsachgemäß",
    "unsachgemäßen": "unsachgemäß",
    "unsachgemäßer": "unsachgemäß",
    "unsachgemäßes": "unsachgemäß",
    "unsachliche": "unsachlich",
    "unsachlichem": "unsachlich",
    "unsachlichen": "unsachlich",
    "unsachlicher": "unsachlich",
    "unsachlichere": "unsachlich",
    "unsachlicherem": "unsachlich",
    "unsachlicheren": "unsachlich",
    "unsachlicherer": "unsachlich",
    "unsachlicheres": "unsachlich",
    "unsachliches": "unsachlich",
    "unsachlichste": "unsachlich",
    "unsachlichstem": "unsachlich",
    "unsachlichsten": "unsachlich",
    "unsachlichster": "unsachlich",
    "unsachlichstes": "unsachlich",
    "unsagbare": "unsagbar",
    "unsagbarem": "unsagbar",
    "unsagbaren": "unsagbar",
    "unsagbarer": "unsagbar",
    "unsagbarere": "unsagbar",
    "unsagbarerem": "unsagbar",
    "unsagbareren": "unsagbar",
    "unsagbarerer": "unsagbar",
    "unsagbareres": "unsagbar",
    "unsagbares": "unsagbar",
    "unsagbarste": "unsagbar",
    "unsagbarstem": "unsagbar",
    "unsagbarsten": "unsagbar",
    "unsagbarster": "unsagbar",
    "unsagbarstes": "unsagbar",
    "unsanfte": "unsanft",
    "unsanftem": "unsanft",
    "unsanften": "unsanft",
    "unsanfter": "unsanft",
    "unsanftere": "unsanft",
    "unsanfterem": "unsanft",
    "unsanfteren": "unsanft",
    "unsanfterer": "unsanft",
    "unsanfteres": "unsanft",
    "unsanftes": "unsanft",
    "unsanfteste": "unsanft",
    "unsanftestem": "unsanft",
    "unsanftesten": "unsanft",
    "unsanftester": "unsanft",
    "unsanftestes": "unsanft",
    "unsaubere": "unsauber",
    "unsauberem": "unsauber",
    "unsauberen": "unsauber",
    "unsauberer": "unsauber",
    "unsauberes": "unsauber",
    "unscharfe": "unscharf",
    "unscharfem": "unscharf",
    "unscharfen": "unscharf",
    "unscharfer": "unscharf",
    "unscharfes": "unscharf",
    "unscheinbare": "unscheinbar",
    "unscheinbarem": "unscheinbar",
    "unscheinbaren": "unscheinbar",
    "unscheinbarer": "unscheinbar",
    "unscheinbarere": "unscheinbar",
    "unscheinbarerem": "unscheinbar",
    "unscheinbareren": "unscheinbar",
    "unscheinbarerer": "unscheinbar",
    "unscheinbareres": "unscheinbar",
    "unscheinbares": "unscheinbar",
    "unscheinbarste": "unscheinbar",
    "unscheinbarstem": "unscheinbar",
    "unscheinbarsten": "unscheinbar",
    "unscheinbarster": "unscheinbar",
    "unscheinbarstes": "unscheinbar",
    "unschlagbare": "unschlagbar",
    "unschlagbarem": "unschlagbar",
    "unschlagbaren": "unschlagbar",
    "unschlagbarer": "unschlagbar",
    "unschlagbares": "unschlagbar",
    "unschlüssige": "unschlüssig",
    "unschlüssigem": "unschlüssig",
    "unschlüssigen": "unschlüssig",
    "unschlüssiger": "unschlüssig",
    "unschlüssigere": "unschlüssig",
    "unschlüssigerem": "unschlüssig",
    "unschlüssigeren": "unschlüssig",
    "unschlüssigerer": "unschlüssig",
    "unschlüssigeres": "unschlüssig",
    "unschlüssiges": "unschlüssig",
    "unschlüssigste": "unschlüssig",
    "unschlüssigstem": "unschlüssig",
    "unschlüssigsten": "unschlüssig",
    "unschlüssigster": "unschlüssig",
    "unschlüssigstes": "unschlüssig",
    "unschuldige": "unschuldig",
    "unschuldigem": "unschuldig",
    "unschuldigen": "unschuldig",
    "unschuldiger": "unschuldig",
    "unschuldigere": "unschuldig",
    "unschuldigerem": "unschuldig",
    "unschuldigeren": "unschuldig",
    "unschuldigerer": "unschuldig",
    "unschuldigeres": "unschuldig",
    "unschuldiges": "unschuldig",
    "unschuldigste": "unschuldig",
    "unschuldigstem": "unschuldig",
    "unschuldigsten": "unschuldig",
    "unschuldigster": "unschuldig",
    "unschuldigstes": "unschuldig",
    "unschädliche": "unschädlich",
    "unschädlichem": "unschädlich",
    "unschädlichen": "unschädlich",
    "unschädlicher": "unschädlich",
    "unschädliches": "unschädlich",
    "unschöne": "unschön",
    "unschönem": "unschön",
    "unschönen": "unschön",
    "unschöner": "unschön",
    "unschönere": "unschön",
    "unschönerem": "unschön",
    "unschöneren": "unschön",
    "unschönerer": "unschön",
    "unschöneres": "unschön",
    "unschönes": "unschön",
    "unschönste": "unschön",
    "unschönstem": "unschön",
    "unschönsten": "unschön",
    "unschönster": "unschön",
    "unschönstes": "unschön",
    "unselbständigem": "unselbständig",
    "unselbständigen": "unselbständig",
    "unselbständiger": "unselbständig",
    "unselbständigere": "unselbständig",
    "unselbständigerem": "unselbständig",
    "unselbständigeren": "unselbständig",
    "unselbständigerer": "unselbständig",
    "unselbständigeres": "unselbständig",
    "unselbständiges": "unselbständig",
    "unselbständigste": "unselbständig",
    "unselbständigstem": "unselbständig",
    "unselbständigsten": "unselbständig",
    "unselbständigster": "unselbständig",
    "unselbständigstes": "unselbständig",
    "unser": "sich",
    "unsere": "mein",
    "unserem": "mein",
    "unseren": "mein",
    "unserer": "mein",
    "unseres": "mein",
    "unseresgleichen": "seinesgleichen",
    "unsichere": "unsicher",
    "unsicherem": "unsicher",
    "unsicheren": "unsicher",
    "unsicherer": "unsicher",
    "unsicherere": "unsicher",
    "unsichererem": "unsicher",
    "unsichereren": "unsicher",
    "unsichererer": "unsicher",
    "unsichereres": "unsicher",
    "unsicheres": "unsicher",
    "unsicherstem": "unsicher",
    "unsichersten": "unsicher",
    "unsicherster": "unsicher",
    "unsicherstes": "unsicher",
    "unsichtbare": "unsichtbar",
    "unsichtbarem": "unsichtbar",
    "unsichtbaren": "unsichtbar",
    "unsichtbarer": "unsichtbar",
    "unsichtbarere": "unsichtbar",
    "unsichtbarerem": "unsichtbar",
    "unsichtbareren": "unsichtbar",
    "unsichtbarerer": "unsichtbar",
    "unsichtbareres": "unsichtbar",
    "unsichtbares": "unsichtbar",
    "unsichtbarste": "unsichtbar",
    "unsichtbarstem": "unsichtbar",
    "unsichtbarsten": "unsichtbar",
    "unsichtbarster": "unsichtbar",
    "unsichtbarstes": "unsichtbar",
    "unsinnige": "unsinnig",
    "unsinnigem": "unsinnig",
    "unsinnigen": "unsinnig",
    "unsinniger": "unsinnig",
    "unsinnigere": "unsinnig",
    "unsinnigerem": "unsinnig",
    "unsinnigeren": "unsinnig",
    "unsinnigerer": "unsinnig",
    "unsinnigeres": "unsinnig",
    "unsinniges": "unsinnig",
    "unsinnigste": "unsinnig",
    "unsinnigstem": "unsinnig",
    "unsinnigsten": "unsinnig",
    "unsinnigster": "unsinnig",
    "unsinnigstes": "unsinnig",
    "unsittlichem": "unsittlich",
    "unsittlichen": "unsittlich",
    "unsittlicher": "unsittlich",
    "unsittlichere": "unsittlich",
    "unsittlicherem": "unsittlich",
    "unsittlicheren": "unsittlich",
    "unsittlicherer": "unsittlich",
    "unsittlicheres": "unsittlich",
    "unsittliches": "unsittlich",
    "unsittlichste": "unsittlich",
    "unsittlichstem": "unsittlich",
    "unsittlichsten": "unsittlich",
    "unsittlichster": "unsittlich",
    "unsittlichstes": "unsittlich",
    "unsoziale": "unsozial",
    "unsozialem": "unsozial",
    "unsozialen": "unsozial",
    "unsozialer": "unsozial",
    "unsozialere": "unsozial",
    "unsozialerem": "unsozial",
    "unsozialeren": "unsozial",
    "unsozialerer": "unsozial",
    "unsozialeres": "unsozial",
    "unsoziales": "unsozial",
    "unsozialste": "unsozial",
    "unsozialstem": "unsozial",
    "unsozialsten": "unsozial",
    "unsozialster": "unsozial",
    "unsozialstes": "unsozial",
    "unsportliche": "unsportlich",
    "unsportlichem": "unsportlich",
    "unsportlichen": "unsportlich",
    "unsportlicher": "unsportlich",
    "unsportlichere": "unsportlich",
    "unsportlicherem": "unsportlich",
    "unsportlicheren": "unsportlich",
    "unsportlicherer": "unsportlich",
    "unsportlicheres": "unsportlich",
    "unsportliches": "unsportlich",
    "unsportlichste": "unsportlich",
    "unsportlichstem": "unsportlich",
    "unsportlichsten": "unsportlich",
    "unsportlichster": "unsportlich",
    "unsportlichstes": "unsportlich",
    "unsterbliche": "unsterblich",
    "unsterblichem": "unsterblich",
    "unsterblichen": "unsterblich",
    "unsterblicher": "unsterblich",
    "unsterblichere": "unsterblich",
    "unsterblicherem": "unsterblich",
    "unsterblicheren": "unsterblich",
    "unsterblicherer": "unsterblich",
    "unsterblicheres": "unsterblich",
    "unsterbliches": "unsterblich",
    "unsterblichste": "unsterblich",
    "unsterblichstem": "unsterblich",
    "unsterblichsten": "unsterblich",
    "unsterblichster": "unsterblich",
    "unsterblichstes": "unsterblich",
    "unstimmige": "unstimmig",
    "unstimmigem": "unstimmig",
    "unstimmigen": "unstimmig",
    "unstimmiger": "unstimmig",
    "unstimmigere": "unstimmig",
    "unstimmigerem": "unstimmig",
    "unstimmigeren": "unstimmig",
    "unstimmigerer": "unstimmig",
    "unstimmigeres": "unstimmig",
    "unstimmiges": "unstimmig",
    "unstimmigstem": "unstimmig",
    "unstimmigsten": "unstimmig",
    "unstimmigster": "unstimmig",
    "unstimmigstes": "unstimmig",
    "unsympathischem": "unsympathisch",
    "unsympathischen": "unsympathisch",
    "unsympathischer": "unsympathisch",
    "unsympathischere": "unsympathisch",
    "unsympathischerem": "unsympathisch",
    "unsympathischeren": "unsympathisch",
    "unsympathischerer": "unsympathisch",
    "unsympathischeres": "unsympathisch",
    "unsympathisches": "unsympathisch",
    "unsympathischste": "unsympathisch",
    "unsympathischstem": "unsympathisch",
    "unsympathischsten": "unsympathisch",
    "unsympathischster": "unsympathisch",
    "unsympathischstes": "unsympathisch",
    "unsystematische": "unsystematisch",
    "unsystematischem": "unsystematisch",
    "unsystematischen": "unsystematisch",
    "unsystematischer": "unsystematisch",
    "unsystematischere": "unsystematisch",
    "unsystematischerem": "unsystematisch",
    "unsystematischeren": "unsystematisch",
    "unsystematischerer": "unsystematisch",
    "unsystematischeres": "unsystematisch",
    "unsystematisches": "unsystematisch",
    "unsystematischste": "unsystematisch",
    "unsystematischstem": "unsystematisch",
    "unsystematischsten": "unsystematisch",
    "unsystematischster": "unsystematisch",
    "unsystematischstes": "unsystematisch",
    "untalentierte": "untalentiert",
    "untalentiertem": "untalentiert",
    "untalentierten": "untalentiert",
    "untalentierter": "untalentiert",
    "untalentiertere": "untalentiert",
    "untalentierterem": "untalentiert",
    "untalentierteren": "untalentiert",
    "untalentierterer": "untalentiert",
    "untalentierteres": "untalentiert",
    "untalentiertes": "untalentiert",
    "untalentierteste": "untalentiert",
    "untalentiertestem": "untalentiert",
    "untalentiertesten": "untalentiert",
    "untalentiertester": "untalentiert",
    "untalentiertestes": "untalentiert",
    "untaugliche": "untauglich",
    "untauglichem": "untauglich",
    "untauglichen": "untauglich",
    "untauglicher": "untauglich",
    "untauglichere": "untauglich",
    "untauglicherem": "untauglich",
    "untauglicheren": "untauglich",
    "untauglicherer": "untauglich",
    "untauglicheres": "untauglich",
    "untaugliches": "untauglich",
    "untauglichste": "untauglich",
    "untauglichstem": "untauglich",
    "untauglichsten": "untauglich",
    "untauglichster": "untauglich",
    "untauglichstes": "untauglich",
    "untenliegende": "untenliegend",
    "untenliegendem": "untenliegend",
    "untenliegenden": "untenliegend",
    "untenliegender": "untenliegend",
    "untenliegendes": "untenliegend",
    "untenstehende": "untenstehend",
    "untenstehendem": "untenstehend",
    "untenstehenden": "untenstehend",
    "untenstehender": "untenstehend",
    "untenstehendes": "untenstehend",
    "unterband": "unterbinden",
    "unterbanden": "unterbinden",
    "unterbandest": "unterbinden",
    "unterbandet": "unterbinden",
    "unterbelegtem": "unterbelegt",
    "unterbelegten": "unterbelegt",
    "unterbelegter": "unterbelegt",
    "unterbelegtes": "unterbelegt",
    "unterbewertend": "unterbewerten",
    "unterbewertende": "unterbewertend",
    "unterbewertendem": "unterbewertend",
    "unterbewertenden": "unterbewertend",
    "unterbewertender": "unterbewertend",
    "unterbewertendere": "unterbewertend",
    "unterbewertenderem": "unterbewertend",
    "unterbewertenderen": "unterbewertend",
    "unterbewertenderer": "unterbewertend",
    "unterbewertenderes": "unterbewertend",
    "unterbewertendes": "unterbewertend",
    "unterbewertendste": "unterbewertend",
    "unterbewertendstem": "unterbewertend",
    "unterbewertendsten": "unterbewertend",
    "unterbewertendster": "unterbewertend",
    "unterbewertendstes": "unterbewertend",
    "unterbewertest": "unterbewerten",
    "unterbewertet": "unterbewerten",
    "unterbewertete": "unterbewerten",
    "unterbewertetem": "unterbewertet",
    "unterbewerteten": "unterbewerten",
    "unterbewerteter": "unterbewertet",
    "unterbewertetere": "unterbewertet",
    "unterbewerteterem": "unterbewertet",
    "unterbewerteteren": "unterbewertet",
    "unterbewerteterer": "unterbewertet",
    "unterbewerteteres": "unterbewertet",
    "unterbewertetes": "unterbewertet",
    "unterbewertetest": "unterbewerten",
    "unterbewertetestem": "unterbewertet",
    "unterbewertetesten": "unterbewertet",
    "unterbewertetester": "unterbewertet",
    "unterbewertetestes": "unterbewertet",
    "unterbewertetet": "unterbewerten",
    "unterbewußtem": "unterbewußt",
    "unterbewußten": "unterbewußt",
    "unterbewußter": "unterbewußt",
    "unterbewußtes": "unterbewußt",
    "unterbezahltem": "unterbezahlt",
    "unterbezahlten": "unterbezahlt",
    "unterbezahlter": "unterbezahlt",
    "unterbezahltes": "unterbezahlt",
    "unterbiete": "unterbieten",
    "unterbietend": "unterbieten",
    "unterbietende": "unterbietend",
    "unterbietendem": "unterbietend",
    "unterbietenden": "unterbietend",
    "unterbietender": "unterbietend",
    "unterbietendes": "unterbietend",
    "unterbietest": "unterbieten",
    "unterbietet": "unterbieten",
    "unterbinde": "unterbinden",
    "unterbindend": "unterbinden",
    "unterbindende": "unterbindend",
    "unterbindendem": "unterbindend",
    "unterbindenden": "unterbindend",
    "unterbindender": "unterbindend",
    "unterbindendes": "unterbindend",
    "unterbindest": "unterbinden",
    "unterbindet": "unterbinden",
    "unterbleibe": "unterbleiben",
    "unterbleibend": "unterbleiben",
    "unterbleibende": "unterbleibend",
    "unterbleibendem": "unterbleibend",
    "unterbleibenden": "unterbleibend",
    "unterbleibender": "unterbleibend",
    "unterbleibendes": "unterbleibend",
    "unterbleibest": "unterbleiben",
    "unterbleibet": "unterbleiben",
    "unterbleibst": "unterbleiben",
    "unterbleibt": "unterbleiben",
    "unterblieb": "unterbleiben",
    "unterbliebe": "unterbleiben",
    "unterblieben": "unterbleiben",
    "unterbliebene": "unterblieben",
    "unterbliebenem": "unterblieben",
    "unterbliebenen": "unterblieben",
    "unterbliebener": "unterblieben",
    "unterbliebenes": "unterblieben",
    "unterbliebest": "unterbleiben",
    "unterbliebet": "unterbleiben",
    "unterbliebst": "unterbleiben",
    "unterbliebt": "unterbleiben",
    "unterbot": "unterbieten",
    "unterboten": "unterbieten",
    "unterbotene": "unterboten",
    "unterbotenem": "unterboten",
    "unterbotenen": "unterboten",
    "unterbotener": "unterboten",
    "unterbotenes": "unterboten",
    "unterbotest": "unterbieten",
    "unterbotet": "unterbieten",
    "unterbrach": "unterbrechen",
    "unterbrachen": "unterbrechen",
    "unterbrachst": "unterbrechen",
    "unterbracht": "unterbrechen",
    "unterbrachte": "unterbringen",
    "unterbrachten": "unterbringen",
    "unterbrachtest": "unterbringen",
    "unterbrachtet": "unterbringen",
    "unterbreche": "unterbrechen",
    "unterbrechend": "unterbrechen",
    "unterbrechende": "unterbrechend",
    "unterbrechendem": "unterbrechend",
    "unterbrechenden": "unterbrechend",
    "unterbrechender": "unterbrechend",
    "unterbrechendes": "unterbrechend",
    "unterbrechest": "unterbrechen",
    "unterbrechet": "unterbrechen",
    "unterbrecht": "unterbrechen",
    "unterbreite": "unterbreiten",
    "unterbreitend": "unterbreiten",
    "unterbreitende": "unterbreitend",
    "unterbreitendem": "unterbreitend",
    "unterbreitenden": "unterbreitend",
    "unterbreitender": "unterbreitend",
    "unterbreitendes": "unterbreitend",
    "unterbreitest": "unterbreiten",
    "unterbreitet": "unterbreiten",
    "unterbreitete": "unterbreiten",
    "unterbreitetem": "unterbreitet",
    "unterbreiteten": "unterbreiten",
    "unterbreiteter": "unterbreitet",
    "unterbreitetes": "unterbreitet",
    "unterbreitetest": "unterbreiten",
    "unterbreitetet": "unterbreiten",
    "unterbrich": "unterbrechen",
    "unterbrichst": "unterbrechen",
    "unterbricht": "unterbrechen",
    "unterbringe": "unterbringen",
    "unterbringend": "unterbringen",
    "unterbringende": "unterbringend",
    "unterbringendem": "unterbringend",
    "unterbringenden": "unterbringend",
    "unterbringender": "unterbringend",
    "unterbringendes": "unterbringend",
    "unterbringest": "unterbringen",
    "unterbringet": "unterbringen",
    "unterbringst": "unterbringen",
    "unterbringt": "unterbringen",
    "unterbrochen": "unterbrechen",
    "unterbrochene": "unterbrochen",
    "unterbrochenem": "unterbrochen",
    "unterbrochenen": "unterbrochen",
    "unterbrochener": "unterbrochen",
    "unterbrochenes": "unterbrochen",
    "unterbräche": "unterbrechen",
    "unterbrächen": "unterbrechen",
    "unterbrächest": "unterbrechen",
    "unterbrächet": "unterbrechen",
    "unterbrächte": "unterbringen",
    "unterbrächten": "unterbringen",
    "unterbrächtest": "unterbringen",
    "unterbrächtet": "unterbringen",
    "unterbunden": "unterbinden",
    "unterbundene": "unterbunden",
    "unterbundenem": "unterbunden",
    "unterbundenen": "unterbunden",
    "unterbundener": "unterbunden",
    "unterbundenes": "unterbunden",
    "unterbände": "unterbinden",
    "unterbänden": "unterbinden",
    "unterbändest": "unterbinden",
    "unterbändet": "unterbinden",
    "unterböte": "unterbieten",
    "unterböten": "unterbieten",
    "unterbötest": "unterbieten",
    "unterbötet": "unterbieten",
    "unterdrücke": "unterdrücken",
    "unterdrückend": "unterdrücken",
    "unterdrückende": "unterdrückend",
    "unterdrückendem": "unterdrückend",
    "unterdrückenden": "unterdrückend",
    "unterdrückender": "unterdrückend",
    "unterdrückendere": "unterdrückend",
    "unterdrückenderem": "unterdrückend",
    "unterdrückenderen": "unterdrückend",
    "unterdrückenderer": "unterdrückend",
    "unterdrückenderes": "unterdrückend",
    "unterdrückendes": "unterdrückend",
    "unterdrückendste": "unterdrückend",
    "unterdrückendstem": "unterdrückend",
    "unterdrückendsten": "unterdrückend",
    "unterdrückendster": "unterdrückend",
    "unterdrückendstes": "unterdrückend",
    "unterdrückest": "unterdrücken",
    "unterdrücket": "unterdrücken",
    "unterdrückst": "unterdrücken",
    "unterdrückt": "unterdrücken",
    "unterdrückte": "unterdrücken",
    "unterdrücktem": "unterdrückt",
    "unterdrückten": "unterdrücken",
    "unterdrückter": "unterdrückt",
    "unterdrücktere": "unterdrückt",
    "unterdrückterem": "unterdrückt",
    "unterdrückteren": "unterdrückt",
    "unterdrückterer": "unterdrückt",
    "unterdrückteres": "unterdrückt",
    "unterdrücktes": "unterdrückt",
    "unterdrücktest": "unterdrücken",
    "unterdrückteste": "unterdrückt",
    "unterdrücktestem": "unterdrückt",
    "unterdrücktesten": "unterdrückt",
    "unterdrücktester": "unterdrückt",
    "unterdrücktestes": "unterdrückt",
    "unterdrücktet": "unterdrücken",
    "unterem": "unter",
    "unteren": "unter",
    "unterentwickeltem": "unterentwickelt",
    "unterentwickelten": "unterentwickelt",
    "unterentwickelter": "unterentwickelt",
    "unterentwickeltere": "unterentwickelt",
    "unterentwickelterem": "unterentwickelt",
    "unterentwickelteren": "unterentwickelt",
    "unterentwickelterer": "unterentwickelt",
    "unterentwickelteres": "unterentwickelt",
    "unterentwickeltes": "unterentwickelt",
    "unterentwickelteste": "unterentwickelt",
    "unterentwickeltestem": "unterentwickelt",
    "unterentwickeltesten": "unterentwickelt",
    "unterentwickeltester": "unterentwickelt",
    "unterentwickeltestes": "unterentwickelt",
    "unterer": "unter",
    "unterere": "unter",
    "untererem": "unter",
    "untereren": "unter",
    "untererer": "unter",
    "untereres": "unter",
    "unterernährte": "unterernährt",
    "unterernährtem": "unterernährt",
    "unterernährten": "unterernährt",
    "unterernährter": "unterernährt",
    "unterernährtes": "unterernährt",
    "unteres": "unter",
    "unterfasse": "unterfassen",
    "unterfassend": "unterfassen",
    "unterfassende": "unterfassend",
    "unterfassendem": "unterfassend",
    "unterfassenden": "unterfassend",
    "unterfassender": "unterfassend",
    "unterfassendes": "unterfassend",
    "unterfassest": "unterfassen",
    "unterfasset": "unterfassen",
    "unterfaßt": "unterfassen",
    "unterfaßte": "unterfassen",
    "unterfaßten": "unterfassen",
    "unterfaßtest": "unterfassen",
    "unterfaßtet": "unterfassen",
    "untergebenem": "untergeben",
    "untergebenen": "untergeben",
    "untergebener": "untergeben",
    "untergebenes": "untergeben",
    "untergebracht": "unterbringen",
    "untergebrachte": "untergebracht",
    "untergebrachtem": "untergebracht",
    "untergebrachten": "untergebracht",
    "untergebrachter": "untergebracht",
    "untergebrachtes": "untergebracht",
    "untergefaßt": "unterfassen",
    "untergefaßte": "untergefaßt",
    "untergefaßtem": "untergefaßt",
    "untergefaßten": "untergefaßt",
    "untergefaßter": "untergefaßt",
    "untergefaßtes": "untergefaßt",
    "untergegangen": "untergehen",
    "untergegangene": "untergegangen",
    "untergegangenem": "untergegangen",
    "untergegangenen": "untergegangen",
    "untergegangener": "untergegangen",
    "untergegangenes": "untergegangen",
    "untergehakt": "unterhaken",
    "untergehakte": "untergehakt",
    "untergehaktem": "untergehakt",
    "untergehakten": "untergehakt",
    "untergehakter": "untergehakt",
    "untergehaktes": "untergehakt",
    "untergehe": "untergehen",
    "untergehend": "untergehen",
    "untergehende": "untergehend",
    "untergehendem": "untergehend",
    "untergehenden": "untergehend",
    "untergehender": "untergehend",
    "untergehendes": "untergehend",
    "untergehest": "untergehen",
    "untergehet": "untergehen",
    "untergehst": "untergehen",
    "untergeht": "untergehen",
    "untergejubelt": "unterjubeln",
    "untergejubelte": "untergejubelt",
    "untergejubeltem": "untergejubelt",
    "untergejubelten": "untergejubelt",
    "untergejubelter": "untergejubelt",
    "untergejubeltere": "untergejubelt",
    "untergejubelterem": "untergejubelt",
    "untergejubelteren": "untergejubelt",
    "untergejubelterer": "untergejubelt",
    "untergejubelteres": "untergejubelt",
    "untergejubeltes": "untergejubelt",
    "untergejubelteste": "untergejubelt",
    "untergejubeltestem": "untergejubelt",
    "untergejubeltesten": "untergejubelt",
    "untergejubeltester": "untergejubelt",
    "untergejubeltestes": "untergejubelt",
    "untergekommen": "unterkommen",
    "untergekommene": "untergekommen",
    "untergekommenem": "untergekommen",
    "untergekommenen": "untergekommen",
    "untergekommener": "untergekommen",
    "untergekommenes": "untergekommen",
    "untergekriegt": "unterkriegen",
    "untergekriegte": "untergekriegt",
    "untergekriegtem": "untergekriegt",
    "untergekriegten": "untergekriegt",
    "untergekriegter": "untergekriegt",
    "untergekriegtes": "untergekriegt",
    "untergekrochen": "unterkriechen",
    "untergekrochene": "untergekrochen",
    "untergekrochenem": "untergekrochen",
    "untergekrochenen": "untergekrochen",
    "untergekrochener": "untergekrochen",
    "untergekrochenes": "untergekrochen",
    "untergemengt": "untermengen",
    "untergemengte": "untergemengt",
    "untergemengtem": "untergemengt",
    "untergemengten": "untergemengt",
    "untergemengter": "untergemengt",
    "untergemengtes": "untergemengt",
    "untergemischt": "untermischen",
    "untergemischte": "untergemischt",
    "untergemischtem": "untergemischt",
    "untergemischten": "untergemischt",
    "untergemischter": "untergemischt",
    "untergemischtes": "untergemischt",
    "untergeordnet": "unterordnen",
    "untergeordnete": "untergeordnet",
    "untergeordnetem": "untergeordnet",
    "untergeordneten": "untergeordnet",
    "untergeordneter": "untergeordnet",
    "untergeordnetere": "untergeordnet",
    "untergeordneterem": "untergeordnet",
    "untergeordneteren": "untergeordnet",
    "untergeordneterer": "untergeordnet",
    "untergeordneteres": "untergeordnet",
    "untergeordnetes": "untergeordnet",
    "untergeordneteste": "untergeordnet",
    "untergeordnetestem": "untergeordnet",
    "untergeordnetesten": "untergeordnet",
    "untergeordnetester": "untergeordnet",
    "untergeordnetestes": "untergeordnet",
    "untergepflügt": "unterpflügen",
    "untergepflügte": "untergepflügt",
    "untergepflügtem": "untergepflügt",
    "untergepflügten": "untergepflügt",
    "untergepflügter": "untergepflügt",
    "untergepflügtes": "untergepflügt",
    "untergeschlagen": "unterschlagen",
    "untergeschlagene": "untergeschlagen",
    "untergeschlagenem": "untergeschlagen",
    "untergeschlagenen": "untergeschlagen",
    "untergeschlagener": "untergeschlagen",
    "untergeschlagenes": "untergeschlagen",
    "untergeschlüpft": "unterschlüpfen",
    "untergeschlüpfte": "untergeschlüpft",
    "untergeschlüpftem": "untergeschlüpft",
    "untergeschlüpften": "untergeschlüpft",
    "untergeschlüpfter": "untergeschlüpft",
    "untergeschlüpftes": "untergeschlüpft",
    "untergeschoben": "unterschieben",
    "untergeschobene": "untergeschoben",
    "untergeschobenem": "untergeschoben",
    "untergeschobenen": "untergeschoben",
    "untergeschobener": "untergeschoben",
    "untergeschobenes": "untergeschoben",
    "untergesetzt": "untersetzen",
    "untergesetzte": "untergesetzt",
    "untergesetztem": "untergesetzt",
    "untergesetzten": "untergesetzt",
    "untergesetzter": "untergesetzt",
    "untergesetztes": "untergesetzt",
    "untergestellt": "unterstellen",
    "untergestellte": "untergestellt",
    "untergestelltem": "untergestellt",
    "untergestellten": "untergestellt",
    "untergestellter": "untergestellt",
    "untergestelltes": "untergestellt",
    "untergestreut": "unterstreuen",
    "untergestreute": "untergestreut",
    "untergestreutem": "untergestreut",
    "untergestreuten": "untergestreut",
    "untergestreuter": "untergestreut",
    "untergestreutes": "untergestreut",
    "untergesunken": "untersinken",
    "untergesunkene": "untergesunken",
    "untergesunkenem": "untergesunken",
    "untergesunkenen": "untergesunken",
    "untergesunkener": "untergesunken",
    "untergesunkenes": "untergesunken",
    "untergetaucht": "untertauchen",
    "untergetauchte": "untergetaucht",
    "untergetauchtem": "untergetaucht",
    "untergetauchten": "untergetaucht",
    "untergetauchter": "untergetaucht",
    "untergetauchtere": "untergetaucht",
    "untergetauchterem": "untergetaucht",
    "untergetauchteren": "untergetaucht",
    "untergetauchterer": "untergetaucht",
    "untergetauchteres": "untergetaucht",
    "untergetauchtes": "untergetaucht",
    "untergetauchteste": "untergetaucht",
    "untergetauchtestem": "untergetaucht",
    "untergetauchtesten": "untergetaucht",
    "untergetauchtester": "untergetaucht",
    "untergetauchtestes": "untergetaucht",
    "untergetreten": "untertreten",
    "untergetretene": "untergetreten",
    "untergetretenem": "untergetreten",
    "untergetretenen": "untergetreten",
    "untergetretener": "untergetreten",
    "untergetretenes": "untergetreten",
    "unterging": "untergehen",
    "unterginge": "untergehen",
    "untergingen": "untergehen",
    "untergingest": "untergehen",
    "unterginget": "untergehen",
    "untergingst": "untergehen",
    "untergingt": "untergehen",
    "untergliedere": "untergliedern",
    "untergliedernd": "untergliedern",
    "untergliedernde": "untergliedernd",
    "untergliederndem": "untergliedernd",
    "untergliedernden": "untergliedernd",
    "untergliedernder": "untergliedernd",
    "untergliederndes": "untergliedernd",
    "untergliederst": "untergliedern",
    "untergliedert": "untergliedern",
    "untergliederte": "untergliedern",
    "untergliedertem": "untergliedert",
    "untergliederten": "untergliedern",
    "untergliederter": "untergliedert",
    "untergliedertes": "untergliedert",
    "untergliedertest": "untergliedern",
    "untergliedertet": "untergliedern",
    "untergrabe": "untergraben",
    "untergrabend": "untergraben",
    "untergrabende": "untergrabend",
    "untergrabendem": "untergrabend",
    "untergrabenden": "untergrabend",
    "untergrabender": "untergrabend",
    "untergrabendere": "untergrabend",
    "untergrabenderem": "untergrabend",
    "untergrabenderen": "untergrabend",
    "untergrabenderer": "untergrabend",
    "untergrabenderes": "untergrabend",
    "untergrabendes": "untergrabend",
    "untergrabendste": "untergrabend",
    "untergrabendstem": "untergrabend",
    "untergrabendsten": "untergrabend",
    "untergrabendster": "untergrabend",
    "untergrabendstes": "untergrabend",
    "untergrabene": "untergraben",
    "untergrabenem": "untergraben",
    "untergrabenen": "untergraben",
    "untergrabener": "untergraben",
    "untergrabenere": "untergraben",
    "untergrabenerem": "untergraben",
    "untergrabeneren": "untergraben",
    "untergrabenerer": "untergraben",
    "untergrabeneres": "untergraben",
    "untergrabenes": "untergraben",
    "untergrabenstem": "untergraben",
    "untergrabensten": "untergraben",
    "untergrabenster": "untergraben",
    "untergrabenstes": "untergraben",
    "untergrabest": "untergraben",
    "untergrabet": "untergraben",
    "untergrabt": "untergraben",
    "untergrub": "untergraben",
    "untergruben": "untergraben",
    "untergrubst": "untergraben",
    "untergrubt": "untergraben",
    "untergräbst": "untergraben",
    "untergräbt": "untergraben",
    "untergrübe": "untergraben",
    "untergrüben": "untergraben",
    "untergrübest": "untergraben",
    "untergrübet": "untergraben",
    "untergründige": "untergründig",
    "untergründigem": "untergründig",
    "untergründigen": "untergründig",
    "untergründiger": "untergründig",
    "untergründigere": "untergründig",
    "untergründigerem": "untergründig",
    "untergründigeren": "untergründig",
    "untergründigerer": "untergründig",
    "untergründigeres": "untergründig",
    "untergründiges": "untergründig",
    "untergründigste": "untergründig",
    "untergründigstem": "untergründig",
    "untergründigsten": "untergründig",
    "untergründigster": "untergründig",
    "untergründigstes": "untergründig",
    "unterhake": "unterhaken",
    "unterhakend": "unterhaken",
    "unterhakende": "unterhakend",
    "unterhakendem": "unterhakend",
    "unterhakenden": "unterhakend",
    "unterhakender": "unterhakend",
    "unterhakendes": "unterhakend",
    "unterhakest": "unterhaken",
    "unterhaket": "unterhaken",
    "unterhakst": "unterhaken",
    "unterhakt": "unterhaken",
    "unterhakte": "unterhaken",
    "unterhakten": "unterhaken",
    "unterhaktest": "unterhaken",
    "unterhaktet": "unterhaken",
    "unterhaltend": "unterhalten",
    "unterhaltende": "unterhaltend",
    "unterhaltendem": "unterhaltend",
    "unterhaltenden": "unterhaltend",
    "unterhaltender": "unterhaltend",
    "unterhaltendere": "unterhaltend",
    "unterhaltenderem": "unterhaltend",
    "unterhaltenderen": "unterhaltend",
    "unterhaltenderer": "unterhaltend",
    "unterhaltenderes": "unterhaltend",
    "unterhaltendes": "unterhaltend",
    "unterhaltendste": "unterhaltend",
    "unterhaltendstem": "unterhaltend",
    "unterhaltendsten": "unterhaltend",
    "unterhaltendster": "unterhaltend",
    "unterhaltendstes": "unterhaltend",
    "unterhaltene": "unterhalten",
    "unterhaltenem": "unterhalten",
    "unterhaltenen": "unterhalten",
    "unterhaltener": "unterhalten",
    "unterhaltenes": "unterhalten",
    "unterhaltest": "unterhalten",
    "unterhaltet": "unterhalten",
    "unterhaltsamem": "unterhaltsam",
    "unterhaltsamen": "unterhaltsam",
    "unterhaltsamer": "unterhaltsam",
    "unterhaltsamere": "unterhaltsam",
    "unterhaltsamerem": "unterhaltsam",
    "unterhaltsameren": "unterhaltsam",
    "unterhaltsamerer": "unterhaltsam",
    "unterhaltsameres": "unterhaltsam",
    "unterhaltsames": "unterhaltsam",
    "unterhaltsamste": "unterhaltsam",
    "unterhaltsamstem": "unterhaltsam",
    "unterhaltsamsten": "unterhaltsam",
    "unterhaltsamster": "unterhaltsam",
    "unterhaltsamstes": "unterhaltsam",
    "unterhaltsberechtigte": "unterhaltsberechtigt",
    "unterhaltsberechtigtem": "unterhaltsberechtigt",
    "unterhaltsberechtigten": "unterhaltsberechtigt",
    "unterhaltsberechtigter": "unterhaltsberechtigt",
    "unterhaltsberechtigtes": "unterhaltsberechtigt",
    "unterhaltspflichtige": "unterhaltspflichtig",
    "unterhaltspflichtigem": "unterhaltspflichtig",
    "unterhaltspflichtigen": "unterhaltspflichtig",
    "unterhaltspflichtiger": "unterhaltspflichtig",
    "unterhaltspflichtiges": "unterhaltspflichtig",
    "unterhielt": "unterhalten",
    "unterhielte": "unterhalten",
    "unterhielten": "unterhalten",
    "unterhieltest": "unterhalten",
    "unterhieltet": "unterhalten",
    "unterhält": "unterhalten",
    "unterhältst": "unterhalten",
    "unterjubele": "unterjubeln",
    "unterjubelnd": "unterjubeln",
    "unterjubelnde": "unterjubelnd",
    "unterjubelndem": "unterjubelnd",
    "unterjubelnden": "unterjubelnd",
    "unterjubelnder": "unterjubelnd",
    "unterjubelndere": "unterjubelnd",
    "unterjubelnderem": "unterjubelnd",
    "unterjubelnderen": "unterjubelnd",
    "unterjubelnderer": "unterjubelnd",
    "unterjubelnderes": "unterjubelnd",
    "unterjubelndes": "unterjubelnd",
    "unterjubelndste": "unterjubelnd",
    "unterjubelndstem": "unterjubelnd",
    "unterjubelndsten": "unterjubelnd",
    "unterjubelndster": "unterjubelnd",
    "unterjubelndstes": "unterjubelnd",
    "unterjubelst": "unterjubeln",
    "unterjubelt": "unterjubeln",
    "unterjubelte": "unterjubeln",
    "unterjubelten": "unterjubeln",
    "unterjubeltest": "unterjubeln",
    "unterjubeltet": "unterjubeln",
    "unterjuble": "unterjubeln",
    "unterkam": "unterkommen",
    "unterkamen": "unterkommen",
    "unterkamst": "unterkommen",
    "unterkamt": "unterkommen",
    "unterkellere": "unterkellern",
    "unterkellernd": "unterkellern",
    "unterkellernde": "unterkellernd",
    "unterkellerndem": "unterkellernd",
    "unterkellernden": "unterkellernd",
    "unterkellernder": "unterkellernd",
    "unterkellerndes": "unterkellernd",
    "unterkellerst": "unterkellern",
    "unterkellert": "unterkellern",
    "unterkellerte": "unterkellern",
    "unterkellertem": "unterkellert",
    "unterkellerten": "unterkellern",
    "unterkellerter": "unterkellert",
    "unterkellertes": "unterkellert",
    "unterkellertest": "unterkellern",
    "unterkellertet": "unterkellern",
    "unterkomme": "unterkommen",
    "unterkommend": "unterkommen",
    "unterkommende": "unterkommend",
    "unterkommendem": "unterkommend",
    "unterkommenden": "unterkommend",
    "unterkommender": "unterkommend",
    "unterkommendes": "unterkommend",
    "unterkommest": "unterkommen",
    "unterkommet": "unterkommen",
    "unterkommst": "unterkommen",
    "unterkommt": "unterkommen",
    "unterkrieche": "unterkriechen",
    "unterkriechend": "unterkriechen",
    "unterkriechende": "unterkriechend",
    "unterkriechendem": "unterkriechend",
    "unterkriechenden": "unterkriechend",
    "unterkriechender": "unterkriechend",
    "unterkriechendes": "unterkriechend",
    "unterkriechest": "unterkriechen",
    "unterkriechet": "unterkriechen",
    "unterkriechst": "unterkriechen",
    "unterkriecht": "unterkriechen",
    "unterkriege": "unterkriegen",
    "unterkriegend": "unterkriegen",
    "unterkriegende": "unterkriegend",
    "unterkriegendem": "unterkriegend",
    "unterkriegenden": "unterkriegend",
    "unterkriegender": "unterkriegend",
    "unterkriegendes": "unterkriegend",
    "unterkriegest": "unterkriegen",
    "unterkrieget": "unterkriegen",
    "unterkriegst": "unterkriegen",
    "unterkriegt": "unterkriegen",
    "unterkriegte": "unterkriegen",
    "unterkriegten": "unterkriegen",
    "unterkriegtest": "unterkriegen",
    "unterkriegtet": "unterkriegen",
    "unterkroch": "unterkriechen",
    "unterkrochen": "unterkriechen",
    "unterkrochst": "unterkriechen",
    "unterkrocht": "unterkriechen",
    "unterkröche": "unterkriechen",
    "unterkröchen": "unterkriechen",
    "unterkröchest": "unterkriechen",
    "unterkröchet": "unterkriechen",
    "unterkäme": "unterkommen",
    "unterkämen": "unterkommen",
    "unterkämest": "unterkommen",
    "unterkämet": "unterkommen",
    "unterkühle": "unterkühlen",
    "unterkühlend": "unterkühlen",
    "unterkühlende": "unterkühlend",
    "unterkühlendem": "unterkühlend",
    "unterkühlenden": "unterkühlend",
    "unterkühlender": "unterkühlend",
    "unterkühlendere": "unterkühlend",
    "unterkühlenderem": "unterkühlend",
    "unterkühlenderen": "unterkühlend",
    "unterkühlenderer": "unterkühlend",
    "unterkühlenderes": "unterkühlend",
    "unterkühlendes": "unterkühlend",
    "unterkühlendste": "unterkühlend",
    "unterkühlendstem": "unterkühlend",
    "unterkühlendsten": "unterkühlend",
    "unterkühlendster": "unterkühlend",
    "unterkühlendstes": "unterkühlend",
    "unterkühlest": "unterkühlen",
    "unterkühlet": "unterkühlen",
    "unterkühlst": "unterkühlen",
    "unterkühlt": "unterkühlen",
    "unterkühlte": "unterkühlen",
    "unterkühltem": "unterkühlt",
    "unterkühlten": "unterkühlen",
    "unterkühlter": "unterkühlt",
    "unterkühltere": "unterkühlt",
    "unterkühlterem": "unterkühlt",
    "unterkühlteren": "unterkühlt",
    "unterkühlterer": "unterkühlt",
    "unterkühlteres": "unterkühlt",
    "unterkühltes": "unterkühlt",
    "unterkühltest": "unterkühlen",
    "unterkühlteste": "unterkühlt",
    "unterkühltestem": "unterkühlt",
    "unterkühltesten": "unterkühlt",
    "unterkühltester": "unterkühlt",
    "unterkühltestes": "unterkühlt",
    "unterkühltet": "unterkühlen",
    "unterlag": "unterliegen",
    "unterlagst": "unterliegen",
    "unterlagt": "unterliegen",
    "unterlasse": "unterlassen",
    "unterlassend": "unterlassen",
    "unterlassende": "unterlassend",
    "unterlassendem": "unterlassend",
    "unterlassenden": "unterlassend",
    "unterlassender": "unterlassend",
    "unterlassendes": "unterlassend",
    "unterlassene": "unterlassen",
    "unterlassenem": "unterlassen",
    "unterlassenen": "unterlassen",
    "unterlassener": "unterlassen",
    "unterlassenes": "unterlassen",
    "unterlassest": "unterlassen",
    "unterlasset": "unterlassen",
    "unterlaufe": "unterlaufen",
    "unterlaufend": "unterlaufen",
    "unterlaufende": "unterlaufend",
    "unterlaufendem": "unterlaufend",
    "unterlaufenden": "unterlaufend",
    "unterlaufender": "unterlaufend",
    "unterlaufendes": "unterlaufend",
    "unterlaufene": "unterlaufen",
    "unterlaufenem": "unterlaufen",
    "unterlaufenen": "unterlaufen",
    "unterlaufener": "unterlaufen",
    "unterlaufenes": "unterlaufen",
    "unterlaufest": "unterlaufen",
    "unterlaufet": "unterlaufen",
    "unterlauft": "unterlaufen",
    "unterlaß": "unterlassen",
    "unterlaßt": "unterlassen",
    "unterlegen": "unterliegen",
    "unterlegene": "unterlegen",
    "unterlegenem": "unterlegen",
    "unterlegenen": "unterlegen",
    "unterlegener": "unterlegen",
    "unterlegenere": "unterlegen",
    "unterlegenerem": "unterlegen",
    "unterlegeneren": "unterlegen",
    "unterlegenerer": "unterlegen",
    "unterlegeneres": "unterlegen",
    "unterlegenes": "unterlegen",
    "unterlegenste": "unterlegen",
    "unterlegenstem": "unterlegen",
    "unterlegensten": "unterlegen",
    "unterlegenster": "unterlegen",
    "unterlegenstes": "unterlegen",
    "unterlief": "unterlaufen",
    "unterliefe": "unterlaufen",
    "unterliefen": "unterlaufen",
    "unterliefest": "unterlaufen",
    "unterliefet": "unterlaufen",
    "unterliefst": "unterlaufen",
    "unterlieft": "unterlaufen",
    "unterliege": "unterliegen",
    "unterliegend": "unterliegen",
    "unterliegende": "unterliegend",
    "unterliegendem": "unterliegend",
    "unterliegenden": "unterliegend",
    "unterliegender": "unterliegend",
    "unterliegendes": "unterliegend",
    "unterliegest": "unterliegen",
    "unterlieget": "unterliegen",
    "unterliegst": "unterliegen",
    "unterliegt": "unterliegen",
    "unterließ": "unterlassen",
    "unterließe": "unterlassen",
    "unterließen": "unterlassen",
    "unterließest": "unterlassen",
    "unterließet": "unterlassen",
    "unterließt": "unterlassen",
    "unterläge": "unterliegen",
    "unterlägen": "unterliegen",
    "unterlägest": "unterliegen",
    "unterläget": "unterliegen",
    "unterläufst": "unterlaufen",
    "unterläuft": "unterlaufen",
    "unterläßt": "unterlassen",
    "untermale": "untermalen",
    "untermalend": "untermalen",
    "untermalende": "untermalend",
    "untermalendem": "untermalend",
    "untermalenden": "untermalend",
    "untermalender": "untermalend",
    "untermalendes": "untermalend",
    "untermalest": "untermalen",
    "untermalet": "untermalen",
    "untermalst": "untermalen",
    "untermalt": "untermalen",
    "untermalte": "untermalen",
    "untermaltem": "untermalt",
    "untermalten": "untermalen",
    "untermalter": "untermalt",
    "untermaltes": "untermalt",
    "untermaltest": "untermalen",
    "untermaltet": "untermalen",
    "untermauere": "untermauern",
    "untermauernd": "untermauern",
    "untermauernde": "untermauernd",
    "untermauerndem": "untermauernd",
    "untermauernden": "untermauernd",
    "untermauernder": "untermauernd",
    "untermauerndes": "untermauernd",
    "untermauerst": "untermauern",
    "untermauert": "untermauern",
    "untermauerte": "untermauern",
    "untermauertem": "untermauert",
    "untermauerten": "untermauern",
    "untermauerter": "untermauert",
    "untermauertes": "untermauert",
    "untermauertest": "untermauern",
    "untermauertet": "untermauern",
    "untermenge": "untermengen",
    "untermengend": "untermengen",
    "untermengende": "untermengend",
    "untermengendem": "untermengend",
    "untermengenden": "untermengend",
    "untermengender": "untermengend",
    "untermengendes": "untermengend",
    "untermengest": "untermengen",
    "untermenget": "untermengen",
    "untermengst": "untermengen",
    "untermengt": "untermengen",
    "untermengte": "untermengen",
    "untermengten": "untermengen",
    "untermengtest": "untermengen",
    "untermengtet": "untermengen",
    "untermische": "untermischen",
    "untermischend": "untermischen",
    "untermischende": "untermischend",
    "untermischendem": "untermischend",
    "untermischenden": "untermischend",
    "untermischender": "untermischend",
    "untermischendes": "untermischend",
    "untermischest": "untermischen",
    "untermischet": "untermischen",
    "untermischst": "untermischen",
    "untermischt": "untermischen",
    "untermischte": "untermischen",
    "untermischten": "untermischen",
    "untermischtest": "untermischen",
    "untermischtet": "untermischen",
    "unternahm": "unternehmen",
    "unternahmen": "unternehmen",
    "unternahmst": "unternehmen",
    "unternahmt": "unternehmen",
    "unternehme": "unternehmen",
    "unternehmend": "unternehmen",
    "unternehmende": "unternehmend",
    "unternehmendem": "unternehmend",
    "unternehmenden": "unternehmend",
    "unternehmender": "unternehmend",
    "unternehmendere": "unternehmend",
    "unternehmenderem": "unternehmend",
    "unternehmenderen": "unternehmend",
    "unternehmenderer": "unternehmend",
    "unternehmenderes": "unternehmend",
    "unternehmendes": "unternehmend",
    "unternehmendste": "unternehmend",
    "unternehmendstem": "unternehmend",
    "unternehmendsten": "unternehmend",
    "unternehmendster": "unternehmend",
    "unternehmendstes": "unternehmend",
    "unternehmest": "unternehmen",
    "unternehmet": "unternehmen",
    "unternehmt": "unternehmen",
    "unternehmungslustigem": "unternehmungslustig",
    "unternehmungslustigen": "unternehmungslustig",
    "unternehmungslustiger": "unternehmungslustig",
    "unternehmungslustigere": "unternehmungslustig",
    "unternehmungslustigerem": "unternehmungslustig",
    "unternehmungslustigeren": "unternehmungslustig",
    "unternehmungslustigerer": "unternehmungslustig",
    "unternehmungslustigeres": "unternehmungslustig",
    "unternehmungslustiges": "unternehmungslustig",
    "unternehmungslustigste": "unternehmungslustig",
    "unternehmungslustigstem": "unternehmungslustig",
    "unternehmungslustigsten": "unternehmungslustig",
    "unternehmungslustigster": "unternehmungslustig",
    "unternehmungslustigstes": "unternehmungslustig",
    "unternimm": "unternehmen",
    "unternimmst": "unternehmen",
    "unternimmt": "unternehmen",
    "unternommen": "unternehmen",
    "unternommene": "unternommen",
    "unternommenem": "unternommen",
    "unternommenen": "unternommen",
    "unternommener": "unternommen",
    "unternommenes": "unternommen",
    "unternähme": "unternehmen",
    "unternähmen": "unternehmen",
    "unternähmest": "unternehmen",
    "unternähmet": "unternehmen",
    "unterordne": "unterordnen",
    "unterordnend": "unterordnen",
    "unterordnende": "unterordnend",
    "unterordnendem": "unterordnend",
    "unterordnenden": "unterordnend",
    "unterordnender": "unterordnend",
    "unterordnendere": "unterordnend",
    "unterordnenderem": "unterordnend",
    "unterordnenderen": "unterordnend",
    "unterordnenderer": "unterordnend",
    "unterordnenderes": "unterordnend",
    "unterordnendes": "unterordnend",
    "unterordnendste": "unterordnend",
    "unterordnendstem": "unterordnend",
    "unterordnendsten": "unterordnend",
    "unterordnendster": "unterordnend",
    "unterordnendstes": "unterordnend",
    "unterordnest": "unterordnen",
    "unterordnet": "unterordnen",
    "unterordnete": "unterordnen",
    "unterordneten": "unterordnen",
    "unterordnetest": "unterordnen",
    "unterordnetet": "unterordnen",
    "unterpflüge": "unterpflügen",
    "unterpflügend": "unterpflügen",
    "unterpflügende": "unterpflügend",
    "unterpflügendem": "unterpflügend",
    "unterpflügenden": "unterpflügend",
    "unterpflügender": "unterpflügend",
    "unterpflügendes": "unterpflügend",
    "unterpflügest": "unterpflügen",
    "unterpflüget": "unterpflügen",
    "unterpflügst": "unterpflügen",
    "unterpflügt": "unterpflügen",
    "unterpflügte": "unterpflügen",
    "unterpflügten": "unterpflügen",
    "unterpflügtest": "unterpflügen",
    "unterpflügtet": "unterpflügen",
    "unterquere": "unterqueren",
    "unterquerend": "unterqueren",
    "unterquerende": "unterquerend",
    "unterquerendem": "unterquerend",
    "unterquerenden": "unterquerend",
    "unterquerender": "unterquerend",
    "unterquerendes": "unterquerend",
    "unterquerest": "unterqueren",
    "unterqueret": "unterqueren",
    "unterquerst": "unterqueren",
    "unterquert": "unterqueren",
    "unterquerte": "unterqueren",
    "unterquertem": "unterquert",
    "unterquerten": "unterqueren",
    "unterquerter": "unterquert",
    "unterquertes": "unterquert",
    "unterquertest": "unterqueren",
    "unterquertet": "unterqueren",
    "unterrepräsentierte": "unterrepräsentiert",
    "unterrepräsentiertem": "unterrepräsentiert",
    "unterrepräsentierten": "unterrepräsentiert",
    "unterrepräsentierter": "unterrepräsentiert",
    "unterrepräsentiertes": "unterrepräsentiert",
    "unterrichtend": "unterrichten",
    "unterrichtende": "unterrichtend",
    "unterrichtendem": "unterrichtend",
    "unterrichtenden": "unterrichtend",
    "unterrichtender": "unterrichtend",
    "unterrichtendes": "unterrichtend",
    "unterrichtest": "unterrichten",
    "unterrichtet": "unterrichten",
    "unterrichtete": "unterrichten",
    "unterrichtetem": "unterrichtet",
    "unterrichteten": "unterrichten",
    "unterrichteter": "unterrichtet",
    "unterrichtetes": "unterrichtet",
    "unterrichtetest": "unterrichten",
    "unterrichtetet": "unterrichten",
    "unterrichtliche": "unterrichtlich",
    "unterrichtlichem": "unterrichtlich",
    "unterrichtlichen": "unterrichtlich",
    "unterrichtlicher": "unterrichtlich",
    "unterrichtliches": "unterrichtlich",
    "untersage": "untersagen",
    "untersagend": "untersagen",
    "untersagende": "untersagend",
    "untersagendem": "untersagend",
    "untersagenden": "untersagend",
    "untersagender": "untersagend",
    "untersagendes": "untersagend",
    "untersagest": "untersagen",
    "untersaget": "untersagen",
    "untersagst": "untersagen",
    "untersagt": "untersagen",
    "untersagte": "untersagen",
    "untersagtem": "untersagt",
    "untersagten": "untersagen",
    "untersagter": "untersagt",
    "untersagtes": "untersagt",
    "untersagtest": "untersagen",
    "untersagtet": "untersagen",
    "untersank": "untersinken",
    "untersanken": "untersinken",
    "untersankst": "untersinken",
    "untersankt": "untersinken",
    "unterscheidbare": "unterscheidbar",
    "unterscheidbarem": "unterscheidbar",
    "unterscheidbaren": "unterscheidbar",
    "unterscheidbarer": "unterscheidbar",
    "unterscheidbares": "unterscheidbar",
    "unterscheide": "unterscheiden",
    "unterscheidend": "unterscheiden",
    "unterscheidende": "unterscheidend",
    "unterscheidendem": "unterscheidend",
    "unterscheidenden": "unterscheidend",
    "unterscheidender": "unterscheidend",
    "unterscheidendes": "unterscheidend",
    "unterscheidest": "unterscheiden",
    "unterscheidet": "unterscheiden",
    "unterschiebe": "unterschieben",
    "unterschiebend": "unterschieben",
    "unterschiebende": "unterschiebend",
    "unterschiebendem": "unterschiebend",
    "unterschiebenden": "unterschiebend",
    "unterschiebender": "unterschiebend",
    "unterschiebendes": "unterschiebend",
    "unterschiebest": "unterschieben",
    "unterschiebet": "unterschieben",
    "unterschiebst": "unterschieben",
    "unterschiebt": "unterschieben",
    "unterschied": "unterscheiden",
    "unterschiedenem": "unterschieden",
    "unterschiedenen": "unterschieden",
    "unterschiedener": "unterschieden",
    "unterschiedenere": "unterschieden",
    "unterschiedenerem": "unterschieden",
    "unterschiedeneren": "unterschieden",
    "unterschiedenerer": "unterschieden",
    "unterschiedeneres": "unterschieden",
    "unterschiedenes": "unterschieden",
    "unterschiedenste": "unterschieden",
    "unterschiedenstem": "unterschieden",
    "unterschiedensten": "unterschieden",
    "unterschiedenster": "unterschieden",
    "unterschiedenstes": "unterschieden",
    "unterschiedest": "unterscheiden",
    "unterschiedet": "unterscheiden",
    "unterschiedliche": "unterschiedlich",
    "unterschiedlichem": "unterschiedlich",
    "unterschiedlichen": "unterschiedlich",
    "unterschiedlicher": "unterschiedlich",
    "unterschiedlichere": "unterschiedlich",
    "unterschiedlicherem": "unterschiedlich",
    "unterschiedlicheren": "unterschiedlich",
    "unterschiedlicherer": "unterschiedlich",
    "unterschiedlicheres": "unterschiedlich",
    "unterschiedliches": "unterschiedlich",
    "unterschiedlichste": "unterschiedlich",
    "unterschiedlichstem": "unterschiedlich",
    "unterschiedlichsten": "unterschiedlich",
    "unterschiedlichster": "unterschiedlich",
    "unterschiedlichstes": "unterschiedlich",
    "unterschlage": "unterschlagen",
    "unterschlagend": "unterschlagen",
    "unterschlagende": "unterschlagend",
    "unterschlagendem": "unterschlagend",
    "unterschlagenden": "unterschlagend",
    "unterschlagender": "unterschlagend",
    "unterschlagendes": "unterschlagend",
    "unterschlagene": "unterschlagen",
    "unterschlagenem": "unterschlagen",
    "unterschlagenen": "unterschlagen",
    "unterschlagener": "unterschlagen",
    "unterschlagenes": "unterschlagen",
    "unterschlagest": "unterschlagen",
    "unterschlaget": "unterschlagen",
    "unterschlagt": "unterschlagen",
    "unterschlug": "unterschlagen",
    "unterschlugen": "unterschlagen",
    "unterschlugst": "unterschlagen",
    "unterschlugt": "unterschlagen",
    "unterschlägst": "unterschlagen",
    "unterschlägt": "unterschlagen",
    "unterschlüge": "unterschlagen",
    "unterschlügen": "unterschlagen",
    "unterschlügest": "unterschlagen",
    "unterschlüget": "unterschlagen",
    "unterschlüpfe": "unterschlüpfen",
    "unterschlüpfend": "unterschlüpfen",
    "unterschlüpfende": "unterschlüpfend",
    "unterschlüpfendem": "unterschlüpfend",
    "unterschlüpfenden": "unterschlüpfend",
    "unterschlüpfender": "unterschlüpfend",
    "unterschlüpfendes": "unterschlüpfend",
    "unterschlüpfest": "unterschlüpfen",
    "unterschlüpfet": "unterschlüpfen",
    "unterschlüpfst": "unterschlüpfen",
    "unterschlüpft": "unterschlüpfen",
    "unterschlüpfte": "unterschlüpfen",
    "unterschlüpften": "unterschlüpfen",
    "unterschlüpftest": "unterschlüpfen",
    "unterschlüpftet": "unterschlüpfen",
    "unterschob": "unterschieben",
    "unterschoben": "unterschieben",
    "unterschobst": "unterschieben",
    "unterschobt": "unterschieben",
    "unterschreibe": "unterschreiben",
    "unterschreibend": "unterschreiben",
    "unterschreibende": "unterschreibend",
    "unterschreibendem": "unterschreibend",
    "unterschreibenden": "unterschreibend",
    "unterschreibender": "unterschreibend",
    "unterschreibendes": "unterschreibend",
    "unterschreibest": "unterschreiben",
    "unterschreibet": "unterschreiben",
    "unterschreibst": "unterschreiben",
    "unterschreibt": "unterschreiben",
    "unterschreite": "unterschreiten",
    "unterschreitend": "unterschreiten",
    "unterschreitende": "unterschreitend",
    "unterschreitendem": "unterschreitend",
    "unterschreitenden": "unterschreitend",
    "unterschreitender": "unterschreitend",
    "unterschreitendes": "unterschreitend",
    "unterschreitest": "unterschreiten",
    "unterschreitet": "unterschreiten",
    "unterschrieb": "unterschreiben",
    "unterschriebe": "unterschreiben",
    "unterschrieben": "unterschreiben",
    "unterschriebene": "unterschrieben",
    "unterschriebenem": "unterschrieben",
    "unterschriebenen": "unterschrieben",
    "unterschriebener": "unterschrieben",
    "unterschriebenes": "unterschrieben",
    "unterschriebest": "unterschreiben",
    "unterschriebet": "unterschreiben",
    "unterschriebst": "unterschreiben",
    "unterschriebt": "unterschreiben",
    "unterschritt": "unterschreiten",
    "unterschritte": "unterschreiten",
    "unterschritten": "unterschreiten",
    "unterschrittene": "unterschritten",
    "unterschrittenem": "unterschritten",
    "unterschrittenen": "unterschritten",
    "unterschrittener": "unterschritten",
    "unterschrittenes": "unterschritten",
    "unterschrittest": "unterschreiten",
    "unterschrittet": "unterschreiten",
    "unterschwellige": "unterschwellig",
    "unterschwelligem": "unterschwellig",
    "unterschwelligen": "unterschwellig",
    "unterschwelliger": "unterschwellig",
    "unterschwelliges": "unterschwellig",
    "unterschätze": "unterschätzen",
    "unterschätzend": "unterschätzen",
    "unterschätzende": "unterschätzend",
    "unterschätzendem": "unterschätzend",
    "unterschätzenden": "unterschätzend",
    "unterschätzender": "unterschätzend",
    "unterschätzendes": "unterschätzend",
    "unterschätzest": "unterschätzen",
    "unterschätzet": "unterschätzen",
    "unterschätzt": "unterschätzen",
    "unterschätzte": "unterschätzen",
    "unterschätztem": "unterschätzt",
    "unterschätzten": "unterschätzen",
    "unterschätzter": "unterschätzt",
    "unterschätztere": "unterschätzt",
    "unterschätzterem": "unterschätzt",
    "unterschätzteren": "unterschätzt",
    "unterschätzterer": "unterschätzt",
    "unterschätzteres": "unterschätzt",
    "unterschätztes": "unterschätzt",
    "unterschätztest": "unterschätzen",
    "unterschätzteste": "unterschätzt",
    "unterschätztestem": "unterschätzt",
    "unterschätztesten": "unterschätzt",
    "unterschätztester": "unterschätzt",
    "unterschätztestes": "unterschätzt",
    "unterschätztet": "unterschätzen",
    "unterschöbe": "unterschieben",
    "unterschöben": "unterschieben",
    "unterschöbest": "unterschieben",
    "unterschöbet": "unterschieben",
    "untersetze": "untersetzen",
    "untersetzend": "untersetzen",
    "untersetzende": "untersetzend",
    "untersetzendem": "untersetzend",
    "untersetzenden": "untersetzend",
    "untersetzender": "untersetzend",
    "untersetzendes": "untersetzend",
    "untersetzest": "untersetzen",
    "untersetzet": "untersetzen",
    "untersetzt": "untersetzen",
    "untersetzte": "untersetzen",
    "untersetzten": "untersetzen",
    "untersetztest": "untersetzen",
    "untersetztet": "untersetzen",
    "untersinke": "untersinken",
    "untersinkend": "untersinken",
    "untersinkende": "untersinkend",
    "untersinkendem": "untersinkend",
    "untersinkenden": "untersinkend",
    "untersinkender": "untersinkend",
    "untersinkendes": "untersinkend",
    "untersinkest": "untersinken",
    "untersinket": "untersinken",
    "untersinkst": "untersinken",
    "untersinkt": "untersinken",
    "unterspüle": "unterspülen",
    "unterspülend": "unterspülen",
    "unterspülende": "unterspülend",
    "unterspülendem": "unterspülend",
    "unterspülenden": "unterspülend",
    "unterspülender": "unterspülend",
    "unterspülendes": "unterspülend",
    "unterspülest": "unterspülen",
    "unterspület": "unterspülen",
    "unterspülst": "unterspülen",
    "unterspült": "unterspülen",
    "unterspülte": "unterspülen",
    "unterspültem": "unterspült",
    "unterspülten": "unterspülen",
    "unterspülter": "unterspült",
    "unterspültes": "unterspült",
    "unterspültest": "unterspülen",
    "unterspültet": "unterspülen",
    "unterstand": "unterstehen",
    "unterstanden": "unterstehen",
    "unterstandene": "unterstanden",
    "unterstandenem": "unterstanden",
    "unterstandenen": "unterstanden",
    "unterstandener": "unterstanden",
    "unterstandenes": "unterstanden",
    "unterstandest": "unterstehen",
    "unterstandet": "unterstehen",
    "unterste": "unter",
    "unterstehe": "unterstehen",
    "unterstehend": "unterstehen",
    "unterstehende": "unterstehend",
    "unterstehendem": "unterstehend",
    "unterstehenden": "unterstehend",
    "unterstehender": "unterstehend",
    "unterstehendes": "unterstehend",
    "unterstehest": "unterstehen",
    "unterstehet": "unterstehen",
    "unterstehst": "unterstehen",
    "untersteht": "unterstehen",
    "unterstelle": "unterstellen",
    "unterstellend": "unterstellen",
    "unterstellende": "unterstellend",
    "unterstellendem": "unterstellend",
    "unterstellenden": "unterstellend",
    "unterstellender": "unterstellend",
    "unterstellendere": "unterstellend",
    "unterstellenderem": "unterstellend",
    "unterstellenderen": "unterstellend",
    "unterstellenderer": "unterstellend",
    "unterstellenderes": "unterstellend",
    "unterstellendes": "unterstellend",
    "unterstellendste": "unterstellend",
    "unterstellendstem": "unterstellend",
    "unterstellendsten": "unterstellend",
    "unterstellendster": "unterstellend",
    "unterstellendstes": "unterstellend",
    "unterstellest": "unterstellen",
    "unterstellet": "unterstellen",
    "unterstellst": "unterstellen",
    "unterstellt": "unterstellen",
    "unterstellte": "unterstellen",
    "unterstelltem": "unterstellt",
    "unterstellten": "unterstellen",
    "unterstellter": "unterstellt",
    "unterstelltes": "unterstellt",
    "unterstelltest": "unterstellen",
    "unterstelltet": "unterstellen",
    "unterstem": "unter",
    "untersten": "unter",
    "unterster": "unter",
    "unterstes": "unter",
    "unterstreiche": "unterstreichen",
    "unterstreichend": "unterstreichen",
    "unterstreichende": "unterstreichend",
    "unterstreichendem": "unterstreichend",
    "unterstreichenden": "unterstreichend",
    "unterstreichender": "unterstreichend",
    "unterstreichendes": "unterstreichend",
    "unterstreichest": "unterstreichen",
    "unterstreichet": "unterstreichen",
    "unterstreichst": "unterstreichen",
    "unterstreicht": "unterstreichen",
    "unterstreue": "unterstreuen",
    "unterstreuend": "unterstreuen",
    "unterstreuende": "unterstreuend",
    "unterstreuendem": "unterstreuend",
    "unterstreuenden": "unterstreuend",
    "unterstreuender": "unterstreuend",
    "unterstreuendes": "unterstreuend",
    "unterstreuest": "unterstreuen",
    "unterstreuet": "unterstreuen",
    "unterstreust": "unterstreuen",
    "unterstreut": "unterstreuen",
    "unterstreute": "unterstreuen",
    "unterstreuten": "unterstreuen",
    "unterstreutest": "unterstreuen",
    "unterstreutet": "unterstreuen",
    "unterstrich": "unterstreichen",
    "unterstriche": "unterstreichen",
    "unterstrichen": "unterstreichen",
    "unterstrichene": "unterstrichen",
    "unterstrichenem": "unterstrichen",
    "unterstrichenen": "unterstrichen",
    "unterstrichener": "unterstrichen",
    "unterstrichenes": "unterstrichen",
    "unterstrichest": "unterstreichen",
    "unterstrichet": "unterstreichen",
    "unterstrichst": "unterstreichen",
    "unterstricht": "unterstreichen",
    "unterstünde": "unterstehen",
    "unterstünden": "unterstehen",
    "unterstündest": "unterstehen",
    "unterstündet": "unterstehen",
    "unterstütze": "unterstützen",
    "unterstützend": "unterstützen",
    "unterstützende": "unterstützend",
    "unterstützendem": "unterstützend",
    "unterstützenden": "unterstützend",
    "unterstützender": "unterstützend",
    "unterstützendere": "unterstützend",
    "unterstützenderem": "unterstützend",
    "unterstützenderen": "unterstützend",
    "unterstützenderer": "unterstützend",
    "unterstützenderes": "unterstützend",
    "unterstützendes": "unterstützend",
    "unterstützendste": "unterstützend",
    "unterstützendstem": "unterstützend",
    "unterstützendsten": "unterstützend",
    "unterstützendster": "unterstützend",
    "unterstützendstes": "unterstützend",
    "unterstützest": "unterstützen",
    "unterstützet": "unterstützen",
    "unterstützt": "unterstützen",
    "unterstützte": "unterstützen",
    "unterstütztem": "unterstützt",
    "unterstützten": "unterstützen",
    "unterstützter": "unterstützt",
    "unterstütztere": "unterstützt",
    "unterstützterem": "unterstützt",
    "unterstützteren": "unterstützt",
    "unterstützterer": "unterstützt",
    "unterstützteres": "unterstützt",
    "unterstütztes": "unterstützt",
    "unterstütztest": "unterstützen",
    "unterstützteste": "unterstützt",
    "unterstütztestem": "unterstützt",
    "unterstütztesten": "unterstützt",
    "unterstütztester": "unterstützt",
    "unterstütztestes": "unterstützt",
    "unterstütztet": "unterstützen",
    "untersuche": "untersuchen",
    "untersuchend": "untersuchen",
    "untersuchende": "untersuchend",
    "untersuchendem": "untersuchend",
    "untersuchenden": "untersuchend",
    "untersuchender": "untersuchend",
    "untersuchendes": "untersuchend",
    "untersuchest": "untersuchen",
    "untersuchet": "untersuchen",
    "untersuchst": "untersuchen",
    "untersucht": "untersuchen",
    "untersuchte": "untersuchen",
    "untersuchtem": "untersucht",
    "untersuchten": "untersuchen",
    "untersuchter": "untersucht",
    "untersuchtes": "untersucht",
    "untersuchtest": "untersuchen",
    "untersuchtet": "untersuchen",
    "untersänke": "untersinken",
    "untersänken": "untersinken",
    "untersänkest": "untersinken",
    "untersänket": "untersinken",
    "untertauche": "untertauchen",
    "untertauchend": "untertauchen",
    "untertauchende": "untertauchend",
    "untertauchendem": "untertauchend",
    "untertauchenden": "untertauchend",
    "untertauchender": "untertauchend",
    "untertauchendere": "untertauchend",
    "untertauchenderem": "untertauchend",
    "untertauchenderen": "untertauchend",
    "untertauchenderer": "untertauchend",
    "untertauchenderes": "untertauchend",
    "untertauchendes": "untertauchend",
    "untertauchendste": "untertauchend",
    "untertauchendstem": "untertauchend",
    "untertauchendsten": "untertauchend",
    "untertauchendster": "untertauchend",
    "untertauchendstes": "untertauchend",
    "untertauchest": "untertauchen",
    "untertauchet": "untertauchen",
    "untertauchst": "untertauchen",
    "untertaucht": "untertauchen",
    "untertauchte": "untertauchen",
    "untertauchten": "untertauchen",
    "untertauchtest": "untertauchen",
    "untertauchtet": "untertauchen",
    "unterteile": "unterteilen",
    "unterteilend": "unterteilen",
    "unterteilende": "unterteilend",
    "unterteilendem": "unterteilend",
    "unterteilenden": "unterteilend",
    "unterteilender": "unterteilend",
    "unterteilendes": "unterteilend",
    "unterteilest": "unterteilen",
    "unterteilet": "unterteilen",
    "unterteilst": "unterteilen",
    "unterteilt": "unterteilen",
    "unterteilte": "unterteilen",
    "unterteiltem": "unterteilt",
    "unterteilten": "unterteilen",
    "unterteilter": "unterteilt",
    "unterteiltes": "unterteilt",
    "unterteiltest": "unterteilen",
    "unterteiltet": "unterteilen",
    "untertrat": "untertreten",
    "untertraten": "untertreten",
    "untertratest": "untertreten",
    "untertratet": "untertreten",
    "untertreibe": "untertreiben",
    "untertreibend": "untertreiben",
    "untertreibende": "untertreibend",
    "untertreibendem": "untertreibend",
    "untertreibenden": "untertreibend",
    "untertreibender": "untertreibend",
    "untertreibendes": "untertreibend",
    "untertreibest": "untertreiben",
    "untertreibet": "untertreiben",
    "untertreibst": "untertreiben",
    "untertreibt": "untertreiben",
    "untertrete": "untertreten",
    "untertretend": "untertreten",
    "untertretende": "untertretend",
    "untertretendem": "untertretend",
    "untertretenden": "untertretend",
    "untertretender": "untertretend",
    "untertretendes": "untertretend",
    "untertretest": "untertreten",
    "untertretet": "untertreten",
    "untertrieb": "untertreiben",
    "untertriebe": "untertreiben",
    "untertrieben": "untertreiben",
    "untertriebene": "untertrieben",
    "untertriebenem": "untertrieben",
    "untertriebenen": "untertrieben",
    "untertriebener": "untertrieben",
    "untertriebenes": "untertrieben",
    "untertriebest": "untertreiben",
    "untertriebet": "untertreiben",
    "untertriebst": "untertreiben",
    "untertriebt": "untertreiben",
    "untertritt": "untertreten",
    "untertrittst": "untertreten",
    "unterträte": "untertreten",
    "unterträten": "untertreten",
    "unterträtest": "untertreten",
    "unterträtet": "untertreten",
    "untertunnele": "untertunneln",
    "untertunnelnd": "untertunneln",
    "untertunnelnde": "untertunnelnd",
    "untertunnelndem": "untertunnelnd",
    "untertunnelnden": "untertunnelnd",
    "untertunnelnder": "untertunnelnd",
    "untertunnelndes": "untertunnelnd",
    "untertunnelst": "untertunneln",
    "untertunnelt": "untertunneln",
    "untertunnelte": "untertunneln",
    "untertunneltem": "untertunnelt",
    "untertunnelten": "untertunneln",
    "untertunnelter": "untertunnelt",
    "untertunneltes": "untertunnelt",
    "untertunneltest": "untertunneln",
    "untertunneltet": "untertunneln",
    "untertunnle": "untertunneln",
    "untervermiete": "untervermieten",
    "untervermietend": "untervermieten",
    "untervermietende": "untervermietend",
    "untervermietendem": "untervermietend",
    "untervermietenden": "untervermietend",
    "untervermietender": "untervermietend",
    "untervermietendes": "untervermietend",
    "untervermietest": "untervermieten",
    "untervermietet": "untervermieten",
    "untervermietete": "untervermieten",
    "untervermietetem": "untervermietet",
    "untervermieteten": "untervermieten",
    "untervermieteter": "untervermietet",
    "untervermietetes": "untervermietet",
    "untervermietetest": "untervermieten",
    "untervermietetet": "untervermieten",
    "unterversichere": "unterversichern",
    "unterversichernd": "unterversichern",
    "unterversichernde": "unterversichernd",
    "unterversicherndem": "unterversichernd",
    "unterversichernden": "unterversichernd",
    "unterversichernder": "unterversichernd",
    "unterversicherndes": "unterversichernd",
    "unterversicherst": "unterversichern",
    "unterversichert": "unterversichern",
    "unterversicherte": "unterversichern",
    "unterversichertem": "unterversichert",
    "unterversicherten": "unterversichern",
    "unterversicherter": "unterversichert",
    "unterversichertes": "unterversichert",
    "unterversichertest": "unterversichern",
    "unterversichertet": "unterversichern",
    "unterwandere": "unterwandern",
    "unterwandernd": "unterwandern",
    "unterwandernde": "unterwandernd",
    "unterwanderndem": "unterwandernd",
    "unterwandernden": "unterwandernd",
    "unterwandernder": "unterwandernd",
    "unterwanderndes": "unterwandernd",
    "unterwanderst": "unterwandern",
    "unterwandert": "unterwandern",
    "unterwanderte": "unterwandern",
    "unterwandertem": "unterwandert",
    "unterwanderten": "unterwandern",
    "unterwanderter": "unterwandert",
    "unterwandertes": "unterwandert",
    "unterwandertest": "unterwandern",
    "unterwandertet": "unterwandern",
    "unterwarf": "unterwerfen",
    "unterwarfen": "unterwerfen",
    "unterwarfst": "unterwerfen",
    "unterwarft": "unterwerfen",
    "unterweise": "unterweisen",
    "unterweisend": "unterweisen",
    "unterweisende": "unterweisend",
    "unterweisendem": "unterweisend",
    "unterweisenden": "unterweisend",
    "unterweisender": "unterweisend",
    "unterweisendes": "unterweisend",
    "unterweisest": "unterweisen",
    "unterweiset": "unterweisen",
    "unterweist": "unterweisen",
    "unterwerfe": "unterwerfen",
    "unterwerfend": "unterwerfen",
    "unterwerfende": "unterwerfend",
    "unterwerfendem": "unterwerfend",
    "unterwerfenden": "unterwerfend",
    "unterwerfender": "unterwerfend",
    "unterwerfendes": "unterwerfend",
    "unterwerfest": "unterwerfen",
    "unterwerfet": "unterwerfen",
    "unterwerft": "unterwerfen",
    "unterwies": "unterweisen",
    "unterwiese": "unterweisen",
    "unterwiesen": "unterweisen",
    "unterwiesene": "unterwiesen",
    "unterwiesenem": "unterwiesen",
    "unterwiesenen": "unterwiesen",
    "unterwiesener": "unterwiesen",
    "unterwiesenes": "unterwiesen",
    "unterwiesest": "unterweisen",
    "unterwieset": "unterweisen",
    "unterwiest": "unterweisen",
    "unterwirf": "unterwerfen",
    "unterwirfst": "unterwerfen",
    "unterwirft": "unterwerfen",
    "unterworfen": "unterwerfen",
    "unterworfene": "unterworfen",
    "unterworfenem": "unterworfen",
    "unterworfenen": "unterworfen",
    "unterworfener": "unterworfen",
    "unterworfenes": "unterworfen",
    "unterwärfe": "unterwerfen",
    "unterwärfen": "unterwerfen",
    "unterwärfest": "unterwerfen",
    "unterwärfet": "unterwerfen",
    "unterwürfige": "unterwürfig",
    "unterwürfigem": "unterwürfig",
    "unterwürfigen": "unterwürfig",
    "unterwürfiger": "unterwürfig",
    "unterwürfigere": "unterwürfig",
    "unterwürfigerem": "unterwürfig",
    "unterwürfigeren": "unterwürfig",
    "unterwürfigerer": "unterwürfig",
    "unterwürfigeres": "unterwürfig",
    "unterwürfiges": "unterwürfig",
    "unterwürfigste": "unterwürfig",
    "unterwürfigstem": "unterwürfig",
    "unterwürfigsten": "unterwürfig",
    "unterwürfigster": "unterwürfig",
    "unterwürfigstes": "unterwürfig",
    "unterzeichne": "unterzeichnen",
    "unterzeichnend": "unterzeichnen",
    "unterzeichnende": "unterzeichnend",
    "unterzeichnendem": "unterzeichnend",
    "unterzeichnenden": "unterzeichnend",
    "unterzeichnender": "unterzeichnend",
    "unterzeichnendes": "unterzeichnend",
    "unterzeichnest": "unterzeichnen",
    "unterzeichnet": "unterzeichnen",
    "unterzeichnete": "unterzeichnen",
    "unterzeichnetem": "unterzeichnet",
    "unterzeichneten": "unterzeichnen",
    "unterzeichneter": "unterzeichnet",
    "unterzeichnetes": "unterzeichnet",
    "unterzeichnetest": "unterzeichnen",
    "unterzeichnetet": "unterzeichnen",
    "unterziehe": "unterziehen",
    "unterziehend": "unterziehen",
    "unterziehende": "unterziehend",
    "unterziehendem": "unterziehend",
    "unterziehenden": "unterziehend",
    "unterziehender": "unterziehend",
    "unterziehendes": "unterziehend",
    "unterziehest": "unterziehen",
    "unterziehet": "unterziehen",
    "unterziehst": "unterziehen",
    "unterzieht": "unterziehen",
    "unterzog": "unterziehen",
    "unterzogen": "unterziehen",
    "unterzogene": "unterzogen",
    "unterzogenem": "unterzogen",
    "unterzogenen": "unterzogen",
    "unterzogener": "unterzogen",
    "unterzogenes": "unterzogen",
    "unterzogst": "unterziehen",
    "unterzogt": "unterziehen",
    "unterzubringen": "unterbringen",
    "unterzufassen": "unterfassen",
    "unterzugehen": "untergehen",
    "unterzuhaken": "unterhaken",
    "unterzujubeln": "unterjubeln",
    "unterzukommen": "unterkommen",
    "unterzukriechen": "unterkriechen",
    "unterzukriegen": "unterkriegen",
    "unterzumengen": "untermengen",
    "unterzumischen": "untermischen",
    "unterzuordnen": "unterordnen",
    "unterzupflügen": "unterpflügen",
    "unterzuschieben": "unterschieben",
    "unterzuschlagen": "unterschlagen",
    "unterzuschlüpfen": "unterschlüpfen",
    "unterzusetzen": "untersetzen",
    "unterzusinken": "untersinken",
    "unterzustellen": "unterstellen",
    "unterzustreuen": "unterstreuen",
    "unterzutauchen": "untertauchen",
    "unterzutreten": "untertreten",
    "unterzuvermieten": "untervermieten",
    "unterzöge": "unterziehen",
    "unterzögen": "unterziehen",
    "unterzögest": "unterziehen",
    "unterzöget": "unterziehen",
    "untragbarem": "untragbar",
    "untragbaren": "untragbar",
    "untragbarer": "untragbar",
    "untragbarere": "untragbar",
    "untragbarerem": "untragbar",
    "untragbareren": "untragbar",
    "untragbarerer": "untragbar",
    "untragbareres": "untragbar",
    "untragbares": "untragbar",
    "untragbarste": "untragbar",
    "untragbarstem": "untragbar",
    "untragbarsten": "untragbar",
    "untragbarster": "untragbar",
    "untragbarstes": "untragbar",
    "untreue": "untreu",
    "untreuem": "untreu",
    "untreuen": "untreu",
    "untreuer": "untreu",
    "untreuere": "untreu",
    "untreuerem": "untreu",
    "untreueren": "untreu",
    "untreuerer": "untreu",
    "untreueres": "untreu",
    "untreues": "untreu",
    "untreuste": "untreu",
    "untreustem": "untreu",
    "untreusten": "untreu",
    "untreuster": "untreu",
    "untreustes": "untreu",
    "untätigem": "untätig",
    "untätigen": "untätig",
    "untätiger": "untätig",
    "untätiges": "untätig",
    "untüchtige": "untüchtig",
    "untüchtigem": "untüchtig",
    "untüchtigen": "untüchtig",
    "untüchtiger": "untüchtig",
    "untüchtigere": "untüchtig",
    "untüchtigerem": "untüchtig",
    "untüchtigeren": "untüchtig",
    "untüchtigerer": "untüchtig",
    "untüchtigeres": "untüchtig",
    "untüchtiges": "untüchtig",
    "untüchtigste": "untüchtig",
    "untüchtigstem": "untüchtig",
    "untüchtigsten": "untüchtig",
    "untüchtigster": "untüchtig",
    "untüchtigstes": "untüchtig",
    "unumstrittene": "unumstritten",
    "unumstrittenem": "unumstritten",
    "unumstrittenen": "unumstritten",
    "unumstrittener": "unumstritten",
    "unumstrittenere": "unumstritten",
    "unumstrittenerem": "unumstritten",
    "unumstritteneren": "unumstritten",
    "unumstrittenerer": "unumstritten",
    "unumstritteneres": "unumstritten",
    "unumstrittenes": "unumstritten",
    "unumstrittenste": "unumstritten",
    "unumstrittenstem": "unumstritten",
    "unumstrittensten": "unumstritten",
    "unumstrittenster": "unumstritten",
    "unumstrittenstes": "unumstritten",
    "ununterbrochene": "ununterbrochen",
    "ununterbrochenem": "ununterbrochen",
    "ununterbrochenen": "ununterbrochen",
    "ununterbrochener": "ununterbrochen",
    "ununterbrochenes": "ununterbrochen",
    "unverantwortliche": "unverantwortlich",
    "unverantwortlichem": "unverantwortlich",
    "unverantwortlichen": "unverantwortlich",
    "unverantwortlicher": "unverantwortlich",
    "unverantwortlichere": "unverantwortlich",
    "unverantwortlicherem": "unverantwortlich",
    "unverantwortlicheren": "unverantwortlich",
    "unverantwortlicherer": "unverantwortlich",
    "unverantwortlicheres": "unverantwortlich",
    "unverantwortliches": "unverantwortlich",
    "unverantwortlichste": "unverantwortlich",
    "unverantwortlichstem": "unverantwortlich",
    "unverantwortlichsten": "unverantwortlich",
    "unverantwortlichster": "unverantwortlich",
    "unverantwortlichstes": "unverantwortlich",
    "unverbindliche": "unverbindlich",
    "unverbindlichem": "unverbindlich",
    "unverbindlichen": "unverbindlich",
    "unverbindlicher": "unverbindlich",
    "unverbindlichere": "unverbindlich",
    "unverbindlicherem": "unverbindlich",
    "unverbindlicheren": "unverbindlich",
    "unverbindlicherer": "unverbindlich",
    "unverbindlicheres": "unverbindlich",
    "unverbindliches": "unverbindlich",
    "unverbindlichste": "unverbindlich",
    "unverbindlichstem": "unverbindlich",
    "unverbindlichsten": "unverbindlich",
    "unverbindlichster": "unverbindlich",
    "unverbindlichstes": "unverbindlich",
    "unverdauliche": "unverdaulich",
    "unverdaulichem": "unverdaulich",
    "unverdaulichen": "unverdaulich",
    "unverdaulicher": "unverdaulich",
    "unverdauliches": "unverdaulich",
    "unverdaute": "unverdaut",
    "unverdautem": "unverdaut",
    "unverdauten": "unverdaut",
    "unverdauter": "unverdaut",
    "unverdautes": "unverdaut",
    "unverdiente": "unverdient",
    "unverdientem": "unverdient",
    "unverdienten": "unverdient",
    "unverdienter": "unverdient",
    "unverdientere": "unverdient",
    "unverdienterem": "unverdient",
    "unverdienteren": "unverdient",
    "unverdienterer": "unverdient",
    "unverdienteres": "unverdient",
    "unverdientes": "unverdient",
    "unverdienteste": "unverdient",
    "unverdientestem": "unverdient",
    "unverdientesten": "unverdient",
    "unverdientester": "unverdient",
    "unverdientestes": "unverdient",
    "unverdorbene": "unverdorben",
    "unverdorbenem": "unverdorben",
    "unverdorbenen": "unverdorben",
    "unverdorbener": "unverdorben",
    "unverdorbenere": "unverdorben",
    "unverdorbenerem": "unverdorben",
    "unverdorbeneren": "unverdorben",
    "unverdorbenerer": "unverdorben",
    "unverdorbeneres": "unverdorben",
    "unverdorbenes": "unverdorben",
    "unverdorbenste": "unverdorben",
    "unverdorbenstem": "unverdorben",
    "unverdorbensten": "unverdorben",
    "unverdorbenster": "unverdorben",
    "unverdorbenstes": "unverdorben",
    "unverdächtige": "unverdächtig",
    "unverdächtigem": "unverdächtig",
    "unverdächtigen": "unverdächtig",
    "unverdächtiger": "unverdächtig",
    "unverdächtigere": "unverdächtig",
    "unverdächtigerem": "unverdächtig",
    "unverdächtigeren": "unverdächtig",
    "unverdächtigerer": "unverdächtig",
    "unverdächtigeres": "unverdächtig",
    "unverdächtiges": "unverdächtig",
    "unverdächtigste": "unverdächtig",
    "unverdächtigstem": "unverdächtig",
    "unverdächtigsten": "unverdächtig",
    "unverdächtigster": "unverdächtig",
    "unverdächtigstes": "unverdächtig",
    "unverdünnte": "unverdünnt",
    "unverdünntem": "unverdünnt",
    "unverdünnten": "unverdünnt",
    "unverdünnter": "unverdünnt",
    "unverdünntere": "unverdünnt",
    "unverdünnterem": "unverdünnt",
    "unverdünnteren": "unverdünnt",
    "unverdünnterer": "unverdünnt",
    "unverdünnteres": "unverdünnt",
    "unverdünntes": "unverdünnt",
    "unverdünnteste": "unverdünnt",
    "unverdünntestem": "unverdünnt",
    "unverdünntesten": "unverdünnt",
    "unverdünntester": "unverdünnt",
    "unverdünntestes": "unverdünnt",
    "unverfrorene": "unverfroren",
    "unverfrorenem": "unverfroren",
    "unverfrorenen": "unverfroren",
    "unverfrorener": "unverfroren",
    "unverfrorenere": "unverfroren",
    "unverfrorenerem": "unverfroren",
    "unverfroreneren": "unverfroren",
    "unverfrorenerer": "unverfroren",
    "unverfroreneres": "unverfroren",
    "unverfrorenes": "unverfroren",
    "unverfrorenste": "unverfroren",
    "unverfrorenstem": "unverfroren",
    "unverfrorensten": "unverfroren",
    "unverfrorenster": "unverfroren",
    "unverfrorenstes": "unverfroren",
    "unverfälschte": "unverfälscht",
    "unverfälschtem": "unverfälscht",
    "unverfälschten": "unverfälscht",
    "unverfälschter": "unverfälscht",
    "unverfälschtes": "unverfälscht",
    "unverfängliche": "unverfänglich",
    "unverfänglichem": "unverfänglich",
    "unverfänglichen": "unverfänglich",
    "unverfänglicher": "unverfänglich",
    "unverfängliches": "unverfänglich",
    "unvergessene": "unvergessen",
    "unvergessenem": "unvergessen",
    "unvergessenen": "unvergessen",
    "unvergessener": "unvergessen",
    "unvergessenes": "unvergessen",
    "unvergleichliche": "unvergleichlich",
    "unvergleichlichem": "unvergleichlich",
    "unvergleichlichen": "unvergleichlich",
    "unvergleichlicher": "unvergleichlich",
    "unvergleichlichere": "unvergleichlich",
    "unvergleichlicherem": "unvergleichlich",
    "unvergleichlicheren": "unvergleichlich",
    "unvergleichlicherer": "unvergleichlich",
    "unvergleichlicheres": "unvergleichlich",
    "unvergleichliches": "unvergleichlich",
    "unvergleichlichste": "unvergleichlich",
    "unvergleichlichstem": "unvergleichlich",
    "unvergleichlichsten": "unvergleichlich",
    "unvergleichlichster": "unvergleichlich",
    "unvergleichlichstes": "unvergleichlich",
    "unverheiratete": "unverheiratet",
    "unverheiratetem": "unverheiratet",
    "unverheirateten": "unverheiratet",
    "unverheirateter": "unverheiratet",
    "unverheiratetes": "unverheiratet",
    "unverhoffte": "unverhofft",
    "unverhofftem": "unverhofft",
    "unverhofften": "unverhofft",
    "unverhoffter": "unverhofft",
    "unverhofftes": "unverhofft",
    "unverhältnismäßige": "unverhältnismäßig",
    "unverhältnismäßigem": "unverhältnismäßig",
    "unverhältnismäßigen": "unverhältnismäßig",
    "unverhältnismäßiger": "unverhältnismäßig",
    "unverhältnismäßiges": "unverhältnismäßig",
    "unverhüllte": "unverhüllt",
    "unverhülltem": "unverhüllt",
    "unverhüllten": "unverhüllt",
    "unverhüllter": "unverhüllt",
    "unverhülltes": "unverhüllt",
    "unverkrampfte": "unverkrampft",
    "unverkrampftem": "unverkrampft",
    "unverkrampften": "unverkrampft",
    "unverkrampfter": "unverkrampft",
    "unverkrampftere": "unverkrampft",
    "unverkrampfterem": "unverkrampft",
    "unverkrampfteren": "unverkrampft",
    "unverkrampfterer": "unverkrampft",
    "unverkrampfteres": "unverkrampft",
    "unverkrampftes": "unverkrampft",
    "unverkrampfteste": "unverkrampft",
    "unverkrampftestem": "unverkrampft",
    "unverkrampftesten": "unverkrampft",
    "unverkrampftester": "unverkrampft",
    "unverkrampftestes": "unverkrampft",
    "unverletzte": "unverletzt",
    "unverletztem": "unverletzt",
    "unverletzten": "unverletzt",
    "unverletzter": "unverletzt",
    "unverletztere": "unverletzt",
    "unverletzterem": "unverletzt",
    "unverletzteren": "unverletzt",
    "unverletzterer": "unverletzt",
    "unverletzteres": "unverletzt",
    "unverletztes": "unverletzt",
    "unverletzteste": "unverletzt",
    "unverletztestem": "unverletzt",
    "unverletztesten": "unverletzt",
    "unverletztester": "unverletzt",
    "unverletztestes": "unverletzt",
    "unverläßliche": "unverläßlich",
    "unverläßlichem": "unverläßlich",
    "unverläßlichen": "unverläßlich",
    "unverläßlicher": "unverläßlich",
    "unverläßlichere": "unverläßlich",
    "unverläßlicherem": "unverläßlich",
    "unverläßlicheren": "unverläßlich",
    "unverläßlicherer": "unverläßlich",
    "unverläßlicheres": "unverläßlich",
    "unverläßliches": "unverläßlich",
    "unverläßlichste": "unverläßlich",
    "unverläßlichstem": "unverläßlich",
    "unverläßlichsten": "unverläßlich",
    "unverläßlichster": "unverläßlich",
    "unverläßlichstes": "unverläßlich",
    "unvermeidbare": "unvermeidbar",
    "unvermeidbarem": "unvermeidbar",
    "unvermeidbaren": "unvermeidbar",
    "unvermeidbarer": "unvermeidbar",
    "unvermeidbares": "unvermeidbar",
    "unvermeidliche": "unvermeidlich",
    "unvermeidlichem": "unvermeidlich",
    "unvermeidlichen": "unvermeidlich",
    "unvermeidlicher": "unvermeidlich",
    "unvermeidlichere": "unvermeidlich",
    "unvermeidlicherem": "unvermeidlich",
    "unvermeidlicheren": "unvermeidlich",
    "unvermeidlicherer": "unvermeidlich",
    "unvermeidlicheres": "unvermeidlich",
    "unvermeidliches": "unvermeidlich",
    "unvermeidlichste": "unvermeidlich",
    "unvermeidlichstem": "unvermeidlich",
    "unvermeidlichsten": "unvermeidlich",
    "unvermeidlichster": "unvermeidlich",
    "unvermeidlichstes": "unvermeidlich",
    "unverminderte": "unvermindert",
    "unvermindertem": "unvermindert",
    "unverminderten": "unvermindert",
    "unverminderter": "unvermindert",
    "unvermindertere": "unvermindert",
    "unverminderterem": "unvermindert",
    "unverminderteren": "unvermindert",
    "unverminderterer": "unvermindert",
    "unverminderteres": "unvermindert",
    "unvermindertes": "unvermindert",
    "unverminderteste": "unvermindert",
    "unvermindertestem": "unvermindert",
    "unvermindertesten": "unvermindert",
    "unvermindertester": "unvermindert",
    "unvermindertestes": "unvermindert",
    "unvermittelte": "unvermittelt",
    "unvermitteltem": "unvermittelt",
    "unvermittelten": "unvermittelt",
    "unvermittelter": "unvermittelt",
    "unvermitteltes": "unvermittelt",
    "unvermutetem": "unvermutet",
    "unvermuteten": "unvermutet",
    "unvermuteter": "unvermutet",
    "unvermutetes": "unvermutet",
    "unvermählte": "unvermählt",
    "unvermähltem": "unvermählt",
    "unvermählten": "unvermählt",
    "unvermählter": "unvermählt",
    "unvermähltes": "unvermählt",
    "unvernünftige": "unvernünftig",
    "unvernünftigem": "unvernünftig",
    "unvernünftigen": "unvernünftig",
    "unvernünftiger": "unvernünftig",
    "unvernünftigere": "unvernünftig",
    "unvernünftigerem": "unvernünftig",
    "unvernünftigeren": "unvernünftig",
    "unvernünftigerer": "unvernünftig",
    "unvernünftigeres": "unvernünftig",
    "unvernünftiges": "unvernünftig",
    "unvernünftigste": "unvernünftig",
    "unvernünftigstem": "unvernünftig",
    "unvernünftigsten": "unvernünftig",
    "unvernünftigster": "unvernünftig",
    "unvernünftigstes": "unvernünftig",
    "unverrichtete": "unverrichtet",
    "unverrichtetem": "unverrichtet",
    "unverrichteten": "unverrichtet",
    "unverrichteter": "unverrichtet",
    "unverrichtetes": "unverrichtet",
    "unverschämte": "unverschämt",
    "unverschämtem": "unverschämt",
    "unverschämten": "unverschämt",
    "unverschämter": "unverschämt",
    "unverschämtere": "unverschämt",
    "unverschämterem": "unverschämt",
    "unverschämteren": "unverschämt",
    "unverschämterer": "unverschämt",
    "unverschämteres": "unverschämt",
    "unverschämtes": "unverschämt",
    "unverschämteste": "unverschämt",
    "unverschämtestem": "unverschämt",
    "unverschämtesten": "unverschämt",
    "unverschämtester": "unverschämt",
    "unverschämtestes": "unverschämt",
    "unverstandenem": "unverstanden",
    "unverstandenen": "unverstanden",
    "unverstandener": "unverstanden",
    "unverstandenere": "unverstanden",
    "unverstandenerem": "unverstanden",
    "unverstandeneren": "unverstanden",
    "unverstandenerer": "unverstanden",
    "unverstandeneres": "unverstanden",
    "unverstandenes": "unverstanden",
    "unverstandenste": "unverstanden",
    "unverstandenstem": "unverstanden",
    "unverstandensten": "unverstanden",
    "unverstandenster": "unverstanden",
    "unverstandenstes": "unverstanden",
    "unversteuertem": "unversteuert",
    "unversteuerten": "unversteuert",
    "unversteuerter": "unversteuert",
    "unversteuertes": "unversteuert",
    "unverständlichem": "unverständlich",
    "unverständlichen": "unverständlich",
    "unverständlicher": "unverständlich",
    "unverständlichere": "unverständlich",
    "unverständlicherem": "unverständlich",
    "unverständlicheren": "unverständlich",
    "unverständlicherer": "unverständlich",
    "unverständlicheres": "unverständlich",
    "unverständliches": "unverständlich",
    "unverständlichste": "unverständlich",
    "unverständlichstem": "unverständlich",
    "unverständlichsten": "unverständlich",
    "unverständlichster": "unverständlich",
    "unverständlichstes": "unverständlich",
    "unversuchte": "unversucht",
    "unversuchtem": "unversucht",
    "unversuchten": "unversucht",
    "unversuchter": "unversucht",
    "unversuchtes": "unversucht",
    "unverträgliche": "unverträglich",
    "unverträglichem": "unverträglich",
    "unverträglichen": "unverträglich",
    "unverträglicher": "unverträglich",
    "unverträglichere": "unverträglich",
    "unverträglicherem": "unverträglich",
    "unverträglicheren": "unverträglich",
    "unverträglicherer": "unverträglich",
    "unverträglicheres": "unverträglich",
    "unverträgliches": "unverträglich",
    "unverträglichstem": "unverträglich",
    "unverträglichsten": "unverträglich",
    "unverträglichster": "unverträglich",
    "unverträglichstes": "unverträglich",
    "unverwechselbare": "unverwechselbar",
    "unverwechselbarem": "unverwechselbar",
    "unverwechselbaren": "unverwechselbar",
    "unverwechselbarer": "unverwechselbar",
    "unverwechselbarere": "unverwechselbar",
    "unverwechselbarerem": "unverwechselbar",
    "unverwechselbareren": "unverwechselbar",
    "unverwechselbarerer": "unverwechselbar",
    "unverwechselbareres": "unverwechselbar",
    "unverwechselbares": "unverwechselbar",
    "unverwechselbarste": "unverwechselbar",
    "unverwechselbarstem": "unverwechselbar",
    "unverwechselbarsten": "unverwechselbar",
    "unverwechselbarster": "unverwechselbar",
    "unverwechselbarstes": "unverwechselbar",
    "unverzichtbare": "unverzichtbar",
    "unverzichtbarem": "unverzichtbar",
    "unverzichtbaren": "unverzichtbar",
    "unverzichtbarer": "unverzichtbar",
    "unverzichtbarere": "unverzichtbar",
    "unverzichtbarerem": "unverzichtbar",
    "unverzichtbareren": "unverzichtbar",
    "unverzichtbarerer": "unverzichtbar",
    "unverzichtbareres": "unverzichtbar",
    "unverzichtbares": "unverzichtbar",
    "unverzichtbarste": "unverzichtbar",
    "unverzichtbarstem": "unverzichtbar",
    "unverzichtbarsten": "unverzichtbar",
    "unverzichtbarster": "unverzichtbar",
    "unverzichtbarstes": "unverzichtbar",
    "unverzinsliche": "unverzinslich",
    "unverzinslichem": "unverzinslich",
    "unverzinslichen": "unverzinslich",
    "unverzinslicher": "unverzinslich",
    "unverzinsliches": "unverzinslich",
    "unverzollte": "unverzollt",
    "unverzolltem": "unverzollt",
    "unverzollten": "unverzollt",
    "unverzollter": "unverzollt",
    "unverzolltes": "unverzollt",
    "unverzügliche": "unverzüglich",
    "unverzüglichem": "unverzüglich",
    "unverzüglichen": "unverzüglich",
    "unverzüglicher": "unverzüglich",
    "unverzüglichere": "unverzüglich",
    "unverzüglicherem": "unverzüglich",
    "unverzüglicheren": "unverzüglich",
    "unverzüglicherer": "unverzüglich",
    "unverzüglicheres": "unverzüglich",
    "unverzügliches": "unverzüglich",
    "unverzüglichste": "unverzüglich",
    "unverzüglichstem": "unverzüglich",
    "unverzüglichsten": "unverzüglich",
    "unverzüglichster": "unverzüglich",
    "unverzüglichstes": "unverzüglich",
    "unveränderte": "unverändert",
    "unverändertem": "unverändert",
    "unveränderten": "unverändert",
    "unveränderter": "unverändert",
    "unverändertes": "unverändert",
    "unveröffentlichte": "unveröffentlicht",
    "unveröffentlichtem": "unveröffentlicht",
    "unveröffentlichten": "unveröffentlicht",
    "unveröffentlichter": "unveröffentlicht",
    "unveröffentlichtes": "unveröffentlicht",
    "unvollkommene": "unvollkommen",
    "unvollkommenem": "unvollkommen",
    "unvollkommenen": "unvollkommen",
    "unvollkommener": "unvollkommen",
    "unvollkommenere": "unvollkommen",
    "unvollkommenerem": "unvollkommen",
    "unvollkommeneren": "unvollkommen",
    "unvollkommenerer": "unvollkommen",
    "unvollkommeneres": "unvollkommen",
    "unvollkommenes": "unvollkommen",
    "unvollkommenstem": "unvollkommen",
    "unvollkommensten": "unvollkommen",
    "unvollkommenster": "unvollkommen",
    "unvollkommenstes": "unvollkommen",
    "unvollständige": "unvollständig",
    "unvollständigem": "unvollständig",
    "unvollständigen": "unvollständig",
    "unvollständiger": "unvollständig",
    "unvollständigere": "unvollständig",
    "unvollständigerem": "unvollständig",
    "unvollständigeren": "unvollständig",
    "unvollständigerer": "unvollständig",
    "unvollständigeres": "unvollständig",
    "unvollständiges": "unvollständig",
    "unvollständigste": "unvollständig",
    "unvollständigstem": "unvollständig",
    "unvollständigsten": "unvollständig",
    "unvollständigster": "unvollständig",
    "unvollständigstes": "unvollständig",
    "unvorbereitete": "unvorbereitet",
    "unvorbereitetem": "unvorbereitet",
    "unvorbereiteten": "unvorbereitet",
    "unvorbereiteter": "unvorbereitet",
    "unvorbereitetes": "unvorbereitet",
    "unvoreingenommene": "unvoreingenommen",
    "unvoreingenommenem": "unvoreingenommen",
    "unvoreingenommenen": "unvoreingenommen",
    "unvoreingenommener": "unvoreingenommen",
    "unvoreingenommenes": "unvoreingenommen",
    "unvorhergesehene": "unvorhergesehen",
    "unvorhergesehenem": "unvorhergesehen",
    "unvorhergesehenen": "unvorhergesehen",
    "unvorhergesehener": "unvorhergesehen",
    "unvorhergesehenes": "unvorhergesehen",
    "unvorschriftsmäßige": "unvorschriftsmäßig",
    "unvorschriftsmäßigem": "unvorschriftsmäßig",
    "unvorschriftsmäßigen": "unvorschriftsmäßig",
    "unvorschriftsmäßiger": "unvorschriftsmäßig",
    "unvorschriftsmäßiges": "unvorschriftsmäßig",
    "unvorsichtige": "unvorsichtig",
    "unvorsichtigem": "unvorsichtig",
    "unvorsichtigen": "unvorsichtig",
    "unvorsichtiger": "unvorsichtig",
    "unvorsichtigere": "unvorsichtig",
    "unvorsichtigerem": "unvorsichtig",
    "unvorsichtigeren": "unvorsichtig",
    "unvorsichtigerer": "unvorsichtig",
    "unvorsichtigeres": "unvorsichtig",
    "unvorsichtiges": "unvorsichtig",
    "unvorsichtigste": "unvorsichtig",
    "unvorsichtigstem": "unvorsichtig",
    "unvorsichtigsten": "unvorsichtig",
    "unvorsichtigster": "unvorsichtig",
    "unvorsichtigstes": "unvorsichtig",
    "unvorstellbare": "unvorstellbar",
    "unvorstellbarem": "unvorstellbar",
    "unvorstellbaren": "unvorstellbar",
    "unvorstellbarer": "unvorstellbar",
    "unvorstellbarere": "unvorstellbar",
    "unvorstellbarerem": "unvorstellbar",
    "unvorstellbareren": "unvorstellbar",
    "unvorstellbarerer": "unvorstellbar",
    "unvorstellbareres": "unvorstellbar",
    "unvorstellbares": "unvorstellbar",
    "unvorstellbarste": "unvorstellbar",
    "unvorstellbarstem": "unvorstellbar",
    "unvorstellbarsten": "unvorstellbar",
    "unvorstellbarster": "unvorstellbar",
    "unvorstellbarstes": "unvorstellbar",
    "unvorteilhafte": "unvorteilhaft",
    "unvorteilhaftem": "unvorteilhaft",
    "unvorteilhaften": "unvorteilhaft",
    "unvorteilhafter": "unvorteilhaft",
    "unvorteilhaftere": "unvorteilhaft",
    "unvorteilhafterem": "unvorteilhaft",
    "unvorteilhafteren": "unvorteilhaft",
    "unvorteilhafterer": "unvorteilhaft",
    "unvorteilhafteres": "unvorteilhaft",
    "unvorteilhaftes": "unvorteilhaft",
    "unvorteilhafteste": "unvorteilhaft",
    "unvorteilhaftestem": "unvorteilhaft",
    "unvorteilhaftesten": "unvorteilhaft",
    "unvorteilhaftester": "unvorteilhaft",
    "unvorteilhaftestes": "unvorteilhaft",
    "unwahre": "unwahr",
    "unwahrem": "unwahr",
    "unwahren": "unwahr",
    "unwahrer": "unwahr",
    "unwahres": "unwahr",
    "unwahrscheinliche": "unwahrscheinlich",
    "unwahrscheinlichem": "unwahrscheinlich",
    "unwahrscheinlichen": "unwahrscheinlich",
    "unwahrscheinlicher": "unwahrscheinlich",
    "unwahrscheinlichere": "unwahrscheinlich",
    "unwahrscheinlicherem": "unwahrscheinlich",
    "unwahrscheinlicheren": "unwahrscheinlich",
    "unwahrscheinlicherer": "unwahrscheinlich",
    "unwahrscheinlicheres": "unwahrscheinlich",
    "unwahrscheinliches": "unwahrscheinlich",
    "unwahrscheinlichste": "unwahrscheinlich",
    "unwahrscheinlichstem": "unwahrscheinlich",
    "unwahrscheinlichsten": "unwahrscheinlich",
    "unwahrscheinlichster": "unwahrscheinlich",
    "unwahrscheinlichstes": "unwahrscheinlich",
    "unwegsame": "unwegsam",
    "unwegsamem": "unwegsam",
    "unwegsamen": "unwegsam",
    "unwegsamer": "unwegsam",
    "unwegsames": "unwegsam",
    "unweigerliche": "unweigerlich",
    "unweigerlichem": "unweigerlich",
    "unweigerlichen": "unweigerlich",
    "unweigerlicher": "unweigerlich",
    "unweigerlichere": "unweigerlich",
    "unweigerlicherem": "unweigerlich",
    "unweigerlicheren": "unweigerlich",
    "unweigerlicherer": "unweigerlich",
    "unweigerlicheres": "unweigerlich",
    "unweigerliches": "unweigerlich",
    "unweigerlichste": "unweigerlich",
    "unweigerlichstem": "unweigerlich",
    "unweigerlichsten": "unweigerlich",
    "unweigerlichster": "unweigerlich",
    "unweigerlichstes": "unweigerlich",
    "unwesentlichem": "unwesentlich",
    "unwesentlichen": "unwesentlich",
    "unwesentlicher": "unwesentlich",
    "unwesentliches": "unwesentlich",
    "unwichtigem": "unwichtig",
    "unwichtigen": "unwichtig",
    "unwichtiger": "unwichtig",
    "unwichtigere": "unwichtig",
    "unwichtigerem": "unwichtig",
    "unwichtigeren": "unwichtig",
    "unwichtigerer": "unwichtig",
    "unwichtigeres": "unwichtig",
    "unwichtiges": "unwichtig",
    "unwichtigste": "unwichtig",
    "unwichtigstem": "unwichtig",
    "unwichtigsten": "unwichtig",
    "unwichtigster": "unwichtig",
    "unwichtigstes": "unwichtig",
    "unwiderrufliche": "unwiderruflich",
    "unwiderruflichem": "unwiderruflich",
    "unwiderruflichen": "unwiderruflich",
    "unwiderruflicher": "unwiderruflich",
    "unwiderrufliches": "unwiderruflich",
    "unwilligem": "unwillig",
    "unwilligen": "unwillig",
    "unwilliger": "unwillig",
    "unwilliges": "unwillig",
    "unwillkommene": "unwillkommen",
    "unwillkommenem": "unwillkommen",
    "unwillkommenen": "unwillkommen",
    "unwillkommener": "unwillkommen",
    "unwillkommenere": "unwillkommen",
    "unwillkommenerem": "unwillkommen",
    "unwillkommeneren": "unwillkommen",
    "unwillkommenerer": "unwillkommen",
    "unwillkommeneres": "unwillkommen",
    "unwillkommenes": "unwillkommen",
    "unwillkommenste": "unwillkommen",
    "unwillkommenstem": "unwillkommen",
    "unwillkommensten": "unwillkommen",
    "unwillkommenster": "unwillkommen",
    "unwillkommenstes": "unwillkommen",
    "unwirkliche": "unwirklich",
    "unwirklichem": "unwirklich",
    "unwirklichen": "unwirklich",
    "unwirklicher": "unwirklich",
    "unwirklichere": "unwirklich",
    "unwirklicherem": "unwirklich",
    "unwirklicheren": "unwirklich",
    "unwirklicherer": "unwirklich",
    "unwirklicheres": "unwirklich",
    "unwirkliches": "unwirklich",
    "unwirklichste": "unwirklich",
    "unwirklichstem": "unwirklich",
    "unwirklichsten": "unwirklich",
    "unwirklichster": "unwirklich",
    "unwirklichstes": "unwirklich",
    "unwirksame": "unwirksam",
    "unwirksamem": "unwirksam",
    "unwirksamen": "unwirksam",
    "unwirksamer": "unwirksam",
    "unwirksamere": "unwirksam",
    "unwirksamerem": "unwirksam",
    "unwirksameren": "unwirksam",
    "unwirksamerer": "unwirksam",
    "unwirksameres": "unwirksam",
    "unwirksames": "unwirksam",
    "unwirksamste": "unwirksam",
    "unwirksamstem": "unwirksam",
    "unwirksamsten": "unwirksam",
    "unwirksamster": "unwirksam",
    "unwirksamstes": "unwirksam",
    "unwirsche": "unwirsch",
    "unwirschem": "unwirsch",
    "unwirschen": "unwirsch",
    "unwirscher": "unwirsch",
    "unwirschere": "unwirsch",
    "unwirscherem": "unwirsch",
    "unwirscheren": "unwirsch",
    "unwirscherer": "unwirsch",
    "unwirscheres": "unwirsch",
    "unwirsches": "unwirsch",
    "unwirschste": "unwirsch",
    "unwirschstem": "unwirsch",
    "unwirschsten": "unwirsch",
    "unwirschster": "unwirsch",
    "unwirschstes": "unwirsch",
    "unwirtschaftliche": "unwirtschaftlich",
    "unwirtschaftlichem": "unwirtschaftlich",
    "unwirtschaftlichen": "unwirtschaftlich",
    "unwirtschaftlicher": "unwirtschaftlich",
    "unwirtschaftlichere": "unwirtschaftlich",
    "unwirtschaftlicherem": "unwirtschaftlich",
    "unwirtschaftlicheren": "unwirtschaftlich",
    "unwirtschaftlicherer": "unwirtschaftlich",
    "unwirtschaftlicheres": "unwirtschaftlich",
    "unwirtschaftliches": "unwirtschaftlich",
    "unwirtschaftlichste": "unwirtschaftlich",
    "unwirtschaftlichstem": "unwirtschaftlich",
    "unwirtschaftlichsten": "unwirtschaftlich",
    "unwirtschaftlichster": "unwirtschaftlich",
    "unwirtschaftlichstes": "unwirtschaftlich",
    "unwissende": "unwissend",
    "unwissendem": "unwissend",
    "unwissenden": "unwissend",
    "unwissender": "unwissend",
    "unwissendes": "unwissend",
    "unwissenschaftlichem": "unwissenschaftlich",
    "unwissenschaftlichen": "unwissenschaftlich",
    "unwissenschaftlicher": "unwissenschaftlich",
    "unwissenschaftliches": "unwissenschaftlich",
    "unwissentliche": "unwissentlich",
    "unwissentlichem": "unwissentlich",
    "unwissentlichen": "unwissentlich",
    "unwissentlicher": "unwissentlich",
    "unwissentliches": "unwissentlich",
    "unwohle": "unwohl",
    "unwohlem": "unwohl",
    "unwohlen": "unwohl",
    "unwohler": "unwohl",
    "unwohlere": "unwohl",
    "unwohlerem": "unwohl",
    "unwohleren": "unwohl",
    "unwohlerer": "unwohl",
    "unwohleres": "unwohl",
    "unwohles": "unwohl",
    "unwohlstem": "unwohl",
    "unwohlsten": "unwohl",
    "unwohlster": "unwohl",
    "unwohlstes": "unwohl",
    "unwohnliche": "unwohnlich",
    "unwohnlichem": "unwohnlich",
    "unwohnlichen": "unwohnlich",
    "unwohnlicher": "unwohnlich",
    "unwohnliches": "unwohnlich",
    "unwürdige": "unwürdig",
    "unwürdigem": "unwürdig",
    "unwürdigen": "unwürdig",
    "unwürdiger": "unwürdig",
    "unwürdigere": "unwürdig",
    "unwürdigerem": "unwürdig",
    "unwürdigeren": "unwürdig",
    "unwürdigerer": "unwürdig",
    "unwürdigeres": "unwürdig",
    "unwürdiges": "unwürdig",
    "unwürdigste": "unwürdig",
    "unwürdigstem": "unwürdig",
    "unwürdigsten": "unwürdig",
    "unwürdigster": "unwürdig",
    "unwürdigstes": "unwürdig",
    "unzeitgemäße": "unzeitgemäß",
    "unzeitgemäßem": "unzeitgemäß",
    "unzeitgemäßen": "unzeitgemäß",
    "unzeitgemäßer": "unzeitgemäß",
    "unzeitgemäßere": "unzeitgemäß",
    "unzeitgemäßerem": "unzeitgemäß",
    "unzeitgemäßeren": "unzeitgemäß",
    "unzeitgemäßerer": "unzeitgemäß",
    "unzeitgemäßeres": "unzeitgemäß",
    "unzeitgemäßes": "unzeitgemäß",
    "unzeitgemäßeste": "unzeitgemäß",
    "unzeitgemäßestem": "unzeitgemäß",
    "unzeitgemäßesten": "unzeitgemäß",
    "unzeitgemäßester": "unzeitgemäß",
    "unzeitgemäßestes": "unzeitgemäß",
    "unzufriedenem": "unzufrieden",
    "unzufriedenen": "unzufrieden",
    "unzufriedener": "unzufrieden",
    "unzufriedenere": "unzufrieden",
    "unzufriedenerem": "unzufrieden",
    "unzufriedeneren": "unzufrieden",
    "unzufriedenerer": "unzufrieden",
    "unzufriedeneres": "unzufrieden",
    "unzufriedenes": "unzufrieden",
    "unzufriedenstem": "unzufrieden",
    "unzufriedensten": "unzufrieden",
    "unzufriedenster": "unzufrieden",
    "unzufriedenstes": "unzufrieden",
    "unzugängliche": "unzugänglich",
    "unzugänglichem": "unzugänglich",
    "unzugänglichen": "unzugänglich",
    "unzugänglicher": "unzugänglich",
    "unzugänglichere": "unzugänglich",
    "unzugänglicherem": "unzugänglich",
    "unzugänglicheren": "unzugänglich",
    "unzugänglicherer": "unzugänglich",
    "unzugänglicheres": "unzugänglich",
    "unzugängliches": "unzugänglich",
    "unzugänglichste": "unzugänglich",
    "unzugänglichstem": "unzugänglich",
    "unzugänglichsten": "unzugänglich",
    "unzugänglichster": "unzugänglich",
    "unzugänglichstes": "unzugänglich",
    "unzulängliche": "unzulänglich",
    "unzulänglichem": "unzulänglich",
    "unzulänglichen": "unzulänglich",
    "unzulänglicher": "unzulänglich",
    "unzulängliches": "unzulänglich",
    "unzulässigem": "unzulässig",
    "unzulässigen": "unzulässig",
    "unzulässiger": "unzulässig",
    "unzulässigere": "unzulässig",
    "unzulässigerem": "unzulässig",
    "unzulässigeren": "unzulässig",
    "unzulässigerer": "unzulässig",
    "unzulässigeres": "unzulässig",
    "unzulässiges": "unzulässig",
    "unzulässigste": "unzulässig",
    "unzulässigstem": "unzulässig",
    "unzulässigsten": "unzulässig",
    "unzulässigster": "unzulässig",
    "unzulässigstes": "unzulässig",
    "unzurechnungsfähige": "unzurechnungsfähig",
    "unzurechnungsfähigem": "unzurechnungsfähig",
    "unzurechnungsfähigen": "unzurechnungsfähig",
    "unzurechnungsfähiger": "unzurechnungsfähig",
    "unzurechnungsfähiges": "unzurechnungsfähig",
    "unzureichende": "unzureichend",
    "unzureichendem": "unzureichend",
    "unzureichenden": "unzureichend",
    "unzureichender": "unzureichend",
    "unzureichendere": "unzureichend",
    "unzureichenderem": "unzureichend",
    "unzureichenderen": "unzureichend",
    "unzureichenderer": "unzureichend",
    "unzureichenderes": "unzureichend",
    "unzureichendes": "unzureichend",
    "unzureichendste": "unzureichend",
    "unzureichendstem": "unzureichend",
    "unzureichendsten": "unzureichend",
    "unzureichendster": "unzureichend",
    "unzureichendstes": "unzureichend",
    "unzusammenhängende": "unzusammenhängend",
    "unzusammenhängendem": "unzusammenhängend",
    "unzusammenhängenden": "unzusammenhängend",
    "unzusammenhängender": "unzusammenhängend",
    "unzusammenhängendes": "unzusammenhängend",
    "unzustellbare": "unzustellbar",
    "unzustellbarem": "unzustellbar",
    "unzustellbaren": "unzustellbar",
    "unzustellbarer": "unzustellbar",
    "unzustellbares": "unzustellbar",
    "unzutreffende": "unzutreffend",
    "unzutreffendem": "unzutreffend",
    "unzutreffenden": "unzutreffend",
    "unzutreffender": "unzutreffend",
    "unzutreffendes": "unzutreffend",
    "unzuverlässige": "unzuverlässig",
    "unzuverlässigem": "unzuverlässig",
    "unzuverlässigen": "unzuverlässig",
    "unzuverlässiger": "unzuverlässig",
    "unzuverlässigere": "unzuverlässig",
    "unzuverlässigerem": "unzuverlässig",
    "unzuverlässigeren": "unzuverlässig",
    "unzuverlässigerer": "unzuverlässig",
    "unzuverlässigeres": "unzuverlässig",
    "unzuverlässiges": "unzuverlässig",
    "unzuverlässigstem": "unzuverlässig",
    "unzuverlässigsten": "unzuverlässig",
    "unzuverlässigster": "unzuverlässig",
    "unzuverlässigstes": "unzuverlässig",
    "unzweckmäßige": "unzweckmäßig",
    "unzweckmäßigem": "unzweckmäßig",
    "unzweckmäßigen": "unzweckmäßig",
    "unzweckmäßiger": "unzweckmäßig",
    "unzweckmäßigere": "unzweckmäßig",
    "unzweckmäßigerem": "unzweckmäßig",
    "unzweckmäßigeren": "unzweckmäßig",
    "unzweckmäßigerer": "unzweckmäßig",
    "unzweckmäßigeres": "unzweckmäßig",
    "unzweckmäßiges": "unzweckmäßig",
    "unzweckmäßigste": "unzweckmäßig",
    "unzweckmäßigstem": "unzweckmäßig",
    "unzweckmäßigsten": "unzweckmäßig",
    "unzweckmäßigster": "unzweckmäßig",
    "unzweckmäßigstes": "unzweckmäßig",
    "unzähligem": "unzählig",
    "unzähligen": "unzählig",
    "unzähliger": "unzählig",
    "unzähliges": "unzählig",
    "unästhetische": "unästhetisch",
    "unästhetischem": "unästhetisch",
    "unästhetischen": "unästhetisch",
    "unästhetischer": "unästhetisch",
    "unästhetisches": "unästhetisch",
    "unüberbrückbarem": "unüberbrückbar",
    "unüberbrückbaren": "unüberbrückbar",
    "unüberbrückbarer": "unüberbrückbar",
    "unüberbrückbares": "unüberbrückbar",
    "unüberlegte": "unüberlegt",
    "unüberlegtem": "unüberlegt",
    "unüberlegten": "unüberlegt",
    "unüberlegter": "unüberlegt",
    "unüberlegtes": "unüberlegt",
    "unübersehbare": "unübersehbar",
    "unübersehbarem": "unübersehbar",
    "unübersehbaren": "unübersehbar",
    "unübersehbarer": "unübersehbar",
    "unübersehbarere": "unübersehbar",
    "unübersehbarerem": "unübersehbar",
    "unübersehbareren": "unübersehbar",
    "unübersehbarerer": "unübersehbar",
    "unübersehbareres": "unübersehbar",
    "unübersehbares": "unübersehbar",
    "unübersehbarste": "unübersehbar",
    "unübersehbarstem": "unübersehbar",
    "unübersehbarsten": "unübersehbar",
    "unübersehbarster": "unübersehbar",
    "unübersehbarstes": "unübersehbar",
    "unübersichtliche": "unübersichtlich",
    "unübersichtlichem": "unübersichtlich",
    "unübersichtlichen": "unübersichtlich",
    "unübersichtlicher": "unübersichtlich",
    "unübersichtlichere": "unübersichtlich",
    "unübersichtlicherem": "unübersichtlich",
    "unübersichtlicheren": "unübersichtlich",
    "unübersichtlicherer": "unübersichtlich",
    "unübersichtlicheres": "unübersichtlich",
    "unübersichtliches": "unübersichtlich",
    "unübersichtlichste": "unübersichtlich",
    "unübersichtlichstem": "unübersichtlich",
    "unübersichtlichsten": "unübersichtlich",
    "unübersichtlichster": "unübersichtlich",
    "unübersichtlichstes": "unübersichtlich",
    "unüberwindliche": "unüberwindlich",
    "unüberwindlichem": "unüberwindlich",
    "unüberwindlichen": "unüberwindlich",
    "unüberwindlicher": "unüberwindlich",
    "unüberwindlichere": "unüberwindlich",
    "unüberwindlicherem": "unüberwindlich",
    "unüberwindlicheren": "unüberwindlich",
    "unüberwindlicherer": "unüberwindlich",
    "unüberwindlicheres": "unüberwindlich",
    "unüberwindliches": "unüberwindlich",
    "unüberwindlichste": "unüberwindlich",
    "unüberwindlichstem": "unüberwindlich",
    "unüberwindlichsten": "unüberwindlich",
    "unüberwindlichster": "unüberwindlich",
    "unüberwindlichstes": "unüberwindlich",
    "unübliche": "unüblich",
    "unüblichem": "unüblich",
    "unüblichen": "unüblich",
    "unüblicher": "unüblich",
    "unübliches": "unüblich",
    "uraltem": "uralt",
    "uralten": "uralt",
    "uralter": "uralt",
    "uraltes": "uralt",
    "urbanem": "urban",
    "urbanen": "urban",
    "urbaner": "urban",
    "urbanes": "urban",
    "urbanisiere": "urbanisieren",
    "urbanisierend": "urbanisieren",
    "urbanisierende": "urbanisierend",
    "urbanisierendem": "urbanisierend",
    "urbanisierenden": "urbanisierend",
    "urbanisierender": "urbanisierend",
    "urbanisierendes": "urbanisierend",
    "urbanisierest": "urbanisieren",
    "urbanisieret": "urbanisieren",
    "urbanisierst": "urbanisieren",
    "urbanisiert": "urbanisieren",
    "urbanisierte": "urbanisieren",
    "urbanisiertem": "urbanisiert",
    "urbanisierten": "urbanisieren",
    "urbanisierter": "urbanisiert",
    "urbanisiertes": "urbanisiert",
    "urbanisiertest": "urbanisieren",
    "urbanisiertet": "urbanisieren",
    "urdeutschem": "urdeutsch",
    "urdeutschen": "urdeutsch",
    "urdeutscher": "urdeutsch",
    "urdeutsches": "urdeutsch",
    "ureigene": "ureigen",
    "ureigenem": "ureigen",
    "ureigenen": "ureigen",
    "ureigener": "ureigen",
    "ureigenere": "ureigen",
    "ureigenerem": "ureigen",
    "ureigeneren": "ureigen",
    "ureigenerer": "ureigen",
    "ureigeneres": "ureigen",
    "ureigenes": "ureigen",
    "ureigenste": "ureigen",
    "ureigenstem": "ureigen",
    "ureigensten": "ureigen",
    "ureigenster": "ureigen",
    "ureigenstes": "ureigen",
    "urgemütlichem": "urgemütlich",
    "urgemütlichen": "urgemütlich",
    "urgemütlicher": "urgemütlich",
    "urgemütliches": "urgemütlich",
    "urgermanische": "urgermanisch",
    "urgermanischem": "urgermanisch",
    "urgermanischen": "urgermanisch",
    "urgermanischer": "urgermanisch",
    "urgermanisches": "urgermanisch",
    "urgeschichtlichem": "urgeschichtlich",
    "urgeschichtlichen": "urgeschichtlich",
    "urgeschichtlicher": "urgeschichtlich",
    "urgeschichtliches": "urgeschichtlich",
    "urigem": "urig",
    "urigen": "urig",
    "uriger": "urig",
    "urigere": "urig",
    "urigerem": "urig",
    "urigeren": "urig",
    "urigerer": "urig",
    "urigeres": "urig",
    "uriges": "urig",
    "urigste": "urig",
    "urigstem": "urig",
    "urigsten": "urig",
    "urigster": "urig",
    "urigstes": "urig",
    "urinale": "urinal",
    "urinalem": "urinal",
    "urinalen": "urinal",
    "urinaler": "urinal",
    "urinales": "urinal",
    "uriniere": "urinieren",
    "urinierend": "urinieren",
    "urinierende": "urinierend",
    "urinierendem": "urinierend",
    "urinierenden": "urinierend",
    "urinierender": "urinierend",
    "urinierendere": "urinierend",
    "urinierenderem": "urinierend",
    "urinierenderen": "urinierend",
    "urinierenderer": "urinierend",
    "urinierenderes": "urinierend",
    "urinierendes": "urinierend",
    "urinierendste": "urinierend",
    "urinierendstem": "urinierend",
    "urinierendsten": "urinierend",
    "urinierendster": "urinierend",
    "urinierendstes": "urinierend",
    "urinierest": "urinieren",
    "urinieret": "urinieren",
    "urinierst": "urinieren",
    "uriniert": "urinieren",
    "urinierte": "urinieren",
    "uriniertem": "uriniert",
    "urinierten": "urinieren",
    "urinierter": "uriniert",
    "uriniertes": "uriniert",
    "uriniertest": "urinieren",
    "uriniertet": "urinieren",
    "urinöse": "urinös",
    "urinösem": "urinös",
    "urinösen": "urinös",
    "urinöser": "urinös",
    "urinöses": "urinös",
    "urkomischem": "urkomisch",
    "urkomischen": "urkomisch",
    "urkomischer": "urkomisch",
    "urkomisches": "urkomisch",
    "urkundlichem": "urkundlich",
    "urkundlichen": "urkundlich",
    "urkundlicher": "urkundlich",
    "urkundliches": "urkundlich",
    "urlaubsreifem": "urlaubsreif",
    "urlaubsreifen": "urlaubsreif",
    "urlaubsreifer": "urlaubsreif",
    "urlaubsreifere": "urlaubsreif",
    "urlaubsreiferem": "urlaubsreif",
    "urlaubsreiferen": "urlaubsreif",
    "urlaubsreiferer": "urlaubsreif",
    "urlaubsreiferes": "urlaubsreif",
    "urlaubsreifes": "urlaubsreif",
    "urlaubsreifste": "urlaubsreif",
    "urlaubsreifstem": "urlaubsreif",
    "urlaubsreifsten": "urlaubsreif",
    "urlaubsreifster": "urlaubsreif",
    "urlaubsreifstes": "urlaubsreif",
    "urplötzlichem": "urplötzlich",
    "urplötzlichen": "urplötzlich",
    "urplötzlicher": "urplötzlich",
    "urplötzliches": "urplötzlich",
    "ursprünglichem": "ursprünglich",
    "ursprünglichen": "ursprünglich",
    "ursprünglicher": "ursprünglich",
    "ursprüngliches": "ursprünglich",
    "ursächlichem": "ursächlich",
    "ursächlichen": "ursächlich",
    "ursächlicher": "ursächlich",
    "ursächliches": "ursächlich",
    "urteilend": "urteilen",
    "urteilende": "urteilend",
    "urteilendem": "urteilend",
    "urteilenden": "urteilend",
    "urteilender": "urteilend",
    "urteilendes": "urteilend",
    "urteilest": "urteilen",
    "urteilet": "urteilen",
    "urteilsfähigem": "urteilsfähig",
    "urteilsfähigen": "urteilsfähig",
    "urteilsfähiger": "urteilsfähig",
    "urteilsfähiges": "urteilsfähig",
    "urteilst": "urteilen",
    "urteilt": "urteilen",
    "urteilte": "urteilen",
    "urteilten": "urteilen",
    "urteiltest": "urteilen",
    "urteiltet": "urteilen",
    "utilisiere": "utilisieren",
    "utilisierend": "utilisieren",
    "utilisierende": "utilisierend",
    "utilisierendem": "utilisierend",
    "utilisierenden": "utilisierend",
    "utilisierender": "utilisierend",
    "utilisierendes": "utilisierend",
    "utilisierest": "utilisieren",
    "utilisieret": "utilisieren",
    "utilisierst": "utilisieren",
    "utilisiert": "utilisieren",
    "utilisierte": "utilisieren",
    "utilisiertem": "utilisiert",
    "utilisierten": "utilisieren",
    "utilisierter": "utilisiert",
    "utilisiertes": "utilisiert",
    "utilisiertest": "utilisieren",
    "utilisiertet": "utilisieren",
    "utopischem": "utopisch",
    "utopischen": "utopisch",
    "utopischer": "utopisch",
    "utopischere": "utopisch",
    "utopischerem": "utopisch",
    "utopischeren": "utopisch",
    "utopischerer": "utopisch",
    "utopischeres": "utopisch",
    "utopisches": "utopisch",
    "utopischste": "utopisch",
    "utopischstem": "utopisch",
    "utopischsten": "utopisch",
    "utopischster": "utopisch",
    "utopischstes": "utopisch",
    "variabelstem": "variabel",
    "variabelsten": "variabel",
    "variabelster": "variabel",
    "variabelstes": "variabel",
    "variable": "variabel",
    "variablem": "variabel",
    "variablen": "variabel",
    "variabler": "variabel",
    "variablere": "variabel",
    "variablerem": "variabel",
    "variableren": "variabel",
    "variablerer": "variabel",
    "variableres": "variabel",
    "variables": "variabel",
    "variiere": "variieren",
    "variierend": "variieren",
    "variierende": "variierend",
    "variierendem": "variierend",
    "variierenden": "variierend",
    "variierender": "variierend",
    "variierendes": "variierend",
    "variierest": "variieren",
    "variieret": "variieren",
    "variierst": "variieren",
    "variiert": "variieren",
    "variierte": "variieren",
    "variiertem": "variiert",
    "variierten": "variieren",
    "variierter": "variiert",
    "variiertes": "variiert",
    "variiertest": "variieren",
    "variiertet": "variieren",
    "vaterlose": "vaterlos",
    "vaterlosem": "vaterlos",
    "vaterlosen": "vaterlos",
    "vaterloser": "vaterlos",
    "vaterloses": "vaterlos",
    "vaterländischem": "vaterländisch",
    "vaterländischen": "vaterländisch",
    "vaterländischer": "vaterländisch",
    "vaterländisches": "vaterländisch",
    "vegetationsarmem": "vegetationsarm",
    "vegetationsarmen": "vegetationsarm",
    "vegetationsarmer": "vegetationsarm",
    "vegetationsarmes": "vegetationsarm",
    "vegetationsärmer": "vegetationsarm",
    "vegetationsärmere": "vegetationsarm",
    "vegetationsärmerem": "vegetationsarm",
    "vegetationsärmeren": "vegetationsarm",
    "vegetationsärmerer": "vegetationsarm",
    "vegetationsärmeres": "vegetationsarm",
    "vegetationsärmsten": "vegetationsarm",
    "vehemente": "vehement",
    "vehementem": "vehement",
    "vehementen": "vehement",
    "vehementer": "vehement",
    "vehementere": "vehement",
    "vehementerem": "vehement",
    "vehementeren": "vehement",
    "vehementerer": "vehement",
    "vehementeres": "vehement",
    "vehementes": "vehement",
    "vehementeste": "vehement",
    "vehementestem": "vehement",
    "vehementesten": "vehement",
    "vehementester": "vehement",
    "vehementestes": "vehement",
    "verabrede": "verabreden",
    "verabredend": "verabreden",
    "verabredende": "verabredend",
    "verabredendem": "verabredend",
    "verabredenden": "verabredend",
    "verabredender": "verabredend",
    "verabredendes": "verabredend",
    "verabredest": "verabreden",
    "verabredet": "verabreden",
    "verabredete": "verabreden",
    "verabredetem": "verabredet",
    "verabredeten": "verabreden",
    "verabredeter": "verabredet",
    "verabredetes": "verabredet",
    "verabredetest": "verabreden",
    "verabredetet": "verabreden",
    "verabreiche": "verabreichen",
    "verabreichend": "verabreichen",
    "verabreichende": "verabreichend",
    "verabreichendem": "verabreichend",
    "verabreichenden": "verabreichend",
    "verabreichender": "verabreichend",
    "verabreichendes": "verabreichend",
    "verabreichest": "verabreichen",
    "verabreichet": "verabreichen",
    "verabreichst": "verabreichen",
    "verabreicht": "verabreichen",
    "verabreichte": "verabreichen",
    "verabreichtem": "verabreicht",
    "verabreichten": "verabreichen",
    "verabreichter": "verabreicht",
    "verabreichtes": "verabreicht",
    "verabreichtest": "verabreichen",
    "verabreichtet": "verabreichen",
    "verabscheue": "verabscheuen",
    "verabscheuend": "verabscheuen",
    "verabscheuende": "verabscheuend",
    "verabscheuendem": "verabscheuend",
    "verabscheuenden": "verabscheuend",
    "verabscheuender": "verabscheuend",
    "verabscheuendere": "verabscheuend",
    "verabscheuenderem": "verabscheuend",
    "verabscheuenderen": "verabscheuend",
    "verabscheuenderer": "verabscheuend",
    "verabscheuenderes": "verabscheuend",
    "verabscheuendes": "verabscheuend",
    "verabscheuendste": "verabscheuend",
    "verabscheuendstem": "verabscheuend",
    "verabscheuendsten": "verabscheuend",
    "verabscheuendster": "verabscheuend",
    "verabscheuendstes": "verabscheuend",
    "verabscheuenswertem": "verabscheuenswert",
    "verabscheuenswerten": "verabscheuenswert",
    "verabscheuenswerter": "verabscheuenswert",
    "verabscheuenswertere": "verabscheuenswert",
    "verabscheuenswerterem": "verabscheuenswert",
    "verabscheuenswerteren": "verabscheuenswert",
    "verabscheuenswerterer": "verabscheuenswert",
    "verabscheuenswerteres": "verabscheuenswert",
    "verabscheuenswertes": "verabscheuenswert",
    "verabscheuenswerteste": "verabscheuenswert",
    "verabscheuenswertestem": "verabscheuenswert",
    "verabscheuenswertesten": "verabscheuenswert",
    "verabscheuenswertester": "verabscheuenswert",
    "verabscheuenswertestes": "verabscheuenswert",
    "verabscheuest": "verabscheuen",
    "verabscheuet": "verabscheuen",
    "verabscheust": "verabscheuen",
    "verabscheut": "verabscheuen",
    "verabscheute": "verabscheuen",
    "verabscheutem": "verabscheut",
    "verabscheuten": "verabscheuen",
    "verabscheuter": "verabscheut",
    "verabscheutere": "verabscheut",
    "verabscheuterem": "verabscheut",
    "verabscheuteren": "verabscheut",
    "verabscheuterer": "verabscheut",
    "verabscheuteres": "verabscheut",
    "verabscheutes": "verabscheut",
    "verabscheutest": "verabscheuen",
    "verabscheuteste": "verabscheut",
    "verabscheutestem": "verabscheut",
    "verabscheutesten": "verabscheut",
    "verabscheutester": "verabscheut",
    "verabscheutestes": "verabscheut",
    "verabscheutet": "verabscheuen",
    "verabschiede": "verabschieden",
    "verabschiedend": "verabschieden",
    "verabschiedende": "verabschiedend",
    "verabschiedendem": "verabschiedend",
    "verabschiedenden": "verabschiedend",
    "verabschiedender": "verabschiedend",
    "verabschiedendes": "verabschiedend",
    "verabschiedest": "verabschieden",
    "verabschiedet": "verabschieden",
    "verabschiedete": "verabschieden",
    "verabschiedetem": "verabschiedet",
    "verabschiedeten": "verabschieden",
    "verabschiedeter": "verabschiedet",
    "verabschiedetes": "verabschiedet",
    "verabschiedetest": "verabschieden",
    "verabschiedetet": "verabschieden",
    "verabsolutiere": "verabsolutieren",
    "verabsolutierend": "verabsolutieren",
    "verabsolutierende": "verabsolutierend",
    "verabsolutierendem": "verabsolutierend",
    "verabsolutierenden": "verabsolutierend",
    "verabsolutierender": "verabsolutierend",
    "verabsolutierendes": "verabsolutierend",
    "verabsolutierest": "verabsolutieren",
    "verabsolutieret": "verabsolutieren",
    "verabsolutierst": "verabsolutieren",
    "verabsolutiert": "verabsolutieren",
    "verabsolutierte": "verabsolutieren",
    "verabsolutiertem": "verabsolutiert",
    "verabsolutierten": "verabsolutieren",
    "verabsolutierter": "verabsolutiert",
    "verabsolutiertes": "verabsolutiert",
    "verabsolutiertest": "verabsolutieren",
    "verabsolutiertet": "verabsolutieren",
    "verachte": "verachten",
    "verachtend": "verachten",
    "verachtende": "verachtend",
    "verachtendem": "verachtend",
    "verachtenden": "verachtend",
    "verachtender": "verachtend",
    "verachtendere": "verachtend",
    "verachtenderem": "verachtend",
    "verachtenderen": "verachtend",
    "verachtenderer": "verachtend",
    "verachtenderes": "verachtend",
    "verachtendes": "verachtend",
    "verachtendste": "verachtend",
    "verachtendstem": "verachtend",
    "verachtendsten": "verachtend",
    "verachtendster": "verachtend",
    "verachtendstes": "verachtend",
    "verachtenswertem": "verachtenswert",
    "verachtenswerten": "verachtenswert",
    "verachtenswerter": "verachtenswert",
    "verachtenswertere": "verachtenswert",
    "verachtenswerterem": "verachtenswert",
    "verachtenswerteren": "verachtenswert",
    "verachtenswerterer": "verachtenswert",
    "verachtenswerteres": "verachtenswert",
    "verachtenswertes": "verachtenswert",
    "verachtenswerteste": "verachtenswert",
    "verachtenswertestem": "verachtenswert",
    "verachtenswertesten": "verachtenswert",
    "verachtenswertester": "verachtenswert",
    "verachtenswertestes": "verachtenswert",
    "verachtest": "verachten",
    "verachtet": "verachten",
    "verachtete": "verachten",
    "verachtetem": "verachtet",
    "verachteten": "verachten",
    "verachteter": "verachtet",
    "verachtetere": "verachtet",
    "verachteterem": "verachtet",
    "verachteteren": "verachtet",
    "verachteterer": "verachtet",
    "verachteteres": "verachtet",
    "verachtetes": "verachtet",
    "verachtetest": "verachten",
    "verachteteste": "verachtet",
    "verachtetestem": "verachtet",
    "verachtetesten": "verachtet",
    "verachtetester": "verachtet",
    "verachtetestes": "verachtet",
    "verachtetet": "verachten",
    "veralbere": "veralbern",
    "veralbernd": "veralbern",
    "veralbernde": "veralbernd",
    "veralberndem": "veralbernd",
    "veralbernden": "veralbernd",
    "veralbernder": "veralbernd",
    "veralberndere": "veralbernd",
    "veralbernderem": "veralbernd",
    "veralbernderen": "veralbernd",
    "veralbernderer": "veralbernd",
    "veralbernderes": "veralbernd",
    "veralberndes": "veralbernd",
    "veralberndste": "veralbernd",
    "veralberndstem": "veralbernd",
    "veralberndsten": "veralbernd",
    "veralberndster": "veralbernd",
    "veralberndstes": "veralbernd",
    "veralberst": "veralbern",
    "veralbert": "veralbern",
    "veralberte": "veralbern",
    "veralbertem": "veralbert",
    "veralberten": "veralbern",
    "veralberter": "veralbert",
    "veralbertere": "veralbert",
    "veralberterem": "veralbert",
    "veralberteren": "veralbert",
    "veralberterer": "veralbert",
    "veralberteres": "veralbert",
    "veralbertes": "veralbert",
    "veralbertest": "veralbern",
    "veralberteste": "veralbert",
    "veralbertestem": "veralbert",
    "veralbertesten": "veralbert",
    "veralbertester": "veralbert",
    "veralbertestes": "veralbert",
    "veralbertet": "veralbern",
    "verallgemeinere": "verallgemeinern",
    "verallgemeinernd": "verallgemeinern",
    "verallgemeinernde": "verallgemeinernd",
    "verallgemeinerndem": "verallgemeinernd",
    "verallgemeinernden": "verallgemeinernd",
    "verallgemeinernder": "verallgemeinernd",
    "verallgemeinerndere": "verallgemeinernd",
    "verallgemeinernderem": "verallgemeinernd",
    "verallgemeinernderen": "verallgemeinernd",
    "verallgemeinernderer": "verallgemeinernd",
    "verallgemeinernderes": "verallgemeinernd",
    "verallgemeinerndes": "verallgemeinernd",
    "verallgemeinerndste": "verallgemeinernd",
    "verallgemeinerndstem": "verallgemeinernd",
    "verallgemeinerndsten": "verallgemeinernd",
    "verallgemeinerndster": "verallgemeinernd",
    "verallgemeinerndstes": "verallgemeinernd",
    "verallgemeinerst": "verallgemeinern",
    "verallgemeinert": "verallgemeinern",
    "verallgemeinerte": "verallgemeinern",
    "verallgemeinertem": "verallgemeinert",
    "verallgemeinerten": "verallgemeinern",
    "verallgemeinerter": "verallgemeinert",
    "verallgemeinertere": "verallgemeinert",
    "verallgemeinerterem": "verallgemeinert",
    "verallgemeinerteren": "verallgemeinert",
    "verallgemeinerterer": "verallgemeinert",
    "verallgemeinerteres": "verallgemeinert",
    "verallgemeinertes": "verallgemeinert",
    "verallgemeinertest": "verallgemeinern",
    "verallgemeinerteste": "verallgemeinert",
    "verallgemeinertestem": "verallgemeinert",
    "verallgemeinertesten": "verallgemeinert",
    "verallgemeinertester": "verallgemeinert",
    "verallgemeinertestes": "verallgemeinert",
    "verallgemeinertet": "verallgemeinern",
    "veralte": "veralten",
    "veraltend": "veralten",
    "veraltende": "veraltend",
    "veraltendem": "veraltend",
    "veraltenden": "veraltend",
    "veraltender": "veraltend",
    "veraltendere": "veraltend",
    "veraltenderem": "veraltend",
    "veraltenderen": "veraltend",
    "veraltenderer": "veraltend",
    "veraltenderes": "veraltend",
    "veraltendes": "veraltend",
    "veraltendste": "veraltend",
    "veraltendstem": "veraltend",
    "veraltendsten": "veraltend",
    "veraltendster": "veraltend",
    "veraltendstes": "veraltend",
    "veraltere": "veraltern",
    "veralternd": "veraltern",
    "veralternde": "veralternd",
    "veralterndem": "veralternd",
    "veralternden": "veralternd",
    "veralternder": "veralternd",
    "veralterndere": "veralternd",
    "veralternderem": "veralternd",
    "veralternderen": "veralternd",
    "veralternderer": "veralternd",
    "veralternderes": "veralternd",
    "veralterndes": "veralternd",
    "veralterndste": "veralternd",
    "veralterndstem": "veralternd",
    "veralterndsten": "veralternd",
    "veralterndster": "veralternd",
    "veralterndstes": "veralternd",
    "veralterst": "veraltern",
    "veraltert": "veraltern",
    "veralterte": "veraltern",
    "veraltertem": "veraltert",
    "veralterten": "veraltern",
    "veralterter": "veraltert",
    "veraltertere": "veraltert",
    "veralterterem": "veraltert",
    "veralterteren": "veraltert",
    "veralterterer": "veraltert",
    "veralterteres": "veraltert",
    "veraltertes": "veraltert",
    "veraltertest": "veraltern",
    "veralterteste": "veraltert",
    "veraltertestem": "veraltert",
    "veraltertesten": "veraltert",
    "veraltertester": "veraltert",
    "veraltertestes": "veraltert",
    "veraltertet": "veraltern",
    "veraltest": "veralten",
    "veraltet": "veralten",
    "veraltete": "veralten",
    "veraltetem": "veraltet",
    "veralteten": "veralten",
    "veralteter": "veraltet",
    "veraltetes": "veraltet",
    "veraltetest": "veralten",
    "veraltetet": "veralten",
    "verankere": "verankern",
    "verankernd": "verankern",
    "verankernde": "verankernd",
    "verankerndem": "verankernd",
    "verankernden": "verankernd",
    "verankernder": "verankernd",
    "verankerndere": "verankernd",
    "verankernderem": "verankernd",
    "verankernderen": "verankernd",
    "verankernderer": "verankernd",
    "verankernderes": "verankernd",
    "verankerndes": "verankernd",
    "verankerndste": "verankernd",
    "verankerndstem": "verankernd",
    "verankerndsten": "verankernd",
    "verankerndster": "verankernd",
    "verankerndstes": "verankernd",
    "verankerst": "verankern",
    "verankert": "verankern",
    "verankerte": "verankern",
    "verankertem": "verankert",
    "verankerten": "verankern",
    "verankerter": "verankert",
    "verankertere": "verankert",
    "verankerterem": "verankert",
    "verankerteren": "verankert",
    "verankerterer": "verankert",
    "verankerteres": "verankert",
    "verankertes": "verankert",
    "verankertest": "verankern",
    "verankerteste": "verankert",
    "verankertestem": "verankert",
    "verankertesten": "verankert",
    "verankertester": "verankert",
    "verankertestes": "verankert",
    "verankertet": "verankern",
    "veranlage": "veranlagen",
    "veranlagend": "veranlagen",
    "veranlagende": "veranlagend",
    "veranlagendem": "veranlagend",
    "veranlagenden": "veranlagend",
    "veranlagender": "veranlagend",
    "veranlagendes": "veranlagend",
    "veranlagest": "veranlagen",
    "veranlaget": "veranlagen",
    "veranlagst": "veranlagen",
    "veranlagt": "veranlagen",
    "veranlagte": "veranlagen",
    "veranlagtem": "veranlagt",
    "veranlagten": "veranlagen",
    "veranlagter": "veranlagt",
    "veranlagtes": "veranlagt",
    "veranlagtest": "veranlagen",
    "veranlagtet": "veranlagen",
    "veranlasse": "veranlassen",
    "veranlassend": "veranlassen",
    "veranlassende": "veranlassend",
    "veranlassendem": "veranlassend",
    "veranlassenden": "veranlassend",
    "veranlassender": "veranlassend",
    "veranlassendes": "veranlassend",
    "veranlassest": "veranlassen",
    "veranlasset": "veranlassen",
    "veranlaßt": "veranlassen",
    "veranlaßte": "veranlassen",
    "veranlaßtem": "veranlaßt",
    "veranlaßten": "veranlassen",
    "veranlaßter": "veranlaßt",
    "veranlaßtes": "veranlaßt",
    "veranlaßtest": "veranlassen",
    "veranlaßtet": "veranlassen",
    "veranschauliche": "veranschaulichen",
    "veranschaulichend": "veranschaulichen",
    "veranschaulichende": "veranschaulichend",
    "veranschaulichendem": "veranschaulichend",
    "veranschaulichenden": "veranschaulichend",
    "veranschaulichender": "veranschaulichend",
    "veranschaulichendere": "veranschaulichend",
    "veranschaulichenderem": "veranschaulichend",
    "veranschaulichenderen": "veranschaulichend",
    "veranschaulichenderer": "veranschaulichend",
    "veranschaulichenderes": "veranschaulichend",
    "veranschaulichendes": "veranschaulichend",
    "veranschaulichendste": "veranschaulichend",
    "veranschaulichendstem": "veranschaulichend",
    "veranschaulichendsten": "veranschaulichend",
    "veranschaulichendster": "veranschaulichend",
    "veranschaulichendstes": "veranschaulichend",
    "veranschaulichest": "veranschaulichen",
    "veranschaulichet": "veranschaulichen",
    "veranschaulichst": "veranschaulichen",
    "veranschaulicht": "veranschaulichen",
    "veranschaulichte": "veranschaulichen",
    "veranschaulichtem": "veranschaulicht",
    "veranschaulichten": "veranschaulichen",
    "veranschaulichter": "veranschaulicht",
    "veranschaulichtere": "veranschaulicht",
    "veranschaulichterem": "veranschaulicht",
    "veranschaulichteren": "veranschaulicht",
    "veranschaulichterer": "veranschaulicht",
    "veranschaulichteres": "veranschaulicht",
    "veranschaulichtes": "veranschaulicht",
    "veranschaulichtest": "veranschaulichen",
    "veranschaulichteste": "veranschaulicht",
    "veranschaulichtestem": "veranschaulicht",
    "veranschaulichtesten": "veranschaulicht",
    "veranschaulichtester": "veranschaulicht",
    "veranschaulichtestes": "veranschaulicht",
    "veranschaulichtet": "veranschaulichen",
    "veranschlage": "veranschlagen",
    "veranschlagend": "veranschlagen",
    "veranschlagende": "veranschlagend",
    "veranschlagendem": "veranschlagend",
    "veranschlagenden": "veranschlagend",
    "veranschlagender": "veranschlagend",
    "veranschlagendes": "veranschlagend",
    "veranschlagest": "veranschlagen",
    "veranschlaget": "veranschlagen",
    "veranschlagst": "veranschlagen",
    "veranschlagt": "veranschlagen",
    "veranschlagte": "veranschlagen",
    "veranschlagtem": "veranschlagt",
    "veranschlagten": "veranschlagen",
    "veranschlagter": "veranschlagt",
    "veranschlagtes": "veranschlagt",
    "veranschlagtest": "veranschlagen",
    "veranschlagtet": "veranschlagen",
    "veranstalte": "veranstalten",
    "veranstaltend": "veranstalten",
    "veranstaltende": "veranstaltend",
    "veranstaltendem": "veranstaltend",
    "veranstaltenden": "veranstaltend",
    "veranstaltender": "veranstaltend",
    "veranstaltendes": "veranstaltend",
    "veranstaltest": "veranstalten",
    "veranstaltet": "veranstalten",
    "veranstaltete": "veranstalten",
    "veranstaltetem": "veranstaltet",
    "veranstalteten": "veranstalten",
    "veranstalteter": "veranstaltet",
    "veranstaltetes": "veranstaltet",
    "veranstaltetest": "veranstalten",
    "veranstaltetet": "veranstalten",
    "verantworte": "verantworten",
    "verantwortend": "verantworten",
    "verantwortende": "verantwortend",
    "verantwortendem": "verantwortend",
    "verantwortenden": "verantwortend",
    "verantwortender": "verantwortend",
    "verantwortendes": "verantwortend",
    "verantwortest": "verantworten",
    "verantwortet": "verantworten",
    "verantwortete": "verantworten",
    "verantwortetem": "verantwortet",
    "verantworteten": "verantworten",
    "verantworteter": "verantwortet",
    "verantwortetes": "verantwortet",
    "verantwortetest": "verantworten",
    "verantwortetet": "verantworten",
    "verantwortliche": "verantwortlich",
    "verantwortlichem": "verantwortlich",
    "verantwortlichen": "verantwortlich",
    "verantwortlicher": "verantwortlich",
    "verantwortlichere": "verantwortlich",
    "verantwortlicherem": "verantwortlich",
    "verantwortlicheren": "verantwortlich",
    "verantwortlicherer": "verantwortlich",
    "verantwortlicheres": "verantwortlich",
    "verantwortliches": "verantwortlich",
    "verantwortlichste": "verantwortlich",
    "verantwortlichstem": "verantwortlich",
    "verantwortlichsten": "verantwortlich",
    "verantwortlichster": "verantwortlich",
    "verantwortlichstes": "verantwortlich",
    "verantwortungsbewußtem": "verantwortungsbewußt",
    "verantwortungsbewußten": "verantwortungsbewußt",
    "verantwortungsbewußter": "verantwortungsbewußt",
    "verantwortungsbewußtere": "verantwortungsbewußt",
    "verantwortungsbewußterem": "verantwortungsbewußt",
    "verantwortungsbewußteren": "verantwortungsbewußt",
    "verantwortungsbewußterer": "verantwortungsbewußt",
    "verantwortungsbewußteres": "verantwortungsbewußt",
    "verantwortungsbewußtes": "verantwortungsbewußt",
    "verantwortungsbewußteste": "verantwortungsbewußt",
    "verantwortungsbewußtestem": "verantwortungsbewußt",
    "verantwortungsbewußtesten": "verantwortungsbewußt",
    "verantwortungsbewußtester": "verantwortungsbewußt",
    "verantwortungsbewußtestes": "verantwortungsbewußt",
    "verantwortungslose": "verantwortungslos",
    "verantwortungslosem": "verantwortungslos",
    "verantwortungslosen": "verantwortungslos",
    "verantwortungsloser": "verantwortungslos",
    "verantwortungslosere": "verantwortungslos",
    "verantwortungsloserem": "verantwortungslos",
    "verantwortungsloseren": "verantwortungslos",
    "verantwortungsloserer": "verantwortungslos",
    "verantwortungsloseres": "verantwortungslos",
    "verantwortungsloses": "verantwortungslos",
    "verantwortungsloseste": "verantwortungslos",
    "verantwortungslosestem": "verantwortungslos",
    "verantwortungslosesten": "verantwortungslos",
    "verantwortungslosester": "verantwortungslos",
    "verantwortungslosestes": "verantwortungslos",
    "verantwortungsvolle": "verantwortungsvoll",
    "verantwortungsvollem": "verantwortungsvoll",
    "verantwortungsvollen": "verantwortungsvoll",
    "verantwortungsvoller": "verantwortungsvoll",
    "verantwortungsvollere": "verantwortungsvoll",
    "verantwortungsvollerem": "verantwortungsvoll",
    "verantwortungsvolleren": "verantwortungsvoll",
    "verantwortungsvollerer": "verantwortungsvoll",
    "verantwortungsvolleres": "verantwortungsvoll",
    "verantwortungsvolles": "verantwortungsvoll",
    "verantwortungsvollste": "verantwortungsvoll",
    "verantwortungsvollstem": "verantwortungsvoll",
    "verantwortungsvollsten": "verantwortungsvoll",
    "verantwortungsvollster": "verantwortungsvoll",
    "verantwortungsvollstes": "verantwortungsvoll",
    "verarbeite": "verarbeiten",
    "verarbeitend": "verarbeiten",
    "verarbeitende": "verarbeitend",
    "verarbeitendem": "verarbeitend",
    "verarbeitenden": "verarbeitend",
    "verarbeitender": "verarbeitend",
    "verarbeitendes": "verarbeitend",
    "verarbeitest": "verarbeiten",
    "verarbeitet": "verarbeiten",
    "verarbeitete": "verarbeiten",
    "verarbeitetem": "verarbeitet",
    "verarbeiteten": "verarbeiten",
    "verarbeiteter": "verarbeitet",
    "verarbeitetes": "verarbeitet",
    "verarbeitetest": "verarbeiten",
    "verarbeitetet": "verarbeiten",
    "verarme": "verarmen",
    "verarmend": "verarmen",
    "verarmende": "verarmend",
    "verarmendem": "verarmend",
    "verarmenden": "verarmend",
    "verarmender": "verarmend",
    "verarmendes": "verarmend",
    "verarmest": "verarmen",
    "verarmet": "verarmen",
    "verarmst": "verarmen",
    "verarmt": "verarmen",
    "verarmte": "verarmen",
    "verarmtem": "verarmt",
    "verarmten": "verarmen",
    "verarmter": "verarmt",
    "verarmtere": "verarmt",
    "verarmterem": "verarmt",
    "verarmteren": "verarmt",
    "verarmterer": "verarmt",
    "verarmteres": "verarmt",
    "verarmtes": "verarmt",
    "verarmtest": "verarmen",
    "verarmteste": "verarmt",
    "verarmtestem": "verarmt",
    "verarmtesten": "verarmt",
    "verarmtester": "verarmt",
    "verarmtestes": "verarmt",
    "verarmtet": "verarmen",
    "verarsche": "verarschen",
    "verarschend": "verarschen",
    "verarschende": "verarschend",
    "verarschendem": "verarschend",
    "verarschenden": "verarschend",
    "verarschender": "verarschend",
    "verarschendere": "verarschend",
    "verarschenderem": "verarschend",
    "verarschenderen": "verarschend",
    "verarschenderer": "verarschend",
    "verarschenderes": "verarschend",
    "verarschendes": "verarschend",
    "verarschendste": "verarschend",
    "verarschendstem": "verarschend",
    "verarschendsten": "verarschend",
    "verarschendster": "verarschend",
    "verarschendstes": "verarschend",
    "verarschest": "verarschen",
    "verarschet": "verarschen",
    "verarschst": "verarschen",
    "verarscht": "verarschen",
    "verarschte": "verarschen",
    "verarschtem": "verarscht",
    "verarschten": "verarschen",
    "verarschter": "verarscht",
    "verarschtere": "verarscht",
    "verarschterem": "verarscht",
    "verarschteren": "verarscht",
    "verarschterer": "verarscht",
    "verarschteres": "verarscht",
    "verarschtes": "verarscht",
    "verarschtest": "verarschen",
    "verarschteste": "verarscht",
    "verarschtestem": "verarscht",
    "verarschtesten": "verarscht",
    "verarschtester": "verarscht",
    "verarschtestes": "verarscht",
    "verarschtet": "verarschen",
    "verarzte": "verarzten",
    "verarztend": "verarzten",
    "verarztende": "verarztend",
    "verarztendem": "verarztend",
    "verarztenden": "verarztend",
    "verarztender": "verarztend",
    "verarztendes": "verarztend",
    "verarztest": "verarzten",
    "verarztet": "verarzten",
    "verarztete": "verarzten",
    "verarztetem": "verarztet",
    "verarzteten": "verarzten",
    "verarzteter": "verarztet",
    "verarztetes": "verarztet",
    "verarztetest": "verarzten",
    "verarztetet": "verarzten",
    "verausgabe": "verausgaben",
    "verausgabend": "verausgaben",
    "verausgabende": "verausgabend",
    "verausgabendem": "verausgabend",
    "verausgabenden": "verausgabend",
    "verausgabender": "verausgabend",
    "verausgabendere": "verausgabend",
    "verausgabenderem": "verausgabend",
    "verausgabenderen": "verausgabend",
    "verausgabenderer": "verausgabend",
    "verausgabenderes": "verausgabend",
    "verausgabendes": "verausgabend",
    "verausgabendste": "verausgabend",
    "verausgabendstem": "verausgabend",
    "verausgabendsten": "verausgabend",
    "verausgabendster": "verausgabend",
    "verausgabendstes": "verausgabend",
    "verausgabest": "verausgaben",
    "verausgabet": "verausgaben",
    "verausgabst": "verausgaben",
    "verausgabt": "verausgaben",
    "verausgabte": "verausgaben",
    "verausgabtem": "verausgabt",
    "verausgabten": "verausgaben",
    "verausgabter": "verausgabt",
    "verausgabtere": "verausgabt",
    "verausgabterem": "verausgabt",
    "verausgabteren": "verausgabt",
    "verausgabterer": "verausgabt",
    "verausgabteres": "verausgabt",
    "verausgabtes": "verausgabt",
    "verausgabtest": "verausgaben",
    "verausgabteste": "verausgabt",
    "verausgabtestem": "verausgabt",
    "verausgabtesten": "verausgabt",
    "verausgabtester": "verausgabt",
    "verausgabtestes": "verausgabt",
    "verausgabtet": "verausgaben",
    "verbale": "verbal",
    "verbalem": "verbal",
    "verbalen": "verbal",
    "verbaler": "verbal",
    "verbales": "verbal",
    "verballere": "verballern",
    "verballernd": "verballern",
    "verballernde": "verballernd",
    "verballerndem": "verballernd",
    "verballernden": "verballernd",
    "verballernder": "verballernd",
    "verballerndere": "verballernd",
    "verballernderem": "verballernd",
    "verballernderen": "verballernd",
    "verballernderer": "verballernd",
    "verballernderes": "verballernd",
    "verballerndes": "verballernd",
    "verballerndste": "verballernd",
    "verballerndstem": "verballernd",
    "verballerndsten": "verballernd",
    "verballerndster": "verballernd",
    "verballerndstes": "verballernd",
    "verballerst": "verballern",
    "verballert": "verballern",
    "verballerte": "verballern",
    "verballertem": "verballert",
    "verballerten": "verballern",
    "verballerter": "verballert",
    "verballertes": "verballert",
    "verballertest": "verballern",
    "verballertet": "verballern",
    "verband": "verbinden",
    "verbanden": "verbinden",
    "verbandest": "verbinden",
    "verbandet": "verbinden",
    "verbanne": "verbannen",
    "verbannend": "verbannen",
    "verbannende": "verbannend",
    "verbannendem": "verbannend",
    "verbannenden": "verbannend",
    "verbannender": "verbannend",
    "verbannendere": "verbannend",
    "verbannenderem": "verbannend",
    "verbannenderen": "verbannend",
    "verbannenderer": "verbannend",
    "verbannenderes": "verbannend",
    "verbannendes": "verbannend",
    "verbannendste": "verbannend",
    "verbannendstem": "verbannend",
    "verbannendsten": "verbannend",
    "verbannendster": "verbannend",
    "verbannendstes": "verbannend",
    "verbannest": "verbannen",
    "verbannet": "verbannen",
    "verbannst": "verbannen",
    "verbannt": "verbannen",
    "verbannte": "verbannen",
    "verbanntem": "verbannt",
    "verbannten": "verbannen",
    "verbannter": "verbannt",
    "verbanntere": "verbannt",
    "verbannterem": "verbannt",
    "verbannteren": "verbannt",
    "verbannterer": "verbannt",
    "verbannteres": "verbannt",
    "verbanntes": "verbannt",
    "verbanntest": "verbannen",
    "verbannteste": "verbannt",
    "verbanntestem": "verbannt",
    "verbanntesten": "verbannt",
    "verbanntester": "verbannt",
    "verbanntestes": "verbannt",
    "verbanntet": "verbannen",
    "verbarg": "verbergen",
    "verbargen": "verbergen",
    "verbargst": "verbergen",
    "verbargt": "verbergen",
    "verbarrikadiere": "verbarrikadieren",
    "verbarrikadierend": "verbarrikadieren",
    "verbarrikadierende": "verbarrikadierend",
    "verbarrikadierendem": "verbarrikadierend",
    "verbarrikadierenden": "verbarrikadierend",
    "verbarrikadierender": "verbarrikadierend",
    "verbarrikadierendere": "verbarrikadierend",
    "verbarrikadierenderem": "verbarrikadierend",
    "verbarrikadierenderen": "verbarrikadierend",
    "verbarrikadierenderer": "verbarrikadierend",
    "verbarrikadierenderes": "verbarrikadierend",
    "verbarrikadierendes": "verbarrikadierend",
    "verbarrikadierendste": "verbarrikadierend",
    "verbarrikadierendstem": "verbarrikadierend",
    "verbarrikadierendsten": "verbarrikadierend",
    "verbarrikadierendster": "verbarrikadierend",
    "verbarrikadierendstes": "verbarrikadierend",
    "verbarrikadierest": "verbarrikadieren",
    "verbarrikadieret": "verbarrikadieren",
    "verbarrikadierst": "verbarrikadieren",
    "verbarrikadiert": "verbarrikadieren",
    "verbarrikadierte": "verbarrikadieren",
    "verbarrikadiertem": "verbarrikadiert",
    "verbarrikadierten": "verbarrikadieren",
    "verbarrikadierter": "verbarrikadiert",
    "verbarrikadiertere": "verbarrikadiert",
    "verbarrikadierterem": "verbarrikadiert",
    "verbarrikadierteren": "verbarrikadiert",
    "verbarrikadierterer": "verbarrikadiert",
    "verbarrikadierteres": "verbarrikadiert",
    "verbarrikadiertes": "verbarrikadiert",
    "verbarrikadiertest": "verbarrikadieren",
    "verbarrikadierteste": "verbarrikadiert",
    "verbarrikadiertestem": "verbarrikadiert",
    "verbarrikadiertesten": "verbarrikadiert",
    "verbarrikadiertester": "verbarrikadiert",
    "verbarrikadiertestes": "verbarrikadiert",
    "verbarrikadiertet": "verbarrikadieren",
    "verbaue": "verbauen",
    "verbauend": "verbauen",
    "verbauende": "verbauend",
    "verbauendem": "verbauend",
    "verbauenden": "verbauend",
    "verbauender": "verbauend",
    "verbauendes": "verbauend",
    "verbauest": "verbauen",
    "verbauet": "verbauen",
    "verbaust": "verbauen",
    "verbaut": "verbauen",
    "verbaute": "verbauen",
    "verbautem": "verbaut",
    "verbauten": "verbauen",
    "verbauter": "verbaut",
    "verbautere": "verbaut",
    "verbauterem": "verbaut",
    "verbauteren": "verbaut",
    "verbauterer": "verbaut",
    "verbauteres": "verbaut",
    "verbautes": "verbaut",
    "verbautest": "verbauen",
    "verbauteste": "verbaut",
    "verbautestem": "verbaut",
    "verbautesten": "verbaut",
    "verbautester": "verbaut",
    "verbautestes": "verbaut",
    "verbautet": "verbauen",
    "verbeamte": "verbeamten",
    "verbeamtend": "verbeamten",
    "verbeamtende": "verbeamtend",
    "verbeamtendem": "verbeamtend",
    "verbeamtenden": "verbeamtend",
    "verbeamtender": "verbeamtend",
    "verbeamtendes": "verbeamtend",
    "verbeamtest": "verbeamten",
    "verbeamtet": "verbeamten",
    "verbeamtete": "verbeamten",
    "verbeamtetem": "verbeamtet",
    "verbeamteten": "verbeamten",
    "verbeamteter": "verbeamtet",
    "verbeamtetes": "verbeamtet",
    "verbeamtetest": "verbeamten",
    "verbeamtetet": "verbeamten",
    "verbeiße": "verbeißen",
    "verbeißend": "verbeißen",
    "verbeißende": "verbeißend",
    "verbeißendem": "verbeißend",
    "verbeißenden": "verbeißend",
    "verbeißender": "verbeißend",
    "verbeißendere": "verbeißend",
    "verbeißenderem": "verbeißend",
    "verbeißenderen": "verbeißend",
    "verbeißenderer": "verbeißend",
    "verbeißenderes": "verbeißend",
    "verbeißendes": "verbeißend",
    "verbeißendste": "verbeißend",
    "verbeißendstem": "verbeißend",
    "verbeißendsten": "verbeißend",
    "verbeißendster": "verbeißend",
    "verbeißendstes": "verbeißend",
    "verbeißest": "verbeißen",
    "verbeißet": "verbeißen",
    "verbeißt": "verbeißen",
    "verberge": "verbergen",
    "verbergend": "verbergen",
    "verbergende": "verbergend",
    "verbergendem": "verbergend",
    "verbergenden": "verbergend",
    "verbergender": "verbergend",
    "verbergendes": "verbergend",
    "verbergest": "verbergen",
    "verberget": "verbergen",
    "verbergt": "verbergen",
    "verbessere": "verbessern",
    "verbessernd": "verbessern",
    "verbessernde": "verbessernd",
    "verbesserndem": "verbessernd",
    "verbessernden": "verbessernd",
    "verbessernder": "verbessernd",
    "verbesserndere": "verbessernd",
    "verbessernderem": "verbessernd",
    "verbessernderen": "verbessernd",
    "verbessernderer": "verbessernd",
    "verbessernderes": "verbessernd",
    "verbesserndes": "verbessernd",
    "verbesserndste": "verbessernd",
    "verbesserndstem": "verbessernd",
    "verbesserndsten": "verbessernd",
    "verbesserndster": "verbessernd",
    "verbesserndstes": "verbessernd",
    "verbesserst": "verbessern",
    "verbessert": "verbessern",
    "verbesserte": "verbessern",
    "verbessertem": "verbessert",
    "verbesserten": "verbessern",
    "verbesserter": "verbessert",
    "verbessertere": "verbessert",
    "verbesserterem": "verbessert",
    "verbesserteren": "verbessert",
    "verbesserterer": "verbessert",
    "verbesserteres": "verbessert",
    "verbessertes": "verbessert",
    "verbessertest": "verbessern",
    "verbesserteste": "verbessert",
    "verbessertestem": "verbessert",
    "verbessertesten": "verbessert",
    "verbessertester": "verbessert",
    "verbessertestes": "verbessert",
    "verbessertet": "verbessern",
    "verbesserungsfähigem": "verbesserungsfähig",
    "verbesserungsfähigen": "verbesserungsfähig",
    "verbesserungsfähiger": "verbesserungsfähig",
    "verbesserungsfähigere": "verbesserungsfähig",
    "verbesserungsfähigerem": "verbesserungsfähig",
    "verbesserungsfähigeren": "verbesserungsfähig",
    "verbesserungsfähigerer": "verbesserungsfähig",
    "verbesserungsfähigeres": "verbesserungsfähig",
    "verbesserungsfähiges": "verbesserungsfähig",
    "verbesserungsfähigste": "verbesserungsfähig",
    "verbesserungsfähigstem": "verbesserungsfähig",
    "verbesserungsfähigsten": "verbesserungsfähig",
    "verbesserungsfähigster": "verbesserungsfähig",
    "verbesserungsfähigstes": "verbesserungsfähig",
    "verbeule": "verbeulen",
    "verbeulend": "verbeulen",
    "verbeulende": "verbeulend",
    "verbeulendem": "verbeulend",
    "verbeulenden": "verbeulend",
    "verbeulender": "verbeulend",
    "verbeulendere": "verbeulend",
    "verbeulenderem": "verbeulend",
    "verbeulenderen": "verbeulend",
    "verbeulenderer": "verbeulend",
    "verbeulenderes": "verbeulend",
    "verbeulendes": "verbeulend",
    "verbeulendste": "verbeulend",
    "verbeulendstem": "verbeulend",
    "verbeulendsten": "verbeulend",
    "verbeulendster": "verbeulend",
    "verbeulendstes": "verbeulend",
    "verbeulest": "verbeulen",
    "verbeulet": "verbeulen",
    "verbeulst": "verbeulen",
    "verbeult": "verbeulen",
    "verbeulte": "verbeulen",
    "verbeultem": "verbeult",
    "verbeulten": "verbeulen",
    "verbeulter": "verbeult",
    "verbeultere": "verbeult",
    "verbeulterem": "verbeult",
    "verbeulteren": "verbeult",
    "verbeulterer": "verbeult",
    "verbeulteres": "verbeult",
    "verbeultes": "verbeult",
    "verbeultest": "verbeulen",
    "verbeulteste": "verbeult",
    "verbeultestem": "verbeult",
    "verbeultesten": "verbeult",
    "verbeultester": "verbeult",
    "verbeultestes": "verbeult",
    "verbeultet": "verbeulen",
    "verbiege": "verbiegen",
    "verbiegend": "verbiegen",
    "verbiegende": "verbiegend",
    "verbiegendem": "verbiegend",
    "verbiegenden": "verbiegend",
    "verbiegender": "verbiegend",
    "verbiegendes": "verbiegend",
    "verbiegest": "verbiegen",
    "verbieget": "verbiegen",
    "verbiegst": "verbiegen",
    "verbiegt": "verbiegen",
    "verbiesterte": "verbiestert",
    "verbiestertem": "verbiestert",
    "verbiesterten": "verbiestert",
    "verbiesterter": "verbiestert",
    "verbiestertere": "verbiestert",
    "verbiesterterem": "verbiestert",
    "verbiesterteren": "verbiestert",
    "verbiesterterer": "verbiestert",
    "verbiesterteres": "verbiestert",
    "verbiestertes": "verbiestert",
    "verbiesterteste": "verbiestert",
    "verbiestertestem": "verbiestert",
    "verbiestertesten": "verbiestert",
    "verbiestertester": "verbiestert",
    "verbiestertestes": "verbiestert",
    "verbiete": "verbieten",
    "verbietend": "verbieten",
    "verbietende": "verbietend",
    "verbietendem": "verbietend",
    "verbietenden": "verbietend",
    "verbietender": "verbietend",
    "verbietendes": "verbietend",
    "verbietest": "verbieten",
    "verbietet": "verbieten",
    "verbillige": "verbilligen",
    "verbilligend": "verbilligen",
    "verbilligende": "verbilligend",
    "verbilligendem": "verbilligend",
    "verbilligenden": "verbilligend",
    "verbilligender": "verbilligend",
    "verbilligendere": "verbilligend",
    "verbilligenderem": "verbilligend",
    "verbilligenderen": "verbilligend",
    "verbilligenderer": "verbilligend",
    "verbilligenderes": "verbilligend",
    "verbilligendes": "verbilligend",
    "verbilligendste": "verbilligend",
    "verbilligendstem": "verbilligend",
    "verbilligendsten": "verbilligend",
    "verbilligendster": "verbilligend",
    "verbilligendstes": "verbilligend",
    "verbilligest": "verbilligen",
    "verbilliget": "verbilligen",
    "verbilligst": "verbilligen",
    "verbilligt": "verbilligen",
    "verbilligte": "verbilligen",
    "verbilligtem": "verbilligt",
    "verbilligten": "verbilligen",
    "verbilligter": "verbilligt",
    "verbilligtere": "verbilligt",
    "verbilligterem": "verbilligt",
    "verbilligteren": "verbilligt",
    "verbilligterer": "verbilligt",
    "verbilligteres": "verbilligt",
    "verbilligtes": "verbilligt",
    "verbilligtest": "verbilligen",
    "verbilligteste": "verbilligt",
    "verbilligtestem": "verbilligt",
    "verbilligtesten": "verbilligt",
    "verbilligtester": "verbilligt",
    "verbilligtestes": "verbilligt",
    "verbilligtet": "verbilligen",
    "verbinde": "verbinden",
    "verbindend": "verbinden",
    "verbindende": "verbindend",
    "verbindendem": "verbindend",
    "verbindenden": "verbindend",
    "verbindender": "verbindend",
    "verbindendes": "verbindend",
    "verbindest": "verbinden",
    "verbindet": "verbinden",
    "verbindliche": "verbindlich",
    "verbindlichem": "verbindlich",
    "verbindlichen": "verbindlich",
    "verbindlicher": "verbindlich",
    "verbindlichere": "verbindlich",
    "verbindlicherem": "verbindlich",
    "verbindlicheren": "verbindlich",
    "verbindlicherer": "verbindlich",
    "verbindlicheres": "verbindlich",
    "verbindliches": "verbindlich",
    "verbindlichstem": "verbindlich",
    "verbindlichsten": "verbindlich",
    "verbindlichster": "verbindlich",
    "verbindlichstes": "verbindlich",
    "verbirg": "verbergen",
    "verbirgst": "verbergen",
    "verbirgt": "verbergen",
    "verbisse": "verbeißen",
    "verbissen": "verbeißen",
    "verbissene": "verbissen",
    "verbissenem": "verbissen",
    "verbissenen": "verbissen",
    "verbissener": "verbissen",
    "verbissenere": "verbissen",
    "verbissenerem": "verbissen",
    "verbisseneren": "verbissen",
    "verbissenerer": "verbissen",
    "verbisseneres": "verbissen",
    "verbissenes": "verbissen",
    "verbissenstem": "verbissen",
    "verbissensten": "verbissen",
    "verbissenster": "verbissen",
    "verbissenstes": "verbissen",
    "verbissest": "verbeißen",
    "verbisset": "verbeißen",
    "verbittere": "verbittern",
    "verbitternd": "verbittern",
    "verbitternde": "verbitternd",
    "verbitterndem": "verbitternd",
    "verbitternden": "verbitternd",
    "verbitternder": "verbitternd",
    "verbitterndere": "verbitternd",
    "verbitternderem": "verbitternd",
    "verbitternderen": "verbitternd",
    "verbitternderer": "verbitternd",
    "verbitternderes": "verbitternd",
    "verbitterndes": "verbitternd",
    "verbitterndste": "verbitternd",
    "verbitterndstem": "verbitternd",
    "verbitterndsten": "verbitternd",
    "verbitterndster": "verbitternd",
    "verbitterndstes": "verbitternd",
    "verbitterst": "verbittern",
    "verbittert": "verbittern",
    "verbitterte": "verbittern",
    "verbittertem": "verbittert",
    "verbitterten": "verbittern",
    "verbitterter": "verbittert",
    "verbittertere": "verbittert",
    "verbitterterem": "verbittert",
    "verbitterteren": "verbittert",
    "verbitterterer": "verbittert",
    "verbitterteres": "verbittert",
    "verbittertes": "verbittert",
    "verbittertest": "verbittern",
    "verbitterteste": "verbittert",
    "verbittertestem": "verbittert",
    "verbittertesten": "verbittert",
    "verbittertester": "verbittert",
    "verbittertestes": "verbittert",
    "verbittertet": "verbittern",
    "verbiß": "verbeißen",
    "verbißt": "verbeißen",
    "verblasse": "verblassen",
    "verblassend": "verblassen",
    "verblassende": "verblassend",
    "verblassendem": "verblassend",
    "verblassenden": "verblassend",
    "verblassender": "verblassend",
    "verblassendere": "verblassend",
    "verblassenderem": "verblassend",
    "verblassenderen": "verblassend",
    "verblassenderer": "verblassend",
    "verblassenderes": "verblassend",
    "verblassendes": "verblassend",
    "verblassendste": "verblassend",
    "verblassendstem": "verblassend",
    "verblassendsten": "verblassend",
    "verblassendster": "verblassend",
    "verblassendstes": "verblassend",
    "verblassest": "verblassen",
    "verblasset": "verblassen",
    "verblaßt": "verblassen",
    "verblaßte": "verblassen",
    "verblaßtem": "verblaßt",
    "verblaßten": "verblassen",
    "verblaßter": "verblaßt",
    "verblaßtere": "verblaßt",
    "verblaßterem": "verblaßt",
    "verblaßteren": "verblaßt",
    "verblaßterer": "verblaßt",
    "verblaßteres": "verblaßt",
    "verblaßtes": "verblaßt",
    "verblaßtest": "verblassen",
    "verblaßteste": "verblaßt",
    "verblaßtestem": "verblaßt",
    "verblaßtesten": "verblaßt",
    "verblaßtester": "verblaßt",
    "verblaßtestes": "verblaßt",
    "verblaßtet": "verblassen",
    "verbleibe": "verbleiben",
    "verbleibend": "verbleiben",
    "verbleibende": "verbleibend",
    "verbleibendem": "verbleibend",
    "verbleibenden": "verbleibend",
    "verbleibender": "verbleibend",
    "verbleibendes": "verbleibend",
    "verbleibest": "verbleiben",
    "verbleibet": "verbleiben",
    "verbleibst": "verbleiben",
    "verbleibt": "verbleiben",
    "verbleiche": "verbleichen",
    "verbleichend": "verbleichen",
    "verbleichende": "verbleichend",
    "verbleichendem": "verbleichend",
    "verbleichenden": "verbleichend",
    "verbleichender": "verbleichend",
    "verbleichendere": "verbleichend",
    "verbleichenderem": "verbleichend",
    "verbleichenderen": "verbleichend",
    "verbleichenderer": "verbleichend",
    "verbleichenderes": "verbleichend",
    "verbleichendes": "verbleichend",
    "verbleichendste": "verbleichend",
    "verbleichendstem": "verbleichend",
    "verbleichendsten": "verbleichend",
    "verbleichendster": "verbleichend",
    "verbleichendstes": "verbleichend",
    "verbleichest": "verbleichen",
    "verbleichet": "verbleichen",
    "verbleichst": "verbleichen",
    "verbleicht": "verbleichen",
    "verblende": "verblenden",
    "verblendend": "verblenden",
    "verblendende": "verblendend",
    "verblendendem": "verblendend",
    "verblendenden": "verblendend",
    "verblendender": "verblendend",
    "verblendendere": "verblendend",
    "verblendenderem": "verblendend",
    "verblendenderen": "verblendend",
    "verblendenderer": "verblendend",
    "verblendenderes": "verblendend",
    "verblendendes": "verblendend",
    "verblendendste": "verblendend",
    "verblendendstem": "verblendend",
    "verblendendsten": "verblendend",
    "verblendendster": "verblendend",
    "verblendendstes": "verblendend",
    "verblendest": "verblenden",
    "verblendet": "verblenden",
    "verblendete": "verblenden",
    "verblendetem": "verblendet",
    "verblendeten": "verblenden",
    "verblendeter": "verblendet",
    "verblendetere": "verblendet",
    "verblendeterem": "verblendet",
    "verblendeteren": "verblendet",
    "verblendeterer": "verblendet",
    "verblendeteres": "verblendet",
    "verblendetes": "verblendet",
    "verblendetest": "verblenden",
    "verblendeteste": "verblendet",
    "verblendetestem": "verblendet",
    "verblendetesten": "verblendet",
    "verblendetester": "verblendet",
    "verblendetestes": "verblendet",
    "verblendetet": "verblenden",
    "verblich": "verbleichen",
    "verbliche": "verbleichen",
    "verblichen": "verbleichen",
    "verblichene": "verblichen",
    "verblichenem": "verblichen",
    "verblichenen": "verblichen",
    "verblichener": "verblichen",
    "verblichenere": "verblichen",
    "verblichenerem": "verblichen",
    "verblicheneren": "verblichen",
    "verblichenerer": "verblichen",
    "verblicheneres": "verblichen",
    "verblichenes": "verblichen",
    "verblichenste": "verblichen",
    "verblichenstem": "verblichen",
    "verblichensten": "verblichen",
    "verblichenster": "verblichen",
    "verblichenstes": "verblichen",
    "verblichest": "verbleichen",
    "verblichet": "verbleichen",
    "verblichst": "verbleichen",
    "verblicht": "verbleichen",
    "verblieb": "verbleiben",
    "verbliebe": "verbleiben",
    "verblieben": "verbleiben",
    "verbliebene": "verblieben",
    "verbliebenem": "verblieben",
    "verbliebenen": "verblieben",
    "verbliebener": "verblieben",
    "verbliebenes": "verblieben",
    "verbliebest": "verbleiben",
    "verbliebet": "verbleiben",
    "verbliebst": "verbleiben",
    "verbliebt": "verbleiben",
    "verblute": "verbluten",
    "verblutend": "verbluten",
    "verblutende": "verblutend",
    "verblutendem": "verblutend",
    "verblutenden": "verblutend",
    "verblutender": "verblutend",
    "verblutendere": "verblutend",
    "verblutenderem": "verblutend",
    "verblutenderen": "verblutend",
    "verblutenderer": "verblutend",
    "verblutenderes": "verblutend",
    "verblutendes": "verblutend",
    "verblutendste": "verblutend",
    "verblutendstem": "verblutend",
    "verblutendsten": "verblutend",
    "verblutendster": "verblutend",
    "verblutendstes": "verblutend",
    "verblutest": "verbluten",
    "verblutet": "verbluten",
    "verblutete": "verbluten",
    "verblutetem": "verblutet",
    "verbluteten": "verbluten",
    "verbluteter": "verblutet",
    "verblutetere": "verblutet",
    "verbluteterem": "verblutet",
    "verbluteteren": "verblutet",
    "verbluteterer": "verblutet",
    "verbluteteres": "verblutet",
    "verblutetes": "verblutet",
    "verblutetest": "verbluten",
    "verbluteteste": "verblutet",
    "verblutetestem": "verblutet",
    "verblutetesten": "verblutet",
    "verblutetester": "verblutet",
    "verblutetestes": "verblutet",
    "verblutetet": "verbluten",
    "verblöde": "verblöden",
    "verblödend": "verblöden",
    "verblödende": "verblödend",
    "verblödendem": "verblödend",
    "verblödenden": "verblödend",
    "verblödender": "verblödend",
    "verblödendere": "verblödend",
    "verblödenderem": "verblödend",
    "verblödenderen": "verblödend",
    "verblödenderer": "verblödend",
    "verblödenderes": "verblödend",
    "verblödendes": "verblödend",
    "verblödendste": "verblödend",
    "verblödendstem": "verblödend",
    "verblödendsten": "verblödend",
    "verblödendster": "verblödend",
    "verblödendstes": "verblödend",
    "verblödest": "verblöden",
    "verblödet": "verblöden",
    "verblödete": "verblöden",
    "verblödetem": "verblödet",
    "verblödeten": "verblöden",
    "verblödeter": "verblödet",
    "verblödetere": "verblödet",
    "verblödeterem": "verblödet",
    "verblödeteren": "verblödet",
    "verblödeterer": "verblödet",
    "verblödeteres": "verblödet",
    "verblödetes": "verblödet",
    "verblödetest": "verblöden",
    "verblödeteste": "verblödet",
    "verblödetestem": "verblödet",
    "verblödetesten": "verblödet",
    "verblödetester": "verblödet",
    "verblödetestes": "verblödet",
    "verblödetet": "verblöden",
    "verblüffe": "verblüffen",
    "verblüffend": "verblüffen",
    "verblüffende": "verblüffend",
    "verblüffendem": "verblüffend",
    "verblüffenden": "verblüffend",
    "verblüffender": "verblüffend",
    "verblüffendere": "verblüffend",
    "verblüffenderem": "verblüffend",
    "verblüffenderen": "verblüffend",
    "verblüffenderer": "verblüffend",
    "verblüffenderes": "verblüffend",
    "verblüffendes": "verblüffend",
    "verblüffendste": "verblüffend",
    "verblüffendstem": "verblüffend",
    "verblüffendsten": "verblüffend",
    "verblüffendster": "verblüffend",
    "verblüffendstes": "verblüffend",
    "verblüffest": "verblüffen",
    "verblüffet": "verblüffen",
    "verblüffst": "verblüffen",
    "verblüfft": "verblüffen",
    "verblüffte": "verblüffen",
    "verblüfftem": "verblüfft",
    "verblüfften": "verblüffen",
    "verblüffter": "verblüfft",
    "verblüfftere": "verblüfft",
    "verblüffterem": "verblüfft",
    "verblüffteren": "verblüfft",
    "verblüffterer": "verblüfft",
    "verblüffteres": "verblüfft",
    "verblüfftes": "verblüfft",
    "verblüfftest": "verblüffen",
    "verblüffteste": "verblüfft",
    "verblüfftestem": "verblüfft",
    "verblüfftesten": "verblüfft",
    "verblüfftester": "verblüfft",
    "verblüfftestes": "verblüfft",
    "verblüfftet": "verblüffen",
    "verblühe": "verblühen",
    "verblühend": "verblühen",
    "verblühende": "verblühend",
    "verblühendem": "verblühend",
    "verblühenden": "verblühend",
    "verblühender": "verblühend",
    "verblühendere": "verblühend",
    "verblühenderem": "verblühend",
    "verblühenderen": "verblühend",
    "verblühenderer": "verblühend",
    "verblühenderes": "verblühend",
    "verblühendes": "verblühend",
    "verblühendste": "verblühend",
    "verblühendstem": "verblühend",
    "verblühendsten": "verblühend",
    "verblühendster": "verblühend",
    "verblühendstes": "verblühend",
    "verblühest": "verblühen",
    "verblühet": "verblühen",
    "verblühst": "verblühen",
    "verblüht": "verblühen",
    "verblühte": "verblühen",
    "verblühtem": "verblüht",
    "verblühten": "verblühen",
    "verblühter": "verblüht",
    "verblühtere": "verblüht",
    "verblühterem": "verblüht",
    "verblühteren": "verblüht",
    "verblühterer": "verblüht",
    "verblühteres": "verblüht",
    "verblühtes": "verblüht",
    "verblühtest": "verblühen",
    "verblühteste": "verblüht",
    "verblühtestem": "verblüht",
    "verblühtesten": "verblüht",
    "verblühtester": "verblüht",
    "verblühtestes": "verblüht",
    "verblühtet": "verblühen",
    "verbog": "verbiegen",
    "verbogen": "verbiegen",
    "verbogene": "verbogen",
    "verbogenem": "verbogen",
    "verbogenen": "verbogen",
    "verbogener": "verbogen",
    "verbogenere": "verbogen",
    "verbogenerem": "verbogen",
    "verbogeneren": "verbogen",
    "verbogenerer": "verbogen",
    "verbogeneres": "verbogen",
    "verbogenes": "verbogen",
    "verbogenste": "verbogen",
    "verbogenstem": "verbogen",
    "verbogensten": "verbogen",
    "verbogenster": "verbogen",
    "verbogenstes": "verbogen",
    "verbogst": "verbiegen",
    "verbogt": "verbiegen",
    "verbohre": "verbohren",
    "verbohrend": "verbohren",
    "verbohrende": "verbohrend",
    "verbohrendem": "verbohrend",
    "verbohrenden": "verbohrend",
    "verbohrender": "verbohrend",
    "verbohrendere": "verbohrend",
    "verbohrenderem": "verbohrend",
    "verbohrenderen": "verbohrend",
    "verbohrenderer": "verbohrend",
    "verbohrenderes": "verbohrend",
    "verbohrendes": "verbohrend",
    "verbohrendste": "verbohrend",
    "verbohrendstem": "verbohrend",
    "verbohrendsten": "verbohrend",
    "verbohrendster": "verbohrend",
    "verbohrendstes": "verbohrend",
    "verbohrest": "verbohren",
    "verbohret": "verbohren",
    "verbohrst": "verbohren",
    "verbohrt": "verbohren",
    "verbohrte": "verbohren",
    "verbohrtem": "verbohrt",
    "verbohrten": "verbohren",
    "verbohrter": "verbohrt",
    "verbohrtere": "verbohrt",
    "verbohrterem": "verbohrt",
    "verbohrteren": "verbohrt",
    "verbohrterer": "verbohrt",
    "verbohrteres": "verbohrt",
    "verbohrtes": "verbohrt",
    "verbohrtest": "verbohren",
    "verbohrteste": "verbohrt",
    "verbohrtestem": "verbohrt",
    "verbohrtesten": "verbohrt",
    "verbohrtester": "verbohrt",
    "verbohrtestes": "verbohrt",
    "verbohrtet": "verbohren",
    "verborgen": "verbergen",
    "verborgene": "verborgen",
    "verborgenem": "verborgen",
    "verborgenen": "verborgen",
    "verborgener": "verborgen",
    "verborgenere": "verborgen",
    "verborgenerem": "verborgen",
    "verborgeneren": "verborgen",
    "verborgenerer": "verborgen",
    "verborgeneres": "verborgen",
    "verborgenes": "verborgen",
    "verborgenste": "verborgen",
    "verborgenstem": "verborgen",
    "verborgensten": "verborgen",
    "verborgenster": "verborgen",
    "verborgenstes": "verborgen",
    "verbot": "verbieten",
    "verboten": "verbieten",
    "verbotene": "verboten",
    "verbotenem": "verboten",
    "verbotenen": "verboten",
    "verbotener": "verboten",
    "verbotenere": "verboten",
    "verbotenerem": "verboten",
    "verboteneren": "verboten",
    "verbotenerer": "verboten",
    "verboteneres": "verboten",
    "verbotenes": "verboten",
    "verbotenste": "verboten",
    "verbotenstem": "verboten",
    "verbotensten": "verboten",
    "verbotenster": "verboten",
    "verbotenstes": "verboten",
    "verbotest": "verbieten",
    "verbotet": "verbieten",
    "verbrach": "verbrechen",
    "verbrachen": "verbrechen",
    "verbrachst": "verbrechen",
    "verbracht": "verbringen",
    "verbrachte": "verbracht",
    "verbrachtem": "verbracht",
    "verbrachten": "verbracht",
    "verbrachter": "verbracht",
    "verbrachtes": "verbracht",
    "verbrachtest": "verbringen",
    "verbrachtet": "verbringen",
    "verbrannt": "verbrennen",
    "verbrannte": "verbrannt",
    "verbranntem": "verbrannt",
    "verbrannten": "verbrannt",
    "verbrannter": "verbrannt",
    "verbranntere": "verbrannt",
    "verbrannterem": "verbrannt",
    "verbrannteren": "verbrannt",
    "verbrannterer": "verbrannt",
    "verbrannteres": "verbrannt",
    "verbranntes": "verbrannt",
    "verbranntest": "verbrennen",
    "verbrannteste": "verbrannt",
    "verbranntestem": "verbrannt",
    "verbranntesten": "verbrannt",
    "verbranntester": "verbrannt",
    "verbranntestes": "verbrannt",
    "verbranntet": "verbrennen",
    "verbrate": "verbraten",
    "verbratend": "verbraten",
    "verbratende": "verbratend",
    "verbratendem": "verbratend",
    "verbratenden": "verbratend",
    "verbratender": "verbratend",
    "verbratendere": "verbratend",
    "verbratenderem": "verbratend",
    "verbratenderen": "verbratend",
    "verbratenderer": "verbratend",
    "verbratenderes": "verbratend",
    "verbratendes": "verbratend",
    "verbratendste": "verbratend",
    "verbratendstem": "verbratend",
    "verbratendsten": "verbratend",
    "verbratendster": "verbratend",
    "verbratendstes": "verbratend",
    "verbratene": "verbraten",
    "verbratenem": "verbraten",
    "verbratenen": "verbraten",
    "verbratener": "verbraten",
    "verbratenere": "verbraten",
    "verbratenerem": "verbraten",
    "verbrateneren": "verbraten",
    "verbratenerer": "verbraten",
    "verbrateneres": "verbraten",
    "verbratenes": "verbraten",
    "verbratenstem": "verbraten",
    "verbratensten": "verbraten",
    "verbratenster": "verbraten",
    "verbratenstes": "verbraten",
    "verbratest": "verbraten",
    "verbratet": "verbraten",
    "verbrauchend": "verbrauchen",
    "verbrauchende": "verbrauchend",
    "verbrauchendem": "verbrauchend",
    "verbrauchenden": "verbrauchend",
    "verbrauchender": "verbrauchend",
    "verbrauchendere": "verbrauchend",
    "verbrauchenderem": "verbrauchend",
    "verbrauchenderen": "verbrauchend",
    "verbrauchenderer": "verbrauchend",
    "verbrauchenderes": "verbrauchend",
    "verbrauchendes": "verbrauchend",
    "verbrauchendste": "verbrauchend",
    "verbrauchendstem": "verbrauchend",
    "verbrauchendsten": "verbrauchend",
    "verbrauchendster": "verbrauchend",
    "verbrauchendstes": "verbrauchend",
    "verbrauchest": "verbrauchen",
    "verbrauchet": "verbrauchen",
    "verbrauchst": "verbrauchen",
    "verbraucht": "verbrauchen",
    "verbrauchte": "verbrauchen",
    "verbrauchtem": "verbraucht",
    "verbrauchten": "verbrauchen",
    "verbrauchter": "verbraucht",
    "verbrauchtere": "verbraucht",
    "verbrauchterem": "verbraucht",
    "verbrauchteren": "verbraucht",
    "verbrauchterer": "verbraucht",
    "verbrauchteres": "verbraucht",
    "verbrauchtes": "verbraucht",
    "verbrauchtest": "verbrauchen",
    "verbrauchteste": "verbraucht",
    "verbrauchtestem": "verbraucht",
    "verbrauchtesten": "verbraucht",
    "verbrauchtester": "verbraucht",
    "verbrauchtestes": "verbraucht",
    "verbrauchtet": "verbrauchen",
    "verbreche": "verbrechen",
    "verbrechend": "verbrechen",
    "verbrechende": "verbrechend",
    "verbrechendem": "verbrechend",
    "verbrechenden": "verbrechend",
    "verbrechender": "verbrechend",
    "verbrechendes": "verbrechend",
    "verbrecherischem": "verbrecherisch",
    "verbrecherischen": "verbrecherisch",
    "verbrecherischer": "verbrecherisch",
    "verbrecherisches": "verbrecherisch",
    "verbrechest": "verbrechen",
    "verbrechet": "verbrechen",
    "verbrecht": "verbrechen",
    "verbreite": "verbreiten",
    "verbreitend": "verbreiten",
    "verbreitende": "verbreitend",
    "verbreitendem": "verbreitend",
    "verbreitenden": "verbreitend",
    "verbreitender": "verbreitend",
    "verbreitendes": "verbreitend",
    "verbreitere": "verbreitern",
    "verbreiternd": "verbreitern",
    "verbreiternde": "verbreiternd",
    "verbreiterndem": "verbreiternd",
    "verbreiternden": "verbreiternd",
    "verbreiternder": "verbreiternd",
    "verbreiterndes": "verbreiternd",
    "verbreiterst": "verbreitern",
    "verbreitert": "verbreitern",
    "verbreiterte": "verbreitern",
    "verbreitertem": "verbreitert",
    "verbreiterten": "verbreitern",
    "verbreiterter": "verbreitert",
    "verbreitertes": "verbreitert",
    "verbreitertest": "verbreitern",
    "verbreitertet": "verbreitern",
    "verbreitest": "verbreiten",
    "verbreitet": "verbreiten",
    "verbreitete": "verbreiten",
    "verbreitetem": "verbreitet",
    "verbreiteten": "verbreiten",
    "verbreiteter": "verbreitet",
    "verbreitetere": "verbreitet",
    "verbreiteterem": "verbreitet",
    "verbreiteteren": "verbreitet",
    "verbreiteterer": "verbreitet",
    "verbreiteteres": "verbreitet",
    "verbreitetes": "verbreitet",
    "verbreitetest": "verbreiten",
    "verbreiteteste": "verbreitet",
    "verbreitetestem": "verbreitet",
    "verbreitetesten": "verbreitet",
    "verbreitetester": "verbreitet",
    "verbreitetestes": "verbreitet",
    "verbreitetet": "verbreiten",
    "verbremse": "verbremsen",
    "verbremsend": "verbremsen",
    "verbremsende": "verbremsend",
    "verbremsendem": "verbremsend",
    "verbremsenden": "verbremsend",
    "verbremsender": "verbremsend",
    "verbremsendes": "verbremsend",
    "verbremsest": "verbremsen",
    "verbremset": "verbremsen",
    "verbremst": "verbremsen",
    "verbremste": "verbremsen",
    "verbremstem": "verbremst",
    "verbremsten": "verbremsen",
    "verbremster": "verbremst",
    "verbremstes": "verbremst",
    "verbremstest": "verbremsen",
    "verbremstet": "verbremsen",
    "verbrenne": "verbrennen",
    "verbrennend": "verbrennen",
    "verbrennende": "verbrennend",
    "verbrennendem": "verbrennend",
    "verbrennenden": "verbrennend",
    "verbrennender": "verbrennend",
    "verbrennendere": "verbrennend",
    "verbrennenderem": "verbrennend",
    "verbrennenderen": "verbrennend",
    "verbrennenderer": "verbrennend",
    "verbrennenderes": "verbrennend",
    "verbrennendes": "verbrennend",
    "verbrennendste": "verbrennend",
    "verbrennendstem": "verbrennend",
    "verbrennendsten": "verbrennend",
    "verbrennendster": "verbrennend",
    "verbrennendstes": "verbrennend",
    "verbrennest": "verbrennen",
    "verbrennet": "verbrennen",
    "verbrennst": "verbrennen",
    "verbrennt": "verbrennen",
    "verbrich": "verbrechen",
    "verbrichst": "verbrechen",
    "verbricht": "verbrechen",
    "verbriet": "verbraten",
    "verbriete": "verbraten",
    "verbrieten": "verbraten",
    "verbrietest": "verbraten",
    "verbrietet": "verbraten",
    "verbringe": "verbringen",
    "verbringend": "verbringen",
    "verbringende": "verbringend",
    "verbringendem": "verbringend",
    "verbringenden": "verbringend",
    "verbringender": "verbringend",
    "verbringendes": "verbringend",
    "verbringest": "verbringen",
    "verbringet": "verbringen",
    "verbringst": "verbringen",
    "verbringt": "verbringen",
    "verbrochen": "verbrechen",
    "verbrochene": "verbrochen",
    "verbrochenem": "verbrochen",
    "verbrochenen": "verbrochen",
    "verbrochener": "verbrochen",
    "verbrochenes": "verbrochen",
    "verbräche": "verbrechen",
    "verbrächen": "verbrechen",
    "verbrächest": "verbrechen",
    "verbrächet": "verbrechen",
    "verbrächte": "verbringen",
    "verbrächten": "verbringen",
    "verbrächtest": "verbringen",
    "verbrächtet": "verbringen",
    "verbrät": "verbraten",
    "verbrätst": "verbraten",
    "verbrüdere": "verbrüdern",
    "verbrüdernd": "verbrüdern",
    "verbrüdernde": "verbrüdernd",
    "verbrüderndem": "verbrüdernd",
    "verbrüdernden": "verbrüdernd",
    "verbrüdernder": "verbrüdernd",
    "verbrüderndes": "verbrüdernd",
    "verbrüderst": "verbrüdern",
    "verbrüdert": "verbrüdern",
    "verbrüderte": "verbrüdern",
    "verbrüdertem": "verbrüdert",
    "verbrüderten": "verbrüdern",
    "verbrüderter": "verbrüdert",
    "verbrüdertes": "verbrüdert",
    "verbrüdertest": "verbrüdern",
    "verbrüdertet": "verbrüdern",
    "verbrühe": "verbrühen",
    "verbrühend": "verbrühen",
    "verbrühende": "verbrühend",
    "verbrühendem": "verbrühend",
    "verbrühenden": "verbrühend",
    "verbrühender": "verbrühend",
    "verbrühendes": "verbrühend",
    "verbrühest": "verbrühen",
    "verbrühet": "verbrühen",
    "verbrühst": "verbrühen",
    "verbrüht": "verbrühen",
    "verbrühte": "verbrühen",
    "verbrühtem": "verbrüht",
    "verbrühten": "verbrühen",
    "verbrühter": "verbrüht",
    "verbrühtes": "verbrüht",
    "verbrühtest": "verbrühen",
    "verbrühtet": "verbrühen",
    "verbuche": "verbuchen",
    "verbuchend": "verbuchen",
    "verbuchende": "verbuchend",
    "verbuchendem": "verbuchend",
    "verbuchenden": "verbuchend",
    "verbuchender": "verbuchend",
    "verbuchendes": "verbuchend",
    "verbuchest": "verbuchen",
    "verbuchet": "verbuchen",
    "verbuchst": "verbuchen",
    "verbucht": "verbuchen",
    "verbuchte": "verbuchen",
    "verbuchtem": "verbucht",
    "verbuchten": "verbuchen",
    "verbuchter": "verbucht",
    "verbuchtes": "verbucht",
    "verbuchtest": "verbuchen",
    "verbuchtet": "verbuchen",
    "verbuddele": "verbuddeln",
    "verbuddelnd": "verbuddeln",
    "verbuddelnde": "verbuddelnd",
    "verbuddelndem": "verbuddelnd",
    "verbuddelnden": "verbuddelnd",
    "verbuddelnder": "verbuddelnd",
    "verbuddelndere": "verbuddelnd",
    "verbuddelnderem": "verbuddelnd",
    "verbuddelnderen": "verbuddelnd",
    "verbuddelnderer": "verbuddelnd",
    "verbuddelnderes": "verbuddelnd",
    "verbuddelndes": "verbuddelnd",
    "verbuddelndste": "verbuddelnd",
    "verbuddelndstem": "verbuddelnd",
    "verbuddelndsten": "verbuddelnd",
    "verbuddelndster": "verbuddelnd",
    "verbuddelndstes": "verbuddelnd",
    "verbuddelst": "verbuddeln",
    "verbuddelt": "verbuddeln",
    "verbuddelte": "verbuddeln",
    "verbuddeltem": "verbuddelt",
    "verbuddelten": "verbuddeln",
    "verbuddelter": "verbuddelt",
    "verbuddeltere": "verbuddelt",
    "verbuddelterem": "verbuddelt",
    "verbuddelteren": "verbuddelt",
    "verbuddelterer": "verbuddelt",
    "verbuddelteres": "verbuddelt",
    "verbuddeltes": "verbuddelt",
    "verbuddeltest": "verbuddeln",
    "verbuddelteste": "verbuddelt",
    "verbuddeltestem": "verbuddelt",
    "verbuddeltesten": "verbuddelt",
    "verbuddeltester": "verbuddelt",
    "verbuddeltestes": "verbuddelt",
    "verbuddeltet": "verbuddeln",
    "verbuddle": "verbuddeln",
    "verbummele": "verbummeln",
    "verbummelnd": "verbummeln",
    "verbummelnde": "verbummelnd",
    "verbummelndem": "verbummelnd",
    "verbummelnden": "verbummelnd",
    "verbummelnder": "verbummelnd",
    "verbummelndes": "verbummelnd",
    "verbummelst": "verbummeln",
    "verbummelt": "verbummeln",
    "verbummelte": "verbummeln",
    "verbummeltem": "verbummelt",
    "verbummelten": "verbummeln",
    "verbummelter": "verbummelt",
    "verbummeltes": "verbummelt",
    "verbummeltest": "verbummeln",
    "verbummeltet": "verbummeln",
    "verbummle": "verbummeln",
    "verbunden": "verbinden",
    "verbundene": "verbunden",
    "verbundenem": "verbunden",
    "verbundenen": "verbunden",
    "verbundener": "verbunden",
    "verbundenere": "verbunden",
    "verbundenerem": "verbunden",
    "verbundeneren": "verbunden",
    "verbundenerer": "verbunden",
    "verbundeneres": "verbunden",
    "verbundenes": "verbunden",
    "verbundenstem": "verbunden",
    "verbundensten": "verbunden",
    "verbundenster": "verbunden",
    "verbundenstes": "verbunden",
    "verbändest": "verbinden",
    "verbändet": "verbinden",
    "verbärge": "verbergen",
    "verbärgen": "verbergen",
    "verbärgest": "verbergen",
    "verbärget": "verbergen",
    "verböge": "verbiegen",
    "verbögen": "verbiegen",
    "verbögest": "verbiegen",
    "verböget": "verbiegen",
    "verböllere": "verböllern",
    "verböllernd": "verböllern",
    "verböllernde": "verböllernd",
    "verböllerndem": "verböllernd",
    "verböllernden": "verböllernd",
    "verböllernder": "verböllernd",
    "verböllerndere": "verböllernd",
    "verböllernderem": "verböllernd",
    "verböllernderen": "verböllernd",
    "verböllernderer": "verböllernd",
    "verböllernderes": "verböllernd",
    "verböllerndes": "verböllernd",
    "verböllerndste": "verböllernd",
    "verböllerndstem": "verböllernd",
    "verböllerndsten": "verböllernd",
    "verböllerndster": "verböllernd",
    "verböllerndstes": "verböllernd",
    "verböllerst": "verböllern",
    "verböllert": "verböllern",
    "verböllerte": "verböllern",
    "verböllertem": "verböllert",
    "verböllerten": "verböllern",
    "verböllerter": "verböllert",
    "verböllertere": "verböllert",
    "verböllerterem": "verböllert",
    "verböllerteren": "verböllert",
    "verböllerterer": "verböllert",
    "verböllerteres": "verböllert",
    "verböllertes": "verböllert",
    "verböllertest": "verböllern",
    "verböllerteste": "verböllert",
    "verböllertestem": "verböllert",
    "verböllertesten": "verböllert",
    "verböllertester": "verböllert",
    "verböllertestes": "verböllert",
    "verböllertet": "verböllern",
    "verböte": "verbieten",
    "verböten": "verbieten",
    "verbötest": "verbieten",
    "verbötet": "verbieten",
    "verbünde": "verbünden",
    "verbündend": "verbünden",
    "verbündende": "verbündend",
    "verbündendem": "verbündend",
    "verbündenden": "verbündend",
    "verbündender": "verbündend",
    "verbündendes": "verbündend",
    "verbündest": "verbünden",
    "verbündet": "verbünden",
    "verbündete": "verbünden",
    "verbündetem": "verbündet",
    "verbündeten": "verbünden",
    "verbündeter": "verbündet",
    "verbündetes": "verbündet",
    "verbündetest": "verbünden",
    "verbündetet": "verbünden",
    "verbürge": "verbürgen",
    "verbürgend": "verbürgen",
    "verbürgende": "verbürgend",
    "verbürgendem": "verbürgend",
    "verbürgenden": "verbürgend",
    "verbürgender": "verbürgend",
    "verbürgendes": "verbürgend",
    "verbürgest": "verbürgen",
    "verbürget": "verbürgen",
    "verbürgst": "verbürgen",
    "verbürgt": "verbürgen",
    "verbürgte": "verbürgen",
    "verbürgtem": "verbürgt",
    "verbürgten": "verbürgen",
    "verbürgter": "verbürgt",
    "verbürgtes": "verbürgt",
    "verbürgtest": "verbürgen",
    "verbürgtet": "verbürgen",
    "verbüße": "verbüßen",
    "verbüßend": "verbüßen",
    "verbüßende": "verbüßend",
    "verbüßendem": "verbüßend",
    "verbüßenden": "verbüßend",
    "verbüßender": "verbüßend",
    "verbüßendes": "verbüßend",
    "verbüßest": "verbüßen",
    "verbüßet": "verbüßen",
    "verbüßt": "verbüßen",
    "verbüßte": "verbüßen",
    "verbüßtem": "verbüßt",
    "verbüßten": "verbüßen",
    "verbüßter": "verbüßt",
    "verbüßtes": "verbüßt",
    "verbüßtest": "verbüßen",
    "verbüßtet": "verbüßen",
    "verdacht": "verdenken",
    "verdachte": "verdenken",
    "verdachtem": "verdacht",
    "verdachten": "verdacht",
    "verdachter": "verdacht",
    "verdachtes": "verdacht",
    "verdachtest": "verdenken",
    "verdachtet": "verdenken",
    "verdamme": "verdammen",
    "verdammend": "verdammen",
    "verdammende": "verdammend",
    "verdammendem": "verdammend",
    "verdammenden": "verdammend",
    "verdammender": "verdammend",
    "verdammendes": "verdammend",
    "verdammest": "verdammen",
    "verdammet": "verdammen",
    "verdammst": "verdammen",
    "verdammt": "verdammen",
    "verdammte": "verdammen",
    "verdammtem": "verdammt",
    "verdammten": "verdammen",
    "verdammter": "verdammt",
    "verdammtere": "verdammt",
    "verdammterem": "verdammt",
    "verdammteren": "verdammt",
    "verdammterer": "verdammt",
    "verdammteres": "verdammt",
    "verdammtes": "verdammt",
    "verdammtest": "verdammen",
    "verdammteste": "verdammt",
    "verdammtestem": "verdammt",
    "verdammtesten": "verdammt",
    "verdammtester": "verdammt",
    "verdammtestes": "verdammt",
    "verdammtet": "verdammen",
    "verdampfe": "verdampfen",
    "verdampfend": "verdampfen",
    "verdampfende": "verdampfend",
    "verdampfendem": "verdampfend",
    "verdampfenden": "verdampfend",
    "verdampfender": "verdampfend",
    "verdampfendere": "verdampfend",
    "verdampfenderem": "verdampfend",
    "verdampfenderen": "verdampfend",
    "verdampfenderer": "verdampfend",
    "verdampfenderes": "verdampfend",
    "verdampfendes": "verdampfend",
    "verdampfendste": "verdampfend",
    "verdampfendstem": "verdampfend",
    "verdampfendsten": "verdampfend",
    "verdampfendster": "verdampfend",
    "verdampfendstes": "verdampfend",
    "verdampfest": "verdampfen",
    "verdampfet": "verdampfen",
    "verdampfst": "verdampfen",
    "verdampft": "verdampfen",
    "verdampfte": "verdampfen",
    "verdampftem": "verdampft",
    "verdampften": "verdampfen",
    "verdampfter": "verdampft",
    "verdampftere": "verdampft",
    "verdampfterem": "verdampft",
    "verdampfteren": "verdampft",
    "verdampfterer": "verdampft",
    "verdampfteres": "verdampft",
    "verdampftes": "verdampft",
    "verdampftest": "verdampfen",
    "verdampfteste": "verdampft",
    "verdampftestem": "verdampft",
    "verdampftesten": "verdampft",
    "verdampftester": "verdampft",
    "verdampftestes": "verdampft",
    "verdampftet": "verdampfen",
    "verdanke": "verdanken",
    "verdankend": "verdanken",
    "verdankende": "verdankend",
    "verdankendem": "verdankend",
    "verdankenden": "verdankend",
    "verdankender": "verdankend",
    "verdankendes": "verdankend",
    "verdankest": "verdanken",
    "verdanket": "verdanken",
    "verdankst": "verdanken",
    "verdankt": "verdanken",
    "verdankte": "verdanken",
    "verdanktem": "verdankt",
    "verdankten": "verdanken",
    "verdankter": "verdankt",
    "verdanktes": "verdankt",
    "verdanktest": "verdanken",
    "verdanktet": "verdanken",
    "verdarb": "verderben",
    "verdarben": "verderben",
    "verdarbst": "verderben",
    "verdarbt": "verderben",
    "verdatterte": "verdattert",
    "verdattertem": "verdattert",
    "verdatterten": "verdattert",
    "verdatterter": "verdattert",
    "verdattertere": "verdattert",
    "verdatterterem": "verdattert",
    "verdatterteren": "verdattert",
    "verdatterterer": "verdattert",
    "verdatterteres": "verdattert",
    "verdattertes": "verdattert",
    "verdatterteste": "verdattert",
    "verdattertestem": "verdattert",
    "verdattertesten": "verdattert",
    "verdattertester": "verdattert",
    "verdattertestes": "verdattert",
    "verdaue": "verdauen",
    "verdauend": "verdauen",
    "verdauende": "verdauend",
    "verdauendem": "verdauend",
    "verdauenden": "verdauend",
    "verdauender": "verdauend",
    "verdauendes": "verdauend",
    "verdauest": "verdauen",
    "verdauet": "verdauen",
    "verdauliche": "verdaulich",
    "verdaulichem": "verdaulich",
    "verdaulichen": "verdaulich",
    "verdaulicher": "verdaulich",
    "verdauliches": "verdaulich",
    "verdaust": "verdauen",
    "verdaut": "verdauen",
    "verdaute": "verdauen",
    "verdautem": "verdaut",
    "verdauten": "verdauen",
    "verdauter": "verdaut",
    "verdautes": "verdaut",
    "verdautest": "verdauen",
    "verdautet": "verdauen",
    "verdeckend": "verdecken",
    "verdeckende": "verdeckend",
    "verdeckendem": "verdeckend",
    "verdeckenden": "verdeckend",
    "verdeckender": "verdeckend",
    "verdeckendere": "verdeckend",
    "verdeckenderem": "verdeckend",
    "verdeckenderen": "verdeckend",
    "verdeckenderer": "verdeckend",
    "verdeckenderes": "verdeckend",
    "verdeckendes": "verdeckend",
    "verdeckendste": "verdeckend",
    "verdeckendstem": "verdeckend",
    "verdeckendsten": "verdeckend",
    "verdeckendster": "verdeckend",
    "verdeckendstes": "verdeckend",
    "verdeckest": "verdecken",
    "verdecket": "verdecken",
    "verdeckst": "verdecken",
    "verdeckt": "verdecken",
    "verdeckte": "verdecken",
    "verdecktem": "verdeckt",
    "verdeckten": "verdecken",
    "verdeckter": "verdeckt",
    "verdecktere": "verdeckt",
    "verdeckterem": "verdeckt",
    "verdeckteren": "verdeckt",
    "verdeckterer": "verdeckt",
    "verdeckteres": "verdeckt",
    "verdecktes": "verdeckt",
    "verdecktest": "verdecken",
    "verdeckteste": "verdeckt",
    "verdecktestem": "verdeckt",
    "verdecktesten": "verdeckt",
    "verdecktester": "verdeckt",
    "verdecktestes": "verdeckt",
    "verdecktet": "verdecken",
    "verdenke": "verdenken",
    "verdenkend": "verdenken",
    "verdenkende": "verdenkend",
    "verdenkendem": "verdenkend",
    "verdenkenden": "verdenkend",
    "verdenkender": "verdenkend",
    "verdenkendes": "verdenkend",
    "verdenkest": "verdenken",
    "verdenket": "verdenken",
    "verdenkst": "verdenken",
    "verdenkt": "verdenken",
    "verderbe": "verderben",
    "verderbend": "verderben",
    "verderbende": "verderbend",
    "verderbendem": "verderbend",
    "verderbenden": "verderbend",
    "verderbender": "verderbend",
    "verderbendes": "verderbend",
    "verderbest": "verderben",
    "verderbet": "verderben",
    "verderbliche": "verderblich",
    "verderblichem": "verderblich",
    "verderblichen": "verderblich",
    "verderblicher": "verderblich",
    "verderblichere": "verderblich",
    "verderblicherem": "verderblich",
    "verderblicheren": "verderblich",
    "verderblicherer": "verderblich",
    "verderblicheres": "verderblich",
    "verderbliches": "verderblich",
    "verderblichste": "verderblich",
    "verderblichstem": "verderblich",
    "verderblichsten": "verderblich",
    "verderblichster": "verderblich",
    "verderblichstes": "verderblich",
    "verderbt": "verderben",
    "verdeutliche": "verdeutlichen",
    "verdeutlichend": "verdeutlichen",
    "verdeutlichende": "verdeutlichend",
    "verdeutlichendem": "verdeutlichend",
    "verdeutlichenden": "verdeutlichend",
    "verdeutlichender": "verdeutlichend",
    "verdeutlichendes": "verdeutlichend",
    "verdeutlichest": "verdeutlichen",
    "verdeutlichet": "verdeutlichen",
    "verdeutlichst": "verdeutlichen",
    "verdeutlicht": "verdeutlichen",
    "verdeutlichte": "verdeutlichen",
    "verdeutlichtem": "verdeutlicht",
    "verdeutlichten": "verdeutlichen",
    "verdeutlichter": "verdeutlicht",
    "verdeutlichtes": "verdeutlicht",
    "verdeutlichtest": "verdeutlichen",
    "verdeutlichtet": "verdeutlichen",
    "verdichte": "verdichten",
    "verdichtend": "verdichten",
    "verdichtende": "verdichtend",
    "verdichtendem": "verdichtend",
    "verdichtenden": "verdichtend",
    "verdichtender": "verdichtend",
    "verdichtendes": "verdichtend",
    "verdichtest": "verdichten",
    "verdichtet": "verdichten",
    "verdichtete": "verdichten",
    "verdichtetem": "verdichtet",
    "verdichteten": "verdichten",
    "verdichteter": "verdichtet",
    "verdichtetes": "verdichtet",
    "verdichtetest": "verdichten",
    "verdichtetet": "verdichten",
    "verdiene": "verdienen",
    "verdienend": "verdienen",
    "verdienende": "verdienend",
    "verdienendem": "verdienend",
    "verdienenden": "verdienend",
    "verdienender": "verdienend",
    "verdienendes": "verdienend",
    "verdienest": "verdienen",
    "verdienet": "verdienen",
    "verdienst": "verdienen",
    "verdient": "verdienen",
    "verdiente": "verdienen",
    "verdientem": "verdient",
    "verdienten": "verdienen",
    "verdienter": "verdient",
    "verdientere": "verdient",
    "verdienterem": "verdient",
    "verdienteren": "verdient",
    "verdienterer": "verdient",
    "verdienteres": "verdient",
    "verdientes": "verdient",
    "verdientest": "verdienen",
    "verdienteste": "verdient",
    "verdientestem": "verdient",
    "verdientesten": "verdient",
    "verdientester": "verdient",
    "verdientestes": "verdient",
    "verdientet": "verdienen",
    "verdinge": "verdingen",
    "verdingend": "verdingen",
    "verdingende": "verdingend",
    "verdingendem": "verdingend",
    "verdingenden": "verdingend",
    "verdingender": "verdingend",
    "verdingendes": "verdingend",
    "verdingest": "verdingen",
    "verdinget": "verdingen",
    "verdingst": "verdingen",
    "verdingt": "verdingen",
    "verdingte": "verdingen",
    "verdingtem": "verdingt",
    "verdingten": "verdingen",
    "verdingter": "verdingt",
    "verdingtes": "verdingt",
    "verdingtest": "verdingen",
    "verdingtet": "verdingen",
    "verdirb": "verderben",
    "verdirbst": "verderben",
    "verdirbt": "verderben",
    "verdonnere": "verdonnern",
    "verdonnernd": "verdonnern",
    "verdonnernde": "verdonnernd",
    "verdonnerndem": "verdonnernd",
    "verdonnernden": "verdonnernd",
    "verdonnernder": "verdonnernd",
    "verdonnerndere": "verdonnernd",
    "verdonnernderem": "verdonnernd",
    "verdonnernderen": "verdonnernd",
    "verdonnernderer": "verdonnernd",
    "verdonnernderes": "verdonnernd",
    "verdonnerndes": "verdonnernd",
    "verdonnerndste": "verdonnernd",
    "verdonnerndstem": "verdonnernd",
    "verdonnerndsten": "verdonnernd",
    "verdonnerndster": "verdonnernd",
    "verdonnerndstes": "verdonnernd",
    "verdonnerst": "verdonnern",
    "verdonnert": "verdonnern",
    "verdonnerte": "verdonnern",
    "verdonnertem": "verdonnert",
    "verdonnerten": "verdonnern",
    "verdonnerter": "verdonnert",
    "verdonnertes": "verdonnert",
    "verdonnertest": "verdonnern",
    "verdonnertet": "verdonnern",
    "verdoppele": "verdoppeln",
    "verdoppelnd": "verdoppeln",
    "verdoppelnde": "verdoppelnd",
    "verdoppelndem": "verdoppelnd",
    "verdoppelnden": "verdoppelnd",
    "verdoppelnder": "verdoppelnd",
    "verdoppelndes": "verdoppelnd",
    "verdoppelst": "verdoppeln",
    "verdoppelt": "verdoppeln",
    "verdoppelte": "verdoppeln",
    "verdoppeltem": "verdoppelt",
    "verdoppelten": "verdoppeln",
    "verdoppelter": "verdoppelt",
    "verdoppeltes": "verdoppelt",
    "verdoppeltest": "verdoppeln",
    "verdoppeltet": "verdoppeln",
    "verdopple": "verdoppeln",
    "verdorben": "verderben",
    "verdorbene": "verdorben",
    "verdorbenem": "verdorben",
    "verdorbenen": "verdorben",
    "verdorbener": "verdorben",
    "verdorbenere": "verdorben",
    "verdorbenerem": "verdorben",
    "verdorbeneren": "verdorben",
    "verdorbenerer": "verdorben",
    "verdorbeneres": "verdorben",
    "verdorbenes": "verdorben",
    "verdorbenste": "verdorben",
    "verdorbenstem": "verdorben",
    "verdorbensten": "verdorben",
    "verdorbenster": "verdorben",
    "verdorbenstes": "verdorben",
    "verdrahte": "verdrahten",
    "verdrahtend": "verdrahten",
    "verdrahtende": "verdrahtend",
    "verdrahtendem": "verdrahtend",
    "verdrahtenden": "verdrahtend",
    "verdrahtender": "verdrahtend",
    "verdrahtendere": "verdrahtend",
    "verdrahtenderem": "verdrahtend",
    "verdrahtenderen": "verdrahtend",
    "verdrahtenderer": "verdrahtend",
    "verdrahtenderes": "verdrahtend",
    "verdrahtendes": "verdrahtend",
    "verdrahtendste": "verdrahtend",
    "verdrahtendstem": "verdrahtend",
    "verdrahtendsten": "verdrahtend",
    "verdrahtendster": "verdrahtend",
    "verdrahtendstes": "verdrahtend",
    "verdrahtest": "verdrahten",
    "verdrahtet": "verdrahten",
    "verdrahtete": "verdrahten",
    "verdrahtetem": "verdrahtet",
    "verdrahteten": "verdrahten",
    "verdrahteter": "verdrahtet",
    "verdrahtetere": "verdrahtet",
    "verdrahteterem": "verdrahtet",
    "verdrahteteren": "verdrahtet",
    "verdrahteterer": "verdrahtet",
    "verdrahteteres": "verdrahtet",
    "verdrahtetes": "verdrahtet",
    "verdrahtetest": "verdrahten",
    "verdrahteteste": "verdrahtet",
    "verdrahtetestem": "verdrahtet",
    "verdrahtetesten": "verdrahtet",
    "verdrahtetester": "verdrahtet",
    "verdrahtetestes": "verdrahtet",
    "verdrahtetet": "verdrahten",
    "verdrecke": "verdrecken",
    "verdreckend": "verdrecken",
    "verdreckende": "verdreckend",
    "verdreckendem": "verdreckend",
    "verdreckenden": "verdreckend",
    "verdreckender": "verdreckend",
    "verdreckendere": "verdreckend",
    "verdreckenderem": "verdreckend",
    "verdreckenderen": "verdreckend",
    "verdreckenderer": "verdreckend",
    "verdreckenderes": "verdreckend",
    "verdreckendes": "verdreckend",
    "verdreckendste": "verdreckend",
    "verdreckendstem": "verdreckend",
    "verdreckendsten": "verdreckend",
    "verdreckendster": "verdreckend",
    "verdreckendstes": "verdreckend",
    "verdreckest": "verdrecken",
    "verdrecket": "verdrecken",
    "verdreckst": "verdrecken",
    "verdreckt": "verdrecken",
    "verdreckte": "verdrecken",
    "verdrecktem": "verdreckt",
    "verdreckten": "verdrecken",
    "verdreckter": "verdreckt",
    "verdrecktere": "verdreckt",
    "verdreckterem": "verdreckt",
    "verdreckteren": "verdreckt",
    "verdreckterer": "verdreckt",
    "verdreckteres": "verdreckt",
    "verdrecktes": "verdreckt",
    "verdrecktest": "verdrecken",
    "verdreckteste": "verdreckt",
    "verdrecktestem": "verdreckt",
    "verdrecktesten": "verdreckt",
    "verdrecktester": "verdreckt",
    "verdrecktestes": "verdreckt",
    "verdrecktet": "verdrecken",
    "verdrehe": "verdrehen",
    "verdrehend": "verdrehen",
    "verdrehende": "verdrehend",
    "verdrehendem": "verdrehend",
    "verdrehenden": "verdrehend",
    "verdrehender": "verdrehend",
    "verdrehendes": "verdrehend",
    "verdrehest": "verdrehen",
    "verdrehet": "verdrehen",
    "verdrehst": "verdrehen",
    "verdreht": "verdrehen",
    "verdrehte": "verdrehen",
    "verdrehtem": "verdreht",
    "verdrehten": "verdrehen",
    "verdrehter": "verdreht",
    "verdrehtere": "verdreht",
    "verdrehterem": "verdreht",
    "verdrehteren": "verdreht",
    "verdrehterer": "verdreht",
    "verdrehteres": "verdreht",
    "verdrehtes": "verdreht",
    "verdrehtest": "verdrehen",
    "verdrehteste": "verdreht",
    "verdrehtestem": "verdreht",
    "verdrehtesten": "verdreht",
    "verdrehtester": "verdreht",
    "verdrehtestes": "verdreht",
    "verdrehtet": "verdrehen",
    "verdreifache": "verdreifachen",
    "verdreifachend": "verdreifachen",
    "verdreifachende": "verdreifachend",
    "verdreifachendem": "verdreifachend",
    "verdreifachenden": "verdreifachend",
    "verdreifachender": "verdreifachend",
    "verdreifachendes": "verdreifachend",
    "verdreifachest": "verdreifachen",
    "verdreifachet": "verdreifachen",
    "verdreifachst": "verdreifachen",
    "verdreifacht": "verdreifachen",
    "verdreifachte": "verdreifachen",
    "verdreifachtem": "verdreifacht",
    "verdreifachten": "verdreifachen",
    "verdreifachter": "verdreifacht",
    "verdreifachtes": "verdreifacht",
    "verdreifachtest": "verdreifachen",
    "verdreifachtet": "verdreifachen",
    "verdresche": "verdreschen",
    "verdreschend": "verdreschen",
    "verdreschende": "verdreschend",
    "verdreschendem": "verdreschend",
    "verdreschenden": "verdreschend",
    "verdreschender": "verdreschend",
    "verdreschendes": "verdreschend",
    "verdreschest": "verdreschen",
    "verdreschet": "verdreschen",
    "verdrescht": "verdreschen",
    "verdribbele": "verdribbeln",
    "verdribbelnd": "verdribbeln",
    "verdribbelnde": "verdribbelnd",
    "verdribbelndem": "verdribbelnd",
    "verdribbelnden": "verdribbelnd",
    "verdribbelnder": "verdribbelnd",
    "verdribbelndes": "verdribbelnd",
    "verdribbelst": "verdribbeln",
    "verdribbelt": "verdribbeln",
    "verdribbelte": "verdribbeln",
    "verdribbeltem": "verdribbelt",
    "verdribbelten": "verdribbeln",
    "verdribbelter": "verdribbelt",
    "verdribbeltes": "verdribbelt",
    "verdribbeltest": "verdribbeln",
    "verdribbeltet": "verdribbeln",
    "verdribble": "verdribbeln",
    "verdrieße": "verdrießen",
    "verdrießend": "verdrießen",
    "verdrießende": "verdrießend",
    "verdrießendem": "verdrießend",
    "verdrießenden": "verdrießend",
    "verdrießender": "verdrießend",
    "verdrießendes": "verdrießend",
    "verdrießest": "verdrießen",
    "verdrießet": "verdrießen",
    "verdrießt": "verdrießen",
    "verdrisch": "verdreschen",
    "verdrischst": "verdreschen",
    "verdrischt": "verdreschen",
    "verdrosch": "verdreschen",
    "verdroschen": "verdreschen",
    "verdroschene": "verdroschen",
    "verdroschenem": "verdroschen",
    "verdroschenen": "verdroschen",
    "verdroschener": "verdroschen",
    "verdroschenere": "verdroschen",
    "verdroschenerem": "verdroschen",
    "verdroscheneren": "verdroschen",
    "verdroschenerer": "verdroschen",
    "verdroscheneres": "verdroschen",
    "verdroschenes": "verdroschen",
    "verdroschenste": "verdroschen",
    "verdroschenstem": "verdroschen",
    "verdroschensten": "verdroschen",
    "verdroschenster": "verdroschen",
    "verdroschenstes": "verdroschen",
    "verdroschst": "verdreschen",
    "verdroscht": "verdreschen",
    "verdrossen": "verdrießen",
    "verdrossene": "verdrossen",
    "verdrossenem": "verdrossen",
    "verdrossenen": "verdrossen",
    "verdrossener": "verdrossen",
    "verdrossenere": "verdrossen",
    "verdrossenerem": "verdrossen",
    "verdrosseneren": "verdrossen",
    "verdrossenerer": "verdrossen",
    "verdrosseneres": "verdrossen",
    "verdrossenes": "verdrossen",
    "verdrossenste": "verdrossen",
    "verdrossenstem": "verdrossen",
    "verdrossensten": "verdrossen",
    "verdrossenster": "verdrossen",
    "verdrossenstes": "verdrossen",
    "verdroß": "verdrießen",
    "verdroßt": "verdrießen",
    "verdränge": "verdrängen",
    "verdrängend": "verdrängen",
    "verdrängende": "verdrängend",
    "verdrängendem": "verdrängend",
    "verdrängenden": "verdrängend",
    "verdrängender": "verdrängend",
    "verdrängendes": "verdrängend",
    "verdrängest": "verdrängen",
    "verdränget": "verdrängen",
    "verdrängst": "verdrängen",
    "verdrängt": "verdrängen",
    "verdrängte": "verdrängen",
    "verdrängtem": "verdrängt",
    "verdrängten": "verdrängen",
    "verdrängter": "verdrängt",
    "verdrängtes": "verdrängt",
    "verdrängtest": "verdrängen",
    "verdrängtet": "verdrängen",
    "verdrösche": "verdreschen",
    "verdröschen": "verdreschen",
    "verdröschest": "verdreschen",
    "verdröschet": "verdreschen",
    "verdrösse": "verdrießen",
    "verdrössen": "verdrießen",
    "verdrössest": "verdrießen",
    "verdrösset": "verdrießen",
    "verdrücke": "verdrücken",
    "verdrückend": "verdrücken",
    "verdrückende": "verdrückend",
    "verdrückendem": "verdrückend",
    "verdrückenden": "verdrückend",
    "verdrückender": "verdrückend",
    "verdrückendes": "verdrückend",
    "verdrückest": "verdrücken",
    "verdrücket": "verdrücken",
    "verdrückst": "verdrücken",
    "verdrückt": "verdrücken",
    "verdrückte": "verdrücken",
    "verdrücktem": "verdrückt",
    "verdrückten": "verdrücken",
    "verdrückter": "verdrückt",
    "verdrücktes": "verdrückt",
    "verdrücktest": "verdrücken",
    "verdrücktet": "verdrücken",
    "verdufte": "verduften",
    "verduftend": "verduften",
    "verduftende": "verduftend",
    "verduftendem": "verduftend",
    "verduftenden": "verduftend",
    "verduftender": "verduftend",
    "verduftendere": "verduftend",
    "verduftenderem": "verduftend",
    "verduftenderen": "verduftend",
    "verduftenderer": "verduftend",
    "verduftenderes": "verduftend",
    "verduftendes": "verduftend",
    "verduftendste": "verduftend",
    "verduftendstem": "verduftend",
    "verduftendsten": "verduftend",
    "verduftendster": "verduftend",
    "verduftendstes": "verduftend",
    "verduftest": "verduften",
    "verduftet": "verduften",
    "verduftete": "verduften",
    "verduftetem": "verduftet",
    "verdufteten": "verduften",
    "verdufteter": "verduftet",
    "verduftetere": "verduftet",
    "verdufteterem": "verduftet",
    "verdufteteren": "verduftet",
    "verdufteterer": "verduftet",
    "verdufteteres": "verduftet",
    "verduftetes": "verduftet",
    "verduftetest": "verduften",
    "verdufteteste": "verduftet",
    "verduftetestem": "verduftet",
    "verduftetesten": "verduftet",
    "verduftetester": "verduftet",
    "verduftetestes": "verduftet",
    "verduftetet": "verduften",
    "verdumme": "verdummen",
    "verdummend": "verdummen",
    "verdummende": "verdummend",
    "verdummendem": "verdummend",
    "verdummenden": "verdummend",
    "verdummender": "verdummend",
    "verdummendere": "verdummend",
    "verdummenderem": "verdummend",
    "verdummenderen": "verdummend",
    "verdummenderer": "verdummend",
    "verdummenderes": "verdummend",
    "verdummendes": "verdummend",
    "verdummendste": "verdummend",
    "verdummendstem": "verdummend",
    "verdummendsten": "verdummend",
    "verdummendster": "verdummend",
    "verdummendstes": "verdummend",
    "verdummest": "verdummen",
    "verdummet": "verdummen",
    "verdummst": "verdummen",
    "verdummt": "verdummen",
    "verdummte": "verdummen",
    "verdummtem": "verdummt",
    "verdummten": "verdummen",
    "verdummter": "verdummt",
    "verdummtere": "verdummt",
    "verdummterem": "verdummt",
    "verdummteren": "verdummt",
    "verdummterer": "verdummt",
    "verdummteres": "verdummt",
    "verdummtes": "verdummt",
    "verdummtest": "verdummen",
    "verdummteste": "verdummt",
    "verdummtestem": "verdummt",
    "verdummtesten": "verdummt",
    "verdummtester": "verdummt",
    "verdummtestes": "verdummt",
    "verdummtet": "verdummen",
    "verdunkele": "verdunkeln",
    "verdunkelnd": "verdunkeln",
    "verdunkelnde": "verdunkelnd",
    "verdunkelndem": "verdunkelnd",
    "verdunkelnden": "verdunkelnd",
    "verdunkelnder": "verdunkelnd",
    "verdunkelndere": "verdunkelnd",
    "verdunkelnderem": "verdunkelnd",
    "verdunkelnderen": "verdunkelnd",
    "verdunkelnderer": "verdunkelnd",
    "verdunkelnderes": "verdunkelnd",
    "verdunkelndes": "verdunkelnd",
    "verdunkelndste": "verdunkelnd",
    "verdunkelndstem": "verdunkelnd",
    "verdunkelndsten": "verdunkelnd",
    "verdunkelndster": "verdunkelnd",
    "verdunkelndstes": "verdunkelnd",
    "verdunkelst": "verdunkeln",
    "verdunkelt": "verdunkeln",
    "verdunkelte": "verdunkeln",
    "verdunkeltem": "verdunkelt",
    "verdunkelten": "verdunkeln",
    "verdunkelter": "verdunkelt",
    "verdunkeltere": "verdunkelt",
    "verdunkelterem": "verdunkelt",
    "verdunkelteren": "verdunkelt",
    "verdunkelterer": "verdunkelt",
    "verdunkelteres": "verdunkelt",
    "verdunkeltes": "verdunkelt",
    "verdunkeltest": "verdunkeln",
    "verdunkelteste": "verdunkelt",
    "verdunkeltestem": "verdunkelt",
    "verdunkeltesten": "verdunkelt",
    "verdunkeltester": "verdunkelt",
    "verdunkeltestes": "verdunkelt",
    "verdunkeltet": "verdunkeln",
    "verdunkle": "verdunkeln",
    "verdunste": "verdunsten",
    "verdunstend": "verdunsten",
    "verdunstende": "verdunstend",
    "verdunstendem": "verdunstend",
    "verdunstenden": "verdunstend",
    "verdunstender": "verdunstend",
    "verdunstendere": "verdunstend",
    "verdunstenderem": "verdunstend",
    "verdunstenderen": "verdunstend",
    "verdunstenderer": "verdunstend",
    "verdunstenderes": "verdunstend",
    "verdunstendes": "verdunstend",
    "verdunstendste": "verdunstend",
    "verdunstendstem": "verdunstend",
    "verdunstendsten": "verdunstend",
    "verdunstendster": "verdunstend",
    "verdunstendstes": "verdunstend",
    "verdunstest": "verdunsten",
    "verdunstet": "verdunsten",
    "verdunstete": "verdunsten",
    "verdunstetem": "verdunstet",
    "verdunsteten": "verdunsten",
    "verdunsteter": "verdunstet",
    "verdunstetere": "verdunstet",
    "verdunsteterem": "verdunstet",
    "verdunsteteren": "verdunstet",
    "verdunsteterer": "verdunstet",
    "verdunsteteres": "verdunstet",
    "verdunstetes": "verdunstet",
    "verdunstetest": "verdunsten",
    "verdunsteteste": "verdunstet",
    "verdunstetestem": "verdunstet",
    "verdunstetesten": "verdunstet",
    "verdunstetester": "verdunstet",
    "verdunstetestes": "verdunstet",
    "verdunstetet": "verdunsten",
    "verdurste": "verdursten",
    "verdurstend": "verdursten",
    "verdurstende": "verdurstend",
    "verdurstendem": "verdurstend",
    "verdurstenden": "verdurstend",
    "verdurstender": "verdurstend",
    "verdurstendere": "verdurstend",
    "verdurstenderem": "verdurstend",
    "verdurstenderen": "verdurstend",
    "verdurstenderer": "verdurstend",
    "verdurstenderes": "verdurstend",
    "verdurstendes": "verdurstend",
    "verdurstendste": "verdurstend",
    "verdurstendstem": "verdurstend",
    "verdurstendsten": "verdurstend",
    "verdurstendster": "verdurstend",
    "verdurstendstes": "verdurstend",
    "verdurstest": "verdursten",
    "verdurstet": "verdursten",
    "verdurstete": "verdursten",
    "verdurstetem": "verdurstet",
    "verdursteten": "verdursten",
    "verdursteter": "verdurstet",
    "verdurstetere": "verdurstet",
    "verdursteterem": "verdurstet",
    "verdursteteren": "verdurstet",
    "verdursteterer": "verdurstet",
    "verdursteteres": "verdurstet",
    "verdurstetes": "verdurstet",
    "verdurstetest": "verdursten",
    "verdursteteste": "verdurstet",
    "verdurstetestem": "verdurstet",
    "verdurstetesten": "verdurstet",
    "verdurstetester": "verdurstet",
    "verdurstetestes": "verdurstet",
    "verdurstetet": "verdursten",
    "verdutzte": "verdutzt",
    "verdutztem": "verdutzt",
    "verdutzten": "verdutzt",
    "verdutzter": "verdutzt",
    "verdutztere": "verdutzt",
    "verdutzterem": "verdutzt",
    "verdutzteren": "verdutzt",
    "verdutzterer": "verdutzt",
    "verdutzteres": "verdutzt",
    "verdutztes": "verdutzt",
    "verdutzteste": "verdutzt",
    "verdutztestem": "verdutzt",
    "verdutztesten": "verdutzt",
    "verdutztester": "verdutzt",
    "verdutztestes": "verdutzt",
    "verdächte": "verdenken",
    "verdächten": "verdenken",
    "verdächtest": "verdenken",
    "verdächtet": "verdenken",
    "verdächtige": "verdächtigen",
    "verdächtigend": "verdächtigen",
    "verdächtigende": "verdächtigend",
    "verdächtigendem": "verdächtigend",
    "verdächtigenden": "verdächtigend",
    "verdächtigender": "verdächtigend",
    "verdächtigendes": "verdächtigend",
    "verdächtigest": "verdächtigen",
    "verdächtiget": "verdächtigen",
    "verdächtigst": "verdächtigen",
    "verdächtigt": "verdächtigen",
    "verdächtigte": "verdächtigen",
    "verdächtigtem": "verdächtigt",
    "verdächtigten": "verdächtigen",
    "verdächtigter": "verdächtigt",
    "verdächtigtes": "verdächtigt",
    "verdächtigtest": "verdächtigen",
    "verdächtigtet": "verdächtigen",
    "verdärbe": "verderben",
    "verdärben": "verderben",
    "verdärbest": "verderben",
    "verdärbet": "verderben",
    "verdünne": "verdünnen",
    "verdünnend": "verdünnen",
    "verdünnende": "verdünnend",
    "verdünnendem": "verdünnend",
    "verdünnenden": "verdünnend",
    "verdünnender": "verdünnend",
    "verdünnendere": "verdünnend",
    "verdünnenderem": "verdünnend",
    "verdünnenderen": "verdünnend",
    "verdünnenderer": "verdünnend",
    "verdünnenderes": "verdünnend",
    "verdünnendes": "verdünnend",
    "verdünnendste": "verdünnend",
    "verdünnendstem": "verdünnend",
    "verdünnendsten": "verdünnend",
    "verdünnendster": "verdünnend",
    "verdünnendstes": "verdünnend",
    "verdünnest": "verdünnen",
    "verdünnet": "verdünnen",
    "verdünnisiere": "verdünnisieren",
    "verdünnisierend": "verdünnisieren",
    "verdünnisierende": "verdünnisierend",
    "verdünnisierendem": "verdünnisierend",
    "verdünnisierenden": "verdünnisierend",
    "verdünnisierender": "verdünnisierend",
    "verdünnisierendes": "verdünnisierend",
    "verdünnisierest": "verdünnisieren",
    "verdünnisieret": "verdünnisieren",
    "verdünnisierst": "verdünnisieren",
    "verdünnisiert": "verdünnisieren",
    "verdünnisierte": "verdünnisieren",
    "verdünnisiertem": "verdünnisiert",
    "verdünnisierten": "verdünnisieren",
    "verdünnisierter": "verdünnisiert",
    "verdünnisiertes": "verdünnisiert",
    "verdünnisiertest": "verdünnisieren",
    "verdünnisiertet": "verdünnisieren",
    "verdünnst": "verdünnen",
    "verdünnt": "verdünnen",
    "verdünnte": "verdünnen",
    "verdünntem": "verdünnt",
    "verdünnten": "verdünnen",
    "verdünnter": "verdünnt",
    "verdünntere": "verdünnt",
    "verdünnterem": "verdünnt",
    "verdünnteren": "verdünnt",
    "verdünnterer": "verdünnt",
    "verdünnteres": "verdünnt",
    "verdünntes": "verdünnt",
    "verdünntest": "verdünnen",
    "verdünnteste": "verdünnt",
    "verdünntestem": "verdünnt",
    "verdünntesten": "verdünnt",
    "verdünntester": "verdünnt",
    "verdünntestes": "verdünnt",
    "verdünntet": "verdünnen",
    "verdünste": "verdünsten",
    "verdünstend": "verdünsten",
    "verdünstendem": "verdünstend",
    "verdünstender": "verdünstend",
    "verdünstenderem": "verdünstend",
    "verdünstenderer": "verdünstend",
    "verdünstenderes": "verdünstend",
    "verdünstendes": "verdünstend",
    "verdünstendstem": "verdünstend",
    "verdünstendster": "verdünstend",
    "verdünstendstes": "verdünstend",
    "verdünstest": "verdünsten",
    "verdünstet": "verdünsten",
    "verdünstete": "verdünsten",
    "verdünstetem": "verdünstet",
    "verdünsteten": "verdünstet",
    "verdünsteter": "verdünstet",
    "verdünsteterem": "verdünstet",
    "verdünsteterer": "verdünstet",
    "verdünsteteres": "verdünstet",
    "verdünstetes": "verdünstet",
    "verdünstetest": "verdünsten",
    "verdünstetestem": "verdünstet",
    "verdünstetester": "verdünstet",
    "verdünstetestes": "verdünstet",
    "verdünstetet": "verdünsten",
    "verebbe": "verebben",
    "verebbend": "verebben",
    "verebbende": "verebbend",
    "verebbendem": "verebbend",
    "verebbenden": "verebbend",
    "verebbender": "verebbend",
    "verebbendes": "verebbend",
    "verebbest": "verebben",
    "verebbet": "verebben",
    "verebbst": "verebben",
    "verebbt": "verebben",
    "verebbte": "verebben",
    "verebbtem": "verebbt",
    "verebbten": "verebben",
    "verebbter": "verebbt",
    "verebbtes": "verebbt",
    "verebbtest": "verebben",
    "verebbtet": "verebben",
    "veredele": "veredeln",
    "veredelnd": "veredeln",
    "veredelnde": "veredelnd",
    "veredelndem": "veredelnd",
    "veredelnden": "veredelnd",
    "veredelnder": "veredelnd",
    "veredelndere": "veredelnd",
    "veredelnderem": "veredelnd",
    "veredelnderen": "veredelnd",
    "veredelnderer": "veredelnd",
    "veredelnderes": "veredelnd",
    "veredelndes": "veredelnd",
    "veredelndste": "veredelnd",
    "veredelndstem": "veredelnd",
    "veredelndsten": "veredelnd",
    "veredelndster": "veredelnd",
    "veredelndstes": "veredelnd",
    "veredelst": "veredeln",
    "veredelt": "veredeln",
    "veredelte": "veredeln",
    "veredeltem": "veredelt",
    "veredelten": "veredeln",
    "veredelter": "veredelt",
    "veredeltere": "veredelt",
    "veredelterem": "veredelt",
    "veredelteren": "veredelt",
    "veredelterer": "veredelt",
    "veredelteres": "veredelt",
    "veredeltes": "veredelt",
    "veredeltest": "veredeln",
    "veredelteste": "veredelt",
    "veredeltestem": "veredelt",
    "veredeltesten": "veredelt",
    "veredeltester": "veredelt",
    "veredeltestes": "veredelt",
    "veredeltet": "veredeln",
    "veredle": "veredeln",
    "verehre": "verehren",
    "verehrend": "verehren",
    "verehrende": "verehrend",
    "verehrendem": "verehrend",
    "verehrenden": "verehrend",
    "verehrender": "verehrend",
    "verehrendere": "verehrend",
    "verehrenderem": "verehrend",
    "verehrenderen": "verehrend",
    "verehrenderer": "verehrend",
    "verehrenderes": "verehrend",
    "verehrendes": "verehrend",
    "verehrendste": "verehrend",
    "verehrendstem": "verehrend",
    "verehrendsten": "verehrend",
    "verehrendster": "verehrend",
    "verehrendstes": "verehrend",
    "verehrest": "verehren",
    "verehret": "verehren",
    "verehrst": "verehren",
    "verehrt": "verehren",
    "verehrte": "verehren",
    "verehrtem": "verehrt",
    "verehrten": "verehren",
    "verehrter": "verehrt",
    "verehrtere": "verehrt",
    "verehrterem": "verehrt",
    "verehrteren": "verehrt",
    "verehrterer": "verehrt",
    "verehrteres": "verehrt",
    "verehrtes": "verehrt",
    "verehrtest": "verehren",
    "verehrteste": "verehrt",
    "verehrtestem": "verehrt",
    "verehrtesten": "verehrt",
    "verehrtester": "verehrt",
    "verehrtestes": "verehrt",
    "verehrtet": "verehren",
    "vereide": "vereiden",
    "vereidend": "vereiden",
    "vereidende": "vereidend",
    "vereidendem": "vereidend",
    "vereidenden": "vereidend",
    "vereidender": "vereidend",
    "vereidendes": "vereidend",
    "vereidest": "vereiden",
    "vereidet": "vereiden",
    "vereidete": "vereiden",
    "vereidetem": "vereidet",
    "vereideten": "vereiden",
    "vereideter": "vereidet",
    "vereidetes": "vereidet",
    "vereidetest": "vereiden",
    "vereidetet": "vereiden",
    "vereidige": "vereidigen",
    "vereidigend": "vereidigen",
    "vereidigende": "vereidigend",
    "vereidigendem": "vereidigend",
    "vereidigenden": "vereidigend",
    "vereidigender": "vereidigend",
    "vereidigendes": "vereidigend",
    "vereidigest": "vereidigen",
    "vereidiget": "vereidigen",
    "vereidigst": "vereidigen",
    "vereidigt": "vereidigen",
    "vereidigte": "vereidigen",
    "vereidigtem": "vereidigt",
    "vereidigten": "vereidigen",
    "vereidigter": "vereidigt",
    "vereidigtes": "vereidigt",
    "vereidigtest": "vereidigen",
    "vereidigtet": "vereidigen",
    "vereinbarendem": "vereinbarend",
    "vereinbarenden": "vereinbarend",
    "vereinbarender": "vereinbarend",
    "vereinbarendes": "vereinbarend",
    "vereinbartem": "vereinbart",
    "vereinbarten": "vereinbart",
    "vereinbarter": "vereinbart",
    "vereinbartes": "vereinbart",
    "vereinend": "vereinen",
    "vereinende": "vereinend",
    "vereinendem": "vereinend",
    "vereinenden": "vereinend",
    "vereinender": "vereinend",
    "vereinendes": "vereinend",
    "vereinest": "vereinen",
    "vereinet": "vereinen",
    "vereinfache": "vereinfachen",
    "vereinfachend": "vereinfachen",
    "vereinfachende": "vereinfachend",
    "vereinfachendem": "vereinfachend",
    "vereinfachenden": "vereinfachend",
    "vereinfachender": "vereinfachend",
    "vereinfachendere": "vereinfachend",
    "vereinfachenderem": "vereinfachend",
    "vereinfachenderen": "vereinfachend",
    "vereinfachenderer": "vereinfachend",
    "vereinfachenderes": "vereinfachend",
    "vereinfachendes": "vereinfachend",
    "vereinfachendste": "vereinfachend",
    "vereinfachendstem": "vereinfachend",
    "vereinfachendsten": "vereinfachend",
    "vereinfachendster": "vereinfachend",
    "vereinfachendstes": "vereinfachend",
    "vereinfachest": "vereinfachen",
    "vereinfachet": "vereinfachen",
    "vereinfachst": "vereinfachen",
    "vereinfacht": "vereinfachen",
    "vereinfachte": "vereinfachen",
    "vereinfachtem": "vereinfacht",
    "vereinfachten": "vereinfachen",
    "vereinfachter": "vereinfacht",
    "vereinfachtere": "vereinfacht",
    "vereinfachterem": "vereinfacht",
    "vereinfachteren": "vereinfacht",
    "vereinfachterer": "vereinfacht",
    "vereinfachteres": "vereinfacht",
    "vereinfachtes": "vereinfacht",
    "vereinfachtest": "vereinfachen",
    "vereinfachteste": "vereinfacht",
    "vereinfachtestem": "vereinfacht",
    "vereinfachtesten": "vereinfacht",
    "vereinfachtester": "vereinfacht",
    "vereinfachtestes": "vereinfacht",
    "vereinfachtet": "vereinfachen",
    "vereinheitliche": "vereinheitlichen",
    "vereinheitlichend": "vereinheitlichen",
    "vereinheitlichende": "vereinheitlichend",
    "vereinheitlichendem": "vereinheitlichend",
    "vereinheitlichenden": "vereinheitlichend",
    "vereinheitlichender": "vereinheitlichend",
    "vereinheitlichendere": "vereinheitlichend",
    "vereinheitlichenderem": "vereinheitlichend",
    "vereinheitlichenderen": "vereinheitlichend",
    "vereinheitlichenderer": "vereinheitlichend",
    "vereinheitlichenderes": "vereinheitlichend",
    "vereinheitlichendes": "vereinheitlichend",
    "vereinheitlichendste": "vereinheitlichend",
    "vereinheitlichendstem": "vereinheitlichend",
    "vereinheitlichendsten": "vereinheitlichend",
    "vereinheitlichendster": "vereinheitlichend",
    "vereinheitlichendstes": "vereinheitlichend",
    "vereinheitlichest": "vereinheitlichen",
    "vereinheitlichet": "vereinheitlichen",
    "vereinheitlichst": "vereinheitlichen",
    "vereinheitlicht": "vereinheitlichen",
    "vereinheitlichte": "vereinheitlichen",
    "vereinheitlichtem": "vereinheitlicht",
    "vereinheitlichten": "vereinheitlichen",
    "vereinheitlichter": "vereinheitlicht",
    "vereinheitlichtere": "vereinheitlicht",
    "vereinheitlichterem": "vereinheitlicht",
    "vereinheitlichteren": "vereinheitlicht",
    "vereinheitlichterer": "vereinheitlicht",
    "vereinheitlichteres": "vereinheitlicht",
    "vereinheitlichtes": "vereinheitlicht",
    "vereinheitlichtest": "vereinheitlichen",
    "vereinheitlichteste": "vereinheitlicht",
    "vereinheitlichtestem": "vereinheitlicht",
    "vereinheitlichtesten": "vereinheitlicht",
    "vereinheitlichtester": "vereinheitlicht",
    "vereinheitlichtestes": "vereinheitlicht",
    "vereinheitlichtet": "vereinheitlichen",
    "vereinige": "vereinigen",
    "vereinigend": "vereinigen",
    "vereinigende": "vereinigend",
    "vereinigendem": "vereinigend",
    "vereinigenden": "vereinigend",
    "vereinigender": "vereinigend",
    "vereinigendes": "vereinigend",
    "vereinigest": "vereinigen",
    "vereiniget": "vereinigen",
    "vereinigst": "vereinigen",
    "vereinigt": "vereinigen",
    "vereinigte": "vereinigen",
    "vereinigtem": "vereinigt",
    "vereinigten": "vereinigen",
    "vereinigter": "vereinigt",
    "vereinigtes": "vereinigt",
    "vereinigtest": "vereinigen",
    "vereinigtet": "vereinigen",
    "vereinnahme": "vereinnahmen",
    "vereinnahmend": "vereinnahmen",
    "vereinnahmende": "vereinnahmend",
    "vereinnahmendem": "vereinnahmend",
    "vereinnahmenden": "vereinnahmend",
    "vereinnahmender": "vereinnahmend",
    "vereinnahmendere": "vereinnahmend",
    "vereinnahmenderem": "vereinnahmend",
    "vereinnahmenderen": "vereinnahmend",
    "vereinnahmenderer": "vereinnahmend",
    "vereinnahmenderes": "vereinnahmend",
    "vereinnahmendes": "vereinnahmend",
    "vereinnahmendste": "vereinnahmend",
    "vereinnahmendstem": "vereinnahmend",
    "vereinnahmendsten": "vereinnahmend",
    "vereinnahmendster": "vereinnahmend",
    "vereinnahmendstes": "vereinnahmend",
    "vereinnahmest": "vereinnahmen",
    "vereinnahmet": "vereinnahmen",
    "vereinnahmst": "vereinnahmen",
    "vereinnahmt": "vereinnahmen",
    "vereinnahmte": "vereinnahmen",
    "vereinnahmtem": "vereinnahmt",
    "vereinnahmten": "vereinnahmen",
    "vereinnahmter": "vereinnahmt",
    "vereinnahmtere": "vereinnahmt",
    "vereinnahmterem": "vereinnahmt",
    "vereinnahmteren": "vereinnahmt",
    "vereinnahmterer": "vereinnahmt",
    "vereinnahmteres": "vereinnahmt",
    "vereinnahmtes": "vereinnahmt",
    "vereinnahmtest": "vereinnahmen",
    "vereinnahmteste": "vereinnahmt",
    "vereinnahmtestem": "vereinnahmt",
    "vereinnahmtesten": "vereinnahmt",
    "vereinnahmtester": "vereinnahmt",
    "vereinnahmtestes": "vereinnahmt",
    "vereinnahmtet": "vereinnahmen",
    "vereinsame": "vereinsamen",
    "vereinsamend": "vereinsamen",
    "vereinsamende": "vereinsamend",
    "vereinsamendem": "vereinsamend",
    "vereinsamenden": "vereinsamend",
    "vereinsamender": "vereinsamend",
    "vereinsamendere": "vereinsamend",
    "vereinsamenderem": "vereinsamend",
    "vereinsamenderen": "vereinsamend",
    "vereinsamenderer": "vereinsamend",
    "vereinsamenderes": "vereinsamend",
    "vereinsamendes": "vereinsamend",
    "vereinsamendste": "vereinsamend",
    "vereinsamendstem": "vereinsamend",
    "vereinsamendsten": "vereinsamend",
    "vereinsamendster": "vereinsamend",
    "vereinsamendstes": "vereinsamend",
    "vereinsamest": "vereinsamen",
    "vereinsamet": "vereinsamen",
    "vereinsamst": "vereinsamen",
    "vereinsamt": "vereinsamen",
    "vereinsamte": "vereinsamen",
    "vereinsamtem": "vereinsamt",
    "vereinsamten": "vereinsamen",
    "vereinsamter": "vereinsamt",
    "vereinsamtere": "vereinsamt",
    "vereinsamterem": "vereinsamt",
    "vereinsamteren": "vereinsamt",
    "vereinsamterer": "vereinsamt",
    "vereinsamteres": "vereinsamt",
    "vereinsamtes": "vereinsamt",
    "vereinsamtest": "vereinsamen",
    "vereinsamteste": "vereinsamt",
    "vereinsamtestem": "vereinsamt",
    "vereinsamtesten": "vereinsamt",
    "vereinsamtester": "vereinsamt",
    "vereinsamtestes": "vereinsamt",
    "vereinsamtet": "vereinsamen",
    "vereinst": "vereinen",
    "vereint": "vereinen",
    "vereinte": "vereinen",
    "vereintem": "vereint",
    "vereinten": "vereinen",
    "vereinter": "vereint",
    "vereintes": "vereint",
    "vereintest": "vereinen",
    "vereintet": "vereinen",
    "vereinzele": "vereinzeln",
    "vereinzelnd": "vereinzeln",
    "vereinzelnde": "vereinzelnd",
    "vereinzelndem": "vereinzelnd",
    "vereinzelnden": "vereinzelnd",
    "vereinzelnder": "vereinzelnd",
    "vereinzelndes": "vereinzelnd",
    "vereinzelst": "vereinzeln",
    "vereinzelt": "vereinzeln",
    "vereinzelte": "vereinzeln",
    "vereinzeltem": "vereinzelt",
    "vereinzelten": "vereinzeln",
    "vereinzelter": "vereinzelt",
    "vereinzeltes": "vereinzelt",
    "vereinzeltest": "vereinzeln",
    "vereinzeltet": "vereinzeln",
    "vereinzle": "vereinzeln",
    "vereise": "vereisen",
    "vereisend": "vereisen",
    "vereisende": "vereisend",
    "vereisendem": "vereisend",
    "vereisenden": "vereisend",
    "vereisender": "vereisend",
    "vereisendere": "vereisend",
    "vereisenderem": "vereisend",
    "vereisenderen": "vereisend",
    "vereisenderer": "vereisend",
    "vereisenderes": "vereisend",
    "vereisendes": "vereisend",
    "vereisendste": "vereisend",
    "vereisendstem": "vereisend",
    "vereisendsten": "vereisend",
    "vereisendster": "vereisend",
    "vereisendstes": "vereisend",
    "vereisest": "vereisen",
    "vereiset": "vereisen",
    "vereist": "vereisen",
    "vereiste": "vereisen",
    "vereistem": "vereist",
    "vereisten": "vereisen",
    "vereister": "vereist",
    "vereistere": "vereist",
    "vereisterem": "vereist",
    "vereisteren": "vereist",
    "vereisterer": "vereist",
    "vereisteres": "vereist",
    "vereistes": "vereist",
    "vereistest": "vereisen",
    "vereisteste": "vereist",
    "vereistestem": "vereist",
    "vereistesten": "vereist",
    "vereistester": "vereist",
    "vereistestes": "vereist",
    "vereistet": "vereisen",
    "vereitele": "vereiteln",
    "vereitelnd": "vereiteln",
    "vereitelnde": "vereitelnd",
    "vereitelndem": "vereitelnd",
    "vereitelnden": "vereitelnd",
    "vereitelnder": "vereitelnd",
    "vereitelndes": "vereitelnd",
    "vereitelst": "vereiteln",
    "vereitelt": "vereiteln",
    "vereitelte": "vereiteln",
    "vereiteltem": "vereitelt",
    "vereitelten": "vereiteln",
    "vereitelter": "vereitelt",
    "vereiteltes": "vereitelt",
    "vereiteltest": "vereiteln",
    "vereiteltet": "vereiteln",
    "vereitere": "vereitern",
    "vereiternd": "vereitern",
    "vereiternde": "vereiternd",
    "vereiterndem": "vereiternd",
    "vereiternden": "vereiternd",
    "vereiternder": "vereiternd",
    "vereiterndere": "vereiternd",
    "vereiternderem": "vereiternd",
    "vereiternderen": "vereiternd",
    "vereiternderer": "vereiternd",
    "vereiternderes": "vereiternd",
    "vereiterndes": "vereiternd",
    "vereiterndste": "vereiternd",
    "vereiterndstem": "vereiternd",
    "vereiterndsten": "vereiternd",
    "vereiterndster": "vereiternd",
    "vereiterndstes": "vereiternd",
    "vereiterst": "vereitern",
    "vereitert": "vereitern",
    "vereiterte": "vereitern",
    "vereitertem": "vereitert",
    "vereiterten": "vereitern",
    "vereiterter": "vereitert",
    "vereitertere": "vereitert",
    "vereiterterem": "vereitert",
    "vereiterteren": "vereitert",
    "vereiterterer": "vereitert",
    "vereiterteres": "vereitert",
    "vereitertes": "vereitert",
    "vereitertest": "vereitern",
    "vereiterteste": "vereitert",
    "vereitertestem": "vereitert",
    "vereitertesten": "vereitert",
    "vereitertester": "vereitert",
    "vereitertestes": "vereitert",
    "vereitertet": "vereitern",
    "vereitle": "vereiteln",
    "verelende": "verelenden",
    "verelendend": "verelenden",
    "verelendende": "verelendend",
    "verelendendem": "verelendend",
    "verelendenden": "verelendend",
    "verelendender": "verelendend",
    "verelendendere": "verelendend",
    "verelendenderem": "verelendend",
    "verelendenderen": "verelendend",
    "verelendenderer": "verelendend",
    "verelendenderes": "verelendend",
    "verelendendes": "verelendend",
    "verelendendste": "verelendend",
    "verelendendstem": "verelendend",
    "verelendendsten": "verelendend",
    "verelendendster": "verelendend",
    "verelendendstes": "verelendend",
    "verelendest": "verelenden",
    "verelendet": "verelenden",
    "verelendete": "verelenden",
    "verelendetem": "verelendet",
    "verelendeten": "verelenden",
    "verelendeter": "verelendet",
    "verelendetere": "verelendet",
    "verelendeterem": "verelendet",
    "verelendeteren": "verelendet",
    "verelendeterer": "verelendet",
    "verelendeteres": "verelendet",
    "verelendetes": "verelendet",
    "verelendetest": "verelenden",
    "verelendeteste": "verelendet",
    "verelendetestem": "verelendet",
    "verelendetesten": "verelendet",
    "verelendetester": "verelendet",
    "verelendetestes": "verelendet",
    "verelendetet": "verelenden",
    "verende": "verenden",
    "verendend": "verenden",
    "verendende": "verendend",
    "verendendem": "verendend",
    "verendenden": "verendend",
    "verendender": "verendend",
    "verendendes": "verendend",
    "verendest": "verenden",
    "verendet": "verenden",
    "verendete": "verenden",
    "verendetem": "verendet",
    "verendeten": "verenden",
    "verendeter": "verendet",
    "verendetes": "verendet",
    "verendetest": "verenden",
    "verendetet": "verenden",
    "verenge": "verengen",
    "verengend": "verengen",
    "verengende": "verengend",
    "verengendem": "verengend",
    "verengenden": "verengend",
    "verengender": "verengend",
    "verengendere": "verengend",
    "verengenderem": "verengend",
    "verengenderen": "verengend",
    "verengenderer": "verengend",
    "verengenderes": "verengend",
    "verengendes": "verengend",
    "verengendste": "verengend",
    "verengendstem": "verengend",
    "verengendsten": "verengend",
    "verengendster": "verengend",
    "verengendstes": "verengend",
    "verengest": "verengen",
    "verenget": "verengen",
    "verengst": "verengen",
    "verengt": "verengen",
    "verengte": "verengen",
    "verengtem": "verengt",
    "verengten": "verengen",
    "verengter": "verengt",
    "verengtere": "verengt",
    "verengterem": "verengt",
    "verengteren": "verengt",
    "verengterer": "verengt",
    "verengteres": "verengt",
    "verengtes": "verengt",
    "verengtest": "verengen",
    "verengteste": "verengt",
    "verengtestem": "verengt",
    "verengtesten": "verengt",
    "verengtester": "verengt",
    "verengtestes": "verengt",
    "verengtet": "verengen",
    "vererbe": "vererben",
    "vererbend": "vererben",
    "vererbende": "vererbend",
    "vererbendem": "vererbend",
    "vererbenden": "vererbend",
    "vererbender": "vererbend",
    "vererbendes": "vererbend",
    "vererbest": "vererben",
    "vererbet": "vererben",
    "vererbst": "vererben",
    "vererbt": "vererben",
    "vererbte": "vererben",
    "vererbtem": "vererbt",
    "vererbten": "vererben",
    "vererbter": "vererbt",
    "vererbtes": "vererbt",
    "vererbtest": "vererben",
    "vererbtet": "vererben",
    "verewige": "verewigen",
    "verewigend": "verewigen",
    "verewigende": "verewigend",
    "verewigendem": "verewigend",
    "verewigenden": "verewigend",
    "verewigender": "verewigend",
    "verewigendes": "verewigend",
    "verewigest": "verewigen",
    "verewiget": "verewigen",
    "verewigst": "verewigen",
    "verewigt": "verewigen",
    "verewigte": "verewigen",
    "verewigtem": "verewigt",
    "verewigten": "verewigen",
    "verewigter": "verewigt",
    "verewigtes": "verewigt",
    "verewigtest": "verewigen",
    "verewigtet": "verewigen",
    "verfahre": "verfahren",
    "verfahrend": "verfahren",
    "verfahrende": "verfahrend",
    "verfahrendem": "verfahrend",
    "verfahrenden": "verfahrend",
    "verfahrender": "verfahrend",
    "verfahrendes": "verfahrend",
    "verfahrene": "verfahren",
    "verfahrenem": "verfahren",
    "verfahrenen": "verfahren",
    "verfahrener": "verfahren",
    "verfahrenere": "verfahren",
    "verfahrenerem": "verfahren",
    "verfahreneren": "verfahren",
    "verfahrenerer": "verfahren",
    "verfahreneres": "verfahren",
    "verfahrenes": "verfahren",
    "verfahrenstem": "verfahren",
    "verfahrensten": "verfahren",
    "verfahrenster": "verfahren",
    "verfahrenstes": "verfahren",
    "verfahrest": "verfahren",
    "verfahret": "verfahren",
    "verfahrt": "verfahren",
    "verfallend": "verfallen",
    "verfallende": "verfallend",
    "verfallendem": "verfallend",
    "verfallenden": "verfallend",
    "verfallender": "verfallend",
    "verfallendes": "verfallend",
    "verfallene": "verfallen",
    "verfallenem": "verfallen",
    "verfallenen": "verfallen",
    "verfallener": "verfallen",
    "verfallenere": "verfallen",
    "verfallenerem": "verfallen",
    "verfalleneren": "verfallen",
    "verfallenerer": "verfallen",
    "verfalleneres": "verfallen",
    "verfallenes": "verfallen",
    "verfallenstem": "verfallen",
    "verfallensten": "verfallen",
    "verfallenster": "verfallen",
    "verfallenstes": "verfallen",
    "verfallest": "verfallen",
    "verfallet": "verfallen",
    "verfallt": "verfallen",
    "verfange": "verfangen",
    "verfangend": "verfangen",
    "verfangende": "verfangend",
    "verfangendem": "verfangend",
    "verfangenden": "verfangend",
    "verfangender": "verfangend",
    "verfangendes": "verfangend",
    "verfangene": "verfangen",
    "verfangenem": "verfangen",
    "verfangenen": "verfangen",
    "verfangener": "verfangen",
    "verfangenes": "verfangen",
    "verfangest": "verfangen",
    "verfanget": "verfangen",
    "verfangt": "verfangen",
    "verfasse": "verfassen",
    "verfassend": "verfassen",
    "verfassende": "verfassend",
    "verfassendem": "verfassend",
    "verfassenden": "verfassend",
    "verfassender": "verfassend",
    "verfassendes": "verfassend",
    "verfassest": "verfassen",
    "verfasset": "verfassen",
    "verfassunggebendem": "verfassunggebend",
    "verfassunggebenden": "verfassunggebend",
    "verfassunggebender": "verfassunggebend",
    "verfassunggebendes": "verfassunggebend",
    "verfassungsmäßige": "verfassungsmäßig",
    "verfassungsmäßigem": "verfassungsmäßig",
    "verfassungsmäßigen": "verfassungsmäßig",
    "verfassungsmäßiger": "verfassungsmäßig",
    "verfassungsmäßiges": "verfassungsmäßig",
    "verfassungspolitische": "verfassungspolitisch",
    "verfassungspolitischem": "verfassungspolitisch",
    "verfassungspolitischen": "verfassungspolitisch",
    "verfassungspolitischer": "verfassungspolitisch",
    "verfassungspolitischere": "verfassungspolitisch",
    "verfassungspolitischerem": "verfassungspolitisch",
    "verfassungspolitischeren": "verfassungspolitisch",
    "verfassungspolitischerer": "verfassungspolitisch",
    "verfassungspolitischeres": "verfassungspolitisch",
    "verfassungspolitisches": "verfassungspolitisch",
    "verfassungspolitischste": "verfassungspolitisch",
    "verfassungspolitischstem": "verfassungspolitisch",
    "verfassungspolitischsten": "verfassungspolitisch",
    "verfassungspolitischster": "verfassungspolitisch",
    "verfassungspolitischstes": "verfassungspolitisch",
    "verfassungsrechtliche": "verfassungsrechtlich",
    "verfassungsrechtlichem": "verfassungsrechtlich",
    "verfassungsrechtlichen": "verfassungsrechtlich",
    "verfassungsrechtlicher": "verfassungsrechtlich",
    "verfassungsrechtlichere": "verfassungsrechtlich",
    "verfassungsrechtlicherem": "verfassungsrechtlich",
    "verfassungsrechtlicheren": "verfassungsrechtlich",
    "verfassungsrechtlicherer": "verfassungsrechtlich",
    "verfassungsrechtlicheres": "verfassungsrechtlich",
    "verfassungsrechtliches": "verfassungsrechtlich",
    "verfassungsrechtlichste": "verfassungsrechtlich",
    "verfassungsrechtlichstem": "verfassungsrechtlich",
    "verfassungsrechtlichsten": "verfassungsrechtlich",
    "verfassungsrechtlichster": "verfassungsrechtlich",
    "verfassungsrechtlichstes": "verfassungsrechtlich",
    "verfassungswidrige": "verfassungswidrig",
    "verfassungswidrigem": "verfassungswidrig",
    "verfassungswidrigen": "verfassungswidrig",
    "verfassungswidriger": "verfassungswidrig",
    "verfassungswidriges": "verfassungswidrig",
    "verfaule": "verfaulen",
    "verfaulend": "verfaulen",
    "verfaulende": "verfaulend",
    "verfaulendem": "verfaulend",
    "verfaulenden": "verfaulend",
    "verfaulender": "verfaulend",
    "verfaulendere": "verfaulend",
    "verfaulenderem": "verfaulend",
    "verfaulenderen": "verfaulend",
    "verfaulenderer": "verfaulend",
    "verfaulenderes": "verfaulend",
    "verfaulendes": "verfaulend",
    "verfaulendste": "verfaulend",
    "verfaulendstem": "verfaulend",
    "verfaulendsten": "verfaulend",
    "verfaulendster": "verfaulend",
    "verfaulendstes": "verfaulend",
    "verfaulest": "verfaulen",
    "verfaulet": "verfaulen",
    "verfaulst": "verfaulen",
    "verfault": "verfaulen",
    "verfaulte": "verfaulen",
    "verfaultem": "verfault",
    "verfaulten": "verfaulen",
    "verfaulter": "verfault",
    "verfaultere": "verfault",
    "verfaulterem": "verfault",
    "verfaulteren": "verfault",
    "verfaulterer": "verfault",
    "verfaulteres": "verfault",
    "verfaultes": "verfault",
    "verfaultest": "verfaulen",
    "verfaulteste": "verfault",
    "verfaultestem": "verfault",
    "verfaultesten": "verfault",
    "verfaultester": "verfault",
    "verfaultestes": "verfault",
    "verfaultet": "verfaulen",
    "verfaßt": "verfassen",
    "verfaßte": "verfassen",
    "verfaßtem": "verfaßt",
    "verfaßten": "verfassen",
    "verfaßter": "verfaßt",
    "verfaßtes": "verfaßt",
    "verfaßtest": "verfassen",
    "verfaßtet": "verfassen",
    "verfechte": "verfechten",
    "verfechtend": "verfechten",
    "verfechtende": "verfechtend",
    "verfechtendem": "verfechtend",
    "verfechtenden": "verfechtend",
    "verfechtender": "verfechtend",
    "verfechtendes": "verfechtend",
    "verfechtest": "verfechten",
    "verfechtet": "verfechten",
    "verfehle": "verfehlen",
    "verfehlend": "verfehlen",
    "verfehlende": "verfehlend",
    "verfehlendem": "verfehlend",
    "verfehlenden": "verfehlend",
    "verfehlender": "verfehlend",
    "verfehlendere": "verfehlend",
    "verfehlenderem": "verfehlend",
    "verfehlenderen": "verfehlend",
    "verfehlenderer": "verfehlend",
    "verfehlenderes": "verfehlend",
    "verfehlendes": "verfehlend",
    "verfehlendste": "verfehlend",
    "verfehlendstem": "verfehlend",
    "verfehlendsten": "verfehlend",
    "verfehlendster": "verfehlend",
    "verfehlendstes": "verfehlend",
    "verfehlest": "verfehlen",
    "verfehlet": "verfehlen",
    "verfehlst": "verfehlen",
    "verfehlt": "verfehlen",
    "verfehlte": "verfehlen",
    "verfehltem": "verfehlt",
    "verfehlten": "verfehlen",
    "verfehlter": "verfehlt",
    "verfehltere": "verfehlt",
    "verfehlterem": "verfehlt",
    "verfehlteren": "verfehlt",
    "verfehlterer": "verfehlt",
    "verfehlteres": "verfehlt",
    "verfehltes": "verfehlt",
    "verfehltest": "verfehlen",
    "verfehlteste": "verfehlt",
    "verfehltestem": "verfehlt",
    "verfehltesten": "verfehlt",
    "verfehltester": "verfehlt",
    "verfehltestes": "verfehlt",
    "verfehltet": "verfehlen",
    "verfeinde": "verfeinden",
    "verfeindend": "verfeinden",
    "verfeindende": "verfeindend",
    "verfeindendem": "verfeindend",
    "verfeindenden": "verfeindend",
    "verfeindender": "verfeindend",
    "verfeindendes": "verfeindend",
    "verfeindest": "verfeinden",
    "verfeindet": "verfeinden",
    "verfeindete": "verfeinden",
    "verfeindetem": "verfeindet",
    "verfeindeten": "verfeinden",
    "verfeindeter": "verfeindet",
    "verfeindetere": "verfeindet",
    "verfeindeterem": "verfeindet",
    "verfeindeteren": "verfeindet",
    "verfeindeterer": "verfeindet",
    "verfeindeteres": "verfeindet",
    "verfeindetes": "verfeindet",
    "verfeindetest": "verfeinden",
    "verfeindeteste": "verfeindet",
    "verfeindetestem": "verfeindet",
    "verfeindetesten": "verfeindet",
    "verfeindetester": "verfeindet",
    "verfeindetestes": "verfeindet",
    "verfeindetet": "verfeinden",
    "verfeinere": "verfeinern",
    "verfeinernd": "verfeinern",
    "verfeinernde": "verfeinernd",
    "verfeinerndem": "verfeinernd",
    "verfeinernden": "verfeinernd",
    "verfeinernder": "verfeinernd",
    "verfeinerndes": "verfeinernd",
    "verfeinerst": "verfeinern",
    "verfeinert": "verfeinern",
    "verfeinerte": "verfeinern",
    "verfeinertem": "verfeinert",
    "verfeinerten": "verfeinern",
    "verfeinerter": "verfeinert",
    "verfeinertere": "verfeinert",
    "verfeinerterem": "verfeinert",
    "verfeinerteren": "verfeinert",
    "verfeinerterer": "verfeinert",
    "verfeinerteres": "verfeinert",
    "verfeinertes": "verfeinert",
    "verfeinertest": "verfeinern",
    "verfeinerteste": "verfeinert",
    "verfeinertestem": "verfeinert",
    "verfeinertesten": "verfeinert",
    "verfeinertester": "verfeinert",
    "verfeinertestes": "verfeinert",
    "verfeinertet": "verfeinern",
    "verfestige": "verfestigen",
    "verfestigend": "verfestigen",
    "verfestigende": "verfestigend",
    "verfestigendem": "verfestigend",
    "verfestigenden": "verfestigend",
    "verfestigender": "verfestigend",
    "verfestigendere": "verfestigend",
    "verfestigenderem": "verfestigend",
    "verfestigenderen": "verfestigend",
    "verfestigenderer": "verfestigend",
    "verfestigenderes": "verfestigend",
    "verfestigendes": "verfestigend",
    "verfestigendste": "verfestigend",
    "verfestigendstem": "verfestigend",
    "verfestigendsten": "verfestigend",
    "verfestigendster": "verfestigend",
    "verfestigendstes": "verfestigend",
    "verfestigest": "verfestigen",
    "verfestiget": "verfestigen",
    "verfestigst": "verfestigen",
    "verfestigt": "verfestigen",
    "verfestigte": "verfestigen",
    "verfestigtem": "verfestigt",
    "verfestigten": "verfestigen",
    "verfestigter": "verfestigt",
    "verfestigtere": "verfestigt",
    "verfestigterem": "verfestigt",
    "verfestigteren": "verfestigt",
    "verfestigterer": "verfestigt",
    "verfestigteres": "verfestigt",
    "verfestigtes": "verfestigt",
    "verfestigtest": "verfestigen",
    "verfestigteste": "verfestigt",
    "verfestigtestem": "verfestigt",
    "verfestigtesten": "verfestigt",
    "verfestigtester": "verfestigt",
    "verfestigtestes": "verfestigt",
    "verfestigtet": "verfestigen",
    "verfeuere": "verfeuern",
    "verfeuernd": "verfeuern",
    "verfeuernde": "verfeuernd",
    "verfeuerndem": "verfeuernd",
    "verfeuernden": "verfeuernd",
    "verfeuernder": "verfeuernd",
    "verfeuerndere": "verfeuernd",
    "verfeuernderem": "verfeuernd",
    "verfeuernderen": "verfeuernd",
    "verfeuernderer": "verfeuernd",
    "verfeuernderes": "verfeuernd",
    "verfeuerndes": "verfeuernd",
    "verfeuerndste": "verfeuernd",
    "verfeuerndstem": "verfeuernd",
    "verfeuerndsten": "verfeuernd",
    "verfeuerndster": "verfeuernd",
    "verfeuerndstes": "verfeuernd",
    "verfeuerst": "verfeuern",
    "verfeuert": "verfeuern",
    "verfeuerte": "verfeuern",
    "verfeuertem": "verfeuert",
    "verfeuerten": "verfeuern",
    "verfeuerter": "verfeuert",
    "verfeuertere": "verfeuert",
    "verfeuerterem": "verfeuert",
    "verfeuerteren": "verfeuert",
    "verfeuerterer": "verfeuert",
    "verfeuerteres": "verfeuert",
    "verfeuertes": "verfeuert",
    "verfeuertest": "verfeuern",
    "verfeuerteste": "verfeuert",
    "verfeuertestem": "verfeuert",
    "verfeuertesten": "verfeuert",
    "verfeuertester": "verfeuert",
    "verfeuertestes": "verfeuert",
    "verfeuertet": "verfeuern",
    "verfich": "verfechten",
    "verficht": "verfechten",
    "verfichtst": "verfechten",
    "verfiel": "verfallen",
    "verfiele": "verfallen",
    "verfielen": "verfallen",
    "verfielest": "verfallen",
    "verfielet": "verfallen",
    "verfielst": "verfallen",
    "verfielt": "verfallen",
    "verfilme": "verfilmen",
    "verfilmend": "verfilmen",
    "verfilmende": "verfilmend",
    "verfilmendem": "verfilmend",
    "verfilmenden": "verfilmend",
    "verfilmender": "verfilmend",
    "verfilmendes": "verfilmend",
    "verfilmest": "verfilmen",
    "verfilmet": "verfilmen",
    "verfilmst": "verfilmen",
    "verfilmt": "verfilmen",
    "verfilmte": "verfilmen",
    "verfilmtem": "verfilmt",
    "verfilmten": "verfilmen",
    "verfilmter": "verfilmt",
    "verfilmtes": "verfilmt",
    "verfilmtest": "verfilmen",
    "verfilmtet": "verfilmen",
    "verfing": "verfangen",
    "verfinge": "verfangen",
    "verfingen": "verfangen",
    "verfingest": "verfangen",
    "verfinget": "verfangen",
    "verfingst": "verfangen",
    "verfingt": "verfangen",
    "verflache": "verflachen",
    "verflachend": "verflachen",
    "verflachende": "verflachend",
    "verflachendem": "verflachend",
    "verflachenden": "verflachend",
    "verflachender": "verflachend",
    "verflachendere": "verflachend",
    "verflachenderem": "verflachend",
    "verflachenderen": "verflachend",
    "verflachenderer": "verflachend",
    "verflachenderes": "verflachend",
    "verflachendes": "verflachend",
    "verflachendste": "verflachend",
    "verflachendstem": "verflachend",
    "verflachendsten": "verflachend",
    "verflachendster": "verflachend",
    "verflachendstes": "verflachend",
    "verflachest": "verflachen",
    "verflachet": "verflachen",
    "verflachst": "verflachen",
    "verflacht": "verflachen",
    "verflachte": "verflachen",
    "verflachtem": "verflacht",
    "verflachten": "verflachen",
    "verflachter": "verflacht",
    "verflachtere": "verflacht",
    "verflachterem": "verflacht",
    "verflachteren": "verflacht",
    "verflachterer": "verflacht",
    "verflachteres": "verflacht",
    "verflachtes": "verflacht",
    "verflachtest": "verflachen",
    "verflachteste": "verflacht",
    "verflachtestem": "verflacht",
    "verflachtesten": "verflacht",
    "verflachtester": "verflacht",
    "verflachtestes": "verflacht",
    "verflachtet": "verflachen",
    "verflechte": "verflechten",
    "verflechtend": "verflechten",
    "verflechtende": "verflechtend",
    "verflechtendem": "verflechtend",
    "verflechtenden": "verflechtend",
    "verflechtender": "verflechtend",
    "verflechtendere": "verflechtend",
    "verflechtenderem": "verflechtend",
    "verflechtenderen": "verflechtend",
    "verflechtenderer": "verflechtend",
    "verflechtenderes": "verflechtend",
    "verflechtendes": "verflechtend",
    "verflechtendste": "verflechtend",
    "verflechtendstem": "verflechtend",
    "verflechtendsten": "verflechtend",
    "verflechtendster": "verflechtend",
    "verflechtendstes": "verflechtend",
    "verflechtest": "verflechten",
    "verflechtet": "verflechten",
    "verflich": "verflechten",
    "verflicht": "verflechten",
    "verflichtst": "verflechten",
    "verfliege": "verfliegen",
    "verfliegend": "verfliegen",
    "verfliegende": "verfliegend",
    "verfliegendem": "verfliegend",
    "verfliegenden": "verfliegend",
    "verfliegender": "verfliegend",
    "verfliegendes": "verfliegend",
    "verfliegest": "verfliegen",
    "verflieget": "verfliegen",
    "verfliegst": "verfliegen",
    "verfliegt": "verfliegen",
    "verfließe": "verfließen",
    "verfließend": "verfließen",
    "verfließende": "verfließend",
    "verfließendem": "verfließend",
    "verfließenden": "verfließend",
    "verfließender": "verfließend",
    "verfließendes": "verfließend",
    "verfließest": "verfließen",
    "verfließet": "verfließen",
    "verfließt": "verfließen",
    "verflocht": "verflechten",
    "verflochten": "verflechten",
    "verflochtene": "verflochten",
    "verflochtenem": "verflochten",
    "verflochtenen": "verflochten",
    "verflochtener": "verflochten",
    "verflochtenere": "verflochten",
    "verflochtenerem": "verflochten",
    "verflochteneren": "verflochten",
    "verflochtenerer": "verflochten",
    "verflochteneres": "verflochten",
    "verflochtenes": "verflochten",
    "verflochtenste": "verflochten",
    "verflochtenstem": "verflochten",
    "verflochtensten": "verflochten",
    "verflochtenster": "verflochten",
    "verflochtenstes": "verflochten",
    "verflochtest": "verflechten",
    "verflochtet": "verflechten",
    "verflog": "verfliegen",
    "verflogen": "verfliegen",
    "verflogene": "verflogen",
    "verflogenem": "verflogen",
    "verflogenen": "verflogen",
    "verflogener": "verflogen",
    "verflogenere": "verflogen",
    "verflogenerem": "verflogen",
    "verflogeneren": "verflogen",
    "verflogenerer": "verflogen",
    "verflogeneres": "verflogen",
    "verflogenes": "verflogen",
    "verflogenste": "verflogen",
    "verflogenstem": "verflogen",
    "verflogensten": "verflogen",
    "verflogenster": "verflogen",
    "verflogenstes": "verflogen",
    "verflogst": "verfliegen",
    "verflogt": "verfliegen",
    "verflossen": "verfließen",
    "verflossene": "verflossen",
    "verflossenem": "verflossen",
    "verflossenen": "verflossen",
    "verflossener": "verflossen",
    "verflossenes": "verflossen",
    "verfloß": "verfließen",
    "verfloßt": "verfließen",
    "verfluche": "verfluchen",
    "verfluchend": "verfluchen",
    "verfluchende": "verfluchend",
    "verfluchendem": "verfluchend",
    "verfluchenden": "verfluchend",
    "verfluchender": "verfluchend",
    "verfluchendere": "verfluchend",
    "verfluchenderem": "verfluchend",
    "verfluchenderen": "verfluchend",
    "verfluchenderer": "verfluchend",
    "verfluchenderes": "verfluchend",
    "verfluchendes": "verfluchend",
    "verfluchendste": "verfluchend",
    "verfluchendstem": "verfluchend",
    "verfluchendsten": "verfluchend",
    "verfluchendster": "verfluchend",
    "verfluchendstes": "verfluchend",
    "verfluchest": "verfluchen",
    "verfluchet": "verfluchen",
    "verfluchst": "verfluchen",
    "verflucht": "verfluchen",
    "verfluchte": "verfluchen",
    "verfluchtem": "verflucht",
    "verfluchten": "verfluchen",
    "verfluchter": "verflucht",
    "verfluchtere": "verflucht",
    "verfluchterem": "verflucht",
    "verfluchteren": "verflucht",
    "verfluchterer": "verflucht",
    "verfluchteres": "verflucht",
    "verfluchtes": "verflucht",
    "verfluchtest": "verfluchen",
    "verfluchteste": "verflucht",
    "verfluchtestem": "verflucht",
    "verfluchtesten": "verflucht",
    "verfluchtester": "verflucht",
    "verfluchtestes": "verflucht",
    "verfluchtet": "verfluchen",
    "verflöchte": "verflechten",
    "verflöchten": "verflechten",
    "verflöchtest": "verflechten",
    "verflöchtet": "verflechten",
    "verflöge": "verfliegen",
    "verflögen": "verfliegen",
    "verflögest": "verfliegen",
    "verflöget": "verfliegen",
    "verflösse": "verfließen",
    "verflössen": "verfließen",
    "verflössest": "verfließen",
    "verflösset": "verfließen",
    "verflüchtige": "verflüchtigen",
    "verflüchtigend": "verflüchtigen",
    "verflüchtigende": "verflüchtigend",
    "verflüchtigendem": "verflüchtigend",
    "verflüchtigenden": "verflüchtigend",
    "verflüchtigender": "verflüchtigend",
    "verflüchtigendes": "verflüchtigend",
    "verflüchtigest": "verflüchtigen",
    "verflüchtiget": "verflüchtigen",
    "verflüchtigst": "verflüchtigen",
    "verflüchtigt": "verflüchtigen",
    "verflüchtigte": "verflüchtigen",
    "verflüchtigtem": "verflüchtigt",
    "verflüchtigten": "verflüchtigen",
    "verflüchtigter": "verflüchtigt",
    "verflüchtigtes": "verflüchtigt",
    "verflüchtigtest": "verflüchtigen",
    "verflüchtigtet": "verflüchtigen",
    "verflüssige": "verflüssigen",
    "verflüssigend": "verflüssigen",
    "verflüssigende": "verflüssigend",
    "verflüssigendem": "verflüssigend",
    "verflüssigenden": "verflüssigend",
    "verflüssigender": "verflüssigend",
    "verflüssigendes": "verflüssigend",
    "verflüssigest": "verflüssigen",
    "verflüssiget": "verflüssigen",
    "verflüssigst": "verflüssigen",
    "verflüssigt": "verflüssigen",
    "verflüssigte": "verflüssigen",
    "verflüssigtem": "verflüssigt",
    "verflüssigten": "verflüssigen",
    "verflüssigter": "verflüssigt",
    "verflüssigtes": "verflüssigt",
    "verflüssigtest": "verflüssigen",
    "verflüssigtet": "verflüssigen",
    "verfocht": "verfechten",
    "verfochten": "verfechten",
    "verfochtene": "verfochten",
    "verfochtenem": "verfochten",
    "verfochtenen": "verfochten",
    "verfochtener": "verfochten",
    "verfochtenes": "verfochten",
    "verfochtest": "verfechten",
    "verfochtet": "verfechten",
    "verfolge": "verfolgen",
    "verfolgend": "verfolgen",
    "verfolgende": "verfolgend",
    "verfolgendem": "verfolgend",
    "verfolgenden": "verfolgend",
    "verfolgender": "verfolgend",
    "verfolgendes": "verfolgend",
    "verfolgest": "verfolgen",
    "verfolget": "verfolgen",
    "verfolgst": "verfolgen",
    "verfolgt": "verfolgen",
    "verfolgte": "verfolgen",
    "verfolgtem": "verfolgt",
    "verfolgten": "verfolgen",
    "verfolgter": "verfolgt",
    "verfolgtere": "verfolgt",
    "verfolgterem": "verfolgt",
    "verfolgteren": "verfolgt",
    "verfolgterer": "verfolgt",
    "verfolgteres": "verfolgt",
    "verfolgtes": "verfolgt",
    "verfolgtest": "verfolgen",
    "verfolgteste": "verfolgt",
    "verfolgtestem": "verfolgt",
    "verfolgtesten": "verfolgt",
    "verfolgtester": "verfolgt",
    "verfolgtestes": "verfolgt",
    "verfolgtet": "verfolgen",
    "verforme": "verformen",
    "verformend": "verformen",
    "verformende": "verformend",
    "verformendem": "verformend",
    "verformenden": "verformend",
    "verformender": "verformend",
    "verformendes": "verformend",
    "verformest": "verformen",
    "verformet": "verformen",
    "verformst": "verformen",
    "verformt": "verformen",
    "verformte": "verformen",
    "verformtem": "verformt",
    "verformten": "verformen",
    "verformter": "verformt",
    "verformtere": "verformt",
    "verformterem": "verformt",
    "verformteren": "verformt",
    "verformterer": "verformt",
    "verformteres": "verformt",
    "verformtes": "verformt",
    "verformtest": "verformen",
    "verformteste": "verformt",
    "verformtestem": "verformt",
    "verformtesten": "verformt",
    "verformtester": "verformt",
    "verformtestes": "verformt",
    "verformtet": "verformen",
    "verfrachte": "verfrachten",
    "verfrachtend": "verfrachten",
    "verfrachtende": "verfrachtend",
    "verfrachtendem": "verfrachtend",
    "verfrachtenden": "verfrachtend",
    "verfrachtender": "verfrachtend",
    "verfrachtendes": "verfrachtend",
    "verfrachtest": "verfrachten",
    "verfrachtet": "verfrachten",
    "verfrachtete": "verfrachten",
    "verfrachtetem": "verfrachtet",
    "verfrachteten": "verfrachten",
    "verfrachteter": "verfrachtet",
    "verfrachtetes": "verfrachtet",
    "verfrachtetest": "verfrachten",
    "verfrachtetet": "verfrachten",
    "verfranse": "verfransen",
    "verfransend": "verfransen",
    "verfransende": "verfransend",
    "verfransendem": "verfransend",
    "verfransenden": "verfransend",
    "verfransender": "verfransend",
    "verfransendere": "verfransend",
    "verfransenderem": "verfransend",
    "verfransenderen": "verfransend",
    "verfransenderer": "verfransend",
    "verfransenderes": "verfransend",
    "verfransendes": "verfransend",
    "verfransendste": "verfransend",
    "verfransendstem": "verfransend",
    "verfransendsten": "verfransend",
    "verfransendster": "verfransend",
    "verfransendstes": "verfransend",
    "verfransest": "verfransen",
    "verfranset": "verfransen",
    "verfranst": "verfransen",
    "verfranste": "verfransen",
    "verfranstem": "verfranst",
    "verfransten": "verfransen",
    "verfranster": "verfranst",
    "verfranstere": "verfranst",
    "verfransterem": "verfranst",
    "verfransteren": "verfranst",
    "verfransterer": "verfranst",
    "verfransteres": "verfranst",
    "verfranstes": "verfranst",
    "verfranstest": "verfransen",
    "verfransteste": "verfranst",
    "verfranstestem": "verfranst",
    "verfranstesten": "verfranst",
    "verfranstester": "verfranst",
    "verfranstestes": "verfranst",
    "verfranstet": "verfransen",
    "verfranze": "verfranzen",
    "verfranzend": "verfranzen",
    "verfranzende": "verfranzend",
    "verfranzendem": "verfranzend",
    "verfranzenden": "verfranzend",
    "verfranzender": "verfranzend",
    "verfranzendere": "verfranzend",
    "verfranzenderem": "verfranzend",
    "verfranzenderen": "verfranzend",
    "verfranzenderer": "verfranzend",
    "verfranzenderes": "verfranzend",
    "verfranzendes": "verfranzend",
    "verfranzendste": "verfranzend",
    "verfranzendstem": "verfranzend",
    "verfranzendsten": "verfranzend",
    "verfranzendster": "verfranzend",
    "verfranzendstes": "verfranzend",
    "verfranzest": "verfranzen",
    "verfranzet": "verfranzen",
    "verfranzt": "verfranzen",
    "verfranzte": "verfranzen",
    "verfranztem": "verfranzt",
    "verfranzten": "verfranzen",
    "verfranzter": "verfranzt",
    "verfranztere": "verfranzt",
    "verfranzterem": "verfranzt",
    "verfranzteren": "verfranzt",
    "verfranzterer": "verfranzt",
    "verfranzteres": "verfranzt",
    "verfranztes": "verfranzt",
    "verfranztest": "verfranzen",
    "verfranzteste": "verfranzt",
    "verfranztestem": "verfranzt",
    "verfranztesten": "verfranzt",
    "verfranztester": "verfranzt",
    "verfranztestes": "verfranzt",
    "verfranztet": "verfranzen",
    "verfremde": "verfremden",
    "verfremdend": "verfremden",
    "verfremdende": "verfremdend",
    "verfremdendem": "verfremdend",
    "verfremdenden": "verfremdend",
    "verfremdender": "verfremdend",
    "verfremdendere": "verfremdend",
    "verfremdenderem": "verfremdend",
    "verfremdenderen": "verfremdend",
    "verfremdenderer": "verfremdend",
    "verfremdenderes": "verfremdend",
    "verfremdendes": "verfremdend",
    "verfremdendste": "verfremdend",
    "verfremdendstem": "verfremdend",
    "verfremdendsten": "verfremdend",
    "verfremdendster": "verfremdend",
    "verfremdendstes": "verfremdend",
    "verfremdest": "verfremden",
    "verfremdet": "verfremden",
    "verfremdete": "verfremden",
    "verfremdetem": "verfremdet",
    "verfremdeten": "verfremden",
    "verfremdeter": "verfremdet",
    "verfremdetere": "verfremdet",
    "verfremdeterem": "verfremdet",
    "verfremdeteren": "verfremdet",
    "verfremdeterer": "verfremdet",
    "verfremdeteres": "verfremdet",
    "verfremdetes": "verfremdet",
    "verfremdetest": "verfremden",
    "verfremdeteste": "verfremdet",
    "verfremdetestem": "verfremdet",
    "verfremdetesten": "verfremdet",
    "verfremdetester": "verfremdet",
    "verfremdetestes": "verfremdet",
    "verfremdetet": "verfremden",
    "verfrorenem": "verfroren",
    "verfrorenen": "verfroren",
    "verfrorener": "verfroren",
    "verfrorenere": "verfroren",
    "verfrorenerem": "verfroren",
    "verfroreneren": "verfroren",
    "verfrorenerer": "verfroren",
    "verfroreneres": "verfroren",
    "verfrorenes": "verfroren",
    "verfrorenste": "verfroren",
    "verfrorenstem": "verfroren",
    "verfrorensten": "verfroren",
    "verfrorenster": "verfroren",
    "verfrorenstes": "verfroren",
    "verfrühe": "verfrühen",
    "verfrühend": "verfrühen",
    "verfrühende": "verfrühend",
    "verfrühendem": "verfrühend",
    "verfrühenden": "verfrühend",
    "verfrühender": "verfrühend",
    "verfrühendere": "verfrühend",
    "verfrühenderem": "verfrühend",
    "verfrühenderen": "verfrühend",
    "verfrühenderer": "verfrühend",
    "verfrühenderes": "verfrühend",
    "verfrühendes": "verfrühend",
    "verfrühendste": "verfrühend",
    "verfrühendstem": "verfrühend",
    "verfrühendsten": "verfrühend",
    "verfrühendster": "verfrühend",
    "verfrühendstes": "verfrühend",
    "verfrühest": "verfrühen",
    "verfrühet": "verfrühen",
    "verfrühst": "verfrühen",
    "verfrüht": "verfrühen",
    "verfrühte": "verfrühen",
    "verfrühtem": "verfrüht",
    "verfrühten": "verfrühen",
    "verfrühter": "verfrüht",
    "verfrühtere": "verfrüht",
    "verfrühterem": "verfrüht",
    "verfrühteren": "verfrüht",
    "verfrühterer": "verfrüht",
    "verfrühteres": "verfrüht",
    "verfrühtes": "verfrüht",
    "verfrühtest": "verfrühen",
    "verfrühteste": "verfrüht",
    "verfrühtestem": "verfrüht",
    "verfrühtesten": "verfrüht",
    "verfrühtester": "verfrüht",
    "verfrühtestes": "verfrüht",
    "verfrühtet": "verfrühen",
    "verfuge": "verfugen",
    "verfugend": "verfugen",
    "verfugende": "verfugend",
    "verfugendem": "verfugend",
    "verfugenden": "verfugend",
    "verfugender": "verfugend",
    "verfugendere": "verfugend",
    "verfugenderem": "verfugend",
    "verfugenderen": "verfugend",
    "verfugenderer": "verfugend",
    "verfugenderes": "verfugend",
    "verfugendes": "verfugend",
    "verfugendste": "verfugend",
    "verfugendstem": "verfugend",
    "verfugendsten": "verfugend",
    "verfugendster": "verfugend",
    "verfugendstes": "verfugend",
    "verfugest": "verfugen",
    "verfuget": "verfugen",
    "verfugst": "verfugen",
    "verfugt": "verfugen",
    "verfugte": "verfugen",
    "verfugtem": "verfugt",
    "verfugten": "verfugen",
    "verfugter": "verfugt",
    "verfugtere": "verfugt",
    "verfugterem": "verfugt",
    "verfugteren": "verfugt",
    "verfugterer": "verfugt",
    "verfugteres": "verfugt",
    "verfugtes": "verfugt",
    "verfugtest": "verfugen",
    "verfugteste": "verfugt",
    "verfugtestem": "verfugt",
    "verfugtesten": "verfugt",
    "verfugtester": "verfugt",
    "verfugtestes": "verfugt",
    "verfugtet": "verfugen",
    "verfuhr": "verfahren",
    "verfuhren": "verfahren",
    "verfuhrst": "verfahren",
    "verfuhrt": "verfahren",
    "verfummele": "verfummeln",
    "verfummelnd": "verfummeln",
    "verfummelnde": "verfummelnd",
    "verfummelndem": "verfummelnd",
    "verfummelnden": "verfummelnd",
    "verfummelnder": "verfummelnd",
    "verfummelndere": "verfummelnd",
    "verfummelnderem": "verfummelnd",
    "verfummelnderen": "verfummelnd",
    "verfummelnderer": "verfummelnd",
    "verfummelnderes": "verfummelnd",
    "verfummelndes": "verfummelnd",
    "verfummelndste": "verfummelnd",
    "verfummelndstem": "verfummelnd",
    "verfummelndsten": "verfummelnd",
    "verfummelndster": "verfummelnd",
    "verfummelndstes": "verfummelnd",
    "verfummelst": "verfummeln",
    "verfummelt": "verfummeln",
    "verfummelte": "verfummeln",
    "verfummeltem": "verfummelt",
    "verfummelten": "verfummeln",
    "verfummelter": "verfummelt",
    "verfummeltere": "verfummelt",
    "verfummelterem": "verfummelt",
    "verfummelteren": "verfummelt",
    "verfummelterer": "verfummelt",
    "verfummelteres": "verfummelt",
    "verfummeltes": "verfummelt",
    "verfummeltest": "verfummeln",
    "verfummelteste": "verfummelt",
    "verfummeltestem": "verfummelt",
    "verfummeltesten": "verfummelt",
    "verfummeltester": "verfummelt",
    "verfummeltestes": "verfummelt",
    "verfummeltet": "verfummeln",
    "verfummle": "verfummeln",
    "verfuttere": "verfuttern",
    "verfutternd": "verfuttern",
    "verfutternde": "verfutternd",
    "verfutterndem": "verfutternd",
    "verfutternden": "verfutternd",
    "verfutternder": "verfutternd",
    "verfutterndes": "verfutternd",
    "verfutterst": "verfuttern",
    "verfuttert": "verfuttern",
    "verfutterte": "verfuttern",
    "verfuttertem": "verfuttert",
    "verfutterten": "verfuttern",
    "verfutterter": "verfuttert",
    "verfuttertere": "verfuttert",
    "verfutterterem": "verfuttert",
    "verfutterteren": "verfuttert",
    "verfutterterer": "verfuttert",
    "verfutterteres": "verfuttert",
    "verfuttertes": "verfuttert",
    "verfuttertest": "verfuttern",
    "verfutterteste": "verfuttert",
    "verfuttertestem": "verfuttert",
    "verfuttertesten": "verfuttert",
    "verfuttertester": "verfuttert",
    "verfuttertestes": "verfuttert",
    "verfuttertet": "verfuttern",
    "verfährst": "verfahren",
    "verfährt": "verfahren",
    "verfällst": "verfallen",
    "verfällt": "verfallen",
    "verfälsche": "verfälschen",
    "verfälschend": "verfälschen",
    "verfälschende": "verfälschend",
    "verfälschendem": "verfälschend",
    "verfälschenden": "verfälschend",
    "verfälschender": "verfälschend",
    "verfälschendes": "verfälschend",
    "verfälschest": "verfälschen",
    "verfälschet": "verfälschen",
    "verfälschst": "verfälschen",
    "verfälscht": "verfälschen",
    "verfälschte": "verfälschen",
    "verfälschtem": "verfälscht",
    "verfälschten": "verfälschen",
    "verfälschter": "verfälscht",
    "verfälschtere": "verfälscht",
    "verfälschterem": "verfälscht",
    "verfälschteren": "verfälscht",
    "verfälschterer": "verfälscht",
    "verfälschteres": "verfälscht",
    "verfälschtes": "verfälscht",
    "verfälschtest": "verfälschen",
    "verfälschteste": "verfälscht",
    "verfälschtestem": "verfälscht",
    "verfälschtesten": "verfälscht",
    "verfälschtester": "verfälscht",
    "verfälschtestes": "verfälscht",
    "verfälschtet": "verfälschen",
    "verfängliche": "verfänglich",
    "verfänglichem": "verfänglich",
    "verfänglichen": "verfänglich",
    "verfänglicher": "verfänglich",
    "verfänglichere": "verfänglich",
    "verfänglicherem": "verfänglich",
    "verfänglicheren": "verfänglich",
    "verfänglicherer": "verfänglich",
    "verfänglicheres": "verfänglich",
    "verfängliches": "verfänglich",
    "verfänglichste": "verfänglich",
    "verfänglichstem": "verfänglich",
    "verfänglichsten": "verfänglich",
    "verfänglichster": "verfänglich",
    "verfänglichstes": "verfänglich",
    "verfängst": "verfangen",
    "verfängt": "verfangen",
    "verfärbe": "verfärben",
    "verfärbend": "verfärben",
    "verfärbende": "verfärbend",
    "verfärbendem": "verfärbend",
    "verfärbenden": "verfärbend",
    "verfärbender": "verfärbend",
    "verfärbendere": "verfärbend",
    "verfärbenderem": "verfärbend",
    "verfärbenderen": "verfärbend",
    "verfärbenderer": "verfärbend",
    "verfärbenderes": "verfärbend",
    "verfärbendes": "verfärbend",
    "verfärbendste": "verfärbend",
    "verfärbendstem": "verfärbend",
    "verfärbendsten": "verfärbend",
    "verfärbendster": "verfärbend",
    "verfärbendstes": "verfärbend",
    "verfärbest": "verfärben",
    "verfärbet": "verfärben",
    "verfärbst": "verfärben",
    "verfärbt": "verfärben",
    "verfärbte": "verfärben",
    "verfärbtem": "verfärbt",
    "verfärbten": "verfärben",
    "verfärbter": "verfärbt",
    "verfärbtere": "verfärbt",
    "verfärbterem": "verfärbt",
    "verfärbteren": "verfärbt",
    "verfärbterer": "verfärbt",
    "verfärbteres": "verfärbt",
    "verfärbtes": "verfärbt",
    "verfärbtest": "verfärben",
    "verfärbteste": "verfärbt",
    "verfärbtestem": "verfärbt",
    "verfärbtesten": "verfärbt",
    "verfärbtester": "verfärbt",
    "verfärbtestes": "verfärbt",
    "verfärbtet": "verfärben",
    "verföchte": "verfechten",
    "verföchten": "verfechten",
    "verföchtest": "verfechten",
    "verföchtet": "verfechten",
    "verfügbare": "verfügbar",
    "verfügbarem": "verfügbar",
    "verfügbaren": "verfügbar",
    "verfügbarer": "verfügbar",
    "verfügbarere": "verfügbar",
    "verfügbarerem": "verfügbar",
    "verfügbareren": "verfügbar",
    "verfügbarerer": "verfügbar",
    "verfügbareres": "verfügbar",
    "verfügbares": "verfügbar",
    "verfügbarste": "verfügbar",
    "verfügbarstem": "verfügbar",
    "verfügbarsten": "verfügbar",
    "verfügbarster": "verfügbar",
    "verfügbarstes": "verfügbar",
    "verfüge": "verfügen",
    "verfügend": "verfügen",
    "verfügendem": "verfügend",
    "verfügender": "verfügend",
    "verfügendes": "verfügend",
    "verfügest": "verfügen",
    "verfüget": "verfügen",
    "verfügst": "verfügen",
    "verfügt": "verfügen",
    "verfügte": "verfügen",
    "verfügtem": "verfügt",
    "verfügten": "verfügt",
    "verfügter": "verfügt",
    "verfügtes": "verfügt",
    "verfügtest": "verfügen",
    "verfügtet": "verfügen",
    "verfügungsberechtigtem": "verfügungsberechtigt",
    "verfügungsberechtigten": "verfügungsberechtigt",
    "verfügungsberechtigter": "verfügungsberechtigt",
    "verfügungsberechtigtes": "verfügungsberechtigt",
    "verführe": "verführen",
    "verführen": "verfahren",
    "verführend": "verführen",
    "verführende": "verführend",
    "verführendem": "verführend",
    "verführenden": "verführend",
    "verführender": "verführend",
    "verführendere": "verführend",
    "verführenderem": "verführend",
    "verführenderen": "verführend",
    "verführenderer": "verführend",
    "verführenderes": "verführend",
    "verführendes": "verführend",
    "verführendste": "verführend",
    "verführendstem": "verführend",
    "verführendsten": "verführend",
    "verführendster": "verführend",
    "verführendstes": "verführend",
    "verführerischem": "verführerisch",
    "verführerischen": "verführerisch",
    "verführerischer": "verführerisch",
    "verführerischere": "verführerisch",
    "verführerischerem": "verführerisch",
    "verführerischeren": "verführerisch",
    "verführerischerer": "verführerisch",
    "verführerischeres": "verführerisch",
    "verführerisches": "verführerisch",
    "verführerischste": "verführerisch",
    "verführerischstem": "verführerisch",
    "verführerischsten": "verführerisch",
    "verführerischster": "verführerisch",
    "verführerischstes": "verführerisch",
    "verführest": "verführen",
    "verführet": "verführen",
    "verführst": "verführen",
    "verführt": "verführen",
    "verführte": "verführen",
    "verführtem": "verführt",
    "verführten": "verführen",
    "verführter": "verführt",
    "verführtere": "verführt",
    "verführterem": "verführt",
    "verführteren": "verführt",
    "verführterer": "verführt",
    "verführteres": "verführt",
    "verführtes": "verführt",
    "verführtest": "verführen",
    "verführteste": "verführt",
    "verführtestem": "verführt",
    "verführtesten": "verführt",
    "verführtester": "verführt",
    "verführtestes": "verführt",
    "verführtet": "verführen",
    "verfüttere": "verfüttern",
    "verfütternd": "verfüttern",
    "verfütterndem": "verfütternd",
    "verfütternder": "verfütternd",
    "verfütterndere": "verfütternd",
    "verfütternderem": "verfütternd",
    "verfütternderen": "verfütternd",
    "verfütternderer": "verfütternd",
    "verfütternderes": "verfütternd",
    "verfütterndes": "verfütternd",
    "verfütterndste": "verfütternd",
    "verfütterndstem": "verfütternd",
    "verfütterndsten": "verfütternd",
    "verfütterndster": "verfütternd",
    "verfütterndstes": "verfütternd",
    "verfütterst": "verfüttern",
    "verfüttert": "verfüttern",
    "verfütterte": "verfüttern",
    "verfüttertem": "verfüttert",
    "verfütterten": "verfüttert",
    "verfütterter": "verfüttert",
    "verfüttertes": "verfüttert",
    "verfüttertest": "verfüttern",
    "verfüttertet": "verfüttern",
    "vergab": "vergeben",
    "vergaben": "vergeben",
    "vergabst": "vergeben",
    "vergabt": "vergeben",
    "vergalt": "vergelten",
    "vergalten": "vergelten",
    "vergaltest": "vergelten",
    "vergaltet": "vergelten",
    "vergammele": "vergammeln",
    "vergammelnd": "vergammeln",
    "vergammelnde": "vergammelnd",
    "vergammelndem": "vergammelnd",
    "vergammelnden": "vergammelnd",
    "vergammelnder": "vergammelnd",
    "vergammelndere": "vergammelnd",
    "vergammelnderem": "vergammelnd",
    "vergammelnderen": "vergammelnd",
    "vergammelnderer": "vergammelnd",
    "vergammelnderes": "vergammelnd",
    "vergammelndes": "vergammelnd",
    "vergammelndste": "vergammelnd",
    "vergammelndstem": "vergammelnd",
    "vergammelndsten": "vergammelnd",
    "vergammelndster": "vergammelnd",
    "vergammelndstes": "vergammelnd",
    "vergammelst": "vergammeln",
    "vergammelt": "vergammeln",
    "vergammelte": "vergammeln",
    "vergammeltem": "vergammelt",
    "vergammelten": "vergammeln",
    "vergammelter": "vergammelt",
    "vergammeltere": "vergammelt",
    "vergammelterem": "vergammelt",
    "vergammelteren": "vergammelt",
    "vergammelterer": "vergammelt",
    "vergammelteres": "vergammelt",
    "vergammeltes": "vergammelt",
    "vergammeltest": "vergammeln",
    "vergammelteste": "vergammelt",
    "vergammeltestem": "vergammelt",
    "vergammeltesten": "vergammelt",
    "vergammeltester": "vergammelt",
    "vergammeltestes": "vergammelt",
    "vergammeltet": "vergammeln",
    "vergammle": "vergammeln",
    "vergangen": "vergehen",
    "vergangene": "vergangen",
    "vergangenem": "vergangen",
    "vergangenen": "vergangen",
    "vergangener": "vergangen",
    "vergangenes": "vergangen",
    "vergase": "vergasen",
    "vergasend": "vergasen",
    "vergasende": "vergasend",
    "vergasendem": "vergasend",
    "vergasenden": "vergasend",
    "vergasender": "vergasend",
    "vergasendes": "vergasend",
    "vergasest": "vergasen",
    "vergaset": "vergasen",
    "vergast": "vergasen",
    "vergaste": "vergasen",
    "vergastem": "vergast",
    "vergasten": "vergasen",
    "vergaster": "vergast",
    "vergastes": "vergast",
    "vergastest": "vergasen",
    "vergastet": "vergasen",
    "vergaß": "vergessen",
    "vergaßen": "vergessen",
    "vergaßt": "vergessen",
    "vergebe": "vergeben",
    "vergebend": "vergeben",
    "vergebende": "vergebend",
    "vergebendem": "vergebend",
    "vergebenden": "vergebend",
    "vergebender": "vergebend",
    "vergebendes": "vergebend",
    "vergebene": "vergeben",
    "vergebenem": "vergeben",
    "vergebenen": "vergeben",
    "vergebener": "vergeben",
    "vergebenes": "vergeben",
    "vergebest": "vergeben",
    "vergebet": "vergeben",
    "vergebliche": "vergeblich",
    "vergeblichem": "vergeblich",
    "vergeblichen": "vergeblich",
    "vergeblicher": "vergeblich",
    "vergebliches": "vergeblich",
    "vergebt": "vergeben",
    "vergefallen": "verfallen",
    "vergegenwärtige": "vergegenwärtigen",
    "vergegenwärtigend": "vergegenwärtigen",
    "vergegenwärtigende": "vergegenwärtigend",
    "vergegenwärtigendem": "vergegenwärtigend",
    "vergegenwärtigenden": "vergegenwärtigend",
    "vergegenwärtigender": "vergegenwärtigend",
    "vergegenwärtigendes": "vergegenwärtigend",
    "vergegenwärtigest": "vergegenwärtigen",
    "vergegenwärtiget": "vergegenwärtigen",
    "vergegenwärtigst": "vergegenwärtigen",
    "vergegenwärtigt": "vergegenwärtigen",
    "vergegenwärtigte": "vergegenwärtigen",
    "vergegenwärtigtem": "vergegenwärtigt",
    "vergegenwärtigten": "vergegenwärtigen",
    "vergegenwärtigter": "vergegenwärtigt",
    "vergegenwärtigtes": "vergegenwärtigt",
    "vergegenwärtigtest": "vergegenwärtigen",
    "vergegenwärtigtet": "vergegenwärtigen",
    "vergehe": "vergehen",
    "vergehend": "vergehen",
    "vergehende": "vergehend",
    "vergehendem": "vergehend",
    "vergehenden": "vergehend",
    "vergehender": "vergehend",
    "vergehendes": "vergehend",
    "vergehest": "vergehen",
    "vergehet": "vergehen",
    "vergehst": "vergehen",
    "vergeht": "vergehen",
    "vergeige": "vergeigen",
    "vergeigend": "vergeigen",
    "vergeigende": "vergeigend",
    "vergeigendem": "vergeigend",
    "vergeigenden": "vergeigend",
    "vergeigender": "vergeigend",
    "vergeigendes": "vergeigend",
    "vergeigest": "vergeigen",
    "vergeiget": "vergeigen",
    "vergeigst": "vergeigen",
    "vergeigt": "vergeigen",
    "vergeigte": "vergeigen",
    "vergeigtem": "vergeigt",
    "vergeigten": "vergeigen",
    "vergeigter": "vergeigt",
    "vergeigtes": "vergeigt",
    "vergeigtest": "vergeigen",
    "vergeigtet": "vergeigen",
    "vergelte": "vergelten",
    "vergeltend": "vergelten",
    "vergeltende": "vergeltend",
    "vergeltendem": "vergeltend",
    "vergeltenden": "vergeltend",
    "vergeltender": "vergeltend",
    "vergeltendes": "vergeltend",
    "vergeltest": "vergelten",
    "vergeltet": "vergelten",
    "vergesse": "vergessen",
    "vergessend": "vergessen",
    "vergessende": "vergessend",
    "vergessendem": "vergessend",
    "vergessenden": "vergessend",
    "vergessender": "vergessend",
    "vergessendes": "vergessend",
    "vergessene": "vergessen",
    "vergessenem": "vergessen",
    "vergessenen": "vergessen",
    "vergessener": "vergessen",
    "vergessenes": "vergessen",
    "vergessest": "vergessen",
    "vergesset": "vergessen",
    "vergeude": "vergeuden",
    "vergeudend": "vergeuden",
    "vergeudende": "vergeudend",
    "vergeudendem": "vergeudend",
    "vergeudenden": "vergeudend",
    "vergeudender": "vergeudend",
    "vergeudendere": "vergeudend",
    "vergeudenderem": "vergeudend",
    "vergeudenderen": "vergeudend",
    "vergeudenderer": "vergeudend",
    "vergeudenderes": "vergeudend",
    "vergeudendes": "vergeudend",
    "vergeudendste": "vergeudend",
    "vergeudendstem": "vergeudend",
    "vergeudendsten": "vergeudend",
    "vergeudendster": "vergeudend",
    "vergeudendstes": "vergeudend",
    "vergeudest": "vergeuden",
    "vergeudet": "vergeuden",
    "vergeudete": "vergeuden",
    "vergeudetem": "vergeudet",
    "vergeudeten": "vergeuden",
    "vergeudeter": "vergeudet",
    "vergeudetere": "vergeudet",
    "vergeudeterem": "vergeudet",
    "vergeudeteren": "vergeudet",
    "vergeudeterer": "vergeudet",
    "vergeudeteres": "vergeudet",
    "vergeudetes": "vergeudet",
    "vergeudetest": "vergeuden",
    "vergeudeteste": "vergeudet",
    "vergeudetestem": "vergeudet",
    "vergeudetesten": "vergeudet",
    "vergeudetester": "vergeudet",
    "vergeudetestes": "vergeudet",
    "vergeudetet": "vergeuden",
    "vergewaltige": "vergewaltigen",
    "vergewaltigend": "vergewaltigen",
    "vergewaltigende": "vergewaltigend",
    "vergewaltigendem": "vergewaltigend",
    "vergewaltigenden": "vergewaltigend",
    "vergewaltigender": "vergewaltigend",
    "vergewaltigendes": "vergewaltigend",
    "vergewaltigest": "vergewaltigen",
    "vergewaltiget": "vergewaltigen",
    "vergewaltigst": "vergewaltigen",
    "vergewaltigt": "vergewaltigen",
    "vergewaltigte": "vergewaltigen",
    "vergewaltigtem": "vergewaltigt",
    "vergewaltigten": "vergewaltigen",
    "vergewaltigter": "vergewaltigt",
    "vergewaltigtes": "vergewaltigt",
    "vergewaltigtest": "vergewaltigen",
    "vergewaltigtet": "vergewaltigen",
    "vergewissere": "vergewissern",
    "vergewissernd": "vergewissern",
    "vergewissernde": "vergewissernd",
    "vergewisserndem": "vergewissernd",
    "vergewissernden": "vergewissernd",
    "vergewissernder": "vergewissernd",
    "vergewisserndes": "vergewissernd",
    "vergewisserst": "vergewissern",
    "vergewissert": "vergewissern",
    "vergewisserte": "vergewissern",
    "vergewissertem": "vergewissert",
    "vergewisserten": "vergewissern",
    "vergewisserter": "vergewissert",
    "vergewissertes": "vergewissert",
    "vergewissertest": "vergewissern",
    "vergewissertet": "vergewissern",
    "vergeßliche": "vergeßlich",
    "vergeßlichem": "vergeßlich",
    "vergeßlichen": "vergeßlich",
    "vergeßlicher": "vergeßlich",
    "vergeßlichere": "vergeßlich",
    "vergeßlicherem": "vergeßlich",
    "vergeßlicheren": "vergeßlich",
    "vergeßlicherer": "vergeßlich",
    "vergeßlicheres": "vergeßlich",
    "vergeßliches": "vergeßlich",
    "vergeßlichste": "vergeßlich",
    "vergeßlichstem": "vergeßlich",
    "vergeßlichsten": "vergeßlich",
    "vergeßlichster": "vergeßlich",
    "vergeßlichstes": "vergeßlich",
    "vergeßt": "vergessen",
    "vergib": "vergeben",
    "vergibst": "vergeben",
    "vergibt": "vergeben",
    "vergieße": "vergießen",
    "vergießend": "vergießen",
    "vergießende": "vergießend",
    "vergießendem": "vergießend",
    "vergießenden": "vergießend",
    "vergießender": "vergießend",
    "vergießendes": "vergießend",
    "vergießest": "vergießen",
    "vergießet": "vergießen",
    "vergießt": "vergießen",
    "vergifte": "vergiften",
    "vergiftend": "vergiften",
    "vergiftende": "vergiftend",
    "vergiftendem": "vergiftend",
    "vergiftenden": "vergiftend",
    "vergiftender": "vergiftend",
    "vergiftendere": "vergiftend",
    "vergiftenderem": "vergiftend",
    "vergiftenderen": "vergiftend",
    "vergiftenderer": "vergiftend",
    "vergiftenderes": "vergiftend",
    "vergiftendes": "vergiftend",
    "vergiftendste": "vergiftend",
    "vergiftendstem": "vergiftend",
    "vergiftendsten": "vergiftend",
    "vergiftendster": "vergiftend",
    "vergiftendstes": "vergiftend",
    "vergiftest": "vergiften",
    "vergiftet": "vergiften",
    "vergiftete": "vergiften",
    "vergiftetem": "vergiftet",
    "vergifteten": "vergiften",
    "vergifteter": "vergiftet",
    "vergiftetere": "vergiftet",
    "vergifteterem": "vergiftet",
    "vergifteteren": "vergiftet",
    "vergifteterer": "vergiftet",
    "vergifteteres": "vergiftet",
    "vergiftetes": "vergiftet",
    "vergiftetest": "vergiften",
    "vergifteteste": "vergiftet",
    "vergiftetestem": "vergiftet",
    "vergiftetesten": "vergiftet",
    "vergiftetester": "vergiftet",
    "vergiftetestes": "vergiftet",
    "vergiftetet": "vergiften",
    "vergilbe": "vergilben",
    "vergilbend": "vergilben",
    "vergilbende": "vergilbend",
    "vergilbendem": "vergilbend",
    "vergilbenden": "vergilbend",
    "vergilbender": "vergilbend",
    "vergilbendere": "vergilbend",
    "vergilbenderem": "vergilbend",
    "vergilbenderen": "vergilbend",
    "vergilbenderer": "vergilbend",
    "vergilbenderes": "vergilbend",
    "vergilbendes": "vergilbend",
    "vergilbendste": "vergilbend",
    "vergilbendstem": "vergilbend",
    "vergilbendsten": "vergilbend",
    "vergilbendster": "vergilbend",
    "vergilbendstes": "vergilbend",
    "vergilbest": "vergilben",
    "vergilbet": "vergilben",
    "vergilbst": "vergilben",
    "vergilbt": "vergilben",
    "vergilbte": "vergilben",
    "vergilbtem": "vergilbt",
    "vergilbten": "vergilben",
    "vergilbter": "vergilbt",
    "vergilbtere": "vergilbt",
    "vergilbterem": "vergilbt",
    "vergilbteren": "vergilbt",
    "vergilbterer": "vergilbt",
    "vergilbteres": "vergilbt",
    "vergilbtes": "vergilbt",
    "vergilbtest": "vergilben",
    "vergilbteste": "vergilbt",
    "vergilbtestem": "vergilbt",
    "vergilbtesten": "vergilbt",
    "vergilbtester": "vergilbt",
    "vergilbtestes": "vergilbt",
    "vergilbtet": "vergilben",
    "vergilt": "vergelten",
    "vergiltst": "vergelten",
    "verging": "vergehen",
    "verginge": "vergehen",
    "vergingen": "vergehen",
    "vergingest": "vergehen",
    "verginget": "vergehen",
    "vergingst": "vergehen",
    "vergingt": "vergehen",
    "vergittere": "vergittern",
    "vergitternd": "vergittern",
    "vergitternde": "vergitternd",
    "vergitterndem": "vergitternd",
    "vergitternden": "vergitternd",
    "vergitternder": "vergitternd",
    "vergitterndere": "vergitternd",
    "vergitternderem": "vergitternd",
    "vergitternderen": "vergitternd",
    "vergitternderer": "vergitternd",
    "vergitternderes": "vergitternd",
    "vergitterndes": "vergitternd",
    "vergitterndste": "vergitternd",
    "vergitterndstem": "vergitternd",
    "vergitterndsten": "vergitternd",
    "vergitterndster": "vergitternd",
    "vergitterndstes": "vergitternd",
    "vergitterst": "vergittern",
    "vergittert": "vergittern",
    "vergitterte": "vergittern",
    "vergittertem": "vergittert",
    "vergitterten": "vergittern",
    "vergitterter": "vergittert",
    "vergittertere": "vergittert",
    "vergitterterem": "vergittert",
    "vergitterteren": "vergittert",
    "vergitterterer": "vergittert",
    "vergitterteres": "vergittert",
    "vergittertes": "vergittert",
    "vergittertest": "vergittern",
    "vergitterteste": "vergittert",
    "vergittertestem": "vergittert",
    "vergittertesten": "vergittert",
    "vergittertester": "vergittert",
    "vergittertestes": "vergittert",
    "vergittertet": "vergittern",
    "vergiß": "vergessen",
    "vergißt": "vergessen",
    "verglase": "verglasen",
    "verglasend": "verglasen",
    "verglasende": "verglasend",
    "verglasendem": "verglasend",
    "verglasenden": "verglasend",
    "verglasender": "verglasend",
    "verglasendere": "verglasend",
    "verglasenderem": "verglasend",
    "verglasenderen": "verglasend",
    "verglasenderer": "verglasend",
    "verglasenderes": "verglasend",
    "verglasendes": "verglasend",
    "verglasendste": "verglasend",
    "verglasendstem": "verglasend",
    "verglasendsten": "verglasend",
    "verglasendster": "verglasend",
    "verglasendstes": "verglasend",
    "verglasest": "verglasen",
    "verglaset": "verglasen",
    "verglast": "verglasen",
    "verglaste": "verglasen",
    "verglastem": "verglast",
    "verglasten": "verglasen",
    "verglaster": "verglast",
    "verglastere": "verglast",
    "verglasterem": "verglast",
    "verglasteren": "verglast",
    "verglasterer": "verglast",
    "verglasteres": "verglast",
    "verglastes": "verglast",
    "verglastest": "verglasen",
    "verglasteste": "verglast",
    "verglastestem": "verglast",
    "verglastesten": "verglast",
    "verglastester": "verglast",
    "verglastestes": "verglast",
    "verglastet": "verglasen",
    "vergleichbarem": "vergleichbar",
    "vergleichbaren": "vergleichbar",
    "vergleichbarer": "vergleichbar",
    "vergleichbarere": "vergleichbar",
    "vergleichbarerem": "vergleichbar",
    "vergleichbareren": "vergleichbar",
    "vergleichbarerer": "vergleichbar",
    "vergleichbareres": "vergleichbar",
    "vergleichbares": "vergleichbar",
    "vergleichbarste": "vergleichbar",
    "vergleichbarstem": "vergleichbar",
    "vergleichbarsten": "vergleichbar",
    "vergleichbarster": "vergleichbar",
    "vergleichbarstes": "vergleichbar",
    "vergleichend": "vergleichen",
    "vergleichende": "vergleichend",
    "vergleichendem": "vergleichend",
    "vergleichenden": "vergleichend",
    "vergleichender": "vergleichend",
    "vergleichendes": "vergleichend",
    "vergleichest": "vergleichen",
    "vergleichet": "vergleichen",
    "vergleichst": "vergleichen",
    "vergleicht": "vergleichen",
    "verglich": "vergleichen",
    "vergliche": "vergleichen",
    "verglichen": "vergleichen",
    "verglichene": "verglichen",
    "verglichenem": "verglichen",
    "verglichenen": "verglichen",
    "verglichener": "verglichen",
    "verglichenes": "verglichen",
    "verglichest": "vergleichen",
    "verglichet": "vergleichen",
    "verglichst": "vergleichen",
    "verglicht": "vergleichen",
    "verglimme": "verglimmen",
    "verglimmend": "verglimmen",
    "verglimmende": "verglimmend",
    "verglimmendem": "verglimmend",
    "verglimmenden": "verglimmend",
    "verglimmender": "verglimmend",
    "verglimmendere": "verglimmend",
    "verglimmenderem": "verglimmend",
    "verglimmenderen": "verglimmend",
    "verglimmenderer": "verglimmend",
    "verglimmenderes": "verglimmend",
    "verglimmendes": "verglimmend",
    "verglimmendste": "verglimmend",
    "verglimmendstem": "verglimmend",
    "verglimmendsten": "verglimmend",
    "verglimmendster": "verglimmend",
    "verglimmendstes": "verglimmend",
    "verglimmest": "verglimmen",
    "verglimmet": "verglimmen",
    "verglimmst": "verglimmen",
    "verglimmt": "verglimmen",
    "verglomm": "verglimmen",
    "verglommen": "verglimmen",
    "verglommene": "verglommen",
    "verglommenem": "verglommen",
    "verglommenen": "verglommen",
    "verglommener": "verglommen",
    "verglommenere": "verglommen",
    "verglommenerem": "verglommen",
    "verglommeneren": "verglommen",
    "verglommenerer": "verglommen",
    "verglommeneres": "verglommen",
    "verglommenes": "verglommen",
    "verglommenste": "verglommen",
    "verglommenstem": "verglommen",
    "verglommensten": "verglommen",
    "verglommenster": "verglommen",
    "verglommenstes": "verglommen",
    "verglommst": "verglimmen",
    "verglommt": "verglimmen",
    "verglömme": "verglimmen",
    "verglömmen": "verglimmen",
    "verglömmest": "verglimmen",
    "verglömmet": "verglimmen",
    "verglühe": "verglühen",
    "verglühend": "verglühen",
    "verglühende": "verglühend",
    "verglühendem": "verglühend",
    "verglühenden": "verglühend",
    "verglühender": "verglühend",
    "verglühendes": "verglühend",
    "verglühest": "verglühen",
    "verglühet": "verglühen",
    "verglühst": "verglühen",
    "verglüht": "verglühen",
    "verglühte": "verglühen",
    "verglühtem": "verglüht",
    "verglühten": "verglühen",
    "verglühter": "verglüht",
    "verglühtes": "verglüht",
    "verglühtest": "verglühen",
    "verglühtet": "verglühen",
    "vergnüge": "vergnügen",
    "vergnügend": "vergnügen",
    "vergnügende": "vergnügend",
    "vergnügendem": "vergnügend",
    "vergnügenden": "vergnügend",
    "vergnügender": "vergnügend",
    "vergnügendes": "vergnügend",
    "vergnügest": "vergnügen",
    "vergnüget": "vergnügen",
    "vergnügliche": "vergnüglich",
    "vergnüglichem": "vergnüglich",
    "vergnüglichen": "vergnüglich",
    "vergnüglicher": "vergnüglich",
    "vergnüglichere": "vergnüglich",
    "vergnüglicherem": "vergnüglich",
    "vergnüglicheren": "vergnüglich",
    "vergnüglicherer": "vergnüglich",
    "vergnüglicheres": "vergnüglich",
    "vergnügliches": "vergnüglich",
    "vergnüglichste": "vergnüglich",
    "vergnüglichstem": "vergnüglich",
    "vergnüglichsten": "vergnüglich",
    "vergnüglichster": "vergnüglich",
    "vergnüglichstes": "vergnüglich",
    "vergnügst": "vergnügen",
    "vergnügt": "vergnügen",
    "vergnügte": "vergnügen",
    "vergnügtem": "vergnügt",
    "vergnügten": "vergnügen",
    "vergnügter": "vergnügt",
    "vergnügtere": "vergnügt",
    "vergnügterem": "vergnügt",
    "vergnügteren": "vergnügt",
    "vergnügterer": "vergnügt",
    "vergnügteres": "vergnügt",
    "vergnügtes": "vergnügt",
    "vergnügtest": "vergnügen",
    "vergnügteste": "vergnügt",
    "vergnügtestem": "vergnügt",
    "vergnügtesten": "vergnügt",
    "vergnügtester": "vergnügt",
    "vergnügtestes": "vergnügt",
    "vergnügtet": "vergnügen",
    "vergnügungssüchtigem": "vergnügungssüchtig",
    "vergnügungssüchtigen": "vergnügungssüchtig",
    "vergnügungssüchtiger": "vergnügungssüchtig",
    "vergnügungssüchtigere": "vergnügungssüchtig",
    "vergnügungssüchtigerem": "vergnügungssüchtig",
    "vergnügungssüchtigeren": "vergnügungssüchtig",
    "vergnügungssüchtigerer": "vergnügungssüchtig",
    "vergnügungssüchtigeres": "vergnügungssüchtig",
    "vergnügungssüchtiges": "vergnügungssüchtig",
    "vergnügungssüchtigste": "vergnügungssüchtig",
    "vergnügungssüchtigstem": "vergnügungssüchtig",
    "vergnügungssüchtigsten": "vergnügungssüchtig",
    "vergnügungssüchtigster": "vergnügungssüchtig",
    "vergnügungssüchtigstes": "vergnügungssüchtig",
    "vergolde": "vergolden",
    "vergoldend": "vergolden",
    "vergoldende": "vergoldend",
    "vergoldendem": "vergoldend",
    "vergoldenden": "vergoldend",
    "vergoldender": "vergoldend",
    "vergoldendere": "vergoldend",
    "vergoldenderem": "vergoldend",
    "vergoldenderen": "vergoldend",
    "vergoldenderer": "vergoldend",
    "vergoldenderes": "vergoldend",
    "vergoldendes": "vergoldend",
    "vergoldendste": "vergoldend",
    "vergoldendstem": "vergoldend",
    "vergoldendsten": "vergoldend",
    "vergoldendster": "vergoldend",
    "vergoldendstes": "vergoldend",
    "vergoldest": "vergolden",
    "vergoldet": "vergolden",
    "vergoldete": "vergolden",
    "vergoldetem": "vergoldet",
    "vergoldeten": "vergolden",
    "vergoldeter": "vergoldet",
    "vergoldetere": "vergoldet",
    "vergoldeterem": "vergoldet",
    "vergoldeteren": "vergoldet",
    "vergoldeterer": "vergoldet",
    "vergoldeteres": "vergoldet",
    "vergoldetes": "vergoldet",
    "vergoldetest": "vergolden",
    "vergoldeteste": "vergoldet",
    "vergoldetestem": "vergoldet",
    "vergoldetesten": "vergoldet",
    "vergoldetester": "vergoldet",
    "vergoldetestes": "vergoldet",
    "vergoldetet": "vergolden",
    "vergolten": "vergelten",
    "vergoltene": "vergolten",
    "vergoltenem": "vergolten",
    "vergoltenen": "vergolten",
    "vergoltener": "vergolten",
    "vergoltenes": "vergolten",
    "vergossen": "vergießen",
    "vergossene": "vergossen",
    "vergossenem": "vergossen",
    "vergossenen": "vergossen",
    "vergossener": "vergossen",
    "vergossenere": "vergossen",
    "vergossenerem": "vergossen",
    "vergosseneren": "vergossen",
    "vergossenerer": "vergossen",
    "vergosseneres": "vergossen",
    "vergossenes": "vergossen",
    "vergossenste": "vergossen",
    "vergossenstem": "vergossen",
    "vergossensten": "vergossen",
    "vergossenster": "vergossen",
    "vergossenstes": "vergossen",
    "vergoß": "vergießen",
    "vergoßt": "vergießen",
    "vergrabe": "vergraben",
    "vergrabend": "vergraben",
    "vergrabende": "vergrabend",
    "vergrabendem": "vergrabend",
    "vergrabenden": "vergrabend",
    "vergrabender": "vergrabend",
    "vergrabendes": "vergrabend",
    "vergrabene": "vergraben",
    "vergrabenem": "vergraben",
    "vergrabenen": "vergraben",
    "vergrabener": "vergraben",
    "vergrabenes": "vergraben",
    "vergrabest": "vergraben",
    "vergrabet": "vergraben",
    "vergrabt": "vergraben",
    "vergraule": "vergraulen",
    "vergraulend": "vergraulen",
    "vergraulende": "vergraulend",
    "vergraulendem": "vergraulend",
    "vergraulenden": "vergraulend",
    "vergraulender": "vergraulend",
    "vergraulendere": "vergraulend",
    "vergraulenderem": "vergraulend",
    "vergraulenderen": "vergraulend",
    "vergraulenderer": "vergraulend",
    "vergraulenderes": "vergraulend",
    "vergraulendes": "vergraulend",
    "vergraulendste": "vergraulend",
    "vergraulendstem": "vergraulend",
    "vergraulendsten": "vergraulend",
    "vergraulendster": "vergraulend",
    "vergraulendstes": "vergraulend",
    "vergraulest": "vergraulen",
    "vergraulet": "vergraulen",
    "vergraulst": "vergraulen",
    "vergrault": "vergraulen",
    "vergraulte": "vergraulen",
    "vergraultem": "vergrault",
    "vergraulten": "vergraulen",
    "vergraulter": "vergrault",
    "vergraultere": "vergrault",
    "vergraulterem": "vergrault",
    "vergraulteren": "vergrault",
    "vergraulterer": "vergrault",
    "vergraulteres": "vergrault",
    "vergraultes": "vergrault",
    "vergraultest": "vergraulen",
    "vergraulteste": "vergrault",
    "vergraultestem": "vergrault",
    "vergraultesten": "vergrault",
    "vergraultester": "vergrault",
    "vergraultestes": "vergrault",
    "vergraultet": "vergraulen",
    "vergreife": "vergreifen",
    "vergreifend": "vergreifen",
    "vergreifende": "vergreifend",
    "vergreifendem": "vergreifend",
    "vergreifenden": "vergreifend",
    "vergreifender": "vergreifend",
    "vergreifendes": "vergreifend",
    "vergreifest": "vergreifen",
    "vergreifet": "vergreifen",
    "vergreifst": "vergreifen",
    "vergreift": "vergreifen",
    "vergrib": "vergraben",
    "vergribe": "vergraben",
    "vergriben": "vergraben",
    "vergribest": "vergraben",
    "vergribet": "vergraben",
    "vergribst": "vergraben",
    "vergribt": "vergraben",
    "vergriff": "vergreifen",
    "vergriffe": "vergreifen",
    "vergriffen": "vergreifen",
    "vergriffene": "vergriffen",
    "vergriffenem": "vergriffen",
    "vergriffenen": "vergriffen",
    "vergriffener": "vergriffen",
    "vergriffenere": "vergriffen",
    "vergriffenerem": "vergriffen",
    "vergriffeneren": "vergriffen",
    "vergriffenerer": "vergriffen",
    "vergriffeneres": "vergriffen",
    "vergriffenes": "vergriffen",
    "vergriffenste": "vergriffen",
    "vergriffenstem": "vergriffen",
    "vergriffensten": "vergriffen",
    "vergriffenster": "vergriffen",
    "vergriffenstes": "vergriffen",
    "vergriffest": "vergreifen",
    "vergriffet": "vergreifen",
    "vergriffst": "vergreifen",
    "vergrifft": "vergreifen",
    "vergräbst": "vergraben",
    "vergräbt": "vergraben",
    "vergräme": "vergrämen",
    "vergrämend": "vergrämen",
    "vergrämende": "vergrämend",
    "vergrämendem": "vergrämend",
    "vergrämenden": "vergrämend",
    "vergrämender": "vergrämend",
    "vergrämendere": "vergrämend",
    "vergrämenderem": "vergrämend",
    "vergrämenderen": "vergrämend",
    "vergrämenderer": "vergrämend",
    "vergrämenderes": "vergrämend",
    "vergrämendes": "vergrämend",
    "vergrämendste": "vergrämend",
    "vergrämendstem": "vergrämend",
    "vergrämendsten": "vergrämend",
    "vergrämendster": "vergrämend",
    "vergrämendstes": "vergrämend",
    "vergrämest": "vergrämen",
    "vergrämet": "vergrämen",
    "vergrämst": "vergrämen",
    "vergrämt": "vergrämen",
    "vergrämte": "vergrämen",
    "vergrämtem": "vergrämt",
    "vergrämten": "vergrämen",
    "vergrämter": "vergrämt",
    "vergrämtere": "vergrämt",
    "vergrämterem": "vergrämt",
    "vergrämteren": "vergrämt",
    "vergrämterer": "vergrämt",
    "vergrämteres": "vergrämt",
    "vergrämtes": "vergrämt",
    "vergrämtest": "vergrämen",
    "vergrämteste": "vergrämt",
    "vergrämtestem": "vergrämt",
    "vergrämtesten": "vergrämt",
    "vergrämtester": "vergrämt",
    "vergrämtestes": "vergrämt",
    "vergrämtet": "vergrämen",
    "vergröbere": "vergröbern",
    "vergröbernd": "vergröbern",
    "vergröbernde": "vergröbernd",
    "vergröberndem": "vergröbernd",
    "vergröbernden": "vergröbernd",
    "vergröbernder": "vergröbernd",
    "vergröberndere": "vergröbernd",
    "vergröbernderem": "vergröbernd",
    "vergröbernderen": "vergröbernd",
    "vergröbernderer": "vergröbernd",
    "vergröbernderes": "vergröbernd",
    "vergröberndes": "vergröbernd",
    "vergröberndste": "vergröbernd",
    "vergröberndstem": "vergröbernd",
    "vergröberndsten": "vergröbernd",
    "vergröberndster": "vergröbernd",
    "vergröberndstes": "vergröbernd",
    "vergröberst": "vergröbern",
    "vergröbert": "vergröbern",
    "vergröberte": "vergröbern",
    "vergröbertem": "vergröbert",
    "vergröberten": "vergröbern",
    "vergröberter": "vergröbert",
    "vergröbertere": "vergröbert",
    "vergröberterem": "vergröbert",
    "vergröberteren": "vergröbert",
    "vergröberterer": "vergröbert",
    "vergröberteres": "vergröbert",
    "vergröbertes": "vergröbert",
    "vergröbertest": "vergröbern",
    "vergröberteste": "vergröbert",
    "vergröbertestem": "vergröbert",
    "vergröbertesten": "vergröbert",
    "vergröbertester": "vergröbert",
    "vergröbertestes": "vergröbert",
    "vergröbertet": "vergröbern",
    "vergrößere": "vergrößern",
    "vergrößernd": "vergrößern",
    "vergrößernde": "vergrößernd",
    "vergrößerndem": "vergrößernd",
    "vergrößernden": "vergrößernd",
    "vergrößernder": "vergrößernd",
    "vergrößerndes": "vergrößernd",
    "vergrößerst": "vergrößern",
    "vergrößert": "vergrößern",
    "vergrößerte": "vergrößern",
    "vergrößertem": "vergrößert",
    "vergrößerten": "vergrößern",
    "vergrößerter": "vergrößert",
    "vergrößertere": "vergrößert",
    "vergrößerterem": "vergrößert",
    "vergrößerteren": "vergrößert",
    "vergrößerterer": "vergrößert",
    "vergrößerteres": "vergrößert",
    "vergrößertes": "vergrößert",
    "vergrößertest": "vergrößern",
    "vergrößerteste": "vergrößert",
    "vergrößertestem": "vergrößert",
    "vergrößertesten": "vergrößert",
    "vergrößertester": "vergrößert",
    "vergrößertestes": "vergrößert",
    "vergrößertet": "vergrößern",
    "vergrößerungsfähigem": "vergrößerungsfähig",
    "vergrößerungsfähigen": "vergrößerungsfähig",
    "vergrößerungsfähiger": "vergrößerungsfähig",
    "vergrößerungsfähigere": "vergrößerungsfähig",
    "vergrößerungsfähigerem": "vergrößerungsfähig",
    "vergrößerungsfähigeren": "vergrößerungsfähig",
    "vergrößerungsfähigerer": "vergrößerungsfähig",
    "vergrößerungsfähigeres": "vergrößerungsfähig",
    "vergrößerungsfähiges": "vergrößerungsfähig",
    "vergrößerungsfähigste": "vergrößerungsfähig",
    "vergrößerungsfähigstem": "vergrößerungsfähig",
    "vergrößerungsfähigsten": "vergrößerungsfähig",
    "vergrößerungsfähigster": "vergrößerungsfähig",
    "vergrößerungsfähigstes": "vergrößerungsfähig",
    "vergucke": "vergucken",
    "verguckend": "vergucken",
    "verguckende": "verguckend",
    "verguckendem": "verguckend",
    "verguckenden": "verguckend",
    "verguckender": "verguckend",
    "verguckendes": "verguckend",
    "verguckest": "vergucken",
    "vergucket": "vergucken",
    "verguckst": "vergucken",
    "verguckt": "vergucken",
    "verguckte": "vergucken",
    "vergucktem": "verguckt",
    "verguckten": "vergucken",
    "verguckter": "verguckt",
    "vergucktes": "verguckt",
    "vergucktest": "vergucken",
    "vergucktet": "vergucken",
    "vergäbe": "vergeben",
    "vergäben": "vergeben",
    "vergäbest": "vergeben",
    "vergäbet": "vergeben",
    "vergälte": "vergelten",
    "vergälten": "vergelten",
    "vergältest": "vergelten",
    "vergältet": "vergelten",
    "vergänglichem": "vergänglich",
    "vergänglichen": "vergänglich",
    "vergänglicher": "vergänglich",
    "vergänglichere": "vergänglich",
    "vergänglicherem": "vergänglich",
    "vergänglicheren": "vergänglich",
    "vergänglicherer": "vergänglich",
    "vergänglicheres": "vergänglich",
    "vergängliches": "vergänglich",
    "vergänglichste": "vergänglich",
    "vergänglichstem": "vergänglich",
    "vergänglichsten": "vergänglich",
    "vergänglichster": "vergänglich",
    "vergänglichstes": "vergänglich",
    "vergäße": "vergessen",
    "vergäßen": "vergessen",
    "vergäßest": "vergessen",
    "vergäßet": "vergessen",
    "vergönne": "vergönnen",
    "vergönnend": "vergönnen",
    "vergönnende": "vergönnend",
    "vergönnendem": "vergönnend",
    "vergönnenden": "vergönnend",
    "vergönnender": "vergönnend",
    "vergönnendes": "vergönnend",
    "vergönnest": "vergönnen",
    "vergönnet": "vergönnen",
    "vergönnst": "vergönnen",
    "vergönnt": "vergönnen",
    "vergönnte": "vergönnen",
    "vergönntem": "vergönnt",
    "vergönnten": "vergönnen",
    "vergönnter": "vergönnt",
    "vergönntes": "vergönnt",
    "vergönntest": "vergönnen",
    "vergönntet": "vergönnen",
    "vergösse": "vergießen",
    "vergössen": "vergießen",
    "vergössest": "vergießen",
    "vergösset": "vergießen",
    "vergöttere": "vergöttern",
    "vergötternd": "vergöttern",
    "vergötternde": "vergötternd",
    "vergötterndem": "vergötternd",
    "vergötternden": "vergötternd",
    "vergötternder": "vergötternd",
    "vergötterndes": "vergötternd",
    "vergötterst": "vergöttern",
    "vergöttert": "vergöttern",
    "vergötterte": "vergöttern",
    "vergöttertem": "vergöttert",
    "vergötterten": "vergöttern",
    "vergötterter": "vergöttert",
    "vergöttertes": "vergöttert",
    "vergöttertest": "vergöttern",
    "vergöttertet": "vergöttern",
    "vergünstige": "vergünstigen",
    "vergünstigend": "vergünstigen",
    "vergünstigende": "vergünstigend",
    "vergünstigendem": "vergünstigend",
    "vergünstigenden": "vergünstigend",
    "vergünstigender": "vergünstigend",
    "vergünstigendes": "vergünstigend",
    "vergünstigest": "vergünstigen",
    "vergünstiget": "vergünstigen",
    "vergünstigst": "vergünstigen",
    "vergünstigt": "vergünstigen",
    "vergünstigte": "vergünstigen",
    "vergünstigtem": "vergünstigt",
    "vergünstigten": "vergünstigen",
    "vergünstigter": "vergünstigt",
    "vergünstigtes": "vergünstigt",
    "vergünstigtest": "vergünstigen",
    "vergünstigtet": "vergünstigen",
    "vergüte": "vergüten",
    "vergütend": "vergüten",
    "vergütende": "vergütend",
    "vergütendem": "vergütend",
    "vergütenden": "vergütend",
    "vergütender": "vergütend",
    "vergütendere": "vergütend",
    "vergütenderem": "vergütend",
    "vergütenderen": "vergütend",
    "vergütenderer": "vergütend",
    "vergütenderes": "vergütend",
    "vergütendes": "vergütend",
    "vergütendste": "vergütend",
    "vergütendstem": "vergütend",
    "vergütendsten": "vergütend",
    "vergütendster": "vergütend",
    "vergütendstes": "vergütend",
    "vergütest": "vergüten",
    "vergütet": "vergüten",
    "vergütete": "vergüten",
    "vergütetem": "vergütet",
    "vergüteten": "vergüten",
    "vergüteter": "vergütet",
    "vergütetes": "vergütet",
    "vergütetest": "vergüten",
    "vergütetet": "vergüten",
    "verhafte": "verhaften",
    "verhaftend": "verhaften",
    "verhaftende": "verhaftend",
    "verhaftendem": "verhaftend",
    "verhaftenden": "verhaftend",
    "verhaftender": "verhaftend",
    "verhaftendes": "verhaftend",
    "verhaftest": "verhaften",
    "verhaftet": "verhaften",
    "verhaftete": "verhaften",
    "verhaftetem": "verhaftet",
    "verhafteten": "verhaften",
    "verhafteter": "verhaftet",
    "verhaftetes": "verhaftet",
    "verhaftetest": "verhaften",
    "verhaftetet": "verhaften",
    "verhagele": "verhageln",
    "verhagelnd": "verhageln",
    "verhagelnde": "verhagelnd",
    "verhagelndem": "verhagelnd",
    "verhagelnden": "verhagelnd",
    "verhagelnder": "verhagelnd",
    "verhagelndere": "verhagelnd",
    "verhagelnderem": "verhagelnd",
    "verhagelnderen": "verhagelnd",
    "verhagelnderer": "verhagelnd",
    "verhagelnderes": "verhagelnd",
    "verhagelndes": "verhagelnd",
    "verhagelndste": "verhagelnd",
    "verhagelndstem": "verhagelnd",
    "verhagelndsten": "verhagelnd",
    "verhagelndster": "verhagelnd",
    "verhagelndstes": "verhagelnd",
    "verhagelst": "verhageln",
    "verhagelt": "verhageln",
    "verhagelte": "verhageln",
    "verhageltem": "verhagelt",
    "verhagelten": "verhageln",
    "verhagelter": "verhagelt",
    "verhageltere": "verhagelt",
    "verhagelterem": "verhagelt",
    "verhagelteren": "verhagelt",
    "verhagelterer": "verhagelt",
    "verhagelteres": "verhagelt",
    "verhageltes": "verhagelt",
    "verhageltest": "verhageln",
    "verhagelteste": "verhagelt",
    "verhageltestem": "verhagelt",
    "verhageltesten": "verhagelt",
    "verhageltester": "verhagelt",
    "verhageltestes": "verhagelt",
    "verhageltet": "verhageln",
    "verhagle": "verhageln",
    "verhalf": "verhelfen",
    "verhalfen": "verhelfen",
    "verhalfst": "verhelfen",
    "verhalft": "verhelfen",
    "verhalle": "verhallen",
    "verhallend": "verhallen",
    "verhallende": "verhallend",
    "verhallendem": "verhallend",
    "verhallenden": "verhallend",
    "verhallender": "verhallend",
    "verhallendere": "verhallend",
    "verhallenderem": "verhallend",
    "verhallenderen": "verhallend",
    "verhallenderer": "verhallend",
    "verhallenderes": "verhallend",
    "verhallendes": "verhallend",
    "verhallendste": "verhallend",
    "verhallendstem": "verhallend",
    "verhallendsten": "verhallend",
    "verhallendster": "verhallend",
    "verhallendstes": "verhallend",
    "verhallest": "verhallen",
    "verhallet": "verhallen",
    "verhallst": "verhallen",
    "verhallt": "verhallen",
    "verhallte": "verhallen",
    "verhalltem": "verhallt",
    "verhallten": "verhallen",
    "verhallter": "verhallt",
    "verhalltere": "verhallt",
    "verhallterem": "verhallt",
    "verhallteren": "verhallt",
    "verhallterer": "verhallt",
    "verhallteres": "verhallt",
    "verhalltes": "verhallt",
    "verhalltest": "verhallen",
    "verhallteste": "verhallt",
    "verhalltestem": "verhallt",
    "verhalltesten": "verhallt",
    "verhalltester": "verhallt",
    "verhalltestes": "verhallt",
    "verhalltet": "verhallen",
    "verhalte": "verhalten",
    "verhaltend": "verhalten",
    "verhaltende": "verhaltend",
    "verhaltendem": "verhaltend",
    "verhaltenden": "verhaltend",
    "verhaltender": "verhaltend",
    "verhaltendes": "verhaltend",
    "verhaltene": "verhalten",
    "verhaltenem": "verhalten",
    "verhaltenen": "verhalten",
    "verhaltener": "verhalten",
    "verhaltenes": "verhalten",
    "verhaltest": "verhalten",
    "verhaltet": "verhalten",
    "verhandele": "verhandeln",
    "verhandelnd": "verhandeln",
    "verhandelnde": "verhandelnd",
    "verhandelndem": "verhandelnd",
    "verhandelnden": "verhandelnd",
    "verhandelnder": "verhandelnd",
    "verhandelndes": "verhandelnd",
    "verhandelst": "verhandeln",
    "verhandelt": "verhandeln",
    "verhandelte": "verhandeln",
    "verhandeltem": "verhandelt",
    "verhandelten": "verhandeln",
    "verhandelter": "verhandelt",
    "verhandeltes": "verhandelt",
    "verhandeltest": "verhandeln",
    "verhandeltet": "verhandeln",
    "verhandle": "verhandeln",
    "verhangene": "verhangen",
    "verhangenem": "verhangen",
    "verhangenen": "verhangen",
    "verhangener": "verhangen",
    "verhangenes": "verhangen",
    "verharmlose": "verharmlosen",
    "verharmlosend": "verharmlosen",
    "verharmlosende": "verharmlosend",
    "verharmlosendem": "verharmlosend",
    "verharmlosenden": "verharmlosend",
    "verharmlosender": "verharmlosend",
    "verharmlosendere": "verharmlosend",
    "verharmlosenderem": "verharmlosend",
    "verharmlosenderen": "verharmlosend",
    "verharmlosenderer": "verharmlosend",
    "verharmlosenderes": "verharmlosend",
    "verharmlosendes": "verharmlosend",
    "verharmlosendste": "verharmlosend",
    "verharmlosendstem": "verharmlosend",
    "verharmlosendsten": "verharmlosend",
    "verharmlosendster": "verharmlosend",
    "verharmlosendstes": "verharmlosend",
    "verharmlosest": "verharmlosen",
    "verharmloset": "verharmlosen",
    "verharmlost": "verharmlosen",
    "verharmloste": "verharmlosen",
    "verharmlostem": "verharmlost",
    "verharmlosten": "verharmlosen",
    "verharmloster": "verharmlost",
    "verharmlostere": "verharmlost",
    "verharmlosterem": "verharmlost",
    "verharmlosteren": "verharmlost",
    "verharmlosterer": "verharmlost",
    "verharmlosteres": "verharmlost",
    "verharmlostes": "verharmlost",
    "verharmlostest": "verharmlosen",
    "verharmlosteste": "verharmlost",
    "verharmlostestem": "verharmlost",
    "verharmlostesten": "verharmlost",
    "verharmlostester": "verharmlost",
    "verharmlostestes": "verharmlost",
    "verharmlostet": "verharmlosen",
    "verharre": "verharren",
    "verharrend": "verharren",
    "verharrende": "verharrend",
    "verharrendem": "verharrend",
    "verharrenden": "verharrend",
    "verharrender": "verharrend",
    "verharrendes": "verharrend",
    "verharrest": "verharren",
    "verharret": "verharren",
    "verharrst": "verharren",
    "verharrt": "verharren",
    "verharrte": "verharren",
    "verharrtem": "verharrt",
    "verharrten": "verharren",
    "verharrter": "verharrt",
    "verharrtes": "verharrt",
    "verharrtest": "verharren",
    "verharrtet": "verharren",
    "verhaspele": "verhaspeln",
    "verhaspelnd": "verhaspeln",
    "verhaspelnde": "verhaspelnd",
    "verhaspelndem": "verhaspelnd",
    "verhaspelnden": "verhaspelnd",
    "verhaspelnder": "verhaspelnd",
    "verhaspelndere": "verhaspelnd",
    "verhaspelnderem": "verhaspelnd",
    "verhaspelnderen": "verhaspelnd",
    "verhaspelnderer": "verhaspelnd",
    "verhaspelnderes": "verhaspelnd",
    "verhaspelndes": "verhaspelnd",
    "verhaspelndste": "verhaspelnd",
    "verhaspelndstem": "verhaspelnd",
    "verhaspelndsten": "verhaspelnd",
    "verhaspelndster": "verhaspelnd",
    "verhaspelndstes": "verhaspelnd",
    "verhaspelst": "verhaspeln",
    "verhaspelt": "verhaspeln",
    "verhaspelte": "verhaspeln",
    "verhaspeltem": "verhaspelt",
    "verhaspelten": "verhaspeln",
    "verhaspelter": "verhaspelt",
    "verhaspeltere": "verhaspelt",
    "verhaspelterem": "verhaspelt",
    "verhaspelteren": "verhaspelt",
    "verhaspelterer": "verhaspelt",
    "verhaspelteres": "verhaspelt",
    "verhaspeltes": "verhaspelt",
    "verhaspeltest": "verhaspeln",
    "verhaspelteste": "verhaspelt",
    "verhaspeltestem": "verhaspelt",
    "verhaspeltesten": "verhaspelt",
    "verhaspeltester": "verhaspelt",
    "verhaspeltestes": "verhaspelt",
    "verhaspeltet": "verhaspeln",
    "verhasple": "verhaspeln",
    "verhauend": "verhauen",
    "verhauende": "verhauend",
    "verhauendem": "verhauend",
    "verhauenden": "verhauend",
    "verhauender": "verhauend",
    "verhauendes": "verhauend",
    "verhauene": "verhauen",
    "verhauenem": "verhauen",
    "verhauenen": "verhauen",
    "verhauener": "verhauen",
    "verhauenere": "verhauen",
    "verhauenerem": "verhauen",
    "verhaueneren": "verhauen",
    "verhauenerer": "verhauen",
    "verhaueneres": "verhauen",
    "verhauenes": "verhauen",
    "verhauenstem": "verhauen",
    "verhauensten": "verhauen",
    "verhauenster": "verhauen",
    "verhauenstes": "verhauen",
    "verhauest": "verhauen",
    "verhauet": "verhauen",
    "verhaust": "verhauen",
    "verhaut": "verhauen",
    "verhaute": "verhauen",
    "verhauten": "verhauen",
    "verhautest": "verhauen",
    "verhautet": "verhauen",
    "verhebe": "verheben",
    "verhebend": "verheben",
    "verhebende": "verhebend",
    "verhebendem": "verhebend",
    "verhebenden": "verhebend",
    "verhebender": "verhebend",
    "verhebendes": "verhebend",
    "verhebest": "verheben",
    "verhebet": "verheben",
    "verhebst": "verheben",
    "verhebt": "verheben",
    "verheddere": "verheddern",
    "verheddernd": "verheddern",
    "verheddernde": "verheddernd",
    "verhedderndem": "verheddernd",
    "verheddernden": "verheddernd",
    "verheddernder": "verheddernd",
    "verhedderndere": "verheddernd",
    "verheddernderem": "verheddernd",
    "verheddernderen": "verheddernd",
    "verheddernderer": "verheddernd",
    "verheddernderes": "verheddernd",
    "verhedderndes": "verheddernd",
    "verhedderndste": "verheddernd",
    "verhedderndstem": "verheddernd",
    "verhedderndsten": "verheddernd",
    "verhedderndster": "verheddernd",
    "verhedderndstes": "verheddernd",
    "verhedderst": "verheddern",
    "verheddert": "verheddern",
    "verhedderte": "verheddern",
    "verheddertem": "verheddert",
    "verhedderten": "verheddern",
    "verhedderter": "verheddert",
    "verheddertere": "verheddert",
    "verhedderterem": "verheddert",
    "verhedderteren": "verheddert",
    "verhedderterer": "verheddert",
    "verhedderteres": "verheddert",
    "verheddertes": "verheddert",
    "verheddertest": "verheddern",
    "verhedderteste": "verheddert",
    "verheddertestem": "verheddert",
    "verheddertesten": "verheddert",
    "verheddertester": "verheddert",
    "verheddertestes": "verheddert",
    "verheddertet": "verheddern",
    "verheere": "verheeren",
    "verheerend": "verheeren",
    "verheerende": "verheerend",
    "verheerendem": "verheerend",
    "verheerenden": "verheerend",
    "verheerender": "verheerend",
    "verheerendere": "verheerend",
    "verheerenderem": "verheerend",
    "verheerenderen": "verheerend",
    "verheerenderer": "verheerend",
    "verheerenderes": "verheerend",
    "verheerendes": "verheerend",
    "verheerendeste": "verheerend",
    "verheerendestem": "verheerend",
    "verheerendesten": "verheerend",
    "verheerendester": "verheerend",
    "verheerendestes": "verheerend",
    "verheerest": "verheeren",
    "verheeret": "verheeren",
    "verheerst": "verheeren",
    "verheert": "verheeren",
    "verheerte": "verheeren",
    "verheertem": "verheert",
    "verheerten": "verheeren",
    "verheerter": "verheert",
    "verheertere": "verheert",
    "verheerterem": "verheert",
    "verheerteren": "verheert",
    "verheerterer": "verheert",
    "verheerteres": "verheert",
    "verheertes": "verheert",
    "verheertest": "verheeren",
    "verheerteste": "verheert",
    "verheertestem": "verheert",
    "verheertesten": "verheert",
    "verheertester": "verheert",
    "verheertestes": "verheert",
    "verheertet": "verheeren",
    "verheile": "verheilen",
    "verheilend": "verheilen",
    "verheilende": "verheilend",
    "verheilendem": "verheilend",
    "verheilenden": "verheilend",
    "verheilender": "verheilend",
    "verheilendes": "verheilend",
    "verheilest": "verheilen",
    "verheilet": "verheilen",
    "verheilst": "verheilen",
    "verheilt": "verheilen",
    "verheilte": "verheilen",
    "verheiltem": "verheilt",
    "verheilten": "verheilen",
    "verheilter": "verheilt",
    "verheiltes": "verheilt",
    "verheiltest": "verheilen",
    "verheiltet": "verheilen",
    "verheimliche": "verheimlichen",
    "verheimlichend": "verheimlichen",
    "verheimlichende": "verheimlichend",
    "verheimlichendem": "verheimlichend",
    "verheimlichenden": "verheimlichend",
    "verheimlichender": "verheimlichend",
    "verheimlichendere": "verheimlichend",
    "verheimlichenderem": "verheimlichend",
    "verheimlichenderen": "verheimlichend",
    "verheimlichenderer": "verheimlichend",
    "verheimlichenderes": "verheimlichend",
    "verheimlichendes": "verheimlichend",
    "verheimlichendste": "verheimlichend",
    "verheimlichendstem": "verheimlichend",
    "verheimlichendsten": "verheimlichend",
    "verheimlichendster": "verheimlichend",
    "verheimlichendstes": "verheimlichend",
    "verheimlichest": "verheimlichen",
    "verheimlichet": "verheimlichen",
    "verheimlichst": "verheimlichen",
    "verheimlicht": "verheimlichen",
    "verheimlichte": "verheimlichen",
    "verheimlichtem": "verheimlicht",
    "verheimlichten": "verheimlichen",
    "verheimlichter": "verheimlicht",
    "verheimlichtere": "verheimlicht",
    "verheimlichterem": "verheimlicht",
    "verheimlichteren": "verheimlicht",
    "verheimlichterer": "verheimlicht",
    "verheimlichteres": "verheimlicht",
    "verheimlichtes": "verheimlicht",
    "verheimlichtest": "verheimlichen",
    "verheimlichteste": "verheimlicht",
    "verheimlichtestem": "verheimlicht",
    "verheimlichtesten": "verheimlicht",
    "verheimlichtester": "verheimlicht",
    "verheimlichtestes": "verheimlicht",
    "verheimlichtet": "verheimlichen",
    "verheirate": "verheiraten",
    "verheiratend": "verheiraten",
    "verheiratende": "verheiratend",
    "verheiratendem": "verheiratend",
    "verheiratenden": "verheiratend",
    "verheiratender": "verheiratend",
    "verheiratendes": "verheiratend",
    "verheiratest": "verheiraten",
    "verheiratet": "verheiraten",
    "verheiratete": "verheiraten",
    "verheiratetem": "verheiratet",
    "verheirateten": "verheiraten",
    "verheirateter": "verheiratet",
    "verheiratetes": "verheiratet",
    "verheiratetest": "verheiraten",
    "verheiratetet": "verheiraten",
    "verheize": "verheizen",
    "verheizend": "verheizen",
    "verheizende": "verheizend",
    "verheizendem": "verheizend",
    "verheizenden": "verheizend",
    "verheizender": "verheizend",
    "verheizendere": "verheizend",
    "verheizenderem": "verheizend",
    "verheizenderen": "verheizend",
    "verheizenderer": "verheizend",
    "verheizenderes": "verheizend",
    "verheizendes": "verheizend",
    "verheizendste": "verheizend",
    "verheizendstem": "verheizend",
    "verheizendsten": "verheizend",
    "verheizendster": "verheizend",
    "verheizendstes": "verheizend",
    "verheizest": "verheizen",
    "verheizet": "verheizen",
    "verheizt": "verheizen",
    "verheizte": "verheizen",
    "verheiztem": "verheizt",
    "verheizten": "verheizen",
    "verheizter": "verheizt",
    "verheiztere": "verheizt",
    "verheizterem": "verheizt",
    "verheizteren": "verheizt",
    "verheizterer": "verheizt",
    "verheizteres": "verheizt",
    "verheiztes": "verheizt",
    "verheiztest": "verheizen",
    "verheizteste": "verheizt",
    "verheiztestem": "verheizt",
    "verheiztesten": "verheizt",
    "verheiztester": "verheizt",
    "verheiztestes": "verheizt",
    "verheiztet": "verheizen",
    "verheiße": "verheißen",
    "verheißend": "verheißen",
    "verheißende": "verheißend",
    "verheißendem": "verheißend",
    "verheißenden": "verheißend",
    "verheißender": "verheißend",
    "verheißendes": "verheißend",
    "verheißene": "verheißen",
    "verheißenem": "verheißen",
    "verheißenen": "verheißen",
    "verheißener": "verheißen",
    "verheißenes": "verheißen",
    "verheißest": "verheißen",
    "verheißet": "verheißen",
    "verheißt": "verheißen",
    "verheißungsvollem": "verheißungsvoll",
    "verheißungsvollen": "verheißungsvoll",
    "verheißungsvoller": "verheißungsvoll",
    "verheißungsvollere": "verheißungsvoll",
    "verheißungsvollerem": "verheißungsvoll",
    "verheißungsvolleren": "verheißungsvoll",
    "verheißungsvollerer": "verheißungsvoll",
    "verheißungsvolleres": "verheißungsvoll",
    "verheißungsvolles": "verheißungsvoll",
    "verheißungsvollste": "verheißungsvoll",
    "verheißungsvollstem": "verheißungsvoll",
    "verheißungsvollsten": "verheißungsvoll",
    "verheißungsvollster": "verheißungsvoll",
    "verheißungsvollstes": "verheißungsvoll",
    "verhelfe": "verhelfen",
    "verhelfend": "verhelfen",
    "verhelfende": "verhelfend",
    "verhelfendem": "verhelfend",
    "verhelfenden": "verhelfend",
    "verhelfender": "verhelfend",
    "verhelfendes": "verhelfend",
    "verhelfest": "verhelfen",
    "verhelfet": "verhelfen",
    "verhelft": "verhelfen",
    "verherrliche": "verherrlichen",
    "verherrlichend": "verherrlichen",
    "verherrlichende": "verherrlichend",
    "verherrlichendem": "verherrlichend",
    "verherrlichenden": "verherrlichend",
    "verherrlichender": "verherrlichend",
    "verherrlichendere": "verherrlichend",
    "verherrlichenderem": "verherrlichend",
    "verherrlichenderen": "verherrlichend",
    "verherrlichenderer": "verherrlichend",
    "verherrlichenderes": "verherrlichend",
    "verherrlichendes": "verherrlichend",
    "verherrlichendste": "verherrlichend",
    "verherrlichendstem": "verherrlichend",
    "verherrlichendsten": "verherrlichend",
    "verherrlichendster": "verherrlichend",
    "verherrlichendstes": "verherrlichend",
    "verherrlichest": "verherrlichen",
    "verherrlichet": "verherrlichen",
    "verherrlichst": "verherrlichen",
    "verherrlicht": "verherrlichen",
    "verherrlichte": "verherrlichen",
    "verherrlichtem": "verherrlicht",
    "verherrlichten": "verherrlichen",
    "verherrlichter": "verherrlicht",
    "verherrlichtere": "verherrlicht",
    "verherrlichterem": "verherrlicht",
    "verherrlichteren": "verherrlicht",
    "verherrlichterer": "verherrlicht",
    "verherrlichteres": "verherrlicht",
    "verherrlichtes": "verherrlicht",
    "verherrlichtest": "verherrlichen",
    "verherrlichteste": "verherrlicht",
    "verherrlichtestem": "verherrlicht",
    "verherrlichtesten": "verherrlicht",
    "verherrlichtester": "verherrlicht",
    "verherrlichtestes": "verherrlicht",
    "verherrlichtet": "verherrlichen",
    "verhexe": "verhexen",
    "verhexend": "verhexen",
    "verhexende": "verhexend",
    "verhexendem": "verhexend",
    "verhexenden": "verhexend",
    "verhexender": "verhexend",
    "verhexendere": "verhexend",
    "verhexenderem": "verhexend",
    "verhexenderen": "verhexend",
    "verhexenderer": "verhexend",
    "verhexenderes": "verhexend",
    "verhexendes": "verhexend",
    "verhexendste": "verhexend",
    "verhexendstem": "verhexend",
    "verhexendsten": "verhexend",
    "verhexendster": "verhexend",
    "verhexendstes": "verhexend",
    "verhexest": "verhexen",
    "verhexet": "verhexen",
    "verhext": "verhexen",
    "verhexte": "verhexen",
    "verhextem": "verhext",
    "verhexten": "verhexen",
    "verhexter": "verhext",
    "verhextere": "verhext",
    "verhexterem": "verhext",
    "verhexteren": "verhext",
    "verhexterer": "verhext",
    "verhexteres": "verhext",
    "verhextes": "verhext",
    "verhextest": "verhexen",
    "verhexteste": "verhext",
    "verhextestem": "verhext",
    "verhextesten": "verhext",
    "verhextester": "verhext",
    "verhextestes": "verhext",
    "verhextet": "verhexen",
    "verhielt": "verhalten",
    "verhielte": "verhalten",
    "verhielten": "verhalten",
    "verhieltest": "verhalten",
    "verhieltet": "verhalten",
    "verhieß": "verheißen",
    "verhieße": "verheißen",
    "verhießen": "verheißen",
    "verhießest": "verheißen",
    "verhießet": "verheißen",
    "verhießt": "verheißen",
    "verhilf": "verhelfen",
    "verhilfst": "verhelfen",
    "verhilft": "verhelfen",
    "verhindere": "verhindern",
    "verhindernd": "verhindern",
    "verhindernde": "verhindernd",
    "verhinderndem": "verhindernd",
    "verhindernden": "verhindernd",
    "verhindernder": "verhindernd",
    "verhinderndes": "verhindernd",
    "verhinderst": "verhindern",
    "verhindert": "verhindern",
    "verhinderte": "verhindern",
    "verhindertem": "verhindert",
    "verhinderten": "verhindern",
    "verhinderter": "verhindert",
    "verhindertes": "verhindert",
    "verhindertest": "verhindern",
    "verhindertet": "verhindern",
    "verhob": "verheben",
    "verhoben": "verheben",
    "verhobene": "verhoben",
    "verhobenem": "verhoben",
    "verhobenen": "verhoben",
    "verhobener": "verhoben",
    "verhobenes": "verhoben",
    "verhobst": "verheben",
    "verhobt": "verheben",
    "verhohnepiepele": "verhohnepiepeln",
    "verhohnepiepelnd": "verhohnepiepeln",
    "verhohnepiepelnde": "verhohnepiepelnd",
    "verhohnepiepelndem": "verhohnepiepelnd",
    "verhohnepiepelnden": "verhohnepiepelnd",
    "verhohnepiepelnder": "verhohnepiepelnd",
    "verhohnepiepelndes": "verhohnepiepelnd",
    "verhohnepiepelst": "verhohnepiepeln",
    "verhohnepiepelt": "verhohnepiepeln",
    "verhohnepiepelte": "verhohnepiepeln",
    "verhohnepiepeltem": "verhohnepiepelt",
    "verhohnepiepelten": "verhohnepiepeln",
    "verhohnepiepelter": "verhohnepiepelt",
    "verhohnepiepeltes": "verhohnepiepelt",
    "verhohnepiepeltest": "verhohnepiepeln",
    "verhohnepiepeltet": "verhohnepiepeln",
    "verhohnepieple": "verhohnepiepeln",
    "verholfen": "verhelfen",
    "verholfene": "verholfen",
    "verholfenem": "verholfen",
    "verholfenen": "verholfen",
    "verholfener": "verholfen",
    "verholfenes": "verholfen",
    "verhungere": "verhungern",
    "verhungernd": "verhungern",
    "verhungernde": "verhungernd",
    "verhungerndem": "verhungernd",
    "verhungernden": "verhungernd",
    "verhungernder": "verhungernd",
    "verhungerndere": "verhungernd",
    "verhungernderem": "verhungernd",
    "verhungernderen": "verhungernd",
    "verhungernderer": "verhungernd",
    "verhungernderes": "verhungernd",
    "verhungerndes": "verhungernd",
    "verhungerndste": "verhungernd",
    "verhungerndstem": "verhungernd",
    "verhungerndsten": "verhungernd",
    "verhungerndster": "verhungernd",
    "verhungerndstes": "verhungernd",
    "verhungerst": "verhungern",
    "verhungert": "verhungern",
    "verhungerte": "verhungern",
    "verhungertem": "verhungert",
    "verhungerten": "verhungern",
    "verhungerter": "verhungert",
    "verhungertes": "verhungert",
    "verhungertest": "verhungern",
    "verhungertet": "verhungern",
    "verhunze": "verhunzen",
    "verhunzend": "verhunzen",
    "verhunzende": "verhunzend",
    "verhunzendem": "verhunzend",
    "verhunzenden": "verhunzend",
    "verhunzender": "verhunzend",
    "verhunzendere": "verhunzend",
    "verhunzenderem": "verhunzend",
    "verhunzenderen": "verhunzend",
    "verhunzenderer": "verhunzend",
    "verhunzenderes": "verhunzend",
    "verhunzendes": "verhunzend",
    "verhunzendste": "verhunzend",
    "verhunzendstem": "verhunzend",
    "verhunzendsten": "verhunzend",
    "verhunzendster": "verhunzend",
    "verhunzendstes": "verhunzend",
    "verhunzest": "verhunzen",
    "verhunzet": "verhunzen",
    "verhunzt": "verhunzen",
    "verhunzte": "verhunzen",
    "verhunztem": "verhunzt",
    "verhunzten": "verhunzen",
    "verhunzter": "verhunzt",
    "verhunztere": "verhunzt",
    "verhunzterem": "verhunzt",
    "verhunzteren": "verhunzt",
    "verhunzterer": "verhunzt",
    "verhunzteres": "verhunzt",
    "verhunztes": "verhunzt",
    "verhunztest": "verhunzen",
    "verhunzteste": "verhunzt",
    "verhunztestem": "verhunzt",
    "verhunztesten": "verhunzt",
    "verhunztester": "verhunzt",
    "verhunztestes": "verhunzt",
    "verhunztet": "verhunzen",
    "verhälfe": "verhelfen",
    "verhälfen": "verhelfen",
    "verhälfest": "verhelfen",
    "verhälfet": "verhelfen",
    "verhält": "verhalten",
    "verhältnismäßige": "verhältnismäßig",
    "verhältnismäßigem": "verhältnismäßig",
    "verhältnismäßigen": "verhältnismäßig",
    "verhältnismäßiger": "verhältnismäßig",
    "verhältnismäßiges": "verhältnismäßig",
    "verhältst": "verhalten",
    "verhänge": "verhängen",
    "verhängend": "verhängen",
    "verhängende": "verhängend",
    "verhängendem": "verhängend",
    "verhängenden": "verhängend",
    "verhängender": "verhängend",
    "verhängendes": "verhängend",
    "verhängest": "verhängen",
    "verhänget": "verhängen",
    "verhängnisvolle": "verhängnisvoll",
    "verhängnisvollem": "verhängnisvoll",
    "verhängnisvollen": "verhängnisvoll",
    "verhängnisvoller": "verhängnisvoll",
    "verhängnisvollere": "verhängnisvoll",
    "verhängnisvollerem": "verhängnisvoll",
    "verhängnisvolleren": "verhängnisvoll",
    "verhängnisvollerer": "verhängnisvoll",
    "verhängnisvolleres": "verhängnisvoll",
    "verhängnisvolles": "verhängnisvoll",
    "verhängnisvollste": "verhängnisvoll",
    "verhängnisvollstem": "verhängnisvoll",
    "verhängnisvollsten": "verhängnisvoll",
    "verhängnisvollster": "verhängnisvoll",
    "verhängnisvollstes": "verhängnisvoll",
    "verhängst": "verhängen",
    "verhängt": "verhängen",
    "verhängte": "verhängen",
    "verhängtem": "verhängt",
    "verhängten": "verhängen",
    "verhängter": "verhängt",
    "verhängtes": "verhängt",
    "verhängtest": "verhängen",
    "verhängtet": "verhängen",
    "verhärte": "verhärten",
    "verhärtend": "verhärten",
    "verhärtende": "verhärtend",
    "verhärtendem": "verhärtend",
    "verhärtenden": "verhärtend",
    "verhärtender": "verhärtend",
    "verhärtendere": "verhärtend",
    "verhärtenderem": "verhärtend",
    "verhärtenderen": "verhärtend",
    "verhärtenderer": "verhärtend",
    "verhärtenderes": "verhärtend",
    "verhärtendes": "verhärtend",
    "verhärtendste": "verhärtend",
    "verhärtendstem": "verhärtend",
    "verhärtendsten": "verhärtend",
    "verhärtendster": "verhärtend",
    "verhärtendstes": "verhärtend",
    "verhärtest": "verhärten",
    "verhärtet": "verhärten",
    "verhärtete": "verhärten",
    "verhärtetem": "verhärtet",
    "verhärteten": "verhärten",
    "verhärteter": "verhärtet",
    "verhärtetere": "verhärtet",
    "verhärteterem": "verhärtet",
    "verhärteteren": "verhärtet",
    "verhärteterer": "verhärtet",
    "verhärteteres": "verhärtet",
    "verhärtetes": "verhärtet",
    "verhärtetest": "verhärten",
    "verhärteteste": "verhärtet",
    "verhärtetestem": "verhärtet",
    "verhärtetesten": "verhärtet",
    "verhärtetester": "verhärtet",
    "verhärtetestes": "verhärtet",
    "verhärtetet": "verhärten",
    "verhätschele": "verhätscheln",
    "verhätschelnd": "verhätscheln",
    "verhätschelnde": "verhätschelnd",
    "verhätschelndem": "verhätschelnd",
    "verhätschelnden": "verhätschelnd",
    "verhätschelnder": "verhätschelnd",
    "verhätschelndere": "verhätschelnd",
    "verhätschelnderem": "verhätschelnd",
    "verhätschelnderen": "verhätschelnd",
    "verhätschelnderer": "verhätschelnd",
    "verhätschelnderes": "verhätschelnd",
    "verhätschelndes": "verhätschelnd",
    "verhätschelndste": "verhätschelnd",
    "verhätschelndstem": "verhätschelnd",
    "verhätschelndsten": "verhätschelnd",
    "verhätschelndster": "verhätschelnd",
    "verhätschelndstes": "verhätschelnd",
    "verhätschelst": "verhätscheln",
    "verhätschelt": "verhätscheln",
    "verhätschelte": "verhätscheln",
    "verhätscheltem": "verhätschelt",
    "verhätschelten": "verhätscheln",
    "verhätschelter": "verhätschelt",
    "verhätscheltere": "verhätschelt",
    "verhätschelterem": "verhätschelt",
    "verhätschelteren": "verhätschelt",
    "verhätschelterer": "verhätschelt",
    "verhätschelteres": "verhätschelt",
    "verhätscheltes": "verhätschelt",
    "verhätscheltest": "verhätscheln",
    "verhätschelteste": "verhätschelt",
    "verhätscheltestem": "verhätschelt",
    "verhätscheltesten": "verhätschelt",
    "verhätscheltester": "verhätschelt",
    "verhätscheltestes": "verhätschelt",
    "verhätscheltet": "verhätscheln",
    "verhätschle": "verhätscheln",
    "verhöbe": "verheben",
    "verhöben": "verheben",
    "verhöbest": "verheben",
    "verhöbet": "verheben",
    "verhöhne": "verhöhnen",
    "verhöhnend": "verhöhnen",
    "verhöhnende": "verhöhnend",
    "verhöhnendem": "verhöhnend",
    "verhöhnenden": "verhöhnend",
    "verhöhnender": "verhöhnend",
    "verhöhnendere": "verhöhnend",
    "verhöhnenderem": "verhöhnend",
    "verhöhnenderen": "verhöhnend",
    "verhöhnenderer": "verhöhnend",
    "verhöhnenderes": "verhöhnend",
    "verhöhnendes": "verhöhnend",
    "verhöhnendste": "verhöhnend",
    "verhöhnendstem": "verhöhnend",
    "verhöhnendsten": "verhöhnend",
    "verhöhnendster": "verhöhnend",
    "verhöhnendstes": "verhöhnend",
    "verhöhnest": "verhöhnen",
    "verhöhnet": "verhöhnen",
    "verhöhnst": "verhöhnen",
    "verhöhnt": "verhöhnen",
    "verhöhnte": "verhöhnen",
    "verhöhntem": "verhöhnt",
    "verhöhnten": "verhöhnen",
    "verhöhnter": "verhöhnt",
    "verhöhntere": "verhöhnt",
    "verhöhnterem": "verhöhnt",
    "verhöhnteren": "verhöhnt",
    "verhöhnterer": "verhöhnt",
    "verhöhnteres": "verhöhnt",
    "verhöhntes": "verhöhnt",
    "verhöhntest": "verhöhnen",
    "verhöhnteste": "verhöhnt",
    "verhöhntestem": "verhöhnt",
    "verhöhntesten": "verhöhnt",
    "verhöhntester": "verhöhnt",
    "verhöhntestes": "verhöhnt",
    "verhöhntet": "verhöhnen",
    "verhökere": "verhökern",
    "verhökernd": "verhökern",
    "verhökernde": "verhökernd",
    "verhökerndem": "verhökernd",
    "verhökernden": "verhökernd",
    "verhökernder": "verhökernd",
    "verhökerndes": "verhökernd",
    "verhökerst": "verhökern",
    "verhökert": "verhökern",
    "verhökerte": "verhökern",
    "verhökertem": "verhökert",
    "verhökerten": "verhökern",
    "verhökerter": "verhökert",
    "verhökertes": "verhökert",
    "verhökertest": "verhökern",
    "verhökertet": "verhökern",
    "verhörend": "verhören",
    "verhörende": "verhörend",
    "verhörendem": "verhörend",
    "verhörenden": "verhörend",
    "verhörender": "verhörend",
    "verhörendes": "verhörend",
    "verhörest": "verhören",
    "verhöret": "verhören",
    "verhörst": "verhören",
    "verhört": "verhören",
    "verhörte": "verhören",
    "verhörtem": "verhört",
    "verhörten": "verhören",
    "verhörter": "verhört",
    "verhörtes": "verhört",
    "verhörtest": "verhören",
    "verhörtet": "verhören",
    "verhülle": "verhüllen",
    "verhüllend": "verhüllen",
    "verhüllende": "verhüllend",
    "verhüllendem": "verhüllend",
    "verhüllenden": "verhüllend",
    "verhüllender": "verhüllend",
    "verhüllendere": "verhüllend",
    "verhüllenderem": "verhüllend",
    "verhüllenderen": "verhüllend",
    "verhüllenderer": "verhüllend",
    "verhüllenderes": "verhüllend",
    "verhüllendes": "verhüllend",
    "verhüllendste": "verhüllend",
    "verhüllendstem": "verhüllend",
    "verhüllendsten": "verhüllend",
    "verhüllendster": "verhüllend",
    "verhüllendstes": "verhüllend",
    "verhüllest": "verhüllen",
    "verhüllet": "verhüllen",
    "verhüllst": "verhüllen",
    "verhüllt": "verhüllen",
    "verhüllte": "verhüllen",
    "verhülltem": "verhüllt",
    "verhüllten": "verhüllen",
    "verhüllter": "verhüllt",
    "verhülltere": "verhüllt",
    "verhüllterem": "verhüllt",
    "verhüllteren": "verhüllt",
    "verhüllterer": "verhüllt",
    "verhüllteres": "verhüllt",
    "verhülltes": "verhüllt",
    "verhülltest": "verhüllen",
    "verhüllteste": "verhüllt",
    "verhülltestem": "verhüllt",
    "verhülltesten": "verhüllt",
    "verhülltester": "verhüllt",
    "verhülltestes": "verhüllt",
    "verhülltet": "verhüllen",
    "verhüte": "verhüten",
    "verhütend": "verhüten",
    "verhütende": "verhütend",
    "verhütendem": "verhütend",
    "verhütenden": "verhütend",
    "verhütender": "verhütend",
    "verhütendes": "verhütend",
    "verhütest": "verhüten",
    "verhütet": "verhüten",
    "verhütete": "verhüten",
    "verhütetem": "verhütet",
    "verhüteten": "verhüten",
    "verhüteter": "verhütet",
    "verhütetes": "verhütet",
    "verhütetest": "verhüten",
    "verhütetet": "verhüten",
    "verinnerliche": "verinnerlichen",
    "verinnerlichend": "verinnerlichen",
    "verinnerlichende": "verinnerlichend",
    "verinnerlichendem": "verinnerlichend",
    "verinnerlichenden": "verinnerlichend",
    "verinnerlichender": "verinnerlichend",
    "verinnerlichendes": "verinnerlichend",
    "verinnerlichest": "verinnerlichen",
    "verinnerlichet": "verinnerlichen",
    "verinnerlichst": "verinnerlichen",
    "verinnerlicht": "verinnerlichen",
    "verinnerlichte": "verinnerlichen",
    "verinnerlichtem": "verinnerlicht",
    "verinnerlichten": "verinnerlichen",
    "verinnerlichter": "verinnerlicht",
    "verinnerlichtes": "verinnerlicht",
    "verinnerlichtest": "verinnerlichen",
    "verinnerlichtet": "verinnerlichen",
    "verirre": "verirren",
    "verirrend": "verirren",
    "verirrende": "verirrend",
    "verirrendem": "verirrend",
    "verirrenden": "verirrend",
    "verirrender": "verirrend",
    "verirrendes": "verirrend",
    "verirrest": "verirren",
    "verirret": "verirren",
    "verirrst": "verirren",
    "verirrt": "verirren",
    "verirrte": "verirren",
    "verirrtem": "verirrt",
    "verirrten": "verirren",
    "verirrter": "verirrt",
    "verirrtere": "verirrt",
    "verirrterem": "verirrt",
    "verirrteren": "verirrt",
    "verirrterer": "verirrt",
    "verirrteres": "verirrt",
    "verirrtes": "verirrt",
    "verirrtest": "verirren",
    "verirrteste": "verirrt",
    "verirrtestem": "verirrt",
    "verirrtesten": "verirrt",
    "verirrtester": "verirrt",
    "verirrtestes": "verirrt",
    "verirrtet": "verirren",
    "verjage": "verjagen",
    "verjagend": "verjagen",
    "verjagende": "verjagend",
    "verjagendem": "verjagend",
    "verjagenden": "verjagend",
    "verjagender": "verjagend",
    "verjagendere": "verjagend",
    "verjagenderem": "verjagend",
    "verjagenderen": "verjagend",
    "verjagenderer": "verjagend",
    "verjagenderes": "verjagend",
    "verjagendes": "verjagend",
    "verjagendste": "verjagend",
    "verjagendstem": "verjagend",
    "verjagendsten": "verjagend",
    "verjagendster": "verjagend",
    "verjagendstes": "verjagend",
    "verjagest": "verjagen",
    "verjaget": "verjagen",
    "verjagst": "verjagen",
    "verjagt": "verjagen",
    "verjagte": "verjagen",
    "verjagtem": "verjagt",
    "verjagten": "verjagen",
    "verjagter": "verjagt",
    "verjagtere": "verjagt",
    "verjagterem": "verjagt",
    "verjagteren": "verjagt",
    "verjagterer": "verjagt",
    "verjagteres": "verjagt",
    "verjagtes": "verjagt",
    "verjagtest": "verjagen",
    "verjagteste": "verjagt",
    "verjagtestem": "verjagt",
    "verjagtesten": "verjagt",
    "verjagtester": "verjagt",
    "verjagtestes": "verjagt",
    "verjagtet": "verjagen",
    "verjubele": "verjubeln",
    "verjubelnd": "verjubeln",
    "verjubelnde": "verjubelnd",
    "verjubelndem": "verjubelnd",
    "verjubelnden": "verjubelnd",
    "verjubelnder": "verjubelnd",
    "verjubelndere": "verjubelnd",
    "verjubelnderem": "verjubelnd",
    "verjubelnderen": "verjubelnd",
    "verjubelnderer": "verjubelnd",
    "verjubelnderes": "verjubelnd",
    "verjubelndes": "verjubelnd",
    "verjubelndste": "verjubelnd",
    "verjubelndstem": "verjubelnd",
    "verjubelndsten": "verjubelnd",
    "verjubelndster": "verjubelnd",
    "verjubelndstes": "verjubelnd",
    "verjubelst": "verjubeln",
    "verjubelt": "verjubeln",
    "verjubelte": "verjubeln",
    "verjubeltem": "verjubelt",
    "verjubelten": "verjubeln",
    "verjubelter": "verjubelt",
    "verjubeltere": "verjubelt",
    "verjubelterem": "verjubelt",
    "verjubelteren": "verjubelt",
    "verjubelterer": "verjubelt",
    "verjubelteres": "verjubelt",
    "verjubeltes": "verjubelt",
    "verjubeltest": "verjubeln",
    "verjubelteste": "verjubelt",
    "verjubeltestem": "verjubelt",
    "verjubeltesten": "verjubelt",
    "verjubeltester": "verjubelt",
    "verjubeltestes": "verjubelt",
    "verjubeltet": "verjubeln",
    "verjuble": "verjubeln",
    "verjähre": "verjähren",
    "verjährend": "verjähren",
    "verjährende": "verjährend",
    "verjährendem": "verjährend",
    "verjährenden": "verjährend",
    "verjährender": "verjährend",
    "verjährendes": "verjährend",
    "verjährest": "verjähren",
    "verjähret": "verjähren",
    "verjährst": "verjähren",
    "verjährt": "verjähren",
    "verjährte": "verjähren",
    "verjährtem": "verjährt",
    "verjährten": "verjähren",
    "verjährter": "verjährt",
    "verjährtes": "verjährt",
    "verjährtest": "verjähren",
    "verjährtet": "verjähren",
    "verjünge": "verjüngen",
    "verjüngend": "verjüngen",
    "verjüngende": "verjüngend",
    "verjüngendem": "verjüngend",
    "verjüngenden": "verjüngend",
    "verjüngender": "verjüngend",
    "verjüngendere": "verjüngend",
    "verjüngenderem": "verjüngend",
    "verjüngenderen": "verjüngend",
    "verjüngenderer": "verjüngend",
    "verjüngenderes": "verjüngend",
    "verjüngendes": "verjüngend",
    "verjüngendste": "verjüngend",
    "verjüngendstem": "verjüngend",
    "verjüngendsten": "verjüngend",
    "verjüngendster": "verjüngend",
    "verjüngendstes": "verjüngend",
    "verjüngest": "verjüngen",
    "verjünget": "verjüngen",
    "verjüngst": "verjüngen",
    "verjüngt": "verjüngen",
    "verjüngte": "verjüngen",
    "verjüngtem": "verjüngt",
    "verjüngten": "verjüngen",
    "verjüngter": "verjüngt",
    "verjüngtere": "verjüngt",
    "verjüngterem": "verjüngt",
    "verjüngteren": "verjüngt",
    "verjüngterer": "verjüngt",
    "verjüngteres": "verjüngt",
    "verjüngtes": "verjüngt",
    "verjüngtest": "verjüngen",
    "verjüngteste": "verjüngt",
    "verjüngtestem": "verjüngt",
    "verjüngtesten": "verjüngt",
    "verjüngtester": "verjüngt",
    "verjüngtestes": "verjüngt",
    "verjüngtet": "verjüngen",
    "verkabele": "verkabeln",
    "verkabelnd": "verkabeln",
    "verkabelnde": "verkabelnd",
    "verkabelndem": "verkabelnd",
    "verkabelnden": "verkabelnd",
    "verkabelnder": "verkabelnd",
    "verkabelndes": "verkabelnd",
    "verkabelst": "verkabeln",
    "verkabelt": "verkabeln",
    "verkabelte": "verkabeln",
    "verkabeltem": "verkabelt",
    "verkabelten": "verkabeln",
    "verkabelter": "verkabelt",
    "verkabeltere": "verkabelt",
    "verkabelterem": "verkabelt",
    "verkabelteren": "verkabelt",
    "verkabelterer": "verkabelt",
    "verkabelteres": "verkabelt",
    "verkabeltes": "verkabelt",
    "verkabeltest": "verkabeln",
    "verkabelteste": "verkabelt",
    "verkabeltestem": "verkabelt",
    "verkabeltesten": "verkabelt",
    "verkabeltester": "verkabelt",
    "verkabeltestes": "verkabelt",
    "verkabeltet": "verkabeln",
    "verkable": "verkabeln",
    "verkachele": "verkacheln",
    "verkachelnd": "verkacheln",
    "verkachelnde": "verkachelnd",
    "verkachelndem": "verkachelnd",
    "verkachelnden": "verkachelnd",
    "verkachelnder": "verkachelnd",
    "verkachelndes": "verkachelnd",
    "verkachelst": "verkacheln",
    "verkachelt": "verkacheln",
    "verkachelte": "verkacheln",
    "verkacheltem": "verkachelt",
    "verkachelten": "verkacheln",
    "verkachelter": "verkachelt",
    "verkacheltere": "verkachelt",
    "verkachelterem": "verkachelt",
    "verkachelteren": "verkachelt",
    "verkachelterer": "verkachelt",
    "verkachelteres": "verkachelt",
    "verkacheltes": "verkachelt",
    "verkacheltest": "verkacheln",
    "verkachelteste": "verkachelt",
    "verkacheltestem": "verkachelt",
    "verkacheltesten": "verkachelt",
    "verkacheltester": "verkachelt",
    "verkacheltestes": "verkachelt",
    "verkacheltet": "verkacheln",
    "verkachle": "verkacheln",
    "verkalke": "verkalken",
    "verkalkend": "verkalken",
    "verkalkende": "verkalkend",
    "verkalkendem": "verkalkend",
    "verkalkenden": "verkalkend",
    "verkalkender": "verkalkend",
    "verkalkendere": "verkalkend",
    "verkalkenderem": "verkalkend",
    "verkalkenderen": "verkalkend",
    "verkalkenderer": "verkalkend",
    "verkalkenderes": "verkalkend",
    "verkalkendes": "verkalkend",
    "verkalkendste": "verkalkend",
    "verkalkendstem": "verkalkend",
    "verkalkendsten": "verkalkend",
    "verkalkendster": "verkalkend",
    "verkalkendstes": "verkalkend",
    "verkalkest": "verkalken",
    "verkalket": "verkalken",
    "verkalkst": "verkalken",
    "verkalkt": "verkalken",
    "verkalkte": "verkalken",
    "verkalktem": "verkalkt",
    "verkalkten": "verkalken",
    "verkalkter": "verkalkt",
    "verkalktere": "verkalkt",
    "verkalkterem": "verkalkt",
    "verkalkteren": "verkalkt",
    "verkalkterer": "verkalkt",
    "verkalkteres": "verkalkt",
    "verkalktes": "verkalkt",
    "verkalktest": "verkalken",
    "verkalkteste": "verkalkt",
    "verkalktestem": "verkalkt",
    "verkalktesten": "verkalkt",
    "verkalktester": "verkalkt",
    "verkalktestes": "verkalkt",
    "verkalktet": "verkalken",
    "verkalkuliere": "verkalkulieren",
    "verkalkulierend": "verkalkulieren",
    "verkalkulierende": "verkalkulierend",
    "verkalkulierendem": "verkalkulierend",
    "verkalkulierenden": "verkalkulierend",
    "verkalkulierender": "verkalkulierend",
    "verkalkulierendes": "verkalkulierend",
    "verkalkulierest": "verkalkulieren",
    "verkalkulieret": "verkalkulieren",
    "verkalkulierst": "verkalkulieren",
    "verkalkuliert": "verkalkulieren",
    "verkalkulierte": "verkalkulieren",
    "verkalkuliertem": "verkalkuliert",
    "verkalkulierten": "verkalkulieren",
    "verkalkulierter": "verkalkuliert",
    "verkalkuliertes": "verkalkuliert",
    "verkalkuliertest": "verkalkulieren",
    "verkalkuliertet": "verkalkulieren",
    "verkam": "verkommen",
    "verkamen": "verkommen",
    "verkamst": "verkommen",
    "verkamt": "verkommen",
    "verkannt": "verkennen",
    "verkannte": "verkannt",
    "verkanntem": "verkannt",
    "verkannten": "verkannt",
    "verkannter": "verkannt",
    "verkanntere": "verkannt",
    "verkannterem": "verkannt",
    "verkannteren": "verkannt",
    "verkannterer": "verkannt",
    "verkannteres": "verkannt",
    "verkanntes": "verkannt",
    "verkanntest": "verkennen",
    "verkannteste": "verkannt",
    "verkanntestem": "verkannt",
    "verkanntesten": "verkannt",
    "verkanntester": "verkannt",
    "verkanntestes": "verkannt",
    "verkanntet": "verkennen",
    "verkante": "verkanten",
    "verkantend": "verkanten",
    "verkantende": "verkantend",
    "verkantendem": "verkantend",
    "verkantenden": "verkantend",
    "verkantender": "verkantend",
    "verkantendere": "verkantend",
    "verkantenderem": "verkantend",
    "verkantenderen": "verkantend",
    "verkantenderer": "verkantend",
    "verkantenderes": "verkantend",
    "verkantendes": "verkantend",
    "verkantendste": "verkantend",
    "verkantendstem": "verkantend",
    "verkantendsten": "verkantend",
    "verkantendster": "verkantend",
    "verkantendstes": "verkantend",
    "verkantest": "verkanten",
    "verkantet": "verkanten",
    "verkantete": "verkanten",
    "verkantetem": "verkantet",
    "verkanteten": "verkanten",
    "verkanteter": "verkantet",
    "verkantetere": "verkantet",
    "verkanteterem": "verkantet",
    "verkanteteren": "verkantet",
    "verkanteterer": "verkantet",
    "verkanteteres": "verkantet",
    "verkantetes": "verkantet",
    "verkantetest": "verkanten",
    "verkanteteste": "verkantet",
    "verkantetestem": "verkantet",
    "verkantetesten": "verkantet",
    "verkantetester": "verkantet",
    "verkantetestes": "verkantet",
    "verkantetet": "verkanten",
    "verkappe": "verkappen",
    "verkappend": "verkappen",
    "verkappende": "verkappend",
    "verkappendem": "verkappend",
    "verkappenden": "verkappend",
    "verkappender": "verkappend",
    "verkappendere": "verkappend",
    "verkappenderem": "verkappend",
    "verkappenderen": "verkappend",
    "verkappenderer": "verkappend",
    "verkappenderes": "verkappend",
    "verkappendes": "verkappend",
    "verkappendste": "verkappend",
    "verkappendstem": "verkappend",
    "verkappendsten": "verkappend",
    "verkappendster": "verkappend",
    "verkappendstes": "verkappend",
    "verkappest": "verkappen",
    "verkappet": "verkappen",
    "verkappst": "verkappen",
    "verkappt": "verkappen",
    "verkappte": "verkappen",
    "verkapptem": "verkappt",
    "verkappten": "verkappen",
    "verkappter": "verkappt",
    "verkapptere": "verkappt",
    "verkappterem": "verkappt",
    "verkappteren": "verkappt",
    "verkappterer": "verkappt",
    "verkappteres": "verkappt",
    "verkapptes": "verkappt",
    "verkapptest": "verkappen",
    "verkappteste": "verkappt",
    "verkapptestem": "verkappt",
    "verkapptesten": "verkappt",
    "verkapptester": "verkappt",
    "verkapptestes": "verkappt",
    "verkapptet": "verkappen",
    "verkaterte": "verkatert",
    "verkatertem": "verkatert",
    "verkaterten": "verkatert",
    "verkaterter": "verkatert",
    "verkatertere": "verkatert",
    "verkaterterem": "verkatert",
    "verkaterteren": "verkatert",
    "verkaterterer": "verkatert",
    "verkaterteres": "verkatert",
    "verkatertes": "verkatert",
    "verkaterteste": "verkatert",
    "verkatertestem": "verkatert",
    "verkatertesten": "verkatert",
    "verkatertester": "verkatert",
    "verkatertestes": "verkatert",
    "verkaufend": "verkaufen",
    "verkaufende": "verkaufend",
    "verkaufendem": "verkaufend",
    "verkaufenden": "verkaufend",
    "verkaufender": "verkaufend",
    "verkaufendes": "verkaufend",
    "verkaufest": "verkaufen",
    "verkaufet": "verkaufen",
    "verkaufsförderndem": "verkaufsfördernd",
    "verkaufsfördernden": "verkaufsfördernd",
    "verkaufsfördernder": "verkaufsfördernd",
    "verkaufsförderndere": "verkaufsfördernd",
    "verkaufsfördernderem": "verkaufsfördernd",
    "verkaufsfördernderen": "verkaufsfördernd",
    "verkaufsfördernderer": "verkaufsfördernd",
    "verkaufsfördernderes": "verkaufsfördernd",
    "verkaufsförderndes": "verkaufsfördernd",
    "verkaufsförderndste": "verkaufsfördernd",
    "verkaufsförderndstem": "verkaufsfördernd",
    "verkaufsförderndsten": "verkaufsfördernd",
    "verkaufsförderndster": "verkaufsfördernd",
    "verkaufsförderndstes": "verkaufsfördernd",
    "verkaufsoffene": "verkaufsoffen",
    "verkaufsoffenem": "verkaufsoffen",
    "verkaufsoffenen": "verkaufsoffen",
    "verkaufsoffener": "verkaufsoffen",
    "verkaufsoffenes": "verkaufsoffen",
    "verkaufst": "verkaufen",
    "verkauft": "verkaufen",
    "verkaufte": "verkaufen",
    "verkauftem": "verkauft",
    "verkauften": "verkaufen",
    "verkaufter": "verkauft",
    "verkauftes": "verkauft",
    "verkauftest": "verkaufen",
    "verkauftet": "verkaufen",
    "verkehre": "verkehren",
    "verkehrend": "verkehren",
    "verkehrende": "verkehrend",
    "verkehrendem": "verkehrend",
    "verkehrenden": "verkehrend",
    "verkehrender": "verkehrend",
    "verkehrendes": "verkehrend",
    "verkehrest": "verkehren",
    "verkehret": "verkehren",
    "verkehrsberuhigtem": "verkehrsberuhigt",
    "verkehrsberuhigten": "verkehrsberuhigt",
    "verkehrsberuhigter": "verkehrsberuhigt",
    "verkehrsberuhigtere": "verkehrsberuhigt",
    "verkehrsberuhigterem": "verkehrsberuhigt",
    "verkehrsberuhigteren": "verkehrsberuhigt",
    "verkehrsberuhigterer": "verkehrsberuhigt",
    "verkehrsberuhigteres": "verkehrsberuhigt",
    "verkehrsberuhigtes": "verkehrsberuhigt",
    "verkehrsberuhigteste": "verkehrsberuhigt",
    "verkehrsberuhigtestem": "verkehrsberuhigt",
    "verkehrsberuhigtesten": "verkehrsberuhigt",
    "verkehrsberuhigtester": "verkehrsberuhigt",
    "verkehrsberuhigtestes": "verkehrsberuhigt",
    "verkehrsreiche": "verkehrsreich",
    "verkehrsreichem": "verkehrsreich",
    "verkehrsreichen": "verkehrsreich",
    "verkehrsreicher": "verkehrsreich",
    "verkehrsreichere": "verkehrsreich",
    "verkehrsreicherem": "verkehrsreich",
    "verkehrsreicheren": "verkehrsreich",
    "verkehrsreicherer": "verkehrsreich",
    "verkehrsreicheres": "verkehrsreich",
    "verkehrsreiches": "verkehrsreich",
    "verkehrsreichste": "verkehrsreich",
    "verkehrsreichstem": "verkehrsreich",
    "verkehrsreichsten": "verkehrsreich",
    "verkehrsreichster": "verkehrsreich",
    "verkehrsreichstes": "verkehrsreich",
    "verkehrsschwache": "verkehrsschwach",
    "verkehrsschwachem": "verkehrsschwach",
    "verkehrsschwachen": "verkehrsschwach",
    "verkehrsschwacher": "verkehrsschwach",
    "verkehrsschwaches": "verkehrsschwach",
    "verkehrsschwächer": "verkehrsschwach",
    "verkehrsschwächere": "verkehrsschwach",
    "verkehrsschwächerem": "verkehrsschwach",
    "verkehrsschwächeren": "verkehrsschwach",
    "verkehrsschwächerer": "verkehrsschwach",
    "verkehrsschwächeres": "verkehrsschwach",
    "verkehrsschwächste": "verkehrsschwach",
    "verkehrsschwächstem": "verkehrsschwach",
    "verkehrsschwächsten": "verkehrsschwach",
    "verkehrsschwächster": "verkehrsschwach",
    "verkehrsschwächstes": "verkehrsschwach",
    "verkehrst": "verkehren",
    "verkehrswidrige": "verkehrswidrig",
    "verkehrswidrigem": "verkehrswidrig",
    "verkehrswidrigen": "verkehrswidrig",
    "verkehrswidriger": "verkehrswidrig",
    "verkehrswidriges": "verkehrswidrig",
    "verkehrt": "verkehren",
    "verkehrte": "verkehren",
    "verkehrtem": "verkehrt",
    "verkehrten": "verkehren",
    "verkehrter": "verkehrt",
    "verkehrtere": "verkehrt",
    "verkehrterem": "verkehrt",
    "verkehrteren": "verkehrt",
    "verkehrterer": "verkehrt",
    "verkehrteres": "verkehrt",
    "verkehrtes": "verkehrt",
    "verkehrtest": "verkehren",
    "verkehrteste": "verkehrt",
    "verkehrtestem": "verkehrt",
    "verkehrtesten": "verkehrt",
    "verkehrtester": "verkehrt",
    "verkehrtestes": "verkehrt",
    "verkehrtet": "verkehren",
    "verkeile": "verkeilen",
    "verkeilend": "verkeilen",
    "verkeilende": "verkeilend",
    "verkeilendem": "verkeilend",
    "verkeilenden": "verkeilend",
    "verkeilender": "verkeilend",
    "verkeilendere": "verkeilend",
    "verkeilenderem": "verkeilend",
    "verkeilenderen": "verkeilend",
    "verkeilenderer": "verkeilend",
    "verkeilenderes": "verkeilend",
    "verkeilendes": "verkeilend",
    "verkeilendste": "verkeilend",
    "verkeilendstem": "verkeilend",
    "verkeilendsten": "verkeilend",
    "verkeilendster": "verkeilend",
    "verkeilendstes": "verkeilend",
    "verkeilest": "verkeilen",
    "verkeilet": "verkeilen",
    "verkeilst": "verkeilen",
    "verkeilt": "verkeilen",
    "verkeilte": "verkeilen",
    "verkeiltem": "verkeilt",
    "verkeilten": "verkeilen",
    "verkeilter": "verkeilt",
    "verkeiltere": "verkeilt",
    "verkeilterem": "verkeilt",
    "verkeilteren": "verkeilt",
    "verkeilterer": "verkeilt",
    "verkeilteres": "verkeilt",
    "verkeiltes": "verkeilt",
    "verkeiltest": "verkeilen",
    "verkeilteste": "verkeilt",
    "verkeiltestem": "verkeilt",
    "verkeiltesten": "verkeilt",
    "verkeiltester": "verkeilt",
    "verkeiltestes": "verkeilt",
    "verkeiltet": "verkeilen",
    "verkenne": "verkennen",
    "verkennend": "verkennen",
    "verkennende": "verkennend",
    "verkennendem": "verkennend",
    "verkennenden": "verkennend",
    "verkennender": "verkennend",
    "verkennendes": "verkennend",
    "verkennest": "verkennen",
    "verkennet": "verkennen",
    "verkennst": "verkennen",
    "verkennt": "verkennen",
    "verkette": "verketten",
    "verkettend": "verketten",
    "verkettende": "verkettend",
    "verkettendem": "verkettend",
    "verkettenden": "verkettend",
    "verkettender": "verkettend",
    "verkettendere": "verkettend",
    "verkettenderem": "verkettend",
    "verkettenderen": "verkettend",
    "verkettenderer": "verkettend",
    "verkettenderes": "verkettend",
    "verkettendes": "verkettend",
    "verkettendste": "verkettend",
    "verkettendstem": "verkettend",
    "verkettendsten": "verkettend",
    "verkettendster": "verkettend",
    "verkettendstes": "verkettend",
    "verkettest": "verketten",
    "verkettet": "verketten",
    "verkettete": "verketten",
    "verkettetem": "verkettet",
    "verketteten": "verketten",
    "verketteter": "verkettet",
    "verkettetere": "verkettet",
    "verketteterem": "verkettet",
    "verketteteren": "verkettet",
    "verketteterer": "verkettet",
    "verketteteres": "verkettet",
    "verkettetes": "verkettet",
    "verkettetest": "verketten",
    "verketteteste": "verkettet",
    "verkettetestem": "verkettet",
    "verkettetesten": "verkettet",
    "verkettetester": "verkettet",
    "verkettetestes": "verkettet",
    "verkettetet": "verketten",
    "verkitte": "verkitten",
    "verkittend": "verkitten",
    "verkittende": "verkittend",
    "verkittendem": "verkittend",
    "verkittenden": "verkittend",
    "verkittender": "verkittend",
    "verkittendes": "verkittend",
    "verkittest": "verkitten",
    "verkittet": "verkitten",
    "verkittete": "verkitten",
    "verkittetem": "verkittet",
    "verkitteten": "verkitten",
    "verkitteter": "verkittet",
    "verkittetes": "verkittet",
    "verkittetest": "verkitten",
    "verkittetet": "verkitten",
    "verklage": "verklagen",
    "verklagend": "verklagen",
    "verklagende": "verklagend",
    "verklagendem": "verklagend",
    "verklagenden": "verklagend",
    "verklagender": "verklagend",
    "verklagendes": "verklagend",
    "verklagest": "verklagen",
    "verklaget": "verklagen",
    "verklagst": "verklagen",
    "verklagt": "verklagen",
    "verklagte": "verklagen",
    "verklagtem": "verklagt",
    "verklagten": "verklagen",
    "verklagter": "verklagt",
    "verklagtes": "verklagt",
    "verklagtest": "verklagen",
    "verklagtet": "verklagen",
    "verklammere": "verklammern",
    "verklammernd": "verklammern",
    "verklammernde": "verklammernd",
    "verklammerndem": "verklammernd",
    "verklammernden": "verklammernd",
    "verklammernder": "verklammernd",
    "verklammerndere": "verklammernd",
    "verklammernderem": "verklammernd",
    "verklammernderen": "verklammernd",
    "verklammernderer": "verklammernd",
    "verklammernderes": "verklammernd",
    "verklammerndes": "verklammernd",
    "verklammerndste": "verklammernd",
    "verklammerndstem": "verklammernd",
    "verklammerndsten": "verklammernd",
    "verklammerndster": "verklammernd",
    "verklammerndstes": "verklammernd",
    "verklammerst": "verklammern",
    "verklammert": "verklammern",
    "verklammerte": "verklammern",
    "verklammertem": "verklammert",
    "verklammerten": "verklammern",
    "verklammerter": "verklammert",
    "verklammertere": "verklammert",
    "verklammerterem": "verklammert",
    "verklammerteren": "verklammert",
    "verklammerterer": "verklammert",
    "verklammerteres": "verklammert",
    "verklammertes": "verklammert",
    "verklammertest": "verklammern",
    "verklammerteste": "verklammert",
    "verklammertestem": "verklammert",
    "verklammertesten": "verklammert",
    "verklammertester": "verklammert",
    "verklammertestes": "verklammert",
    "verklammertet": "verklammern",
    "verklang": "verklingen",
    "verklangen": "verklingen",
    "verklangst": "verklingen",
    "verklangt": "verklingen",
    "verklausele": "verklauseln",
    "verklauselnd": "verklauseln",
    "verklauselnde": "verklauselnd",
    "verklauselndem": "verklauselnd",
    "verklauselnden": "verklauselnd",
    "verklauselnder": "verklauselnd",
    "verklauselndere": "verklauselnd",
    "verklauselnderem": "verklauselnd",
    "verklauselnderen": "verklauselnd",
    "verklauselnderer": "verklauselnd",
    "verklauselnderes": "verklauselnd",
    "verklauselndes": "verklauselnd",
    "verklauselndste": "verklauselnd",
    "verklauselndstem": "verklauselnd",
    "verklauselndsten": "verklauselnd",
    "verklauselndster": "verklauselnd",
    "verklauselndstes": "verklauselnd",
    "verklauselst": "verklauseln",
    "verklauselt": "verklauseln",
    "verklauselte": "verklauseln",
    "verklauseltem": "verklauselt",
    "verklauselten": "verklauseln",
    "verklauselter": "verklauselt",
    "verklauseltere": "verklauselt",
    "verklauselterem": "verklauselt",
    "verklauselteren": "verklauselt",
    "verklauselterer": "verklauselt",
    "verklauselteres": "verklauselt",
    "verklauseltes": "verklauselt",
    "verklauseltest": "verklauseln",
    "verklauselteste": "verklauselt",
    "verklauseltestem": "verklauselt",
    "verklauseltesten": "verklauselt",
    "verklauseltester": "verklauselt",
    "verklauseltestes": "verklauselt",
    "verklauseltet": "verklauseln",
    "verklausle": "verklauseln",
    "verklebe": "verkleben",
    "verklebend": "verkleben",
    "verklebende": "verklebend",
    "verklebendem": "verklebend",
    "verklebenden": "verklebend",
    "verklebender": "verklebend",
    "verklebendere": "verklebend",
    "verklebenderem": "verklebend",
    "verklebenderen": "verklebend",
    "verklebenderer": "verklebend",
    "verklebenderes": "verklebend",
    "verklebendes": "verklebend",
    "verklebendste": "verklebend",
    "verklebendstem": "verklebend",
    "verklebendsten": "verklebend",
    "verklebendster": "verklebend",
    "verklebendstes": "verklebend",
    "verklebest": "verkleben",
    "verklebet": "verkleben",
    "verklebst": "verkleben",
    "verklebt": "verkleben",
    "verklebte": "verkleben",
    "verklebtem": "verklebt",
    "verklebten": "verkleben",
    "verklebter": "verklebt",
    "verklebtere": "verklebt",
    "verklebterem": "verklebt",
    "verklebteren": "verklebt",
    "verklebterer": "verklebt",
    "verklebteres": "verklebt",
    "verklebtes": "verklebt",
    "verklebtest": "verkleben",
    "verklebteste": "verklebt",
    "verklebtestem": "verklebt",
    "verklebtesten": "verklebt",
    "verklebtester": "verklebt",
    "verklebtestes": "verklebt",
    "verklebtet": "verkleben",
    "verkleide": "verkleiden",
    "verkleidend": "verkleiden",
    "verkleidende": "verkleidend",
    "verkleidendem": "verkleidend",
    "verkleidenden": "verkleidend",
    "verkleidender": "verkleidend",
    "verkleidendere": "verkleidend",
    "verkleidenderem": "verkleidend",
    "verkleidenderen": "verkleidend",
    "verkleidenderer": "verkleidend",
    "verkleidenderes": "verkleidend",
    "verkleidendes": "verkleidend",
    "verkleidendste": "verkleidend",
    "verkleidendstem": "verkleidend",
    "verkleidendsten": "verkleidend",
    "verkleidendster": "verkleidend",
    "verkleidendstes": "verkleidend",
    "verkleidest": "verkleiden",
    "verkleidet": "verkleiden",
    "verkleidete": "verkleiden",
    "verkleidetem": "verkleidet",
    "verkleideten": "verkleiden",
    "verkleideter": "verkleidet",
    "verkleidetere": "verkleidet",
    "verkleideterem": "verkleidet",
    "verkleideteren": "verkleidet",
    "verkleideterer": "verkleidet",
    "verkleideteres": "verkleidet",
    "verkleidetes": "verkleidet",
    "verkleidetest": "verkleiden",
    "verkleideteste": "verkleidet",
    "verkleidetestem": "verkleidet",
    "verkleidetesten": "verkleidet",
    "verkleidetester": "verkleidet",
    "verkleidetestes": "verkleidet",
    "verkleidetet": "verkleiden",
    "verkleinere": "verkleinern",
    "verkleinernd": "verkleinern",
    "verkleinernde": "verkleinernd",
    "verkleinerndem": "verkleinernd",
    "verkleinernden": "verkleinernd",
    "verkleinernder": "verkleinernd",
    "verkleinerndes": "verkleinernd",
    "verkleinerst": "verkleinern",
    "verkleinert": "verkleinern",
    "verkleinerte": "verkleinern",
    "verkleinertem": "verkleinert",
    "verkleinerten": "verkleinern",
    "verkleinerter": "verkleinert",
    "verkleinertere": "verkleinert",
    "verkleinerterem": "verkleinert",
    "verkleinerteren": "verkleinert",
    "verkleinerterer": "verkleinert",
    "verkleinerteres": "verkleinert",
    "verkleinertes": "verkleinert",
    "verkleinertest": "verkleinern",
    "verkleinerteste": "verkleinert",
    "verkleinertestem": "verkleinert",
    "verkleinertesten": "verkleinert",
    "verkleinertester": "verkleinert",
    "verkleinertestes": "verkleinert",
    "verkleinertet": "verkleinern",
    "verkleistere": "verkleistern",
    "verkleisternd": "verkleistern",
    "verkleisternde": "verkleisternd",
    "verkleisterndem": "verkleisternd",
    "verkleisternden": "verkleisternd",
    "verkleisternder": "verkleisternd",
    "verkleisterndes": "verkleisternd",
    "verkleisterst": "verkleistern",
    "verkleistert": "verkleistern",
    "verkleisterte": "verkleistern",
    "verkleistertem": "verkleistert",
    "verkleisterten": "verkleistern",
    "verkleisterter": "verkleistert",
    "verkleistertes": "verkleistert",
    "verkleistertest": "verkleistern",
    "verkleistertet": "verkleistern",
    "verklemme": "verklemmen",
    "verklemmend": "verklemmen",
    "verklemmende": "verklemmend",
    "verklemmendem": "verklemmend",
    "verklemmenden": "verklemmend",
    "verklemmender": "verklemmend",
    "verklemmendere": "verklemmend",
    "verklemmenderem": "verklemmend",
    "verklemmenderen": "verklemmend",
    "verklemmenderer": "verklemmend",
    "verklemmenderes": "verklemmend",
    "verklemmendes": "verklemmend",
    "verklemmendste": "verklemmend",
    "verklemmendstem": "verklemmend",
    "verklemmendsten": "verklemmend",
    "verklemmendster": "verklemmend",
    "verklemmendstes": "verklemmend",
    "verklemmest": "verklemmen",
    "verklemmet": "verklemmen",
    "verklemmst": "verklemmen",
    "verklemmt": "verklemmen",
    "verklemmte": "verklemmen",
    "verklemmtem": "verklemmt",
    "verklemmten": "verklemmen",
    "verklemmter": "verklemmt",
    "verklemmtere": "verklemmt",
    "verklemmterem": "verklemmt",
    "verklemmteren": "verklemmt",
    "verklemmterer": "verklemmt",
    "verklemmteres": "verklemmt",
    "verklemmtes": "verklemmt",
    "verklemmtest": "verklemmen",
    "verklemmteste": "verklemmt",
    "verklemmtestem": "verklemmt",
    "verklemmtesten": "verklemmt",
    "verklemmtester": "verklemmt",
    "verklemmtestes": "verklemmt",
    "verklemmtet": "verklemmen",
    "verklinge": "verklingen",
    "verklingend": "verklingen",
    "verklingende": "verklingend",
    "verklingendem": "verklingend",
    "verklingenden": "verklingend",
    "verklingender": "verklingend",
    "verklingendes": "verklingend",
    "verklingest": "verklingen",
    "verklinget": "verklingen",
    "verklingst": "verklingen",
    "verklingt": "verklingen",
    "verkloppe": "verkloppen",
    "verkloppend": "verkloppen",
    "verkloppende": "verkloppend",
    "verkloppendem": "verkloppend",
    "verkloppenden": "verkloppend",
    "verkloppender": "verkloppend",
    "verkloppendes": "verkloppend",
    "verkloppest": "verkloppen",
    "verkloppet": "verkloppen",
    "verkloppst": "verkloppen",
    "verkloppt": "verkloppen",
    "verkloppte": "verkloppen",
    "verklopptem": "verkloppt",
    "verkloppten": "verkloppen",
    "verkloppter": "verkloppt",
    "verklopptes": "verkloppt",
    "verklopptest": "verkloppen",
    "verklopptet": "verkloppen",
    "verklumpe": "verklumpen",
    "verklumpend": "verklumpen",
    "verklumpende": "verklumpend",
    "verklumpendem": "verklumpend",
    "verklumpenden": "verklumpend",
    "verklumpender": "verklumpend",
    "verklumpendere": "verklumpend",
    "verklumpenderem": "verklumpend",
    "verklumpenderen": "verklumpend",
    "verklumpenderer": "verklumpend",
    "verklumpenderes": "verklumpend",
    "verklumpendes": "verklumpend",
    "verklumpendste": "verklumpend",
    "verklumpendstem": "verklumpend",
    "verklumpendsten": "verklumpend",
    "verklumpendster": "verklumpend",
    "verklumpendstes": "verklumpend",
    "verklumpest": "verklumpen",
    "verklumpet": "verklumpen",
    "verklumpst": "verklumpen",
    "verklumpt": "verklumpen",
    "verklumpte": "verklumpen",
    "verklumptem": "verklumpt",
    "verklumpten": "verklumpen",
    "verklumpter": "verklumpt",
    "verklumptere": "verklumpt",
    "verklumpterem": "verklumpt",
    "verklumpteren": "verklumpt",
    "verklumpterer": "verklumpt",
    "verklumpteres": "verklumpt",
    "verklumptes": "verklumpt",
    "verklumptest": "verklumpen",
    "verklumpteste": "verklumpt",
    "verklumptestem": "verklumpt",
    "verklumptesten": "verklumpt",
    "verklumptester": "verklumpt",
    "verklumptestes": "verklumpt",
    "verklumptet": "verklumpen",
    "verklungen": "verklingen",
    "verklungene": "verklungen",
    "verklungenem": "verklungen",
    "verklungenen": "verklungen",
    "verklungener": "verklungen",
    "verklungenes": "verklungen",
    "verklänge": "verklingen",
    "verklängen": "verklingen",
    "verklängest": "verklingen",
    "verklänget": "verklingen",
    "verkläre": "verklären",
    "verklärend": "verklären",
    "verklärende": "verklärend",
    "verklärendem": "verklärend",
    "verklärenden": "verklärend",
    "verklärender": "verklärend",
    "verklärendere": "verklärend",
    "verklärenderem": "verklärend",
    "verklärenderen": "verklärend",
    "verklärenderer": "verklärend",
    "verklärenderes": "verklärend",
    "verklärendes": "verklärend",
    "verklärendste": "verklärend",
    "verklärendstem": "verklärend",
    "verklärendsten": "verklärend",
    "verklärendster": "verklärend",
    "verklärendstes": "verklärend",
    "verklärest": "verklären",
    "verkläret": "verklären",
    "verklärst": "verklären",
    "verklärt": "verklären",
    "verklärte": "verklären",
    "verklärtem": "verklärt",
    "verklärten": "verklären",
    "verklärter": "verklärt",
    "verklärtere": "verklärt",
    "verklärterem": "verklärt",
    "verklärteren": "verklärt",
    "verklärterer": "verklärt",
    "verklärteres": "verklärt",
    "verklärtes": "verklärt",
    "verklärtest": "verklären",
    "verklärteste": "verklärt",
    "verklärtestem": "verklärt",
    "verklärtesten": "verklärt",
    "verklärtester": "verklärt",
    "verklärtestes": "verklärt",
    "verklärtet": "verklären",
    "verklüngele": "verklüngeln",
    "verklüngelnd": "verklüngeln",
    "verklüngelnde": "verklüngelnd",
    "verklüngelndem": "verklüngelnd",
    "verklüngelnden": "verklüngelnd",
    "verklüngelnder": "verklüngelnd",
    "verklüngelndere": "verklüngelnd",
    "verklüngelnderem": "verklüngelnd",
    "verklüngelnderen": "verklüngelnd",
    "verklüngelnderer": "verklüngelnd",
    "verklüngelnderes": "verklüngelnd",
    "verklüngelndes": "verklüngelnd",
    "verklüngelndste": "verklüngelnd",
    "verklüngelndstem": "verklüngelnd",
    "verklüngelndsten": "verklüngelnd",
    "verklüngelndster": "verklüngelnd",
    "verklüngelndstes": "verklüngelnd",
    "verklüngelst": "verklüngeln",
    "verklüngelt": "verklüngeln",
    "verklüngelte": "verklüngeln",
    "verklüngeltem": "verklüngelt",
    "verklüngelten": "verklüngeln",
    "verklüngelter": "verklüngelt",
    "verklüngeltere": "verklüngelt",
    "verklüngelterem": "verklüngelt",
    "verklüngelteren": "verklüngelt",
    "verklüngelterer": "verklüngelt",
    "verklüngelteres": "verklüngelt",
    "verklüngeltes": "verklüngelt",
    "verklüngeltest": "verklüngeln",
    "verklüngelteste": "verklüngelt",
    "verklüngeltestem": "verklüngelt",
    "verklüngeltesten": "verklüngelt",
    "verklüngeltester": "verklüngelt",
    "verklüngeltestes": "verklüngelt",
    "verklüngeltet": "verklüngeln",
    "verklüngle": "verklüngeln",
    "verknacke": "verknacken",
    "verknackend": "verknacken",
    "verknackende": "verknackend",
    "verknackendem": "verknackend",
    "verknackenden": "verknackend",
    "verknackender": "verknackend",
    "verknackendes": "verknackend",
    "verknackest": "verknacken",
    "verknacket": "verknacken",
    "verknackse": "verknacksen",
    "verknacksend": "verknacksen",
    "verknacksende": "verknacksend",
    "verknacksendem": "verknacksend",
    "verknacksenden": "verknacksend",
    "verknacksender": "verknacksend",
    "verknacksendes": "verknacksend",
    "verknacksest": "verknacksen",
    "verknackset": "verknacksen",
    "verknackst": "verknacksen",
    "verknackste": "verknacksen",
    "verknackstem": "verknackst",
    "verknacksten": "verknacksen",
    "verknackster": "verknackst",
    "verknackstes": "verknackst",
    "verknackstest": "verknacksen",
    "verknackstet": "verknacksen",
    "verknackt": "verknacken",
    "verknackte": "verknacken",
    "verknacktem": "verknackt",
    "verknackten": "verknacken",
    "verknackter": "verknackt",
    "verknacktes": "verknackt",
    "verknacktest": "verknacken",
    "verknacktet": "verknacken",
    "verknalle": "verknallen",
    "verknallend": "verknallen",
    "verknallende": "verknallend",
    "verknallendem": "verknallend",
    "verknallenden": "verknallend",
    "verknallender": "verknallend",
    "verknallendere": "verknallend",
    "verknallenderem": "verknallend",
    "verknallenderen": "verknallend",
    "verknallenderer": "verknallend",
    "verknallenderes": "verknallend",
    "verknallendes": "verknallend",
    "verknallendste": "verknallend",
    "verknallendstem": "verknallend",
    "verknallendsten": "verknallend",
    "verknallendster": "verknallend",
    "verknallendstes": "verknallend",
    "verknallest": "verknallen",
    "verknallet": "verknallen",
    "verknallst": "verknallen",
    "verknallt": "verknallen",
    "verknallte": "verknallen",
    "verknalltem": "verknallt",
    "verknallten": "verknallen",
    "verknallter": "verknallt",
    "verknalltere": "verknallt",
    "verknallterem": "verknallt",
    "verknallteren": "verknallt",
    "verknallterer": "verknallt",
    "verknallteres": "verknallt",
    "verknalltes": "verknallt",
    "verknalltest": "verknallen",
    "verknallteste": "verknallt",
    "verknalltestem": "verknallt",
    "verknalltesten": "verknallt",
    "verknalltester": "verknallt",
    "verknalltestes": "verknallt",
    "verknalltet": "verknallen",
    "verknappe": "verknappen",
    "verknappend": "verknappen",
    "verknappende": "verknappend",
    "verknappendem": "verknappend",
    "verknappenden": "verknappend",
    "verknappender": "verknappend",
    "verknappendes": "verknappend",
    "verknappest": "verknappen",
    "verknappet": "verknappen",
    "verknappst": "verknappen",
    "verknappt": "verknappen",
    "verknappte": "verknappen",
    "verknapptem": "verknappt",
    "verknappten": "verknappen",
    "verknappter": "verknappt",
    "verknapptes": "verknappt",
    "verknapptest": "verknappen",
    "verknapptet": "verknappen",
    "verkneife": "verkneifen",
    "verkneifend": "verkneifen",
    "verkneifende": "verkneifend",
    "verkneifendem": "verkneifend",
    "verkneifenden": "verkneifend",
    "verkneifender": "verkneifend",
    "verkneifendes": "verkneifend",
    "verkneifest": "verkneifen",
    "verkneifet": "verkneifen",
    "verkneifst": "verkneifen",
    "verkneift": "verkneifen",
    "verknete": "verkneten",
    "verknetend": "verkneten",
    "verknetende": "verknetend",
    "verknetendem": "verknetend",
    "verknetenden": "verknetend",
    "verknetender": "verknetend",
    "verknetendere": "verknetend",
    "verknetenderem": "verknetend",
    "verknetenderen": "verknetend",
    "verknetenderer": "verknetend",
    "verknetenderes": "verknetend",
    "verknetendes": "verknetend",
    "verknetendste": "verknetend",
    "verknetendstem": "verknetend",
    "verknetendsten": "verknetend",
    "verknetendster": "verknetend",
    "verknetendstes": "verknetend",
    "verknetest": "verkneten",
    "verknetet": "verkneten",
    "verknetete": "verkneten",
    "verknetetem": "verknetet",
    "verkneteten": "verkneten",
    "verkneteter": "verknetet",
    "verknetetere": "verknetet",
    "verkneteterem": "verknetet",
    "verkneteteren": "verknetet",
    "verkneteterer": "verknetet",
    "verkneteteres": "verknetet",
    "verknetetes": "verknetet",
    "verknetetest": "verkneten",
    "verkneteteste": "verknetet",
    "verknetetestem": "verknetet",
    "verknetetesten": "verknetet",
    "verknetetester": "verknetet",
    "verknetetestes": "verknetet",
    "verknetetet": "verkneten",
    "verkniff": "verkneifen",
    "verkniffe": "verkneifen",
    "verkniffen": "verkneifen",
    "verkniffene": "verkniffen",
    "verkniffenem": "verkniffen",
    "verkniffenen": "verkniffen",
    "verkniffener": "verkniffen",
    "verkniffenes": "verkniffen",
    "verkniffest": "verkneifen",
    "verkniffet": "verkneifen",
    "verkniffst": "verkneifen",
    "verknifft": "verkneifen",
    "verknittere": "verknittern",
    "verknitternd": "verknittern",
    "verknitternde": "verknitternd",
    "verknitterndem": "verknitternd",
    "verknitternden": "verknitternd",
    "verknitternder": "verknitternd",
    "verknitterndere": "verknitternd",
    "verknitternderem": "verknitternd",
    "verknitternderen": "verknitternd",
    "verknitternderer": "verknitternd",
    "verknitternderes": "verknitternd",
    "verknitterndes": "verknitternd",
    "verknitterndste": "verknitternd",
    "verknitterndstem": "verknitternd",
    "verknitterndsten": "verknitternd",
    "verknitterndster": "verknitternd",
    "verknitterndstes": "verknitternd",
    "verknitterst": "verknittern",
    "verknittert": "verknittern",
    "verknitterte": "verknittern",
    "verknittertem": "verknittert",
    "verknitterten": "verknittern",
    "verknitterter": "verknittert",
    "verknittertere": "verknittert",
    "verknitterterem": "verknittert",
    "verknitterteren": "verknittert",
    "verknitterterer": "verknittert",
    "verknitterteres": "verknittert",
    "verknittertes": "verknittert",
    "verknittertest": "verknittern",
    "verknitterteste": "verknittert",
    "verknittertestem": "verknittert",
    "verknittertesten": "verknittert",
    "verknittertester": "verknittert",
    "verknittertestes": "verknittert",
    "verknittertet": "verknittern",
    "verknorpele": "verknorpeln",
    "verknorpelnd": "verknorpeln",
    "verknorpelnde": "verknorpelnd",
    "verknorpelndem": "verknorpelnd",
    "verknorpelnden": "verknorpelnd",
    "verknorpelnder": "verknorpelnd",
    "verknorpelndere": "verknorpelnd",
    "verknorpelnderem": "verknorpelnd",
    "verknorpelnderen": "verknorpelnd",
    "verknorpelnderer": "verknorpelnd",
    "verknorpelnderes": "verknorpelnd",
    "verknorpelndes": "verknorpelnd",
    "verknorpelndste": "verknorpelnd",
    "verknorpelndstem": "verknorpelnd",
    "verknorpelndsten": "verknorpelnd",
    "verknorpelndster": "verknorpelnd",
    "verknorpelndstes": "verknorpelnd",
    "verknorpelst": "verknorpeln",
    "verknorpelt": "verknorpeln",
    "verknorpelte": "verknorpeln",
    "verknorpeltem": "verknorpelt",
    "verknorpelten": "verknorpeln",
    "verknorpelter": "verknorpelt",
    "verknorpeltere": "verknorpelt",
    "verknorpelterem": "verknorpelt",
    "verknorpelteren": "verknorpelt",
    "verknorpelterer": "verknorpelt",
    "verknorpelteres": "verknorpelt",
    "verknorpeltes": "verknorpelt",
    "verknorpeltest": "verknorpeln",
    "verknorpelteste": "verknorpelt",
    "verknorpeltestem": "verknorpelt",
    "verknorpeltesten": "verknorpelt",
    "verknorpeltester": "verknorpelt",
    "verknorpeltestes": "verknorpelt",
    "verknorpeltet": "verknorpeln",
    "verknorple": "verknorpeln",
    "verknote": "verknoten",
    "verknotend": "verknoten",
    "verknotende": "verknotend",
    "verknotendem": "verknotend",
    "verknotenden": "verknotend",
    "verknotender": "verknotend",
    "verknotendes": "verknotend",
    "verknotest": "verknoten",
    "verknotet": "verknoten",
    "verknotete": "verknoten",
    "verknotetem": "verknotet",
    "verknoteten": "verknoten",
    "verknoteter": "verknotet",
    "verknotetere": "verknotet",
    "verknoteterem": "verknotet",
    "verknoteteren": "verknotet",
    "verknoteterer": "verknotet",
    "verknoteteres": "verknotet",
    "verknotetes": "verknotet",
    "verknotetest": "verknoten",
    "verknoteteste": "verknotet",
    "verknotetestem": "verknotet",
    "verknotetesten": "verknotet",
    "verknotetester": "verknotet",
    "verknotetestes": "verknotet",
    "verknotetet": "verknoten",
    "verknüpfe": "verknüpfen",
    "verknüpfend": "verknüpfen",
    "verknüpfende": "verknüpfend",
    "verknüpfendem": "verknüpfend",
    "verknüpfenden": "verknüpfend",
    "verknüpfender": "verknüpfend",
    "verknüpfendes": "verknüpfend",
    "verknüpfest": "verknüpfen",
    "verknüpfet": "verknüpfen",
    "verknüpfst": "verknüpfen",
    "verknüpft": "verknüpfen",
    "verknüpfte": "verknüpfen",
    "verknüpftem": "verknüpft",
    "verknüpften": "verknüpfen",
    "verknüpfter": "verknüpft",
    "verknüpftes": "verknüpft",
    "verknüpftest": "verknüpfen",
    "verknüpftet": "verknüpfen",
    "verkohle": "verkohlen",
    "verkohlend": "verkohlen",
    "verkohlende": "verkohlend",
    "verkohlendem": "verkohlend",
    "verkohlenden": "verkohlend",
    "verkohlender": "verkohlend",
    "verkohlendere": "verkohlend",
    "verkohlenderem": "verkohlend",
    "verkohlenderen": "verkohlend",
    "verkohlenderer": "verkohlend",
    "verkohlenderes": "verkohlend",
    "verkohlendes": "verkohlend",
    "verkohlendste": "verkohlend",
    "verkohlendstem": "verkohlend",
    "verkohlendsten": "verkohlend",
    "verkohlendster": "verkohlend",
    "verkohlendstes": "verkohlend",
    "verkohlest": "verkohlen",
    "verkohlet": "verkohlen",
    "verkohlst": "verkohlen",
    "verkohlt": "verkohlen",
    "verkohlte": "verkohlen",
    "verkohltem": "verkohlt",
    "verkohlten": "verkohlen",
    "verkohlter": "verkohlt",
    "verkohltere": "verkohlt",
    "verkohlterem": "verkohlt",
    "verkohlteren": "verkohlt",
    "verkohlterer": "verkohlt",
    "verkohlteres": "verkohlt",
    "verkohltes": "verkohlt",
    "verkohltest": "verkohlen",
    "verkohlteste": "verkohlt",
    "verkohltestem": "verkohlt",
    "verkohltesten": "verkohlt",
    "verkohltester": "verkohlt",
    "verkohltestes": "verkohlt",
    "verkohltet": "verkohlen",
    "verkokele": "verkokeln",
    "verkokelnd": "verkokeln",
    "verkokelnde": "verkokelnd",
    "verkokelndem": "verkokelnd",
    "verkokelnden": "verkokelnd",
    "verkokelnder": "verkokelnd",
    "verkokelndere": "verkokelnd",
    "verkokelnderem": "verkokelnd",
    "verkokelnderen": "verkokelnd",
    "verkokelnderer": "verkokelnd",
    "verkokelnderes": "verkokelnd",
    "verkokelndes": "verkokelnd",
    "verkokelndste": "verkokelnd",
    "verkokelndstem": "verkokelnd",
    "verkokelndsten": "verkokelnd",
    "verkokelndster": "verkokelnd",
    "verkokelndstes": "verkokelnd",
    "verkokelst": "verkokeln",
    "verkokelt": "verkokeln",
    "verkokelte": "verkokeln",
    "verkokeltem": "verkokelt",
    "verkokelten": "verkokeln",
    "verkokelter": "verkokelt",
    "verkokeltere": "verkokelt",
    "verkokelterem": "verkokelt",
    "verkokelteren": "verkokelt",
    "verkokelterer": "verkokelt",
    "verkokelteres": "verkokelt",
    "verkokeltes": "verkokelt",
    "verkokeltest": "verkokeln",
    "verkokelteste": "verkokelt",
    "verkokeltestem": "verkokelt",
    "verkokeltesten": "verkokelt",
    "verkokeltester": "verkokelt",
    "verkokeltestes": "verkokelt",
    "verkokeltet": "verkokeln",
    "verkokle": "verkokeln",
    "verkomme": "verkommen",
    "verkommend": "verkommen",
    "verkommende": "verkommend",
    "verkommendem": "verkommend",
    "verkommenden": "verkommend",
    "verkommender": "verkommend",
    "verkommendes": "verkommend",
    "verkommene": "verkommen",
    "verkommenem": "verkommen",
    "verkommenen": "verkommen",
    "verkommener": "verkommen",
    "verkommenere": "verkommen",
    "verkommenerem": "verkommen",
    "verkommeneren": "verkommen",
    "verkommenerer": "verkommen",
    "verkommeneres": "verkommen",
    "verkommenes": "verkommen",
    "verkommenstem": "verkommen",
    "verkommensten": "verkommen",
    "verkommenster": "verkommen",
    "verkommenstes": "verkommen",
    "verkommest": "verkommen",
    "verkommet": "verkommen",
    "verkommst": "verkommen",
    "verkommt": "verkommen",
    "verkonsumiere": "verkonsumieren",
    "verkonsumierend": "verkonsumieren",
    "verkonsumierende": "verkonsumierend",
    "verkonsumierendem": "verkonsumierend",
    "verkonsumierenden": "verkonsumierend",
    "verkonsumierender": "verkonsumierend",
    "verkonsumierendes": "verkonsumierend",
    "verkonsumierest": "verkonsumieren",
    "verkonsumieret": "verkonsumieren",
    "verkonsumierst": "verkonsumieren",
    "verkonsumiert": "verkonsumieren",
    "verkonsumierte": "verkonsumieren",
    "verkonsumiertem": "verkonsumiert",
    "verkonsumierten": "verkonsumieren",
    "verkonsumierter": "verkonsumiert",
    "verkonsumiertes": "verkonsumiert",
    "verkonsumiertest": "verkonsumieren",
    "verkonsumiertet": "verkonsumieren",
    "verkorkse": "verkorksen",
    "verkorksend": "verkorksen",
    "verkorksende": "verkorksend",
    "verkorksendem": "verkorksend",
    "verkorksenden": "verkorksend",
    "verkorksender": "verkorksend",
    "verkorksendere": "verkorksend",
    "verkorksenderem": "verkorksend",
    "verkorksenderen": "verkorksend",
    "verkorksenderer": "verkorksend",
    "verkorksenderes": "verkorksend",
    "verkorksendes": "verkorksend",
    "verkorksendste": "verkorksend",
    "verkorksendstem": "verkorksend",
    "verkorksendsten": "verkorksend",
    "verkorksendster": "verkorksend",
    "verkorksendstes": "verkorksend",
    "verkorksest": "verkorksen",
    "verkorkset": "verkorksen",
    "verkorkst": "verkorksen",
    "verkorkste": "verkorksen",
    "verkorkstem": "verkorkst",
    "verkorksten": "verkorksen",
    "verkorkster": "verkorkst",
    "verkorkstere": "verkorkst",
    "verkorksterem": "verkorkst",
    "verkorksteren": "verkorkst",
    "verkorksterer": "verkorkst",
    "verkorksteres": "verkorkst",
    "verkorkstes": "verkorkst",
    "verkorkstest": "verkorksen",
    "verkorksteste": "verkorkst",
    "verkorkstestem": "verkorkst",
    "verkorkstesten": "verkorkst",
    "verkorkstester": "verkorkst",
    "verkorkstestes": "verkorkst",
    "verkorkstet": "verkorksen",
    "verkoste": "verkosten",
    "verkostend": "verkosten",
    "verkostende": "verkostend",
    "verkostendem": "verkostend",
    "verkostenden": "verkostend",
    "verkostender": "verkostend",
    "verkostendes": "verkostend",
    "verkostest": "verkosten",
    "verkostet": "verkosten",
    "verkostete": "verkosten",
    "verkostetem": "verkostet",
    "verkosteten": "verkosten",
    "verkosteter": "verkostet",
    "verkostetes": "verkostet",
    "verkostetest": "verkosten",
    "verkostetet": "verkosten",
    "verkrache": "verkrachen",
    "verkrachend": "verkrachen",
    "verkrachende": "verkrachend",
    "verkrachendem": "verkrachend",
    "verkrachenden": "verkrachend",
    "verkrachender": "verkrachend",
    "verkrachendere": "verkrachend",
    "verkrachenderem": "verkrachend",
    "verkrachenderen": "verkrachend",
    "verkrachenderer": "verkrachend",
    "verkrachenderes": "verkrachend",
    "verkrachendes": "verkrachend",
    "verkrachendste": "verkrachend",
    "verkrachendstem": "verkrachend",
    "verkrachendsten": "verkrachend",
    "verkrachendster": "verkrachend",
    "verkrachendstes": "verkrachend",
    "verkrachest": "verkrachen",
    "verkrachet": "verkrachen",
    "verkrachst": "verkrachen",
    "verkracht": "verkrachen",
    "verkrachte": "verkrachen",
    "verkrachtem": "verkracht",
    "verkrachten": "verkrachen",
    "verkrachter": "verkracht",
    "verkrachtere": "verkracht",
    "verkrachterem": "verkracht",
    "verkrachteren": "verkracht",
    "verkrachterer": "verkracht",
    "verkrachteres": "verkracht",
    "verkrachtes": "verkracht",
    "verkrachtest": "verkrachen",
    "verkrachteste": "verkracht",
    "verkrachtestem": "verkracht",
    "verkrachtesten": "verkracht",
    "verkrachtester": "verkracht",
    "verkrachtestes": "verkracht",
    "verkrachtet": "verkrachen",
    "verkraftbare": "verkraftbar",
    "verkraftbarem": "verkraftbar",
    "verkraftbaren": "verkraftbar",
    "verkraftbarer": "verkraftbar",
    "verkraftbares": "verkraftbar",
    "verkrafte": "verkraften",
    "verkraftend": "verkraften",
    "verkraftende": "verkraftend",
    "verkraftendem": "verkraftend",
    "verkraftenden": "verkraftend",
    "verkraftender": "verkraftend",
    "verkraftendes": "verkraftend",
    "verkraftest": "verkraften",
    "verkraftet": "verkraften",
    "verkraftete": "verkraften",
    "verkraftetem": "verkraftet",
    "verkrafteten": "verkraften",
    "verkrafteter": "verkraftet",
    "verkraftetes": "verkraftet",
    "verkraftetest": "verkraften",
    "verkraftetet": "verkraften",
    "verkrampfe": "verkrampfen",
    "verkrampfend": "verkrampfen",
    "verkrampfende": "verkrampfend",
    "verkrampfendem": "verkrampfend",
    "verkrampfenden": "verkrampfend",
    "verkrampfender": "verkrampfend",
    "verkrampfendere": "verkrampfend",
    "verkrampfenderem": "verkrampfend",
    "verkrampfenderen": "verkrampfend",
    "verkrampfenderer": "verkrampfend",
    "verkrampfenderes": "verkrampfend",
    "verkrampfendes": "verkrampfend",
    "verkrampfendste": "verkrampfend",
    "verkrampfendstem": "verkrampfend",
    "verkrampfendsten": "verkrampfend",
    "verkrampfendster": "verkrampfend",
    "verkrampfendstes": "verkrampfend",
    "verkrampfest": "verkrampfen",
    "verkrampfet": "verkrampfen",
    "verkrampfst": "verkrampfen",
    "verkrampft": "verkrampfen",
    "verkrampfte": "verkrampfen",
    "verkrampftem": "verkrampft",
    "verkrampften": "verkrampfen",
    "verkrampfter": "verkrampft",
    "verkrampftere": "verkrampft",
    "verkrampfterem": "verkrampft",
    "verkrampfteren": "verkrampft",
    "verkrampfterer": "verkrampft",
    "verkrampfteres": "verkrampft",
    "verkrampftes": "verkrampft",
    "verkrampftest": "verkrampfen",
    "verkrampfteste": "verkrampft",
    "verkrampftestem": "verkrampft",
    "verkrampftesten": "verkrampft",
    "verkrampftester": "verkrampft",
    "verkrampftestes": "verkrampft",
    "verkrampftet": "verkrampfen",
    "verkratze": "verkratzen",
    "verkratzend": "verkratzen",
    "verkratzende": "verkratzend",
    "verkratzendem": "verkratzend",
    "verkratzenden": "verkratzend",
    "verkratzender": "verkratzend",
    "verkratzendere": "verkratzend",
    "verkratzenderem": "verkratzend",
    "verkratzenderen": "verkratzend",
    "verkratzenderer": "verkratzend",
    "verkratzenderes": "verkratzend",
    "verkratzendes": "verkratzend",
    "verkratzendste": "verkratzend",
    "verkratzendstem": "verkratzend",
    "verkratzendsten": "verkratzend",
    "verkratzendster": "verkratzend",
    "verkratzendstes": "verkratzend",
    "verkratzest": "verkratzen",
    "verkratzet": "verkratzen",
    "verkratzt": "verkratzen",
    "verkratzte": "verkratzen",
    "verkratztem": "verkratzt",
    "verkratzten": "verkratzen",
    "verkratzter": "verkratzt",
    "verkratztere": "verkratzt",
    "verkratzterem": "verkratzt",
    "verkratzteren": "verkratzt",
    "verkratzterer": "verkratzt",
    "verkratzteres": "verkratzt",
    "verkratztes": "verkratzt",
    "verkratztest": "verkratzen",
    "verkratzteste": "verkratzt",
    "verkratztestem": "verkratzt",
    "verkratztesten": "verkratzt",
    "verkratztester": "verkratzt",
    "verkratztestes": "verkratzt",
    "verkratztet": "verkratzen",
    "verkrieche": "verkriechen",
    "verkriechend": "verkriechen",
    "verkriechende": "verkriechend",
    "verkriechendem": "verkriechend",
    "verkriechenden": "verkriechend",
    "verkriechender": "verkriechend",
    "verkriechendere": "verkriechend",
    "verkriechenderem": "verkriechend",
    "verkriechenderen": "verkriechend",
    "verkriechenderer": "verkriechend",
    "verkriechenderes": "verkriechend",
    "verkriechendes": "verkriechend",
    "verkriechendste": "verkriechend",
    "verkriechendstem": "verkriechend",
    "verkriechendsten": "verkriechend",
    "verkriechendster": "verkriechend",
    "verkriechendstes": "verkriechend",
    "verkriechest": "verkriechen",
    "verkriechet": "verkriechen",
    "verkriechst": "verkriechen",
    "verkriecht": "verkriechen",
    "verkroch": "verkriechen",
    "verkrochen": "verkriechen",
    "verkrochene": "verkrochen",
    "verkrochenem": "verkrochen",
    "verkrochenen": "verkrochen",
    "verkrochener": "verkrochen",
    "verkrochenere": "verkrochen",
    "verkrochenerem": "verkrochen",
    "verkrocheneren": "verkrochen",
    "verkrochenerer": "verkrochen",
    "verkrocheneres": "verkrochen",
    "verkrochenes": "verkrochen",
    "verkrochenste": "verkrochen",
    "verkrochenstem": "verkrochen",
    "verkrochensten": "verkrochen",
    "verkrochenster": "verkrochen",
    "verkrochenstes": "verkrochen",
    "verkrochst": "verkriechen",
    "verkrocht": "verkriechen",
    "verkruste": "verkrusten",
    "verkrustend": "verkrusten",
    "verkrustende": "verkrustend",
    "verkrustendem": "verkrustend",
    "verkrustenden": "verkrustend",
    "verkrustender": "verkrustend",
    "verkrustendere": "verkrustend",
    "verkrustenderem": "verkrustend",
    "verkrustenderen": "verkrustend",
    "verkrustenderer": "verkrustend",
    "verkrustenderes": "verkrustend",
    "verkrustendes": "verkrustend",
    "verkrustendste": "verkrustend",
    "verkrustendstem": "verkrustend",
    "verkrustendsten": "verkrustend",
    "verkrustendster": "verkrustend",
    "verkrustendstes": "verkrustend",
    "verkrustest": "verkrusten",
    "verkrustet": "verkrusten",
    "verkrustete": "verkrusten",
    "verkrustetem": "verkrustet",
    "verkrusteten": "verkrusten",
    "verkrusteter": "verkrustet",
    "verkrustetere": "verkrustet",
    "verkrusteterem": "verkrustet",
    "verkrusteteren": "verkrustet",
    "verkrusteterer": "verkrustet",
    "verkrusteteres": "verkrustet",
    "verkrustetes": "verkrustet",
    "verkrustetest": "verkrusten",
    "verkrusteteste": "verkrustet",
    "verkrustetestem": "verkrustet",
    "verkrustetesten": "verkrustet",
    "verkrustetester": "verkrustet",
    "verkrustetestes": "verkrustet",
    "verkrustetet": "verkrusten",
    "verkröche": "verkriechen",
    "verkröchen": "verkriechen",
    "verkröchest": "verkriechen",
    "verkröchet": "verkriechen",
    "verkrümele": "verkrümeln",
    "verkrümelnd": "verkrümeln",
    "verkrümelnde": "verkrümelnd",
    "verkrümelndem": "verkrümelnd",
    "verkrümelnden": "verkrümelnd",
    "verkrümelnder": "verkrümelnd",
    "verkrümelndere": "verkrümelnd",
    "verkrümelnderem": "verkrümelnd",
    "verkrümelnderen": "verkrümelnd",
    "verkrümelnderer": "verkrümelnd",
    "verkrümelnderes": "verkrümelnd",
    "verkrümelndes": "verkrümelnd",
    "verkrümelndste": "verkrümelnd",
    "verkrümelndstem": "verkrümelnd",
    "verkrümelndsten": "verkrümelnd",
    "verkrümelndster": "verkrümelnd",
    "verkrümelndstes": "verkrümelnd",
    "verkrümelst": "verkrümeln",
    "verkrümelt": "verkrümeln",
    "verkrümelte": "verkrümeln",
    "verkrümeltem": "verkrümelt",
    "verkrümelten": "verkrümeln",
    "verkrümelter": "verkrümelt",
    "verkrümeltere": "verkrümelt",
    "verkrümelterem": "verkrümelt",
    "verkrümelteren": "verkrümelt",
    "verkrümelterer": "verkrümelt",
    "verkrümelteres": "verkrümelt",
    "verkrümeltes": "verkrümelt",
    "verkrümeltest": "verkrümeln",
    "verkrümelteste": "verkrümelt",
    "verkrümeltestem": "verkrümelt",
    "verkrümeltesten": "verkrümelt",
    "verkrümeltester": "verkrümelt",
    "verkrümeltestes": "verkrümelt",
    "verkrümeltet": "verkrümeln",
    "verkrümle": "verkrümeln",
    "verkrümme": "verkrümmen",
    "verkrümmend": "verkrümmen",
    "verkrümmende": "verkrümmend",
    "verkrümmendem": "verkrümmend",
    "verkrümmenden": "verkrümmend",
    "verkrümmender": "verkrümmend",
    "verkrümmendere": "verkrümmend",
    "verkrümmenderem": "verkrümmend",
    "verkrümmenderen": "verkrümmend",
    "verkrümmenderer": "verkrümmend",
    "verkrümmenderes": "verkrümmend",
    "verkrümmendes": "verkrümmend",
    "verkrümmendste": "verkrümmend",
    "verkrümmendstem": "verkrümmend",
    "verkrümmendsten": "verkrümmend",
    "verkrümmendster": "verkrümmend",
    "verkrümmendstes": "verkrümmend",
    "verkrümmest": "verkrümmen",
    "verkrümmet": "verkrümmen",
    "verkrümmst": "verkrümmen",
    "verkrümmt": "verkrümmen",
    "verkrümmte": "verkrümmen",
    "verkrümmtem": "verkrümmt",
    "verkrümmten": "verkrümmen",
    "verkrümmter": "verkrümmt",
    "verkrümmtere": "verkrümmt",
    "verkrümmterem": "verkrümmt",
    "verkrümmteren": "verkrümmt",
    "verkrümmterer": "verkrümmt",
    "verkrümmteres": "verkrümmt",
    "verkrümmtes": "verkrümmt",
    "verkrümmtest": "verkrümmen",
    "verkrümmteste": "verkrümmt",
    "verkrümmtestem": "verkrümmt",
    "verkrümmtesten": "verkrümmt",
    "verkrümmtester": "verkrümmt",
    "verkrümmtestes": "verkrümmt",
    "verkrümmtet": "verkrümmen",
    "verkrüppele": "verkrüppeln",
    "verkrüppelnd": "verkrüppeln",
    "verkrüppelnde": "verkrüppelnd",
    "verkrüppelndem": "verkrüppelnd",
    "verkrüppelnden": "verkrüppelnd",
    "verkrüppelnder": "verkrüppelnd",
    "verkrüppelndere": "verkrüppelnd",
    "verkrüppelnderem": "verkrüppelnd",
    "verkrüppelnderen": "verkrüppelnd",
    "verkrüppelnderer": "verkrüppelnd",
    "verkrüppelnderes": "verkrüppelnd",
    "verkrüppelndes": "verkrüppelnd",
    "verkrüppelndste": "verkrüppelnd",
    "verkrüppelndstem": "verkrüppelnd",
    "verkrüppelndsten": "verkrüppelnd",
    "verkrüppelndster": "verkrüppelnd",
    "verkrüppelndstes": "verkrüppelnd",
    "verkrüppelst": "verkrüppeln",
    "verkrüppelt": "verkrüppeln",
    "verkrüppelte": "verkrüppeln",
    "verkrüppeltem": "verkrüppelt",
    "verkrüppelten": "verkrüppeln",
    "verkrüppelter": "verkrüppelt",
    "verkrüppeltere": "verkrüppelt",
    "verkrüppelterem": "verkrüppelt",
    "verkrüppelteren": "verkrüppelt",
    "verkrüppelterer": "verkrüppelt",
    "verkrüppelteres": "verkrüppelt",
    "verkrüppeltes": "verkrüppelt",
    "verkrüppeltest": "verkrüppeln",
    "verkrüppelteste": "verkrüppelt",
    "verkrüppeltestem": "verkrüppelt",
    "verkrüppeltesten": "verkrüppelt",
    "verkrüppeltester": "verkrüppelt",
    "verkrüppeltestes": "verkrüppelt",
    "verkrüppeltet": "verkrüppeln",
    "verkrüpple": "verkrüppeln",
    "verkuppele": "verkuppeln",
    "verkuppelnd": "verkuppeln",
    "verkuppelnde": "verkuppelnd",
    "verkuppelndem": "verkuppelnd",
    "verkuppelnden": "verkuppelnd",
    "verkuppelnder": "verkuppelnd",
    "verkuppelndes": "verkuppelnd",
    "verkuppelst": "verkuppeln",
    "verkuppelt": "verkuppeln",
    "verkuppelte": "verkuppeln",
    "verkuppeltem": "verkuppelt",
    "verkuppelten": "verkuppeln",
    "verkuppelter": "verkuppelt",
    "verkuppeltes": "verkuppelt",
    "verkuppeltest": "verkuppeln",
    "verkuppeltet": "verkuppeln",
    "verkupple": "verkuppeln",
    "verkäme": "verkommen",
    "verkämen": "verkommen",
    "verkämest": "verkommen",
    "verkämet": "verkommen",
    "verkäufliche": "verkäuflich",
    "verkäuflichem": "verkäuflich",
    "verkäuflichen": "verkäuflich",
    "verkäuflicher": "verkäuflich",
    "verkäufliches": "verkäuflich",
    "verkörpere": "verkörpern",
    "verkörpernd": "verkörpern",
    "verkörpernde": "verkörpernd",
    "verkörperndem": "verkörpernd",
    "verkörpernden": "verkörpernd",
    "verkörpernder": "verkörpernd",
    "verkörperndes": "verkörpernd",
    "verkörperst": "verkörpern",
    "verkörpert": "verkörpern",
    "verkörperte": "verkörpern",
    "verkörpertem": "verkörpert",
    "verkörperten": "verkörpern",
    "verkörperter": "verkörpert",
    "verkörpertes": "verkörpert",
    "verkörpertest": "verkörpern",
    "verkörpertet": "verkörpern",
    "verköstige": "verköstigen",
    "verköstigend": "verköstigen",
    "verköstigende": "verköstigend",
    "verköstigendem": "verköstigend",
    "verköstigenden": "verköstigend",
    "verköstigender": "verköstigend",
    "verköstigendes": "verköstigend",
    "verköstigest": "verköstigen",
    "verköstiget": "verköstigen",
    "verköstigst": "verköstigen",
    "verköstigt": "verköstigen",
    "verköstigte": "verköstigen",
    "verköstigtem": "verköstigt",
    "verköstigten": "verköstigen",
    "verköstigter": "verköstigt",
    "verköstigtes": "verköstigt",
    "verköstigtest": "verköstigen",
    "verköstigtet": "verköstigen",
    "verkühle": "verkühlen",
    "verkühlend": "verkühlen",
    "verkühlende": "verkühlend",
    "verkühlendem": "verkühlend",
    "verkühlenden": "verkühlend",
    "verkühlender": "verkühlend",
    "verkühlendere": "verkühlend",
    "verkühlenderem": "verkühlend",
    "verkühlenderen": "verkühlend",
    "verkühlenderer": "verkühlend",
    "verkühlenderes": "verkühlend",
    "verkühlendes": "verkühlend",
    "verkühlendste": "verkühlend",
    "verkühlendstem": "verkühlend",
    "verkühlendsten": "verkühlend",
    "verkühlendster": "verkühlend",
    "verkühlendstes": "verkühlend",
    "verkühlest": "verkühlen",
    "verkühlet": "verkühlen",
    "verkühlst": "verkühlen",
    "verkühlt": "verkühlen",
    "verkühlte": "verkühlen",
    "verkühltem": "verkühlt",
    "verkühlten": "verkühlen",
    "verkühlter": "verkühlt",
    "verkühltere": "verkühlt",
    "verkühlterem": "verkühlt",
    "verkühlteren": "verkühlt",
    "verkühlterer": "verkühlt",
    "verkühlteres": "verkühlt",
    "verkühltes": "verkühlt",
    "verkühltest": "verkühlen",
    "verkühlteste": "verkühlt",
    "verkühltestem": "verkühlt",
    "verkühltesten": "verkühlt",
    "verkühltester": "verkühlt",
    "verkühltestes": "verkühlt",
    "verkühltet": "verkühlen",
    "verkümmere": "verkümmern",
    "verkümmernd": "verkümmern",
    "verkümmernde": "verkümmernd",
    "verkümmerndem": "verkümmernd",
    "verkümmernden": "verkümmernd",
    "verkümmernder": "verkümmernd",
    "verkümmerndere": "verkümmernd",
    "verkümmernderem": "verkümmernd",
    "verkümmernderen": "verkümmernd",
    "verkümmernderer": "verkümmernd",
    "verkümmernderes": "verkümmernd",
    "verkümmerndes": "verkümmernd",
    "verkümmerndste": "verkümmernd",
    "verkümmerndstem": "verkümmernd",
    "verkümmerndsten": "verkümmernd",
    "verkümmerndster": "verkümmernd",
    "verkümmerndstes": "verkümmernd",
    "verkümmerst": "verkümmern",
    "verkümmert": "verkümmern",
    "verkümmerte": "verkümmern",
    "verkümmertem": "verkümmert",
    "verkümmerten": "verkümmern",
    "verkümmerter": "verkümmert",
    "verkümmertere": "verkümmert",
    "verkümmerterem": "verkümmert",
    "verkümmerteren": "verkümmert",
    "verkümmerterer": "verkümmert",
    "verkümmerteres": "verkümmert",
    "verkümmertes": "verkümmert",
    "verkümmertest": "verkümmern",
    "verkümmerteste": "verkümmert",
    "verkümmertestem": "verkümmert",
    "verkümmertesten": "verkümmert",
    "verkümmertester": "verkümmert",
    "verkümmertestes": "verkümmert",
    "verkümmertet": "verkümmern",
    "verkünde": "verkünden",
    "verkündend": "verkünden",
    "verkündende": "verkündend",
    "verkündendem": "verkündend",
    "verkündenden": "verkündend",
    "verkündender": "verkündend",
    "verkündendes": "verkündend",
    "verkündest": "verkünden",
    "verkündet": "verkünden",
    "verkündete": "verkünden",
    "verkündetem": "verkündet",
    "verkündeten": "verkünden",
    "verkündeter": "verkündet",
    "verkündetes": "verkündet",
    "verkündetest": "verkünden",
    "verkündetet": "verkünden",
    "verkündige": "verkündigen",
    "verkündigend": "verkündigen",
    "verkündigende": "verkündigend",
    "verkündigendem": "verkündigend",
    "verkündigenden": "verkündigend",
    "verkündigender": "verkündigend",
    "verkündigendes": "verkündigend",
    "verkündigest": "verkündigen",
    "verkündiget": "verkündigen",
    "verkündigst": "verkündigen",
    "verkündigt": "verkündigen",
    "verkündigte": "verkündigen",
    "verkündigtem": "verkündigt",
    "verkündigten": "verkündigen",
    "verkündigter": "verkündigt",
    "verkündigtes": "verkündigt",
    "verkündigtest": "verkündigen",
    "verkündigtet": "verkündigen",
    "verkürze": "verkürzen",
    "verkürzend": "verkürzen",
    "verkürzende": "verkürzend",
    "verkürzendem": "verkürzend",
    "verkürzenden": "verkürzend",
    "verkürzender": "verkürzend",
    "verkürzendes": "verkürzend",
    "verkürzest": "verkürzen",
    "verkürzet": "verkürzen",
    "verkürzt": "verkürzen",
    "verkürzte": "verkürzen",
    "verkürztem": "verkürzt",
    "verkürzten": "verkürzen",
    "verkürzter": "verkürzt",
    "verkürztes": "verkürzt",
    "verkürztest": "verkürzen",
    "verkürztet": "verkürzen",
    "verlade": "verladen",
    "verladend": "verladen",
    "verladende": "verladend",
    "verladendem": "verladend",
    "verladenden": "verladend",
    "verladender": "verladend",
    "verladendes": "verladend",
    "verladene": "verladen",
    "verladenem": "verladen",
    "verladenen": "verladen",
    "verladener": "verladen",
    "verladenes": "verladen",
    "verladest": "verladen",
    "verladet": "verladen",
    "verlagere": "verlagern",
    "verlagernd": "verlagern",
    "verlagernde": "verlagernd",
    "verlagerndem": "verlagernd",
    "verlagernden": "verlagernd",
    "verlagernder": "verlagernd",
    "verlagerndes": "verlagernd",
    "verlagerst": "verlagern",
    "verlagert": "verlagern",
    "verlagerte": "verlagern",
    "verlagertem": "verlagert",
    "verlagerten": "verlagern",
    "verlagerter": "verlagert",
    "verlagertere": "verlagert",
    "verlagerterem": "verlagert",
    "verlagerteren": "verlagert",
    "verlagerterer": "verlagert",
    "verlagerteres": "verlagert",
    "verlagertes": "verlagert",
    "verlagertest": "verlagern",
    "verlagerteste": "verlagert",
    "verlagertestem": "verlagert",
    "verlagertesten": "verlagert",
    "verlagertester": "verlagert",
    "verlagertestes": "verlagert",
    "verlagertet": "verlagern",
    "verlange": "verlangen",
    "verlangend": "verlangen",
    "verlangende": "verlangend",
    "verlangendem": "verlangend",
    "verlangenden": "verlangend",
    "verlangender": "verlangend",
    "verlangendere": "verlangend",
    "verlangenderem": "verlangend",
    "verlangenderen": "verlangend",
    "verlangenderer": "verlangend",
    "verlangenderes": "verlangend",
    "verlangendes": "verlangend",
    "verlangendste": "verlangend",
    "verlangendstem": "verlangend",
    "verlangendsten": "verlangend",
    "verlangendster": "verlangend",
    "verlangendstes": "verlangend",
    "verlangest": "verlangen",
    "verlanget": "verlangen",
    "verlangsame": "verlangsamen",
    "verlangsamend": "verlangsamen",
    "verlangsamende": "verlangsamend",
    "verlangsamendem": "verlangsamend",
    "verlangsamenden": "verlangsamend",
    "verlangsamender": "verlangsamend",
    "verlangsamendere": "verlangsamend",
    "verlangsamenderem": "verlangsamend",
    "verlangsamenderen": "verlangsamend",
    "verlangsamenderer": "verlangsamend",
    "verlangsamenderes": "verlangsamend",
    "verlangsamendes": "verlangsamend",
    "verlangsamendste": "verlangsamend",
    "verlangsamendstem": "verlangsamend",
    "verlangsamendsten": "verlangsamend",
    "verlangsamendster": "verlangsamend",
    "verlangsamendstes": "verlangsamend",
    "verlangsamest": "verlangsamen",
    "verlangsamet": "verlangsamen",
    "verlangsamst": "verlangsamen",
    "verlangsamt": "verlangsamen",
    "verlangsamte": "verlangsamen",
    "verlangsamtem": "verlangsamt",
    "verlangsamten": "verlangsamen",
    "verlangsamter": "verlangsamt",
    "verlangsamtere": "verlangsamt",
    "verlangsamterem": "verlangsamt",
    "verlangsamteren": "verlangsamt",
    "verlangsamterer": "verlangsamt",
    "verlangsamteres": "verlangsamt",
    "verlangsamtes": "verlangsamt",
    "verlangsamtest": "verlangsamen",
    "verlangsamteste": "verlangsamt",
    "verlangsamtestem": "verlangsamt",
    "verlangsamtesten": "verlangsamt",
    "verlangsamtester": "verlangsamt",
    "verlangsamtestes": "verlangsamt",
    "verlangsamtet": "verlangsamen",
    "verlangst": "verlangen",
    "verlangt": "verlangen",
    "verlangte": "verlangen",
    "verlangtem": "verlangt",
    "verlangten": "verlangen",
    "verlangter": "verlangt",
    "verlangtere": "verlangt",
    "verlangterem": "verlangt",
    "verlangteren": "verlangt",
    "verlangterer": "verlangt",
    "verlangteres": "verlangt",
    "verlangtes": "verlangt",
    "verlangtest": "verlangen",
    "verlangteste": "verlangt",
    "verlangtestem": "verlangt",
    "verlangtesten": "verlangt",
    "verlangtester": "verlangt",
    "verlangtestes": "verlangt",
    "verlangtet": "verlangen",
    "verlas": "verlesen",
    "verlasen": "verlesen",
    "verlasse": "verlassen",
    "verlassend": "verlassen",
    "verlassende": "verlassend",
    "verlassendem": "verlassend",
    "verlassenden": "verlassend",
    "verlassender": "verlassend",
    "verlassendes": "verlassend",
    "verlassene": "verlassen",
    "verlassenem": "verlassen",
    "verlassenen": "verlassen",
    "verlassener": "verlassen",
    "verlassenere": "verlassen",
    "verlassenerem": "verlassen",
    "verlasseneren": "verlassen",
    "verlassenerer": "verlassen",
    "verlasseneres": "verlassen",
    "verlassenes": "verlassen",
    "verlassenstem": "verlassen",
    "verlassensten": "verlassen",
    "verlassenster": "verlassen",
    "verlassenstes": "verlassen",
    "verlassest": "verlassen",
    "verlasset": "verlassen",
    "verlast": "verlesen",
    "verlaufend": "verlaufen",
    "verlaufende": "verlaufend",
    "verlaufendem": "verlaufend",
    "verlaufenden": "verlaufend",
    "verlaufender": "verlaufend",
    "verlaufendes": "verlaufend",
    "verlaufene": "verlaufen",
    "verlaufenem": "verlaufen",
    "verlaufenen": "verlaufen",
    "verlaufener": "verlaufen",
    "verlaufenes": "verlaufen",
    "verlaufest": "verlaufen",
    "verlaufet": "verlaufen",
    "verlauft": "verlaufen",
    "verlaute": "verlauten",
    "verlautend": "verlauten",
    "verlautende": "verlautend",
    "verlautendem": "verlautend",
    "verlautenden": "verlautend",
    "verlautender": "verlautend",
    "verlautendes": "verlautend",
    "verlautest": "verlauten",
    "verlautet": "verlauten",
    "verlautete": "verlauten",
    "verlautetem": "verlautet",
    "verlauteten": "verlauten",
    "verlauteter": "verlautet",
    "verlautetes": "verlautet",
    "verlautetest": "verlauten",
    "verlautetet": "verlauten",
    "verlaß": "verlassen",
    "verlaßt": "verlassen",
    "verlebe": "verleben",
    "verlebend": "verleben",
    "verlebende": "verlebend",
    "verlebendem": "verlebend",
    "verlebenden": "verlebend",
    "verlebender": "verlebend",
    "verlebendes": "verlebend",
    "verlebest": "verleben",
    "verlebet": "verleben",
    "verlebst": "verleben",
    "verlebt": "verleben",
    "verlebte": "verleben",
    "verlebtem": "verlebt",
    "verlebten": "verleben",
    "verlebter": "verlebt",
    "verlebtes": "verlebt",
    "verlebtest": "verleben",
    "verlebtet": "verleben",
    "verlege": "verlegen",
    "verlegend": "verlegen",
    "verlegende": "verlegend",
    "verlegendem": "verlegend",
    "verlegenden": "verlegend",
    "verlegender": "verlegend",
    "verlegendes": "verlegend",
    "verlegest": "verlegen",
    "verleget": "verlegen",
    "verlegst": "verlegen",
    "verlegt": "verlegen",
    "verlegte": "verlegen",
    "verlegtem": "verlegt",
    "verlegten": "verlegen",
    "verlegter": "verlegt",
    "verlegtes": "verlegt",
    "verlegtest": "verlegen",
    "verlegtet": "verlegen",
    "verleibe": "verleiben",
    "verleibend": "verleiben",
    "verleibende": "verleibend",
    "verleibendem": "verleibend",
    "verleibenden": "verleibend",
    "verleibender": "verleibend",
    "verleibendes": "verleibend",
    "verleibest": "verleiben",
    "verleibet": "verleiben",
    "verleibst": "verleiben",
    "verleibt": "verleiben",
    "verleibte": "verleiben",
    "verleibtem": "verleibt",
    "verleibten": "verleiben",
    "verleibter": "verleibt",
    "verleibtes": "verleibt",
    "verleibtest": "verleiben",
    "verleibtet": "verleiben",
    "verleihend": "verleihen",
    "verleihende": "verleihend",
    "verleihendem": "verleihend",
    "verleihenden": "verleihend",
    "verleihender": "verleihend",
    "verleihendes": "verleihend",
    "verleihest": "verleihen",
    "verleihet": "verleihen",
    "verleihst": "verleihen",
    "verleiht": "verleihen",
    "verleime": "verleimen",
    "verleimend": "verleimen",
    "verleimende": "verleimend",
    "verleimendem": "verleimend",
    "verleimenden": "verleimend",
    "verleimender": "verleimend",
    "verleimendes": "verleimend",
    "verleimest": "verleimen",
    "verleimet": "verleimen",
    "verleimst": "verleimen",
    "verleimt": "verleimen",
    "verleimte": "verleimen",
    "verleimtem": "verleimt",
    "verleimten": "verleimen",
    "verleimter": "verleimt",
    "verleimtes": "verleimt",
    "verleimtest": "verleimen",
    "verleimtet": "verleimen",
    "verleite": "verleiten",
    "verleitend": "verleiten",
    "verleitende": "verleitend",
    "verleitendem": "verleitend",
    "verleitenden": "verleitend",
    "verleitender": "verleitend",
    "verleitendes": "verleitend",
    "verleitest": "verleiten",
    "verleitet": "verleiten",
    "verleitete": "verleiten",
    "verleitetem": "verleitet",
    "verleiteten": "verleiten",
    "verleiteter": "verleitet",
    "verleitetes": "verleitet",
    "verleitetest": "verleiten",
    "verleitetet": "verleiten",
    "verlerne": "verlernen",
    "verlernend": "verlernen",
    "verlernende": "verlernend",
    "verlernendem": "verlernend",
    "verlernenden": "verlernend",
    "verlernender": "verlernend",
    "verlernendes": "verlernend",
    "verlernest": "verlernen",
    "verlernet": "verlernen",
    "verlernst": "verlernen",
    "verlernt": "verlernen",
    "verlernte": "verlernen",
    "verlerntem": "verlernt",
    "verlernten": "verlernen",
    "verlernter": "verlernt",
    "verlerntere": "verlernt",
    "verlernterem": "verlernt",
    "verlernteren": "verlernt",
    "verlernterer": "verlernt",
    "verlernteres": "verlernt",
    "verlerntes": "verlernt",
    "verlerntest": "verlernen",
    "verlernteste": "verlernt",
    "verlerntestem": "verlernt",
    "verlerntesten": "verlernt",
    "verlerntester": "verlernt",
    "verlerntestes": "verlernt",
    "verlerntet": "verlernen",
    "verlese": "verlesen",
    "verlesend": "verlesen",
    "verlesende": "verlesend",
    "verlesendem": "verlesend",
    "verlesenden": "verlesend",
    "verlesender": "verlesend",
    "verlesendes": "verlesend",
    "verlesene": "verlesen",
    "verlesenem": "verlesen",
    "verlesenen": "verlesen",
    "verlesener": "verlesen",
    "verlesenes": "verlesen",
    "verlesest": "verlesen",
    "verleset": "verlesen",
    "verlest": "verlesen",
    "verletzbarem": "verletzbar",
    "verletzbaren": "verletzbar",
    "verletzbarer": "verletzbar",
    "verletzbarere": "verletzbar",
    "verletzbarerem": "verletzbar",
    "verletzbareren": "verletzbar",
    "verletzbarerer": "verletzbar",
    "verletzbareres": "verletzbar",
    "verletzbares": "verletzbar",
    "verletzbarste": "verletzbar",
    "verletzbarstem": "verletzbar",
    "verletzbarsten": "verletzbar",
    "verletzbarster": "verletzbar",
    "verletzbarstes": "verletzbar",
    "verletze": "verletzen",
    "verletzend": "verletzen",
    "verletzende": "verletzend",
    "verletzendem": "verletzend",
    "verletzenden": "verletzend",
    "verletzender": "verletzend",
    "verletzendere": "verletzend",
    "verletzenderem": "verletzend",
    "verletzenderen": "verletzend",
    "verletzenderer": "verletzend",
    "verletzenderes": "verletzend",
    "verletzendes": "verletzend",
    "verletzendste": "verletzend",
    "verletzendstem": "verletzend",
    "verletzendsten": "verletzend",
    "verletzendster": "verletzend",
    "verletzendstes": "verletzend",
    "verletzest": "verletzen",
    "verletzet": "verletzen",
    "verletzt": "verletzen",
    "verletzte": "verletzen",
    "verletztem": "verletzt",
    "verletzten": "verletzen",
    "verletzter": "verletzt",
    "verletztere": "verletzt",
    "verletzterem": "verletzt",
    "verletzteren": "verletzt",
    "verletzterer": "verletzt",
    "verletzteres": "verletzt",
    "verletztes": "verletzt",
    "verletztest": "verletzen",
    "verletzteste": "verletzt",
    "verletztestem": "verletzt",
    "verletztesten": "verletzt",
    "verletztester": "verletzt",
    "verletztestes": "verletzt",
    "verletztet": "verletzen",
    "verleugne": "verleugnen",
    "verleugnend": "verleugnen",
    "verleugnende": "verleugnend",
    "verleugnendem": "verleugnend",
    "verleugnenden": "verleugnend",
    "verleugnender": "verleugnend",
    "verleugnendes": "verleugnend",
    "verleugnest": "verleugnen",
    "verleugnet": "verleugnen",
    "verleugnete": "verleugnen",
    "verleugnetem": "verleugnet",
    "verleugneten": "verleugnen",
    "verleugneter": "verleugnet",
    "verleugnetes": "verleugnet",
    "verleugnetest": "verleugnen",
    "verleugnetet": "verleugnen",
    "verleumde": "verleumden",
    "verleumdend": "verleumden",
    "verleumdende": "verleumdend",
    "verleumdendem": "verleumdend",
    "verleumdenden": "verleumdend",
    "verleumdender": "verleumdend",
    "verleumdendes": "verleumdend",
    "verleumderischem": "verleumderisch",
    "verleumderischen": "verleumderisch",
    "verleumderischer": "verleumderisch",
    "verleumderischere": "verleumderisch",
    "verleumderischerem": "verleumderisch",
    "verleumderischeren": "verleumderisch",
    "verleumderischerer": "verleumderisch",
    "verleumderischeres": "verleumderisch",
    "verleumderisches": "verleumderisch",
    "verleumderischste": "verleumderisch",
    "verleumderischstem": "verleumderisch",
    "verleumderischsten": "verleumderisch",
    "verleumderischster": "verleumderisch",
    "verleumderischstes": "verleumderisch",
    "verleumdest": "verleumden",
    "verleumdet": "verleumden",
    "verleumdete": "verleumden",
    "verleumdetem": "verleumdet",
    "verleumdeten": "verleumden",
    "verleumdeter": "verleumdet",
    "verleumdetes": "verleumdet",
    "verleumdetest": "verleumden",
    "verleumdetet": "verleumden",
    "verliebe": "verlieben",
    "verliebend": "verlieben",
    "verliebende": "verliebend",
    "verliebendem": "verliebend",
    "verliebenden": "verliebend",
    "verliebender": "verliebend",
    "verliebendes": "verliebend",
    "verliebest": "verlieben",
    "verliebet": "verlieben",
    "verliebst": "verlieben",
    "verliebt": "verlieben",
    "verliebte": "verlieben",
    "verliebtem": "verliebt",
    "verliebten": "verlieben",
    "verliebter": "verliebt",
    "verliebtere": "verliebt",
    "verliebterem": "verliebt",
    "verliebteren": "verliebt",
    "verliebterer": "verliebt",
    "verliebteres": "verliebt",
    "verliebtes": "verliebt",
    "verliebtest": "verlieben",
    "verliebteste": "verliebt",
    "verliebtestem": "verliebt",
    "verliebtesten": "verliebt",
    "verliebtester": "verliebt",
    "verliebtestes": "verliebt",
    "verliebtet": "verlieben",
    "verlief": "verlaufen",
    "verliefe": "verlaufen",
    "verliefen": "verlaufen",
    "verliefest": "verlaufen",
    "verliefet": "verlaufen",
    "verliefst": "verlaufen",
    "verlieft": "verlaufen",
    "verlieh": "verleihen",
    "verliehe": "verleihen",
    "verliehen": "verleihen",
    "verliehene": "verliehen",
    "verliehenem": "verliehen",
    "verliehenen": "verliehen",
    "verliehener": "verliehen",
    "verliehenes": "verliehen",
    "verliehest": "verleihen",
    "verliehet": "verleihen",
    "verliehst": "verleihen",
    "verlieht": "verleihen",
    "verliere": "verlieren",
    "verlierend": "verlieren",
    "verlierende": "verlierend",
    "verlierendem": "verlierend",
    "verlierenden": "verlierend",
    "verlierender": "verlierend",
    "verlierendes": "verlierend",
    "verlierest": "verlieren",
    "verlieret": "verlieren",
    "verlierst": "verlieren",
    "verliert": "verlieren",
    "verlies": "verlesen",
    "verliest": "verlesen",
    "verließ": "verlassen",
    "verließe": "verlassen",
    "verließen": "verlassen",
    "verließest": "verlassen",
    "verließet": "verlassen",
    "verließt": "verlassen",
    "verlisch": "verlöschen",
    "verlischst": "verlöschen",
    "verlischt": "verlöschen",
    "verlobe": "verloben",
    "verlobend": "verloben",
    "verlobende": "verlobend",
    "verlobendem": "verlobend",
    "verlobenden": "verlobend",
    "verlobender": "verlobend",
    "verlobendes": "verlobend",
    "verlobest": "verloben",
    "verlobet": "verloben",
    "verlobst": "verloben",
    "verlobt": "verloben",
    "verlobte": "verloben",
    "verlobtem": "verlobt",
    "verlobten": "verloben",
    "verlobter": "verlobt",
    "verlobtes": "verlobt",
    "verlobtest": "verloben",
    "verlobtet": "verloben",
    "verlocke": "verlocken",
    "verlockend": "verlocken",
    "verlockende": "verlockend",
    "verlockendem": "verlockend",
    "verlockenden": "verlockend",
    "verlockender": "verlockend",
    "verlockendere": "verlockend",
    "verlockenderem": "verlockend",
    "verlockenderen": "verlockend",
    "verlockenderer": "verlockend",
    "verlockenderes": "verlockend",
    "verlockendes": "verlockend",
    "verlockendste": "verlockend",
    "verlockendstem": "verlockend",
    "verlockendsten": "verlockend",
    "verlockendster": "verlockend",
    "verlockendstes": "verlockend",
    "verlockest": "verlocken",
    "verlocket": "verlocken",
    "verlockst": "verlocken",
    "verlockt": "verlocken",
    "verlockte": "verlocken",
    "verlocktem": "verlockt",
    "verlockten": "verlocken",
    "verlockter": "verlockt",
    "verlocktes": "verlockt",
    "verlocktest": "verlocken",
    "verlocktet": "verlocken",
    "verlogene": "verlogen",
    "verlogenem": "verlogen",
    "verlogenen": "verlogen",
    "verlogener": "verlogen",
    "verlogenere": "verlogen",
    "verlogenerem": "verlogen",
    "verlogeneren": "verlogen",
    "verlogenerer": "verlogen",
    "verlogeneres": "verlogen",
    "verlogenes": "verlogen",
    "verlogenstem": "verlogen",
    "verlogensten": "verlogen",
    "verlogenster": "verlogen",
    "verlogenstes": "verlogen",
    "verlor": "verlieren",
    "verloren": "verlieren",
    "verlorene": "verloren",
    "verlorenem": "verloren",
    "verlorenen": "verloren",
    "verlorener": "verloren",
    "verlorenere": "verloren",
    "verlorenerem": "verloren",
    "verloreneren": "verloren",
    "verlorenerer": "verloren",
    "verloreneres": "verloren",
    "verlorenes": "verloren",
    "verlorenste": "verloren",
    "verlorenstem": "verloren",
    "verlorensten": "verloren",
    "verlorenster": "verloren",
    "verlorenstes": "verloren",
    "verlorst": "verlieren",
    "verlort": "verlieren",
    "verlosch": "verlöschen",
    "verloschen": "verlöschen",
    "verloschene": "verloschen",
    "verloschenem": "verloschen",
    "verloschenen": "verloschen",
    "verloschener": "verloschen",
    "verloschenere": "verloschen",
    "verloschenerem": "verloschen",
    "verloscheneren": "verloschen",
    "verloschenerer": "verloschen",
    "verloscheneres": "verloschen",
    "verloschenes": "verloschen",
    "verloschenstem": "verloschen",
    "verloschensten": "verloschen",
    "verloschenster": "verloschen",
    "verloschenstes": "verloschen",
    "verloschst": "verlöschen",
    "verloscht": "verlöschen",
    "verlose": "verlosen",
    "verlosend": "verlosen",
    "verlosende": "verlosend",
    "verlosendem": "verlosend",
    "verlosenden": "verlosend",
    "verlosender": "verlosend",
    "verlosendes": "verlosend",
    "verlosest": "verlosen",
    "verloset": "verlosen",
    "verlost": "verlosen",
    "verloste": "verlosen",
    "verlostem": "verlost",
    "verlosten": "verlosen",
    "verloster": "verlost",
    "verlostes": "verlost",
    "verlostest": "verlosen",
    "verlostet": "verlosen",
    "verlottere": "verlottern",
    "verlotternd": "verlottern",
    "verlotternde": "verlotternd",
    "verlotterndem": "verlotternd",
    "verlotternden": "verlotternd",
    "verlotternder": "verlotternd",
    "verlotterndere": "verlotternd",
    "verlotternderem": "verlotternd",
    "verlotternderen": "verlotternd",
    "verlotternderer": "verlotternd",
    "verlotternderes": "verlotternd",
    "verlotterndes": "verlotternd",
    "verlotterndste": "verlotternd",
    "verlotterndstem": "verlotternd",
    "verlotterndsten": "verlotternd",
    "verlotterndster": "verlotternd",
    "verlotterndstes": "verlotternd",
    "verlotterst": "verlottern",
    "verlottert": "verlottern",
    "verlotterte": "verlottern",
    "verlottertem": "verlottert",
    "verlotterten": "verlottern",
    "verlotterter": "verlottert",
    "verlottertere": "verlottert",
    "verlotterterem": "verlottert",
    "verlotterteren": "verlottert",
    "verlotterterer": "verlottert",
    "verlotterteres": "verlottert",
    "verlottertes": "verlottert",
    "verlottertest": "verlottern",
    "verlotterteste": "verlottert",
    "verlottertestem": "verlottert",
    "verlottertesten": "verlottert",
    "verlottertester": "verlottert",
    "verlottertestes": "verlottert",
    "verlottertet": "verlottern",
    "verlud": "verladen",
    "verluden": "verladen",
    "verludere": "verludern",
    "verludernd": "verludern",
    "verludernde": "verludernd",
    "verluderndem": "verludernd",
    "verludernden": "verludernd",
    "verludernder": "verludernd",
    "verluderndere": "verludernd",
    "verludernderem": "verludernd",
    "verludernderen": "verludernd",
    "verludernderer": "verludernd",
    "verludernderes": "verludernd",
    "verluderndes": "verludernd",
    "verluderndste": "verludernd",
    "verluderndstem": "verludernd",
    "verluderndsten": "verludernd",
    "verluderndster": "verludernd",
    "verluderndstes": "verludernd",
    "verluderst": "verludern",
    "verludert": "verludern",
    "verluderte": "verludern",
    "verludertem": "verludert",
    "verluderten": "verludern",
    "verluderter": "verludert",
    "verludertere": "verludert",
    "verluderterem": "verludert",
    "verluderteren": "verludert",
    "verluderterer": "verludert",
    "verluderteres": "verludert",
    "verludertes": "verludert",
    "verludertest": "verludern",
    "verluderteste": "verludert",
    "verludertestem": "verludert",
    "verludertesten": "verludert",
    "verludertester": "verludert",
    "verludertestes": "verludert",
    "verludertet": "verludern",
    "verludest": "verladen",
    "verludet": "verladen",
    "verlädst": "verladen",
    "verlädt": "verladen",
    "verlängere": "verlängern",
    "verlängernd": "verlängern",
    "verlängernde": "verlängernd",
    "verlängerndem": "verlängernd",
    "verlängernden": "verlängernd",
    "verlängernder": "verlängernd",
    "verlängerndes": "verlängernd",
    "verlängerst": "verlängern",
    "verlängert": "verlängern",
    "verlängerte": "verlängern",
    "verlängertem": "verlängert",
    "verlängerten": "verlängern",
    "verlängerter": "verlängert",
    "verlängertere": "verlängert",
    "verlängerterem": "verlängert",
    "verlängerteren": "verlängert",
    "verlängerterer": "verlängert",
    "verlängerteres": "verlängert",
    "verlängertes": "verlängert",
    "verlängertest": "verlängern",
    "verlängerteste": "verlängert",
    "verlängertestem": "verlängert",
    "verlängertesten": "verlängert",
    "verlängertester": "verlängert",
    "verlängertestes": "verlängert",
    "verlängertet": "verlängern",
    "verläse": "verlesen",
    "verläsen": "verlesen",
    "verläsest": "verlesen",
    "verläset": "verlesen",
    "verläufst": "verlaufen",
    "verläuft": "verlaufen",
    "verläßliche": "verläßlich",
    "verläßlichem": "verläßlich",
    "verläßlichen": "verläßlich",
    "verläßlicher": "verläßlich",
    "verläßlichere": "verläßlich",
    "verläßlicherem": "verläßlich",
    "verläßlicheren": "verläßlich",
    "verläßlicherer": "verläßlich",
    "verläßlicheres": "verläßlich",
    "verläßliches": "verläßlich",
    "verläßlichste": "verläßlich",
    "verläßlichstem": "verläßlich",
    "verläßlichsten": "verläßlich",
    "verläßlichster": "verläßlich",
    "verläßlichstes": "verläßlich",
    "verläßt": "verlassen",
    "verlöre": "verlieren",
    "verlören": "verlieren",
    "verlörest": "verlieren",
    "verlöret": "verlieren",
    "verlösche": "verlöschen",
    "verlöschend": "verlöschen",
    "verlöschende": "verlöschend",
    "verlöschendem": "verlöschend",
    "verlöschenden": "verlöschend",
    "verlöschender": "verlöschend",
    "verlöschendes": "verlöschend",
    "verlöschest": "verlöschen",
    "verlöschet": "verlöschen",
    "verlöscht": "verlöschen",
    "verlöte": "verlöten",
    "verlötend": "verlöten",
    "verlötende": "verlötend",
    "verlötendem": "verlötend",
    "verlötenden": "verlötend",
    "verlötender": "verlötend",
    "verlötendes": "verlötend",
    "verlötest": "verlöten",
    "verlötet": "verlöten",
    "verlötete": "verlöten",
    "verlötetem": "verlötet",
    "verlöteten": "verlöten",
    "verlöteter": "verlötet",
    "verlötetes": "verlötet",
    "verlötetest": "verlöten",
    "verlötetet": "verlöten",
    "verlüde": "verladen",
    "verlüden": "verladen",
    "verlüdest": "verladen",
    "verlüdet": "verladen",
    "vermache": "vermachen",
    "vermachend": "vermachen",
    "vermachende": "vermachend",
    "vermachendem": "vermachend",
    "vermachenden": "vermachend",
    "vermachender": "vermachend",
    "vermachendes": "vermachend",
    "vermachest": "vermachen",
    "vermachet": "vermachen",
    "vermachst": "vermachen",
    "vermacht": "vermachen",
    "vermachte": "vermachen",
    "vermachtem": "vermacht",
    "vermachten": "vermachen",
    "vermachter": "vermacht",
    "vermachtes": "vermacht",
    "vermachtest": "vermachen",
    "vermachtet": "vermachen",
    "vermale": "vermalen",
    "vermalend": "vermalen",
    "vermalende": "vermalend",
    "vermalendem": "vermalend",
    "vermalenden": "vermalend",
    "vermalender": "vermalend",
    "vermalendes": "vermalend",
    "vermalest": "vermalen",
    "vermalet": "vermalen",
    "vermalst": "vermalen",
    "vermalt": "vermalen",
    "vermalte": "vermalen",
    "vermaltem": "vermalt",
    "vermalten": "vermalen",
    "vermalter": "vermalt",
    "vermaltes": "vermalt",
    "vermaltest": "vermalen",
    "vermaltet": "vermalen",
    "vermampfe": "vermampfen",
    "vermampfend": "vermampfen",
    "vermampfende": "vermampfend",
    "vermampfendem": "vermampfend",
    "vermampfenden": "vermampfend",
    "vermampfender": "vermampfend",
    "vermampfendere": "vermampfend",
    "vermampfenderem": "vermampfend",
    "vermampfenderen": "vermampfend",
    "vermampfenderer": "vermampfend",
    "vermampfenderes": "vermampfend",
    "vermampfendes": "vermampfend",
    "vermampfendste": "vermampfend",
    "vermampfendstem": "vermampfend",
    "vermampfendsten": "vermampfend",
    "vermampfendster": "vermampfend",
    "vermampfendstes": "vermampfend",
    "vermampfest": "vermampfen",
    "vermampfet": "vermampfen",
    "vermampfst": "vermampfen",
    "vermampft": "vermampfen",
    "vermampfte": "vermampfen",
    "vermampftem": "vermampft",
    "vermampften": "vermampfen",
    "vermampfter": "vermampft",
    "vermampftes": "vermampft",
    "vermampftest": "vermampfen",
    "vermampftet": "vermampfen",
    "vermarkte": "vermarkten",
    "vermarktend": "vermarkten",
    "vermarktende": "vermarktend",
    "vermarktendem": "vermarktend",
    "vermarktenden": "vermarktend",
    "vermarktender": "vermarktend",
    "vermarktendere": "vermarktend",
    "vermarktenderem": "vermarktend",
    "vermarktenderen": "vermarktend",
    "vermarktenderer": "vermarktend",
    "vermarktenderes": "vermarktend",
    "vermarktendes": "vermarktend",
    "vermarktendste": "vermarktend",
    "vermarktendstem": "vermarktend",
    "vermarktendsten": "vermarktend",
    "vermarktendster": "vermarktend",
    "vermarktendstes": "vermarktend",
    "vermarktest": "vermarkten",
    "vermarktet": "vermarkten",
    "vermarktete": "vermarkten",
    "vermarktetem": "vermarktet",
    "vermarkteten": "vermarkten",
    "vermarkteter": "vermarktet",
    "vermarktetere": "vermarktet",
    "vermarkteterem": "vermarktet",
    "vermarkteteren": "vermarktet",
    "vermarkteterer": "vermarktet",
    "vermarkteteres": "vermarktet",
    "vermarktetes": "vermarktet",
    "vermarktetest": "vermarkten",
    "vermarkteteste": "vermarktet",
    "vermarktetestem": "vermarktet",
    "vermarktetesten": "vermarktet",
    "vermarktetester": "vermarktet",
    "vermarktetestes": "vermarktet",
    "vermarktetet": "vermarkten",
    "vermassele": "vermasseln",
    "vermasselnd": "vermasseln",
    "vermasselnde": "vermasselnd",
    "vermasselndem": "vermasselnd",
    "vermasselnden": "vermasselnd",
    "vermasselnder": "vermasselnd",
    "vermasselndere": "vermasselnd",
    "vermasselnderem": "vermasselnd",
    "vermasselnderen": "vermasselnd",
    "vermasselnderer": "vermasselnd",
    "vermasselnderes": "vermasselnd",
    "vermasselndes": "vermasselnd",
    "vermasselndste": "vermasselnd",
    "vermasselndstem": "vermasselnd",
    "vermasselndsten": "vermasselnd",
    "vermasselndster": "vermasselnd",
    "vermasselndstes": "vermasselnd",
    "vermasselst": "vermasseln",
    "vermasselt": "vermasseln",
    "vermasselte": "vermasseln",
    "vermasseltem": "vermasselt",
    "vermasselten": "vermasseln",
    "vermasselter": "vermasselt",
    "vermasseltere": "vermasselt",
    "vermasselterem": "vermasselt",
    "vermasselteren": "vermasselt",
    "vermasselterer": "vermasselt",
    "vermasselteres": "vermasselt",
    "vermasseltes": "vermasselt",
    "vermasseltest": "vermasseln",
    "vermasselteste": "vermasselt",
    "vermasseltestem": "vermasselt",
    "vermasseltesten": "vermasselt",
    "vermasseltester": "vermasselt",
    "vermasseltestes": "vermasselt",
    "vermasseltet": "vermasseln",
    "vermassle": "vermasseln",
    "vermaß": "vermessen",
    "vermaßen": "vermessen",
    "vermaßt": "vermessen",
    "vermehre": "vermehren",
    "vermehrend": "vermehren",
    "vermehrende": "vermehrend",
    "vermehrendem": "vermehrend",
    "vermehrenden": "vermehrend",
    "vermehrender": "vermehrend",
    "vermehrendes": "vermehrend",
    "vermehrest": "vermehren",
    "vermehret": "vermehren",
    "vermehrst": "vermehren",
    "vermehrt": "vermehren",
    "vermehrte": "vermehren",
    "vermehrtem": "vermehrt",
    "vermehrten": "vermehren",
    "vermehrter": "vermehrt",
    "vermehrtes": "vermehrt",
    "vermehrtest": "vermehren",
    "vermehrtet": "vermehren",
    "vermeidbare": "vermeidbar",
    "vermeidbarem": "vermeidbar",
    "vermeidbaren": "vermeidbar",
    "vermeidbarer": "vermeidbar",
    "vermeidbares": "vermeidbar",
    "vermeide": "vermeiden",
    "vermeidend": "vermeiden",
    "vermeidende": "vermeidend",
    "vermeidendem": "vermeidend",
    "vermeidenden": "vermeidend",
    "vermeidender": "vermeidend",
    "vermeidendes": "vermeidend",
    "vermeidest": "vermeiden",
    "vermeidet": "vermeiden",
    "vermeintlichem": "vermeintlich",
    "vermeintlichen": "vermeintlich",
    "vermeintlicher": "vermeintlich",
    "vermeintliches": "vermeintlich",
    "vermelde": "vermelden",
    "vermeldend": "vermelden",
    "vermeldende": "vermeldend",
    "vermeldendem": "vermeldend",
    "vermeldenden": "vermeldend",
    "vermeldender": "vermeldend",
    "vermeldendes": "vermeldend",
    "vermeldest": "vermelden",
    "vermeldet": "vermelden",
    "vermeldete": "vermelden",
    "vermeldetem": "vermeldet",
    "vermeldeten": "vermelden",
    "vermeldeter": "vermeldet",
    "vermeldetes": "vermeldet",
    "vermeldetest": "vermelden",
    "vermeldetet": "vermelden",
    "vermenge": "vermengen",
    "vermengend": "vermengen",
    "vermengende": "vermengend",
    "vermengendem": "vermengend",
    "vermengenden": "vermengend",
    "vermengender": "vermengend",
    "vermengendes": "vermengend",
    "vermengest": "vermengen",
    "vermenget": "vermengen",
    "vermengst": "vermengen",
    "vermengt": "vermengen",
    "vermengte": "vermengen",
    "vermengtem": "vermengt",
    "vermengten": "vermengen",
    "vermengter": "vermengt",
    "vermengtes": "vermengt",
    "vermengtest": "vermengen",
    "vermengtet": "vermengen",
    "vermenschliche": "vermenschlichen",
    "vermenschlichend": "vermenschlichen",
    "vermenschlichende": "vermenschlichend",
    "vermenschlichendem": "vermenschlichend",
    "vermenschlichenden": "vermenschlichend",
    "vermenschlichender": "vermenschlichend",
    "vermenschlichendere": "vermenschlichend",
    "vermenschlichenderem": "vermenschlichend",
    "vermenschlichenderen": "vermenschlichend",
    "vermenschlichenderer": "vermenschlichend",
    "vermenschlichenderes": "vermenschlichend",
    "vermenschlichendes": "vermenschlichend",
    "vermenschlichendste": "vermenschlichend",
    "vermenschlichendstem": "vermenschlichend",
    "vermenschlichendsten": "vermenschlichend",
    "vermenschlichendster": "vermenschlichend",
    "vermenschlichendstes": "vermenschlichend",
    "vermenschlichest": "vermenschlichen",
    "vermenschlichet": "vermenschlichen",
    "vermenschlichst": "vermenschlichen",
    "vermenschlicht": "vermenschlichen",
    "vermenschlichte": "vermenschlichen",
    "vermenschlichtem": "vermenschlicht",
    "vermenschlichten": "vermenschlichen",
    "vermenschlichter": "vermenschlicht",
    "vermenschlichtere": "vermenschlicht",
    "vermenschlichterem": "vermenschlicht",
    "vermenschlichteren": "vermenschlicht",
    "vermenschlichterer": "vermenschlicht",
    "vermenschlichteres": "vermenschlicht",
    "vermenschlichtes": "vermenschlicht",
    "vermenschlichtest": "vermenschlichen",
    "vermenschlichteste": "vermenschlicht",
    "vermenschlichtestem": "vermenschlicht",
    "vermenschlichtesten": "vermenschlicht",
    "vermenschlichtester": "vermenschlicht",
    "vermenschlichtestes": "vermenschlicht",
    "vermenschlichtet": "vermenschlichen",
    "vermerkend": "vermerken",
    "vermerkende": "vermerkend",
    "vermerkendem": "vermerkend",
    "vermerkenden": "vermerkend",
    "vermerkender": "vermerkend",
    "vermerkendes": "vermerkend",
    "vermerkest": "vermerken",
    "vermerket": "vermerken",
    "vermerkst": "vermerken",
    "vermerkt": "vermerken",
    "vermerkte": "vermerken",
    "vermerktem": "vermerkt",
    "vermerkten": "vermerken",
    "vermerkter": "vermerkt",
    "vermerktes": "vermerkt",
    "vermerktest": "vermerken",
    "vermerktet": "vermerken",
    "vermesse": "vermessen",
    "vermessend": "vermessen",
    "vermessende": "vermessend",
    "vermessendem": "vermessend",
    "vermessenden": "vermessend",
    "vermessender": "vermessend",
    "vermessendes": "vermessend",
    "vermessene": "vermessen",
    "vermessenem": "vermessen",
    "vermessenen": "vermessen",
    "vermessener": "vermessen",
    "vermessenes": "vermessen",
    "vermessest": "vermessen",
    "vermesset": "vermessen",
    "vermeßt": "vermessen",
    "vermied": "vermeiden",
    "vermiede": "vermeiden",
    "vermieden": "vermeiden",
    "vermiedene": "vermieden",
    "vermiedenem": "vermieden",
    "vermiedenen": "vermieden",
    "vermiedener": "vermieden",
    "vermiedenere": "vermieden",
    "vermiedenerem": "vermieden",
    "vermiedeneren": "vermieden",
    "vermiedenerer": "vermieden",
    "vermiedeneres": "vermieden",
    "vermiedenes": "vermieden",
    "vermiedenste": "vermieden",
    "vermiedenstem": "vermieden",
    "vermiedensten": "vermieden",
    "vermiedenster": "vermieden",
    "vermiedenstes": "vermieden",
    "vermiedest": "vermeiden",
    "vermiedet": "vermeiden",
    "vermiefe": "vermiefen",
    "vermiefend": "vermiefen",
    "vermiefende": "vermiefend",
    "vermiefendem": "vermiefend",
    "vermiefenden": "vermiefend",
    "vermiefender": "vermiefend",
    "vermiefendere": "vermiefend",
    "vermiefenderem": "vermiefend",
    "vermiefenderen": "vermiefend",
    "vermiefenderer": "vermiefend",
    "vermiefenderes": "vermiefend",
    "vermiefendes": "vermiefend",
    "vermiefendste": "vermiefend",
    "vermiefendstem": "vermiefend",
    "vermiefendsten": "vermiefend",
    "vermiefendster": "vermiefend",
    "vermiefendstes": "vermiefend",
    "vermiefest": "vermiefen",
    "vermiefet": "vermiefen",
    "vermiefst": "vermiefen",
    "vermieft": "vermiefen",
    "vermiefte": "vermiefen",
    "vermieftem": "vermieft",
    "vermieften": "vermiefen",
    "vermiefter": "vermieft",
    "vermieftere": "vermieft",
    "vermiefterem": "vermieft",
    "vermiefteren": "vermieft",
    "vermiefterer": "vermieft",
    "vermiefteres": "vermieft",
    "vermieftes": "vermieft",
    "vermieftest": "vermiefen",
    "vermiefteste": "vermieft",
    "vermieftestem": "vermieft",
    "vermieftesten": "vermieft",
    "vermieftester": "vermieft",
    "vermieftestes": "vermieft",
    "vermieftet": "vermiefen",
    "vermiese": "vermiesen",
    "vermiesend": "vermiesen",
    "vermiesende": "vermiesend",
    "vermiesendem": "vermiesend",
    "vermiesenden": "vermiesend",
    "vermiesender": "vermiesend",
    "vermiesendere": "vermiesend",
    "vermiesenderem": "vermiesend",
    "vermiesenderen": "vermiesend",
    "vermiesenderer": "vermiesend",
    "vermiesenderes": "vermiesend",
    "vermiesendes": "vermiesend",
    "vermiesendste": "vermiesend",
    "vermiesendstem": "vermiesend",
    "vermiesendsten": "vermiesend",
    "vermiesendster": "vermiesend",
    "vermiesendstes": "vermiesend",
    "vermiesest": "vermiesen",
    "vermieset": "vermiesen",
    "vermiest": "vermiesen",
    "vermieste": "vermiesen",
    "vermiestem": "vermiest",
    "vermiesten": "vermiesen",
    "vermiester": "vermiest",
    "vermiestere": "vermiest",
    "vermiesterem": "vermiest",
    "vermiesteren": "vermiest",
    "vermiesterer": "vermiest",
    "vermiesteres": "vermiest",
    "vermiestes": "vermiest",
    "vermiestest": "vermiesen",
    "vermiesteste": "vermiest",
    "vermiestestem": "vermiest",
    "vermiestesten": "vermiest",
    "vermiestester": "vermiest",
    "vermiestestes": "vermiest",
    "vermiestet": "vermiesen",
    "vermiete": "vermieten",
    "vermietend": "vermieten",
    "vermietende": "vermietend",
    "vermietendem": "vermietend",
    "vermietenden": "vermietend",
    "vermietender": "vermietend",
    "vermietendes": "vermietend",
    "vermietest": "vermieten",
    "vermietet": "vermieten",
    "vermietete": "vermieten",
    "vermietetem": "vermietet",
    "vermieteten": "vermieten",
    "vermieteter": "vermietet",
    "vermietetes": "vermietet",
    "vermietetest": "vermieten",
    "vermietetet": "vermieten",
    "vermime": "vermimen",
    "vermimend": "vermimen",
    "vermimende": "vermimend",
    "vermimendem": "vermimend",
    "vermimenden": "vermimend",
    "vermimender": "vermimend",
    "vermimendere": "vermimend",
    "vermimenderem": "vermimend",
    "vermimenderen": "vermimend",
    "vermimenderer": "vermimend",
    "vermimenderes": "vermimend",
    "vermimendes": "vermimend",
    "vermimendste": "vermimend",
    "vermimendstem": "vermimend",
    "vermimendsten": "vermimend",
    "vermimendster": "vermimend",
    "vermimendstes": "vermimend",
    "vermimest": "vermimen",
    "vermimet": "vermimen",
    "vermimst": "vermimen",
    "vermimt": "vermimen",
    "vermimte": "vermimen",
    "vermimtem": "vermimt",
    "vermimten": "vermimen",
    "vermimter": "vermimt",
    "vermimtere": "vermimt",
    "vermimterem": "vermimt",
    "vermimteren": "vermimt",
    "vermimterer": "vermimt",
    "vermimteres": "vermimt",
    "vermimtes": "vermimt",
    "vermimtest": "vermimen",
    "vermimteste": "vermimt",
    "vermimtestem": "vermimt",
    "vermimtesten": "vermimt",
    "vermimtester": "vermimt",
    "vermimtestes": "vermimt",
    "vermimtet": "vermimen",
    "vermindere": "vermindern",
    "vermindernd": "vermindern",
    "vermindernde": "vermindernd",
    "verminderndem": "vermindernd",
    "vermindernden": "vermindernd",
    "vermindernder": "vermindernd",
    "verminderndes": "vermindernd",
    "verminderst": "vermindern",
    "vermindert": "vermindern",
    "verminderte": "vermindern",
    "vermindertem": "vermindert",
    "verminderten": "vermindern",
    "verminderter": "vermindert",
    "vermindertes": "vermindert",
    "vermindertest": "vermindern",
    "vermindertet": "vermindern",
    "vermine": "verminen",
    "verminend": "verminen",
    "verminende": "verminend",
    "verminendem": "verminend",
    "verminenden": "verminend",
    "verminender": "verminend",
    "verminendere": "verminend",
    "verminenderem": "verminend",
    "verminenderen": "verminend",
    "verminenderer": "verminend",
    "verminenderes": "verminend",
    "verminendes": "verminend",
    "verminendste": "verminend",
    "verminendstem": "verminend",
    "verminendsten": "verminend",
    "verminendster": "verminend",
    "verminendstes": "verminend",
    "verminest": "verminen",
    "verminet": "verminen",
    "verminst": "verminen",
    "vermint": "verminen",
    "verminte": "verminen",
    "vermintem": "vermint",
    "verminten": "verminen",
    "verminter": "vermint",
    "vermintere": "vermint",
    "verminterem": "vermint",
    "verminteren": "vermint",
    "verminterer": "vermint",
    "verminteres": "vermint",
    "vermintes": "vermint",
    "vermintest": "verminen",
    "verminteste": "vermint",
    "vermintestem": "vermint",
    "vermintesten": "vermint",
    "vermintester": "vermint",
    "vermintestes": "vermint",
    "vermintet": "verminen",
    "vermische": "vermischen",
    "vermischend": "vermischen",
    "vermischende": "vermischend",
    "vermischendem": "vermischend",
    "vermischenden": "vermischend",
    "vermischender": "vermischend",
    "vermischendes": "vermischend",
    "vermischest": "vermischen",
    "vermischet": "vermischen",
    "vermischst": "vermischen",
    "vermischt": "vermischen",
    "vermischte": "vermischen",
    "vermischtem": "vermischt",
    "vermischten": "vermischen",
    "vermischter": "vermischt",
    "vermischtere": "vermischt",
    "vermischterem": "vermischt",
    "vermischteren": "vermischt",
    "vermischterer": "vermischt",
    "vermischteres": "vermischt",
    "vermischtes": "vermischt",
    "vermischtest": "vermischen",
    "vermischteste": "vermischt",
    "vermischtestem": "vermischt",
    "vermischtesten": "vermischt",
    "vermischtester": "vermischt",
    "vermischtestes": "vermischt",
    "vermischtet": "vermischen",
    "vermisse": "vermissen",
    "vermissend": "vermissen",
    "vermissende": "vermissend",
    "vermissendem": "vermissend",
    "vermissenden": "vermissend",
    "vermissender": "vermissend",
    "vermissendes": "vermissend",
    "vermissest": "vermissen",
    "vermisset": "vermissen",
    "vermittele": "vermitteln",
    "vermittelnd": "vermitteln",
    "vermittelnde": "vermittelnd",
    "vermittelndem": "vermittelnd",
    "vermittelnden": "vermittelnd",
    "vermittelnder": "vermittelnd",
    "vermittelndes": "vermittelnd",
    "vermittelst": "vermitteln",
    "vermittelt": "vermitteln",
    "vermittelte": "vermitteln",
    "vermitteltem": "vermittelt",
    "vermittelten": "vermitteln",
    "vermittelter": "vermittelt",
    "vermitteltes": "vermittelt",
    "vermitteltest": "vermitteln",
    "vermitteltet": "vermitteln",
    "vermittle": "vermitteln",
    "vermiß": "vermissen",
    "vermißt": "vermissen",
    "vermißte": "vermissen",
    "vermißtem": "vermißt",
    "vermißten": "vermissen",
    "vermißter": "vermißt",
    "vermißtes": "vermißt",
    "vermißtest": "vermissen",
    "vermißtet": "vermissen",
    "vermumme": "vermummen",
    "vermummend": "vermummen",
    "vermummende": "vermummend",
    "vermummendem": "vermummend",
    "vermummenden": "vermummend",
    "vermummender": "vermummend",
    "vermummendes": "vermummend",
    "vermummest": "vermummen",
    "vermummet": "vermummen",
    "vermummst": "vermummen",
    "vermummt": "vermummen",
    "vermummte": "vermummen",
    "vermummtem": "vermummt",
    "vermummten": "vermummen",
    "vermummter": "vermummt",
    "vermummtere": "vermummt",
    "vermummterem": "vermummt",
    "vermummteren": "vermummt",
    "vermummterer": "vermummt",
    "vermummteres": "vermummt",
    "vermummtes": "vermummt",
    "vermummtest": "vermummen",
    "vermummteste": "vermummt",
    "vermummtestem": "vermummt",
    "vermummtesten": "vermummt",
    "vermummtester": "vermummt",
    "vermummtestes": "vermummt",
    "vermummtet": "vermummen",
    "vermurkse": "vermurksen",
    "vermurksend": "vermurksen",
    "vermurksende": "vermurksend",
    "vermurksendem": "vermurksend",
    "vermurksenden": "vermurksend",
    "vermurksender": "vermurksend",
    "vermurksendere": "vermurksend",
    "vermurksenderem": "vermurksend",
    "vermurksenderen": "vermurksend",
    "vermurksenderer": "vermurksend",
    "vermurksenderes": "vermurksend",
    "vermurksendes": "vermurksend",
    "vermurksendste": "vermurksend",
    "vermurksendstem": "vermurksend",
    "vermurksendsten": "vermurksend",
    "vermurksendster": "vermurksend",
    "vermurksendstes": "vermurksend",
    "vermurksest": "vermurksen",
    "vermurkset": "vermurksen",
    "vermurkst": "vermurksen",
    "vermurkste": "vermurksen",
    "vermurkstem": "vermurkst",
    "vermurksten": "vermurksen",
    "vermurkster": "vermurkst",
    "vermurkstere": "vermurkst",
    "vermurksterem": "vermurkst",
    "vermurksteren": "vermurkst",
    "vermurksterer": "vermurkst",
    "vermurksteres": "vermurkst",
    "vermurkstes": "vermurkst",
    "vermurkstest": "vermurksen",
    "vermurksteste": "vermurkst",
    "vermurkstestem": "vermurkst",
    "vermurkstesten": "vermurkst",
    "vermurkstester": "vermurkst",
    "vermurkstestes": "vermurkst",
    "vermurkstet": "vermurksen",
    "vermute": "vermuten",
    "vermutend": "vermuten",
    "vermutende": "vermutend",
    "vermutendem": "vermutend",
    "vermutenden": "vermutend",
    "vermutender": "vermutend",
    "vermutendes": "vermutend",
    "vermutest": "vermuten",
    "vermutet": "vermuten",
    "vermutete": "vermuten",
    "vermutetem": "vermutet",
    "vermuteten": "vermuten",
    "vermuteter": "vermutet",
    "vermutetes": "vermutet",
    "vermutetest": "vermuten",
    "vermutetet": "vermuten",
    "vermutliche": "vermutlich",
    "vermutlichem": "vermutlich",
    "vermutlichen": "vermutlich",
    "vermutlicher": "vermutlich",
    "vermutliches": "vermutlich",
    "vermähle": "vermählen",
    "vermählend": "vermählen",
    "vermählende": "vermählend",
    "vermählendem": "vermählend",
    "vermählenden": "vermählend",
    "vermählender": "vermählend",
    "vermählendes": "vermählend",
    "vermählest": "vermählen",
    "vermählet": "vermählen",
    "vermählst": "vermählen",
    "vermählt": "vermählen",
    "vermählte": "vermählen",
    "vermähltem": "vermählt",
    "vermählten": "vermählen",
    "vermählter": "vermählt",
    "vermähltes": "vermählt",
    "vermähltest": "vermählen",
    "vermähltet": "vermählen",
    "vermäße": "vermessen",
    "vermäßen": "vermessen",
    "vermäßest": "vermessen",
    "vermäßet": "vermessen",
    "vermöbele": "vermöbeln",
    "vermöbelnd": "vermöbeln",
    "vermöbelnde": "vermöbelnd",
    "vermöbelndem": "vermöbelnd",
    "vermöbelnden": "vermöbelnd",
    "vermöbelnder": "vermöbelnd",
    "vermöbelndes": "vermöbelnd",
    "vermöbelst": "vermöbeln",
    "vermöbelt": "vermöbeln",
    "vermöbelte": "vermöbeln",
    "vermöbeltem": "vermöbelt",
    "vermöbelten": "vermöbeln",
    "vermöbelter": "vermöbelt",
    "vermöbeltes": "vermöbelt",
    "vermöbeltest": "vermöbeln",
    "vermöbeltet": "vermöbeln",
    "vermöble": "vermöbeln",
    "vermögende": "vermögend",
    "vermögendem": "vermögend",
    "vermögenden": "vermögend",
    "vermögender": "vermögend",
    "vermögendere": "vermögend",
    "vermögenderem": "vermögend",
    "vermögenderen": "vermögend",
    "vermögenderer": "vermögend",
    "vermögenderes": "vermögend",
    "vermögendes": "vermögend",
    "vermögendste": "vermögend",
    "vermögendstem": "vermögend",
    "vermögendsten": "vermögend",
    "vermögendster": "vermögend",
    "vermögendstes": "vermögend",
    "vermögenswirksamem": "vermögenswirksam",
    "vermögenswirksamen": "vermögenswirksam",
    "vermögenswirksamer": "vermögenswirksam",
    "vermögenswirksames": "vermögenswirksam",
    "vernachlässige": "vernachlässigen",
    "vernachlässigend": "vernachlässigen",
    "vernachlässigende": "vernachlässigend",
    "vernachlässigendem": "vernachlässigend",
    "vernachlässigenden": "vernachlässigend",
    "vernachlässigender": "vernachlässigend",
    "vernachlässigendes": "vernachlässigend",
    "vernachlässigest": "vernachlässigen",
    "vernachlässiget": "vernachlässigen",
    "vernachlässigst": "vernachlässigen",
    "vernachlässigt": "vernachlässigen",
    "vernachlässigte": "vernachlässigen",
    "vernachlässigtem": "vernachlässigt",
    "vernachlässigten": "vernachlässigen",
    "vernachlässigter": "vernachlässigt",
    "vernachlässigtere": "vernachlässigt",
    "vernachlässigterem": "vernachlässigt",
    "vernachlässigteren": "vernachlässigt",
    "vernachlässigterer": "vernachlässigt",
    "vernachlässigteres": "vernachlässigt",
    "vernachlässigtes": "vernachlässigt",
    "vernachlässigtest": "vernachlässigen",
    "vernachlässigteste": "vernachlässigt",
    "vernachlässigtestem": "vernachlässigt",
    "vernachlässigtesten": "vernachlässigt",
    "vernachlässigtester": "vernachlässigt",
    "vernachlässigtestes": "vernachlässigt",
    "vernachlässigtet": "vernachlässigen",
    "vernagele": "vernageln",
    "vernagelnd": "vernageln",
    "vernagelnde": "vernagelnd",
    "vernagelndem": "vernagelnd",
    "vernagelnden": "vernagelnd",
    "vernagelnder": "vernagelnd",
    "vernagelndes": "vernagelnd",
    "vernagelst": "vernageln",
    "vernagelt": "vernageln",
    "vernagelte": "vernageln",
    "vernageltem": "vernagelt",
    "vernagelten": "vernageln",
    "vernagelter": "vernagelt",
    "vernageltere": "vernagelt",
    "vernagelterem": "vernagelt",
    "vernagelteren": "vernagelt",
    "vernagelterer": "vernagelt",
    "vernagelteres": "vernagelt",
    "vernageltes": "vernagelt",
    "vernageltest": "vernageln",
    "vernagelteste": "vernagelt",
    "vernageltestem": "vernagelt",
    "vernageltesten": "vernagelt",
    "vernageltester": "vernagelt",
    "vernageltestes": "vernagelt",
    "vernageltet": "vernageln",
    "vernagle": "vernageln",
    "vernahm": "vernehmen",
    "vernahmen": "vernehmen",
    "vernahmst": "vernehmen",
    "vernahmt": "vernehmen",
    "vernarbe": "vernarben",
    "vernarbend": "vernarben",
    "vernarbende": "vernarbend",
    "vernarbendem": "vernarbend",
    "vernarbenden": "vernarbend",
    "vernarbender": "vernarbend",
    "vernarbendere": "vernarbend",
    "vernarbenderem": "vernarbend",
    "vernarbenderen": "vernarbend",
    "vernarbenderer": "vernarbend",
    "vernarbenderes": "vernarbend",
    "vernarbendes": "vernarbend",
    "vernarbendste": "vernarbend",
    "vernarbendstem": "vernarbend",
    "vernarbendsten": "vernarbend",
    "vernarbendster": "vernarbend",
    "vernarbendstes": "vernarbend",
    "vernarbest": "vernarben",
    "vernarbet": "vernarben",
    "vernarbst": "vernarben",
    "vernarbt": "vernarben",
    "vernarbte": "vernarben",
    "vernarbtem": "vernarbt",
    "vernarbten": "vernarben",
    "vernarbter": "vernarbt",
    "vernarbtere": "vernarbt",
    "vernarbterem": "vernarbt",
    "vernarbteren": "vernarbt",
    "vernarbterer": "vernarbt",
    "vernarbteres": "vernarbt",
    "vernarbtes": "vernarbt",
    "vernarbtest": "vernarben",
    "vernarbteste": "vernarbt",
    "vernarbtestem": "vernarbt",
    "vernarbtesten": "vernarbt",
    "vernarbtester": "vernarbt",
    "vernarbtestes": "vernarbt",
    "vernarbtet": "vernarben",
    "vernarre": "vernarren",
    "vernarrend": "vernarren",
    "vernarrende": "vernarrend",
    "vernarrendem": "vernarrend",
    "vernarrenden": "vernarrend",
    "vernarrender": "vernarrend",
    "vernarrendere": "vernarrend",
    "vernarrenderem": "vernarrend",
    "vernarrenderen": "vernarrend",
    "vernarrenderer": "vernarrend",
    "vernarrenderes": "vernarrend",
    "vernarrendes": "vernarrend",
    "vernarrendste": "vernarrend",
    "vernarrendstem": "vernarrend",
    "vernarrendsten": "vernarrend",
    "vernarrendster": "vernarrend",
    "vernarrendstes": "vernarrend",
    "vernarrest": "vernarren",
    "vernarret": "vernarren",
    "vernarrst": "vernarren",
    "vernarrt": "vernarren",
    "vernarrte": "vernarren",
    "vernarrtem": "vernarrt",
    "vernarrten": "vernarren",
    "vernarrter": "vernarrt",
    "vernarrtere": "vernarrt",
    "vernarrterem": "vernarrt",
    "vernarrteren": "vernarrt",
    "vernarrterer": "vernarrt",
    "vernarrteres": "vernarrt",
    "vernarrtes": "vernarrt",
    "vernarrtest": "vernarren",
    "vernarrteste": "vernarrt",
    "vernarrtestem": "vernarrt",
    "vernarrtesten": "vernarrt",
    "vernarrtester": "vernarrt",
    "vernarrtestes": "vernarrt",
    "vernarrtet": "vernarren",
    "vernasche": "vernaschen",
    "vernaschend": "vernaschen",
    "vernaschende": "vernaschend",
    "vernaschendem": "vernaschend",
    "vernaschenden": "vernaschend",
    "vernaschender": "vernaschend",
    "vernaschendere": "vernaschend",
    "vernaschenderem": "vernaschend",
    "vernaschenderen": "vernaschend",
    "vernaschenderer": "vernaschend",
    "vernaschenderes": "vernaschend",
    "vernaschendes": "vernaschend",
    "vernaschendste": "vernaschend",
    "vernaschendstem": "vernaschend",
    "vernaschendsten": "vernaschend",
    "vernaschendster": "vernaschend",
    "vernaschendstes": "vernaschend",
    "vernaschest": "vernaschen",
    "vernaschet": "vernaschen",
    "vernaschst": "vernaschen",
    "vernascht": "vernaschen",
    "vernaschte": "vernaschen",
    "vernaschtem": "vernascht",
    "vernaschten": "vernaschen",
    "vernaschter": "vernascht",
    "vernaschtere": "vernascht",
    "vernaschterem": "vernascht",
    "vernaschteren": "vernascht",
    "vernaschterer": "vernascht",
    "vernaschteres": "vernascht",
    "vernaschtes": "vernascht",
    "vernaschtest": "vernaschen",
    "vernaschteste": "vernascht",
    "vernaschtestem": "vernascht",
    "vernaschtesten": "vernascht",
    "vernaschtester": "vernascht",
    "vernaschtestes": "vernascht",
    "vernaschtet": "vernaschen",
    "vernebele": "vernebeln",
    "vernebelnd": "vernebeln",
    "vernebelnde": "vernebelnd",
    "vernebelndem": "vernebelnd",
    "vernebelnden": "vernebelnd",
    "vernebelnder": "vernebelnd",
    "vernebelndere": "vernebelnd",
    "vernebelnderem": "vernebelnd",
    "vernebelnderen": "vernebelnd",
    "vernebelnderer": "vernebelnd",
    "vernebelnderes": "vernebelnd",
    "vernebelndes": "vernebelnd",
    "vernebelndste": "vernebelnd",
    "vernebelndstem": "vernebelnd",
    "vernebelndsten": "vernebelnd",
    "vernebelndster": "vernebelnd",
    "vernebelndstes": "vernebelnd",
    "vernebelst": "vernebeln",
    "vernebelt": "vernebeln",
    "vernebelte": "vernebeln",
    "vernebeltem": "vernebelt",
    "vernebelten": "vernebeln",
    "vernebelter": "vernebelt",
    "vernebeltere": "vernebelt",
    "vernebelterem": "vernebelt",
    "vernebelteren": "vernebelt",
    "vernebelterer": "vernebelt",
    "vernebelteres": "vernebelt",
    "vernebeltes": "vernebelt",
    "vernebeltest": "vernebeln",
    "vernebelteste": "vernebelt",
    "vernebeltestem": "vernebelt",
    "vernebeltesten": "vernebelt",
    "vernebeltester": "vernebelt",
    "vernebeltestes": "vernebelt",
    "vernebeltet": "vernebeln",
    "verneble": "vernebeln",
    "vernehme": "vernehmen",
    "vernehmend": "vernehmen",
    "vernehmende": "vernehmend",
    "vernehmendem": "vernehmend",
    "vernehmenden": "vernehmend",
    "vernehmender": "vernehmend",
    "vernehmendes": "vernehmend",
    "vernehmest": "vernehmen",
    "vernehmet": "vernehmen",
    "vernehmt": "vernehmen",
    "vernehmungsfähigem": "vernehmungsfähig",
    "vernehmungsfähigen": "vernehmungsfähig",
    "vernehmungsfähiger": "vernehmungsfähig",
    "vernehmungsfähiges": "vernehmungsfähig",
    "verneige": "verneigen",
    "verneigend": "verneigen",
    "verneigende": "verneigend",
    "verneigendem": "verneigend",
    "verneigenden": "verneigend",
    "verneigender": "verneigend",
    "verneigendes": "verneigend",
    "verneigest": "verneigen",
    "verneiget": "verneigen",
    "verneigst": "verneigen",
    "verneigt": "verneigen",
    "verneigte": "verneigen",
    "verneigtem": "verneigt",
    "verneigten": "verneigen",
    "verneigter": "verneigt",
    "verneigtes": "verneigt",
    "verneigtest": "verneigen",
    "verneigtet": "verneigen",
    "verneine": "verneinen",
    "verneinend": "verneinen",
    "verneinende": "verneinend",
    "verneinendem": "verneinend",
    "verneinenden": "verneinend",
    "verneinender": "verneinend",
    "verneinendes": "verneinend",
    "verneinest": "verneinen",
    "verneinet": "verneinen",
    "verneinst": "verneinen",
    "verneint": "verneinen",
    "verneinte": "verneinen",
    "verneintem": "verneint",
    "verneinten": "verneinen",
    "verneinter": "verneint",
    "verneintes": "verneint",
    "verneintest": "verneinen",
    "verneintet": "verneinen",
    "vernetze": "vernetzen",
    "vernetzend": "vernetzen",
    "vernetzende": "vernetzend",
    "vernetzendem": "vernetzend",
    "vernetzenden": "vernetzend",
    "vernetzender": "vernetzend",
    "vernetzendere": "vernetzend",
    "vernetzenderem": "vernetzend",
    "vernetzenderen": "vernetzend",
    "vernetzenderer": "vernetzend",
    "vernetzenderes": "vernetzend",
    "vernetzendes": "vernetzend",
    "vernetzendste": "vernetzend",
    "vernetzendstem": "vernetzend",
    "vernetzendsten": "vernetzend",
    "vernetzendster": "vernetzend",
    "vernetzendstes": "vernetzend",
    "vernetzest": "vernetzen",
    "vernetzet": "vernetzen",
    "vernetzt": "vernetzen",
    "vernetzte": "vernetzen",
    "vernetztem": "vernetzt",
    "vernetzten": "vernetzen",
    "vernetzter": "vernetzt",
    "vernetztere": "vernetzt",
    "vernetzterem": "vernetzt",
    "vernetzteren": "vernetzt",
    "vernetzterer": "vernetzt",
    "vernetzteres": "vernetzt",
    "vernetztes": "vernetzt",
    "vernetztest": "vernetzen",
    "vernetzteste": "vernetzt",
    "vernetztestem": "vernetzt",
    "vernetztesten": "vernetzt",
    "vernetztester": "vernetzt",
    "vernetztestes": "vernetzt",
    "vernetztet": "vernetzen",
    "vernichte": "vernichten",
    "vernichtend": "vernichten",
    "vernichtende": "vernichtend",
    "vernichtendem": "vernichtend",
    "vernichtenden": "vernichtend",
    "vernichtender": "vernichtend",
    "vernichtendere": "vernichtend",
    "vernichtenderem": "vernichtend",
    "vernichtenderen": "vernichtend",
    "vernichtenderer": "vernichtend",
    "vernichtenderes": "vernichtend",
    "vernichtendes": "vernichtend",
    "vernichtendste": "vernichtend",
    "vernichtendstem": "vernichtend",
    "vernichtendsten": "vernichtend",
    "vernichtendster": "vernichtend",
    "vernichtendstes": "vernichtend",
    "vernichtest": "vernichten",
    "vernichtet": "vernichten",
    "vernichtete": "vernichten",
    "vernichtetem": "vernichtet",
    "vernichteten": "vernichten",
    "vernichteter": "vernichtet",
    "vernichtetes": "vernichtet",
    "vernichtetest": "vernichten",
    "vernichtetet": "vernichten",
    "verniedlichend": "verniedlichen",
    "verniedlichende": "verniedlichend",
    "verniedlichendem": "verniedlichend",
    "verniedlichenden": "verniedlichend",
    "verniedlichender": "verniedlichend",
    "verniedlichendere": "verniedlichend",
    "verniedlichenderem": "verniedlichend",
    "verniedlichenderen": "verniedlichend",
    "verniedlichenderer": "verniedlichend",
    "verniedlichenderes": "verniedlichend",
    "verniedlichendes": "verniedlichend",
    "verniedlichendste": "verniedlichend",
    "verniedlichendstem": "verniedlichend",
    "verniedlichendsten": "verniedlichend",
    "verniedlichendster": "verniedlichend",
    "verniedlichendstes": "verniedlichend",
    "verniedlichest": "verniedlichen",
    "verniedlichet": "verniedlichen",
    "verniedlichst": "verniedlichen",
    "verniedlicht": "verniedlichen",
    "verniedlichte": "verniedlichen",
    "verniedlichtem": "verniedlicht",
    "verniedlichten": "verniedlichen",
    "verniedlichter": "verniedlicht",
    "verniedlichtere": "verniedlicht",
    "verniedlichterem": "verniedlicht",
    "verniedlichteren": "verniedlicht",
    "verniedlichterer": "verniedlicht",
    "verniedlichteres": "verniedlicht",
    "verniedlichtes": "verniedlicht",
    "verniedlichtest": "verniedlichen",
    "verniedlichteste": "verniedlicht",
    "verniedlichtestem": "verniedlicht",
    "verniedlichtesten": "verniedlicht",
    "verniedlichtester": "verniedlicht",
    "verniedlichtestes": "verniedlicht",
    "verniedlichtet": "verniedlichen",
    "verniete": "vernieten",
    "vernietend": "vernieten",
    "vernietende": "vernietend",
    "vernietendem": "vernietend",
    "vernietenden": "vernietend",
    "vernietender": "vernietend",
    "vernietendes": "vernietend",
    "vernietest": "vernieten",
    "vernietet": "vernieten",
    "vernietete": "vernieten",
    "vernietetem": "vernietet",
    "vernieteten": "vernieten",
    "vernieteter": "vernietet",
    "vernietetes": "vernietet",
    "vernietetest": "vernieten",
    "vernietetet": "vernieten",
    "vernimm": "vernehmen",
    "vernimmst": "vernehmen",
    "vernimmt": "vernehmen",
    "vernommen": "vernehmen",
    "vernommene": "vernommen",
    "vernommenem": "vernommen",
    "vernommenen": "vernommen",
    "vernommener": "vernommen",
    "vernommenere": "vernommen",
    "vernommenerem": "vernommen",
    "vernommeneren": "vernommen",
    "vernommenerer": "vernommen",
    "vernommeneres": "vernommen",
    "vernommenes": "vernommen",
    "vernommenste": "vernommen",
    "vernommenstem": "vernommen",
    "vernommensten": "vernommen",
    "vernommenster": "vernommen",
    "vernommenstes": "vernommen",
    "vernähe": "vernähen",
    "vernähend": "vernähen",
    "vernähende": "vernähend",
    "vernähendem": "vernähend",
    "vernähenden": "vernähend",
    "vernähender": "vernähend",
    "vernähendes": "vernähend",
    "vernähest": "vernähen",
    "vernähet": "vernähen",
    "vernähme": "vernehmen",
    "vernähmen": "vernehmen",
    "vernähmest": "vernehmen",
    "vernähmet": "vernehmen",
    "vernähst": "vernähen",
    "vernäht": "vernähen",
    "vernähte": "vernähen",
    "vernähtem": "vernäht",
    "vernähten": "vernähen",
    "vernähter": "vernäht",
    "vernähtes": "vernäht",
    "vernähtest": "vernähen",
    "vernähtet": "vernähen",
    "vernünftige": "vernünftig",
    "vernünftigem": "vernünftig",
    "vernünftigen": "vernünftig",
    "vernünftiger": "vernünftig",
    "vernünftigere": "vernünftig",
    "vernünftigerem": "vernünftig",
    "vernünftigeren": "vernünftig",
    "vernünftigerer": "vernünftig",
    "vernünftigeres": "vernünftig",
    "vernünftiges": "vernünftig",
    "vernünftigste": "vernünftig",
    "vernünftigstem": "vernünftig",
    "vernünftigsten": "vernünftig",
    "vernünftigster": "vernünftig",
    "vernünftigstes": "vernünftig",
    "verordne": "verordnen",
    "verordnend": "verordnen",
    "verordnende": "verordnend",
    "verordnendem": "verordnend",
    "verordnenden": "verordnend",
    "verordnender": "verordnend",
    "verordnendes": "verordnend",
    "verordnest": "verordnen",
    "verordnet": "verordnen",
    "verordnete": "verordnen",
    "verordnetem": "verordnet",
    "verordneten": "verordnen",
    "verordneter": "verordnet",
    "verordnetes": "verordnet",
    "verordnetest": "verordnen",
    "verordnetet": "verordnen",
    "verpachte": "verpachten",
    "verpachtend": "verpachten",
    "verpachtende": "verpachtend",
    "verpachtendem": "verpachtend",
    "verpachtenden": "verpachtend",
    "verpachtender": "verpachtend",
    "verpachtendes": "verpachtend",
    "verpachtest": "verpachten",
    "verpachtet": "verpachten",
    "verpachtete": "verpachten",
    "verpachtetem": "verpachtet",
    "verpachteten": "verpachten",
    "verpachteter": "verpachtet",
    "verpachtetes": "verpachtet",
    "verpachtetest": "verpachten",
    "verpachtetet": "verpachten",
    "verpacke": "verpacken",
    "verpackend": "verpacken",
    "verpackende": "verpackend",
    "verpackendem": "verpackend",
    "verpackenden": "verpackend",
    "verpackender": "verpackend",
    "verpackendes": "verpackend",
    "verpackest": "verpacken",
    "verpacket": "verpacken",
    "verpackst": "verpacken",
    "verpackt": "verpacken",
    "verpackte": "verpacken",
    "verpacktem": "verpackt",
    "verpackten": "verpacken",
    "verpackter": "verpackt",
    "verpacktere": "verpackt",
    "verpackterem": "verpackt",
    "verpackteren": "verpackt",
    "verpackterer": "verpackt",
    "verpackteres": "verpackt",
    "verpacktes": "verpackt",
    "verpacktest": "verpacken",
    "verpackteste": "verpackt",
    "verpacktestem": "verpackt",
    "verpacktesten": "verpackt",
    "verpacktester": "verpackt",
    "verpacktestes": "verpackt",
    "verpacktet": "verpacken",
    "verpasse": "verpassen",
    "verpassend": "verpassen",
    "verpassende": "verpassend",
    "verpassendem": "verpassend",
    "verpassenden": "verpassend",
    "verpassender": "verpassend",
    "verpassendes": "verpassend",
    "verpassest": "verpassen",
    "verpasset": "verpassen",
    "verpatze": "verpatzen",
    "verpatzend": "verpatzen",
    "verpatzende": "verpatzend",
    "verpatzendem": "verpatzend",
    "verpatzenden": "verpatzend",
    "verpatzender": "verpatzend",
    "verpatzendere": "verpatzend",
    "verpatzenderem": "verpatzend",
    "verpatzenderen": "verpatzend",
    "verpatzenderer": "verpatzend",
    "verpatzenderes": "verpatzend",
    "verpatzendes": "verpatzend",
    "verpatzendste": "verpatzend",
    "verpatzendstem": "verpatzend",
    "verpatzendsten": "verpatzend",
    "verpatzendster": "verpatzend",
    "verpatzendstes": "verpatzend",
    "verpatzest": "verpatzen",
    "verpatzet": "verpatzen",
    "verpatzt": "verpatzen",
    "verpatzte": "verpatzen",
    "verpatztem": "verpatzt",
    "verpatzten": "verpatzen",
    "verpatzter": "verpatzt",
    "verpatztere": "verpatzt",
    "verpatzterem": "verpatzt",
    "verpatzteren": "verpatzt",
    "verpatzterer": "verpatzt",
    "verpatzteres": "verpatzt",
    "verpatztes": "verpatzt",
    "verpatztest": "verpatzen",
    "verpatzteste": "verpatzt",
    "verpatztestem": "verpatzt",
    "verpatztesten": "verpatzt",
    "verpatztester": "verpatzt",
    "verpatztestes": "verpatzt",
    "verpatztet": "verpatzen",
    "verpaßt": "verpassen",
    "verpaßte": "verpassen",
    "verpaßtem": "verpaßt",
    "verpaßten": "verpassen",
    "verpaßter": "verpaßt",
    "verpaßtes": "verpaßt",
    "verpaßtest": "verpassen",
    "verpaßtet": "verpassen",
    "verpenne": "verpennen",
    "verpennend": "verpennen",
    "verpennende": "verpennend",
    "verpennendem": "verpennend",
    "verpennenden": "verpennend",
    "verpennender": "verpennend",
    "verpennendes": "verpennend",
    "verpennest": "verpennen",
    "verpennet": "verpennen",
    "verpennst": "verpennen",
    "verpennt": "verpennen",
    "verpennte": "verpennen",
    "verpenntem": "verpennt",
    "verpennten": "verpennen",
    "verpennter": "verpennt",
    "verpenntes": "verpennt",
    "verpenntest": "verpennen",
    "verpenntet": "verpennen",
    "verpeste": "verpesten",
    "verpestend": "verpesten",
    "verpestende": "verpestend",
    "verpestendem": "verpestend",
    "verpestenden": "verpestend",
    "verpestender": "verpestend",
    "verpestendes": "verpestend",
    "verpestest": "verpesten",
    "verpestet": "verpesten",
    "verpestete": "verpesten",
    "verpestetem": "verpestet",
    "verpesteten": "verpesten",
    "verpesteter": "verpestet",
    "verpestetes": "verpestet",
    "verpestetest": "verpesten",
    "verpestetet": "verpesten",
    "verpetze": "verpetzen",
    "verpetzend": "verpetzen",
    "verpetzende": "verpetzend",
    "verpetzendem": "verpetzend",
    "verpetzenden": "verpetzend",
    "verpetzender": "verpetzend",
    "verpetzendere": "verpetzend",
    "verpetzenderem": "verpetzend",
    "verpetzenderen": "verpetzend",
    "verpetzenderer": "verpetzend",
    "verpetzenderes": "verpetzend",
    "verpetzendes": "verpetzend",
    "verpetzendste": "verpetzend",
    "verpetzendstem": "verpetzend",
    "verpetzendsten": "verpetzend",
    "verpetzendster": "verpetzend",
    "verpetzendstes": "verpetzend",
    "verpetzest": "verpetzen",
    "verpetzet": "verpetzen",
    "verpetzt": "verpetzen",
    "verpetzte": "verpetzen",
    "verpetztem": "verpetzt",
    "verpetzten": "verpetzen",
    "verpetzter": "verpetzt",
    "verpetztes": "verpetzt",
    "verpetztest": "verpetzen",
    "verpetztet": "verpetzen",
    "verpfeffere": "verpfeffern",
    "verpfeffernd": "verpfeffern",
    "verpfeffernde": "verpfeffernd",
    "verpfefferndem": "verpfeffernd",
    "verpfeffernden": "verpfeffernd",
    "verpfeffernder": "verpfeffernd",
    "verpfefferndere": "verpfeffernd",
    "verpfeffernderem": "verpfeffernd",
    "verpfeffernderen": "verpfeffernd",
    "verpfeffernderer": "verpfeffernd",
    "verpfeffernderes": "verpfeffernd",
    "verpfefferndes": "verpfeffernd",
    "verpfefferndste": "verpfeffernd",
    "verpfefferndstem": "verpfeffernd",
    "verpfefferndsten": "verpfeffernd",
    "verpfefferndster": "verpfeffernd",
    "verpfefferndstes": "verpfeffernd",
    "verpfefferst": "verpfeffern",
    "verpfeffert": "verpfeffern",
    "verpfefferte": "verpfeffern",
    "verpfeffertem": "verpfeffert",
    "verpfefferten": "verpfeffern",
    "verpfefferter": "verpfeffert",
    "verpfeffertere": "verpfeffert",
    "verpfefferterem": "verpfeffert",
    "verpfefferteren": "verpfeffert",
    "verpfefferterer": "verpfeffert",
    "verpfefferteres": "verpfeffert",
    "verpfeffertes": "verpfeffert",
    "verpfeffertest": "verpfeffern",
    "verpfefferteste": "verpfeffert",
    "verpfeffertestem": "verpfeffert",
    "verpfeffertesten": "verpfeffert",
    "verpfeffertester": "verpfeffert",
    "verpfeffertestes": "verpfeffert",
    "verpfeffertet": "verpfeffern",
    "verpfeife": "verpfeifen",
    "verpfeifend": "verpfeifen",
    "verpfeifende": "verpfeifend",
    "verpfeifendem": "verpfeifend",
    "verpfeifenden": "verpfeifend",
    "verpfeifender": "verpfeifend",
    "verpfeifendere": "verpfeifend",
    "verpfeifenderem": "verpfeifend",
    "verpfeifenderen": "verpfeifend",
    "verpfeifenderer": "verpfeifend",
    "verpfeifenderes": "verpfeifend",
    "verpfeifendes": "verpfeifend",
    "verpfeifendste": "verpfeifend",
    "verpfeifendstem": "verpfeifend",
    "verpfeifendsten": "verpfeifend",
    "verpfeifendster": "verpfeifend",
    "verpfeifendstes": "verpfeifend",
    "verpfeifest": "verpfeifen",
    "verpfeifet": "verpfeifen",
    "verpfeifst": "verpfeifen",
    "verpfeift": "verpfeifen",
    "verpfiff": "verpfeifen",
    "verpfiffe": "verpfeifen",
    "verpfiffen": "verpfeifen",
    "verpfiffene": "verpfiffen",
    "verpfiffenem": "verpfiffen",
    "verpfiffenen": "verpfiffen",
    "verpfiffener": "verpfiffen",
    "verpfiffenere": "verpfiffen",
    "verpfiffenerem": "verpfiffen",
    "verpfiffeneren": "verpfiffen",
    "verpfiffenerer": "verpfiffen",
    "verpfiffeneres": "verpfiffen",
    "verpfiffenes": "verpfiffen",
    "verpfiffenste": "verpfiffen",
    "verpfiffenstem": "verpfiffen",
    "verpfiffensten": "verpfiffen",
    "verpfiffenster": "verpfiffen",
    "verpfiffenstes": "verpfiffen",
    "verpfiffest": "verpfeifen",
    "verpfiffet": "verpfeifen",
    "verpfiffst": "verpfeifen",
    "verpfifft": "verpfeifen",
    "verpflanze": "verpflanzen",
    "verpflanzend": "verpflanzen",
    "verpflanzende": "verpflanzend",
    "verpflanzendem": "verpflanzend",
    "verpflanzenden": "verpflanzend",
    "verpflanzender": "verpflanzend",
    "verpflanzendes": "verpflanzend",
    "verpflanzest": "verpflanzen",
    "verpflanzet": "verpflanzen",
    "verpflanzt": "verpflanzen",
    "verpflanzte": "verpflanzen",
    "verpflanztem": "verpflanzt",
    "verpflanzten": "verpflanzen",
    "verpflanzter": "verpflanzt",
    "verpflanztes": "verpflanzt",
    "verpflanztest": "verpflanzen",
    "verpflanztet": "verpflanzen",
    "verpflege": "verpflegen",
    "verpflegend": "verpflegen",
    "verpflegende": "verpflegend",
    "verpflegendem": "verpflegend",
    "verpflegenden": "verpflegend",
    "verpflegender": "verpflegend",
    "verpflegendes": "verpflegend",
    "verpflegest": "verpflegen",
    "verpfleget": "verpflegen",
    "verpflegst": "verpflegen",
    "verpflegt": "verpflegen",
    "verpflegte": "verpflegen",
    "verpflegtem": "verpflegt",
    "verpflegten": "verpflegen",
    "verpflegter": "verpflegt",
    "verpflegtere": "verpflegt",
    "verpflegterem": "verpflegt",
    "verpflegteren": "verpflegt",
    "verpflegterer": "verpflegt",
    "verpflegteres": "verpflegt",
    "verpflegtes": "verpflegt",
    "verpflegtest": "verpflegen",
    "verpflegteste": "verpflegt",
    "verpflegtestem": "verpflegt",
    "verpflegtesten": "verpflegt",
    "verpflegtester": "verpflegt",
    "verpflegtestes": "verpflegt",
    "verpflegtet": "verpflegen",
    "verpflichte": "verpflichten",
    "verpflichtend": "verpflichten",
    "verpflichtende": "verpflichtend",
    "verpflichtendem": "verpflichtend",
    "verpflichtenden": "verpflichtend",
    "verpflichtender": "verpflichtend",
    "verpflichtendes": "verpflichtend",
    "verpflichtest": "verpflichten",
    "verpflichtet": "verpflichten",
    "verpflichtete": "verpflichten",
    "verpflichtetem": "verpflichtet",
    "verpflichteten": "verpflichten",
    "verpflichteter": "verpflichtet",
    "verpflichtetes": "verpflichtet",
    "verpflichtetest": "verpflichten",
    "verpflichtetet": "verpflichten",
    "verpfusche": "verpfuschen",
    "verpfuschend": "verpfuschen",
    "verpfuschende": "verpfuschend",
    "verpfuschendem": "verpfuschend",
    "verpfuschenden": "verpfuschend",
    "verpfuschender": "verpfuschend",
    "verpfuschendere": "verpfuschend",
    "verpfuschenderem": "verpfuschend",
    "verpfuschenderen": "verpfuschend",
    "verpfuschenderer": "verpfuschend",
    "verpfuschenderes": "verpfuschend",
    "verpfuschendes": "verpfuschend",
    "verpfuschendste": "verpfuschend",
    "verpfuschendstem": "verpfuschend",
    "verpfuschendsten": "verpfuschend",
    "verpfuschendster": "verpfuschend",
    "verpfuschendstes": "verpfuschend",
    "verpfuschest": "verpfuschen",
    "verpfuschet": "verpfuschen",
    "verpfuschst": "verpfuschen",
    "verpfuscht": "verpfuschen",
    "verpfuschte": "verpfuschen",
    "verpfuschtem": "verpfuscht",
    "verpfuschten": "verpfuschen",
    "verpfuschter": "verpfuscht",
    "verpfuschtere": "verpfuscht",
    "verpfuschterem": "verpfuscht",
    "verpfuschteren": "verpfuscht",
    "verpfuschterer": "verpfuscht",
    "verpfuschteres": "verpfuscht",
    "verpfuschtes": "verpfuscht",
    "verpfuschtest": "verpfuschen",
    "verpfuschteste": "verpfuscht",
    "verpfuschtestem": "verpfuscht",
    "verpfuschtesten": "verpfuscht",
    "verpfuschtester": "verpfuscht",
    "verpfuschtestes": "verpfuscht",
    "verpfuschtet": "verpfuschen",
    "verpfände": "verpfänden",
    "verpfändend": "verpfänden",
    "verpfändende": "verpfändend",
    "verpfändendem": "verpfändend",
    "verpfändenden": "verpfändend",
    "verpfändender": "verpfändend",
    "verpfändendes": "verpfändend",
    "verpfändest": "verpfänden",
    "verpfändet": "verpfänden",
    "verpfändete": "verpfänden",
    "verpfändetem": "verpfändet",
    "verpfändeten": "verpfänden",
    "verpfändeter": "verpfändet",
    "verpfändetes": "verpfändet",
    "verpfändetest": "verpfänden",
    "verpfändetet": "verpfänden",
    "verpisse": "verpissen",
    "verpissend": "verpissen",
    "verpissende": "verpissend",
    "verpissendem": "verpissend",
    "verpissenden": "verpissend",
    "verpissender": "verpissend",
    "verpissendere": "verpissend",
    "verpissenderem": "verpissend",
    "verpissenderen": "verpissend",
    "verpissenderer": "verpissend",
    "verpissenderes": "verpissend",
    "verpissendes": "verpissend",
    "verpissendste": "verpissend",
    "verpissendstem": "verpissend",
    "verpissendsten": "verpissend",
    "verpissendster": "verpissend",
    "verpissendstes": "verpissend",
    "verpissest": "verpissen",
    "verpisset": "verpissen",
    "verpißt": "verpissen",
    "verpißte": "verpissen",
    "verpißtem": "verpißt",
    "verpißten": "verpissen",
    "verpißter": "verpißt",
    "verpißtes": "verpißt",
    "verpißtest": "verpissen",
    "verpißtet": "verpissen",
    "verplane": "verplanen",
    "verplanend": "verplanen",
    "verplanende": "verplanend",
    "verplanendem": "verplanend",
    "verplanenden": "verplanend",
    "verplanender": "verplanend",
    "verplanendes": "verplanend",
    "verplanest": "verplanen",
    "verplanet": "verplanen",
    "verplanst": "verplanen",
    "verplant": "verplanen",
    "verplante": "verplanen",
    "verplantem": "verplant",
    "verplanten": "verplanen",
    "verplanter": "verplant",
    "verplantere": "verplant",
    "verplanterem": "verplant",
    "verplanteren": "verplant",
    "verplanterer": "verplant",
    "verplanteres": "verplant",
    "verplantes": "verplant",
    "verplantest": "verplanen",
    "verplanteste": "verplant",
    "verplantestem": "verplant",
    "verplantesten": "verplant",
    "verplantester": "verplant",
    "verplantestes": "verplant",
    "verplantet": "verplanen",
    "verplappere": "verplappern",
    "verplappernd": "verplappern",
    "verplappernde": "verplappernd",
    "verplapperndem": "verplappernd",
    "verplappernden": "verplappernd",
    "verplappernder": "verplappernd",
    "verplapperndere": "verplappernd",
    "verplappernderem": "verplappernd",
    "verplappernderen": "verplappernd",
    "verplappernderer": "verplappernd",
    "verplappernderes": "verplappernd",
    "verplapperndes": "verplappernd",
    "verplapperndste": "verplappernd",
    "verplapperndstem": "verplappernd",
    "verplapperndsten": "verplappernd",
    "verplapperndster": "verplappernd",
    "verplapperndstes": "verplappernd",
    "verplapperst": "verplappern",
    "verplappert": "verplappern",
    "verplapperte": "verplappern",
    "verplappertem": "verplappert",
    "verplapperten": "verplappern",
    "verplapperter": "verplappert",
    "verplappertes": "verplappert",
    "verplappertest": "verplappern",
    "verplappertet": "verplappern",
    "verplaudere": "verplaudern",
    "verplaudernd": "verplaudern",
    "verplaudernde": "verplaudernd",
    "verplauderndem": "verplaudernd",
    "verplaudernden": "verplaudernd",
    "verplaudernder": "verplaudernd",
    "verplauderndere": "verplaudernd",
    "verplaudernderem": "verplaudernd",
    "verplaudernderen": "verplaudernd",
    "verplaudernderer": "verplaudernd",
    "verplaudernderes": "verplaudernd",
    "verplauderndes": "verplaudernd",
    "verplauderndste": "verplaudernd",
    "verplauderndstem": "verplaudernd",
    "verplauderndsten": "verplaudernd",
    "verplauderndster": "verplaudernd",
    "verplauderndstes": "verplaudernd",
    "verplauderst": "verplaudern",
    "verplaudert": "verplaudern",
    "verplauderte": "verplaudern",
    "verplaudertem": "verplaudert",
    "verplauderten": "verplaudern",
    "verplauderter": "verplaudert",
    "verplaudertes": "verplaudert",
    "verplaudertest": "verplaudern",
    "verplaudertet": "verplaudern",
    "verplempere": "verplempern",
    "verplempernd": "verplempern",
    "verplempernde": "verplempernd",
    "verplemperndem": "verplempernd",
    "verplempernden": "verplempernd",
    "verplempernder": "verplempernd",
    "verplemperndere": "verplempernd",
    "verplempernderem": "verplempernd",
    "verplempernderen": "verplempernd",
    "verplempernderer": "verplempernd",
    "verplempernderes": "verplempernd",
    "verplemperndes": "verplempernd",
    "verplemperndste": "verplempernd",
    "verplemperndstem": "verplempernd",
    "verplemperndsten": "verplempernd",
    "verplemperndster": "verplempernd",
    "verplemperndstes": "verplempernd",
    "verplemperst": "verplempern",
    "verplempert": "verplempern",
    "verplemperte": "verplempern",
    "verplempertem": "verplempert",
    "verplemperten": "verplempern",
    "verplemperter": "verplempert",
    "verplempertere": "verplempert",
    "verplemperterem": "verplempert",
    "verplemperteren": "verplempert",
    "verplemperterer": "verplempert",
    "verplemperteres": "verplempert",
    "verplempertes": "verplempert",
    "verplempertest": "verplempern",
    "verplemperteste": "verplempert",
    "verplempertestem": "verplempert",
    "verplempertesten": "verplempert",
    "verplempertester": "verplempert",
    "verplempertestes": "verplempert",
    "verplempertet": "verplempern",
    "verplombe": "verplomben",
    "verplombend": "verplomben",
    "verplombende": "verplombend",
    "verplombendem": "verplombend",
    "verplombenden": "verplombend",
    "verplombender": "verplombend",
    "verplombendes": "verplombend",
    "verplombest": "verplomben",
    "verplombet": "verplomben",
    "verplombst": "verplomben",
    "verplombt": "verplomben",
    "verplombte": "verplomben",
    "verplombtem": "verplombt",
    "verplombten": "verplomben",
    "verplombter": "verplombt",
    "verplombtes": "verplombt",
    "verplombtest": "verplomben",
    "verplombtet": "verplomben",
    "verpokere": "verpokern",
    "verpokernd": "verpokern",
    "verpokernde": "verpokernd",
    "verpokerndem": "verpokernd",
    "verpokernden": "verpokernd",
    "verpokernder": "verpokernd",
    "verpokerndere": "verpokernd",
    "verpokernderem": "verpokernd",
    "verpokernderen": "verpokernd",
    "verpokernderer": "verpokernd",
    "verpokernderes": "verpokernd",
    "verpokerndes": "verpokernd",
    "verpokerndste": "verpokernd",
    "verpokerndstem": "verpokernd",
    "verpokerndsten": "verpokernd",
    "verpokerndster": "verpokernd",
    "verpokerndstes": "verpokernd",
    "verpokerst": "verpokern",
    "verpokert": "verpokern",
    "verpokerte": "verpokern",
    "verpokertem": "verpokert",
    "verpokerten": "verpokern",
    "verpokerter": "verpokert",
    "verpokertes": "verpokert",
    "verpokertest": "verpokern",
    "verpokertet": "verpokern",
    "verprasse": "verprassen",
    "verprassend": "verprassen",
    "verprassende": "verprassend",
    "verprassendem": "verprassend",
    "verprassenden": "verprassend",
    "verprassender": "verprassend",
    "verprassendere": "verprassend",
    "verprassenderem": "verprassend",
    "verprassenderen": "verprassend",
    "verprassenderer": "verprassend",
    "verprassenderes": "verprassend",
    "verprassendes": "verprassend",
    "verprassendste": "verprassend",
    "verprassendstem": "verprassend",
    "verprassendsten": "verprassend",
    "verprassendster": "verprassend",
    "verprassendstes": "verprassend",
    "verprassest": "verprassen",
    "verprasset": "verprassen",
    "verpraßt": "verprassen",
    "verpraßte": "verprassen",
    "verpraßtem": "verpraßt",
    "verpraßten": "verprassen",
    "verpraßter": "verpraßt",
    "verpraßtere": "verpraßt",
    "verpraßterem": "verpraßt",
    "verpraßteren": "verpraßt",
    "verpraßterer": "verpraßt",
    "verpraßteres": "verpraßt",
    "verpraßtes": "verpraßt",
    "verpraßtest": "verprassen",
    "verpraßteste": "verpraßt",
    "verpraßtestem": "verpraßt",
    "verpraßtesten": "verpraßt",
    "verpraßtester": "verpraßt",
    "verpraßtestes": "verpraßt",
    "verpraßtet": "verprassen",
    "verprelle": "verprellen",
    "verprellend": "verprellen",
    "verprellende": "verprellend",
    "verprellendem": "verprellend",
    "verprellenden": "verprellend",
    "verprellender": "verprellend",
    "verprellendere": "verprellend",
    "verprellenderem": "verprellend",
    "verprellenderen": "verprellend",
    "verprellenderer": "verprellend",
    "verprellenderes": "verprellend",
    "verprellendes": "verprellend",
    "verprellendste": "verprellend",
    "verprellendstem": "verprellend",
    "verprellendsten": "verprellend",
    "verprellendster": "verprellend",
    "verprellendstes": "verprellend",
    "verprellest": "verprellen",
    "verprellet": "verprellen",
    "verprellst": "verprellen",
    "verprellt": "verprellen",
    "verprellte": "verprellen",
    "verprelltem": "verprellt",
    "verprellten": "verprellen",
    "verprellter": "verprellt",
    "verprelltere": "verprellt",
    "verprellterem": "verprellt",
    "verprellteren": "verprellt",
    "verprellterer": "verprellt",
    "verprellteres": "verprellt",
    "verprelltes": "verprellt",
    "verprelltest": "verprellen",
    "verprellteste": "verprellt",
    "verprelltestem": "verprellt",
    "verprelltesten": "verprellt",
    "verprelltester": "verprellt",
    "verprelltestes": "verprellt",
    "verprelltet": "verprellen",
    "verprügele": "verprügeln",
    "verprügelnd": "verprügeln",
    "verprügelnde": "verprügelnd",
    "verprügelndem": "verprügelnd",
    "verprügelnden": "verprügelnd",
    "verprügelnder": "verprügelnd",
    "verprügelndes": "verprügelnd",
    "verprügelst": "verprügeln",
    "verprügelt": "verprügeln",
    "verprügelte": "verprügeln",
    "verprügeltem": "verprügelt",
    "verprügelten": "verprügeln",
    "verprügelter": "verprügelt",
    "verprügeltes": "verprügelt",
    "verprügeltest": "verprügeln",
    "verprügeltet": "verprügeln",
    "verprügle": "verprügeln",
    "verpuffe": "verpuffen",
    "verpuffend": "verpuffen",
    "verpuffende": "verpuffend",
    "verpuffendem": "verpuffend",
    "verpuffenden": "verpuffend",
    "verpuffender": "verpuffend",
    "verpuffendere": "verpuffend",
    "verpuffenderem": "verpuffend",
    "verpuffenderen": "verpuffend",
    "verpuffenderer": "verpuffend",
    "verpuffenderes": "verpuffend",
    "verpuffendes": "verpuffend",
    "verpuffendste": "verpuffend",
    "verpuffendstem": "verpuffend",
    "verpuffendsten": "verpuffend",
    "verpuffendster": "verpuffend",
    "verpuffendstes": "verpuffend",
    "verpuffest": "verpuffen",
    "verpuffet": "verpuffen",
    "verpuffst": "verpuffen",
    "verpufft": "verpuffen",
    "verpuffte": "verpuffen",
    "verpufftem": "verpufft",
    "verpufften": "verpuffen",
    "verpuffter": "verpufft",
    "verpufftere": "verpufft",
    "verpuffterem": "verpufft",
    "verpuffteren": "verpufft",
    "verpuffterer": "verpufft",
    "verpuffteres": "verpufft",
    "verpufftes": "verpufft",
    "verpufftest": "verpuffen",
    "verpuffteste": "verpufft",
    "verpufftestem": "verpufft",
    "verpufftesten": "verpufft",
    "verpufftester": "verpufft",
    "verpufftestes": "verpufft",
    "verpufftet": "verpuffen",
    "verpulvere": "verpulvern",
    "verpulvernd": "verpulvern",
    "verpulvernde": "verpulvernd",
    "verpulverndem": "verpulvernd",
    "verpulvernden": "verpulvernd",
    "verpulvernder": "verpulvernd",
    "verpulverndere": "verpulvernd",
    "verpulvernderem": "verpulvernd",
    "verpulvernderen": "verpulvernd",
    "verpulvernderer": "verpulvernd",
    "verpulvernderes": "verpulvernd",
    "verpulverndes": "verpulvernd",
    "verpulverndste": "verpulvernd",
    "verpulverndstem": "verpulvernd",
    "verpulverndsten": "verpulvernd",
    "verpulverndster": "verpulvernd",
    "verpulverndstes": "verpulvernd",
    "verpulverst": "verpulvern",
    "verpulvert": "verpulvern",
    "verpulverte": "verpulvern",
    "verpulvertem": "verpulvert",
    "verpulverten": "verpulvern",
    "verpulverter": "verpulvert",
    "verpulvertere": "verpulvert",
    "verpulverterem": "verpulvert",
    "verpulverteren": "verpulvert",
    "verpulverterer": "verpulvert",
    "verpulverteres": "verpulvert",
    "verpulvertes": "verpulvert",
    "verpulvertest": "verpulvern",
    "verpulverteste": "verpulvert",
    "verpulvertestem": "verpulvert",
    "verpulvertesten": "verpulvert",
    "verpulvertester": "verpulvert",
    "verpulvertestes": "verpulvert",
    "verpulvertet": "verpulvern",
    "verpuppe": "verpuppen",
    "verpuppend": "verpuppen",
    "verpuppende": "verpuppend",
    "verpuppendem": "verpuppend",
    "verpuppenden": "verpuppend",
    "verpuppender": "verpuppend",
    "verpuppendes": "verpuppend",
    "verpuppest": "verpuppen",
    "verpuppet": "verpuppen",
    "verpuppst": "verpuppen",
    "verpuppt": "verpuppen",
    "verpuppte": "verpuppen",
    "verpupptem": "verpuppt",
    "verpuppten": "verpuppen",
    "verpuppter": "verpuppt",
    "verpupptes": "verpuppt",
    "verpupptest": "verpuppen",
    "verpupptet": "verpuppen",
    "verputze": "verputzen",
    "verputzend": "verputzen",
    "verputzende": "verputzend",
    "verputzendem": "verputzend",
    "verputzenden": "verputzend",
    "verputzender": "verputzend",
    "verputzendere": "verputzend",
    "verputzenderem": "verputzend",
    "verputzenderen": "verputzend",
    "verputzenderer": "verputzend",
    "verputzenderes": "verputzend",
    "verputzendes": "verputzend",
    "verputzendste": "verputzend",
    "verputzendstem": "verputzend",
    "verputzendsten": "verputzend",
    "verputzendster": "verputzend",
    "verputzendstes": "verputzend",
    "verputzest": "verputzen",
    "verputzet": "verputzen",
    "verputzt": "verputzen",
    "verputzte": "verputzen",
    "verputztem": "verputzt",
    "verputzten": "verputzen",
    "verputzter": "verputzt",
    "verputztere": "verputzt",
    "verputzterem": "verputzt",
    "verputzteren": "verputzt",
    "verputzterer": "verputzt",
    "verputzteres": "verputzt",
    "verputztes": "verputzt",
    "verputztest": "verputzen",
    "verputzteste": "verputzt",
    "verputztestem": "verputzt",
    "verputztesten": "verputzt",
    "verputztester": "verputzt",
    "verputztestes": "verputzt",
    "verputztet": "verputzen",
    "verpöne": "verpönen",
    "verpönend": "verpönen",
    "verpönende": "verpönend",
    "verpönendem": "verpönend",
    "verpönenden": "verpönend",
    "verpönender": "verpönend",
    "verpönendere": "verpönend",
    "verpönenderem": "verpönend",
    "verpönenderen": "verpönend",
    "verpönenderer": "verpönend",
    "verpönenderes": "verpönend",
    "verpönendes": "verpönend",
    "verpönendste": "verpönend",
    "verpönendstem": "verpönend",
    "verpönendsten": "verpönend",
    "verpönendster": "verpönend",
    "verpönendstes": "verpönend",
    "verpönest": "verpönen",
    "verpönet": "verpönen",
    "verpönst": "verpönen",
    "verpönt": "verpönen",
    "verpönte": "verpönen",
    "verpöntem": "verpönt",
    "verpönten": "verpönen",
    "verpönter": "verpönt",
    "verpöntere": "verpönt",
    "verpönterem": "verpönt",
    "verpönteren": "verpönt",
    "verpönterer": "verpönt",
    "verpönteres": "verpönt",
    "verpöntes": "verpönt",
    "verpöntest": "verpönen",
    "verpönteste": "verpönt",
    "verpöntestem": "verpönt",
    "verpöntesten": "verpönt",
    "verpöntester": "verpönt",
    "verpöntestes": "verpönt",
    "verpöntet": "verpönen",
    "verqualme": "verqualmen",
    "verqualmend": "verqualmen",
    "verqualmende": "verqualmend",
    "verqualmendem": "verqualmend",
    "verqualmenden": "verqualmend",
    "verqualmender": "verqualmend",
    "verqualmendere": "verqualmend",
    "verqualmenderem": "verqualmend",
    "verqualmenderen": "verqualmend",
    "verqualmenderer": "verqualmend",
    "verqualmenderes": "verqualmend",
    "verqualmendes": "verqualmend",
    "verqualmendste": "verqualmend",
    "verqualmendstem": "verqualmend",
    "verqualmendsten": "verqualmend",
    "verqualmendster": "verqualmend",
    "verqualmendstes": "verqualmend",
    "verqualmest": "verqualmen",
    "verqualmet": "verqualmen",
    "verqualmst": "verqualmen",
    "verqualmt": "verqualmen",
    "verqualmte": "verqualmen",
    "verqualmtem": "verqualmt",
    "verqualmten": "verqualmen",
    "verqualmter": "verqualmt",
    "verqualmtere": "verqualmt",
    "verqualmterem": "verqualmt",
    "verqualmteren": "verqualmt",
    "verqualmterer": "verqualmt",
    "verqualmteres": "verqualmt",
    "verqualmtes": "verqualmt",
    "verqualmtest": "verqualmen",
    "verqualmteste": "verqualmt",
    "verqualmtestem": "verqualmt",
    "verqualmtesten": "verqualmt",
    "verqualmtester": "verqualmt",
    "verqualmtestes": "verqualmt",
    "verqualmtet": "verqualmen",
    "verquatsche": "verquatschen",
    "verquatschend": "verquatschen",
    "verquatschende": "verquatschend",
    "verquatschendem": "verquatschend",
    "verquatschenden": "verquatschend",
    "verquatschender": "verquatschend",
    "verquatschendere": "verquatschend",
    "verquatschenderem": "verquatschend",
    "verquatschenderen": "verquatschend",
    "verquatschenderer": "verquatschend",
    "verquatschenderes": "verquatschend",
    "verquatschendes": "verquatschend",
    "verquatschendste": "verquatschend",
    "verquatschendstem": "verquatschend",
    "verquatschendsten": "verquatschend",
    "verquatschendster": "verquatschend",
    "verquatschendstes": "verquatschend",
    "verquatschest": "verquatschen",
    "verquatschet": "verquatschen",
    "verquatschst": "verquatschen",
    "verquatscht": "verquatschen",
    "verquatschte": "verquatschen",
    "verquatschtem": "verquatscht",
    "verquatschten": "verquatschen",
    "verquatschter": "verquatscht",
    "verquatschtes": "verquatscht",
    "verquatschtest": "verquatschen",
    "verquatschtet": "verquatschen",
    "verquirle": "verquirlen",
    "verquirlend": "verquirlen",
    "verquirlende": "verquirlend",
    "verquirlendem": "verquirlend",
    "verquirlenden": "verquirlend",
    "verquirlender": "verquirlend",
    "verquirlendes": "verquirlend",
    "verquirlest": "verquirlen",
    "verquirlet": "verquirlen",
    "verquirlst": "verquirlen",
    "verquirlt": "verquirlen",
    "verquirlte": "verquirlen",
    "verquirltem": "verquirlt",
    "verquirlten": "verquirlen",
    "verquirlter": "verquirlt",
    "verquirltere": "verquirlt",
    "verquirlterem": "verquirlt",
    "verquirlteren": "verquirlt",
    "verquirlterer": "verquirlt",
    "verquirlteres": "verquirlt",
    "verquirltes": "verquirlt",
    "verquirltest": "verquirlen",
    "verquirlteste": "verquirlt",
    "verquirltestem": "verquirlt",
    "verquirltesten": "verquirlt",
    "verquirltester": "verquirlt",
    "verquirltestes": "verquirlt",
    "verquirltet": "verquirlen",
    "verrammele": "verrammeln",
    "verrammelnd": "verrammeln",
    "verrammelnde": "verrammelnd",
    "verrammelndem": "verrammelnd",
    "verrammelnden": "verrammelnd",
    "verrammelnder": "verrammelnd",
    "verrammelndere": "verrammelnd",
    "verrammelnderem": "verrammelnd",
    "verrammelnderen": "verrammelnd",
    "verrammelnderer": "verrammelnd",
    "verrammelnderes": "verrammelnd",
    "verrammelndes": "verrammelnd",
    "verrammelndste": "verrammelnd",
    "verrammelndstem": "verrammelnd",
    "verrammelndsten": "verrammelnd",
    "verrammelndster": "verrammelnd",
    "verrammelndstes": "verrammelnd",
    "verrammelst": "verrammeln",
    "verrammelt": "verrammeln",
    "verrammelte": "verrammeln",
    "verrammeltem": "verrammelt",
    "verrammelten": "verrammeln",
    "verrammelter": "verrammelt",
    "verrammeltere": "verrammelt",
    "verrammelterem": "verrammelt",
    "verrammelteren": "verrammelt",
    "verrammelterer": "verrammelt",
    "verrammelteres": "verrammelt",
    "verrammeltes": "verrammelt",
    "verrammeltest": "verrammeln",
    "verrammelteste": "verrammelt",
    "verrammeltestem": "verrammelt",
    "verrammeltesten": "verrammelt",
    "verrammeltester": "verrammelt",
    "verrammeltestes": "verrammelt",
    "verrammeltet": "verrammeln",
    "verrammle": "verrammeln",
    "verramsche": "verramschen",
    "verramschend": "verramschen",
    "verramschende": "verramschend",
    "verramschendem": "verramschend",
    "verramschenden": "verramschend",
    "verramschender": "verramschend",
    "verramschendere": "verramschend",
    "verramschenderem": "verramschend",
    "verramschenderen": "verramschend",
    "verramschenderer": "verramschend",
    "verramschenderes": "verramschend",
    "verramschendes": "verramschend",
    "verramschendste": "verramschend",
    "verramschendstem": "verramschend",
    "verramschendsten": "verramschend",
    "verramschendster": "verramschend",
    "verramschendstes": "verramschend",
    "verramschest": "verramschen",
    "verramschet": "verramschen",
    "verramschst": "verramschen",
    "verramscht": "verramschen",
    "verramschte": "verramschen",
    "verramschtem": "verramscht",
    "verramschten": "verramschen",
    "verramschter": "verramscht",
    "verramschtere": "verramscht",
    "verramschterem": "verramscht",
    "verramschteren": "verramscht",
    "verramschterer": "verramscht",
    "verramschteres": "verramscht",
    "verramschtes": "verramscht",
    "verramschtest": "verramschen",
    "verramschteste": "verramscht",
    "verramschtestem": "verramscht",
    "verramschtesten": "verramscht",
    "verramschtester": "verramscht",
    "verramschtestes": "verramscht",
    "verramschtet": "verramschen",
    "verrann": "verrinnen",
    "verrannen": "verrinnen",
    "verrannst": "verrinnen",
    "verrannt": "verrinnen",
    "verrannte": "verrannt",
    "verranntem": "verrannt",
    "verrannten": "verrannt",
    "verrannter": "verrannt",
    "verranntes": "verrannt",
    "verranntest": "verrennen",
    "verranntet": "verrennen",
    "verrate": "verraten",
    "verratend": "verraten",
    "verratende": "verratend",
    "verratendem": "verratend",
    "verratenden": "verratend",
    "verratender": "verratend",
    "verratendes": "verratend",
    "verratene": "verraten",
    "verratenem": "verraten",
    "verratenen": "verraten",
    "verratener": "verraten",
    "verratenes": "verraten",
    "verratest": "verraten",
    "verratet": "verraten",
    "verrausche": "verrauschen",
    "verrauschend": "verrauschen",
    "verrauschende": "verrauschend",
    "verrauschendem": "verrauschend",
    "verrauschenden": "verrauschend",
    "verrauschender": "verrauschend",
    "verrauschendere": "verrauschend",
    "verrauschenderem": "verrauschend",
    "verrauschenderen": "verrauschend",
    "verrauschenderer": "verrauschend",
    "verrauschenderes": "verrauschend",
    "verrauschendes": "verrauschend",
    "verrauschendste": "verrauschend",
    "verrauschendstem": "verrauschend",
    "verrauschendsten": "verrauschend",
    "verrauschendster": "verrauschend",
    "verrauschendstes": "verrauschend",
    "verrauschest": "verrauschen",
    "verrauschet": "verrauschen",
    "verrauschst": "verrauschen",
    "verrauscht": "verrauschen",
    "verrauschte": "verrauschen",
    "verrauschtem": "verrauscht",
    "verrauschten": "verrauschen",
    "verrauschter": "verrauscht",
    "verrauschtere": "verrauscht",
    "verrauschterem": "verrauscht",
    "verrauschteren": "verrauscht",
    "verrauschterer": "verrauscht",
    "verrauschteres": "verrauscht",
    "verrauschtes": "verrauscht",
    "verrauschtest": "verrauschen",
    "verrauschteste": "verrauscht",
    "verrauschtestem": "verrauscht",
    "verrauschtesten": "verrauscht",
    "verrauschtester": "verrauscht",
    "verrauschtestes": "verrauscht",
    "verrauschtet": "verrauschen",
    "verrechne": "verrechnen",
    "verrechnend": "verrechnen",
    "verrechnende": "verrechnend",
    "verrechnendem": "verrechnend",
    "verrechnenden": "verrechnend",
    "verrechnender": "verrechnend",
    "verrechnendes": "verrechnend",
    "verrechnest": "verrechnen",
    "verrechnet": "verrechnen",
    "verrechnete": "verrechnen",
    "verrechnetem": "verrechnet",
    "verrechneten": "verrechnen",
    "verrechneter": "verrechnet",
    "verrechnetes": "verrechnet",
    "verrechnetest": "verrechnen",
    "verrechnetet": "verrechnen",
    "verregne": "verregnen",
    "verregnend": "verregnen",
    "verregnende": "verregnend",
    "verregnendem": "verregnend",
    "verregnenden": "verregnend",
    "verregnender": "verregnend",
    "verregnendes": "verregnend",
    "verregnest": "verregnen",
    "verregnet": "verregnen",
    "verregnete": "verregnen",
    "verregnetem": "verregnet",
    "verregneten": "verregnen",
    "verregneter": "verregnet",
    "verregnetere": "verregnet",
    "verregneterem": "verregnet",
    "verregneteren": "verregnet",
    "verregneterer": "verregnet",
    "verregneteres": "verregnet",
    "verregnetes": "verregnet",
    "verregnetest": "verregnen",
    "verregneteste": "verregnet",
    "verregnetestem": "verregnet",
    "verregnetesten": "verregnet",
    "verregnetester": "verregnet",
    "verregnetestes": "verregnet",
    "verregnetet": "verregnen",
    "verreibe": "verreiben",
    "verreibend": "verreiben",
    "verreibende": "verreibend",
    "verreibendem": "verreibend",
    "verreibenden": "verreibend",
    "verreibender": "verreibend",
    "verreibendere": "verreibend",
    "verreibenderem": "verreibend",
    "verreibenderen": "verreibend",
    "verreibenderer": "verreibend",
    "verreibenderes": "verreibend",
    "verreibendes": "verreibend",
    "verreibendste": "verreibend",
    "verreibendstem": "verreibend",
    "verreibendsten": "verreibend",
    "verreibendster": "verreibend",
    "verreibendstes": "verreibend",
    "verreibest": "verreiben",
    "verreibet": "verreiben",
    "verreibst": "verreiben",
    "verreibt": "verreiben",
    "verreise": "verreisen",
    "verreisend": "verreisen",
    "verreisende": "verreisend",
    "verreisendem": "verreisend",
    "verreisenden": "verreisend",
    "verreisender": "verreisend",
    "verreisendes": "verreisend",
    "verreisest": "verreisen",
    "verreiset": "verreisen",
    "verreist": "verreisen",
    "verreiste": "verreisen",
    "verreistem": "verreist",
    "verreisten": "verreisen",
    "verreister": "verreist",
    "verreistes": "verreist",
    "verreistest": "verreisen",
    "verreistet": "verreisen",
    "verreiße": "verreißen",
    "verreißend": "verreißen",
    "verreißende": "verreißend",
    "verreißendem": "verreißend",
    "verreißenden": "verreißend",
    "verreißender": "verreißend",
    "verreißendere": "verreißend",
    "verreißenderem": "verreißend",
    "verreißenderen": "verreißend",
    "verreißenderer": "verreißend",
    "verreißenderes": "verreißend",
    "verreißendes": "verreißend",
    "verreißendste": "verreißend",
    "verreißendstem": "verreißend",
    "verreißendsten": "verreißend",
    "verreißendster": "verreißend",
    "verreißendstes": "verreißend",
    "verreißest": "verreißen",
    "verreißet": "verreißen",
    "verreißt": "verreißen",
    "verrenke": "verrenken",
    "verrenkend": "verrenken",
    "verrenkende": "verrenkend",
    "verrenkendem": "verrenkend",
    "verrenkenden": "verrenkend",
    "verrenkender": "verrenkend",
    "verrenkendere": "verrenkend",
    "verrenkenderem": "verrenkend",
    "verrenkenderen": "verrenkend",
    "verrenkenderer": "verrenkend",
    "verrenkenderes": "verrenkend",
    "verrenkendes": "verrenkend",
    "verrenkendste": "verrenkend",
    "verrenkendstem": "verrenkend",
    "verrenkendsten": "verrenkend",
    "verrenkendster": "verrenkend",
    "verrenkendstes": "verrenkend",
    "verrenkest": "verrenken",
    "verrenket": "verrenken",
    "verrenkst": "verrenken",
    "verrenkt": "verrenken",
    "verrenkte": "verrenken",
    "verrenktem": "verrenkt",
    "verrenkten": "verrenken",
    "verrenkter": "verrenkt",
    "verrenktere": "verrenkt",
    "verrenkterem": "verrenkt",
    "verrenkteren": "verrenkt",
    "verrenkterer": "verrenkt",
    "verrenkteres": "verrenkt",
    "verrenktes": "verrenkt",
    "verrenktest": "verrenken",
    "verrenkteste": "verrenkt",
    "verrenktestem": "verrenkt",
    "verrenktesten": "verrenkt",
    "verrenktester": "verrenkt",
    "verrenktestes": "verrenkt",
    "verrenktet": "verrenken",
    "verrenne": "verrennen",
    "verrennend": "verrennen",
    "verrennende": "verrennend",
    "verrennendem": "verrennend",
    "verrennenden": "verrennend",
    "verrennender": "verrennend",
    "verrennendes": "verrennend",
    "verrennest": "verrennen",
    "verrennet": "verrennen",
    "verrennst": "verrennen",
    "verrennt": "verrennen",
    "verrichte": "verrichten",
    "verrichtend": "verrichten",
    "verrichtende": "verrichtend",
    "verrichtendem": "verrichtend",
    "verrichtenden": "verrichtend",
    "verrichtender": "verrichtend",
    "verrichtendes": "verrichtend",
    "verrichtest": "verrichten",
    "verrichtet": "verrichten",
    "verrichtete": "verrichten",
    "verrichtetem": "verrichtet",
    "verrichteten": "verrichten",
    "verrichteter": "verrichtet",
    "verrichtetes": "verrichtet",
    "verrichtetest": "verrichten",
    "verrichtetet": "verrichten",
    "verrieb": "verreiben",
    "verriebe": "verreiben",
    "verrieben": "verreiben",
    "verriebene": "verrieben",
    "verriebenem": "verrieben",
    "verriebenen": "verrieben",
    "verriebener": "verrieben",
    "verriebenere": "verrieben",
    "verriebenerem": "verrieben",
    "verriebeneren": "verrieben",
    "verriebenerer": "verrieben",
    "verriebeneres": "verrieben",
    "verriebenes": "verrieben",
    "verriebenste": "verrieben",
    "verriebenstem": "verrieben",
    "verriebensten": "verrieben",
    "verriebenster": "verrieben",
    "verriebenstes": "verrieben",
    "verriebest": "verreiben",
    "verriebet": "verreiben",
    "verriebst": "verreiben",
    "verriebt": "verreiben",
    "verriegele": "verriegeln",
    "verriegelnd": "verriegeln",
    "verriegelnde": "verriegelnd",
    "verriegelndem": "verriegelnd",
    "verriegelnden": "verriegelnd",
    "verriegelnder": "verriegelnd",
    "verriegelndes": "verriegelnd",
    "verriegelst": "verriegeln",
    "verriegelt": "verriegeln",
    "verriegelte": "verriegeln",
    "verriegeltem": "verriegelt",
    "verriegelten": "verriegeln",
    "verriegelter": "verriegelt",
    "verriegeltes": "verriegelt",
    "verriegeltest": "verriegeln",
    "verriegeltet": "verriegeln",
    "verriegle": "verriegeln",
    "verriet": "verraten",
    "verriete": "verraten",
    "verrieten": "verraten",
    "verrietest": "verraten",
    "verrietet": "verraten",
    "verringere": "verringern",
    "verringernd": "verringern",
    "verringernde": "verringernd",
    "verringerndem": "verringernd",
    "verringernden": "verringernd",
    "verringernder": "verringernd",
    "verringerndes": "verringernd",
    "verringerst": "verringern",
    "verringert": "verringern",
    "verringerte": "verringern",
    "verringertem": "verringert",
    "verringerten": "verringern",
    "verringerter": "verringert",
    "verringertes": "verringert",
    "verringertest": "verringern",
    "verringertet": "verringern",
    "verrinne": "verrinnen",
    "verrinnend": "verrinnen",
    "verrinnende": "verrinnend",
    "verrinnendem": "verrinnend",
    "verrinnenden": "verrinnend",
    "verrinnender": "verrinnend",
    "verrinnendes": "verrinnend",
    "verrinnest": "verrinnen",
    "verrinnet": "verrinnen",
    "verrinnst": "verrinnen",
    "verrinnt": "verrinnen",
    "verrisse": "verreißen",
    "verrissen": "verreißen",
    "verrissene": "verrissen",
    "verrissenem": "verrissen",
    "verrissenen": "verrissen",
    "verrissener": "verrissen",
    "verrissenere": "verrissen",
    "verrissenerem": "verrissen",
    "verrisseneren": "verrissen",
    "verrissenerer": "verrissen",
    "verrisseneres": "verrissen",
    "verrissenes": "verrissen",
    "verrissenste": "verrissen",
    "verrissenstem": "verrissen",
    "verrissensten": "verrissen",
    "verrissenster": "verrissen",
    "verrissenstes": "verrissen",
    "verrissest": "verreißen",
    "verrisset": "verreißen",
    "verriß": "verreißen",
    "verrißt": "verreißen",
    "verronnen": "verrinnen",
    "verronnene": "verronnen",
    "verronnenem": "verronnen",
    "verronnenen": "verronnen",
    "verronnener": "verronnen",
    "verronnenes": "verronnen",
    "verroste": "verrosten",
    "verrostend": "verrosten",
    "verrostende": "verrostend",
    "verrostendem": "verrostend",
    "verrostenden": "verrostend",
    "verrostender": "verrostend",
    "verrostendere": "verrostend",
    "verrostenderem": "verrostend",
    "verrostenderen": "verrostend",
    "verrostenderer": "verrostend",
    "verrostenderes": "verrostend",
    "verrostendes": "verrostend",
    "verrostendste": "verrostend",
    "verrostendstem": "verrostend",
    "verrostendsten": "verrostend",
    "verrostendster": "verrostend",
    "verrostendstes": "verrostend",
    "verrostest": "verrosten",
    "verrostet": "verrosten",
    "verrostete": "verrosten",
    "verrostetem": "verrostet",
    "verrosteten": "verrosten",
    "verrosteter": "verrostet",
    "verrostetere": "verrostet",
    "verrosteterem": "verrostet",
    "verrosteteren": "verrostet",
    "verrosteterer": "verrostet",
    "verrosteteres": "verrostet",
    "verrostetes": "verrostet",
    "verrostetest": "verrosten",
    "verrosteteste": "verrostet",
    "verrostetestem": "verrostet",
    "verrostetesten": "verrostet",
    "verrostetester": "verrostet",
    "verrostetestes": "verrostet",
    "verrostetet": "verrosten",
    "verrutsche": "verrutschen",
    "verrutschend": "verrutschen",
    "verrutschende": "verrutschend",
    "verrutschendem": "verrutschend",
    "verrutschenden": "verrutschend",
    "verrutschender": "verrutschend",
    "verrutschendere": "verrutschend",
    "verrutschenderem": "verrutschend",
    "verrutschenderen": "verrutschend",
    "verrutschenderer": "verrutschend",
    "verrutschenderes": "verrutschend",
    "verrutschendes": "verrutschend",
    "verrutschendste": "verrutschend",
    "verrutschendstem": "verrutschend",
    "verrutschendsten": "verrutschend",
    "verrutschendster": "verrutschend",
    "verrutschendstes": "verrutschend",
    "verrutschest": "verrutschen",
    "verrutschet": "verrutschen",
    "verrutschst": "verrutschen",
    "verrutscht": "verrutschen",
    "verrutschte": "verrutschen",
    "verrutschtem": "verrutscht",
    "verrutschten": "verrutschen",
    "verrutschter": "verrutscht",
    "verrutschtere": "verrutscht",
    "verrutschterem": "verrutscht",
    "verrutschteren": "verrutscht",
    "verrutschterer": "verrutscht",
    "verrutschteres": "verrutscht",
    "verrutschtes": "verrutscht",
    "verrutschtest": "verrutschen",
    "verrutschteste": "verrutscht",
    "verrutschtestem": "verrutscht",
    "verrutschtesten": "verrutscht",
    "verrutschtester": "verrutscht",
    "verrutschtestes": "verrutscht",
    "verrutschtet": "verrutschen",
    "verränne": "verrinnen",
    "verrännen": "verrinnen",
    "verrännest": "verrinnen",
    "verrännet": "verrinnen",
    "verrät": "verraten",
    "verräterischem": "verräterisch",
    "verräterischen": "verräterisch",
    "verräterischer": "verräterisch",
    "verräterischere": "verräterisch",
    "verräterischerem": "verräterisch",
    "verräterischeren": "verräterisch",
    "verräterischerer": "verräterisch",
    "verräterischeres": "verräterisch",
    "verräterisches": "verräterisch",
    "verräterischste": "verräterisch",
    "verräterischstem": "verräterisch",
    "verräterischsten": "verräterisch",
    "verräterischster": "verräterisch",
    "verräterischstes": "verräterisch",
    "verrätst": "verraten",
    "verräuchere": "verräuchern",
    "verräuchernd": "verräuchern",
    "verräuchernde": "verräuchernd",
    "verräucherndem": "verräuchernd",
    "verräuchernden": "verräuchernd",
    "verräuchernder": "verräuchernd",
    "verräucherndere": "verräuchernd",
    "verräuchernderem": "verräuchernd",
    "verräuchernderen": "verräuchernd",
    "verräuchernderer": "verräuchernd",
    "verräuchernderes": "verräuchernd",
    "verräucherndes": "verräuchernd",
    "verräucherndste": "verräuchernd",
    "verräucherndstem": "verräuchernd",
    "verräucherndsten": "verräuchernd",
    "verräucherndster": "verräuchernd",
    "verräucherndstes": "verräuchernd",
    "verräucherst": "verräuchern",
    "verräuchert": "verräuchern",
    "verräucherte": "verräuchern",
    "verräuchertem": "verräuchert",
    "verräucherten": "verräuchern",
    "verräucherter": "verräuchert",
    "verräuchertere": "verräuchert",
    "verräucherterem": "verräuchert",
    "verräucherteren": "verräuchert",
    "verräucherterer": "verräuchert",
    "verräucherteres": "verräuchert",
    "verräuchertes": "verräuchert",
    "verräuchertest": "verräuchern",
    "verräucherteste": "verräuchert",
    "verräuchertestem": "verräuchert",
    "verräuchertesten": "verräuchert",
    "verräuchertester": "verräuchert",
    "verräuchertestes": "verräuchert",
    "verräuchertet": "verräuchern",
    "verrücke": "verrücken",
    "verrückend": "verrücken",
    "verrückende": "verrückend",
    "verrückendem": "verrückend",
    "verrückenden": "verrückend",
    "verrückender": "verrückend",
    "verrückendes": "verrückend",
    "verrückest": "verrücken",
    "verrücket": "verrücken",
    "verrückst": "verrücken",
    "verrückt": "verrücken",
    "verrückte": "verrücken",
    "verrücktem": "verrückt",
    "verrückten": "verrücken",
    "verrückter": "verrückt",
    "verrücktere": "verrückt",
    "verrückterem": "verrückt",
    "verrückteren": "verrückt",
    "verrückterer": "verrückt",
    "verrückteres": "verrückt",
    "verrücktes": "verrückt",
    "verrücktest": "verrücken",
    "verrückteste": "verrückt",
    "verrücktestem": "verrückt",
    "verrücktesten": "verrückt",
    "verrücktester": "verrückt",
    "verrücktestes": "verrückt",
    "verrücktet": "verrücken",
    "verrühre": "verrühren",
    "verrührend": "verrühren",
    "verrührende": "verrührend",
    "verrührendem": "verrührend",
    "verrührenden": "verrührend",
    "verrührender": "verrührend",
    "verrührendes": "verrührend",
    "verrührest": "verrühren",
    "verrühret": "verrühren",
    "verrührst": "verrühren",
    "verrührt": "verrühren",
    "verrührte": "verrühren",
    "verrührtem": "verrührt",
    "verrührten": "verrühren",
    "verrührter": "verrührt",
    "verrührtes": "verrührt",
    "verrührtest": "verrühren",
    "verrührtet": "verrühren",
    "versachliche": "versachlichen",
    "versachlichend": "versachlichen",
    "versachlichende": "versachlichend",
    "versachlichendem": "versachlichend",
    "versachlichenden": "versachlichend",
    "versachlichender": "versachlichend",
    "versachlichendes": "versachlichend",
    "versachlichest": "versachlichen",
    "versachlichet": "versachlichen",
    "versachlichst": "versachlichen",
    "versachlicht": "versachlichen",
    "versachlichte": "versachlichen",
    "versachlichtem": "versachlicht",
    "versachlichten": "versachlichen",
    "versachlichter": "versachlicht",
    "versachlichtes": "versachlicht",
    "versachlichtest": "versachlichen",
    "versachlichtet": "versachlichen",
    "versage": "versagen",
    "versagend": "versagen",
    "versagende": "versagend",
    "versagendem": "versagend",
    "versagenden": "versagend",
    "versagender": "versagend",
    "versagendes": "versagend",
    "versagest": "versagen",
    "versaget": "versagen",
    "versagst": "versagen",
    "versagt": "versagen",
    "versagte": "versagen",
    "versagtem": "versagt",
    "versagten": "versagen",
    "versagter": "versagt",
    "versagtes": "versagt",
    "versagtest": "versagen",
    "versagtet": "versagen",
    "versah": "versehen",
    "versahen": "versehen",
    "versahst": "versehen",
    "versaht": "versehen",
    "versalze": "versalzen",
    "versalzend": "versalzen",
    "versalzende": "versalzend",
    "versalzendem": "versalzend",
    "versalzenden": "versalzend",
    "versalzender": "versalzend",
    "versalzendere": "versalzend",
    "versalzenderem": "versalzend",
    "versalzenderen": "versalzend",
    "versalzenderer": "versalzend",
    "versalzenderes": "versalzend",
    "versalzendes": "versalzend",
    "versalzendste": "versalzend",
    "versalzendstem": "versalzend",
    "versalzendsten": "versalzend",
    "versalzendster": "versalzend",
    "versalzendstes": "versalzend",
    "versalzene": "versalzen",
    "versalzenem": "versalzen",
    "versalzenen": "versalzen",
    "versalzener": "versalzen",
    "versalzenere": "versalzen",
    "versalzenerem": "versalzen",
    "versalzeneren": "versalzen",
    "versalzenerer": "versalzen",
    "versalzeneres": "versalzen",
    "versalzenes": "versalzen",
    "versalzenstem": "versalzen",
    "versalzensten": "versalzen",
    "versalzenster": "versalzen",
    "versalzenstes": "versalzen",
    "versalzest": "versalzen",
    "versalzet": "versalzen",
    "versalzt": "versalzen",
    "versalzte": "versalzen",
    "versalzten": "versalzen",
    "versalztest": "versalzen",
    "versalztet": "versalzen",
    "versammele": "versammeln",
    "versammelnd": "versammeln",
    "versammelnde": "versammelnd",
    "versammelndem": "versammelnd",
    "versammelnden": "versammelnd",
    "versammelnder": "versammelnd",
    "versammelndes": "versammelnd",
    "versammelst": "versammeln",
    "versammelt": "versammeln",
    "versammelte": "versammeln",
    "versammeltem": "versammelt",
    "versammelten": "versammeln",
    "versammelter": "versammelt",
    "versammeltes": "versammelt",
    "versammeltest": "versammeln",
    "versammeltet": "versammeln",
    "versammle": "versammeln",
    "versande": "versanden",
    "versandend": "versanden",
    "versandende": "versandend",
    "versandendem": "versandend",
    "versandenden": "versandend",
    "versandender": "versandend",
    "versandendes": "versandend",
    "versandest": "versanden",
    "versandet": "versanden",
    "versandete": "versanden",
    "versandetem": "versandet",
    "versandeten": "versanden",
    "versandeter": "versandet",
    "versandetes": "versandet",
    "versandetest": "versanden",
    "versandetet": "versanden",
    "versandfertige": "versandfertig",
    "versandfertigem": "versandfertig",
    "versandfertigen": "versandfertig",
    "versandfertiger": "versandfertig",
    "versandfertiges": "versandfertig",
    "versandt": "versenden",
    "versandte": "versandt",
    "versandtem": "versandt",
    "versandten": "versandt",
    "versandter": "versandt",
    "versandtes": "versandt",
    "versandtest": "versenden",
    "versandtet": "versenden",
    "versank": "versinken",
    "versanken": "versinken",
    "versankst": "versinken",
    "versankt": "versinken",
    "versaue": "versauen",
    "versauend": "versauen",
    "versauende": "versauend",
    "versauendem": "versauend",
    "versauenden": "versauend",
    "versauender": "versauend",
    "versauendere": "versauend",
    "versauenderem": "versauend",
    "versauenderen": "versauend",
    "versauenderer": "versauend",
    "versauenderes": "versauend",
    "versauendes": "versauend",
    "versauendste": "versauend",
    "versauendstem": "versauend",
    "versauendsten": "versauend",
    "versauendster": "versauend",
    "versauendstes": "versauend",
    "versauere": "versauern",
    "versauernd": "versauern",
    "versauernde": "versauernd",
    "versauerndem": "versauernd",
    "versauernden": "versauernd",
    "versauernder": "versauernd",
    "versauerndere": "versauernd",
    "versauernderem": "versauernd",
    "versauernderen": "versauernd",
    "versauernderer": "versauernd",
    "versauernderes": "versauernd",
    "versauerndes": "versauernd",
    "versauerndste": "versauernd",
    "versauerndstem": "versauernd",
    "versauerndsten": "versauernd",
    "versauerndster": "versauernd",
    "versauerndstes": "versauernd",
    "versauerst": "versauern",
    "versauert": "versauern",
    "versauerte": "versauern",
    "versauertem": "versauert",
    "versauerten": "versauern",
    "versauerter": "versauert",
    "versauertere": "versauert",
    "versauerterem": "versauert",
    "versauerteren": "versauert",
    "versauerterer": "versauert",
    "versauerteres": "versauert",
    "versauertes": "versauert",
    "versauertest": "versauern",
    "versauerteste": "versauert",
    "versauertestem": "versauert",
    "versauertesten": "versauert",
    "versauertester": "versauert",
    "versauertestes": "versauert",
    "versauertet": "versauern",
    "versauest": "versauen",
    "versauet": "versauen",
    "versaufe": "versaufen",
    "versaufend": "versaufen",
    "versaufende": "versaufend",
    "versaufendem": "versaufend",
    "versaufenden": "versaufend",
    "versaufender": "versaufend",
    "versaufendere": "versaufend",
    "versaufenderem": "versaufend",
    "versaufenderen": "versaufend",
    "versaufenderer": "versaufend",
    "versaufenderes": "versaufend",
    "versaufendes": "versaufend",
    "versaufendste": "versaufend",
    "versaufendstem": "versaufend",
    "versaufendsten": "versaufend",
    "versaufendster": "versaufend",
    "versaufendstes": "versaufend",
    "versaufest": "versaufen",
    "versaufet": "versaufen",
    "versauft": "versaufen",
    "versaust": "versauen",
    "versaut": "versauen",
    "versaute": "versauen",
    "versautem": "versaut",
    "versauten": "versauen",
    "versauter": "versaut",
    "versautere": "versaut",
    "versauterem": "versaut",
    "versauteren": "versaut",
    "versauterer": "versaut",
    "versauteres": "versaut",
    "versautes": "versaut",
    "versautest": "versauen",
    "versauteste": "versaut",
    "versautestem": "versaut",
    "versautesten": "versaut",
    "versautester": "versaut",
    "versautestes": "versaut",
    "versautet": "versauen",
    "verschachere": "verschachern",
    "verschachernd": "verschachern",
    "verschachernde": "verschachernd",
    "verschacherndem": "verschachernd",
    "verschachernden": "verschachernd",
    "verschachernder": "verschachernd",
    "verschacherndes": "verschachernd",
    "verschacherst": "verschachern",
    "verschachert": "verschachern",
    "verschacherte": "verschachern",
    "verschachertem": "verschachert",
    "verschacherten": "verschachern",
    "verschacherter": "verschachert",
    "verschachertes": "verschachert",
    "verschachertest": "verschachern",
    "verschachertet": "verschachern",
    "verschachtele": "verschachteln",
    "verschachtelnd": "verschachteln",
    "verschachtelnde": "verschachtelnd",
    "verschachtelndem": "verschachtelnd",
    "verschachtelnden": "verschachtelnd",
    "verschachtelnder": "verschachtelnd",
    "verschachtelndere": "verschachtelnd",
    "verschachtelnderem": "verschachtelnd",
    "verschachtelnderen": "verschachtelnd",
    "verschachtelnderer": "verschachtelnd",
    "verschachtelnderes": "verschachtelnd",
    "verschachtelndes": "verschachtelnd",
    "verschachtelndste": "verschachtelnd",
    "verschachtelndstem": "verschachtelnd",
    "verschachtelndsten": "verschachtelnd",
    "verschachtelndster": "verschachtelnd",
    "verschachtelndstes": "verschachtelnd",
    "verschachtelst": "verschachteln",
    "verschachtelt": "verschachteln",
    "verschachtelte": "verschachteln",
    "verschachteltem": "verschachtelt",
    "verschachtelten": "verschachteln",
    "verschachtelter": "verschachtelt",
    "verschachteltere": "verschachtelt",
    "verschachtelterem": "verschachtelt",
    "verschachtelteren": "verschachtelt",
    "verschachtelterer": "verschachtelt",
    "verschachtelteres": "verschachtelt",
    "verschachteltes": "verschachtelt",
    "verschachteltest": "verschachteln",
    "verschachteltestem": "verschachtelt",
    "verschachteltesten": "verschachtelt",
    "verschachteltester": "verschachtelt",
    "verschachteltestes": "verschachtelt",
    "verschachteltet": "verschachteln",
    "verschachtle": "verschachteln",
    "verschaffe": "verschaffen",
    "verschaffend": "verschaffen",
    "verschaffende": "verschaffend",
    "verschaffendem": "verschaffend",
    "verschaffenden": "verschaffend",
    "verschaffender": "verschaffend",
    "verschaffendes": "verschaffend",
    "verschaffest": "verschaffen",
    "verschaffet": "verschaffen",
    "verschaffst": "verschaffen",
    "verschafft": "verschaffen",
    "verschaffte": "verschaffen",
    "verschafftem": "verschafft",
    "verschafften": "verschaffen",
    "verschaffter": "verschafft",
    "verschafftes": "verschafft",
    "verschafftest": "verschaffen",
    "verschafftet": "verschaffen",
    "verschale": "verschalen",
    "verschalend": "verschalen",
    "verschalende": "verschalend",
    "verschalendem": "verschalend",
    "verschalenden": "verschalend",
    "verschalender": "verschalend",
    "verschalendes": "verschalend",
    "verschalest": "verschalen",
    "verschalet": "verschalen",
    "verschalst": "verschalen",
    "verschalt": "verschalen",
    "verschalte": "verschalten",
    "verschaltem": "verschalt",
    "verschalten": "verschalen",
    "verschaltend": "verschalten",
    "verschaltende": "verschaltend",
    "verschaltendem": "verschaltend",
    "verschaltenden": "verschaltend",
    "verschaltender": "verschaltend",
    "verschaltendes": "verschaltend",
    "verschalter": "verschalt",
    "verschaltes": "verschalt",
    "verschaltest": "verschalten",
    "verschaltet": "verschalten",
    "verschaltete": "verschalten",
    "verschaltetem": "verschaltet",
    "verschalteten": "verschalten",
    "verschalteter": "verschaltet",
    "verschaltetes": "verschaltet",
    "verschaltetest": "verschalten",
    "verschaltetet": "verschalten",
    "verschandele": "verschandeln",
    "verschandelnd": "verschandeln",
    "verschandelnde": "verschandelnd",
    "verschandelndem": "verschandelnd",
    "verschandelnden": "verschandelnd",
    "verschandelnder": "verschandelnd",
    "verschandelndere": "verschandelnd",
    "verschandelnderem": "verschandelnd",
    "verschandelnderen": "verschandelnd",
    "verschandelnderer": "verschandelnd",
    "verschandelnderes": "verschandelnd",
    "verschandelndes": "verschandelnd",
    "verschandelndste": "verschandelnd",
    "verschandelndstem": "verschandelnd",
    "verschandelndsten": "verschandelnd",
    "verschandelndster": "verschandelnd",
    "verschandelndstes": "verschandelnd",
    "verschandelst": "verschandeln",
    "verschandelt": "verschandeln",
    "verschandelte": "verschandeln",
    "verschandeltem": "verschandelt",
    "verschandelten": "verschandeln",
    "verschandelter": "verschandelt",
    "verschandeltere": "verschandelt",
    "verschandelterem": "verschandelt",
    "verschandelteren": "verschandelt",
    "verschandelterer": "verschandelt",
    "verschandelteres": "verschandelt",
    "verschandeltes": "verschandelt",
    "verschandeltest": "verschandeln",
    "verschandelteste": "verschandelt",
    "verschandeltestem": "verschandelt",
    "verschandeltesten": "verschandelt",
    "verschandeltester": "verschandelt",
    "verschandeltestes": "verschandelt",
    "verschandeltet": "verschandeln",
    "verschandle": "verschandeln",
    "verschanze": "verschanzen",
    "verschanzend": "verschanzen",
    "verschanzende": "verschanzend",
    "verschanzendem": "verschanzend",
    "verschanzenden": "verschanzend",
    "verschanzender": "verschanzend",
    "verschanzendere": "verschanzend",
    "verschanzenderem": "verschanzend",
    "verschanzenderen": "verschanzend",
    "verschanzenderer": "verschanzend",
    "verschanzenderes": "verschanzend",
    "verschanzendes": "verschanzend",
    "verschanzendste": "verschanzend",
    "verschanzendstem": "verschanzend",
    "verschanzendsten": "verschanzend",
    "verschanzendster": "verschanzend",
    "verschanzendstes": "verschanzend",
    "verschanzest": "verschanzen",
    "verschanzet": "verschanzen",
    "verschanzt": "verschanzen",
    "verschanzte": "verschanzen",
    "verschanztem": "verschanzt",
    "verschanzten": "verschanzen",
    "verschanzter": "verschanzt",
    "verschanztere": "verschanzt",
    "verschanzterem": "verschanzt",
    "verschanzteren": "verschanzt",
    "verschanzterer": "verschanzt",
    "verschanzteres": "verschanzt",
    "verschanztes": "verschanzt",
    "verschanztest": "verschanzen",
    "verschanzteste": "verschanzt",
    "verschanztestem": "verschanzt",
    "verschanztesten": "verschanzt",
    "verschanztester": "verschanzt",
    "verschanztestes": "verschanzt",
    "verschanztet": "verschanzen",
    "verscharre": "verscharren",
    "verscharrend": "verscharren",
    "verscharrende": "verscharrend",
    "verscharrendem": "verscharrend",
    "verscharrenden": "verscharrend",
    "verscharrender": "verscharrend",
    "verscharrendes": "verscharrend",
    "verscharrest": "verscharren",
    "verscharret": "verscharren",
    "verscharrst": "verscharren",
    "verscharrt": "verscharren",
    "verscharrte": "verscharren",
    "verscharrtem": "verscharrt",
    "verscharrten": "verscharren",
    "verscharrter": "verscharrt",
    "verscharrtes": "verscharrt",
    "verscharrtest": "verscharren",
    "verscharrtet": "verscharren",
    "verschaukele": "verschaukeln",
    "verschaukelnd": "verschaukeln",
    "verschaukelnde": "verschaukelnd",
    "verschaukelndem": "verschaukelnd",
    "verschaukelnden": "verschaukelnd",
    "verschaukelnder": "verschaukelnd",
    "verschaukelndere": "verschaukelnd",
    "verschaukelnderem": "verschaukelnd",
    "verschaukelnderen": "verschaukelnd",
    "verschaukelnderer": "verschaukelnd",
    "verschaukelnderes": "verschaukelnd",
    "verschaukelndes": "verschaukelnd",
    "verschaukelndste": "verschaukelnd",
    "verschaukelndstem": "verschaukelnd",
    "verschaukelndsten": "verschaukelnd",
    "verschaukelndster": "verschaukelnd",
    "verschaukelndstes": "verschaukelnd",
    "verschaukelst": "verschaukeln",
    "verschaukelt": "verschaukeln",
    "verschaukelte": "verschaukeln",
    "verschaukeltem": "verschaukelt",
    "verschaukelten": "verschaukeln",
    "verschaukelter": "verschaukelt",
    "verschaukeltere": "verschaukelt",
    "verschaukelterem": "verschaukelt",
    "verschaukelteren": "verschaukelt",
    "verschaukelterer": "verschaukelt",
    "verschaukelteres": "verschaukelt",
    "verschaukeltes": "verschaukelt",
    "verschaukeltest": "verschaukeln",
    "verschaukelteste": "verschaukelt",
    "verschaukeltestem": "verschaukelt",
    "verschaukeltesten": "verschaukelt",
    "verschaukeltester": "verschaukelt",
    "verschaukeltestes": "verschaukelt",
    "verschaukeltet": "verschaukeln",
    "verschaukle": "verschaukeln",
    "verscheide": "verscheiden",
    "verscheidend": "verscheiden",
    "verscheidende": "verscheidend",
    "verscheidendem": "verscheidend",
    "verscheidenden": "verscheidend",
    "verscheidender": "verscheidend",
    "verscheidendes": "verscheidend",
    "verscheidest": "verscheiden",
    "verscheidet": "verscheiden",
    "verscheißere": "verscheißern",
    "verscheißernd": "verscheißern",
    "verscheißernde": "verscheißernd",
    "verscheißerndem": "verscheißernd",
    "verscheißernden": "verscheißernd",
    "verscheißernder": "verscheißernd",
    "verscheißerndere": "verscheißernd",
    "verscheißernderem": "verscheißernd",
    "verscheißernderen": "verscheißernd",
    "verscheißernderer": "verscheißernd",
    "verscheißernderes": "verscheißernd",
    "verscheißerndes": "verscheißernd",
    "verscheißerndste": "verscheißernd",
    "verscheißerndstem": "verscheißernd",
    "verscheißerndsten": "verscheißernd",
    "verscheißerndster": "verscheißernd",
    "verscheißerndstes": "verscheißernd",
    "verscheißerst": "verscheißern",
    "verscheißert": "verscheißern",
    "verscheißerte": "verscheißern",
    "verscheißertem": "verscheißert",
    "verscheißerten": "verscheißern",
    "verscheißerter": "verscheißert",
    "verscheißertere": "verscheißert",
    "verscheißerterem": "verscheißert",
    "verscheißerteren": "verscheißert",
    "verscheißerterer": "verscheißert",
    "verscheißerteres": "verscheißert",
    "verscheißertes": "verscheißert",
    "verscheißertest": "verscheißern",
    "verscheißerteste": "verscheißert",
    "verscheißertestem": "verscheißert",
    "verscheißertesten": "verscheißert",
    "verscheißertester": "verscheißert",
    "verscheißertestes": "verscheißert",
    "verscheißertet": "verscheißern",
    "verschenke": "verschenken",
    "verschenkend": "verschenken",
    "verschenkende": "verschenkend",
    "verschenkendem": "verschenkend",
    "verschenkenden": "verschenkend",
    "verschenkender": "verschenkend",
    "verschenkendes": "verschenkend",
    "verschenkest": "verschenken",
    "verschenket": "verschenken",
    "verschenkst": "verschenken",
    "verschenkt": "verschenken",
    "verschenkte": "verschenken",
    "verschenktem": "verschenkt",
    "verschenkten": "verschenken",
    "verschenkter": "verschenkt",
    "verschenktes": "verschenkt",
    "verschenktest": "verschenken",
    "verschenktet": "verschenken",
    "verscherbele": "verscherbeln",
    "verscherbelnd": "verscherbeln",
    "verscherbelnde": "verscherbelnd",
    "verscherbelndem": "verscherbelnd",
    "verscherbelnden": "verscherbelnd",
    "verscherbelnder": "verscherbelnd",
    "verscherbelndes": "verscherbelnd",
    "verscherbelst": "verscherbeln",
    "verscherbelt": "verscherbeln",
    "verscherbelte": "verscherbeln",
    "verscherbeltem": "verscherbelt",
    "verscherbelten": "verscherbeln",
    "verscherbelter": "verscherbelt",
    "verscherbeltes": "verscherbelt",
    "verscherbeltest": "verscherbeln",
    "verscherbeltet": "verscherbeln",
    "verscherble": "verscherbeln",
    "verscherze": "verscherzen",
    "verscherzend": "verscherzen",
    "verscherzende": "verscherzend",
    "verscherzendem": "verscherzend",
    "verscherzenden": "verscherzend",
    "verscherzender": "verscherzend",
    "verscherzendere": "verscherzend",
    "verscherzenderem": "verscherzend",
    "verscherzenderen": "verscherzend",
    "verscherzenderer": "verscherzend",
    "verscherzenderes": "verscherzend",
    "verscherzendes": "verscherzend",
    "verscherzendste": "verscherzend",
    "verscherzendstem": "verscherzend",
    "verscherzendsten": "verscherzend",
    "verscherzendster": "verscherzend",
    "verscherzendstes": "verscherzend",
    "verscherzest": "verscherzen",
    "verscherzet": "verscherzen",
    "verscherzt": "verscherzen",
    "verscherzte": "verscherzen",
    "verscherztem": "verscherzt",
    "verscherzten": "verscherzen",
    "verscherzter": "verscherzt",
    "verscherztes": "verscherzt",
    "verscherztest": "verscherzen",
    "verscherztet": "verscherzen",
    "verscheuche": "verscheuchen",
    "verscheuchend": "verscheuchen",
    "verscheuchende": "verscheuchend",
    "verscheuchendem": "verscheuchend",
    "verscheuchenden": "verscheuchend",
    "verscheuchender": "verscheuchend",
    "verscheuchendere": "verscheuchend",
    "verscheuchenderem": "verscheuchend",
    "verscheuchenderen": "verscheuchend",
    "verscheuchenderer": "verscheuchend",
    "verscheuchenderes": "verscheuchend",
    "verscheuchendes": "verscheuchend",
    "verscheuchendste": "verscheuchend",
    "verscheuchendstem": "verscheuchend",
    "verscheuchendsten": "verscheuchend",
    "verscheuchendster": "verscheuchend",
    "verscheuchendstes": "verscheuchend",
    "verscheuchest": "verscheuchen",
    "verscheuchet": "verscheuchen",
    "verscheuchst": "verscheuchen",
    "verscheucht": "verscheuchen",
    "verscheuchte": "verscheuchen",
    "verscheuchtem": "verscheucht",
    "verscheuchten": "verscheuchen",
    "verscheuchter": "verscheucht",
    "verscheuchtes": "verscheucht",
    "verscheuchtest": "verscheuchen",
    "verscheuchtet": "verscheuchen",
    "verscheuere": "verscheuern",
    "verscheuernd": "verscheuern",
    "verscheuernde": "verscheuernd",
    "verscheuerndem": "verscheuernd",
    "verscheuernden": "verscheuernd",
    "verscheuernder": "verscheuernd",
    "verscheuerndere": "verscheuernd",
    "verscheuernderem": "verscheuernd",
    "verscheuernderen": "verscheuernd",
    "verscheuernderer": "verscheuernd",
    "verscheuernderes": "verscheuernd",
    "verscheuerndes": "verscheuernd",
    "verscheuerndste": "verscheuernd",
    "verscheuerndstem": "verscheuernd",
    "verscheuerndsten": "verscheuernd",
    "verscheuerndster": "verscheuernd",
    "verscheuerndstes": "verscheuernd",
    "verscheuerst": "verscheuern",
    "verscheuert": "verscheuern",
    "verscheuerte": "verscheuern",
    "verscheuertem": "verscheuert",
    "verscheuerten": "verscheuern",
    "verscheuerter": "verscheuert",
    "verscheuertes": "verscheuert",
    "verscheuertest": "verscheuern",
    "verscheuertet": "verscheuern",
    "verschicke": "verschicken",
    "verschickend": "verschicken",
    "verschickende": "verschickend",
    "verschickendem": "verschickend",
    "verschickenden": "verschickend",
    "verschickender": "verschickend",
    "verschickendes": "verschickend",
    "verschickest": "verschicken",
    "verschicket": "verschicken",
    "verschickst": "verschicken",
    "verschickt": "verschicken",
    "verschickte": "verschicken",
    "verschicktem": "verschickt",
    "verschickten": "verschicken",
    "verschickter": "verschickt",
    "verschicktes": "verschickt",
    "verschicktest": "verschicken",
    "verschicktet": "verschicken",
    "verschiebe": "verschieben",
    "verschiebend": "verschieben",
    "verschiebende": "verschiebend",
    "verschiebendem": "verschiebend",
    "verschiebenden": "verschiebend",
    "verschiebender": "verschiebend",
    "verschiebendere": "verschiebend",
    "verschiebenderem": "verschiebend",
    "verschiebenderen": "verschiebend",
    "verschiebenderer": "verschiebend",
    "verschiebenderes": "verschiebend",
    "verschiebendes": "verschiebend",
    "verschiebendste": "verschiebend",
    "verschiebendstem": "verschiebend",
    "verschiebendsten": "verschiebend",
    "verschiebendster": "verschiebend",
    "verschiebendstes": "verschiebend",
    "verschiebest": "verschieben",
    "verschiebet": "verschieben",
    "verschiebst": "verschieben",
    "verschiebt": "verschieben",
    "verschied": "verscheiden",
    "verschiede": "verscheiden",
    "verschieden": "verscheiden",
    "verschiedenartige": "verschiedenartig",
    "verschiedenartigem": "verschiedenartig",
    "verschiedenartigen": "verschiedenartig",
    "verschiedenartiger": "verschiedenartig",
    "verschiedenartigere": "verschiedenartig",
    "verschiedenartigerem": "verschiedenartig",
    "verschiedenartigeren": "verschiedenartig",
    "verschiedenartigerer": "verschiedenartig",
    "verschiedenartigeres": "verschiedenartig",
    "verschiedenartiges": "verschiedenartig",
    "verschiedenartigste": "verschiedenartig",
    "verschiedenartigstem": "verschiedenartig",
    "verschiedenartigsten": "verschiedenartig",
    "verschiedenartigster": "verschiedenartig",
    "verschiedenartigstes": "verschiedenartig",
    "verschiedene": "verschieden",
    "verschiedenem": "verschieden",
    "verschiedenen": "verschieden",
    "verschiedener": "verschieden",
    "verschiedenere": "verschieden",
    "verschiedenerem": "verschieden",
    "verschiedeneren": "verschieden",
    "verschiedenerer": "verschieden",
    "verschiedeneres": "verschieden",
    "verschiedenes": "verschieden",
    "verschiedenstem": "verschieden",
    "verschiedensten": "verschieden",
    "verschiedenster": "verschieden",
    "verschiedenstes": "verschieden",
    "verschiedest": "verscheiden",
    "verschiedet": "verscheiden",
    "verschieße": "verschießen",
    "verschießend": "verschießen",
    "verschießende": "verschießend",
    "verschießendem": "verschießend",
    "verschießenden": "verschießend",
    "verschießender": "verschießend",
    "verschießendes": "verschießend",
    "verschießest": "verschießen",
    "verschießet": "verschießen",
    "verschießt": "verschießen",
    "verschiffe": "verschiffen",
    "verschiffend": "verschiffen",
    "verschiffende": "verschiffend",
    "verschiffendem": "verschiffend",
    "verschiffenden": "verschiffend",
    "verschiffender": "verschiffend",
    "verschiffendere": "verschiffend",
    "verschiffenderem": "verschiffend",
    "verschiffenderen": "verschiffend",
    "verschiffenderer": "verschiffend",
    "verschiffenderes": "verschiffend",
    "verschiffendes": "verschiffend",
    "verschiffendste": "verschiffend",
    "verschiffendstem": "verschiffend",
    "verschiffendsten": "verschiffend",
    "verschiffendster": "verschiffend",
    "verschiffendstes": "verschiffend",
    "verschiffest": "verschiffen",
    "verschiffet": "verschiffen",
    "verschiffst": "verschiffen",
    "verschifft": "verschiffen",
    "verschiffte": "verschiffen",
    "verschifftem": "verschifft",
    "verschifften": "verschiffen",
    "verschiffter": "verschifft",
    "verschifftes": "verschifft",
    "verschifftest": "verschiffen",
    "verschifftet": "verschiffen",
    "verschimmele": "verschimmeln",
    "verschimmelnd": "verschimmeln",
    "verschimmelnde": "verschimmelnd",
    "verschimmelndem": "verschimmelnd",
    "verschimmelnden": "verschimmelnd",
    "verschimmelnder": "verschimmelnd",
    "verschimmelndere": "verschimmelnd",
    "verschimmelnderem": "verschimmelnd",
    "verschimmelnderen": "verschimmelnd",
    "verschimmelnderer": "verschimmelnd",
    "verschimmelnderes": "verschimmelnd",
    "verschimmelndes": "verschimmelnd",
    "verschimmelndste": "verschimmelnd",
    "verschimmelndstem": "verschimmelnd",
    "verschimmelndsten": "verschimmelnd",
    "verschimmelndster": "verschimmelnd",
    "verschimmelndstes": "verschimmelnd",
    "verschimmelst": "verschimmeln",
    "verschimmelt": "verschimmeln",
    "verschimmelte": "verschimmeln",
    "verschimmeltem": "verschimmelt",
    "verschimmelten": "verschimmeln",
    "verschimmelter": "verschimmelt",
    "verschimmeltere": "verschimmelt",
    "verschimmelterem": "verschimmelt",
    "verschimmelteren": "verschimmelt",
    "verschimmelterer": "verschimmelt",
    "verschimmelteres": "verschimmelt",
    "verschimmeltes": "verschimmelt",
    "verschimmeltest": "verschimmeln",
    "verschimmelteste": "verschimmelt",
    "verschimmeltestem": "verschimmelt",
    "verschimmeltesten": "verschimmelt",
    "verschimmeltester": "verschimmelt",
    "verschimmeltestes": "verschimmelt",
    "verschimmeltet": "verschimmeln",
    "verschimmle": "verschimmeln",
    "verschlafe": "verschlafen",
    "verschlafend": "verschlafen",
    "verschlafende": "verschlafend",
    "verschlafendem": "verschlafend",
    "verschlafenden": "verschlafend",
    "verschlafender": "verschlafend",
    "verschlafendes": "verschlafend",
    "verschlafene": "verschlafen",
    "verschlafenem": "verschlafen",
    "verschlafenen": "verschlafen",
    "verschlafener": "verschlafen",
    "verschlafenere": "verschlafen",
    "verschlafenerem": "verschlafen",
    "verschlafeneren": "verschlafen",
    "verschlafenerer": "verschlafen",
    "verschlafeneres": "verschlafen",
    "verschlafenes": "verschlafen",
    "verschlafenstem": "verschlafen",
    "verschlafensten": "verschlafen",
    "verschlafenster": "verschlafen",
    "verschlafenstes": "verschlafen",
    "verschlafest": "verschlafen",
    "verschlafet": "verschlafen",
    "verschlaft": "verschlafen",
    "verschlagend": "verschlagen",
    "verschlagende": "verschlagend",
    "verschlagendem": "verschlagend",
    "verschlagenden": "verschlagend",
    "verschlagender": "verschlagend",
    "verschlagendes": "verschlagend",
    "verschlagene": "verschlagen",
    "verschlagenem": "verschlagen",
    "verschlagenen": "verschlagen",
    "verschlagener": "verschlagen",
    "verschlagenere": "verschlagen",
    "verschlagenerem": "verschlagen",
    "verschlageneren": "verschlagen",
    "verschlagenerer": "verschlagen",
    "verschlageneres": "verschlagen",
    "verschlagenes": "verschlagen",
    "verschlagenstem": "verschlagen",
    "verschlagensten": "verschlagen",
    "verschlagenster": "verschlagen",
    "verschlagenstes": "verschlagen",
    "verschlagest": "verschlagen",
    "verschlaget": "verschlagen",
    "verschlagt": "verschlagen",
    "verschlamme": "verschlammen",
    "verschlammend": "verschlammen",
    "verschlammende": "verschlammend",
    "verschlammendem": "verschlammend",
    "verschlammenden": "verschlammend",
    "verschlammender": "verschlammend",
    "verschlammendes": "verschlammend",
    "verschlammest": "verschlammen",
    "verschlammet": "verschlammen",
    "verschlammst": "verschlammen",
    "verschlammt": "verschlammen",
    "verschlammte": "verschlammen",
    "verschlammtem": "verschlammt",
    "verschlammten": "verschlammen",
    "verschlammter": "verschlammt",
    "verschlammtes": "verschlammt",
    "verschlammtest": "verschlammen",
    "verschlammtet": "verschlammen",
    "verschlampe": "verschlampen",
    "verschlampend": "verschlampen",
    "verschlampende": "verschlampend",
    "verschlampendem": "verschlampend",
    "verschlampenden": "verschlampend",
    "verschlampender": "verschlampend",
    "verschlampendere": "verschlampend",
    "verschlampenderem": "verschlampend",
    "verschlampenderen": "verschlampend",
    "verschlampenderer": "verschlampend",
    "verschlampenderes": "verschlampend",
    "verschlampendes": "verschlampend",
    "verschlampendste": "verschlampend",
    "verschlampendstem": "verschlampend",
    "verschlampendsten": "verschlampend",
    "verschlampendster": "verschlampend",
    "verschlampendstes": "verschlampend",
    "verschlampest": "verschlampen",
    "verschlampet": "verschlampen",
    "verschlampst": "verschlampen",
    "verschlampt": "verschlampen",
    "verschlampte": "verschlampen",
    "verschlamptem": "verschlampt",
    "verschlampten": "verschlampen",
    "verschlampter": "verschlampt",
    "verschlamptere": "verschlampt",
    "verschlampterem": "verschlampt",
    "verschlampteren": "verschlampt",
    "verschlampterer": "verschlampt",
    "verschlampteres": "verschlampt",
    "verschlamptes": "verschlampt",
    "verschlamptest": "verschlampen",
    "verschlampteste": "verschlampt",
    "verschlamptestem": "verschlampt",
    "verschlamptesten": "verschlampt",
    "verschlamptester": "verschlampt",
    "verschlamptestes": "verschlampt",
    "verschlamptet": "verschlampen",
    "verschlang": "verschlingen",
    "verschlangen": "verschlingen",
    "verschlangst": "verschlingen",
    "verschlangt": "verschlingen",
    "verschlechtere": "verschlechtern",
    "verschlechternd": "verschlechtern",
    "verschlechternde": "verschlechternd",
    "verschlechterndem": "verschlechternd",
    "verschlechternden": "verschlechternd",
    "verschlechternder": "verschlechternd",
    "verschlechterndes": "verschlechternd",
    "verschlechterst": "verschlechtern",
    "verschlechtert": "verschlechtern",
    "verschlechterte": "verschlechtern",
    "verschlechtertem": "verschlechtert",
    "verschlechterten": "verschlechtern",
    "verschlechterter": "verschlechtert",
    "verschlechtertes": "verschlechtert",
    "verschlechtertest": "verschlechtern",
    "verschlechtertet": "verschlechtern",
    "verschleiere": "verschleiern",
    "verschleiernd": "verschleiern",
    "verschleiernde": "verschleiernd",
    "verschleierndem": "verschleiernd",
    "verschleiernden": "verschleiernd",
    "verschleiernder": "verschleiernd",
    "verschleierndere": "verschleiernd",
    "verschleiernderem": "verschleiernd",
    "verschleiernderen": "verschleiernd",
    "verschleiernderer": "verschleiernd",
    "verschleiernderes": "verschleiernd",
    "verschleierndes": "verschleiernd",
    "verschleierndste": "verschleiernd",
    "verschleierndstem": "verschleiernd",
    "verschleierndsten": "verschleiernd",
    "verschleierndster": "verschleiernd",
    "verschleierndstes": "verschleiernd",
    "verschleierst": "verschleiern",
    "verschleiert": "verschleiern",
    "verschleierte": "verschleiern",
    "verschleiertem": "verschleiert",
    "verschleierten": "verschleiern",
    "verschleierter": "verschleiert",
    "verschleiertere": "verschleiert",
    "verschleierterem": "verschleiert",
    "verschleierteren": "verschleiert",
    "verschleierterer": "verschleiert",
    "verschleierteres": "verschleiert",
    "verschleiertes": "verschleiert",
    "verschleiertest": "verschleiern",
    "verschleierteste": "verschleiert",
    "verschleiertestem": "verschleiert",
    "verschleiertesten": "verschleiert",
    "verschleiertester": "verschleiert",
    "verschleiertestes": "verschleiert",
    "verschleiertet": "verschleiern",
    "verschleime": "verschleimen",
    "verschleimend": "verschleimen",
    "verschleimende": "verschleimend",
    "verschleimendem": "verschleimend",
    "verschleimenden": "verschleimend",
    "verschleimender": "verschleimend",
    "verschleimendere": "verschleimend",
    "verschleimenderem": "verschleimend",
    "verschleimenderen": "verschleimend",
    "verschleimenderer": "verschleimend",
    "verschleimenderes": "verschleimend",
    "verschleimendes": "verschleimend",
    "verschleimendste": "verschleimend",
    "verschleimendstem": "verschleimend",
    "verschleimendsten": "verschleimend",
    "verschleimendster": "verschleimend",
    "verschleimendstes": "verschleimend",
    "verschleimest": "verschleimen",
    "verschleimet": "verschleimen",
    "verschleimst": "verschleimen",
    "verschleimt": "verschleimen",
    "verschleimte": "verschleimen",
    "verschleimtem": "verschleimt",
    "verschleimten": "verschleimen",
    "verschleimter": "verschleimt",
    "verschleimtere": "verschleimt",
    "verschleimterem": "verschleimt",
    "verschleimteren": "verschleimt",
    "verschleimterer": "verschleimt",
    "verschleimteres": "verschleimt",
    "verschleimtes": "verschleimt",
    "verschleimtest": "verschleimen",
    "verschleimteste": "verschleimt",
    "verschleimtestem": "verschleimt",
    "verschleimtesten": "verschleimt",
    "verschleimtester": "verschleimt",
    "verschleimtestes": "verschleimt",
    "verschleimtet": "verschleimen",
    "verschleiße": "verschleißen",
    "verschleißend": "verschleißen",
    "verschleißende": "verschleißend",
    "verschleißendem": "verschleißend",
    "verschleißenden": "verschleißend",
    "verschleißender": "verschleißend",
    "verschleißendes": "verschleißend",
    "verschleißest": "verschleißen",
    "verschleißet": "verschleißen",
    "verschleißt": "verschleißen",
    "verschleppe": "verschleppen",
    "verschleppend": "verschleppen",
    "verschleppende": "verschleppend",
    "verschleppendem": "verschleppend",
    "verschleppenden": "verschleppend",
    "verschleppender": "verschleppend",
    "verschleppendes": "verschleppend",
    "verschleppest": "verschleppen",
    "verschleppet": "verschleppen",
    "verschleppst": "verschleppen",
    "verschleppt": "verschleppen",
    "verschleppte": "verschleppen",
    "verschlepptem": "verschleppt",
    "verschleppten": "verschleppen",
    "verschleppter": "verschleppt",
    "verschlepptes": "verschleppt",
    "verschlepptest": "verschleppen",
    "verschlepptet": "verschleppen",
    "verschleudere": "verschleudern",
    "verschleudernd": "verschleudern",
    "verschleudernde": "verschleudernd",
    "verschleuderndem": "verschleudernd",
    "verschleudernden": "verschleudernd",
    "verschleudernder": "verschleudernd",
    "verschleuderndes": "verschleudernd",
    "verschleuderst": "verschleudern",
    "verschleudert": "verschleudern",
    "verschleuderte": "verschleudern",
    "verschleudertem": "verschleudert",
    "verschleuderten": "verschleudern",
    "verschleuderter": "verschleudert",
    "verschleudertere": "verschleudert",
    "verschleuderterem": "verschleudert",
    "verschleuderteren": "verschleudert",
    "verschleuderterer": "verschleudert",
    "verschleuderteres": "verschleudert",
    "verschleudertes": "verschleudert",
    "verschleudertest": "verschleudern",
    "verschleudertestem": "verschleudert",
    "verschleudertesten": "verschleudert",
    "verschleudertester": "verschleudert",
    "verschleudertestes": "verschleudert",
    "verschleudertet": "verschleudern",
    "verschlief": "verschlafen",
    "verschliefe": "verschlafen",
    "verschliefen": "verschlafen",
    "verschliefest": "verschlafen",
    "verschliefet": "verschlafen",
    "verschliefst": "verschlafen",
    "verschlieft": "verschlafen",
    "verschließe": "verschließen",
    "verschließend": "verschließen",
    "verschließende": "verschließend",
    "verschließendem": "verschließend",
    "verschließenden": "verschließend",
    "verschließender": "verschließend",
    "verschließendes": "verschließend",
    "verschließest": "verschließen",
    "verschließet": "verschließen",
    "verschließt": "verschließen",
    "verschlimmbessere": "verschlimmbessern",
    "verschlimmbessernd": "verschlimmbessern",
    "verschlimmbessernde": "verschlimmbessernd",
    "verschlimmbesserndem": "verschlimmbessernd",
    "verschlimmbessernden": "verschlimmbessernd",
    "verschlimmbessernder": "verschlimmbessernd",
    "verschlimmbesserndes": "verschlimmbessernd",
    "verschlimmbesserst": "verschlimmbessern",
    "verschlimmbessert": "verschlimmbessern",
    "verschlimmbesserte": "verschlimmbessern",
    "verschlimmbessertem": "verschlimmbessert",
    "verschlimmbesserten": "verschlimmbessern",
    "verschlimmbesserter": "verschlimmbessert",
    "verschlimmbessertes": "verschlimmbessert",
    "verschlimmbessertest": "verschlimmbessern",
    "verschlimmbessertet": "verschlimmbessern",
    "verschlimmere": "verschlimmern",
    "verschlimmernd": "verschlimmern",
    "verschlimmernde": "verschlimmernd",
    "verschlimmerndem": "verschlimmernd",
    "verschlimmernden": "verschlimmernd",
    "verschlimmernder": "verschlimmernd",
    "verschlimmerndes": "verschlimmernd",
    "verschlimmerst": "verschlimmern",
    "verschlimmert": "verschlimmern",
    "verschlimmerte": "verschlimmern",
    "verschlimmertem": "verschlimmert",
    "verschlimmerten": "verschlimmern",
    "verschlimmerter": "verschlimmert",
    "verschlimmertes": "verschlimmert",
    "verschlimmertest": "verschlimmern",
    "verschlimmertet": "verschlimmern",
    "verschlinge": "verschlingen",
    "verschlingend": "verschlingen",
    "verschlingende": "verschlingend",
    "verschlingendem": "verschlingend",
    "verschlingenden": "verschlingend",
    "verschlingender": "verschlingend",
    "verschlingendere": "verschlingend",
    "verschlingenderem": "verschlingend",
    "verschlingenderen": "verschlingend",
    "verschlingenderer": "verschlingend",
    "verschlingenderes": "verschlingend",
    "verschlingendes": "verschlingend",
    "verschlingendste": "verschlingend",
    "verschlingendstem": "verschlingend",
    "verschlingendsten": "verschlingend",
    "verschlingendster": "verschlingend",
    "verschlingendstes": "verschlingend",
    "verschlingest": "verschlingen",
    "verschlinget": "verschlingen",
    "verschlingst": "verschlingen",
    "verschlingt": "verschlingen",
    "verschlisse": "verschleißen",
    "verschlissen": "verschleißen",
    "verschlissene": "verschlissen",
    "verschlissenem": "verschlissen",
    "verschlissenen": "verschlissen",
    "verschlissener": "verschlissen",
    "verschlissenere": "verschlissen",
    "verschlissenerem": "verschlissen",
    "verschlisseneren": "verschlissen",
    "verschlissenerer": "verschlissen",
    "verschlisseneres": "verschlissen",
    "verschlissenes": "verschlissen",
    "verschlissenste": "verschlissen",
    "verschlissenstem": "verschlissen",
    "verschlissensten": "verschlissen",
    "verschlissenster": "verschlissen",
    "verschlissenstes": "verschlissen",
    "verschlissest": "verschleißen",
    "verschlisset": "verschleißen",
    "verschliß": "verschleißen",
    "verschlißt": "verschleißen",
    "verschlossen": "verschließen",
    "verschlossene": "verschlossen",
    "verschlossenem": "verschlossen",
    "verschlossenen": "verschlossen",
    "verschlossener": "verschlossen",
    "verschlossenere": "verschlossen",
    "verschlossenerem": "verschlossen",
    "verschlosseneren": "verschlossen",
    "verschlossenerer": "verschlossen",
    "verschlosseneres": "verschlossen",
    "verschlossenes": "verschlossen",
    "verschlossenste": "verschlossen",
    "verschlossenstem": "verschlossen",
    "verschlossensten": "verschlossen",
    "verschlossenster": "verschlossen",
    "verschlossenstes": "verschlossen",
    "verschloß": "verschließen",
    "verschloßt": "verschließen",
    "verschlucke": "verschlucken",
    "verschluckend": "verschlucken",
    "verschluckende": "verschluckend",
    "verschluckendem": "verschluckend",
    "verschluckenden": "verschluckend",
    "verschluckender": "verschluckend",
    "verschluckendes": "verschluckend",
    "verschluckest": "verschlucken",
    "verschlucket": "verschlucken",
    "verschluckst": "verschlucken",
    "verschluckt": "verschlucken",
    "verschluckte": "verschlucken",
    "verschlucktem": "verschluckt",
    "verschluckten": "verschlucken",
    "verschluckter": "verschluckt",
    "verschlucktes": "verschluckt",
    "verschlucktest": "verschlucken",
    "verschlucktet": "verschlucken",
    "verschludere": "verschludern",
    "verschludernd": "verschludern",
    "verschludernde": "verschludernd",
    "verschluderndem": "verschludernd",
    "verschludernden": "verschludernd",
    "verschludernder": "verschludernd",
    "verschluderndes": "verschludernd",
    "verschluderst": "verschludern",
    "verschludert": "verschludern",
    "verschluderte": "verschludern",
    "verschludertem": "verschludert",
    "verschluderten": "verschludern",
    "verschluderter": "verschludert",
    "verschludertes": "verschludert",
    "verschludertest": "verschludern",
    "verschludertet": "verschludern",
    "verschlug": "verschlagen",
    "verschlugen": "verschlagen",
    "verschlugst": "verschlagen",
    "verschlugt": "verschlagen",
    "verschlungen": "verschlingen",
    "verschlungene": "verschlungen",
    "verschlungenem": "verschlungen",
    "verschlungenen": "verschlungen",
    "verschlungener": "verschlungen",
    "verschlungenere": "verschlungen",
    "verschlungenerem": "verschlungen",
    "verschlungeneren": "verschlungen",
    "verschlungenerer": "verschlungen",
    "verschlungeneres": "verschlungen",
    "verschlungenes": "verschlungen",
    "verschlungenste": "verschlungen",
    "verschlungenstem": "verschlungen",
    "verschlungensten": "verschlungen",
    "verschlungenster": "verschlungen",
    "verschlungenstes": "verschlungen",
    "verschläfst": "verschlafen",
    "verschläft": "verschlafen",
    "verschlägst": "verschlagen",
    "verschlägt": "verschlagen",
    "verschlänge": "verschlingen",
    "verschlängen": "verschlingen",
    "verschlängest": "verschlingen",
    "verschlänget": "verschlingen",
    "verschlösse": "verschließen",
    "verschlössen": "verschließen",
    "verschlössest": "verschließen",
    "verschlösset": "verschließen",
    "verschlüge": "verschlagen",
    "verschlügen": "verschlagen",
    "verschlügest": "verschlagen",
    "verschlüget": "verschlagen",
    "verschlüssele": "verschlüsseln",
    "verschlüsselnd": "verschlüsseln",
    "verschlüsselnde": "verschlüsselnd",
    "verschlüsselndem": "verschlüsselnd",
    "verschlüsselnden": "verschlüsselnd",
    "verschlüsselnder": "verschlüsselnd",
    "verschlüsselndes": "verschlüsselnd",
    "verschlüsselst": "verschlüsseln",
    "verschlüsselt": "verschlüsseln",
    "verschlüsselte": "verschlüsseln",
    "verschlüsseltem": "verschlüsselt",
    "verschlüsselten": "verschlüsseln",
    "verschlüsselter": "verschlüsselt",
    "verschlüsseltes": "verschlüsselt",
    "verschlüsseltest": "verschlüsseln",
    "verschlüsseltet": "verschlüsseln",
    "verschlüssle": "verschlüsseln",
    "verschmelze": "verschmelzen",
    "verschmelzend": "verschmelzen",
    "verschmelzende": "verschmelzend",
    "verschmelzendem": "verschmelzend",
    "verschmelzenden": "verschmelzend",
    "verschmelzender": "verschmelzend",
    "verschmelzendere": "verschmelzend",
    "verschmelzenderem": "verschmelzend",
    "verschmelzenderen": "verschmelzend",
    "verschmelzenderer": "verschmelzend",
    "verschmelzenderes": "verschmelzend",
    "verschmelzendes": "verschmelzend",
    "verschmelzendste": "verschmelzend",
    "verschmelzendstem": "verschmelzend",
    "verschmelzendsten": "verschmelzend",
    "verschmelzendster": "verschmelzend",
    "verschmelzendstes": "verschmelzend",
    "verschmelzest": "verschmelzen",
    "verschmelzet": "verschmelzen",
    "verschmelzt": "verschmelzen",
    "verschmerze": "verschmerzen",
    "verschmerzend": "verschmerzen",
    "verschmerzende": "verschmerzend",
    "verschmerzendem": "verschmerzend",
    "verschmerzenden": "verschmerzend",
    "verschmerzender": "verschmerzend",
    "verschmerzendes": "verschmerzend",
    "verschmerzest": "verschmerzen",
    "verschmerzet": "verschmerzen",
    "verschmerzt": "verschmerzen",
    "verschmerzte": "verschmerzen",
    "verschmerztem": "verschmerzt",
    "verschmerzten": "verschmerzen",
    "verschmerzter": "verschmerzt",
    "verschmerztes": "verschmerzt",
    "verschmerztest": "verschmerzen",
    "verschmerztet": "verschmerzen",
    "verschmiere": "verschmieren",
    "verschmierend": "verschmieren",
    "verschmierende": "verschmierend",
    "verschmierendem": "verschmierend",
    "verschmierenden": "verschmierend",
    "verschmierender": "verschmierend",
    "verschmierendere": "verschmierend",
    "verschmierenderem": "verschmierend",
    "verschmierenderen": "verschmierend",
    "verschmierenderer": "verschmierend",
    "verschmierenderes": "verschmierend",
    "verschmierendes": "verschmierend",
    "verschmierendste": "verschmierend",
    "verschmierendstem": "verschmierend",
    "verschmierendsten": "verschmierend",
    "verschmierendster": "verschmierend",
    "verschmierendstes": "verschmierend",
    "verschmierest": "verschmieren",
    "verschmieret": "verschmieren",
    "verschmierst": "verschmieren",
    "verschmiert": "verschmieren",
    "verschmierte": "verschmieren",
    "verschmiertem": "verschmiert",
    "verschmierten": "verschmieren",
    "verschmierter": "verschmiert",
    "verschmiertere": "verschmiert",
    "verschmierterem": "verschmiert",
    "verschmierteren": "verschmiert",
    "verschmierterer": "verschmiert",
    "verschmierteres": "verschmiert",
    "verschmiertes": "verschmiert",
    "verschmiertest": "verschmieren",
    "verschmierteste": "verschmiert",
    "verschmiertestem": "verschmiert",
    "verschmiertesten": "verschmiert",
    "verschmiertester": "verschmiert",
    "verschmiertestes": "verschmiert",
    "verschmiertet": "verschmieren",
    "verschmilz": "verschmelzen",
    "verschmilzst": "verschmelzen",
    "verschmilzt": "verschmelzen",
    "verschmolz": "verschmelzen",
    "verschmolzen": "verschmelzen",
    "verschmolzene": "verschmolzen",
    "verschmolzenem": "verschmolzen",
    "verschmolzenen": "verschmolzen",
    "verschmolzener": "verschmolzen",
    "verschmolzenere": "verschmolzen",
    "verschmolzenerem": "verschmolzen",
    "verschmolzeneren": "verschmolzen",
    "verschmolzenerer": "verschmolzen",
    "verschmolzeneres": "verschmolzen",
    "verschmolzenes": "verschmolzen",
    "verschmolzenste": "verschmolzen",
    "verschmolzenstem": "verschmolzen",
    "verschmolzensten": "verschmolzen",
    "verschmolzenster": "verschmolzen",
    "verschmolzenstes": "verschmolzen",
    "verschmolzst": "verschmelzen",
    "verschmolzt": "verschmelzen",
    "verschmutze": "verschmutzen",
    "verschmutzend": "verschmutzen",
    "verschmutzende": "verschmutzend",
    "verschmutzendem": "verschmutzend",
    "verschmutzenden": "verschmutzend",
    "verschmutzender": "verschmutzend",
    "verschmutzendere": "verschmutzend",
    "verschmutzenderem": "verschmutzend",
    "verschmutzenderen": "verschmutzend",
    "verschmutzenderer": "verschmutzend",
    "verschmutzenderes": "verschmutzend",
    "verschmutzendes": "verschmutzend",
    "verschmutzendste": "verschmutzend",
    "verschmutzendstem": "verschmutzend",
    "verschmutzendsten": "verschmutzend",
    "verschmutzendster": "verschmutzend",
    "verschmutzendstes": "verschmutzend",
    "verschmutzest": "verschmutzen",
    "verschmutzet": "verschmutzen",
    "verschmutzt": "verschmutzen",
    "verschmutzte": "verschmutzen",
    "verschmutztem": "verschmutzt",
    "verschmutzten": "verschmutzen",
    "verschmutzter": "verschmutzt",
    "verschmutztere": "verschmutzt",
    "verschmutzterem": "verschmutzt",
    "verschmutzteren": "verschmutzt",
    "verschmutzterer": "verschmutzt",
    "verschmutzteres": "verschmutzt",
    "verschmutztes": "verschmutzt",
    "verschmutztest": "verschmutzen",
    "verschmutzteste": "verschmutzt",
    "verschmutztestem": "verschmutzt",
    "verschmutztesten": "verschmutzt",
    "verschmutztester": "verschmutzt",
    "verschmutztestes": "verschmutzt",
    "verschmutztet": "verschmutzen",
    "verschmähe": "verschmähen",
    "verschmähend": "verschmähen",
    "verschmähende": "verschmähend",
    "verschmähendem": "verschmähend",
    "verschmähenden": "verschmähend",
    "verschmähender": "verschmähend",
    "verschmähendere": "verschmähend",
    "verschmähenderem": "verschmähend",
    "verschmähenderen": "verschmähend",
    "verschmähenderer": "verschmähend",
    "verschmähenderes": "verschmähend",
    "verschmähendes": "verschmähend",
    "verschmähendste": "verschmähend",
    "verschmähendstem": "verschmähend",
    "verschmähendsten": "verschmähend",
    "verschmähendster": "verschmähend",
    "verschmähendstes": "verschmähend",
    "verschmähest": "verschmähen",
    "verschmähet": "verschmähen",
    "verschmähst": "verschmähen",
    "verschmäht": "verschmähen",
    "verschmähte": "verschmähen",
    "verschmähtem": "verschmäht",
    "verschmähten": "verschmähen",
    "verschmähter": "verschmäht",
    "verschmähtere": "verschmäht",
    "verschmähterem": "verschmäht",
    "verschmähteren": "verschmäht",
    "verschmähterer": "verschmäht",
    "verschmähteres": "verschmäht",
    "verschmähtes": "verschmäht",
    "verschmähtest": "verschmähen",
    "verschmähteste": "verschmäht",
    "verschmähtestem": "verschmäht",
    "verschmähtesten": "verschmäht",
    "verschmähtester": "verschmäht",
    "verschmähtestes": "verschmäht",
    "verschmähtet": "verschmähen",
    "verschmölze": "verschmelzen",
    "verschmölzen": "verschmelzen",
    "verschmölzest": "verschmelzen",
    "verschmölzet": "verschmelzen",
    "verschnaufe": "verschnaufen",
    "verschnaufend": "verschnaufen",
    "verschnaufende": "verschnaufend",
    "verschnaufendem": "verschnaufend",
    "verschnaufenden": "verschnaufend",
    "verschnaufender": "verschnaufend",
    "verschnaufendere": "verschnaufend",
    "verschnaufenderem": "verschnaufend",
    "verschnaufenderen": "verschnaufend",
    "verschnaufenderer": "verschnaufend",
    "verschnaufenderes": "verschnaufend",
    "verschnaufendes": "verschnaufend",
    "verschnaufendste": "verschnaufend",
    "verschnaufendstem": "verschnaufend",
    "verschnaufendsten": "verschnaufend",
    "verschnaufendster": "verschnaufend",
    "verschnaufendstes": "verschnaufend",
    "verschnaufest": "verschnaufen",
    "verschnaufet": "verschnaufen",
    "verschnaufst": "verschnaufen",
    "verschnauft": "verschnaufen",
    "verschnaufte": "verschnaufen",
    "verschnauftem": "verschnauft",
    "verschnauften": "verschnaufen",
    "verschnaufter": "verschnauft",
    "verschnauftes": "verschnauft",
    "verschnauftest": "verschnaufen",
    "verschnauftet": "verschnaufen",
    "verschneide": "verschneiden",
    "verschneidend": "verschneiden",
    "verschneidende": "verschneidend",
    "verschneidendem": "verschneidend",
    "verschneidenden": "verschneidend",
    "verschneidender": "verschneidend",
    "verschneidendere": "verschneidend",
    "verschneidenderem": "verschneidend",
    "verschneidenderen": "verschneidend",
    "verschneidenderer": "verschneidend",
    "verschneidenderes": "verschneidend",
    "verschneidendes": "verschneidend",
    "verschneidendste": "verschneidend",
    "verschneidendstem": "verschneidend",
    "verschneidendsten": "verschneidend",
    "verschneidendster": "verschneidend",
    "verschneidendstes": "verschneidend",
    "verschneidest": "verschneiden",
    "verschneidet": "verschneiden",
    "verschneie": "verschneien",
    "verschneiend": "verschneien",
    "verschneiende": "verschneiend",
    "verschneiendem": "verschneiend",
    "verschneienden": "verschneiend",
    "verschneiender": "verschneiend",
    "verschneiendes": "verschneiend",
    "verschneiest": "verschneien",
    "verschneiet": "verschneien",
    "verschneist": "verschneien",
    "verschneit": "verschneien",
    "verschneite": "verschneien",
    "verschneitem": "verschneit",
    "verschneiten": "verschneien",
    "verschneiter": "verschneit",
    "verschneitere": "verschneit",
    "verschneiterem": "verschneit",
    "verschneiteren": "verschneit",
    "verschneiterer": "verschneit",
    "verschneiteres": "verschneit",
    "verschneites": "verschneit",
    "verschneitest": "verschneien",
    "verschneiteste": "verschneit",
    "verschneitestem": "verschneit",
    "verschneitesten": "verschneit",
    "verschneitester": "verschneit",
    "verschneitestes": "verschneit",
    "verschneitet": "verschneien",
    "verschnitt": "verschneiden",
    "verschnitte": "verschneiden",
    "verschnitten": "verschneiden",
    "verschnittene": "verschnitten",
    "verschnittenem": "verschnitten",
    "verschnittenen": "verschnitten",
    "verschnittener": "verschnitten",
    "verschnittenere": "verschnitten",
    "verschnittenerem": "verschnitten",
    "verschnitteneren": "verschnitten",
    "verschnittenerer": "verschnitten",
    "verschnitteneres": "verschnitten",
    "verschnittenes": "verschnitten",
    "verschnittenste": "verschnitten",
    "verschnittenstem": "verschnitten",
    "verschnittensten": "verschnitten",
    "verschnittenster": "verschnitten",
    "verschnittenstes": "verschnitten",
    "verschnittest": "verschneiden",
    "verschnittet": "verschneiden",
    "verschnupfe": "verschnupfen",
    "verschnupfend": "verschnupfen",
    "verschnupfende": "verschnupfend",
    "verschnupfendem": "verschnupfend",
    "verschnupfenden": "verschnupfend",
    "verschnupfender": "verschnupfend",
    "verschnupfendere": "verschnupfend",
    "verschnupfenderem": "verschnupfend",
    "verschnupfenderen": "verschnupfend",
    "verschnupfenderer": "verschnupfend",
    "verschnupfenderes": "verschnupfend",
    "verschnupfendes": "verschnupfend",
    "verschnupfendste": "verschnupfend",
    "verschnupfendstem": "verschnupfend",
    "verschnupfendsten": "verschnupfend",
    "verschnupfendster": "verschnupfend",
    "verschnupfendstes": "verschnupfend",
    "verschnupfest": "verschnupfen",
    "verschnupfet": "verschnupfen",
    "verschnupfst": "verschnupfen",
    "verschnupft": "verschnupfen",
    "verschnupfte": "verschnupfen",
    "verschnupftem": "verschnupft",
    "verschnupften": "verschnupfen",
    "verschnupfter": "verschnupft",
    "verschnupftere": "verschnupft",
    "verschnupfterem": "verschnupft",
    "verschnupfteren": "verschnupft",
    "verschnupfterer": "verschnupft",
    "verschnupfteres": "verschnupft",
    "verschnupftes": "verschnupft",
    "verschnupftest": "verschnupfen",
    "verschnupfteste": "verschnupft",
    "verschnupftestem": "verschnupft",
    "verschnupftesten": "verschnupft",
    "verschnupftester": "verschnupft",
    "verschnupftestes": "verschnupft",
    "verschnupftet": "verschnupfen",
    "verschnörkele": "verschnörkeln",
    "verschnörkelnd": "verschnörkeln",
    "verschnörkelnde": "verschnörkelnd",
    "verschnörkelndem": "verschnörkelnd",
    "verschnörkelnden": "verschnörkelnd",
    "verschnörkelnder": "verschnörkelnd",
    "verschnörkelndere": "verschnörkelnd",
    "verschnörkelnderem": "verschnörkelnd",
    "verschnörkelnderen": "verschnörkelnd",
    "verschnörkelnderer": "verschnörkelnd",
    "verschnörkelnderes": "verschnörkelnd",
    "verschnörkelndes": "verschnörkelnd",
    "verschnörkelndste": "verschnörkelnd",
    "verschnörkelndstem": "verschnörkelnd",
    "verschnörkelndsten": "verschnörkelnd",
    "verschnörkelndster": "verschnörkelnd",
    "verschnörkelndstes": "verschnörkelnd",
    "verschnörkelst": "verschnörkeln",
    "verschnörkelt": "verschnörkeln",
    "verschnörkelte": "verschnörkeln",
    "verschnörkeltem": "verschnörkelt",
    "verschnörkelten": "verschnörkeln",
    "verschnörkelter": "verschnörkelt",
    "verschnörkeltere": "verschnörkelt",
    "verschnörkelterem": "verschnörkelt",
    "verschnörkelteren": "verschnörkelt",
    "verschnörkelterer": "verschnörkelt",
    "verschnörkelteres": "verschnörkelt",
    "verschnörkeltes": "verschnörkelt",
    "verschnörkeltest": "verschnörkeln",
    "verschnörkeltestem": "verschnörkelt",
    "verschnörkeltesten": "verschnörkelt",
    "verschnörkeltester": "verschnörkelt",
    "verschnörkeltestes": "verschnörkelt",
    "verschnörkeltet": "verschnörkeln",
    "verschnörkle": "verschnörkeln",
    "verschnüre": "verschnüren",
    "verschnürend": "verschnüren",
    "verschnürende": "verschnürend",
    "verschnürendem": "verschnürend",
    "verschnürenden": "verschnürend",
    "verschnürender": "verschnürend",
    "verschnürendes": "verschnürend",
    "verschnürest": "verschnüren",
    "verschnüret": "verschnüren",
    "verschnürst": "verschnüren",
    "verschnürt": "verschnüren",
    "verschnürte": "verschnüren",
    "verschnürtem": "verschnürt",
    "verschnürten": "verschnüren",
    "verschnürter": "verschnürt",
    "verschnürtes": "verschnürt",
    "verschnürtest": "verschnüren",
    "verschnürtet": "verschnüren",
    "verschob": "verschieben",
    "verschoben": "verschieben",
    "verschobene": "verschoben",
    "verschobenem": "verschoben",
    "verschobenen": "verschoben",
    "verschobener": "verschoben",
    "verschobenes": "verschoben",
    "verschobst": "verschieben",
    "verschobt": "verschieben",
    "verschollene": "verschollen",
    "verschollenem": "verschollen",
    "verschollenen": "verschollen",
    "verschollener": "verschollen",
    "verschollenes": "verschollen",
    "verschone": "verschonen",
    "verschonend": "verschonen",
    "verschonende": "verschonend",
    "verschonendem": "verschonend",
    "verschonenden": "verschonend",
    "verschonender": "verschonend",
    "verschonendes": "verschonend",
    "verschonest": "verschonen",
    "verschonet": "verschonen",
    "verschonst": "verschonen",
    "verschont": "verschonen",
    "verschonte": "verschonen",
    "verschontem": "verschont",
    "verschonten": "verschonen",
    "verschonter": "verschont",
    "verschontes": "verschont",
    "verschontest": "verschonen",
    "verschontet": "verschonen",
    "verschossen": "verschießen",
    "verschossene": "verschossen",
    "verschossenem": "verschossen",
    "verschossenen": "verschossen",
    "verschossener": "verschossen",
    "verschossenere": "verschossen",
    "verschossenerem": "verschossen",
    "verschosseneren": "verschossen",
    "verschossenerer": "verschossen",
    "verschosseneres": "verschossen",
    "verschossenes": "verschossen",
    "verschossenste": "verschossen",
    "verschossenstem": "verschossen",
    "verschossensten": "verschossen",
    "verschossenster": "verschossen",
    "verschossenstes": "verschossen",
    "verschoß": "verschießen",
    "verschoßt": "verschießen",
    "verschramme": "verschrammen",
    "verschrammend": "verschrammen",
    "verschrammende": "verschrammend",
    "verschrammendem": "verschrammend",
    "verschrammenden": "verschrammend",
    "verschrammender": "verschrammend",
    "verschrammendere": "verschrammend",
    "verschrammenderem": "verschrammend",
    "verschrammenderen": "verschrammend",
    "verschrammenderer": "verschrammend",
    "verschrammenderes": "verschrammend",
    "verschrammendes": "verschrammend",
    "verschrammendste": "verschrammend",
    "verschrammendstem": "verschrammend",
    "verschrammendsten": "verschrammend",
    "verschrammendster": "verschrammend",
    "verschrammendstes": "verschrammend",
    "verschrammest": "verschrammen",
    "verschrammet": "verschrammen",
    "verschrammst": "verschrammen",
    "verschrammt": "verschrammen",
    "verschrammte": "verschrammen",
    "verschrammtem": "verschrammt",
    "verschrammten": "verschrammen",
    "verschrammter": "verschrammt",
    "verschrammtere": "verschrammt",
    "verschrammterem": "verschrammt",
    "verschrammteren": "verschrammt",
    "verschrammterer": "verschrammt",
    "verschrammteres": "verschrammt",
    "verschrammtes": "verschrammt",
    "verschrammtest": "verschrammen",
    "verschrammteste": "verschrammt",
    "verschrammtestem": "verschrammt",
    "verschrammtesten": "verschrammt",
    "verschrammtester": "verschrammt",
    "verschrammtestes": "verschrammt",
    "verschrammtet": "verschrammen",
    "verschraube": "verschrauben",
    "verschraubend": "verschrauben",
    "verschraubende": "verschraubend",
    "verschraubendem": "verschraubend",
    "verschraubenden": "verschraubend",
    "verschraubender": "verschraubend",
    "verschraubendes": "verschraubend",
    "verschraubest": "verschrauben",
    "verschraubet": "verschrauben",
    "verschraubst": "verschrauben",
    "verschraubt": "verschrauben",
    "verschraubte": "verschrauben",
    "verschraubtem": "verschraubt",
    "verschraubten": "verschrauben",
    "verschraubter": "verschraubt",
    "verschraubtes": "verschraubt",
    "verschraubtest": "verschrauben",
    "verschraubtet": "verschrauben",
    "verschrecke": "verschrecken",
    "verschreckend": "verschrecken",
    "verschreckende": "verschreckend",
    "verschreckendem": "verschreckend",
    "verschreckenden": "verschreckend",
    "verschreckender": "verschreckend",
    "verschreckendere": "verschreckend",
    "verschreckenderem": "verschreckend",
    "verschreckenderen": "verschreckend",
    "verschreckenderer": "verschreckend",
    "verschreckenderes": "verschreckend",
    "verschreckendes": "verschreckend",
    "verschreckendste": "verschreckend",
    "verschreckendstem": "verschreckend",
    "verschreckendsten": "verschreckend",
    "verschreckendster": "verschreckend",
    "verschreckendstes": "verschreckend",
    "verschreckest": "verschrecken",
    "verschrecket": "verschrecken",
    "verschreckst": "verschrecken",
    "verschreckt": "verschrecken",
    "verschreckte": "verschrecken",
    "verschrecktem": "verschreckt",
    "verschreckten": "verschrecken",
    "verschreckter": "verschreckt",
    "verschrecktere": "verschreckt",
    "verschreckterem": "verschreckt",
    "verschreckteren": "verschreckt",
    "verschreckterer": "verschreckt",
    "verschreckteres": "verschreckt",
    "verschrecktes": "verschreckt",
    "verschrecktest": "verschrecken",
    "verschreckteste": "verschreckt",
    "verschrecktestem": "verschreckt",
    "verschrecktesten": "verschreckt",
    "verschrecktester": "verschreckt",
    "verschrecktestes": "verschreckt",
    "verschrecktet": "verschrecken",
    "verschreibe": "verschreiben",
    "verschreibend": "verschreiben",
    "verschreibende": "verschreibend",
    "verschreibendem": "verschreibend",
    "verschreibenden": "verschreibend",
    "verschreibender": "verschreibend",
    "verschreibendes": "verschreibend",
    "verschreibest": "verschreiben",
    "verschreibet": "verschreiben",
    "verschreibst": "verschreiben",
    "verschreibt": "verschreiben",
    "verschreie": "verschreien",
    "verschreiend": "verschreien",
    "verschreiende": "verschreiend",
    "verschreiendem": "verschreiend",
    "verschreienden": "verschreiend",
    "verschreiender": "verschreiend",
    "verschreiendes": "verschreiend",
    "verschreiest": "verschreien",
    "verschreiet": "verschreien",
    "verschreist": "verschreien",
    "verschreit": "verschreien",
    "verschrie": "verschreien",
    "verschrieb": "verschreiben",
    "verschriebe": "verschreiben",
    "verschrieben": "verschreiben",
    "verschriebene": "verschrieben",
    "verschriebenem": "verschrieben",
    "verschriebenen": "verschrieben",
    "verschriebener": "verschrieben",
    "verschriebenere": "verschrieben",
    "verschriebenerem": "verschrieben",
    "verschriebeneren": "verschrieben",
    "verschriebenerer": "verschrieben",
    "verschriebeneres": "verschrieben",
    "verschriebenes": "verschrieben",
    "verschriebenste": "verschrieben",
    "verschriebenstem": "verschrieben",
    "verschriebensten": "verschrieben",
    "verschriebenster": "verschrieben",
    "verschriebenstes": "verschrieben",
    "verschriebest": "verschreiben",
    "verschriebet": "verschreiben",
    "verschriebst": "verschreiben",
    "verschriebt": "verschreiben",
    "verschriee": "verschreien",
    "verschrieen": "verschreien",
    "verschrieest": "verschreien",
    "verschrieet": "verschreien",
    "verschrien": "verschreien",
    "verschriene": "verschrien",
    "verschrienem": "verschrien",
    "verschrienen": "verschrien",
    "verschriener": "verschrien",
    "verschrienere": "verschrien",
    "verschrienerem": "verschrien",
    "verschrieneren": "verschrien",
    "verschrienerer": "verschrien",
    "verschrieneres": "verschrien",
    "verschrienes": "verschrien",
    "verschrienste": "verschrien",
    "verschrienstem": "verschrien",
    "verschriensten": "verschrien",
    "verschrienster": "verschrien",
    "verschrienstes": "verschrien",
    "verschriest": "verschreien",
    "verschriet": "verschreien",
    "verschrotte": "verschrotten",
    "verschrottend": "verschrotten",
    "verschrottende": "verschrottend",
    "verschrottendem": "verschrottend",
    "verschrottenden": "verschrottend",
    "verschrottender": "verschrottend",
    "verschrottendes": "verschrottend",
    "verschrottest": "verschrotten",
    "verschrottet": "verschrotten",
    "verschrottete": "verschrotten",
    "verschrottetem": "verschrottet",
    "verschrotteten": "verschrotten",
    "verschrotteter": "verschrottet",
    "verschrottetes": "verschrottet",
    "verschrottetest": "verschrotten",
    "verschrottetet": "verschrotten",
    "verschrumpele": "verschrumpeln",
    "verschrumpelnd": "verschrumpeln",
    "verschrumpelnde": "verschrumpelnd",
    "verschrumpelndem": "verschrumpelnd",
    "verschrumpelnden": "verschrumpelnd",
    "verschrumpelnder": "verschrumpelnd",
    "verschrumpelndere": "verschrumpelnd",
    "verschrumpelnderem": "verschrumpelnd",
    "verschrumpelnderen": "verschrumpelnd",
    "verschrumpelnderer": "verschrumpelnd",
    "verschrumpelnderes": "verschrumpelnd",
    "verschrumpelndes": "verschrumpelnd",
    "verschrumpelndste": "verschrumpelnd",
    "verschrumpelndstem": "verschrumpelnd",
    "verschrumpelndsten": "verschrumpelnd",
    "verschrumpelndster": "verschrumpelnd",
    "verschrumpelndstes": "verschrumpelnd",
    "verschrumpelst": "verschrumpeln",
    "verschrumpelt": "verschrumpeln",
    "verschrumpelte": "verschrumpeln",
    "verschrumpeltem": "verschrumpelt",
    "verschrumpelten": "verschrumpeln",
    "verschrumpelter": "verschrumpelt",
    "verschrumpeltere": "verschrumpelt",
    "verschrumpelterem": "verschrumpelt",
    "verschrumpelteren": "verschrumpelt",
    "verschrumpelterer": "verschrumpelt",
    "verschrumpelteres": "verschrumpelt",
    "verschrumpeltes": "verschrumpelt",
    "verschrumpeltest": "verschrumpeln",
    "verschrumpeltestem": "verschrumpelt",
    "verschrumpeltesten": "verschrumpelt",
    "verschrumpeltester": "verschrumpelt",
    "verschrumpeltestes": "verschrumpelt",
    "verschrumpeltet": "verschrumpeln",
    "verschrumple": "verschrumpeln",
    "verschränke": "verschränken",
    "verschränkend": "verschränken",
    "verschränkende": "verschränkend",
    "verschränkendem": "verschränkend",
    "verschränkenden": "verschränkend",
    "verschränkender": "verschränkend",
    "verschränkendes": "verschränkend",
    "verschränkest": "verschränken",
    "verschränket": "verschränken",
    "verschränkst": "verschränken",
    "verschränkt": "verschränken",
    "verschränkte": "verschränken",
    "verschränktem": "verschränkt",
    "verschränkten": "verschränken",
    "verschränkter": "verschränkt",
    "verschränktes": "verschränkt",
    "verschränktest": "verschränken",
    "verschränktet": "verschränken",
    "verschulde": "verschulden",
    "verschuldend": "verschulden",
    "verschuldende": "verschuldend",
    "verschuldendem": "verschuldend",
    "verschuldenden": "verschuldend",
    "verschuldender": "verschuldend",
    "verschuldendere": "verschuldend",
    "verschuldenderem": "verschuldend",
    "verschuldenderen": "verschuldend",
    "verschuldenderer": "verschuldend",
    "verschuldenderes": "verschuldend",
    "verschuldendes": "verschuldend",
    "verschuldendste": "verschuldend",
    "verschuldendstem": "verschuldend",
    "verschuldendsten": "verschuldend",
    "verschuldendster": "verschuldend",
    "verschuldendstes": "verschuldend",
    "verschuldest": "verschulden",
    "verschuldet": "verschulden",
    "verschuldete": "verschulden",
    "verschuldetem": "verschuldet",
    "verschuldeten": "verschulden",
    "verschuldeter": "verschuldet",
    "verschuldetere": "verschuldet",
    "verschuldeterem": "verschuldet",
    "verschuldeteren": "verschuldet",
    "verschuldeterer": "verschuldet",
    "verschuldeteres": "verschuldet",
    "verschuldetes": "verschuldet",
    "verschuldetest": "verschulden",
    "verschuldeteste": "verschuldet",
    "verschuldetestem": "verschuldet",
    "verschuldetesten": "verschuldet",
    "verschuldetester": "verschuldet",
    "verschuldetestes": "verschuldet",
    "verschuldetet": "verschulden",
    "verschwamm": "verschwimmen",
    "verschwammen": "verschwimmen",
    "verschwammst": "verschwimmen",
    "verschwammt": "verschwimmen",
    "verschwand": "verschwinden",
    "verschwanden": "verschwinden",
    "verschwandest": "verschwinden",
    "verschwandet": "verschwinden",
    "verschwatze": "verschwatzen",
    "verschwatzend": "verschwatzen",
    "verschwatzende": "verschwatzend",
    "verschwatzendem": "verschwatzend",
    "verschwatzenden": "verschwatzend",
    "verschwatzender": "verschwatzend",
    "verschwatzendere": "verschwatzend",
    "verschwatzenderem": "verschwatzend",
    "verschwatzenderen": "verschwatzend",
    "verschwatzenderer": "verschwatzend",
    "verschwatzenderes": "verschwatzend",
    "verschwatzendes": "verschwatzend",
    "verschwatzendste": "verschwatzend",
    "verschwatzendstem": "verschwatzend",
    "verschwatzendsten": "verschwatzend",
    "verschwatzendster": "verschwatzend",
    "verschwatzendstes": "verschwatzend",
    "verschwatzest": "verschwatzen",
    "verschwatzet": "verschwatzen",
    "verschwatzt": "verschwatzen",
    "verschwatzte": "verschwatzen",
    "verschwatztem": "verschwatzt",
    "verschwatzten": "verschwatzen",
    "verschwatzter": "verschwatzt",
    "verschwatztere": "verschwatzt",
    "verschwatzterem": "verschwatzt",
    "verschwatzteren": "verschwatzt",
    "verschwatzterer": "verschwatzt",
    "verschwatzteres": "verschwatzt",
    "verschwatztes": "verschwatzt",
    "verschwatztest": "verschwatzen",
    "verschwatzteste": "verschwatzt",
    "verschwatztestem": "verschwatzt",
    "verschwatztesten": "verschwatzt",
    "verschwatztester": "verschwatzt",
    "verschwatztestes": "verschwatzt",
    "verschwatztet": "verschwatzen",
    "verschweige": "verschweigen",
    "verschweigend": "verschweigen",
    "verschweigende": "verschweigend",
    "verschweigendem": "verschweigend",
    "verschweigenden": "verschweigend",
    "verschweigender": "verschweigend",
    "verschweigendere": "verschweigend",
    "verschweigenderem": "verschweigend",
    "verschweigenderen": "verschweigend",
    "verschweigenderer": "verschweigend",
    "verschweigenderes": "verschweigend",
    "verschweigendes": "verschweigend",
    "verschweigendste": "verschweigend",
    "verschweigendstem": "verschweigend",
    "verschweigendsten": "verschweigend",
    "verschweigendster": "verschweigend",
    "verschweigendstes": "verschweigend",
    "verschweigest": "verschweigen",
    "verschweiget": "verschweigen",
    "verschweigst": "verschweigen",
    "verschweigt": "verschweigen",
    "verschweiße": "verschweißen",
    "verschweißend": "verschweißen",
    "verschweißende": "verschweißend",
    "verschweißendem": "verschweißend",
    "verschweißenden": "verschweißend",
    "verschweißender": "verschweißend",
    "verschweißendes": "verschweißend",
    "verschweißest": "verschweißen",
    "verschweißet": "verschweißen",
    "verschweißt": "verschweißen",
    "verschweißte": "verschweißen",
    "verschweißtem": "verschweißt",
    "verschweißten": "verschweißen",
    "verschweißter": "verschweißt",
    "verschweißtes": "verschweißt",
    "verschweißtest": "verschweißen",
    "verschweißtet": "verschweißen",
    "verschwende": "verschwenden",
    "verschwendend": "verschwenden",
    "verschwendende": "verschwendend",
    "verschwendendem": "verschwendend",
    "verschwendenden": "verschwendend",
    "verschwendender": "verschwendend",
    "verschwendendere": "verschwendend",
    "verschwendenderem": "verschwendend",
    "verschwendenderen": "verschwendend",
    "verschwendenderer": "verschwendend",
    "verschwendenderes": "verschwendend",
    "verschwendendes": "verschwendend",
    "verschwendendste": "verschwendend",
    "verschwendendstem": "verschwendend",
    "verschwendendsten": "verschwendend",
    "verschwendendster": "verschwendend",
    "verschwendendstes": "verschwendend",
    "verschwenderischem": "verschwenderisch",
    "verschwenderischen": "verschwenderisch",
    "verschwenderischer": "verschwenderisch",
    "verschwenderischere": "verschwenderisch",
    "verschwenderischerem": "verschwenderisch",
    "verschwenderischeren": "verschwenderisch",
    "verschwenderischerer": "verschwenderisch",
    "verschwenderischeres": "verschwenderisch",
    "verschwenderisches": "verschwenderisch",
    "verschwenderischste": "verschwenderisch",
    "verschwenderischstem": "verschwenderisch",
    "verschwenderischsten": "verschwenderisch",
    "verschwenderischster": "verschwenderisch",
    "verschwenderischstes": "verschwenderisch",
    "verschwendest": "verschwenden",
    "verschwendet": "verschwenden",
    "verschwendete": "verschwenden",
    "verschwendetem": "verschwendet",
    "verschwendeten": "verschwenden",
    "verschwendeter": "verschwendet",
    "verschwendetere": "verschwendet",
    "verschwendeterem": "verschwendet",
    "verschwendeteren": "verschwendet",
    "verschwendeterer": "verschwendet",
    "verschwendeteres": "verschwendet",
    "verschwendetes": "verschwendet",
    "verschwendetest": "verschwenden",
    "verschwendeteste": "verschwendet",
    "verschwendetestem": "verschwendet",
    "verschwendetesten": "verschwendet",
    "verschwendetester": "verschwendet",
    "verschwendetestes": "verschwendet",
    "verschwendetet": "verschwenden",
    "verschwieg": "verschweigen",
    "verschwiege": "verschweigen",
    "verschwiegen": "verschweigen",
    "verschwiegene": "verschwiegen",
    "verschwiegenem": "verschwiegen",
    "verschwiegenen": "verschwiegen",
    "verschwiegener": "verschwiegen",
    "verschwiegenere": "verschwiegen",
    "verschwiegenerem": "verschwiegen",
    "verschwiegeneren": "verschwiegen",
    "verschwiegenerer": "verschwiegen",
    "verschwiegeneres": "verschwiegen",
    "verschwiegenes": "verschwiegen",
    "verschwiegenste": "verschwiegen",
    "verschwiegenstem": "verschwiegen",
    "verschwiegensten": "verschwiegen",
    "verschwiegenster": "verschwiegen",
    "verschwiegenstes": "verschwiegen",
    "verschwiegest": "verschweigen",
    "verschwieget": "verschweigen",
    "verschwiegst": "verschweigen",
    "verschwiegt": "verschweigen",
    "verschwimme": "verschwimmen",
    "verschwimmend": "verschwimmen",
    "verschwimmende": "verschwimmend",
    "verschwimmendem": "verschwimmend",
    "verschwimmenden": "verschwimmend",
    "verschwimmender": "verschwimmend",
    "verschwimmendere": "verschwimmend",
    "verschwimmenderem": "verschwimmend",
    "verschwimmenderen": "verschwimmend",
    "verschwimmenderer": "verschwimmend",
    "verschwimmenderes": "verschwimmend",
    "verschwimmendes": "verschwimmend",
    "verschwimmendste": "verschwimmend",
    "verschwimmendstem": "verschwimmend",
    "verschwimmendsten": "verschwimmend",
    "verschwimmendster": "verschwimmend",
    "verschwimmendstes": "verschwimmend",
    "verschwimmest": "verschwimmen",
    "verschwimmet": "verschwimmen",
    "verschwimmst": "verschwimmen",
    "verschwimmt": "verschwimmen",
    "verschwinde": "verschwinden",
    "verschwindend": "verschwinden",
    "verschwindende": "verschwindend",
    "verschwindendem": "verschwindend",
    "verschwindenden": "verschwindend",
    "verschwindender": "verschwindend",
    "verschwindendes": "verschwindend",
    "verschwindest": "verschwinden",
    "verschwindet": "verschwinden",
    "verschwitze": "verschwitzen",
    "verschwitzend": "verschwitzen",
    "verschwitzende": "verschwitzend",
    "verschwitzendem": "verschwitzend",
    "verschwitzenden": "verschwitzend",
    "verschwitzender": "verschwitzend",
    "verschwitzendere": "verschwitzend",
    "verschwitzenderem": "verschwitzend",
    "verschwitzenderen": "verschwitzend",
    "verschwitzenderer": "verschwitzend",
    "verschwitzenderes": "verschwitzend",
    "verschwitzendes": "verschwitzend",
    "verschwitzendste": "verschwitzend",
    "verschwitzendstem": "verschwitzend",
    "verschwitzendsten": "verschwitzend",
    "verschwitzendster": "verschwitzend",
    "verschwitzendstes": "verschwitzend",
    "verschwitzest": "verschwitzen",
    "verschwitzet": "verschwitzen",
    "verschwitzt": "verschwitzen",
    "verschwitzte": "verschwitzen",
    "verschwitztem": "verschwitzt",
    "verschwitzten": "verschwitzen",
    "verschwitzter": "verschwitzt",
    "verschwitztere": "verschwitzt",
    "verschwitzterem": "verschwitzt",
    "verschwitzteren": "verschwitzt",
    "verschwitzterer": "verschwitzt",
    "verschwitzteres": "verschwitzt",
    "verschwitztes": "verschwitzt",
    "verschwitztest": "verschwitzen",
    "verschwitzteste": "verschwitzt",
    "verschwitztestem": "verschwitzt",
    "verschwitztesten": "verschwitzt",
    "verschwitztester": "verschwitzt",
    "verschwitztestes": "verschwitzt",
    "verschwitztet": "verschwitzen",
    "verschwommen": "verschwimmen",
    "verschwommene": "verschwommen",
    "verschwommenem": "verschwommen",
    "verschwommenen": "verschwommen",
    "verschwommener": "verschwommen",
    "verschwommenere": "verschwommen",
    "verschwommenerem": "verschwommen",
    "verschwommeneren": "verschwommen",
    "verschwommenerer": "verschwommen",
    "verschwommeneres": "verschwommen",
    "verschwommenes": "verschwommen",
    "verschwommenste": "verschwommen",
    "verschwommenstem": "verschwommen",
    "verschwommensten": "verschwommen",
    "verschwommenster": "verschwommen",
    "verschwommenstes": "verschwommen",
    "verschwor": "verschwören",
    "verschworen": "verschwören",
    "verschworene": "verschworen",
    "verschworenem": "verschworen",
    "verschworenen": "verschworen",
    "verschworener": "verschworen",
    "verschworenere": "verschworen",
    "verschworenerem": "verschworen",
    "verschworeneren": "verschworen",
    "verschworenerer": "verschworen",
    "verschworeneres": "verschworen",
    "verschworenes": "verschworen",
    "verschworenstem": "verschworen",
    "verschworensten": "verschworen",
    "verschworenster": "verschworen",
    "verschworenstes": "verschworen",
    "verschworst": "verschwören",
    "verschwort": "verschwören",
    "verschwunden": "verschwinden",
    "verschwundene": "verschwunden",
    "verschwundenem": "verschwunden",
    "verschwundenen": "verschwunden",
    "verschwundener": "verschwunden",
    "verschwundenes": "verschwunden",
    "verschwägere": "verschwägern",
    "verschwägernd": "verschwägern",
    "verschwägernde": "verschwägernd",
    "verschwägerndem": "verschwägernd",
    "verschwägernden": "verschwägernd",
    "verschwägernder": "verschwägernd",
    "verschwägerndes": "verschwägernd",
    "verschwägerst": "verschwägern",
    "verschwägert": "verschwägern",
    "verschwägerte": "verschwägern",
    "verschwägertem": "verschwägert",
    "verschwägerten": "verschwägern",
    "verschwägerter": "verschwägert",
    "verschwägertes": "verschwägert",
    "verschwägertest": "verschwägern",
    "verschwägertet": "verschwägern",
    "verschwämme": "verschwimmen",
    "verschwämmen": "verschwimmen",
    "verschwämmest": "verschwimmen",
    "verschwämmet": "verschwimmen",
    "verschwände": "verschwinden",
    "verschwänden": "verschwinden",
    "verschwändest": "verschwinden",
    "verschwändet": "verschwinden",
    "verschwöre": "verschwören",
    "verschwörend": "verschwören",
    "verschwörende": "verschwörend",
    "verschwörendem": "verschwörend",
    "verschwörenden": "verschwörend",
    "verschwörender": "verschwörend",
    "verschwörendes": "verschwörend",
    "verschwörest": "verschwören",
    "verschwöret": "verschwören",
    "verschwörst": "verschwören",
    "verschwört": "verschwören",
    "verschärfe": "verschärfen",
    "verschärfend": "verschärfen",
    "verschärfende": "verschärfend",
    "verschärfendem": "verschärfend",
    "verschärfenden": "verschärfend",
    "verschärfender": "verschärfend",
    "verschärfendes": "verschärfend",
    "verschärfest": "verschärfen",
    "verschärfet": "verschärfen",
    "verschärfst": "verschärfen",
    "verschärft": "verschärfen",
    "verschärfte": "verschärfen",
    "verschärftem": "verschärft",
    "verschärften": "verschärfen",
    "verschärfter": "verschärft",
    "verschärftere": "verschärft",
    "verschärfterem": "verschärft",
    "verschärfteren": "verschärft",
    "verschärfterer": "verschärft",
    "verschärfteres": "verschärft",
    "verschärftes": "verschärft",
    "verschärftest": "verschärfen",
    "verschärfteste": "verschärft",
    "verschärftestem": "verschärft",
    "verschärftesten": "verschärft",
    "verschärftester": "verschärft",
    "verschärftestes": "verschärft",
    "verschärftet": "verschärfen",
    "verschätze": "verschätzen",
    "verschätzend": "verschätzen",
    "verschätzende": "verschätzend",
    "verschätzendem": "verschätzend",
    "verschätzenden": "verschätzend",
    "verschätzender": "verschätzend",
    "verschätzendes": "verschätzend",
    "verschätzest": "verschätzen",
    "verschätzet": "verschätzen",
    "verschätzt": "verschätzen",
    "verschätzte": "verschätzen",
    "verschätztem": "verschätzt",
    "verschätzten": "verschätzen",
    "verschätzter": "verschätzt",
    "verschätztes": "verschätzt",
    "verschätztest": "verschätzen",
    "verschätztet": "verschätzen",
    "verschöbe": "verschieben",
    "verschöben": "verschieben",
    "verschöbest": "verschieben",
    "verschöbet": "verschieben",
    "verschönere": "verschönern",
    "verschönernd": "verschönern",
    "verschönernde": "verschönernd",
    "verschönerndem": "verschönernd",
    "verschönernden": "verschönernd",
    "verschönernder": "verschönernd",
    "verschönerndes": "verschönernd",
    "verschönerst": "verschönern",
    "verschönert": "verschönern",
    "verschönerte": "verschönern",
    "verschönertem": "verschönert",
    "verschönerten": "verschönern",
    "verschönerter": "verschönert",
    "verschönertere": "verschönert",
    "verschönerterem": "verschönert",
    "verschönerteren": "verschönert",
    "verschönerterer": "verschönert",
    "verschönerteres": "verschönert",
    "verschönertes": "verschönert",
    "verschönertest": "verschönern",
    "verschönerteste": "verschönert",
    "verschönertestem": "verschönert",
    "verschönertesten": "verschönert",
    "verschönertester": "verschönert",
    "verschönertestes": "verschönert",
    "verschönertet": "verschönern",
    "verschösse": "verschießen",
    "verschössen": "verschießen",
    "verschössest": "verschießen",
    "verschösset": "verschießen",
    "verschüchtere": "verschüchtern",
    "verschüchternd": "verschüchtern",
    "verschüchternde": "verschüchternd",
    "verschüchterndem": "verschüchternd",
    "verschüchternden": "verschüchternd",
    "verschüchternder": "verschüchternd",
    "verschüchterndere": "verschüchternd",
    "verschüchternderem": "verschüchternd",
    "verschüchternderen": "verschüchternd",
    "verschüchternderer": "verschüchternd",
    "verschüchternderes": "verschüchternd",
    "verschüchterndes": "verschüchternd",
    "verschüchterndste": "verschüchternd",
    "verschüchterndstem": "verschüchternd",
    "verschüchterndsten": "verschüchternd",
    "verschüchterndster": "verschüchternd",
    "verschüchterndstes": "verschüchternd",
    "verschüchterst": "verschüchtern",
    "verschüchtert": "verschüchtern",
    "verschüchterte": "verschüchtern",
    "verschüchtertem": "verschüchtert",
    "verschüchterten": "verschüchtern",
    "verschüchterter": "verschüchtert",
    "verschüchtertere": "verschüchtert",
    "verschüchterterem": "verschüchtert",
    "verschüchterteren": "verschüchtert",
    "verschüchterterer": "verschüchtert",
    "verschüchterteres": "verschüchtert",
    "verschüchtertes": "verschüchtert",
    "verschüchtertest": "verschüchtern",
    "verschüchtertestem": "verschüchtert",
    "verschüchtertesten": "verschüchtert",
    "verschüchtertester": "verschüchtert",
    "verschüchtertestes": "verschüchtert",
    "verschüchtertet": "verschüchtern",
    "verschütte": "verschütten",
    "verschüttend": "verschütten",
    "verschüttende": "verschüttend",
    "verschüttendem": "verschüttend",
    "verschüttenden": "verschüttend",
    "verschüttender": "verschüttend",
    "verschüttendes": "verschüttend",
    "verschüttest": "verschütten",
    "verschüttet": "verschütten",
    "verschüttete": "verschütten",
    "verschüttetem": "verschüttet",
    "verschütteten": "verschütten",
    "verschütteter": "verschüttet",
    "verschüttetere": "verschüttet",
    "verschütteterem": "verschüttet",
    "verschütteteren": "verschüttet",
    "verschütteterer": "verschüttet",
    "verschütteteres": "verschüttet",
    "verschüttetes": "verschüttet",
    "verschüttetest": "verschütten",
    "verschütteteste": "verschüttet",
    "verschüttetestem": "verschüttet",
    "verschüttetesten": "verschüttet",
    "verschüttetester": "verschüttet",
    "verschüttetestes": "verschüttet",
    "verschüttetet": "verschütten",
    "verschüttgegangen": "verschüttgehen",
    "verschüttgegangene": "verschüttgegangen",
    "verschüttgegangenem": "verschüttgegangen",
    "verschüttgegangenen": "verschüttgegangen",
    "verschüttgegangener": "verschüttgegangen",
    "verschüttgegangenes": "verschüttgegangen",
    "verschüttgehe": "verschüttgehen",
    "verschüttgehend": "verschüttgehen",
    "verschüttgehende": "verschüttgehend",
    "verschüttgehendem": "verschüttgehend",
    "verschüttgehenden": "verschüttgehend",
    "verschüttgehender": "verschüttgehend",
    "verschüttgehendes": "verschüttgehend",
    "verschüttgehest": "verschüttgehen",
    "verschüttgehet": "verschüttgehen",
    "verschüttgehst": "verschüttgehen",
    "verschüttgeht": "verschüttgehen",
    "verschüttging": "verschüttgehen",
    "verschüttginge": "verschüttgehen",
    "verschüttgingen": "verschüttgehen",
    "verschüttgingest": "verschüttgehen",
    "verschüttginget": "verschüttgehen",
    "verschüttgingst": "verschüttgehen",
    "verschüttgingt": "verschüttgehen",
    "verschüttzugehen": "verschüttgehen",
    "versegele": "versegeln",
    "versegelnd": "versegeln",
    "versegelnde": "versegelnd",
    "versegelndem": "versegelnd",
    "versegelnden": "versegelnd",
    "versegelnder": "versegelnd",
    "versegelndes": "versegelnd",
    "versegelst": "versegeln",
    "versegelt": "versegeln",
    "versegelte": "versegeln",
    "versegeltem": "versegelt",
    "versegelten": "versegeln",
    "versegelter": "versegelt",
    "versegeltes": "versegelt",
    "versegeltest": "versegeln",
    "versegeltet": "versegeln",
    "versegle": "versegeln",
    "versehe": "versehen",
    "versehend": "versehen",
    "versehende": "versehend",
    "versehendem": "versehend",
    "versehenden": "versehend",
    "versehender": "versehend",
    "versehendes": "versehend",
    "versehene": "versehen",
    "versehenem": "versehen",
    "versehenen": "versehen",
    "versehener": "versehen",
    "versehenes": "versehen",
    "versehest": "versehen",
    "versehet": "versehen",
    "versehre": "versehren",
    "versehrend": "versehren",
    "versehrende": "versehrend",
    "versehrendem": "versehrend",
    "versehrenden": "versehrend",
    "versehrender": "versehrend",
    "versehrendes": "versehrend",
    "versehrest": "versehren",
    "versehret": "versehren",
    "versehrst": "versehren",
    "versehrt": "versehren",
    "versehrte": "versehren",
    "versehrtem": "versehrt",
    "versehrten": "versehren",
    "versehrter": "versehrt",
    "versehrtes": "versehrt",
    "versehrtest": "versehren",
    "versehrtet": "versehren",
    "verseht": "versehen",
    "verselbständige": "verselbständigen",
    "verselbständigend": "verselbständigen",
    "verselbständigende": "verselbständigend",
    "verselbständigendem": "verselbständigend",
    "verselbständigenden": "verselbständigend",
    "verselbständigender": "verselbständigend",
    "verselbständigendere": "verselbständigend",
    "verselbständigenderem": "verselbständigend",
    "verselbständigenderen": "verselbständigend",
    "verselbständigenderer": "verselbständigend",
    "verselbständigenderes": "verselbständigend",
    "verselbständigendes": "verselbständigend",
    "verselbständigendste": "verselbständigend",
    "verselbständigendstem": "verselbständigend",
    "verselbständigendsten": "verselbständigend",
    "verselbständigendster": "verselbständigend",
    "verselbständigendstes": "verselbständigend",
    "verselbständigest": "verselbständigen",
    "verselbständiget": "verselbständigen",
    "verselbständigst": "verselbständigen",
    "verselbständigt": "verselbständigen",
    "verselbständigte": "verselbständigen",
    "verselbständigtem": "verselbständigt",
    "verselbständigten": "verselbständigen",
    "verselbständigter": "verselbständigt",
    "verselbständigtere": "verselbständigt",
    "verselbständigterem": "verselbständigt",
    "verselbständigteren": "verselbständigt",
    "verselbständigterer": "verselbständigt",
    "verselbständigteres": "verselbständigt",
    "verselbständigtes": "verselbständigt",
    "verselbständigtest": "verselbständigen",
    "verselbständigteste": "verselbständigt",
    "verselbständigtestem": "verselbständigt",
    "verselbständigtesten": "verselbständigt",
    "verselbständigtester": "verselbständigt",
    "verselbständigtestes": "verselbständigt",
    "verselbständigtet": "verselbständigen",
    "versende": "versenden",
    "versendend": "versenden",
    "versendende": "versendend",
    "versendendem": "versendend",
    "versendenden": "versendend",
    "versendender": "versendend",
    "versendendes": "versendend",
    "versendest": "versenden",
    "versendet": "versenden",
    "versendete": "versenden",
    "versendetem": "versendet",
    "versendeten": "versenden",
    "versendeter": "versendet",
    "versendetes": "versendet",
    "versendetest": "versenden",
    "versendetet": "versenden",
    "versenke": "versenken",
    "versenkend": "versenken",
    "versenkende": "versenkend",
    "versenkendem": "versenkend",
    "versenkenden": "versenkend",
    "versenkender": "versenkend",
    "versenkendes": "versenkend",
    "versenkest": "versenken",
    "versenket": "versenken",
    "versenkst": "versenken",
    "versenkt": "versenken",
    "versenkte": "versenken",
    "versenktem": "versenkt",
    "versenkten": "versenken",
    "versenkter": "versenkt",
    "versenktes": "versenkt",
    "versenktest": "versenken",
    "versenktet": "versenken",
    "versessenem": "versessen",
    "versessenen": "versessen",
    "versessener": "versessen",
    "versessenere": "versessen",
    "versessenerem": "versessen",
    "versesseneren": "versessen",
    "versessenerer": "versessen",
    "versesseneres": "versessen",
    "versessenes": "versessen",
    "versessenste": "versessen",
    "versessenstem": "versessen",
    "versessensten": "versessen",
    "versessenster": "versessen",
    "versessenstes": "versessen",
    "versetze": "versetzen",
    "versetzend": "versetzen",
    "versetzende": "versetzend",
    "versetzendem": "versetzend",
    "versetzenden": "versetzend",
    "versetzender": "versetzend",
    "versetzendes": "versetzend",
    "versetzest": "versetzen",
    "versetzet": "versetzen",
    "versetzt": "versetzen",
    "versetzte": "versetzen",
    "versetztem": "versetzt",
    "versetzten": "versetzen",
    "versetzter": "versetzt",
    "versetztes": "versetzt",
    "versetztest": "versetzen",
    "versetztet": "versetzen",
    "verseuche": "verseuchen",
    "verseuchend": "verseuchen",
    "verseuchende": "verseuchend",
    "verseuchendem": "verseuchend",
    "verseuchenden": "verseuchend",
    "verseuchender": "verseuchend",
    "verseuchendere": "verseuchend",
    "verseuchenderem": "verseuchend",
    "verseuchenderen": "verseuchend",
    "verseuchenderer": "verseuchend",
    "verseuchenderes": "verseuchend",
    "verseuchendes": "verseuchend",
    "verseuchendste": "verseuchend",
    "verseuchendstem": "verseuchend",
    "verseuchendsten": "verseuchend",
    "verseuchendster": "verseuchend",
    "verseuchendstes": "verseuchend",
    "verseuchest": "verseuchen",
    "verseuchet": "verseuchen",
    "verseuchst": "verseuchen",
    "verseucht": "verseuchen",
    "verseuchte": "verseuchen",
    "verseuchtem": "verseucht",
    "verseuchten": "verseuchen",
    "verseuchter": "verseucht",
    "verseuchtere": "verseucht",
    "verseuchterem": "verseucht",
    "verseuchteren": "verseucht",
    "verseuchterer": "verseucht",
    "verseuchteres": "verseucht",
    "verseuchtes": "verseucht",
    "verseuchtest": "verseuchen",
    "verseuchteste": "verseucht",
    "verseuchtestem": "verseucht",
    "verseuchtesten": "verseucht",
    "verseuchtester": "verseucht",
    "verseuchtestes": "verseucht",
    "verseuchtet": "verseuchen",
    "versichere": "versichern",
    "versichernd": "versichern",
    "versichernde": "versichernd",
    "versicherndem": "versichernd",
    "versichernden": "versichernd",
    "versichernder": "versichernd",
    "versicherndes": "versichernd",
    "versicherst": "versichern",
    "versichert": "versichern",
    "versicherte": "versichern",
    "versichertem": "versichert",
    "versicherten": "versichern",
    "versicherter": "versichert",
    "versichertes": "versichert",
    "versichertest": "versichern",
    "versichertet": "versichern",
    "versiebe": "versieben",
    "versiebend": "versieben",
    "versiebende": "versiebend",
    "versiebendem": "versiebend",
    "versiebenden": "versiebend",
    "versiebender": "versiebend",
    "versiebendes": "versiebend",
    "versiebest": "versieben",
    "versiebet": "versieben",
    "versiebst": "versieben",
    "versiebt": "versieben",
    "versiebte": "versieben",
    "versiebtem": "versiebt",
    "versiebten": "versieben",
    "versiebter": "versiebt",
    "versiebtes": "versiebt",
    "versiebtest": "versieben",
    "versiebtet": "versieben",
    "versieche": "versiechen",
    "versiechend": "versiechen",
    "versiechende": "versiechend",
    "versiechendem": "versiechend",
    "versiechenden": "versiechend",
    "versiechender": "versiechend",
    "versiechendere": "versiechend",
    "versiechenderem": "versiechend",
    "versiechenderen": "versiechend",
    "versiechenderer": "versiechend",
    "versiechenderes": "versiechend",
    "versiechendes": "versiechend",
    "versiechendste": "versiechend",
    "versiechendstem": "versiechend",
    "versiechendsten": "versiechend",
    "versiechendster": "versiechend",
    "versiechendstes": "versiechend",
    "versiechest": "versiechen",
    "versiechet": "versiechen",
    "versiechst": "versiechen",
    "versiecht": "versiechen",
    "versiechte": "versiechen",
    "versiechtem": "versiecht",
    "versiechten": "versiechen",
    "versiechter": "versiecht",
    "versiechtes": "versiecht",
    "versiechtest": "versiechen",
    "versiechtet": "versiechen",
    "versiege": "versiegen",
    "versiegele": "versiegeln",
    "versiegelnd": "versiegeln",
    "versiegelnde": "versiegelnd",
    "versiegelndem": "versiegelnd",
    "versiegelnden": "versiegelnd",
    "versiegelnder": "versiegelnd",
    "versiegelndes": "versiegelnd",
    "versiegelst": "versiegeln",
    "versiegelt": "versiegeln",
    "versiegelte": "versiegeln",
    "versiegeltem": "versiegelt",
    "versiegelten": "versiegeln",
    "versiegelter": "versiegelt",
    "versiegeltes": "versiegelt",
    "versiegeltest": "versiegeln",
    "versiegeltet": "versiegeln",
    "versiegend": "versiegen",
    "versiegende": "versiegend",
    "versiegendem": "versiegend",
    "versiegenden": "versiegend",
    "versiegender": "versiegend",
    "versiegendes": "versiegend",
    "versiegest": "versiegen",
    "versieget": "versiegen",
    "versiegle": "versiegeln",
    "versiegst": "versiegen",
    "versiegt": "versiegen",
    "versiegte": "versiegen",
    "versiegtem": "versiegt",
    "versiegten": "versiegen",
    "versiegter": "versiegt",
    "versiegtere": "versiegt",
    "versiegterem": "versiegt",
    "versiegteren": "versiegt",
    "versiegterer": "versiegt",
    "versiegteres": "versiegt",
    "versiegtes": "versiegt",
    "versiegtest": "versiegen",
    "versiegteste": "versiegt",
    "versiegtestem": "versiegt",
    "versiegtesten": "versiegt",
    "versiegtester": "versiegt",
    "versiegtestes": "versiegt",
    "versiegtet": "versiegen",
    "versieh": "versehen",
    "versiehst": "versehen",
    "versieht": "versehen",
    "versiffte": "versifft",
    "versifftem": "versifft",
    "versifften": "versifft",
    "versiffter": "versifft",
    "versifftere": "versifft",
    "versiffterem": "versifft",
    "versiffteren": "versifft",
    "versiffterer": "versifft",
    "versiffteres": "versifft",
    "versifftes": "versifft",
    "versiffteste": "versifft",
    "versifftestem": "versifft",
    "versifftesten": "versifft",
    "versifftester": "versifft",
    "versifftestes": "versifft",
    "versilbere": "versilbern",
    "versilbernd": "versilbern",
    "versilbernde": "versilbernd",
    "versilberndem": "versilbernd",
    "versilbernden": "versilbernd",
    "versilbernder": "versilbernd",
    "versilberndes": "versilbernd",
    "versilberst": "versilbern",
    "versilbert": "versilbern",
    "versilberte": "versilbern",
    "versilbertem": "versilbert",
    "versilberten": "versilbern",
    "versilberter": "versilbert",
    "versilbertes": "versilbert",
    "versilbertest": "versilbern",
    "versilbertet": "versilbern",
    "versinke": "versinken",
    "versinkend": "versinken",
    "versinkende": "versinkend",
    "versinkendem": "versinkend",
    "versinkenden": "versinkend",
    "versinkender": "versinkend",
    "versinkendere": "versinkend",
    "versinkenderem": "versinkend",
    "versinkenderen": "versinkend",
    "versinkenderer": "versinkend",
    "versinkenderes": "versinkend",
    "versinkendes": "versinkend",
    "versinkendste": "versinkend",
    "versinkendstem": "versinkend",
    "versinkendsten": "versinkend",
    "versinkendster": "versinkend",
    "versinkendstes": "versinkend",
    "versinkest": "versinken",
    "versinket": "versinken",
    "versinkst": "versinken",
    "versinkt": "versinken",
    "versittliche": "versittlichen",
    "versittlichend": "versittlichen",
    "versittlichende": "versittlichend",
    "versittlichendem": "versittlichend",
    "versittlichenden": "versittlichend",
    "versittlichender": "versittlichend",
    "versittlichendes": "versittlichend",
    "versittlichest": "versittlichen",
    "versittlichet": "versittlichen",
    "versittlichst": "versittlichen",
    "versittlicht": "versittlichen",
    "versittlichte": "versittlichen",
    "versittlichtem": "versittlicht",
    "versittlichten": "versittlichen",
    "versittlichter": "versittlicht",
    "versittlichtere": "versittlicht",
    "versittlichterem": "versittlicht",
    "versittlichteren": "versittlicht",
    "versittlichterer": "versittlicht",
    "versittlichteres": "versittlicht",
    "versittlichtes": "versittlicht",
    "versittlichtest": "versittlichen",
    "versittlichteste": "versittlicht",
    "versittlichtestem": "versittlicht",
    "versittlichtesten": "versittlicht",
    "versittlichtester": "versittlicht",
    "versittlichtestes": "versittlicht",
    "versittlichtet": "versittlichen",
    "versklave": "versklaven",
    "versklavend": "versklaven",
    "versklavende": "versklavend",
    "versklavendem": "versklavend",
    "versklavenden": "versklavend",
    "versklavender": "versklavend",
    "versklavendes": "versklavend",
    "versklavest": "versklaven",
    "versklavet": "versklaven",
    "versklavst": "versklaven",
    "versklavt": "versklaven",
    "versklavte": "versklaven",
    "versklavtem": "versklavt",
    "versklavten": "versklaven",
    "versklavter": "versklavt",
    "versklavtes": "versklavt",
    "versklavtest": "versklaven",
    "versklavtet": "versklaven",
    "versoff": "versaufen",
    "versoffen": "versaufen",
    "versoffene": "versoffen",
    "versoffenem": "versoffen",
    "versoffenen": "versoffen",
    "versoffener": "versoffen",
    "versoffenere": "versoffen",
    "versoffenerem": "versoffen",
    "versoffeneren": "versoffen",
    "versoffenerer": "versoffen",
    "versoffeneres": "versoffen",
    "versoffenes": "versoffen",
    "versoffenste": "versoffen",
    "versoffenstem": "versoffen",
    "versoffensten": "versoffen",
    "versoffenster": "versoffen",
    "versoffenstes": "versoffen",
    "versoffst": "versaufen",
    "versofft": "versaufen",
    "versohle": "versohlen",
    "versohlend": "versohlen",
    "versohlende": "versohlend",
    "versohlendem": "versohlend",
    "versohlenden": "versohlend",
    "versohlender": "versohlend",
    "versohlendes": "versohlend",
    "versohlest": "versohlen",
    "versohlet": "versohlen",
    "versohlst": "versohlen",
    "versohlt": "versohlen",
    "versohlte": "versohlen",
    "versohltem": "versohlt",
    "versohlten": "versohlen",
    "versohlter": "versohlt",
    "versohltes": "versohlt",
    "versohltest": "versohlen",
    "versohltet": "versohlen",
    "versorge": "versorgen",
    "versorgend": "versorgen",
    "versorgende": "versorgend",
    "versorgendem": "versorgend",
    "versorgenden": "versorgend",
    "versorgender": "versorgend",
    "versorgendes": "versorgend",
    "versorgest": "versorgen",
    "versorget": "versorgen",
    "versorgst": "versorgen",
    "versorgt": "versorgen",
    "versorgte": "versorgen",
    "versorgtem": "versorgt",
    "versorgten": "versorgen",
    "versorgter": "versorgt",
    "versorgtes": "versorgt",
    "versorgtest": "versorgen",
    "versorgtet": "versorgen",
    "verspachtele": "verspachteln",
    "verspachtelnd": "verspachteln",
    "verspachtelnde": "verspachtelnd",
    "verspachtelndem": "verspachtelnd",
    "verspachtelnden": "verspachtelnd",
    "verspachtelnder": "verspachtelnd",
    "verspachtelndes": "verspachtelnd",
    "verspachtelst": "verspachteln",
    "verspachtelt": "verspachteln",
    "verspachtelte": "verspachteln",
    "verspachteltem": "verspachtelt",
    "verspachtelten": "verspachteln",
    "verspachtelter": "verspachtelt",
    "verspachteltes": "verspachtelt",
    "verspachteltest": "verspachteln",
    "verspachteltet": "verspachteln",
    "verspachtle": "verspachteln",
    "verspanne": "verspannen",
    "verspannend": "verspannen",
    "verspannende": "verspannend",
    "verspannendem": "verspannend",
    "verspannenden": "verspannend",
    "verspannender": "verspannend",
    "verspannendes": "verspannend",
    "verspannest": "verspannen",
    "verspannet": "verspannen",
    "verspannst": "verspannen",
    "verspannt": "verspannen",
    "verspannte": "verspannen",
    "verspanntem": "verspannt",
    "verspannten": "verspannen",
    "verspannter": "verspannt",
    "verspanntere": "verspannt",
    "verspannterem": "verspannt",
    "verspannteren": "verspannt",
    "verspannterer": "verspannt",
    "verspannteres": "verspannt",
    "verspanntes": "verspannt",
    "verspanntest": "verspannen",
    "verspannteste": "verspannt",
    "verspanntestem": "verspannt",
    "verspanntesten": "verspannt",
    "verspanntester": "verspannt",
    "verspanntestes": "verspannt",
    "verspanntet": "verspannen",
    "verspeise": "verspeisen",
    "verspeisend": "verspeisen",
    "verspeisende": "verspeisend",
    "verspeisendem": "verspeisend",
    "verspeisenden": "verspeisend",
    "verspeisender": "verspeisend",
    "verspeisendes": "verspeisend",
    "verspeisest": "verspeisen",
    "verspeiset": "verspeisen",
    "verspeist": "verspeisen",
    "verspeiste": "verspeisen",
    "verspeistem": "verspeist",
    "verspeisten": "verspeisen",
    "verspeister": "verspeist",
    "verspeistes": "verspeist",
    "verspeistest": "verspeisen",
    "verspeistet": "verspeisen",
    "verspekuliere": "verspekulieren",
    "verspekulierend": "verspekulieren",
    "verspekulierende": "verspekulierend",
    "verspekulierendem": "verspekulierend",
    "verspekulierenden": "verspekulierend",
    "verspekulierender": "verspekulierend",
    "verspekulierendes": "verspekulierend",
    "verspekulierest": "verspekulieren",
    "verspekulieret": "verspekulieren",
    "verspekulierst": "verspekulieren",
    "verspekuliert": "verspekulieren",
    "verspekulierte": "verspekulieren",
    "verspekuliertem": "verspekuliert",
    "verspekulierten": "verspekulieren",
    "verspekulierter": "verspekuliert",
    "verspekuliertes": "verspekuliert",
    "verspekuliertest": "verspekulieren",
    "verspekuliertet": "verspekulieren",
    "versperre": "versperren",
    "versperrend": "versperren",
    "versperrende": "versperrend",
    "versperrendem": "versperrend",
    "versperrenden": "versperrend",
    "versperrender": "versperrend",
    "versperrendere": "versperrend",
    "versperrenderem": "versperrend",
    "versperrenderen": "versperrend",
    "versperrenderer": "versperrend",
    "versperrenderes": "versperrend",
    "versperrendes": "versperrend",
    "versperrendste": "versperrend",
    "versperrendstem": "versperrend",
    "versperrendsten": "versperrend",
    "versperrendster": "versperrend",
    "versperrendstes": "versperrend",
    "versperrest": "versperren",
    "versperret": "versperren",
    "versperrst": "versperren",
    "versperrt": "versperren",
    "versperrte": "versperren",
    "versperrtem": "versperrt",
    "versperrten": "versperren",
    "versperrter": "versperrt",
    "versperrtere": "versperrt",
    "versperrterem": "versperrt",
    "versperrteren": "versperrt",
    "versperrterer": "versperrt",
    "versperrteres": "versperrt",
    "versperrtes": "versperrt",
    "versperrtest": "versperren",
    "versperrteste": "versperrt",
    "versperrtestem": "versperrt",
    "versperrtesten": "versperrt",
    "versperrtester": "versperrt",
    "versperrtestes": "versperrt",
    "versperrtet": "versperren",
    "verspiele": "verspielen",
    "verspielend": "verspielen",
    "verspielende": "verspielend",
    "verspielendem": "verspielend",
    "verspielenden": "verspielend",
    "verspielender": "verspielend",
    "verspielendes": "verspielend",
    "verspielest": "verspielen",
    "verspielet": "verspielen",
    "verspielst": "verspielen",
    "verspielt": "verspielen",
    "verspielte": "verspielen",
    "verspieltem": "verspielt",
    "verspielten": "verspielen",
    "verspielter": "verspielt",
    "verspieltere": "verspielt",
    "verspielterem": "verspielt",
    "verspielteren": "verspielt",
    "verspielterer": "verspielt",
    "verspielteres": "verspielt",
    "verspieltes": "verspielt",
    "verspieltest": "verspielen",
    "verspielteste": "verspielt",
    "verspieltestem": "verspielt",
    "verspieltesten": "verspielt",
    "verspieltester": "verspielt",
    "verspieltestes": "verspielt",
    "verspieltet": "verspielen",
    "verspotte": "verspotten",
    "verspottend": "verspotten",
    "verspottende": "verspottend",
    "verspottendem": "verspottend",
    "verspottenden": "verspottend",
    "verspottender": "verspottend",
    "verspottendere": "verspottend",
    "verspottenderem": "verspottend",
    "verspottenderen": "verspottend",
    "verspottenderer": "verspottend",
    "verspottenderes": "verspottend",
    "verspottendes": "verspottend",
    "verspottendste": "verspottend",
    "verspottendstem": "verspottend",
    "verspottendsten": "verspottend",
    "verspottendster": "verspottend",
    "verspottendstes": "verspottend",
    "verspottest": "verspotten",
    "verspottet": "verspotten",
    "verspottete": "verspotten",
    "verspottetem": "verspottet",
    "verspotteten": "verspotten",
    "verspotteter": "verspottet",
    "verspottetere": "verspottet",
    "verspotteterem": "verspottet",
    "verspotteteren": "verspottet",
    "verspotteterer": "verspottet",
    "verspotteteres": "verspottet",
    "verspottetes": "verspottet",
    "verspottetest": "verspotten",
    "verspotteteste": "verspottet",
    "verspottetestem": "verspottet",
    "verspottetesten": "verspottet",
    "verspottetester": "verspottet",
    "verspottetestes": "verspottet",
    "verspottetet": "verspotten",
    "versprach": "versprechen",
    "versprachen": "versprechen",
    "versprachst": "versprechen",
    "verspracht": "versprechen",
    "versprang": "verspringen",
    "versprangen": "verspringen",
    "versprangst": "verspringen",
    "versprangt": "verspringen",
    "verspreche": "versprechen",
    "versprechend": "versprechen",
    "versprechende": "versprechend",
    "versprechendem": "versprechend",
    "versprechenden": "versprechend",
    "versprechender": "versprechend",
    "versprechendere": "versprechend",
    "versprechenderem": "versprechend",
    "versprechenderen": "versprechend",
    "versprechenderer": "versprechend",
    "versprechenderes": "versprechend",
    "versprechendes": "versprechend",
    "versprechendste": "versprechend",
    "versprechendstem": "versprechend",
    "versprechendsten": "versprechend",
    "versprechendster": "versprechend",
    "versprechendstes": "versprechend",
    "versprechest": "versprechen",
    "versprechet": "versprechen",
    "versprecht": "versprechen",
    "versprich": "versprechen",
    "versprichst": "versprechen",
    "verspricht": "versprechen",
    "verspringe": "verspringen",
    "verspringend": "verspringen",
    "verspringende": "verspringend",
    "verspringendem": "verspringend",
    "verspringenden": "verspringend",
    "verspringender": "verspringend",
    "verspringendere": "verspringend",
    "verspringenderem": "verspringend",
    "verspringenderen": "verspringend",
    "verspringenderer": "verspringend",
    "verspringenderes": "verspringend",
    "verspringendes": "verspringend",
    "verspringendste": "verspringend",
    "verspringendstem": "verspringend",
    "verspringendsten": "verspringend",
    "verspringendster": "verspringend",
    "verspringendstes": "verspringend",
    "verspringest": "verspringen",
    "verspringet": "verspringen",
    "verspringst": "verspringen",
    "verspringt": "verspringen",
    "verspritze": "verspritzen",
    "verspritzend": "verspritzen",
    "verspritzende": "verspritzend",
    "verspritzendem": "verspritzend",
    "verspritzenden": "verspritzend",
    "verspritzender": "verspritzend",
    "verspritzendere": "verspritzend",
    "verspritzenderem": "verspritzend",
    "verspritzenderen": "verspritzend",
    "verspritzenderer": "verspritzend",
    "verspritzenderes": "verspritzend",
    "verspritzendes": "verspritzend",
    "verspritzendste": "verspritzend",
    "verspritzendstem": "verspritzend",
    "verspritzendsten": "verspritzend",
    "verspritzendster": "verspritzend",
    "verspritzendstes": "verspritzend",
    "verspritzest": "verspritzen",
    "verspritzet": "verspritzen",
    "verspritzt": "verspritzen",
    "verspritzte": "verspritzen",
    "verspritztem": "verspritzt",
    "verspritzten": "verspritzen",
    "verspritzter": "verspritzt",
    "verspritztere": "verspritzt",
    "verspritzterem": "verspritzt",
    "verspritzteren": "verspritzt",
    "verspritzterer": "verspritzt",
    "verspritzteres": "verspritzt",
    "verspritztes": "verspritzt",
    "verspritztest": "verspritzen",
    "verspritzteste": "verspritzt",
    "verspritztestem": "verspritzt",
    "verspritztesten": "verspritzt",
    "verspritztester": "verspritzt",
    "verspritztestes": "verspritzt",
    "verspritztet": "verspritzen",
    "versprochen": "versprechen",
    "versprochene": "versprochen",
    "versprochenem": "versprochen",
    "versprochenen": "versprochen",
    "versprochener": "versprochen",
    "versprochenere": "versprochen",
    "versprochenerem": "versprochen",
    "versprocheneren": "versprochen",
    "versprochenerer": "versprochen",
    "versprocheneres": "versprochen",
    "versprochenes": "versprochen",
    "versprochenste": "versprochen",
    "versprochenstem": "versprochen",
    "versprochensten": "versprochen",
    "versprochenster": "versprochen",
    "versprochenstes": "versprochen",
    "versprungen": "verspringen",
    "versprungene": "versprungen",
    "versprungenem": "versprungen",
    "versprungenen": "versprungen",
    "versprungener": "versprungen",
    "versprungenere": "versprungen",
    "versprungenerem": "versprungen",
    "versprungeneren": "versprungen",
    "versprungenerer": "versprungen",
    "versprungeneres": "versprungen",
    "versprungenes": "versprungen",
    "versprungenste": "versprungen",
    "versprungenstem": "versprungen",
    "versprungensten": "versprungen",
    "versprungenster": "versprungen",
    "versprungenstes": "versprungen",
    "verspräche": "versprechen",
    "versprächen": "versprechen",
    "versprächest": "versprechen",
    "versprächet": "versprechen",
    "verspränge": "verspringen",
    "versprängen": "verspringen",
    "versprängest": "verspringen",
    "verspränget": "verspringen",
    "versprühe": "versprühen",
    "versprühend": "versprühen",
    "versprühende": "versprühend",
    "versprühendem": "versprühend",
    "versprühenden": "versprühend",
    "versprühender": "versprühend",
    "versprühendes": "versprühend",
    "versprühest": "versprühen",
    "versprühet": "versprühen",
    "versprühst": "versprühen",
    "versprüht": "versprühen",
    "versprühte": "versprühen",
    "versprühtem": "versprüht",
    "versprühten": "versprühen",
    "versprühter": "versprüht",
    "versprühtes": "versprüht",
    "versprühtest": "versprühen",
    "versprühtet": "versprühen",
    "verspäte": "verspäten",
    "verspätend": "verspäten",
    "verspätende": "verspätend",
    "verspätendem": "verspätend",
    "verspätenden": "verspätend",
    "verspätender": "verspätend",
    "verspätendes": "verspätend",
    "verspätest": "verspäten",
    "verspätet": "verspäten",
    "verspätete": "verspäten",
    "verspätetem": "verspätet",
    "verspäteten": "verspäten",
    "verspäteter": "verspätet",
    "verspätetere": "verspätet",
    "verspäteterem": "verspätet",
    "verspäteteren": "verspätet",
    "verspäteterer": "verspätet",
    "verspäteteres": "verspätet",
    "verspätetes": "verspätet",
    "verspätetest": "verspäten",
    "verspäteteste": "verspätet",
    "verspätetestem": "verspätet",
    "verspätetesten": "verspätet",
    "verspätetester": "verspätet",
    "verspätetestes": "verspätet",
    "verspätetet": "verspäten",
    "verspüre": "verspüren",
    "verspürend": "verspüren",
    "verspürende": "verspürend",
    "verspürendem": "verspürend",
    "verspürenden": "verspürend",
    "verspürender": "verspürend",
    "verspürendes": "verspürend",
    "verspürest": "verspüren",
    "verspüret": "verspüren",
    "verspürst": "verspüren",
    "verspürt": "verspüren",
    "verspürte": "verspüren",
    "verspürtem": "verspürt",
    "verspürten": "verspüren",
    "verspürter": "verspürt",
    "verspürtes": "verspürt",
    "verspürtest": "verspüren",
    "verspürtet": "verspüren",
    "verstaatliche": "verstaatlichen",
    "verstaatlichend": "verstaatlichen",
    "verstaatlichende": "verstaatlichend",
    "verstaatlichendem": "verstaatlichend",
    "verstaatlichenden": "verstaatlichend",
    "verstaatlichender": "verstaatlichend",
    "verstaatlichendere": "verstaatlichend",
    "verstaatlichenderem": "verstaatlichend",
    "verstaatlichenderen": "verstaatlichend",
    "verstaatlichenderer": "verstaatlichend",
    "verstaatlichenderes": "verstaatlichend",
    "verstaatlichendes": "verstaatlichend",
    "verstaatlichendste": "verstaatlichend",
    "verstaatlichendstem": "verstaatlichend",
    "verstaatlichendsten": "verstaatlichend",
    "verstaatlichendster": "verstaatlichend",
    "verstaatlichendstes": "verstaatlichend",
    "verstaatlichest": "verstaatlichen",
    "verstaatlichet": "verstaatlichen",
    "verstaatlichst": "verstaatlichen",
    "verstaatlicht": "verstaatlichen",
    "verstaatlichte": "verstaatlichen",
    "verstaatlichtem": "verstaatlicht",
    "verstaatlichten": "verstaatlichen",
    "verstaatlichter": "verstaatlicht",
    "verstaatlichtere": "verstaatlicht",
    "verstaatlichterem": "verstaatlicht",
    "verstaatlichteren": "verstaatlicht",
    "verstaatlichterer": "verstaatlicht",
    "verstaatlichteres": "verstaatlicht",
    "verstaatlichtes": "verstaatlicht",
    "verstaatlichtest": "verstaatlichen",
    "verstaatlichtestem": "verstaatlicht",
    "verstaatlichtesten": "verstaatlicht",
    "verstaatlichtester": "verstaatlicht",
    "verstaatlichtestes": "verstaatlicht",
    "verstaatlichtet": "verstaatlichen",
    "verstand": "verstehen",
    "verstanden": "verstehen",
    "verstandene": "verstanden",
    "verstandenem": "verstanden",
    "verstandenen": "verstanden",
    "verstandener": "verstanden",
    "verstandenere": "verstanden",
    "verstandenerem": "verstanden",
    "verstandeneren": "verstanden",
    "verstandenerer": "verstanden",
    "verstandeneres": "verstanden",
    "verstandenes": "verstanden",
    "verstandenste": "verstanden",
    "verstandenstem": "verstanden",
    "verstandensten": "verstanden",
    "verstandenster": "verstanden",
    "verstandenstes": "verstanden",
    "verstandest": "verstehen",
    "verstandet": "verstehen",
    "verstarb": "versterben",
    "verstarben": "versterben",
    "verstarbst": "versterben",
    "verstarbt": "versterben",
    "verstaube": "verstauben",
    "verstaubend": "verstauben",
    "verstaubende": "verstaubend",
    "verstaubendem": "verstaubend",
    "verstaubenden": "verstaubend",
    "verstaubender": "verstaubend",
    "verstaubendere": "verstaubend",
    "verstaubenderem": "verstaubend",
    "verstaubenderen": "verstaubend",
    "verstaubenderer": "verstaubend",
    "verstaubenderes": "verstaubend",
    "verstaubendes": "verstaubend",
    "verstaubendste": "verstaubend",
    "verstaubendstem": "verstaubend",
    "verstaubendsten": "verstaubend",
    "verstaubendster": "verstaubend",
    "verstaubendstes": "verstaubend",
    "verstaubest": "verstauben",
    "verstaubet": "verstauben",
    "verstaubst": "verstauben",
    "verstaubt": "verstauben",
    "verstaubte": "verstauben",
    "verstaubtem": "verstaubt",
    "verstaubten": "verstauben",
    "verstaubter": "verstaubt",
    "verstaubtere": "verstaubt",
    "verstaubterem": "verstaubt",
    "verstaubteren": "verstaubt",
    "verstaubterer": "verstaubt",
    "verstaubteres": "verstaubt",
    "verstaubtes": "verstaubt",
    "verstaubtest": "verstauben",
    "verstaubteste": "verstaubt",
    "verstaubtestem": "verstaubt",
    "verstaubtesten": "verstaubt",
    "verstaubtester": "verstaubt",
    "verstaubtestes": "verstaubt",
    "verstaubtet": "verstauben",
    "verstauche": "verstauchen",
    "verstauchend": "verstauchen",
    "verstauchende": "verstauchend",
    "verstauchendem": "verstauchend",
    "verstauchenden": "verstauchend",
    "verstauchender": "verstauchend",
    "verstauchendere": "verstauchend",
    "verstauchenderem": "verstauchend",
    "verstauchenderen": "verstauchend",
    "verstauchenderer": "verstauchend",
    "verstauchenderes": "verstauchend",
    "verstauchendes": "verstauchend",
    "verstauchendste": "verstauchend",
    "verstauchendstem": "verstauchend",
    "verstauchendsten": "verstauchend",
    "verstauchendster": "verstauchend",
    "verstauchendstes": "verstauchend",
    "verstauchest": "verstauchen",
    "verstauchet": "verstauchen",
    "verstauchst": "verstauchen",
    "verstaucht": "verstauchen",
    "verstauchte": "verstauchen",
    "verstauchtem": "verstaucht",
    "verstauchten": "verstauchen",
    "verstauchter": "verstaucht",
    "verstauchtere": "verstaucht",
    "verstauchterem": "verstaucht",
    "verstauchteren": "verstaucht",
    "verstauchterer": "verstaucht",
    "verstauchteres": "verstaucht",
    "verstauchtes": "verstaucht",
    "verstauchtest": "verstauchen",
    "verstauchteste": "verstaucht",
    "verstauchtestem": "verstaucht",
    "verstauchtesten": "verstaucht",
    "verstauchtester": "verstaucht",
    "verstauchtestes": "verstaucht",
    "verstauchtet": "verstauchen",
    "verstaue": "verstauen",
    "verstauend": "verstauen",
    "verstauende": "verstauend",
    "verstauendem": "verstauend",
    "verstauenden": "verstauend",
    "verstauender": "verstauend",
    "verstauendes": "verstauend",
    "verstauest": "verstauen",
    "verstauet": "verstauen",
    "verstaust": "verstauen",
    "verstaut": "verstauen",
    "verstaute": "verstauen",
    "verstautem": "verstaut",
    "verstauten": "verstauen",
    "verstauter": "verstaut",
    "verstautes": "verstaut",
    "verstautest": "verstauen",
    "verstautet": "verstauen",
    "versteckend": "verstecken",
    "versteckende": "versteckend",
    "versteckendem": "versteckend",
    "versteckenden": "versteckend",
    "versteckender": "versteckend",
    "versteckendes": "versteckend",
    "versteckest": "verstecken",
    "verstecket": "verstecken",
    "versteckst": "verstecken",
    "versteckt": "verstecken",
    "versteckte": "verstecken",
    "verstecktem": "versteckt",
    "versteckten": "verstecken",
    "versteckter": "versteckt",
    "verstecktere": "versteckt",
    "versteckterem": "versteckt",
    "versteckteren": "versteckt",
    "versteckterer": "versteckt",
    "versteckteres": "versteckt",
    "verstecktes": "versteckt",
    "verstecktest": "verstecken",
    "versteckteste": "versteckt",
    "verstecktestem": "versteckt",
    "verstecktesten": "versteckt",
    "verstecktester": "versteckt",
    "verstecktestes": "versteckt",
    "verstecktet": "verstecken",
    "verstehbare": "verstehbar",
    "verstehbarem": "verstehbar",
    "verstehbaren": "verstehbar",
    "verstehbarer": "verstehbar",
    "verstehbarere": "verstehbar",
    "verstehbarerem": "verstehbar",
    "verstehbareren": "verstehbar",
    "verstehbarerer": "verstehbar",
    "verstehbareres": "verstehbar",
    "verstehbares": "verstehbar",
    "verstehbarste": "verstehbar",
    "verstehbarstem": "verstehbar",
    "verstehbarsten": "verstehbar",
    "verstehbarster": "verstehbar",
    "verstehbarstes": "verstehbar",
    "verstehe": "verstehen",
    "verstehend": "verstehen",
    "verstehende": "verstehend",
    "verstehendem": "verstehend",
    "verstehenden": "verstehend",
    "verstehender": "verstehend",
    "verstehendere": "verstehend",
    "verstehenderem": "verstehend",
    "verstehenderen": "verstehend",
    "verstehenderer": "verstehend",
    "verstehenderes": "verstehend",
    "verstehendes": "verstehend",
    "verstehendste": "verstehend",
    "verstehendstem": "verstehend",
    "verstehendsten": "verstehend",
    "verstehendster": "verstehend",
    "verstehendstes": "verstehend",
    "verstehest": "verstehen",
    "verstehet": "verstehen",
    "verstehst": "verstehen",
    "versteht": "verstehen",
    "versteife": "versteifen",
    "versteifend": "versteifen",
    "versteifende": "versteifend",
    "versteifendem": "versteifend",
    "versteifenden": "versteifend",
    "versteifender": "versteifend",
    "versteifendes": "versteifend",
    "versteifest": "versteifen",
    "versteifet": "versteifen",
    "versteifst": "versteifen",
    "versteift": "versteifen",
    "versteifte": "versteifen",
    "versteiftem": "versteift",
    "versteiften": "versteifen",
    "versteifter": "versteift",
    "versteiftes": "versteift",
    "versteiftest": "versteifen",
    "versteiftet": "versteifen",
    "versteigere": "versteigern",
    "versteigernd": "versteigern",
    "versteigernde": "versteigernd",
    "versteigerndem": "versteigernd",
    "versteigernden": "versteigernd",
    "versteigernder": "versteigernd",
    "versteigerndes": "versteigernd",
    "versteigerst": "versteigern",
    "versteigert": "versteigern",
    "versteigerte": "versteigern",
    "versteigertem": "versteigert",
    "versteigerten": "versteigern",
    "versteigerter": "versteigert",
    "versteigertes": "versteigert",
    "versteigertest": "versteigern",
    "versteigertet": "versteigern",
    "versteinere": "versteinern",
    "versteinernd": "versteinern",
    "versteinernde": "versteinernd",
    "versteinerndem": "versteinernd",
    "versteinernden": "versteinernd",
    "versteinernder": "versteinernd",
    "versteinerndere": "versteinernd",
    "versteinernderem": "versteinernd",
    "versteinernderen": "versteinernd",
    "versteinernderer": "versteinernd",
    "versteinernderes": "versteinernd",
    "versteinerndes": "versteinernd",
    "versteinerndste": "versteinernd",
    "versteinerndstem": "versteinernd",
    "versteinerndsten": "versteinernd",
    "versteinerndster": "versteinernd",
    "versteinerndstes": "versteinernd",
    "versteinerst": "versteinern",
    "versteinert": "versteinern",
    "versteinerte": "versteinern",
    "versteinertem": "versteinert",
    "versteinerten": "versteinern",
    "versteinerter": "versteinert",
    "versteinertere": "versteinert",
    "versteinerterem": "versteinert",
    "versteinerteren": "versteinert",
    "versteinerterer": "versteinert",
    "versteinerteres": "versteinert",
    "versteinertes": "versteinert",
    "versteinertest": "versteinern",
    "versteinerteste": "versteinert",
    "versteinertestem": "versteinert",
    "versteinertesten": "versteinert",
    "versteinertester": "versteinert",
    "versteinertestes": "versteinert",
    "versteinertet": "versteinern",
    "verstelle": "verstellen",
    "verstellend": "verstellen",
    "verstellende": "verstellend",
    "verstellendem": "verstellend",
    "verstellenden": "verstellend",
    "verstellender": "verstellend",
    "verstellendes": "verstellend",
    "verstellest": "verstellen",
    "verstellet": "verstellen",
    "verstellst": "verstellen",
    "verstellt": "verstellen",
    "verstellte": "verstellen",
    "verstelltem": "verstellt",
    "verstellten": "verstellen",
    "verstellter": "verstellt",
    "verstelltere": "verstellt",
    "verstellterem": "verstellt",
    "verstellteren": "verstellt",
    "verstellterer": "verstellt",
    "verstellteres": "verstellt",
    "verstelltes": "verstellt",
    "verstelltest": "verstellen",
    "verstellteste": "verstellt",
    "verstelltestem": "verstellt",
    "verstelltesten": "verstellt",
    "verstelltester": "verstellt",
    "verstelltestes": "verstellt",
    "verstelltet": "verstellen",
    "versterbe": "versterben",
    "versterbend": "versterben",
    "versterbende": "versterbend",
    "versterbendem": "versterbend",
    "versterbenden": "versterbend",
    "versterbender": "versterbend",
    "versterbendes": "versterbend",
    "versterbest": "versterben",
    "versterbet": "versterben",
    "versterbt": "versterben",
    "versteuere": "versteuern",
    "versteuernd": "versteuern",
    "versteuernde": "versteuernd",
    "versteuerndem": "versteuernd",
    "versteuernden": "versteuernd",
    "versteuernder": "versteuernd",
    "versteuerndes": "versteuernd",
    "versteuerst": "versteuern",
    "versteuert": "versteuern",
    "versteuerte": "versteuern",
    "versteuertem": "versteuert",
    "versteuerten": "versteuern",
    "versteuerter": "versteuert",
    "versteuertes": "versteuert",
    "versteuertest": "versteuern",
    "versteuertet": "versteuern",
    "verstieß": "verstoßen",
    "verstieße": "verstoßen",
    "verstießen": "verstoßen",
    "verstießest": "verstoßen",
    "verstießet": "verstoßen",
    "verstießt": "verstoßen",
    "verstimme": "verstimmen",
    "verstimmend": "verstimmen",
    "verstimmende": "verstimmend",
    "verstimmendem": "verstimmend",
    "verstimmenden": "verstimmend",
    "verstimmender": "verstimmend",
    "verstimmendes": "verstimmend",
    "verstimmest": "verstimmen",
    "verstimmet": "verstimmen",
    "verstimmst": "verstimmen",
    "verstimmt": "verstimmen",
    "verstimmte": "verstimmen",
    "verstimmtem": "verstimmt",
    "verstimmten": "verstimmen",
    "verstimmter": "verstimmt",
    "verstimmtere": "verstimmt",
    "verstimmterem": "verstimmt",
    "verstimmteren": "verstimmt",
    "verstimmterer": "verstimmt",
    "verstimmteres": "verstimmt",
    "verstimmtes": "verstimmt",
    "verstimmtest": "verstimmen",
    "verstimmteste": "verstimmt",
    "verstimmtestem": "verstimmt",
    "verstimmtesten": "verstimmt",
    "verstimmtester": "verstimmt",
    "verstimmtestes": "verstimmt",
    "verstimmtet": "verstimmen",
    "verstirb": "versterben",
    "verstirbst": "versterben",
    "verstirbt": "versterben",
    "verstohlene": "verstohlen",
    "verstohlenem": "verstohlen",
    "verstohlenen": "verstohlen",
    "verstohlener": "verstohlen",
    "verstohlenere": "verstohlen",
    "verstohlenerem": "verstohlen",
    "verstohleneren": "verstohlen",
    "verstohlenerer": "verstohlen",
    "verstohleneres": "verstohlen",
    "verstohlenes": "verstohlen",
    "verstohlenste": "verstohlen",
    "verstohlenstem": "verstohlen",
    "verstohlensten": "verstohlen",
    "verstohlenster": "verstohlen",
    "verstohlenstes": "verstohlen",
    "verstopfe": "verstopfen",
    "verstopfend": "verstopfen",
    "verstopfende": "verstopfend",
    "verstopfendem": "verstopfend",
    "verstopfenden": "verstopfend",
    "verstopfender": "verstopfend",
    "verstopfendere": "verstopfend",
    "verstopfenderem": "verstopfend",
    "verstopfenderen": "verstopfend",
    "verstopfenderer": "verstopfend",
    "verstopfenderes": "verstopfend",
    "verstopfendes": "verstopfend",
    "verstopfendste": "verstopfend",
    "verstopfendstem": "verstopfend",
    "verstopfendsten": "verstopfend",
    "verstopfendster": "verstopfend",
    "verstopfendstes": "verstopfend",
    "verstopfest": "verstopfen",
    "verstopfet": "verstopfen",
    "verstopfst": "verstopfen",
    "verstopft": "verstopfen",
    "verstopfte": "verstopfen",
    "verstopftem": "verstopft",
    "verstopften": "verstopfen",
    "verstopfter": "verstopft",
    "verstopftere": "verstopft",
    "verstopfterem": "verstopft",
    "verstopfteren": "verstopft",
    "verstopfterer": "verstopft",
    "verstopfteres": "verstopft",
    "verstopftes": "verstopft",
    "verstopftest": "verstopfen",
    "verstopfteste": "verstopft",
    "verstopftestem": "verstopft",
    "verstopftesten": "verstopft",
    "verstopftester": "verstopft",
    "verstopftestes": "verstopft",
    "verstopftet": "verstopfen",
    "verstorben": "versterben",
    "verstorbene": "verstorben",
    "verstorbenem": "verstorben",
    "verstorbenen": "verstorben",
    "verstorbener": "verstorben",
    "verstorbenes": "verstorben",
    "verstoßend": "verstoßen",
    "verstoßende": "verstoßend",
    "verstoßendem": "verstoßend",
    "verstoßenden": "verstoßend",
    "verstoßender": "verstoßend",
    "verstoßendes": "verstoßend",
    "verstoßene": "verstoßen",
    "verstoßenem": "verstoßen",
    "verstoßenen": "verstoßen",
    "verstoßener": "verstoßen",
    "verstoßenes": "verstoßen",
    "verstoßest": "verstoßen",
    "verstoßet": "verstoßen",
    "verstoßt": "verstoßen",
    "verstrahle": "verstrahlen",
    "verstrahlend": "verstrahlen",
    "verstrahlende": "verstrahlend",
    "verstrahlendem": "verstrahlend",
    "verstrahlenden": "verstrahlend",
    "verstrahlender": "verstrahlend",
    "verstrahlendes": "verstrahlend",
    "verstrahlest": "verstrahlen",
    "verstrahlet": "verstrahlen",
    "verstrahlst": "verstrahlen",
    "verstrahlt": "verstrahlen",
    "verstrahlte": "verstrahlen",
    "verstrahltem": "verstrahlt",
    "verstrahlten": "verstrahlen",
    "verstrahlter": "verstrahlt",
    "verstrahltere": "verstrahlt",
    "verstrahlterem": "verstrahlt",
    "verstrahlteren": "verstrahlt",
    "verstrahlterer": "verstrahlt",
    "verstrahlteres": "verstrahlt",
    "verstrahltes": "verstrahlt",
    "verstrahltest": "verstrahlen",
    "verstrahlteste": "verstrahlt",
    "verstrahltestem": "verstrahlt",
    "verstrahltesten": "verstrahlt",
    "verstrahltester": "verstrahlt",
    "verstrahltestes": "verstrahlt",
    "verstrahltet": "verstrahlen",
    "verstreiche": "verstreichen",
    "verstreichend": "verstreichen",
    "verstreichende": "verstreichend",
    "verstreichendem": "verstreichend",
    "verstreichenden": "verstreichend",
    "verstreichender": "verstreichend",
    "verstreichendes": "verstreichend",
    "verstreichest": "verstreichen",
    "verstreichet": "verstreichen",
    "verstreichst": "verstreichen",
    "verstreicht": "verstreichen",
    "verstreue": "verstreuen",
    "verstreuend": "verstreuen",
    "verstreuende": "verstreuend",
    "verstreuendem": "verstreuend",
    "verstreuenden": "verstreuend",
    "verstreuender": "verstreuend",
    "verstreuendes": "verstreuend",
    "verstreuest": "verstreuen",
    "verstreuet": "verstreuen",
    "verstreust": "verstreuen",
    "verstreut": "verstreuen",
    "verstreute": "verstreuen",
    "verstreutem": "verstreut",
    "verstreuten": "verstreuen",
    "verstreuter": "verstreut",
    "verstreutes": "verstreut",
    "verstreutest": "verstreuen",
    "verstreutet": "verstreuen",
    "verstrich": "verstreichen",
    "verstriche": "verstreichen",
    "verstrichen": "verstreichen",
    "verstrichene": "verstrichen",
    "verstrichenem": "verstrichen",
    "verstrichenen": "verstrichen",
    "verstrichener": "verstrichen",
    "verstrichenes": "verstrichen",
    "verstrichest": "verstreichen",
    "verstrichet": "verstreichen",
    "verstrichst": "verstreichen",
    "verstricht": "verstreichen",
    "verstrome": "verstromen",
    "verstromend": "verstromen",
    "verstromende": "verstromend",
    "verstromendem": "verstromend",
    "verstromenden": "verstromend",
    "verstromender": "verstromend",
    "verstromendes": "verstromend",
    "verstromest": "verstromen",
    "verstromet": "verstromen",
    "verstromst": "verstromen",
    "verstromt": "verstromen",
    "verstromte": "verstromen",
    "verstromtem": "verstromt",
    "verstromten": "verstromen",
    "verstromter": "verstromt",
    "verstromtes": "verstromt",
    "verstromtest": "verstromen",
    "verstromtet": "verstromen",
    "verstumme": "verstummen",
    "verstummend": "verstummen",
    "verstummende": "verstummend",
    "verstummendem": "verstummend",
    "verstummenden": "verstummend",
    "verstummender": "verstummend",
    "verstummendes": "verstummend",
    "verstummest": "verstummen",
    "verstummet": "verstummen",
    "verstummst": "verstummen",
    "verstummt": "verstummen",
    "verstummte": "verstummen",
    "verstummtem": "verstummt",
    "verstummten": "verstummen",
    "verstummter": "verstummt",
    "verstummtes": "verstummt",
    "verstummtest": "verstummen",
    "verstummtet": "verstummen",
    "verständige": "verständigen",
    "verständigend": "verständigen",
    "verständigende": "verständigend",
    "verständigendem": "verständigend",
    "verständigenden": "verständigend",
    "verständigender": "verständigend",
    "verständigendes": "verständigend",
    "verständigest": "verständigen",
    "verständiget": "verständigen",
    "verständigst": "verständigen",
    "verständigt": "verständigen",
    "verständigte": "verständigen",
    "verständigtem": "verständigt",
    "verständigten": "verständigen",
    "verständigter": "verständigt",
    "verständigtes": "verständigt",
    "verständigtest": "verständigen",
    "verständigtet": "verständigen",
    "verständlichem": "verständlich",
    "verständlichen": "verständlich",
    "verständlicher": "verständlich",
    "verständlichere": "verständlich",
    "verständlicherem": "verständlich",
    "verständlicheren": "verständlich",
    "verständlicherer": "verständlich",
    "verständlicheres": "verständlich",
    "verständliches": "verständlich",
    "verständlichste": "verständlich",
    "verständlichstem": "verständlich",
    "verständlichsten": "verständlich",
    "verständlichster": "verständlich",
    "verständlichstes": "verständlich",
    "verständnislose": "verständnislos",
    "verständnislosem": "verständnislos",
    "verständnislosen": "verständnislos",
    "verständnisloser": "verständnislos",
    "verständnislosere": "verständnislos",
    "verständnisloserem": "verständnislos",
    "verständnisloseren": "verständnislos",
    "verständnisloserer": "verständnislos",
    "verständnisloseres": "verständnislos",
    "verständnisloses": "verständnislos",
    "verständnisloseste": "verständnislos",
    "verständnislosestem": "verständnislos",
    "verständnislosesten": "verständnislos",
    "verständnislosester": "verständnislos",
    "verständnislosestes": "verständnislos",
    "verständnisvollem": "verständnisvoll",
    "verständnisvollen": "verständnisvoll",
    "verständnisvoller": "verständnisvoll",
    "verständnisvollere": "verständnisvoll",
    "verständnisvollerem": "verständnisvoll",
    "verständnisvolleren": "verständnisvoll",
    "verständnisvollerer": "verständnisvoll",
    "verständnisvolleres": "verständnisvoll",
    "verständnisvolles": "verständnisvoll",
    "verständnisvollste": "verständnisvoll",
    "verständnisvollstem": "verständnisvoll",
    "verständnisvollsten": "verständnisvoll",
    "verständnisvollster": "verständnisvoll",
    "verständnisvollstes": "verständnisvoll",
    "verstänkere": "verstänkern",
    "verstänkernd": "verstänkern",
    "verstänkernde": "verstänkernd",
    "verstänkerndem": "verstänkernd",
    "verstänkernden": "verstänkernd",
    "verstänkernder": "verstänkernd",
    "verstänkerndes": "verstänkernd",
    "verstänkerst": "verstänkern",
    "verstänkert": "verstänkern",
    "verstänkerte": "verstänkern",
    "verstänkertem": "verstänkert",
    "verstänkerten": "verstänkern",
    "verstänkerter": "verstänkert",
    "verstänkertes": "verstänkert",
    "verstänkertest": "verstänkern",
    "verstänkertet": "verstänkern",
    "verstärbe": "versterben",
    "verstärben": "versterben",
    "verstärbest": "versterben",
    "verstärbet": "versterben",
    "verstärke": "verstärken",
    "verstärkend": "verstärken",
    "verstärkende": "verstärkend",
    "verstärkendem": "verstärkend",
    "verstärkenden": "verstärkend",
    "verstärkender": "verstärkend",
    "verstärkendere": "verstärkend",
    "verstärkenderem": "verstärkend",
    "verstärkenderen": "verstärkend",
    "verstärkenderer": "verstärkend",
    "verstärkenderes": "verstärkend",
    "verstärkendes": "verstärkend",
    "verstärkendste": "verstärkend",
    "verstärkendstem": "verstärkend",
    "verstärkendsten": "verstärkend",
    "verstärkendster": "verstärkend",
    "verstärkendstes": "verstärkend",
    "verstärkest": "verstärken",
    "verstärket": "verstärken",
    "verstärkst": "verstärken",
    "verstärkt": "verstärken",
    "verstärkte": "verstärken",
    "verstärktem": "verstärkt",
    "verstärkten": "verstärken",
    "verstärkter": "verstärkt",
    "verstärktere": "verstärkt",
    "verstärkterem": "verstärkt",
    "verstärkteren": "verstärkt",
    "verstärkterer": "verstärkt",
    "verstärkteres": "verstärkt",
    "verstärktes": "verstärkt",
    "verstärktest": "verstärken",
    "verstärkteste": "verstärkt",
    "verstärktestem": "verstärkt",
    "verstärktesten": "verstärkt",
    "verstärktester": "verstärkt",
    "verstärktestes": "verstärkt",
    "verstärktet": "verstärken",
    "verstößt": "verstoßen",
    "verstückele": "verstückeln",
    "verstückelnd": "verstückeln",
    "verstückelnde": "verstückelnd",
    "verstückelndem": "verstückelnd",
    "verstückelnden": "verstückelnd",
    "verstückelnder": "verstückelnd",
    "verstückelndere": "verstückelnd",
    "verstückelnderem": "verstückelnd",
    "verstückelnderen": "verstückelnd",
    "verstückelnderer": "verstückelnd",
    "verstückelnderes": "verstückelnd",
    "verstückelndes": "verstückelnd",
    "verstückelndste": "verstückelnd",
    "verstückelndstem": "verstückelnd",
    "verstückelndsten": "verstückelnd",
    "verstückelndster": "verstückelnd",
    "verstückelndstes": "verstückelnd",
    "verstückelst": "verstückeln",
    "verstückelt": "verstückeln",
    "verstückelte": "verstückeln",
    "verstückeltem": "verstückelt",
    "verstückelten": "verstückeln",
    "verstückelter": "verstückelt",
    "verstückeltere": "verstückelt",
    "verstückelterem": "verstückelt",
    "verstückelteren": "verstückelt",
    "verstückelterer": "verstückelt",
    "verstückelteres": "verstückelt",
    "verstückeltes": "verstückelt",
    "verstückeltest": "verstückeln",
    "verstückelteste": "verstückelt",
    "verstückeltestem": "verstückelt",
    "verstückeltesten": "verstückelt",
    "verstückeltester": "verstückelt",
    "verstückeltestes": "verstückelt",
    "verstückeltet": "verstückeln",
    "verstückle": "verstückeln",
    "verstümmele": "verstümmeln",
    "verstümmelnd": "verstümmeln",
    "verstümmelnde": "verstümmelnd",
    "verstümmelndem": "verstümmelnd",
    "verstümmelnden": "verstümmelnd",
    "verstümmelnder": "verstümmelnd",
    "verstümmelndere": "verstümmelnd",
    "verstümmelnderem": "verstümmelnd",
    "verstümmelnderen": "verstümmelnd",
    "verstümmelnderer": "verstümmelnd",
    "verstümmelnderes": "verstümmelnd",
    "verstümmelndes": "verstümmelnd",
    "verstümmelndste": "verstümmelnd",
    "verstümmelndstem": "verstümmelnd",
    "verstümmelndsten": "verstümmelnd",
    "verstümmelndster": "verstümmelnd",
    "verstümmelndstes": "verstümmelnd",
    "verstümmelst": "verstümmeln",
    "verstümmelt": "verstümmeln",
    "verstümmelte": "verstümmeln",
    "verstümmeltem": "verstümmelt",
    "verstümmelten": "verstümmeln",
    "verstümmelter": "verstümmelt",
    "verstümmeltere": "verstümmelt",
    "verstümmelterem": "verstümmelt",
    "verstümmelteren": "verstümmelt",
    "verstümmelterer": "verstümmelt",
    "verstümmelteres": "verstümmelt",
    "verstümmeltes": "verstümmelt",
    "verstümmeltest": "verstümmeln",
    "verstümmelteste": "verstümmelt",
    "verstümmeltestem": "verstümmelt",
    "verstümmeltesten": "verstümmelt",
    "verstümmeltester": "verstümmelt",
    "verstümmeltestes": "verstümmelt",
    "verstümmeltet": "verstümmeln",
    "verstümmle": "verstümmeln",
    "verstünde": "verstehen",
    "verstünden": "verstehen",
    "verstündest": "verstehen",
    "verstündet": "verstehen",
    "versuchend": "versuchen",
    "versuchende": "versuchend",
    "versuchendem": "versuchend",
    "versuchenden": "versuchend",
    "versuchender": "versuchend",
    "versuchendes": "versuchend",
    "versuchest": "versuchen",
    "versuchet": "versuchen",
    "versuchst": "versuchen",
    "versucht": "versuchen",
    "versuchte": "versuchen",
    "versuchtem": "versucht",
    "versuchten": "versuchen",
    "versuchter": "versucht",
    "versuchtere": "versucht",
    "versuchterem": "versucht",
    "versuchteren": "versucht",
    "versuchterer": "versucht",
    "versuchteres": "versucht",
    "versuchtes": "versucht",
    "versuchtest": "versuchen",
    "versuchteste": "versucht",
    "versuchtestem": "versucht",
    "versuchtesten": "versucht",
    "versuchtester": "versucht",
    "versuchtestes": "versucht",
    "versuchtet": "versuchen",
    "versumpfe": "versumpfen",
    "versumpfend": "versumpfen",
    "versumpfende": "versumpfend",
    "versumpfendem": "versumpfend",
    "versumpfenden": "versumpfend",
    "versumpfender": "versumpfend",
    "versumpfendere": "versumpfend",
    "versumpfenderem": "versumpfend",
    "versumpfenderen": "versumpfend",
    "versumpfenderer": "versumpfend",
    "versumpfenderes": "versumpfend",
    "versumpfendes": "versumpfend",
    "versumpfendste": "versumpfend",
    "versumpfendstem": "versumpfend",
    "versumpfendsten": "versumpfend",
    "versumpfendster": "versumpfend",
    "versumpfendstes": "versumpfend",
    "versumpfest": "versumpfen",
    "versumpfet": "versumpfen",
    "versumpfst": "versumpfen",
    "versumpft": "versumpfen",
    "versumpfte": "versumpfen",
    "versumpftem": "versumpft",
    "versumpften": "versumpfen",
    "versumpfter": "versumpft",
    "versumpftere": "versumpft",
    "versumpfterem": "versumpft",
    "versumpfteren": "versumpft",
    "versumpfterer": "versumpft",
    "versumpfteres": "versumpft",
    "versumpftes": "versumpft",
    "versumpftest": "versumpfen",
    "versumpfteste": "versumpft",
    "versumpftestem": "versumpft",
    "versumpftesten": "versumpft",
    "versumpftester": "versumpft",
    "versumpftestes": "versumpft",
    "versumpftet": "versumpfen",
    "versunken": "versinken",
    "versunkene": "versunken",
    "versunkenem": "versunken",
    "versunkenen": "versunken",
    "versunkener": "versunken",
    "versunkenere": "versunken",
    "versunkenerem": "versunken",
    "versunkeneren": "versunken",
    "versunkenerer": "versunken",
    "versunkeneres": "versunken",
    "versunkenes": "versunken",
    "versunkenste": "versunken",
    "versunkenstem": "versunken",
    "versunkensten": "versunken",
    "versunkenster": "versunken",
    "versunkenstes": "versunken",
    "versäbele": "versäbeln",
    "versäbelnd": "versäbeln",
    "versäbelnde": "versäbelnd",
    "versäbelndem": "versäbelnd",
    "versäbelnden": "versäbelnd",
    "versäbelnder": "versäbelnd",
    "versäbelndes": "versäbelnd",
    "versäbelst": "versäbeln",
    "versäbelt": "versäbeln",
    "versäbelte": "versäbeln",
    "versäbeltem": "versäbelt",
    "versäbelten": "versäbeln",
    "versäbelter": "versäbelt",
    "versäbeltes": "versäbelt",
    "versäbeltest": "versäbeln",
    "versäbeltet": "versäbeln",
    "versäble": "versäbeln",
    "versähe": "versehen",
    "versähen": "versehen",
    "versähest": "versehen",
    "versähet": "versehen",
    "versänke": "versinken",
    "versänken": "versinken",
    "versänkest": "versinken",
    "versänket": "versinken",
    "versäufst": "versaufen",
    "versäuft": "versaufen",
    "versäume": "versäumen",
    "versäumend": "versäumen",
    "versäumende": "versäumend",
    "versäumendem": "versäumend",
    "versäumenden": "versäumend",
    "versäumender": "versäumend",
    "versäumendes": "versäumend",
    "versäumest": "versäumen",
    "versäumet": "versäumen",
    "versäumst": "versäumen",
    "versäumt": "versäumen",
    "versäumte": "versäumen",
    "versäumtem": "versäumt",
    "versäumten": "versäumen",
    "versäumter": "versäumt",
    "versäumtes": "versäumt",
    "versäumtest": "versäumen",
    "versäumtet": "versäumen",
    "versöffe": "versaufen",
    "versöffen": "versaufen",
    "versöffest": "versaufen",
    "versöffet": "versaufen",
    "versöhne": "versöhnen",
    "versöhnend": "versöhnen",
    "versöhnende": "versöhnend",
    "versöhnendem": "versöhnend",
    "versöhnenden": "versöhnend",
    "versöhnender": "versöhnend",
    "versöhnendes": "versöhnend",
    "versöhnest": "versöhnen",
    "versöhnet": "versöhnen",
    "versöhnliche": "versöhnlich",
    "versöhnlichem": "versöhnlich",
    "versöhnlichen": "versöhnlich",
    "versöhnlicher": "versöhnlich",
    "versöhnlichere": "versöhnlich",
    "versöhnlicherem": "versöhnlich",
    "versöhnlicheren": "versöhnlich",
    "versöhnlicherer": "versöhnlich",
    "versöhnlicheres": "versöhnlich",
    "versöhnliches": "versöhnlich",
    "versöhnlichste": "versöhnlich",
    "versöhnlichstem": "versöhnlich",
    "versöhnlichsten": "versöhnlich",
    "versöhnlichster": "versöhnlich",
    "versöhnlichstes": "versöhnlich",
    "versöhnst": "versöhnen",
    "versöhnt": "versöhnen",
    "versöhnte": "versöhnen",
    "versöhntem": "versöhnt",
    "versöhnten": "versöhnen",
    "versöhnter": "versöhnt",
    "versöhntes": "versöhnt",
    "versöhntest": "versöhnen",
    "versöhntet": "versöhnen",
    "versühne": "versühnen",
    "versühnend": "versühnen",
    "versühnende": "versühnend",
    "versühnendem": "versühnend",
    "versühnenden": "versühnend",
    "versühnender": "versühnend",
    "versühnendes": "versühnend",
    "versühnest": "versühnen",
    "versühnet": "versühnen",
    "versühnst": "versühnen",
    "versühnt": "versühnen",
    "versühnte": "versühnen",
    "versühntem": "versühnt",
    "versühnten": "versühnen",
    "versühnter": "versühnt",
    "versühntes": "versühnt",
    "versühntest": "versühnen",
    "versühntet": "versühnen",
    "versündige": "versündigen",
    "versündigend": "versündigen",
    "versündigende": "versündigend",
    "versündigendem": "versündigend",
    "versündigenden": "versündigend",
    "versündigender": "versündigend",
    "versündigendes": "versündigend",
    "versündigest": "versündigen",
    "versündiget": "versündigen",
    "versündigst": "versündigen",
    "versündigt": "versündigen",
    "versündigte": "versündigen",
    "versündigtem": "versündigt",
    "versündigten": "versündigen",
    "versündigter": "versündigt",
    "versündigtes": "versündigt",
    "versündigtest": "versündigen",
    "versündigtet": "versündigen",
    "versüße": "versüßen",
    "versüßend": "versüßen",
    "versüßende": "versüßend",
    "versüßendem": "versüßend",
    "versüßenden": "versüßend",
    "versüßender": "versüßend",
    "versüßendere": "versüßend",
    "versüßenderem": "versüßend",
    "versüßenderen": "versüßend",
    "versüßenderer": "versüßend",
    "versüßenderes": "versüßend",
    "versüßendes": "versüßend",
    "versüßendste": "versüßend",
    "versüßendstem": "versüßend",
    "versüßendsten": "versüßend",
    "versüßendster": "versüßend",
    "versüßendstes": "versüßend",
    "versüßest": "versüßen",
    "versüßet": "versüßen",
    "versüßt": "versüßen",
    "versüßte": "versüßen",
    "versüßtem": "versüßt",
    "versüßten": "versüßen",
    "versüßter": "versüßt",
    "versüßtere": "versüßt",
    "versüßterem": "versüßt",
    "versüßteren": "versüßt",
    "versüßterer": "versüßt",
    "versüßteres": "versüßt",
    "versüßtes": "versüßt",
    "versüßtest": "versüßen",
    "versüßteste": "versüßt",
    "versüßtestem": "versüßt",
    "versüßtesten": "versüßt",
    "versüßtester": "versüßt",
    "versüßtestes": "versüßt",
    "versüßtet": "versüßen",
    "vertage": "vertagen",
    "vertagend": "vertagen",
    "vertagende": "vertagend",
    "vertagendem": "vertagend",
    "vertagenden": "vertagend",
    "vertagender": "vertagend",
    "vertagendes": "vertagend",
    "vertagest": "vertagen",
    "vertaget": "vertagen",
    "vertagst": "vertagen",
    "vertagt": "vertagen",
    "vertagte": "vertagen",
    "vertagtem": "vertagt",
    "vertagten": "vertagen",
    "vertagter": "vertagt",
    "vertagtere": "vertagt",
    "vertagterem": "vertagt",
    "vertagteren": "vertagt",
    "vertagterer": "vertagt",
    "vertagteres": "vertagt",
    "vertagtes": "vertagt",
    "vertagtest": "vertagen",
    "vertagteste": "vertagt",
    "vertagtestem": "vertagt",
    "vertagtesten": "vertagt",
    "vertagtester": "vertagt",
    "vertagtestes": "vertagt",
    "vertagtet": "vertagen",
    "vertan": "vertuen",
    "vertane": "vertan",
    "vertanem": "vertan",
    "vertanen": "vertan",
    "vertaner": "vertan",
    "vertanere": "vertan",
    "vertanerem": "vertan",
    "vertaneren": "vertan",
    "vertanerer": "vertan",
    "vertaneres": "vertan",
    "vertanes": "vertan",
    "vertanste": "vertan",
    "vertanstem": "vertan",
    "vertansten": "vertan",
    "vertanster": "vertan",
    "vertanstes": "vertan",
    "vertat": "vertuen",
    "vertaten": "vertuen",
    "vertatest": "vertuen",
    "vertatet": "vertuen",
    "vertausche": "vertauschen",
    "vertauschend": "vertauschen",
    "vertauschende": "vertauschend",
    "vertauschendem": "vertauschend",
    "vertauschenden": "vertauschend",
    "vertauschender": "vertauschend",
    "vertauschendes": "vertauschend",
    "vertauschest": "vertauschen",
    "vertauschet": "vertauschen",
    "vertauschst": "vertauschen",
    "vertauscht": "vertauschen",
    "vertauschte": "vertauschen",
    "vertauschtem": "vertauscht",
    "vertauschten": "vertauschen",
    "vertauschter": "vertauscht",
    "vertauschtes": "vertauscht",
    "vertauschtest": "vertauschen",
    "vertauschtet": "vertauschen",
    "verteidige": "verteidigen",
    "verteidigend": "verteidigen",
    "verteidigende": "verteidigend",
    "verteidigendem": "verteidigend",
    "verteidigenden": "verteidigend",
    "verteidigender": "verteidigend",
    "verteidigendes": "verteidigend",
    "verteidigest": "verteidigen",
    "verteidiget": "verteidigen",
    "verteidigst": "verteidigen",
    "verteidigt": "verteidigen",
    "verteidigte": "verteidigen",
    "verteidigtem": "verteidigt",
    "verteidigten": "verteidigen",
    "verteidigter": "verteidigt",
    "verteidigtes": "verteidigt",
    "verteidigtest": "verteidigen",
    "verteidigtet": "verteidigen",
    "verteile": "verteilen",
    "verteilend": "verteilen",
    "verteilende": "verteilend",
    "verteilendem": "verteilend",
    "verteilenden": "verteilend",
    "verteilender": "verteilend",
    "verteilendes": "verteilend",
    "verteilest": "verteilen",
    "verteilet": "verteilen",
    "verteilst": "verteilen",
    "verteilt": "verteilen",
    "verteilte": "verteilen",
    "verteiltem": "verteilt",
    "verteilten": "verteilen",
    "verteilter": "verteilt",
    "verteiltes": "verteilt",
    "verteiltest": "verteilen",
    "verteiltet": "verteilen",
    "verteuere": "verteuern",
    "verteuernd": "verteuern",
    "verteuernde": "verteuernd",
    "verteuerndem": "verteuernd",
    "verteuernden": "verteuernd",
    "verteuernder": "verteuernd",
    "verteuerndes": "verteuernd",
    "verteuerst": "verteuern",
    "verteuert": "verteuern",
    "verteuerte": "verteuern",
    "verteuertem": "verteuert",
    "verteuerten": "verteuern",
    "verteuerter": "verteuert",
    "verteuertes": "verteuert",
    "verteuertest": "verteuern",
    "verteuertet": "verteuern",
    "verteufele": "verteufeln",
    "verteufelnd": "verteufeln",
    "verteufelnde": "verteufelnd",
    "verteufelndem": "verteufelnd",
    "verteufelnden": "verteufelnd",
    "verteufelnder": "verteufelnd",
    "verteufelndes": "verteufelnd",
    "verteufelst": "verteufeln",
    "verteufelt": "verteufeln",
    "verteufelte": "verteufeln",
    "verteufeltem": "verteufelt",
    "verteufelten": "verteufeln",
    "verteufelter": "verteufelt",
    "verteufeltes": "verteufelt",
    "verteufeltest": "verteufeln",
    "verteufeltet": "verteufeln",
    "verteufle": "verteufeln",
    "vertiefe": "vertiefen",
    "vertiefend": "vertiefen",
    "vertiefende": "vertiefend",
    "vertiefendem": "vertiefend",
    "vertiefenden": "vertiefend",
    "vertiefender": "vertiefend",
    "vertiefendere": "vertiefend",
    "vertiefenderem": "vertiefend",
    "vertiefenderen": "vertiefend",
    "vertiefenderer": "vertiefend",
    "vertiefenderes": "vertiefend",
    "vertiefendes": "vertiefend",
    "vertiefendste": "vertiefend",
    "vertiefendstem": "vertiefend",
    "vertiefendsten": "vertiefend",
    "vertiefendster": "vertiefend",
    "vertiefendstes": "vertiefend",
    "vertiefest": "vertiefen",
    "vertiefet": "vertiefen",
    "vertiefst": "vertiefen",
    "vertieft": "vertiefen",
    "vertiefte": "vertiefen",
    "vertieftem": "vertieft",
    "vertieften": "vertiefen",
    "vertiefter": "vertieft",
    "vertieftes": "vertieft",
    "vertieftest": "vertiefen",
    "vertieftet": "vertiefen",
    "vertilge": "vertilgen",
    "vertilgend": "vertilgen",
    "vertilgende": "vertilgend",
    "vertilgendem": "vertilgend",
    "vertilgenden": "vertilgend",
    "vertilgender": "vertilgend",
    "vertilgendere": "vertilgend",
    "vertilgenderem": "vertilgend",
    "vertilgenderen": "vertilgend",
    "vertilgenderer": "vertilgend",
    "vertilgenderes": "vertilgend",
    "vertilgendes": "vertilgend",
    "vertilgendste": "vertilgend",
    "vertilgendstem": "vertilgend",
    "vertilgendsten": "vertilgend",
    "vertilgendster": "vertilgend",
    "vertilgendstes": "vertilgend",
    "vertilgest": "vertilgen",
    "vertilget": "vertilgen",
    "vertilgst": "vertilgen",
    "vertilgt": "vertilgen",
    "vertilgte": "vertilgen",
    "vertilgtem": "vertilgt",
    "vertilgten": "vertilgen",
    "vertilgter": "vertilgt",
    "vertilgtes": "vertilgt",
    "vertilgtest": "vertilgen",
    "vertilgtet": "vertilgen",
    "vertippe": "vertippen",
    "vertippend": "vertippen",
    "vertippende": "vertippend",
    "vertippendem": "vertippend",
    "vertippenden": "vertippend",
    "vertippender": "vertippend",
    "vertippendere": "vertippend",
    "vertippenderem": "vertippend",
    "vertippenderen": "vertippend",
    "vertippenderer": "vertippend",
    "vertippenderes": "vertippend",
    "vertippendes": "vertippend",
    "vertippendste": "vertippend",
    "vertippendstem": "vertippend",
    "vertippendsten": "vertippend",
    "vertippendster": "vertippend",
    "vertippendstes": "vertippend",
    "vertippest": "vertippen",
    "vertippet": "vertippen",
    "vertippst": "vertippen",
    "vertippt": "vertippen",
    "vertippte": "vertippen",
    "vertipptem": "vertippt",
    "vertippten": "vertippen",
    "vertippter": "vertippt",
    "vertipptes": "vertippt",
    "vertipptest": "vertippen",
    "vertipptet": "vertippen",
    "vertone": "vertonen",
    "vertonend": "vertonen",
    "vertonende": "vertonend",
    "vertonendem": "vertonend",
    "vertonenden": "vertonend",
    "vertonender": "vertonend",
    "vertonendes": "vertonend",
    "vertonest": "vertonen",
    "vertonet": "vertonen",
    "vertonst": "vertonen",
    "vertont": "vertonen",
    "vertonte": "vertonen",
    "vertontem": "vertont",
    "vertonten": "vertonen",
    "vertonter": "vertont",
    "vertontes": "vertont",
    "vertontest": "vertonen",
    "vertontet": "vertonen",
    "vertracktem": "vertrackt",
    "vertrackten": "vertrackt",
    "vertrackter": "vertrackt",
    "vertracktere": "vertrackt",
    "vertrackterem": "vertrackt",
    "vertrackteren": "vertrackt",
    "vertrackterer": "vertrackt",
    "vertrackteres": "vertrackt",
    "vertracktes": "vertrackt",
    "vertrackteste": "vertrackt",
    "vertracktestem": "vertrackt",
    "vertracktesten": "vertrackt",
    "vertracktester": "vertrackt",
    "vertracktestes": "vertrackt",
    "vertragend": "vertragen",
    "vertragende": "vertragend",
    "vertragendem": "vertragend",
    "vertragenden": "vertragend",
    "vertragender": "vertragend",
    "vertragendes": "vertragend",
    "vertragene": "vertragen",
    "vertragenem": "vertragen",
    "vertragenen": "vertragen",
    "vertragener": "vertragen",
    "vertragenes": "vertragen",
    "vertragest": "vertragen",
    "vertraget": "vertragen",
    "vertragliche": "vertraglich",
    "vertraglichem": "vertraglich",
    "vertraglichen": "vertraglich",
    "vertraglicher": "vertraglich",
    "vertragliches": "vertraglich",
    "vertragsbrüchigem": "vertragsbrüchig",
    "vertragsbrüchigen": "vertragsbrüchig",
    "vertragsbrüchiger": "vertragsbrüchig",
    "vertragsbrüchiges": "vertragsbrüchig",
    "vertragsgemäße": "vertragsgemäß",
    "vertragsgemäßem": "vertragsgemäß",
    "vertragsgemäßen": "vertragsgemäß",
    "vertragsgemäßer": "vertragsgemäß",
    "vertragsgemäßes": "vertragsgemäß",
    "vertragswidrige": "vertragswidrig",
    "vertragswidrigem": "vertragswidrig",
    "vertragswidrigen": "vertragswidrig",
    "vertragswidriger": "vertragswidrig",
    "vertragswidriges": "vertragswidrig",
    "vertragt": "vertragen",
    "vertrat": "vertreten",
    "vertraten": "vertreten",
    "vertratest": "vertreten",
    "vertratet": "vertreten",
    "vertraue": "vertrauen",
    "vertrauend": "vertrauen",
    "vertrauende": "vertrauend",
    "vertrauendem": "vertrauend",
    "vertrauenden": "vertrauend",
    "vertrauender": "vertrauend",
    "vertrauendere": "vertrauend",
    "vertrauenderem": "vertrauend",
    "vertrauenderen": "vertrauend",
    "vertrauenderer": "vertrauend",
    "vertrauenderes": "vertrauend",
    "vertrauendes": "vertrauend",
    "vertrauendste": "vertrauend",
    "vertrauendstem": "vertrauend",
    "vertrauendsten": "vertrauend",
    "vertrauendster": "vertrauend",
    "vertrauendstes": "vertrauend",
    "vertrauensbildendem": "vertrauensbildend",
    "vertrauensbildenden": "vertrauensbildend",
    "vertrauensbildender": "vertrauensbildend",
    "vertrauensbildendes": "vertrauensbildend",
    "vertrauensselige": "vertrauensselig",
    "vertrauensseligem": "vertrauensselig",
    "vertrauensseligen": "vertrauensselig",
    "vertrauensseliger": "vertrauensselig",
    "vertrauensseligere": "vertrauensselig",
    "vertrauensseligerem": "vertrauensselig",
    "vertrauensseligeren": "vertrauensselig",
    "vertrauensseligerer": "vertrauensselig",
    "vertrauensseligeres": "vertrauensselig",
    "vertrauensseliges": "vertrauensselig",
    "vertrauensseligste": "vertrauensselig",
    "vertrauensseligstem": "vertrauensselig",
    "vertrauensseligsten": "vertrauensselig",
    "vertrauensseligster": "vertrauensselig",
    "vertrauensseligstes": "vertrauensselig",
    "vertrauensvolle": "vertrauensvoll",
    "vertrauensvollem": "vertrauensvoll",
    "vertrauensvollen": "vertrauensvoll",
    "vertrauensvoller": "vertrauensvoll",
    "vertrauensvollere": "vertrauensvoll",
    "vertrauensvollerem": "vertrauensvoll",
    "vertrauensvolleren": "vertrauensvoll",
    "vertrauensvollerer": "vertrauensvoll",
    "vertrauensvolleres": "vertrauensvoll",
    "vertrauensvolles": "vertrauensvoll",
    "vertrauensvollste": "vertrauensvoll",
    "vertrauensvollstem": "vertrauensvoll",
    "vertrauensvollsten": "vertrauensvoll",
    "vertrauensvollster": "vertrauensvoll",
    "vertrauensvollstes": "vertrauensvoll",
    "vertrauenswürdige": "vertrauenswürdig",
    "vertrauenswürdigem": "vertrauenswürdig",
    "vertrauenswürdigen": "vertrauenswürdig",
    "vertrauenswürdiger": "vertrauenswürdig",
    "vertrauenswürdigere": "vertrauenswürdig",
    "vertrauenswürdigerem": "vertrauenswürdig",
    "vertrauenswürdigeren": "vertrauenswürdig",
    "vertrauenswürdigerer": "vertrauenswürdig",
    "vertrauenswürdigeres": "vertrauenswürdig",
    "vertrauenswürdiges": "vertrauenswürdig",
    "vertrauenswürdigste": "vertrauenswürdig",
    "vertrauenswürdigstem": "vertrauenswürdig",
    "vertrauenswürdigsten": "vertrauenswürdig",
    "vertrauenswürdigster": "vertrauenswürdig",
    "vertrauenswürdigstes": "vertrauenswürdig",
    "vertrauest": "vertrauen",
    "vertrauet": "vertrauen",
    "vertrauliche": "vertraulich",
    "vertraulichem": "vertraulich",
    "vertraulichen": "vertraulich",
    "vertraulicher": "vertraulich",
    "vertraulichere": "vertraulich",
    "vertraulicherem": "vertraulich",
    "vertraulicheren": "vertraulich",
    "vertraulicherer": "vertraulich",
    "vertraulicheres": "vertraulich",
    "vertrauliches": "vertraulich",
    "vertraulichstem": "vertraulich",
    "vertraulichsten": "vertraulich",
    "vertraulichster": "vertraulich",
    "vertraulichstes": "vertraulich",
    "vertraust": "vertrauen",
    "vertraut": "vertrauen",
    "vertraute": "vertrauen",
    "vertrautem": "vertraut",
    "vertrauten": "vertrauen",
    "vertrauter": "vertraut",
    "vertrautere": "vertraut",
    "vertrauterem": "vertraut",
    "vertrauteren": "vertraut",
    "vertrauterer": "vertraut",
    "vertrauteres": "vertraut",
    "vertrautes": "vertraut",
    "vertrautest": "vertrauen",
    "vertrauteste": "vertraut",
    "vertrautestem": "vertraut",
    "vertrautesten": "vertraut",
    "vertrautester": "vertraut",
    "vertrautestes": "vertraut",
    "vertrautet": "vertrauen",
    "vertreibe": "vertreiben",
    "vertreibend": "vertreiben",
    "vertreibende": "vertreibend",
    "vertreibendem": "vertreibend",
    "vertreibenden": "vertreibend",
    "vertreibender": "vertreibend",
    "vertreibendes": "vertreibend",
    "vertreibest": "vertreiben",
    "vertreibet": "vertreiben",
    "vertreibst": "vertreiben",
    "vertreibt": "vertreiben",
    "vertretbarem": "vertretbar",
    "vertretbaren": "vertretbar",
    "vertretbarer": "vertretbar",
    "vertretbares": "vertretbar",
    "vertrete": "vertreten",
    "vertretend": "vertreten",
    "vertretende": "vertretend",
    "vertretendem": "vertretend",
    "vertretenden": "vertretend",
    "vertretender": "vertretend",
    "vertretendes": "vertretend",
    "vertretene": "vertreten",
    "vertretenem": "vertreten",
    "vertretenen": "vertreten",
    "vertretener": "vertreten",
    "vertretenes": "vertreten",
    "vertretest": "vertreten",
    "vertretet": "vertreten",
    "vertriebe": "vertreiben",
    "vertrieben": "vertreiben",
    "vertriebene": "vertrieben",
    "vertriebenem": "vertrieben",
    "vertriebenen": "vertrieben",
    "vertriebener": "vertrieben",
    "vertriebenes": "vertrieben",
    "vertriebest": "vertreiben",
    "vertriebet": "vertreiben",
    "vertriebst": "vertreiben",
    "vertriebt": "vertreiben",
    "vertrimme": "vertrimmen",
    "vertrimmend": "vertrimmen",
    "vertrimmende": "vertrimmend",
    "vertrimmendem": "vertrimmend",
    "vertrimmenden": "vertrimmend",
    "vertrimmender": "vertrimmend",
    "vertrimmendes": "vertrimmend",
    "vertrimmest": "vertrimmen",
    "vertrimmet": "vertrimmen",
    "vertrimmst": "vertrimmen",
    "vertrimmt": "vertrimmen",
    "vertrimmte": "vertrimmen",
    "vertrimmtem": "vertrimmt",
    "vertrimmten": "vertrimmen",
    "vertrimmter": "vertrimmt",
    "vertrimmtes": "vertrimmt",
    "vertrimmtest": "vertrimmen",
    "vertrimmtet": "vertrimmen",
    "vertritt": "vertreten",
    "vertrittst": "vertreten",
    "vertrockne": "vertrocknen",
    "vertrocknend": "vertrocknen",
    "vertrocknende": "vertrocknend",
    "vertrocknendem": "vertrocknend",
    "vertrocknenden": "vertrocknend",
    "vertrocknender": "vertrocknend",
    "vertrocknendere": "vertrocknend",
    "vertrocknenderem": "vertrocknend",
    "vertrocknenderen": "vertrocknend",
    "vertrocknenderer": "vertrocknend",
    "vertrocknenderes": "vertrocknend",
    "vertrocknendes": "vertrocknend",
    "vertrocknendste": "vertrocknend",
    "vertrocknendstem": "vertrocknend",
    "vertrocknendsten": "vertrocknend",
    "vertrocknendster": "vertrocknend",
    "vertrocknendstes": "vertrocknend",
    "vertrocknest": "vertrocknen",
    "vertrocknet": "vertrocknen",
    "vertrocknete": "vertrocknen",
    "vertrocknetem": "vertrocknet",
    "vertrockneten": "vertrocknen",
    "vertrockneter": "vertrocknet",
    "vertrocknetere": "vertrocknet",
    "vertrockneterem": "vertrocknet",
    "vertrockneteren": "vertrocknet",
    "vertrockneterer": "vertrocknet",
    "vertrockneteres": "vertrocknet",
    "vertrocknetes": "vertrocknet",
    "vertrocknetest": "vertrocknen",
    "vertrockneteste": "vertrocknet",
    "vertrocknetestem": "vertrocknet",
    "vertrocknetesten": "vertrocknet",
    "vertrocknetester": "vertrocknet",
    "vertrocknetestes": "vertrocknet",
    "vertrocknetet": "vertrocknen",
    "vertrug": "vertragen",
    "vertrugen": "vertragen",
    "vertrugst": "vertragen",
    "vertrugt": "vertragen",
    "verträglichem": "verträglich",
    "verträglicher": "verträglich",
    "verträglichere": "verträglich",
    "verträglicherem": "verträglich",
    "verträglicheren": "verträglich",
    "verträglicherer": "verträglich",
    "verträglicheres": "verträglich",
    "verträgliches": "verträglich",
    "verträglichste": "verträglich",
    "verträglichstem": "verträglich",
    "verträglichsten": "verträglich",
    "verträglichster": "verträglich",
    "verträglichstes": "verträglich",
    "verträgst": "vertragen",
    "verträgt": "vertragen",
    "verträte": "vertreten",
    "verträten": "vertreten",
    "verträtest": "vertreten",
    "verträtet": "vertreten",
    "verträume": "verträumen",
    "verträumend": "verträumen",
    "verträumende": "verträumend",
    "verträumendem": "verträumend",
    "verträumenden": "verträumend",
    "verträumender": "verträumend",
    "verträumendere": "verträumend",
    "verträumenderem": "verträumend",
    "verträumenderen": "verträumend",
    "verträumenderer": "verträumend",
    "verträumenderes": "verträumend",
    "verträumendes": "verträumend",
    "verträumendste": "verträumend",
    "verträumendstem": "verträumend",
    "verträumendsten": "verträumend",
    "verträumendster": "verträumend",
    "verträumendstes": "verträumend",
    "verträumest": "verträumen",
    "verträumet": "verträumen",
    "verträumst": "verträumen",
    "verträumt": "verträumen",
    "verträumte": "verträumen",
    "verträumtem": "verträumt",
    "verträumten": "verträumen",
    "verträumter": "verträumt",
    "verträumtere": "verträumt",
    "verträumterem": "verträumt",
    "verträumteren": "verträumt",
    "verträumterer": "verträumt",
    "verträumteres": "verträumt",
    "verträumtes": "verträumt",
    "verträumtest": "verträumen",
    "verträumteste": "verträumt",
    "verträumtestem": "verträumt",
    "verträumtesten": "verträumt",
    "verträumtester": "verträumt",
    "verträumtestes": "verträumt",
    "verträumtet": "verträumen",
    "vertrödele": "vertrödeln",
    "vertrödelnd": "vertrödeln",
    "vertrödelnde": "vertrödelnd",
    "vertrödelndem": "vertrödelnd",
    "vertrödelnden": "vertrödelnd",
    "vertrödelnder": "vertrödelnd",
    "vertrödelndere": "vertrödelnd",
    "vertrödelnderem": "vertrödelnd",
    "vertrödelnderen": "vertrödelnd",
    "vertrödelnderer": "vertrödelnd",
    "vertrödelnderes": "vertrödelnd",
    "vertrödelndes": "vertrödelnd",
    "vertrödelndste": "vertrödelnd",
    "vertrödelndstem": "vertrödelnd",
    "vertrödelndsten": "vertrödelnd",
    "vertrödelndster": "vertrödelnd",
    "vertrödelndstes": "vertrödelnd",
    "vertrödelst": "vertrödeln",
    "vertrödelt": "vertrödeln",
    "vertrödelte": "vertrödeln",
    "vertrödeltem": "vertrödelt",
    "vertrödelten": "vertrödeln",
    "vertrödelter": "vertrödelt",
    "vertrödeltere": "vertrödelt",
    "vertrödelterem": "vertrödelt",
    "vertrödelteren": "vertrödelt",
    "vertrödelterer": "vertrödelt",
    "vertrödelteres": "vertrödelt",
    "vertrödeltes": "vertrödelt",
    "vertrödeltest": "vertrödeln",
    "vertrödelteste": "vertrödelt",
    "vertrödeltestem": "vertrödelt",
    "vertrödeltesten": "vertrödelt",
    "vertrödeltester": "vertrödelt",
    "vertrödeltestes": "vertrödelt",
    "vertrödeltet": "vertrödeln",
    "vertrödle": "vertrödeln",
    "vertröste": "vertrösten",
    "vertröstend": "vertrösten",
    "vertröstende": "vertröstend",
    "vertröstendem": "vertröstend",
    "vertröstenden": "vertröstend",
    "vertröstender": "vertröstend",
    "vertröstendere": "vertröstend",
    "vertröstenderem": "vertröstend",
    "vertröstenderen": "vertröstend",
    "vertröstenderer": "vertröstend",
    "vertröstenderes": "vertröstend",
    "vertröstendes": "vertröstend",
    "vertröstendste": "vertröstend",
    "vertröstendstem": "vertröstend",
    "vertröstendsten": "vertröstend",
    "vertröstendster": "vertröstend",
    "vertröstendstes": "vertröstend",
    "vertröstest": "vertrösten",
    "vertröstet": "vertrösten",
    "vertröstete": "vertrösten",
    "vertröstetem": "vertröstet",
    "vertrösteten": "vertrösten",
    "vertrösteter": "vertröstet",
    "vertröstetere": "vertröstet",
    "vertrösteterem": "vertröstet",
    "vertrösteteren": "vertröstet",
    "vertrösteterer": "vertröstet",
    "vertrösteteres": "vertröstet",
    "vertröstetes": "vertröstet",
    "vertröstetest": "vertrösten",
    "vertrösteteste": "vertröstet",
    "vertröstetestem": "vertröstet",
    "vertröstetesten": "vertröstet",
    "vertröstetester": "vertröstet",
    "vertröstetestes": "vertröstet",
    "vertröstetet": "vertrösten",
    "vertrüge": "vertragen",
    "vertrügen": "vertragen",
    "vertrügest": "vertragen",
    "vertrüget": "vertragen",
    "vertue": "vertuen",
    "vertuend": "vertuen",
    "vertuende": "vertuend",
    "vertuendem": "vertuend",
    "vertuenden": "vertuend",
    "vertuender": "vertuend",
    "vertuendes": "vertuend",
    "vertuest": "vertuen",
    "vertuet": "vertuen",
    "vertun": "vertuen",
    "vertusche": "vertuschen",
    "vertuschend": "vertuschen",
    "vertuschende": "vertuschend",
    "vertuschendem": "vertuschend",
    "vertuschenden": "vertuschend",
    "vertuschender": "vertuschend",
    "vertuschendes": "vertuschend",
    "vertuschest": "vertuschen",
    "vertuschet": "vertuschen",
    "vertuschst": "vertuschen",
    "vertuscht": "vertuschen",
    "vertuschte": "vertuschen",
    "vertuschtem": "vertuscht",
    "vertuschten": "vertuschen",
    "vertuschter": "vertuscht",
    "vertuschtes": "vertuscht",
    "vertuschtest": "vertuschen",
    "vertuschtet": "vertuschen",
    "vertust": "vertuen",
    "vertut": "vertuen",
    "vertäfele": "vertäfeln",
    "vertäfelnd": "vertäfeln",
    "vertäfelnde": "vertäfelnd",
    "vertäfelndem": "vertäfelnd",
    "vertäfelnden": "vertäfelnd",
    "vertäfelnder": "vertäfelnd",
    "vertäfelndes": "vertäfelnd",
    "vertäfelst": "vertäfeln",
    "vertäfelt": "vertäfeln",
    "vertäfelte": "vertäfeln",
    "vertäfeltem": "vertäfelt",
    "vertäfelten": "vertäfeln",
    "vertäfelter": "vertäfelt",
    "vertäfeltes": "vertäfelt",
    "vertäfeltest": "vertäfeln",
    "vertäfeltet": "vertäfeln",
    "vertäfle": "vertäfeln",
    "vertändele": "vertändeln",
    "vertändelnd": "vertändeln",
    "vertändelnde": "vertändelnd",
    "vertändelndem": "vertändelnd",
    "vertändelnden": "vertändelnd",
    "vertändelnder": "vertändelnd",
    "vertändelndere": "vertändelnd",
    "vertändelnderem": "vertändelnd",
    "vertändelnderen": "vertändelnd",
    "vertändelnderer": "vertändelnd",
    "vertändelnderes": "vertändelnd",
    "vertändelndes": "vertändelnd",
    "vertändelndste": "vertändelnd",
    "vertändelndstem": "vertändelnd",
    "vertändelndsten": "vertändelnd",
    "vertändelndster": "vertändelnd",
    "vertändelndstes": "vertändelnd",
    "vertändelst": "vertändeln",
    "vertändelt": "vertändeln",
    "vertändelte": "vertändeln",
    "vertändeltem": "vertändelt",
    "vertändelten": "vertändeln",
    "vertändelter": "vertändelt",
    "vertändeltes": "vertändelt",
    "vertändeltest": "vertändeln",
    "vertändeltet": "vertändeln",
    "vertändle": "vertändeln",
    "vertäte": "vertuen",
    "vertäten": "vertuen",
    "vertätest": "vertuen",
    "vertätet": "vertuen",
    "verulke": "verulken",
    "verulkend": "verulken",
    "verulkende": "verulkend",
    "verulkendem": "verulkend",
    "verulkenden": "verulkend",
    "verulkender": "verulkend",
    "verulkendere": "verulkend",
    "verulkenderem": "verulkend",
    "verulkenderen": "verulkend",
    "verulkenderer": "verulkend",
    "verulkenderes": "verulkend",
    "verulkendes": "verulkend",
    "verulkendste": "verulkend",
    "verulkendstem": "verulkend",
    "verulkendsten": "verulkend",
    "verulkendster": "verulkend",
    "verulkendstes": "verulkend",
    "verulkest": "verulken",
    "verulket": "verulken",
    "verulkst": "verulken",
    "verulkt": "verulken",
    "verulkte": "verulken",
    "verulktem": "verulkt",
    "verulkten": "verulken",
    "verulkter": "verulkt",
    "verulktere": "verulkt",
    "verulkterem": "verulkt",
    "verulkteren": "verulkt",
    "verulkterer": "verulkt",
    "verulkteres": "verulkt",
    "verulktes": "verulkt",
    "verulktest": "verulken",
    "verulkteste": "verulkt",
    "verulktestem": "verulkt",
    "verulktesten": "verulkt",
    "verulktester": "verulkt",
    "verulktestes": "verulkt",
    "verulktet": "verulken",
    "verunfalle": "verunfallen",
    "verunfallend": "verunfallen",
    "verunfallende": "verunfallend",
    "verunfallendem": "verunfallend",
    "verunfallenden": "verunfallend",
    "verunfallender": "verunfallend",
    "verunfallendes": "verunfallend",
    "verunfallest": "verunfallen",
    "verunfallet": "verunfallen",
    "verunfallst": "verunfallen",
    "verunfallt": "verunfallen",
    "verunfallte": "verunfallen",
    "verunfalltem": "verunfallt",
    "verunfallten": "verunfallen",
    "verunfallter": "verunfallt",
    "verunfalltes": "verunfallt",
    "verunfalltest": "verunfallen",
    "verunfalltet": "verunfallen",
    "verunglimpfe": "verunglimpfen",
    "verunglimpfend": "verunglimpfen",
    "verunglimpfende": "verunglimpfend",
    "verunglimpfendem": "verunglimpfend",
    "verunglimpfenden": "verunglimpfend",
    "verunglimpfender": "verunglimpfend",
    "verunglimpfendes": "verunglimpfend",
    "verunglimpfest": "verunglimpfen",
    "verunglimpfet": "verunglimpfen",
    "verunglimpfst": "verunglimpfen",
    "verunglimpft": "verunglimpfen",
    "verunglimpfte": "verunglimpfen",
    "verunglimpftem": "verunglimpft",
    "verunglimpften": "verunglimpfen",
    "verunglimpfter": "verunglimpft",
    "verunglimpftes": "verunglimpft",
    "verunglimpftest": "verunglimpfen",
    "verunglimpftet": "verunglimpfen",
    "verunglücke": "verunglücken",
    "verunglückend": "verunglücken",
    "verunglückende": "verunglückend",
    "verunglückendem": "verunglückend",
    "verunglückenden": "verunglückend",
    "verunglückender": "verunglückend",
    "verunglückendes": "verunglückend",
    "verunglückest": "verunglücken",
    "verunglücket": "verunglücken",
    "verunglückst": "verunglücken",
    "verunglückt": "verunglücken",
    "verunglückte": "verunglücken",
    "verunglücktem": "verunglückt",
    "verunglückten": "verunglücken",
    "verunglückter": "verunglückt",
    "verunglücktes": "verunglückt",
    "verunglücktest": "verunglücken",
    "verunglücktet": "verunglücken",
    "verunreinige": "verunreinigen",
    "verunreinigend": "verunreinigen",
    "verunreinigende": "verunreinigend",
    "verunreinigendem": "verunreinigend",
    "verunreinigenden": "verunreinigend",
    "verunreinigender": "verunreinigend",
    "verunreinigendes": "verunreinigend",
    "verunreinigest": "verunreinigen",
    "verunreiniget": "verunreinigen",
    "verunreinigst": "verunreinigen",
    "verunreinigt": "verunreinigen",
    "verunreinigte": "verunreinigen",
    "verunreinigtem": "verunreinigt",
    "verunreinigten": "verunreinigen",
    "verunreinigter": "verunreinigt",
    "verunreinigtes": "verunreinigt",
    "verunreinigtest": "verunreinigen",
    "verunreinigtet": "verunreinigen",
    "verunsichere": "verunsichern",
    "verunsichernd": "verunsichern",
    "verunsichernde": "verunsichernd",
    "verunsicherndem": "verunsichernd",
    "verunsichernden": "verunsichernd",
    "verunsichernder": "verunsichernd",
    "verunsicherndere": "verunsichernd",
    "verunsichernderem": "verunsichernd",
    "verunsichernderen": "verunsichernd",
    "verunsichernderer": "verunsichernd",
    "verunsichernderes": "verunsichernd",
    "verunsicherndes": "verunsichernd",
    "verunsicherndste": "verunsichernd",
    "verunsicherndstem": "verunsichernd",
    "verunsicherndsten": "verunsichernd",
    "verunsicherndster": "verunsichernd",
    "verunsicherndstes": "verunsichernd",
    "verunsicherst": "verunsichern",
    "verunsichert": "verunsichern",
    "verunsicherte": "verunsichern",
    "verunsichertem": "verunsichert",
    "verunsicherten": "verunsichern",
    "verunsicherter": "verunsichert",
    "verunsichertere": "verunsichert",
    "verunsicherterem": "verunsichert",
    "verunsicherteren": "verunsichert",
    "verunsicherterer": "verunsichert",
    "verunsicherteres": "verunsichert",
    "verunsichertes": "verunsichert",
    "verunsichertest": "verunsichern",
    "verunsicherteste": "verunsichert",
    "verunsichertestem": "verunsichert",
    "verunsichertesten": "verunsichert",
    "verunsichertester": "verunsichert",
    "verunsichertestes": "verunsichert",
    "verunsichertet": "verunsichern",
    "verunstalte": "verunstalten",
    "verunstaltend": "verunstalten",
    "verunstaltende": "verunstaltend",
    "verunstaltendem": "verunstaltend",
    "verunstaltenden": "verunstaltend",
    "verunstaltender": "verunstaltend",
    "verunstaltendes": "verunstaltend",
    "verunstaltest": "verunstalten",
    "verunstaltet": "verunstalten",
    "verunstaltete": "verunstalten",
    "verunstaltetem": "verunstaltet",
    "verunstalteten": "verunstalten",
    "verunstalteter": "verunstaltet",
    "verunstaltetes": "verunstaltet",
    "verunstaltetest": "verunstalten",
    "verunstaltetet": "verunstalten",
    "veruntreue": "veruntreuen",
    "veruntreuend": "veruntreuen",
    "veruntreuende": "veruntreuend",
    "veruntreuendem": "veruntreuend",
    "veruntreuenden": "veruntreuend",
    "veruntreuender": "veruntreuend",
    "veruntreuendes": "veruntreuend",
    "veruntreuest": "veruntreuen",
    "veruntreuet": "veruntreuen",
    "veruntreust": "veruntreuen",
    "veruntreut": "veruntreuen",
    "veruntreute": "veruntreuen",
    "veruntreutem": "veruntreut",
    "veruntreuten": "veruntreuen",
    "veruntreuter": "veruntreut",
    "veruntreutes": "veruntreut",
    "veruntreutest": "veruntreuen",
    "veruntreutet": "veruntreuen",
    "verursache": "verursachen",
    "verursachend": "verursachen",
    "verursachende": "verursachend",
    "verursachendem": "verursachend",
    "verursachenden": "verursachend",
    "verursachender": "verursachend",
    "verursachendes": "verursachend",
    "verursachest": "verursachen",
    "verursachet": "verursachen",
    "verursachst": "verursachen",
    "verursacht": "verursachen",
    "verursachte": "verursachen",
    "verursachtem": "verursacht",
    "verursachten": "verursachen",
    "verursachter": "verursacht",
    "verursachtes": "verursacht",
    "verursachtest": "verursachen",
    "verursachtet": "verursachen",
    "verurteile": "verurteilen",
    "verurteilend": "verurteilen",
    "verurteilende": "verurteilend",
    "verurteilendem": "verurteilend",
    "verurteilenden": "verurteilend",
    "verurteilender": "verurteilend",
    "verurteilendes": "verurteilend",
    "verurteilest": "verurteilen",
    "verurteilet": "verurteilen",
    "verurteilst": "verurteilen",
    "verurteilt": "verurteilen",
    "verurteilte": "verurteilen",
    "verurteiltem": "verurteilt",
    "verurteilten": "verurteilen",
    "verurteilter": "verurteilt",
    "verurteiltes": "verurteilt",
    "verurteiltest": "verurteilen",
    "verurteiltet": "verurteilen",
    "vervielfache": "vervielfachen",
    "vervielfachend": "vervielfachen",
    "vervielfachende": "vervielfachend",
    "vervielfachendem": "vervielfachend",
    "vervielfachenden": "vervielfachend",
    "vervielfachender": "vervielfachend",
    "vervielfachendes": "vervielfachend",
    "vervielfachest": "vervielfachen",
    "vervielfachet": "vervielfachen",
    "vervielfachst": "vervielfachen",
    "vervielfacht": "vervielfachen",
    "vervielfachte": "vervielfachen",
    "vervielfachtem": "vervielfacht",
    "vervielfachten": "vervielfachen",
    "vervielfachter": "vervielfacht",
    "vervielfachtes": "vervielfacht",
    "vervielfachtest": "vervielfachen",
    "vervielfachtet": "vervielfachen",
    "vervielfältige": "vervielfältigen",
    "vervielfältigend": "vervielfältigen",
    "vervielfältigende": "vervielfältigend",
    "vervielfältigendem": "vervielfältigend",
    "vervielfältigenden": "vervielfältigend",
    "vervielfältigender": "vervielfältigend",
    "vervielfältigendes": "vervielfältigend",
    "vervielfältigest": "vervielfältigen",
    "vervielfältiget": "vervielfältigen",
    "vervielfältigst": "vervielfältigen",
    "vervielfältigt": "vervielfältigen",
    "vervielfältigte": "vervielfältigen",
    "vervielfältigtem": "vervielfältigt",
    "vervielfältigten": "vervielfältigen",
    "vervielfältigter": "vervielfältigt",
    "vervielfältigtere": "vervielfältigt",
    "vervielfältigterem": "vervielfältigt",
    "vervielfältigteren": "vervielfältigt",
    "vervielfältigterer": "vervielfältigt",
    "vervielfältigteres": "vervielfältigt",
    "vervielfältigtes": "vervielfältigt",
    "vervielfältigtest": "vervielfältigen",
    "vervielfältigteste": "vervielfältigt",
    "vervielfältigtestem": "vervielfältigt",
    "vervielfältigtesten": "vervielfältigt",
    "vervielfältigtester": "vervielfältigt",
    "vervielfältigtestes": "vervielfältigt",
    "vervielfältigtet": "vervielfältigen",
    "vervollkommne": "vervollkommnen",
    "vervollkommnend": "vervollkommnen",
    "vervollkommnende": "vervollkommnend",
    "vervollkommnendem": "vervollkommnend",
    "vervollkommnenden": "vervollkommnend",
    "vervollkommnender": "vervollkommnend",
    "vervollkommnendere": "vervollkommnend",
    "vervollkommnenderem": "vervollkommnend",
    "vervollkommnenderen": "vervollkommnend",
    "vervollkommnenderer": "vervollkommnend",
    "vervollkommnenderes": "vervollkommnend",
    "vervollkommnendes": "vervollkommnend",
    "vervollkommnendste": "vervollkommnend",
    "vervollkommnendstem": "vervollkommnend",
    "vervollkommnendsten": "vervollkommnend",
    "vervollkommnendster": "vervollkommnend",
    "vervollkommnendstes": "vervollkommnend",
    "vervollkommnest": "vervollkommnen",
    "vervollkommnet": "vervollkommnen",
    "vervollkommnete": "vervollkommnen",
    "vervollkommnetem": "vervollkommnet",
    "vervollkommneten": "vervollkommnen",
    "vervollkommneter": "vervollkommnet",
    "vervollkommnetere": "vervollkommnet",
    "vervollkommneterem": "vervollkommnet",
    "vervollkommneteren": "vervollkommnet",
    "vervollkommneterer": "vervollkommnet",
    "vervollkommneteres": "vervollkommnet",
    "vervollkommnetes": "vervollkommnet",
    "vervollkommnetest": "vervollkommnen",
    "vervollkommneteste": "vervollkommnet",
    "vervollkommnetestem": "vervollkommnet",
    "vervollkommnetesten": "vervollkommnet",
    "vervollkommnetester": "vervollkommnet",
    "vervollkommnetestes": "vervollkommnet",
    "vervollkommnetet": "vervollkommnen",
    "vervollständige": "vervollständigen",
    "vervollständigend": "vervollständigen",
    "vervollständigende": "vervollständigend",
    "vervollständigendem": "vervollständigend",
    "vervollständigenden": "vervollständigend",
    "vervollständigender": "vervollständigend",
    "vervollständigendes": "vervollständigend",
    "vervollständigest": "vervollständigen",
    "vervollständiget": "vervollständigen",
    "vervollständigst": "vervollständigen",
    "vervollständigt": "vervollständigen",
    "vervollständigte": "vervollständigen",
    "vervollständigtem": "vervollständigt",
    "vervollständigten": "vervollständigen",
    "vervollständigter": "vervollständigt",
    "vervollständigtes": "vervollständigt",
    "vervollständigtest": "vervollständigen",
    "vervollständigtet": "vervollständigen",
    "verwachse": "verwachsen",
    "verwachsend": "verwachsen",
    "verwachsende": "verwachsend",
    "verwachsendem": "verwachsend",
    "verwachsenden": "verwachsend",
    "verwachsender": "verwachsend",
    "verwachsendes": "verwachsend",
    "verwachsene": "verwachsen",
    "verwachsenem": "verwachsen",
    "verwachsenen": "verwachsen",
    "verwachsener": "verwachsen",
    "verwachsenes": "verwachsen",
    "verwachsest": "verwachsen",
    "verwachset": "verwachsen",
    "verwachst": "verwachsen",
    "verwahre": "verwahren",
    "verwahrend": "verwahren",
    "verwahrende": "verwahrend",
    "verwahrendem": "verwahrend",
    "verwahrenden": "verwahrend",
    "verwahrender": "verwahrend",
    "verwahrendes": "verwahrend",
    "verwahrest": "verwahren",
    "verwahret": "verwahren",
    "verwahrlose": "verwahrlosen",
    "verwahrlosend": "verwahrlosen",
    "verwahrlosende": "verwahrlosend",
    "verwahrlosendem": "verwahrlosend",
    "verwahrlosenden": "verwahrlosend",
    "verwahrlosender": "verwahrlosend",
    "verwahrlosendes": "verwahrlosend",
    "verwahrlosest": "verwahrlosen",
    "verwahrloset": "verwahrlosen",
    "verwahrlost": "verwahrlosen",
    "verwahrloste": "verwahrlosen",
    "verwahrlostem": "verwahrlost",
    "verwahrlosten": "verwahrlosen",
    "verwahrloster": "verwahrlost",
    "verwahrlostes": "verwahrlost",
    "verwahrlostest": "verwahrlosen",
    "verwahrlostet": "verwahrlosen",
    "verwahrst": "verwahren",
    "verwahrt": "verwahren",
    "verwahrte": "verwahren",
    "verwahrtem": "verwahrt",
    "verwahrten": "verwahren",
    "verwahrter": "verwahrt",
    "verwahrtes": "verwahrt",
    "verwahrtest": "verwahren",
    "verwahrtet": "verwahren",
    "verwaise": "verwaisen",
    "verwaisend": "verwaisen",
    "verwaisende": "verwaisend",
    "verwaisendem": "verwaisend",
    "verwaisenden": "verwaisend",
    "verwaisender": "verwaisend",
    "verwaisendes": "verwaisend",
    "verwaisest": "verwaisen",
    "verwaiset": "verwaisen",
    "verwaist": "verwaisen",
    "verwaiste": "verwaisen",
    "verwaistem": "verwaist",
    "verwaisten": "verwaisen",
    "verwaister": "verwaist",
    "verwaistes": "verwaist",
    "verwaistest": "verwaisen",
    "verwaistet": "verwaisen",
    "verwalte": "verwalten",
    "verwaltend": "verwalten",
    "verwaltende": "verwaltend",
    "verwaltendem": "verwaltend",
    "verwaltenden": "verwaltend",
    "verwaltender": "verwaltend",
    "verwaltendes": "verwaltend",
    "verwaltest": "verwalten",
    "verwaltet": "verwalten",
    "verwaltete": "verwalten",
    "verwaltetem": "verwaltet",
    "verwalteten": "verwalten",
    "verwalteter": "verwaltet",
    "verwaltetes": "verwaltet",
    "verwaltetest": "verwalten",
    "verwaltetet": "verwalten",
    "verwand": "verwinden",
    "verwandele": "verwandeln",
    "verwandelnd": "verwandeln",
    "verwandelnde": "verwandelnd",
    "verwandelndem": "verwandelnd",
    "verwandelnden": "verwandelnd",
    "verwandelnder": "verwandelnd",
    "verwandelndes": "verwandelnd",
    "verwandelst": "verwandeln",
    "verwandelt": "verwandeln",
    "verwandelte": "verwandeln",
    "verwandeltem": "verwandelt",
    "verwandelten": "verwandeln",
    "verwandelter": "verwandelt",
    "verwandeltere": "verwandelt",
    "verwandelterem": "verwandelt",
    "verwandelteren": "verwandelt",
    "verwandelterer": "verwandelt",
    "verwandelteres": "verwandelt",
    "verwandeltes": "verwandelt",
    "verwandeltest": "verwandeln",
    "verwandelteste": "verwandelt",
    "verwandeltestem": "verwandelt",
    "verwandeltesten": "verwandelt",
    "verwandeltester": "verwandelt",
    "verwandeltestes": "verwandelt",
    "verwandeltet": "verwandeln",
    "verwanden": "verwinden",
    "verwandest": "verwinden",
    "verwandet": "verwinden",
    "verwandle": "verwandeln",
    "verwandt": "verwenden",
    "verwandte": "verwandt",
    "verwandtem": "verwandt",
    "verwandten": "verwandt",
    "verwandter": "verwandt",
    "verwandtes": "verwandt",
    "verwandtest": "verwenden",
    "verwandtet": "verwenden",
    "verwanztem": "verwanzt",
    "verwanzten": "verwanzt",
    "verwanzter": "verwanzt",
    "verwanztere": "verwanzt",
    "verwanzterem": "verwanzt",
    "verwanzteren": "verwanzt",
    "verwanzterer": "verwanzt",
    "verwanzteres": "verwanzt",
    "verwanztes": "verwanzt",
    "verwanzteste": "verwanzt",
    "verwanztestem": "verwanzt",
    "verwanztesten": "verwanzt",
    "verwanztester": "verwanzt",
    "verwanztestes": "verwanzt",
    "verwarf": "verwerfen",
    "verwarfen": "verwerfen",
    "verwarfst": "verwerfen",
    "verwarft": "verwerfen",
    "verwarne": "verwarnen",
    "verwarnend": "verwarnen",
    "verwarnende": "verwarnend",
    "verwarnendem": "verwarnend",
    "verwarnenden": "verwarnend",
    "verwarnender": "verwarnend",
    "verwarnendes": "verwarnend",
    "verwarnest": "verwarnen",
    "verwarnet": "verwarnen",
    "verwarnst": "verwarnen",
    "verwarnt": "verwarnen",
    "verwarnte": "verwarnen",
    "verwarntem": "verwarnt",
    "verwarnten": "verwarnen",
    "verwarnter": "verwarnt",
    "verwarntes": "verwarnt",
    "verwarntest": "verwarnen",
    "verwarntet": "verwarnen",
    "verwaschene": "verwaschen",
    "verwaschenem": "verwaschen",
    "verwaschenen": "verwaschen",
    "verwaschener": "verwaschen",
    "verwaschenere": "verwaschen",
    "verwaschenerem": "verwaschen",
    "verwascheneren": "verwaschen",
    "verwaschenerer": "verwaschen",
    "verwascheneres": "verwaschen",
    "verwaschenes": "verwaschen",
    "verwaschenste": "verwaschen",
    "verwaschenstem": "verwaschen",
    "verwaschensten": "verwaschen",
    "verwaschenster": "verwaschen",
    "verwaschenstes": "verwaschen",
    "verwechsele": "verwechseln",
    "verwechselnd": "verwechseln",
    "verwechselnde": "verwechselnd",
    "verwechselndem": "verwechselnd",
    "verwechselnden": "verwechselnd",
    "verwechselnder": "verwechselnd",
    "verwechselndes": "verwechselnd",
    "verwechselst": "verwechseln",
    "verwechselt": "verwechseln",
    "verwechselte": "verwechseln",
    "verwechseltem": "verwechselt",
    "verwechselten": "verwechseln",
    "verwechselter": "verwechselt",
    "verwechseltes": "verwechselt",
    "verwechseltest": "verwechseln",
    "verwechseltet": "verwechseln",
    "verwechsle": "verwechseln",
    "verwehe": "verwehen",
    "verwehend": "verwehen",
    "verwehende": "verwehend",
    "verwehendem": "verwehend",
    "verwehenden": "verwehend",
    "verwehender": "verwehend",
    "verwehendes": "verwehend",
    "verwehest": "verwehen",
    "verwehet": "verwehen",
    "verwehre": "verwehren",
    "verwehrend": "verwehren",
    "verwehrende": "verwehrend",
    "verwehrendem": "verwehrend",
    "verwehrenden": "verwehrend",
    "verwehrender": "verwehrend",
    "verwehrendere": "verwehrend",
    "verwehrenderem": "verwehrend",
    "verwehrenderen": "verwehrend",
    "verwehrenderer": "verwehrend",
    "verwehrenderes": "verwehrend",
    "verwehrendes": "verwehrend",
    "verwehrendste": "verwehrend",
    "verwehrendstem": "verwehrend",
    "verwehrendsten": "verwehrend",
    "verwehrendster": "verwehrend",
    "verwehrendstes": "verwehrend",
    "verwehrest": "verwehren",
    "verwehret": "verwehren",
    "verwehrst": "verwehren",
    "verwehrt": "verwehren",
    "verwehrte": "verwehren",
    "verwehrtem": "verwehrt",
    "verwehrten": "verwehren",
    "verwehrter": "verwehrt",
    "verwehrtes": "verwehrt",
    "verwehrtest": "verwehren",
    "verwehrtet": "verwehren",
    "verwehst": "verwehen",
    "verweht": "verwehen",
    "verwehte": "verwehen",
    "verwehtem": "verweht",
    "verwehten": "verwehen",
    "verwehter": "verweht",
    "verwehtere": "verweht",
    "verwehterem": "verweht",
    "verwehteren": "verweht",
    "verwehterer": "verweht",
    "verwehteres": "verweht",
    "verwehtes": "verweht",
    "verwehtest": "verwehen",
    "verwehteste": "verweht",
    "verwehtestem": "verweht",
    "verwehtesten": "verweht",
    "verwehtester": "verweht",
    "verwehtestes": "verweht",
    "verwehtet": "verwehen",
    "verweichliche": "verweichlichen",
    "verweichlichend": "verweichlichen",
    "verweichlichende": "verweichlichend",
    "verweichlichendem": "verweichlichend",
    "verweichlichenden": "verweichlichend",
    "verweichlichender": "verweichlichend",
    "verweichlichendere": "verweichlichend",
    "verweichlichenderem": "verweichlichend",
    "verweichlichenderen": "verweichlichend",
    "verweichlichenderer": "verweichlichend",
    "verweichlichenderes": "verweichlichend",
    "verweichlichendes": "verweichlichend",
    "verweichlichendste": "verweichlichend",
    "verweichlichendstem": "verweichlichend",
    "verweichlichendsten": "verweichlichend",
    "verweichlichendster": "verweichlichend",
    "verweichlichendstes": "verweichlichend",
    "verweichlichest": "verweichlichen",
    "verweichlichet": "verweichlichen",
    "verweichlichst": "verweichlichen",
    "verweichlicht": "verweichlichen",
    "verweichlichte": "verweichlichen",
    "verweichlichtem": "verweichlicht",
    "verweichlichten": "verweichlichen",
    "verweichlichter": "verweichlicht",
    "verweichlichtere": "verweichlicht",
    "verweichlichterem": "verweichlicht",
    "verweichlichteren": "verweichlicht",
    "verweichlichterer": "verweichlicht",
    "verweichlichteres": "verweichlicht",
    "verweichlichtes": "verweichlicht",
    "verweichlichtest": "verweichlichen",
    "verweichlichtestem": "verweichlicht",
    "verweichlichtesten": "verweichlicht",
    "verweichlichtester": "verweichlicht",
    "verweichlichtestes": "verweichlicht",
    "verweichlichtet": "verweichlichen",
    "verweigere": "verweigern",
    "verweigernd": "verweigern",
    "verweigernde": "verweigernd",
    "verweigerndem": "verweigernd",
    "verweigernden": "verweigernd",
    "verweigernder": "verweigernd",
    "verweigerndere": "verweigernd",
    "verweigernderem": "verweigernd",
    "verweigernderen": "verweigernd",
    "verweigernderer": "verweigernd",
    "verweigernderes": "verweigernd",
    "verweigerndes": "verweigernd",
    "verweigerndste": "verweigernd",
    "verweigerndstem": "verweigernd",
    "verweigerndsten": "verweigernd",
    "verweigerndster": "verweigernd",
    "verweigerndstes": "verweigernd",
    "verweigerst": "verweigern",
    "verweigert": "verweigern",
    "verweigerte": "verweigern",
    "verweigertem": "verweigert",
    "verweigerten": "verweigern",
    "verweigerter": "verweigert",
    "verweigertes": "verweigert",
    "verweigertest": "verweigern",
    "verweigertet": "verweigern",
    "verweile": "verweilen",
    "verweilend": "verweilen",
    "verweilende": "verweilend",
    "verweilendem": "verweilend",
    "verweilenden": "verweilend",
    "verweilender": "verweilend",
    "verweilendes": "verweilend",
    "verweilest": "verweilen",
    "verweilet": "verweilen",
    "verweilst": "verweilen",
    "verweilt": "verweilen",
    "verweilte": "verweilen",
    "verweiltem": "verweilt",
    "verweilten": "verweilen",
    "verweilter": "verweilt",
    "verweiltes": "verweilt",
    "verweiltest": "verweilen",
    "verweiltet": "verweilen",
    "verweisend": "verweisen",
    "verweisende": "verweisend",
    "verweisendem": "verweisend",
    "verweisenden": "verweisend",
    "verweisender": "verweisend",
    "verweisendes": "verweisend",
    "verweisest": "verweisen",
    "verweiset": "verweisen",
    "verweist": "verweisen",
    "verwelke": "verwelken",
    "verwelkend": "verwelken",
    "verwelkende": "verwelkend",
    "verwelkendem": "verwelkend",
    "verwelkenden": "verwelkend",
    "verwelkender": "verwelkend",
    "verwelkendere": "verwelkend",
    "verwelkenderem": "verwelkend",
    "verwelkenderen": "verwelkend",
    "verwelkenderer": "verwelkend",
    "verwelkenderes": "verwelkend",
    "verwelkendes": "verwelkend",
    "verwelkendste": "verwelkend",
    "verwelkendstem": "verwelkend",
    "verwelkendsten": "verwelkend",
    "verwelkendster": "verwelkend",
    "verwelkendstes": "verwelkend",
    "verwelkest": "verwelken",
    "verwelket": "verwelken",
    "verwelkst": "verwelken",
    "verwelkt": "verwelken",
    "verwelkte": "verwelken",
    "verwelktem": "verwelkt",
    "verwelkten": "verwelken",
    "verwelkter": "verwelkt",
    "verwelktere": "verwelkt",
    "verwelkterem": "verwelkt",
    "verwelkteren": "verwelkt",
    "verwelkterer": "verwelkt",
    "verwelkteres": "verwelkt",
    "verwelktes": "verwelkt",
    "verwelktest": "verwelken",
    "verwelkteste": "verwelkt",
    "verwelktestem": "verwelkt",
    "verwelktesten": "verwelkt",
    "verwelktester": "verwelkt",
    "verwelktestes": "verwelkt",
    "verwelktet": "verwelken",
    "verweltliche": "verweltlichen",
    "verweltlichend": "verweltlichen",
    "verweltlichende": "verweltlichend",
    "verweltlichendem": "verweltlichend",
    "verweltlichenden": "verweltlichend",
    "verweltlichender": "verweltlichend",
    "verweltlichendes": "verweltlichend",
    "verweltlichest": "verweltlichen",
    "verweltlichet": "verweltlichen",
    "verweltlichst": "verweltlichen",
    "verweltlicht": "verweltlichen",
    "verweltlichte": "verweltlichen",
    "verweltlichtem": "verweltlicht",
    "verweltlichten": "verweltlichen",
    "verweltlichter": "verweltlicht",
    "verweltlichtes": "verweltlicht",
    "verweltlichtest": "verweltlichen",
    "verweltlichtet": "verweltlichen",
    "verwende": "verwenden",
    "verwendend": "verwenden",
    "verwendende": "verwendend",
    "verwendendem": "verwendend",
    "verwendenden": "verwendend",
    "verwendender": "verwendend",
    "verwendendes": "verwendend",
    "verwendest": "verwenden",
    "verwendet": "verwenden",
    "verwendete": "verwenden",
    "verwendetem": "verwendet",
    "verwendeten": "verwenden",
    "verwendeter": "verwendet",
    "verwendetere": "verwendet",
    "verwendeterem": "verwendet",
    "verwendeteren": "verwendet",
    "verwendeterer": "verwendet",
    "verwendeteres": "verwendet",
    "verwendetes": "verwendet",
    "verwendetest": "verwenden",
    "verwendeteste": "verwendet",
    "verwendetestem": "verwendet",
    "verwendetesten": "verwendet",
    "verwendetester": "verwendet",
    "verwendetestes": "verwendet",
    "verwendetet": "verwenden",
    "verwerfe": "verwerfen",
    "verwerfend": "verwerfen",
    "verwerfende": "verwerfend",
    "verwerfendem": "verwerfend",
    "verwerfenden": "verwerfend",
    "verwerfender": "verwerfend",
    "verwerfendes": "verwerfend",
    "verwerfest": "verwerfen",
    "verwerfet": "verwerfen",
    "verwerfliche": "verwerflich",
    "verwerflichem": "verwerflich",
    "verwerflichen": "verwerflich",
    "verwerflicher": "verwerflich",
    "verwerflichere": "verwerflich",
    "verwerflicherem": "verwerflich",
    "verwerflicheren": "verwerflich",
    "verwerflicherer": "verwerflich",
    "verwerflicheres": "verwerflich",
    "verwerfliches": "verwerflich",
    "verwerflichste": "verwerflich",
    "verwerflichstem": "verwerflich",
    "verwerflichsten": "verwerflich",
    "verwerflichster": "verwerflich",
    "verwerflichstes": "verwerflich",
    "verwerft": "verwerfen",
    "verwertbarem": "verwertbar",
    "verwertbaren": "verwertbar",
    "verwertbarer": "verwertbar",
    "verwertbares": "verwertbar",
    "verwerte": "verwerten",
    "verwertend": "verwerten",
    "verwertende": "verwertend",
    "verwertendem": "verwertend",
    "verwertenden": "verwertend",
    "verwertender": "verwertend",
    "verwertendere": "verwertend",
    "verwertenderem": "verwertend",
    "verwertenderen": "verwertend",
    "verwertenderer": "verwertend",
    "verwertenderes": "verwertend",
    "verwertendes": "verwertend",
    "verwertendste": "verwertend",
    "verwertendstem": "verwertend",
    "verwertendsten": "verwertend",
    "verwertendster": "verwertend",
    "verwertendstes": "verwertend",
    "verwertest": "verwerten",
    "verwertet": "verwerten",
    "verwertete": "verwerten",
    "verwertetem": "verwertet",
    "verwerteten": "verwerten",
    "verwerteter": "verwertet",
    "verwertetere": "verwertet",
    "verwerteterem": "verwertet",
    "verwerteteren": "verwertet",
    "verwerteterer": "verwertet",
    "verwerteteres": "verwertet",
    "verwertetes": "verwertet",
    "verwertetest": "verwerten",
    "verwerteteste": "verwertet",
    "verwertetestem": "verwertet",
    "verwertetesten": "verwertet",
    "verwertetester": "verwertet",
    "verwertetestes": "verwertet",
    "verwertetet": "verwerten",
    "verwese": "verwesen",
    "verwesend": "verwesen",
    "verwesende": "verwesend",
    "verwesendem": "verwesend",
    "verwesenden": "verwesend",
    "verwesender": "verwesend",
    "verwesendere": "verwesend",
    "verwesenderem": "verwesend",
    "verwesenderen": "verwesend",
    "verwesenderer": "verwesend",
    "verwesenderes": "verwesend",
    "verwesendes": "verwesend",
    "verwesendste": "verwesend",
    "verwesendstem": "verwesend",
    "verwesendsten": "verwesend",
    "verwesendster": "verwesend",
    "verwesendstes": "verwesend",
    "verwesest": "verwesen",
    "verweset": "verwesen",
    "verwest": "verwesen",
    "verweste": "verwesen",
    "verwestem": "verwest",
    "verwesten": "verwesen",
    "verwester": "verwest",
    "verwestere": "verwest",
    "verwesterem": "verwest",
    "verwesteren": "verwest",
    "verwesterer": "verwest",
    "verwesteres": "verwest",
    "verwestes": "verwest",
    "verwestest": "verwesen",
    "verwesteste": "verwest",
    "verwestestem": "verwest",
    "verwestesten": "verwest",
    "verwestester": "verwest",
    "verwestestes": "verwest",
    "verwestet": "verwesen",
    "verwette": "verwetten",
    "verwettend": "verwetten",
    "verwettende": "verwettend",
    "verwettendem": "verwettend",
    "verwettenden": "verwettend",
    "verwettender": "verwettend",
    "verwettendes": "verwettend",
    "verwettest": "verwetten",
    "verwettet": "verwetten",
    "verwettete": "verwetten",
    "verwettetem": "verwettet",
    "verwetteten": "verwetten",
    "verwetteter": "verwettet",
    "verwettetes": "verwettet",
    "verwettetest": "verwetten",
    "verwettetet": "verwetten",
    "verwickele": "verwickeln",
    "verwickelnd": "verwickeln",
    "verwickelnde": "verwickelnd",
    "verwickelndem": "verwickelnd",
    "verwickelnden": "verwickelnd",
    "verwickelnder": "verwickelnd",
    "verwickelndes": "verwickelnd",
    "verwickelst": "verwickeln",
    "verwickelt": "verwickeln",
    "verwickelte": "verwickeln",
    "verwickeltem": "verwickelt",
    "verwickelten": "verwickeln",
    "verwickelter": "verwickelt",
    "verwickeltere": "verwickelt",
    "verwickelterem": "verwickelt",
    "verwickelteren": "verwickelt",
    "verwickelterer": "verwickelt",
    "verwickelteres": "verwickelt",
    "verwickeltes": "verwickelt",
    "verwickeltest": "verwickeln",
    "verwickelteste": "verwickelt",
    "verwickeltestem": "verwickelt",
    "verwickeltesten": "verwickelt",
    "verwickeltester": "verwickelt",
    "verwickeltestes": "verwickelt",
    "verwickeltet": "verwickeln",
    "verwickle": "verwickeln",
    "verwies": "verweisen",
    "verwiese": "verweisen",
    "verwiesen": "verweisen",
    "verwiesene": "verwiesen",
    "verwiesenem": "verwiesen",
    "verwiesenen": "verwiesen",
    "verwiesener": "verwiesen",
    "verwiesenes": "verwiesen",
    "verwiesest": "verweisen",
    "verwieset": "verweisen",
    "verwiest": "verweisen",
    "verwinde": "verwinden",
    "verwindend": "verwinden",
    "verwindende": "verwindend",
    "verwindendem": "verwindend",
    "verwindenden": "verwindend",
    "verwindender": "verwindend",
    "verwindendes": "verwindend",
    "verwindest": "verwinden",
    "verwindet": "verwinden",
    "verwinkele": "verwinkeln",
    "verwinkelnd": "verwinkeln",
    "verwinkelnde": "verwinkelnd",
    "verwinkelndem": "verwinkelnd",
    "verwinkelnden": "verwinkelnd",
    "verwinkelnder": "verwinkelnd",
    "verwinkelndere": "verwinkelnd",
    "verwinkelnderem": "verwinkelnd",
    "verwinkelnderen": "verwinkelnd",
    "verwinkelnderer": "verwinkelnd",
    "verwinkelnderes": "verwinkelnd",
    "verwinkelndes": "verwinkelnd",
    "verwinkelndste": "verwinkelnd",
    "verwinkelndstem": "verwinkelnd",
    "verwinkelndsten": "verwinkelnd",
    "verwinkelndster": "verwinkelnd",
    "verwinkelndstes": "verwinkelnd",
    "verwinkelst": "verwinkeln",
    "verwinkelt": "verwinkeln",
    "verwinkelte": "verwinkeln",
    "verwinkeltem": "verwinkelt",
    "verwinkelten": "verwinkeln",
    "verwinkelter": "verwinkelt",
    "verwinkeltere": "verwinkelt",
    "verwinkelterem": "verwinkelt",
    "verwinkelteren": "verwinkelt",
    "verwinkelterer": "verwinkelt",
    "verwinkelteres": "verwinkelt",
    "verwinkeltes": "verwinkelt",
    "verwinkeltest": "verwinkeln",
    "verwinkelteste": "verwinkelt",
    "verwinkeltestem": "verwinkelt",
    "verwinkeltesten": "verwinkelt",
    "verwinkeltester": "verwinkelt",
    "verwinkeltestes": "verwinkelt",
    "verwinkeltet": "verwinkeln",
    "verwinkle": "verwinkeln",
    "verwirf": "verwerfen",
    "verwirfst": "verwerfen",
    "verwirft": "verwerfen",
    "verwirkliche": "verwirklichen",
    "verwirklichend": "verwirklichen",
    "verwirklichende": "verwirklichend",
    "verwirklichendem": "verwirklichend",
    "verwirklichenden": "verwirklichend",
    "verwirklichender": "verwirklichend",
    "verwirklichendere": "verwirklichend",
    "verwirklichenderem": "verwirklichend",
    "verwirklichenderen": "verwirklichend",
    "verwirklichenderer": "verwirklichend",
    "verwirklichenderes": "verwirklichend",
    "verwirklichendes": "verwirklichend",
    "verwirklichendste": "verwirklichend",
    "verwirklichendstem": "verwirklichend",
    "verwirklichendsten": "verwirklichend",
    "verwirklichendster": "verwirklichend",
    "verwirklichendstes": "verwirklichend",
    "verwirklichest": "verwirklichen",
    "verwirklichet": "verwirklichen",
    "verwirklichst": "verwirklichen",
    "verwirklicht": "verwirklichen",
    "verwirklichte": "verwirklichen",
    "verwirklichtem": "verwirklicht",
    "verwirklichten": "verwirklichen",
    "verwirklichter": "verwirklicht",
    "verwirklichtere": "verwirklicht",
    "verwirklichterem": "verwirklicht",
    "verwirklichteren": "verwirklicht",
    "verwirklichterer": "verwirklicht",
    "verwirklichteres": "verwirklicht",
    "verwirklichtes": "verwirklicht",
    "verwirklichtest": "verwirklichen",
    "verwirklichteste": "verwirklicht",
    "verwirklichtestem": "verwirklicht",
    "verwirklichtesten": "verwirklicht",
    "verwirklichtester": "verwirklicht",
    "verwirklichtestes": "verwirklicht",
    "verwirklichtet": "verwirklichen",
    "verwirre": "verwirren",
    "verwirrend": "verwirren",
    "verwirrende": "verwirrend",
    "verwirrendem": "verwirrend",
    "verwirrenden": "verwirrend",
    "verwirrender": "verwirrend",
    "verwirrendere": "verwirrend",
    "verwirrenderem": "verwirrend",
    "verwirrenderen": "verwirrend",
    "verwirrenderer": "verwirrend",
    "verwirrenderes": "verwirrend",
    "verwirrendes": "verwirrend",
    "verwirrendste": "verwirrend",
    "verwirrendstem": "verwirrend",
    "verwirrendsten": "verwirrend",
    "verwirrendster": "verwirrend",
    "verwirrendstes": "verwirrend",
    "verwirrest": "verwirren",
    "verwirret": "verwirren",
    "verwirrst": "verwirren",
    "verwirrt": "verwirren",
    "verwirrte": "verwirren",
    "verwirrtem": "verwirrt",
    "verwirrten": "verwirren",
    "verwirrter": "verwirrt",
    "verwirrtere": "verwirrt",
    "verwirrterem": "verwirrt",
    "verwirrteren": "verwirrt",
    "verwirrterer": "verwirrt",
    "verwirrteres": "verwirrt",
    "verwirrtes": "verwirrt",
    "verwirrtest": "verwirren",
    "verwirrteste": "verwirrt",
    "verwirrtestem": "verwirrt",
    "verwirrtesten": "verwirrt",
    "verwirrtester": "verwirrt",
    "verwirrtestes": "verwirrt",
    "verwirrtet": "verwirren",
    "verwische": "verwischen",
    "verwischend": "verwischen",
    "verwischende": "verwischend",
    "verwischendem": "verwischend",
    "verwischenden": "verwischend",
    "verwischender": "verwischend",
    "verwischendere": "verwischend",
    "verwischenderem": "verwischend",
    "verwischenderen": "verwischend",
    "verwischenderer": "verwischend",
    "verwischenderes": "verwischend",
    "verwischendes": "verwischend",
    "verwischendste": "verwischend",
    "verwischendstem": "verwischend",
    "verwischendsten": "verwischend",
    "verwischendster": "verwischend",
    "verwischendstes": "verwischend",
    "verwischest": "verwischen",
    "verwischet": "verwischen",
    "verwischst": "verwischen",
    "verwischt": "verwischen",
    "verwischte": "verwischen",
    "verwischtem": "verwischt",
    "verwischten": "verwischen",
    "verwischter": "verwischt",
    "verwischtere": "verwischt",
    "verwischterem": "verwischt",
    "verwischteren": "verwischt",
    "verwischterer": "verwischt",
    "verwischteres": "verwischt",
    "verwischtes": "verwischt",
    "verwischtest": "verwischen",
    "verwischteste": "verwischt",
    "verwischtestem": "verwischt",
    "verwischtesten": "verwischt",
    "verwischtester": "verwischt",
    "verwischtestes": "verwischt",
    "verwischtet": "verwischen",
    "verwitwetem": "verwitwet",
    "verwitweten": "verwitwet",
    "verwitweter": "verwitwet",
    "verwitwetes": "verwitwet",
    "verwohne": "verwohnen",
    "verwohnend": "verwohnen",
    "verwohnende": "verwohnend",
    "verwohnendem": "verwohnend",
    "verwohnenden": "verwohnend",
    "verwohnender": "verwohnend",
    "verwohnendere": "verwohnend",
    "verwohnenderem": "verwohnend",
    "verwohnenderen": "verwohnend",
    "verwohnenderer": "verwohnend",
    "verwohnenderes": "verwohnend",
    "verwohnendes": "verwohnend",
    "verwohnendste": "verwohnend",
    "verwohnendstem": "verwohnend",
    "verwohnendsten": "verwohnend",
    "verwohnendster": "verwohnend",
    "verwohnendstes": "verwohnend",
    "verwohnest": "verwohnen",
    "verwohnet": "verwohnen",
    "verwohnst": "verwohnen",
    "verwohnt": "verwohnen",
    "verwohnte": "verwohnen",
    "verwohntem": "verwohnt",
    "verwohnten": "verwohnen",
    "verwohnter": "verwohnt",
    "verwohntere": "verwohnt",
    "verwohnterem": "verwohnt",
    "verwohnteren": "verwohnt",
    "verwohnterer": "verwohnt",
    "verwohnteres": "verwohnt",
    "verwohntes": "verwohnt",
    "verwohntest": "verwohnen",
    "verwohnteste": "verwohnt",
    "verwohntestem": "verwohnt",
    "verwohntesten": "verwohnt",
    "verwohntester": "verwohnt",
    "verwohntestes": "verwohnt",
    "verwohntet": "verwohnen",
    "verworfen": "verwerfen",
    "verworfene": "verworfen",
    "verworfenem": "verworfen",
    "verworfenen": "verworfen",
    "verworfener": "verworfen",
    "verworfenere": "verworfen",
    "verworfenerem": "verworfen",
    "verworfeneren": "verworfen",
    "verworfenerer": "verworfen",
    "verworfeneres": "verworfen",
    "verworfenes": "verworfen",
    "verworfenste": "verworfen",
    "verworfenstem": "verworfen",
    "verworfensten": "verworfen",
    "verworfenster": "verworfen",
    "verworfenstes": "verworfen",
    "verwuchere": "verwuchern",
    "verwuchernd": "verwuchern",
    "verwuchernde": "verwuchernd",
    "verwucherndem": "verwuchernd",
    "verwuchernden": "verwuchernd",
    "verwuchernder": "verwuchernd",
    "verwucherndere": "verwuchernd",
    "verwuchernderem": "verwuchernd",
    "verwuchernderen": "verwuchernd",
    "verwuchernderer": "verwuchernd",
    "verwuchernderes": "verwuchernd",
    "verwucherndes": "verwuchernd",
    "verwucherndste": "verwuchernd",
    "verwucherndstem": "verwuchernd",
    "verwucherndsten": "verwuchernd",
    "verwucherndster": "verwuchernd",
    "verwucherndstes": "verwuchernd",
    "verwucherst": "verwuchern",
    "verwuchert": "verwuchern",
    "verwucherte": "verwuchern",
    "verwuchertem": "verwuchert",
    "verwucherten": "verwuchern",
    "verwucherter": "verwuchert",
    "verwuchertere": "verwuchert",
    "verwucherterem": "verwuchert",
    "verwucherteren": "verwuchert",
    "verwucherterer": "verwuchert",
    "verwucherteres": "verwuchert",
    "verwuchertes": "verwuchert",
    "verwuchertest": "verwuchern",
    "verwucherteste": "verwuchert",
    "verwuchertestem": "verwuchert",
    "verwuchertesten": "verwuchert",
    "verwuchertester": "verwuchert",
    "verwuchertestes": "verwuchert",
    "verwuchertet": "verwuchern",
    "verwuchs": "verwachsen",
    "verwuchsen": "verwachsen",
    "verwuchst": "verwachsen",
    "verwundbare": "verwundbar",
    "verwundbarem": "verwundbar",
    "verwundbaren": "verwundbar",
    "verwundbarer": "verwundbar",
    "verwundbarere": "verwundbar",
    "verwundbarerem": "verwundbar",
    "verwundbareren": "verwundbar",
    "verwundbarerer": "verwundbar",
    "verwundbareres": "verwundbar",
    "verwundbares": "verwundbar",
    "verwundbarste": "verwundbar",
    "verwundbarstem": "verwundbar",
    "verwundbarsten": "verwundbar",
    "verwundbarster": "verwundbar",
    "verwundbarstes": "verwundbar",
    "verwunden": "verwinden",
    "verwundene": "verwunden",
    "verwundenem": "verwunden",
    "verwundenen": "verwunden",
    "verwundener": "verwunden",
    "verwundenes": "verwunden",
    "verwundere": "verwundern",
    "verwundernd": "verwundern",
    "verwundernde": "verwundernd",
    "verwunderndem": "verwundernd",
    "verwundernden": "verwundernd",
    "verwundernder": "verwundernd",
    "verwunderndes": "verwundernd",
    "verwunderst": "verwundern",
    "verwundert": "verwundern",
    "verwunderte": "verwundern",
    "verwundertem": "verwundert",
    "verwunderten": "verwundern",
    "verwunderter": "verwundert",
    "verwundertere": "verwundert",
    "verwunderterem": "verwundert",
    "verwunderteren": "verwundert",
    "verwunderterer": "verwundert",
    "verwunderteres": "verwundert",
    "verwundertes": "verwundert",
    "verwundertest": "verwundern",
    "verwunderteste": "verwundert",
    "verwundertestem": "verwundert",
    "verwundertesten": "verwundert",
    "verwundertester": "verwundert",
    "verwundertestes": "verwundert",
    "verwundertet": "verwundern",
    "verwunschene": "verwunschen",
    "verwunschenem": "verwunschen",
    "verwunschenen": "verwunschen",
    "verwunschener": "verwunschen",
    "verwunschenes": "verwunschen",
    "verwurste": "verwursten",
    "verwurstele": "verwursteln",
    "verwurstelnd": "verwursteln",
    "verwurstelnde": "verwurstelnd",
    "verwurstelndem": "verwurstelnd",
    "verwurstelnden": "verwurstelnd",
    "verwurstelnder": "verwurstelnd",
    "verwurstelndere": "verwurstelnd",
    "verwurstelnderem": "verwurstelnd",
    "verwurstelnderen": "verwurstelnd",
    "verwurstelnderer": "verwurstelnd",
    "verwurstelnderes": "verwurstelnd",
    "verwurstelndes": "verwurstelnd",
    "verwurstelndste": "verwurstelnd",
    "verwurstelndstem": "verwurstelnd",
    "verwurstelndsten": "verwurstelnd",
    "verwurstelndster": "verwurstelnd",
    "verwurstelndstes": "verwurstelnd",
    "verwurstelst": "verwursteln",
    "verwurstelt": "verwursteln",
    "verwurstelte": "verwursteln",
    "verwursteltem": "verwurstelt",
    "verwurstelten": "verwursteln",
    "verwurstelter": "verwurstelt",
    "verwursteltere": "verwurstelt",
    "verwurstelterem": "verwurstelt",
    "verwurstelteren": "verwurstelt",
    "verwurstelterer": "verwurstelt",
    "verwurstelteres": "verwurstelt",
    "verwursteltes": "verwurstelt",
    "verwursteltest": "verwursteln",
    "verwurstelteste": "verwurstelt",
    "verwursteltestem": "verwurstelt",
    "verwursteltesten": "verwurstelt",
    "verwursteltester": "verwurstelt",
    "verwursteltestes": "verwurstelt",
    "verwursteltet": "verwursteln",
    "verwurstend": "verwursten",
    "verwurstende": "verwurstend",
    "verwurstendem": "verwurstend",
    "verwurstenden": "verwurstend",
    "verwurstender": "verwurstend",
    "verwurstendere": "verwurstend",
    "verwurstenderem": "verwurstend",
    "verwurstenderen": "verwurstend",
    "verwurstenderer": "verwurstend",
    "verwurstenderes": "verwurstend",
    "verwurstendes": "verwurstend",
    "verwurstendste": "verwurstend",
    "verwurstendstem": "verwurstend",
    "verwurstendsten": "verwurstend",
    "verwurstendster": "verwurstend",
    "verwurstendstes": "verwurstend",
    "verwurstest": "verwursten",
    "verwurstet": "verwursten",
    "verwurstete": "verwursten",
    "verwurstetem": "verwurstet",
    "verwursteten": "verwursten",
    "verwursteter": "verwurstet",
    "verwurstetere": "verwurstet",
    "verwursteterem": "verwurstet",
    "verwursteteren": "verwurstet",
    "verwursteterer": "verwurstet",
    "verwursteteres": "verwurstet",
    "verwurstetes": "verwurstet",
    "verwurstetest": "verwursten",
    "verwursteteste": "verwurstet",
    "verwurstetestem": "verwurstet",
    "verwurstetesten": "verwurstet",
    "verwurstetester": "verwurstet",
    "verwurstetestes": "verwurstet",
    "verwurstetet": "verwursten",
    "verwurstle": "verwursteln",
    "verwurzele": "verwurzeln",
    "verwurzelnd": "verwurzeln",
    "verwurzelnde": "verwurzelnd",
    "verwurzelndem": "verwurzelnd",
    "verwurzelnden": "verwurzelnd",
    "verwurzelnder": "verwurzelnd",
    "verwurzelndes": "verwurzelnd",
    "verwurzelst": "verwurzeln",
    "verwurzelt": "verwurzeln",
    "verwurzelte": "verwurzeln",
    "verwurzeltem": "verwurzelt",
    "verwurzelten": "verwurzeln",
    "verwurzelter": "verwurzelt",
    "verwurzeltere": "verwurzelt",
    "verwurzelterem": "verwurzelt",
    "verwurzelteren": "verwurzelt",
    "verwurzelterer": "verwurzelt",
    "verwurzelteres": "verwurzelt",
    "verwurzeltes": "verwurzelt",
    "verwurzeltest": "verwurzeln",
    "verwurzelteste": "verwurzelt",
    "verwurzeltestem": "verwurzelt",
    "verwurzeltesten": "verwurzelt",
    "verwurzeltester": "verwurzelt",
    "verwurzeltestes": "verwurzelt",
    "verwurzeltet": "verwurzeln",
    "verwurzle": "verwurzeln",
    "verwächst": "verwachsen",
    "verwähle": "verwählen",
    "verwählend": "verwählen",
    "verwählende": "verwählend",
    "verwählendem": "verwählend",
    "verwählenden": "verwählend",
    "verwählender": "verwählend",
    "verwählendes": "verwählend",
    "verwählest": "verwählen",
    "verwählet": "verwählen",
    "verwählst": "verwählen",
    "verwählt": "verwählen",
    "verwählte": "verwählen",
    "verwähltem": "verwählt",
    "verwählten": "verwählen",
    "verwählter": "verwählt",
    "verwähltes": "verwählt",
    "verwähltest": "verwählen",
    "verwähltet": "verwählen",
    "verwähre": "verwähren",
    "verwährend": "verwähren",
    "verwährendem": "verwährend",
    "verwährender": "verwährend",
    "verwährendes": "verwährend",
    "verwährest": "verwähren",
    "verwähret": "verwähren",
    "verwährst": "verwähren",
    "verwährt": "verwähren",
    "verwährte": "verwähren",
    "verwährtem": "verwährt",
    "verwährten": "verwährt",
    "verwährter": "verwährt",
    "verwährtes": "verwährt",
    "verwährtest": "verwähren",
    "verwährtet": "verwähren",
    "verwände": "verwinden",
    "verwänden": "verwinden",
    "verwändest": "verwinden",
    "verwändet": "verwinden",
    "verwärfe": "verwerfen",
    "verwärfen": "verwerfen",
    "verwärfest": "verwerfen",
    "verwärfet": "verwerfen",
    "verwöhne": "verwöhnen",
    "verwöhnend": "verwöhnen",
    "verwöhnendem": "verwöhnend",
    "verwöhnender": "verwöhnend",
    "verwöhnenderem": "verwöhnend",
    "verwöhnenderer": "verwöhnend",
    "verwöhnenderes": "verwöhnend",
    "verwöhnendes": "verwöhnend",
    "verwöhnendstem": "verwöhnend",
    "verwöhnendster": "verwöhnend",
    "verwöhnendstes": "verwöhnend",
    "verwöhnest": "verwöhnen",
    "verwöhnet": "verwöhnen",
    "verwöhnst": "verwöhnen",
    "verwöhnt": "verwöhnen",
    "verwöhnte": "verwöhnen",
    "verwöhntem": "verwöhnt",
    "verwöhnten": "verwöhnt",
    "verwöhnter": "verwöhnt",
    "verwöhnterem": "verwöhnt",
    "verwöhnterer": "verwöhnt",
    "verwöhnteres": "verwöhnt",
    "verwöhntes": "verwöhnt",
    "verwöhntest": "verwöhnen",
    "verwöhntestem": "verwöhnt",
    "verwöhntester": "verwöhnt",
    "verwöhntestes": "verwöhnt",
    "verwöhntet": "verwöhnen",
    "verwüchse": "verwachsen",
    "verwüchsen": "verwachsen",
    "verwüchsest": "verwachsen",
    "verwüchset": "verwachsen",
    "verwünsche": "verwünschen",
    "verwünschend": "verwünschen",
    "verwünschende": "verwünschend",
    "verwünschendem": "verwünschend",
    "verwünschenden": "verwünschend",
    "verwünschender": "verwünschend",
    "verwünschendes": "verwünschend",
    "verwünschest": "verwünschen",
    "verwünschet": "verwünschen",
    "verwünschst": "verwünschen",
    "verwünscht": "verwünschen",
    "verwünschte": "verwünschen",
    "verwünschtem": "verwünscht",
    "verwünschten": "verwünschen",
    "verwünschter": "verwünscht",
    "verwünschtes": "verwünscht",
    "verwünschtest": "verwünschen",
    "verwünschtet": "verwünschen",
    "verwüste": "verwüsten",
    "verwüstend": "verwüsten",
    "verwüstende": "verwüstend",
    "verwüstendem": "verwüstend",
    "verwüstenden": "verwüstend",
    "verwüstender": "verwüstend",
    "verwüstendere": "verwüstend",
    "verwüstenderem": "verwüstend",
    "verwüstenderen": "verwüstend",
    "verwüstenderer": "verwüstend",
    "verwüstenderes": "verwüstend",
    "verwüstendes": "verwüstend",
    "verwüstendste": "verwüstend",
    "verwüstendstem": "verwüstend",
    "verwüstendsten": "verwüstend",
    "verwüstendster": "verwüstend",
    "verwüstendstes": "verwüstend",
    "verwüstest": "verwüsten",
    "verwüstet": "verwüsten",
    "verwüstete": "verwüsten",
    "verwüstetem": "verwüstet",
    "verwüsteten": "verwüsten",
    "verwüsteter": "verwüstet",
    "verwüstetere": "verwüstet",
    "verwüsteterem": "verwüstet",
    "verwüsteteren": "verwüstet",
    "verwüsteterer": "verwüstet",
    "verwüsteteres": "verwüstet",
    "verwüstetes": "verwüstet",
    "verwüstetest": "verwüsten",
    "verwüsteteste": "verwüstet",
    "verwüstetestem": "verwüstet",
    "verwüstetesten": "verwüstet",
    "verwüstetester": "verwüstet",
    "verwüstetestes": "verwüstet",
    "verwüstetet": "verwüsten",
    "verzage": "verzagen",
    "verzagend": "verzagen",
    "verzagende": "verzagend",
    "verzagendem": "verzagend",
    "verzagenden": "verzagend",
    "verzagender": "verzagend",
    "verzagendere": "verzagend",
    "verzagenderem": "verzagend",
    "verzagenderen": "verzagend",
    "verzagenderer": "verzagend",
    "verzagenderes": "verzagend",
    "verzagendes": "verzagend",
    "verzagendste": "verzagend",
    "verzagendstem": "verzagend",
    "verzagendsten": "verzagend",
    "verzagendster": "verzagend",
    "verzagendstes": "verzagend",
    "verzagest": "verzagen",
    "verzaget": "verzagen",
    "verzagst": "verzagen",
    "verzagt": "verzagen",
    "verzagte": "verzagen",
    "verzagtem": "verzagt",
    "verzagten": "verzagen",
    "verzagter": "verzagt",
    "verzagtere": "verzagt",
    "verzagterem": "verzagt",
    "verzagteren": "verzagt",
    "verzagterer": "verzagt",
    "verzagteres": "verzagt",
    "verzagtes": "verzagt",
    "verzagtest": "verzagen",
    "verzagteste": "verzagt",
    "verzagtestem": "verzagt",
    "verzagtesten": "verzagt",
    "verzagtester": "verzagt",
    "verzagtestes": "verzagt",
    "verzagtet": "verzagen",
    "verzahne": "verzahnen",
    "verzahnend": "verzahnen",
    "verzahnende": "verzahnend",
    "verzahnendem": "verzahnend",
    "verzahnenden": "verzahnend",
    "verzahnender": "verzahnend",
    "verzahnendes": "verzahnend",
    "verzahnest": "verzahnen",
    "verzahnet": "verzahnen",
    "verzahnst": "verzahnen",
    "verzahnt": "verzahnen",
    "verzahnte": "verzahnen",
    "verzahntem": "verzahnt",
    "verzahnten": "verzahnen",
    "verzahnter": "verzahnt",
    "verzahntes": "verzahnt",
    "verzahntest": "verzahnen",
    "verzahntet": "verzahnen",
    "verzapfe": "verzapfen",
    "verzapfend": "verzapfen",
    "verzapfende": "verzapfend",
    "verzapfendem": "verzapfend",
    "verzapfenden": "verzapfend",
    "verzapfender": "verzapfend",
    "verzapfendes": "verzapfend",
    "verzapfest": "verzapfen",
    "verzapfet": "verzapfen",
    "verzapfst": "verzapfen",
    "verzapft": "verzapfen",
    "verzapfte": "verzapfen",
    "verzapftem": "verzapft",
    "verzapften": "verzapfen",
    "verzapfter": "verzapft",
    "verzapftes": "verzapft",
    "verzapftest": "verzapfen",
    "verzapftet": "verzapfen",
    "verzaubere": "verzaubern",
    "verzaubernd": "verzaubern",
    "verzaubernde": "verzaubernd",
    "verzauberndem": "verzaubernd",
    "verzaubernden": "verzaubernd",
    "verzaubernder": "verzaubernd",
    "verzauberndere": "verzaubernd",
    "verzaubernderem": "verzaubernd",
    "verzaubernderen": "verzaubernd",
    "verzaubernderer": "verzaubernd",
    "verzaubernderes": "verzaubernd",
    "verzauberndes": "verzaubernd",
    "verzauberndste": "verzaubernd",
    "verzauberndstem": "verzaubernd",
    "verzauberndsten": "verzaubernd",
    "verzauberndster": "verzaubernd",
    "verzauberndstes": "verzaubernd",
    "verzauberst": "verzaubern",
    "verzaubert": "verzaubern",
    "verzauberte": "verzaubern",
    "verzaubertem": "verzaubert",
    "verzauberten": "verzaubern",
    "verzauberter": "verzaubert",
    "verzaubertere": "verzaubert",
    "verzauberterem": "verzaubert",
    "verzauberteren": "verzaubert",
    "verzauberterer": "verzaubert",
    "verzauberteres": "verzaubert",
    "verzaubertes": "verzaubert",
    "verzaubertest": "verzaubern",
    "verzauberteste": "verzaubert",
    "verzaubertestem": "verzaubert",
    "verzaubertesten": "verzaubert",
    "verzaubertester": "verzaubert",
    "verzaubertestes": "verzaubert",
    "verzaubertet": "verzaubern",
    "verzehre": "verzehren",
    "verzehrend": "verzehren",
    "verzehrende": "verzehrend",
    "verzehrendem": "verzehrend",
    "verzehrenden": "verzehrend",
    "verzehrender": "verzehrend",
    "verzehrendere": "verzehrend",
    "verzehrenderem": "verzehrend",
    "verzehrenderen": "verzehrend",
    "verzehrenderer": "verzehrend",
    "verzehrenderes": "verzehrend",
    "verzehrendes": "verzehrend",
    "verzehrendste": "verzehrend",
    "verzehrendstem": "verzehrend",
    "verzehrendsten": "verzehrend",
    "verzehrendster": "verzehrend",
    "verzehrendstes": "verzehrend",
    "verzehrest": "verzehren",
    "verzehret": "verzehren",
    "verzehrst": "verzehren",
    "verzehrt": "verzehren",
    "verzehrte": "verzehren",
    "verzehrtem": "verzehrt",
    "verzehrten": "verzehren",
    "verzehrter": "verzehrt",
    "verzehrtere": "verzehrt",
    "verzehrterem": "verzehrt",
    "verzehrteren": "verzehrt",
    "verzehrterer": "verzehrt",
    "verzehrteres": "verzehrt",
    "verzehrtes": "verzehrt",
    "verzehrtest": "verzehren",
    "verzehrteste": "verzehrt",
    "verzehrtestem": "verzehrt",
    "verzehrtesten": "verzehrt",
    "verzehrtester": "verzehrt",
    "verzehrtestes": "verzehrt",
    "verzehrtet": "verzehren",
    "verzeichne": "verzeichnen",
    "verzeichnend": "verzeichnen",
    "verzeichnende": "verzeichnend",
    "verzeichnendem": "verzeichnend",
    "verzeichnenden": "verzeichnend",
    "verzeichnender": "verzeichnend",
    "verzeichnendes": "verzeichnend",
    "verzeichnest": "verzeichnen",
    "verzeichnet": "verzeichnen",
    "verzeichnete": "verzeichnen",
    "verzeichnetem": "verzeichnet",
    "verzeichneten": "verzeichnen",
    "verzeichneter": "verzeichnet",
    "verzeichnetes": "verzeichnet",
    "verzeichnetest": "verzeichnen",
    "verzeichnetet": "verzeichnen",
    "verzeihe": "verzeihen",
    "verzeihend": "verzeihen",
    "verzeihende": "verzeihend",
    "verzeihendem": "verzeihend",
    "verzeihenden": "verzeihend",
    "verzeihender": "verzeihend",
    "verzeihendere": "verzeihend",
    "verzeihenderem": "verzeihend",
    "verzeihenderen": "verzeihend",
    "verzeihenderer": "verzeihend",
    "verzeihenderes": "verzeihend",
    "verzeihendes": "verzeihend",
    "verzeihendste": "verzeihend",
    "verzeihendstem": "verzeihend",
    "verzeihendsten": "verzeihend",
    "verzeihendster": "verzeihend",
    "verzeihendstes": "verzeihend",
    "verzeihest": "verzeihen",
    "verzeihet": "verzeihen",
    "verzeihst": "verzeihen",
    "verzeiht": "verzeihen",
    "verzeihte": "verzeihen",
    "verzeihtem": "verzeiht",
    "verzeihten": "verzeihen",
    "verzeihter": "verzeiht",
    "verzeihtes": "verzeiht",
    "verzeihtest": "verzeihen",
    "verzeihtet": "verzeihen",
    "verzerre": "verzerren",
    "verzerrend": "verzerren",
    "verzerrende": "verzerrend",
    "verzerrendem": "verzerrend",
    "verzerrenden": "verzerrend",
    "verzerrender": "verzerrend",
    "verzerrendes": "verzerrend",
    "verzerrest": "verzerren",
    "verzerret": "verzerren",
    "verzerrst": "verzerren",
    "verzerrt": "verzerren",
    "verzerrte": "verzerren",
    "verzerrtem": "verzerrt",
    "verzerrten": "verzerren",
    "verzerrter": "verzerrt",
    "verzerrtere": "verzerrt",
    "verzerrterem": "verzerrt",
    "verzerrteren": "verzerrt",
    "verzerrterer": "verzerrt",
    "verzerrteres": "verzerrt",
    "verzerrtes": "verzerrt",
    "verzerrtest": "verzerren",
    "verzerrteste": "verzerrt",
    "verzerrtestem": "verzerrt",
    "verzerrtesten": "verzerrt",
    "verzerrtester": "verzerrt",
    "verzerrtestes": "verzerrt",
    "verzerrtet": "verzerren",
    "verzettele": "verzetteln",
    "verzettelnd": "verzetteln",
    "verzettelnde": "verzettelnd",
    "verzettelndem": "verzettelnd",
    "verzettelnden": "verzettelnd",
    "verzettelnder": "verzettelnd",
    "verzettelndes": "verzettelnd",
    "verzettelst": "verzetteln",
    "verzettelt": "verzetteln",
    "verzettelte": "verzetteln",
    "verzetteltem": "verzettelt",
    "verzettelten": "verzetteln",
    "verzettelter": "verzettelt",
    "verzetteltes": "verzettelt",
    "verzetteltest": "verzetteln",
    "verzetteltet": "verzetteln",
    "verzettle": "verzetteln",
    "verzichtend": "verzichten",
    "verzichtende": "verzichtend",
    "verzichtendem": "verzichtend",
    "verzichtenden": "verzichtend",
    "verzichtender": "verzichtend",
    "verzichtendes": "verzichtend",
    "verzichtest": "verzichten",
    "verzichtet": "verzichten",
    "verzichtete": "verzichten",
    "verzichtetem": "verzichtet",
    "verzichteten": "verzichten",
    "verzichteter": "verzichtet",
    "verzichtetes": "verzichtet",
    "verzichtetest": "verzichten",
    "verzichtetet": "verzichten",
    "verzieh": "verziehen",
    "verziehe": "verziehen",
    "verziehen": "verzeihen",
    "verziehend": "verziehen",
    "verziehende": "verziehend",
    "verziehendem": "verziehend",
    "verziehenden": "verziehend",
    "verziehender": "verziehend",
    "verziehendes": "verziehend",
    "verziehene": "verziehen",
    "verziehenem": "verziehen",
    "verziehenen": "verziehen",
    "verziehener": "verziehen",
    "verziehenere": "verziehen",
    "verziehenerem": "verziehen",
    "verzieheneren": "verziehen",
    "verziehenerer": "verziehen",
    "verzieheneres": "verziehen",
    "verziehenes": "verziehen",
    "verziehenstem": "verziehen",
    "verziehensten": "verziehen",
    "verziehenster": "verziehen",
    "verziehenstes": "verziehen",
    "verziehest": "verziehen",
    "verziehet": "verziehen",
    "verziehst": "verziehen",
    "verzieht": "verziehen",
    "verziere": "verzieren",
    "verzierend": "verzieren",
    "verzierende": "verzierend",
    "verzierendem": "verzierend",
    "verzierenden": "verzierend",
    "verzierender": "verzierend",
    "verzierendere": "verzierend",
    "verzierenderem": "verzierend",
    "verzierenderen": "verzierend",
    "verzierenderer": "verzierend",
    "verzierenderes": "verzierend",
    "verzierendes": "verzierend",
    "verzierendste": "verzierend",
    "verzierendstem": "verzierend",
    "verzierendsten": "verzierend",
    "verzierendster": "verzierend",
    "verzierendstes": "verzierend",
    "verzierest": "verzieren",
    "verzieret": "verzieren",
    "verzierst": "verzieren",
    "verziert": "verzieren",
    "verzierte": "verzieren",
    "verziertem": "verziert",
    "verzierten": "verzieren",
    "verzierter": "verziert",
    "verziertes": "verziert",
    "verziertest": "verzieren",
    "verziertet": "verzieren",
    "verzinke": "verzinken",
    "verzinkend": "verzinken",
    "verzinkende": "verzinkend",
    "verzinkendem": "verzinkend",
    "verzinkenden": "verzinkend",
    "verzinkender": "verzinkend",
    "verzinkendere": "verzinkend",
    "verzinkenderem": "verzinkend",
    "verzinkenderen": "verzinkend",
    "verzinkenderer": "verzinkend",
    "verzinkenderes": "verzinkend",
    "verzinkendes": "verzinkend",
    "verzinkendste": "verzinkend",
    "verzinkendstem": "verzinkend",
    "verzinkendsten": "verzinkend",
    "verzinkendster": "verzinkend",
    "verzinkendstes": "verzinkend",
    "verzinkest": "verzinken",
    "verzinket": "verzinken",
    "verzinkst": "verzinken",
    "verzinkt": "verzinken",
    "verzinkte": "verzinken",
    "verzinktem": "verzinkt",
    "verzinkten": "verzinken",
    "verzinkter": "verzinkt",
    "verzinktere": "verzinkt",
    "verzinkterem": "verzinkt",
    "verzinkteren": "verzinkt",
    "verzinkterer": "verzinkt",
    "verzinkteres": "verzinkt",
    "verzinktes": "verzinkt",
    "verzinktest": "verzinken",
    "verzinkteste": "verzinkt",
    "verzinktestem": "verzinkt",
    "verzinktesten": "verzinkt",
    "verzinktester": "verzinkt",
    "verzinktestes": "verzinkt",
    "verzinktet": "verzinken",
    "verzinse": "verzinsen",
    "verzinsend": "verzinsen",
    "verzinsende": "verzinsend",
    "verzinsendem": "verzinsend",
    "verzinsenden": "verzinsend",
    "verzinsender": "verzinsend",
    "verzinsendes": "verzinsend",
    "verzinsest": "verzinsen",
    "verzinset": "verzinsen",
    "verzinsliche": "verzinslich",
    "verzinslichem": "verzinslich",
    "verzinslichen": "verzinslich",
    "verzinslicher": "verzinslich",
    "verzinsliches": "verzinslich",
    "verzinst": "verzinsen",
    "verzinste": "verzinsen",
    "verzinstem": "verzinst",
    "verzinsten": "verzinsen",
    "verzinster": "verzinst",
    "verzinstes": "verzinst",
    "verzinstest": "verzinsen",
    "verzinstet": "verzinsen",
    "verzog": "verziehen",
    "verzogen": "verziehen",
    "verzogene": "verzogen",
    "verzogenem": "verzogen",
    "verzogenen": "verzogen",
    "verzogener": "verzogen",
    "verzogenes": "verzogen",
    "verzogst": "verziehen",
    "verzogt": "verziehen",
    "verzolle": "verzollen",
    "verzollend": "verzollen",
    "verzollende": "verzollend",
    "verzollendem": "verzollend",
    "verzollenden": "verzollend",
    "verzollender": "verzollend",
    "verzollendes": "verzollend",
    "verzollest": "verzollen",
    "verzollet": "verzollen",
    "verzollst": "verzollen",
    "verzollt": "verzollen",
    "verzollte": "verzollen",
    "verzolltem": "verzollt",
    "verzollten": "verzollen",
    "verzollter": "verzollt",
    "verzolltes": "verzollt",
    "verzolltest": "verzollen",
    "verzolltet": "verzollen",
    "verzweifele": "verzweifeln",
    "verzweifelnd": "verzweifeln",
    "verzweifelnde": "verzweifelnd",
    "verzweifelndem": "verzweifelnd",
    "verzweifelnden": "verzweifelnd",
    "verzweifelnder": "verzweifelnd",
    "verzweifelndere": "verzweifelnd",
    "verzweifelnderem": "verzweifelnd",
    "verzweifelnderen": "verzweifelnd",
    "verzweifelnderer": "verzweifelnd",
    "verzweifelnderes": "verzweifelnd",
    "verzweifelndes": "verzweifelnd",
    "verzweifelndste": "verzweifelnd",
    "verzweifelndstem": "verzweifelnd",
    "verzweifelndsten": "verzweifelnd",
    "verzweifelndster": "verzweifelnd",
    "verzweifelndstes": "verzweifelnd",
    "verzweifelst": "verzweifeln",
    "verzweifelt": "verzweifeln",
    "verzweifelte": "verzweifeln",
    "verzweifeltem": "verzweifelt",
    "verzweifelten": "verzweifeln",
    "verzweifelter": "verzweifelt",
    "verzweifeltere": "verzweifelt",
    "verzweifelterem": "verzweifelt",
    "verzweifelteren": "verzweifelt",
    "verzweifelterer": "verzweifelt",
    "verzweifelteres": "verzweifelt",
    "verzweifeltes": "verzweifelt",
    "verzweifeltest": "verzweifeln",
    "verzweifelteste": "verzweifelt",
    "verzweifeltestem": "verzweifelt",
    "verzweifeltesten": "verzweifelt",
    "verzweifeltester": "verzweifelt",
    "verzweifeltestes": "verzweifelt",
    "verzweifeltet": "verzweifeln",
    "verzweifle": "verzweifeln",
    "verzweige": "verzweigen",
    "verzweigend": "verzweigen",
    "verzweigende": "verzweigend",
    "verzweigendem": "verzweigend",
    "verzweigenden": "verzweigend",
    "verzweigender": "verzweigend",
    "verzweigendere": "verzweigend",
    "verzweigenderem": "verzweigend",
    "verzweigenderen": "verzweigend",
    "verzweigenderer": "verzweigend",
    "verzweigenderes": "verzweigend",
    "verzweigendes": "verzweigend",
    "verzweigendste": "verzweigend",
    "verzweigendstem": "verzweigend",
    "verzweigendsten": "verzweigend",
    "verzweigendster": "verzweigend",
    "verzweigendstes": "verzweigend",
    "verzweigest": "verzweigen",
    "verzweiget": "verzweigen",
    "verzweigst": "verzweigen",
    "verzweigt": "verzweigen",
    "verzweigte": "verzweigen",
    "verzweigtem": "verzweigt",
    "verzweigten": "verzweigen",
    "verzweigter": "verzweigt",
    "verzweigtere": "verzweigt",
    "verzweigterem": "verzweigt",
    "verzweigteren": "verzweigt",
    "verzweigterer": "verzweigt",
    "verzweigteres": "verzweigt",
    "verzweigtes": "verzweigt",
    "verzweigtest": "verzweigen",
    "verzweigteste": "verzweigt",
    "verzweigtestem": "verzweigt",
    "verzweigtesten": "verzweigt",
    "verzweigtester": "verzweigt",
    "verzweigtestes": "verzweigt",
    "verzweigtet": "verzweigen",
    "verzwicktem": "verzwickt",
    "verzwickten": "verzwickt",
    "verzwickter": "verzwickt",
    "verzwicktere": "verzwickt",
    "verzwickterem": "verzwickt",
    "verzwickteren": "verzwickt",
    "verzwickterer": "verzwickt",
    "verzwickteres": "verzwickt",
    "verzwicktes": "verzwickt",
    "verzwickteste": "verzwickt",
    "verzwicktestem": "verzwickt",
    "verzwicktesten": "verzwickt",
    "verzwicktester": "verzwickt",
    "verzwicktestes": "verzwickt",
    "verzähle": "verzählen",
    "verzählend": "verzählen",
    "verzählende": "verzählend",
    "verzählendem": "verzählend",
    "verzählenden": "verzählend",
    "verzählender": "verzählend",
    "verzählendere": "verzählend",
    "verzählenderem": "verzählend",
    "verzählenderen": "verzählend",
    "verzählenderer": "verzählend",
    "verzählenderes": "verzählend",
    "verzählendes": "verzählend",
    "verzählendste": "verzählend",
    "verzählendstem": "verzählend",
    "verzählendsten": "verzählend",
    "verzählendster": "verzählend",
    "verzählendstes": "verzählend",
    "verzählest": "verzählen",
    "verzählet": "verzählen",
    "verzählst": "verzählen",
    "verzählt": "verzählen",
    "verzählte": "verzählen",
    "verzähltem": "verzählt",
    "verzählten": "verzählen",
    "verzählter": "verzählt",
    "verzähltes": "verzählt",
    "verzähltest": "verzählen",
    "verzähltet": "verzählen",
    "verzöge": "verziehen",
    "verzögen": "verziehen",
    "verzögere": "verzögern",
    "verzögernd": "verzögern",
    "verzögernde": "verzögernd",
    "verzögerndem": "verzögernd",
    "verzögernden": "verzögernd",
    "verzögernder": "verzögernd",
    "verzögerndere": "verzögernd",
    "verzögernderem": "verzögernd",
    "verzögernderen": "verzögernd",
    "verzögernderer": "verzögernd",
    "verzögernderes": "verzögernd",
    "verzögerndes": "verzögernd",
    "verzögerndste": "verzögernd",
    "verzögerndstem": "verzögernd",
    "verzögerndsten": "verzögernd",
    "verzögerndster": "verzögernd",
    "verzögerndstes": "verzögernd",
    "verzögerst": "verzögern",
    "verzögert": "verzögern",
    "verzögerte": "verzögern",
    "verzögertem": "verzögert",
    "verzögerten": "verzögern",
    "verzögerter": "verzögert",
    "verzögertere": "verzögert",
    "verzögerterem": "verzögert",
    "verzögerteren": "verzögert",
    "verzögerterer": "verzögert",
    "verzögerteres": "verzögert",
    "verzögertes": "verzögert",
    "verzögertest": "verzögern",
    "verzögerteste": "verzögert",
    "verzögertestem": "verzögert",
    "verzögertesten": "verzögert",
    "verzögertester": "verzögert",
    "verzögertestes": "verzögert",
    "verzögertet": "verzögern",
    "verzögest": "verziehen",
    "verzöget": "verziehen",
    "verächtliche": "verächtlich",
    "verächtlichem": "verächtlich",
    "verächtlichen": "verächtlich",
    "verächtlicher": "verächtlich",
    "verächtlichere": "verächtlich",
    "verächtlicherem": "verächtlich",
    "verächtlicheren": "verächtlich",
    "verächtlicherer": "verächtlich",
    "verächtlicheres": "verächtlich",
    "verächtliches": "verächtlich",
    "verächtlichste": "verächtlich",
    "verächtlichstem": "verächtlich",
    "verächtlichsten": "verächtlich",
    "verächtlichster": "verächtlich",
    "verächtlichstes": "verächtlich",
    "veränderbarem": "veränderbar",
    "veränderbaren": "veränderbar",
    "veränderbarer": "veränderbar",
    "veränderbarere": "veränderbar",
    "veränderbarerem": "veränderbar",
    "veränderbareren": "veränderbar",
    "veränderbarerer": "veränderbar",
    "veränderbareres": "veränderbar",
    "veränderbares": "veränderbar",
    "veränderbarste": "veränderbar",
    "veränderbarstem": "veränderbar",
    "veränderbarsten": "veränderbar",
    "veränderbarster": "veränderbar",
    "veränderbarstes": "veränderbar",
    "verändere": "verändern",
    "verändernd": "verändern",
    "verändernde": "verändernd",
    "veränderndem": "verändernd",
    "verändernden": "verändernd",
    "verändernder": "verändernd",
    "veränderndere": "verändernd",
    "verändernderem": "verändernd",
    "verändernderen": "verändernd",
    "verändernderer": "verändernd",
    "verändernderes": "verändernd",
    "veränderndes": "verändernd",
    "veränderndste": "verändernd",
    "veränderndstem": "verändernd",
    "veränderndsten": "verändernd",
    "veränderndster": "verändernd",
    "veränderndstes": "verändernd",
    "veränderst": "verändern",
    "verändert": "verändern",
    "veränderte": "verändern",
    "verändertem": "verändert",
    "veränderten": "verändern",
    "veränderter": "verändert",
    "verändertere": "verändert",
    "veränderterem": "verändert",
    "veränderteren": "verändert",
    "veränderterer": "verändert",
    "veränderteres": "verändert",
    "verändertes": "verändert",
    "verändertest": "verändern",
    "veränderteste": "verändert",
    "verändertestem": "verändert",
    "verändertesten": "verändert",
    "verändertester": "verändert",
    "verändertestes": "verändert",
    "verändertet": "verändern",
    "verängstige": "verängstigen",
    "verängstigend": "verängstigen",
    "verängstigende": "verängstigend",
    "verängstigendem": "verängstigend",
    "verängstigenden": "verängstigend",
    "verängstigender": "verängstigend",
    "verängstigendere": "verängstigend",
    "verängstigenderem": "verängstigend",
    "verängstigenderen": "verängstigend",
    "verängstigenderer": "verängstigend",
    "verängstigenderes": "verängstigend",
    "verängstigendes": "verängstigend",
    "verängstigendste": "verängstigend",
    "verängstigendstem": "verängstigend",
    "verängstigendsten": "verängstigend",
    "verängstigendster": "verängstigend",
    "verängstigendstes": "verängstigend",
    "verängstigest": "verängstigen",
    "verängstiget": "verängstigen",
    "verängstigst": "verängstigen",
    "verängstigt": "verängstigen",
    "verängstigte": "verängstigen",
    "verängstigtem": "verängstigt",
    "verängstigten": "verängstigen",
    "verängstigter": "verängstigt",
    "verängstigtere": "verängstigt",
    "verängstigterem": "verängstigt",
    "verängstigteren": "verängstigt",
    "verängstigterer": "verängstigt",
    "verängstigteres": "verängstigt",
    "verängstigtes": "verängstigt",
    "verängstigtest": "verängstigen",
    "verängstigteste": "verängstigt",
    "verängstigtestem": "verängstigt",
    "verängstigtesten": "verängstigt",
    "verängstigtester": "verängstigt",
    "verängstigtestes": "verängstigt",
    "verängstigtet": "verängstigen",
    "veräppele": "veräppeln",
    "veräppelnd": "veräppeln",
    "veräppelnde": "veräppelnd",
    "veräppelndem": "veräppelnd",
    "veräppelnden": "veräppelnd",
    "veräppelnder": "veräppelnd",
    "veräppelndere": "veräppelnd",
    "veräppelnderem": "veräppelnd",
    "veräppelnderen": "veräppelnd",
    "veräppelnderer": "veräppelnd",
    "veräppelnderes": "veräppelnd",
    "veräppelndes": "veräppelnd",
    "veräppelndste": "veräppelnd",
    "veräppelndstem": "veräppelnd",
    "veräppelndsten": "veräppelnd",
    "veräppelndster": "veräppelnd",
    "veräppelndstes": "veräppelnd",
    "veräppelst": "veräppeln",
    "veräppelt": "veräppeln",
    "veräppelte": "veräppeln",
    "veräppeltem": "veräppelt",
    "veräppelten": "veräppeln",
    "veräppelter": "veräppelt",
    "veräppeltere": "veräppelt",
    "veräppelterem": "veräppelt",
    "veräppelteren": "veräppelt",
    "veräppelterer": "veräppelt",
    "veräppelteres": "veräppelt",
    "veräppeltes": "veräppelt",
    "veräppeltest": "veräppeln",
    "veräppelteste": "veräppelt",
    "veräppeltestem": "veräppelt",
    "veräppeltesten": "veräppelt",
    "veräppeltester": "veräppelt",
    "veräppeltestes": "veräppelt",
    "veräppeltet": "veräppeln",
    "veräpple": "veräppeln",
    "verärgere": "verärgern",
    "verärgernd": "verärgern",
    "verärgernde": "verärgernd",
    "verärgerndem": "verärgernd",
    "verärgernden": "verärgernd",
    "verärgernder": "verärgernd",
    "verärgerndes": "verärgernd",
    "verärgerst": "verärgern",
    "verärgert": "verärgern",
    "verärgerte": "verärgern",
    "verärgertem": "verärgert",
    "verärgerten": "verärgern",
    "verärgerter": "verärgert",
    "verärgertere": "verärgert",
    "verärgerterem": "verärgert",
    "verärgerteren": "verärgert",
    "verärgerterer": "verärgert",
    "verärgerteres": "verärgert",
    "verärgertes": "verärgert",
    "verärgertest": "verärgern",
    "verärgerteste": "verärgert",
    "verärgertestem": "verärgert",
    "verärgertesten": "verärgert",
    "verärgertester": "verärgert",
    "verärgertestes": "verärgert",
    "verärgertet": "verärgern",
    "verästele": "verästeln",
    "verästelnd": "verästeln",
    "verästelnde": "verästelnd",
    "verästelndem": "verästelnd",
    "verästelnden": "verästelnd",
    "verästelnder": "verästelnd",
    "verästelndere": "verästelnd",
    "verästelnderem": "verästelnd",
    "verästelnderen": "verästelnd",
    "verästelnderer": "verästelnd",
    "verästelnderes": "verästelnd",
    "verästelndes": "verästelnd",
    "verästelndste": "verästelnd",
    "verästelndstem": "verästelnd",
    "verästelndsten": "verästelnd",
    "verästelndster": "verästelnd",
    "verästelndstes": "verästelnd",
    "verästelst": "verästeln",
    "verästelt": "verästeln",
    "verästelte": "verästeln",
    "verästeltem": "verästelt",
    "verästelten": "verästeln",
    "verästelter": "verästelt",
    "verästeltere": "verästelt",
    "verästelterem": "verästelt",
    "verästelteren": "verästelt",
    "verästelterer": "verästelt",
    "verästelteres": "verästelt",
    "verästeltes": "verästelt",
    "verästeltest": "verästeln",
    "verästelteste": "verästelt",
    "verästeltestem": "verästelt",
    "verästeltesten": "verästelt",
    "verästeltester": "verästelt",
    "verästeltestes": "verästelt",
    "verästeltet": "verästeln",
    "verästle": "verästeln",
    "veräußere": "veräußern",
    "veräußernd": "veräußern",
    "veräußernde": "veräußernd",
    "veräußerndem": "veräußernd",
    "veräußernden": "veräußernd",
    "veräußernder": "veräußernd",
    "veräußerndes": "veräußernd",
    "veräußerst": "veräußern",
    "veräußert": "veräußern",
    "veräußerte": "veräußern",
    "veräußertem": "veräußert",
    "veräußerten": "veräußern",
    "veräußerter": "veräußert",
    "veräußertes": "veräußert",
    "veräußertest": "veräußern",
    "veräußertet": "veräußern",
    "veröde": "veröden",
    "verödend": "veröden",
    "verödende": "verödend",
    "verödendem": "verödend",
    "verödenden": "verödend",
    "verödender": "verödend",
    "verödendes": "verödend",
    "verödest": "veröden",
    "verödet": "veröden",
    "verödete": "veröden",
    "verödetem": "verödet",
    "verödeten": "veröden",
    "verödeter": "verödet",
    "verödetes": "verödet",
    "verödetest": "veröden",
    "verödetet": "veröden",
    "veröffentliche": "veröffentlichen",
    "veröffentlichend": "veröffentlichen",
    "veröffentlichende": "veröffentlichend",
    "veröffentlichendem": "veröffentlichend",
    "veröffentlichenden": "veröffentlichend",
    "veröffentlichender": "veröffentlichend",
    "veröffentlichendes": "veröffentlichend",
    "veröffentlichest": "veröffentlichen",
    "veröffentlichet": "veröffentlichen",
    "veröffentlichst": "veröffentlichen",
    "veröffentlicht": "veröffentlichen",
    "veröffentlichte": "veröffentlichen",
    "veröffentlichtem": "veröffentlicht",
    "veröffentlichten": "veröffentlichen",
    "veröffentlichter": "veröffentlicht",
    "veröffentlichtes": "veröffentlicht",
    "veröffentlichtest": "veröffentlichen",
    "veröffentlichtet": "veröffentlichen",
    "verübe": "verüben",
    "verübele": "verübeln",
    "verübelnd": "verübeln",
    "verübelnde": "verübelnd",
    "verübelndem": "verübelnd",
    "verübelnden": "verübelnd",
    "verübelnder": "verübelnd",
    "verübelndere": "verübelnd",
    "verübelnderem": "verübelnd",
    "verübelnderen": "verübelnd",
    "verübelnderer": "verübelnd",
    "verübelnderes": "verübelnd",
    "verübelndes": "verübelnd",
    "verübelndste": "verübelnd",
    "verübelndstem": "verübelnd",
    "verübelndsten": "verübelnd",
    "verübelndster": "verübelnd",
    "verübelndstes": "verübelnd",
    "verübelst": "verübeln",
    "verübelt": "verübeln",
    "verübelte": "verübeln",
    "verübeltem": "verübelt",
    "verübelten": "verübeln",
    "verübelter": "verübelt",
    "verübeltere": "verübelt",
    "verübelterem": "verübelt",
    "verübelteren": "verübelt",
    "verübelterer": "verübelt",
    "verübelteres": "verübelt",
    "verübeltes": "verübelt",
    "verübeltest": "verübeln",
    "verübelteste": "verübelt",
    "verübeltestem": "verübelt",
    "verübeltesten": "verübelt",
    "verübeltester": "verübelt",
    "verübeltestes": "verübelt",
    "verübeltet": "verübeln",
    "verübend": "verüben",
    "verübende": "verübend",
    "verübendem": "verübend",
    "verübenden": "verübend",
    "verübender": "verübend",
    "verübendes": "verübend",
    "verübest": "verüben",
    "verübet": "verüben",
    "verüble": "verübeln",
    "verübst": "verüben",
    "verübt": "verüben",
    "verübte": "verüben",
    "verübtem": "verübt",
    "verübten": "verüben",
    "verübter": "verübt",
    "verübtes": "verübt",
    "verübtest": "verüben",
    "verübtet": "verüben",
    "vielbefahrene": "vielbefahren",
    "vielbefahrenem": "vielbefahren",
    "vielbefahrenen": "vielbefahren",
    "vielbefahrener": "vielbefahren",
    "vielbefahrenere": "vielbefahren",
    "vielbefahrenerem": "vielbefahren",
    "vielbefahreneren": "vielbefahren",
    "vielbefahrenerer": "vielbefahren",
    "vielbefahreneres": "vielbefahren",
    "vielbefahrenes": "vielbefahren",
    "vielbefahrenste": "vielbefahren",
    "vielbefahrenstem": "vielbefahren",
    "vielbefahrensten": "vielbefahren",
    "vielbefahrenster": "vielbefahren",
    "vielbefahrenstes": "vielbefahren",
    "vielbesungene": "vielbesungen",
    "vielbesungenem": "vielbesungen",
    "vielbesungenen": "vielbesungen",
    "vielbesungener": "vielbesungen",
    "vielbesungenes": "vielbesungen",
    "vielbändigem": "vielbändig",
    "vielbändigen": "vielbändig",
    "vielbändiger": "vielbändig",
    "vielbändiges": "vielbändig",
    "vieldeutige": "vieldeutig",
    "vieldeutigem": "vieldeutig",
    "vieldeutigen": "vieldeutig",
    "vieldeutiger": "vieldeutig",
    "vieldeutiges": "vieldeutig",
    "viele": "viel",
    "vielem": "viel",
    "vielen": "viel",
    "vieler": "viel",
    "vieles": "viel",
    "vielfache": "vielfach",
    "vielfachem": "vielfach",
    "vielfachen": "vielfach",
    "vielfacher": "vielfach",
    "vielfaches": "vielfach",
    "vielfältige": "vielfältig",
    "vielfältigem": "vielfältig",
    "vielfältigen": "vielfältig",
    "vielfältiger": "vielfältig",
    "vielfältigere": "vielfältig",
    "vielfältigerem": "vielfältig",
    "vielfältigeren": "vielfältig",
    "vielfältigerer": "vielfältig",
    "vielfältigeres": "vielfältig",
    "vielfältiges": "vielfältig",
    "vielfältigste": "vielfältig",
    "vielfältigstem": "vielfältig",
    "vielfältigsten": "vielfältig",
    "vielfältigster": "vielfältig",
    "vielfältigstes": "vielfältig",
    "vielsagende": "vielsagend",
    "vielsagendem": "vielsagend",
    "vielsagenden": "vielsagend",
    "vielsagender": "vielsagend",
    "vielsagendes": "vielsagend",
    "vielschichtige": "vielschichtig",
    "vielschichtigem": "vielschichtig",
    "vielschichtigen": "vielschichtig",
    "vielschichtiger": "vielschichtig",
    "vielschichtiges": "vielschichtig",
    "vielseitige": "vielseitig",
    "vielseitigem": "vielseitig",
    "vielseitigen": "vielseitig",
    "vielseitiger": "vielseitig",
    "vielseitigere": "vielseitig",
    "vielseitigerem": "vielseitig",
    "vielseitigeren": "vielseitig",
    "vielseitigerer": "vielseitig",
    "vielseitigeres": "vielseitig",
    "vielseitiges": "vielseitig",
    "vielseitigste": "vielseitig",
    "vielseitigstem": "vielseitig",
    "vielseitigsten": "vielseitig",
    "vielseitigster": "vielseitig",
    "vielseitigstes": "vielseitig",
    "vielversprechende": "vielversprechend",
    "vielversprechendem": "vielversprechend",
    "vielversprechenden": "vielversprechend",
    "vielversprechender": "vielversprechend",
    "vielversprechendere": "vielversprechend",
    "vielversprechenderem": "vielversprechend",
    "vielversprechenderen": "vielversprechend",
    "vielversprechenderer": "vielversprechend",
    "vielversprechenderes": "vielversprechend",
    "vielversprechendes": "vielversprechend",
    "vielversprechendste": "vielversprechend",
    "vielversprechendstem": "vielversprechend",
    "vielversprechendsten": "vielversprechend",
    "vielversprechendster": "vielversprechend",
    "vielversprechendstes": "vielversprechend",
    "vierbeinigem": "vierbeinig",
    "vierbeinigen": "vierbeinig",
    "vierbeiniger": "vierbeinig",
    "vierbeiniges": "vierbeinig",
    "vierhändigem": "vierhändig",
    "vierhändigen": "vierhändig",
    "vierhändiger": "vierhändig",
    "vierhändiges": "vierhändig",
    "vierteile": "vierteilen",
    "vierteilend": "vierteilen",
    "vierteilende": "vierteilend",
    "vierteilendem": "vierteilend",
    "vierteilenden": "vierteilend",
    "vierteilender": "vierteilend",
    "vierteilendes": "vierteilend",
    "vierteilest": "vierteilen",
    "vierteilet": "vierteilen",
    "vierteilst": "vierteilen",
    "vierteilt": "vierteilen",
    "vierteilte": "vierteilen",
    "vierteilten": "vierteilen",
    "vierteiltest": "vierteilen",
    "vierteiltet": "vierteilen",
    "viertele": "vierteln",
    "vierteljährlichem": "vierteljährlich",
    "vierteljährlichen": "vierteljährlich",
    "vierteljährlicher": "vierteljährlich",
    "vierteljährliches": "vierteljährlich",
    "viertelnd": "vierteln",
    "viertelnde": "viertelnd",
    "viertelndem": "viertelnd",
    "viertelnden": "viertelnd",
    "viertelnder": "viertelnd",
    "viertelndes": "viertelnd",
    "viertelst": "vierteln",
    "viertelstündige": "viertelstündig",
    "viertelstündigem": "viertelstündig",
    "viertelstündigen": "viertelstündig",
    "viertelstündiger": "viertelstündig",
    "viertelstündiges": "viertelstündig",
    "viertelt": "vierteln",
    "viertelte": "vierteln",
    "viertelten": "vierteln",
    "vierteltest": "vierteln",
    "vierteltet": "vierteln",
    "viertem": "viert",
    "vierten": "viert",
    "vierter": "viert",
    "viertes": "viert",
    "viertle": "vierteln",
    "viertürige": "viertürig",
    "viertürigem": "viertürig",
    "viertürigen": "viertürig",
    "viertüriger": "viertürig",
    "viertüriges": "viertürig",
    "violettem": "violett",
    "violetten": "violett",
    "violetter": "violett",
    "violettes": "violett",
    "visierend": "visieren",
    "visierende": "visierend",
    "visierendem": "visierend",
    "visierenden": "visierend",
    "visierender": "visierend",
    "visierendes": "visierend",
    "visierest": "visieren",
    "visieret": "visieren",
    "visierst": "visieren",
    "visiert": "visieren",
    "visierte": "visieren",
    "visiertem": "visiert",
    "visierten": "visieren",
    "visierter": "visiert",
    "visiertes": "visiert",
    "visiertest": "visieren",
    "visiertet": "visieren",
    "visionäre": "visionär",
    "visionärem": "visionär",
    "visionären": "visionär",
    "visionärer": "visionär",
    "visionärere": "visionär",
    "visionärerem": "visionär",
    "visionäreren": "visionär",
    "visionärerer": "visionär",
    "visionäreres": "visionär",
    "visionäres": "visionär",
    "visionärste": "visionär",
    "visionärstem": "visionär",
    "visionärsten": "visionär",
    "visionärster": "visionär",
    "visionärstes": "visionär",
    "visuellem": "visuell",
    "visuellen": "visuell",
    "visueller": "visuell",
    "visuelles": "visuell",
    "vitale": "vital",
    "vitalem": "vital",
    "vitalen": "vital",
    "vitaler": "vital",
    "vitalere": "vital",
    "vitalerem": "vital",
    "vitaleren": "vital",
    "vitalerer": "vital",
    "vitaleres": "vital",
    "vitales": "vital",
    "vitalste": "vital",
    "vitalstem": "vital",
    "vitalsten": "vital",
    "vitalster": "vital",
    "vitalstes": "vital",
    "vogelfreie": "vogelfrei",
    "vogelfreiem": "vogelfrei",
    "vogelfreien": "vogelfrei",
    "vogelfreier": "vogelfrei",
    "vogelfreies": "vogelfrei",
    "volksdeutschem": "volksdeutsch",
    "volksdeutschen": "volksdeutsch",
    "volksdeutscher": "volksdeutsch",
    "volksdeutschere": "volksdeutsch",
    "volksdeutscherem": "volksdeutsch",
    "volksdeutscheren": "volksdeutsch",
    "volksdeutscherer": "volksdeutsch",
    "volksdeutscheres": "volksdeutsch",
    "volksdeutsches": "volksdeutsch",
    "volksdeutscheste": "volksdeutsch",
    "volksdeutschestem": "volksdeutsch",
    "volksdeutschesten": "volksdeutsch",
    "volksdeutschester": "volksdeutsch",
    "volksdeutschestes": "volksdeutsch",
    "volkseigene": "volkseigen",
    "volkseigenem": "volkseigen",
    "volkseigenen": "volkseigen",
    "volkseigener": "volkseigen",
    "volkseigenes": "volkseigen",
    "volksfremdem": "volksfremd",
    "volksfremden": "volksfremd",
    "volksfremder": "volksfremd",
    "volksfremdes": "volksfremd",
    "volkskundlichem": "volkskundlich",
    "volkskundlichen": "volkskundlich",
    "volkskundlicher": "volkskundlich",
    "volkskundliches": "volkskundlich",
    "volkstümliche": "volkstümlich",
    "volkstümlichem": "volkstümlich",
    "volkstümlichen": "volkstümlich",
    "volkstümlicher": "volkstümlich",
    "volkstümliches": "volkstümlich",
    "volkswirtschaftliche": "volkswirtschaftlich",
    "volkswirtschaftlichem": "volkswirtschaftlich",
    "volkswirtschaftlichen": "volkswirtschaftlich",
    "volkswirtschaftlicher": "volkswirtschaftlich",
    "volkswirtschaftliches": "volkswirtschaftlich",
    "vollautomatische": "vollautomatisch",
    "vollautomatischem": "vollautomatisch",
    "vollautomatischen": "vollautomatisch",
    "vollautomatischer": "vollautomatisch",
    "vollautomatisches": "vollautomatisch",
    "vollaß": "vollessen",
    "vollaßen": "vollessen",
    "vollaßt": "vollessen",
    "vollberechtigte": "vollberechtigt",
    "vollberechtigtem": "vollberechtigt",
    "vollberechtigten": "vollberechtigt",
    "vollberechtigter": "vollberechtigt",
    "vollberechtigtes": "vollberechtigt",
    "vollblütigem": "vollblütig",
    "vollblütigen": "vollblütig",
    "vollblütiger": "vollblütig",
    "vollblütiges": "vollblütig",
    "vollbracht": "vollbringen",
    "vollbrachte": "vollbracht",
    "vollbrachtem": "vollbracht",
    "vollbrachten": "vollbracht",
    "vollbrachter": "vollbracht",
    "vollbrachtes": "vollbracht",
    "vollbrachtest": "vollbringen",
    "vollbrachtet": "vollbringen",
    "vollbringe": "vollbringen",
    "vollbringend": "vollbringen",
    "vollbringende": "vollbringend",
    "vollbringendem": "vollbringend",
    "vollbringenden": "vollbringend",
    "vollbringender": "vollbringend",
    "vollbringendes": "vollbringend",
    "vollbringest": "vollbringen",
    "vollbringet": "vollbringen",
    "vollbringst": "vollbringen",
    "vollbringt": "vollbringen",
    "vollbrächte": "vollbringen",
    "vollbrächten": "vollbringen",
    "vollbrächtest": "vollbringen",
    "vollbrächtet": "vollbringen",
    "vollbusige": "vollbusig",
    "vollbusigem": "vollbusig",
    "vollbusigen": "vollbusig",
    "vollbusiger": "vollbusig",
    "vollbusigere": "vollbusig",
    "vollbusigerem": "vollbusig",
    "vollbusigeren": "vollbusig",
    "vollbusigerer": "vollbusig",
    "vollbusigeres": "vollbusig",
    "vollbusiges": "vollbusig",
    "vollbusigste": "vollbusig",
    "vollbusigstem": "vollbusig",
    "vollbusigsten": "vollbusig",
    "vollbusigster": "vollbusig",
    "vollbusigstes": "vollbusig",
    "volle": "voll",
    "vollem": "voll",
    "vollen": "voll",
    "vollende": "vollenden",
    "vollendend": "vollenden",
    "vollendende": "vollendend",
    "vollendendem": "vollendend",
    "vollendenden": "vollendend",
    "vollendender": "vollendend",
    "vollendendes": "vollendend",
    "vollendest": "vollenden",
    "vollendet": "vollenden",
    "vollendete": "vollenden",
    "vollendetem": "vollendet",
    "vollendeten": "vollenden",
    "vollendeter": "vollendet",
    "vollendetes": "vollendet",
    "vollendetest": "vollenden",
    "vollendetet": "vollenden",
    "voller": "voll",
    "vollere": "voll",
    "vollerem": "voll",
    "volleren": "voll",
    "vollerer": "voll",
    "volleres": "voll",
    "volles": "voll",
    "vollesse": "vollessen",
    "vollessend": "vollessen",
    "vollessende": "vollessend",
    "vollessendem": "vollessend",
    "vollessenden": "vollessend",
    "vollessender": "vollessend",
    "vollessendere": "vollessend",
    "vollessenderem": "vollessend",
    "vollessenderen": "vollessend",
    "vollessenderer": "vollessend",
    "vollessenderes": "vollessend",
    "vollessendes": "vollessend",
    "vollessendste": "vollessend",
    "vollessendstem": "vollessend",
    "vollessendsten": "vollessend",
    "vollessendster": "vollessend",
    "vollessendstes": "vollessend",
    "vollessest": "vollessen",
    "vollesset": "vollessen",
    "volleßt": "vollessen",
    "vollführe": "vollführen",
    "vollführend": "vollführen",
    "vollführende": "vollführend",
    "vollführendem": "vollführend",
    "vollführenden": "vollführend",
    "vollführender": "vollführend",
    "vollführendes": "vollführend",
    "vollführest": "vollführen",
    "vollführet": "vollführen",
    "vollführst": "vollführen",
    "vollführt": "vollführen",
    "vollführte": "vollführen",
    "vollführtem": "vollführt",
    "vollführten": "vollführen",
    "vollführter": "vollführt",
    "vollführtes": "vollführt",
    "vollführtest": "vollführen",
    "vollführtet": "vollführen",
    "vollfülle": "vollfüllen",
    "vollfüllend": "vollfüllen",
    "vollfüllende": "vollfüllend",
    "vollfüllendem": "vollfüllend",
    "vollfüllenden": "vollfüllend",
    "vollfüllender": "vollfüllend",
    "vollfüllendere": "vollfüllend",
    "vollfüllenderem": "vollfüllend",
    "vollfüllenderen": "vollfüllend",
    "vollfüllenderer": "vollfüllend",
    "vollfüllenderes": "vollfüllend",
    "vollfüllendes": "vollfüllend",
    "vollfüllendste": "vollfüllend",
    "vollfüllendstem": "vollfüllend",
    "vollfüllendsten": "vollfüllend",
    "vollfüllendster": "vollfüllend",
    "vollfüllendstes": "vollfüllend",
    "vollfüllest": "vollfüllen",
    "vollfüllet": "vollfüllen",
    "vollfüllst": "vollfüllen",
    "vollfüllt": "vollfüllen",
    "vollfüllte": "vollfüllen",
    "vollfüllten": "vollfüllen",
    "vollfülltest": "vollfüllen",
    "vollfülltet": "vollfüllen",
    "vollgefüllt": "vollfüllen",
    "vollgefüllte": "vollgefüllt",
    "vollgefülltem": "vollgefüllt",
    "vollgefüllten": "vollgefüllt",
    "vollgefüllter": "vollgefüllt",
    "vollgefülltere": "vollgefüllt",
    "vollgefüllterem": "vollgefüllt",
    "vollgefüllteren": "vollgefüllt",
    "vollgefüllterer": "vollgefüllt",
    "vollgefüllteres": "vollgefüllt",
    "vollgefülltes": "vollgefüllt",
    "vollgefüllteste": "vollgefüllt",
    "vollgefülltestem": "vollgefüllt",
    "vollgefülltesten": "vollgefüllt",
    "vollgefülltester": "vollgefüllt",
    "vollgefülltestes": "vollgefüllt",
    "vollgegessen": "vollessen",
    "vollgegessene": "vollgegessen",
    "vollgegessenem": "vollgegessen",
    "vollgegessenen": "vollgegessen",
    "vollgegessener": "vollgegessen",
    "vollgegessenere": "vollgegessen",
    "vollgegessenerem": "vollgegessen",
    "vollgegesseneren": "vollgegessen",
    "vollgegessenerer": "vollgegessen",
    "vollgegesseneres": "vollgegessen",
    "vollgegessenes": "vollgegessen",
    "vollgegessenste": "vollgegessen",
    "vollgegessenstem": "vollgegessen",
    "vollgegessensten": "vollgegessen",
    "vollgegessenster": "vollgegessen",
    "vollgegessenstes": "vollgegessen",
    "vollgegossen": "vollgießen",
    "vollgegossene": "vollgegossen",
    "vollgegossenem": "vollgegossen",
    "vollgegossenen": "vollgegossen",
    "vollgegossener": "vollgegossen",
    "vollgegossenes": "vollgegossen",
    "vollgekritzelt": "vollkritzeln",
    "vollgekritzelte": "vollgekritzelt",
    "vollgekritzeltem": "vollgekritzelt",
    "vollgekritzelten": "vollgekritzelt",
    "vollgekritzelter": "vollgekritzelt",
    "vollgekritzeltere": "vollgekritzelt",
    "vollgekritzelterem": "vollgekritzelt",
    "vollgekritzelteren": "vollgekritzelt",
    "vollgekritzelterer": "vollgekritzelt",
    "vollgekritzelteres": "vollgekritzelt",
    "vollgekritzeltes": "vollgekritzelt",
    "vollgekritzelteste": "vollgekritzelt",
    "vollgekritzeltestem": "vollgekritzelt",
    "vollgekritzeltesten": "vollgekritzelt",
    "vollgekritzeltester": "vollgekritzelt",
    "vollgekritzeltestes": "vollgekritzelt",
    "vollgelabert": "volllabern",
    "vollgelaberte": "vollgelabert",
    "vollgelabertem": "vollgelabert",
    "vollgelaberten": "vollgelabert",
    "vollgelaberter": "vollgelabert",
    "vollgelabertere": "vollgelabert",
    "vollgelaberterem": "vollgelabert",
    "vollgelaberteren": "vollgelabert",
    "vollgelaberterer": "vollgelabert",
    "vollgelaberteres": "vollgelabert",
    "vollgelabertes": "vollgelabert",
    "vollgelaberteste": "vollgelabert",
    "vollgelabertestem": "vollgelabert",
    "vollgelabertesten": "vollgelabert",
    "vollgelabertester": "vollgelabert",
    "vollgelabertestes": "vollgelabert",
    "vollgemacht": "vollmachen",
    "vollgemachte": "vollgemacht",
    "vollgemachtem": "vollgemacht",
    "vollgemachten": "vollgemacht",
    "vollgemachter": "vollgemacht",
    "vollgemachtes": "vollgemacht",
    "vollgemalt": "vollmalen",
    "vollgemalte": "vollgemalt",
    "vollgemaltem": "vollgemalt",
    "vollgemalten": "vollgemalt",
    "vollgemalter": "vollgemalt",
    "vollgemaltere": "vollgemalt",
    "vollgemalterem": "vollgemalt",
    "vollgemalteren": "vollgemalt",
    "vollgemalterer": "vollgemalt",
    "vollgemalteres": "vollgemalt",
    "vollgemaltes": "vollgemalt",
    "vollgemalteste": "vollgemalt",
    "vollgemaltestem": "vollgemalt",
    "vollgemaltesten": "vollgemalt",
    "vollgemaltester": "vollgemalt",
    "vollgemaltestes": "vollgemalt",
    "vollgepfropft": "vollpfropfen",
    "vollgepfropfte": "vollgepfropft",
    "vollgepfropftem": "vollgepfropft",
    "vollgepfropften": "vollgepfropft",
    "vollgepfropfter": "vollgepfropft",
    "vollgepfropftere": "vollgepfropft",
    "vollgepfropfterem": "vollgepfropft",
    "vollgepfropfteren": "vollgepfropft",
    "vollgepfropfterer": "vollgepfropft",
    "vollgepfropfteres": "vollgepfropft",
    "vollgepfropftes": "vollgepfropft",
    "vollgepfropfteste": "vollgepfropft",
    "vollgepfropftestem": "vollgepfropft",
    "vollgepfropftesten": "vollgepfropft",
    "vollgepfropftester": "vollgepfropft",
    "vollgepfropftestes": "vollgepfropft",
    "vollgequatscht": "vollquatschen",
    "vollgequatschte": "vollgequatscht",
    "vollgequatschtem": "vollgequatscht",
    "vollgequatschten": "vollgequatscht",
    "vollgequatschter": "vollgequatscht",
    "vollgequatschtere": "vollgequatscht",
    "vollgequatschterem": "vollgequatscht",
    "vollgequatschteren": "vollgequatscht",
    "vollgequatschterer": "vollgequatscht",
    "vollgequatschteres": "vollgequatscht",
    "vollgequatschtes": "vollgequatscht",
    "vollgequatschteste": "vollgequatscht",
    "vollgequatschtestem": "vollgequatscht",
    "vollgequatschtesten": "vollgequatscht",
    "vollgequatschtester": "vollgequatscht",
    "vollgequatschtestes": "vollgequatscht",
    "vollgeschlagen": "vollschlagen",
    "vollgeschlagene": "vollgeschlagen",
    "vollgeschlagenem": "vollgeschlagen",
    "vollgeschlagenen": "vollgeschlagen",
    "vollgeschlagener": "vollgeschlagen",
    "vollgeschlagenes": "vollgeschlagen",
    "vollgeschmiert": "vollschmieren",
    "vollgeschmierte": "vollgeschmiert",
    "vollgeschmiertem": "vollgeschmiert",
    "vollgeschmierten": "vollgeschmiert",
    "vollgeschmierter": "vollgeschmiert",
    "vollgeschmiertere": "vollgeschmiert",
    "vollgeschmierterem": "vollgeschmiert",
    "vollgeschmierteren": "vollgeschmiert",
    "vollgeschmierterer": "vollgeschmiert",
    "vollgeschmierteres": "vollgeschmiert",
    "vollgeschmiertes": "vollgeschmiert",
    "vollgeschmierteste": "vollgeschmiert",
    "vollgeschmiertestem": "vollgeschmiert",
    "vollgeschmiertesten": "vollgeschmiert",
    "vollgeschmiertester": "vollgeschmiert",
    "vollgeschmiertestes": "vollgeschmiert",
    "vollgeschrieben": "vollschreiben",
    "vollgeschriebene": "vollgeschrieben",
    "vollgeschriebenem": "vollgeschrieben",
    "vollgeschriebenen": "vollgeschrieben",
    "vollgeschriebener": "vollgeschrieben",
    "vollgeschriebenere": "vollgeschrieben",
    "vollgeschriebenerem": "vollgeschrieben",
    "vollgeschriebeneren": "vollgeschrieben",
    "vollgeschriebenerer": "vollgeschrieben",
    "vollgeschriebeneres": "vollgeschrieben",
    "vollgeschriebenes": "vollgeschrieben",
    "vollgeschriebenste": "vollgeschrieben",
    "vollgeschriebenstem": "vollgeschrieben",
    "vollgeschriebensten": "vollgeschrieben",
    "vollgeschriebenster": "vollgeschrieben",
    "vollgeschriebenstes": "vollgeschrieben",
    "vollgespritzt": "vollspritzen",
    "vollgespritzte": "vollgespritzt",
    "vollgespritztem": "vollgespritzt",
    "vollgespritzten": "vollgespritzt",
    "vollgespritzter": "vollgespritzt",
    "vollgespritztes": "vollgespritzt",
    "vollgestopft": "vollstopfen",
    "vollgestopfte": "vollgestopft",
    "vollgestopftem": "vollgestopft",
    "vollgestopften": "vollgestopft",
    "vollgestopfter": "vollgestopft",
    "vollgestopftere": "vollgestopft",
    "vollgestopfterem": "vollgestopft",
    "vollgestopfteren": "vollgestopft",
    "vollgestopfterer": "vollgestopft",
    "vollgestopfteres": "vollgestopft",
    "vollgestopftes": "vollgestopft",
    "vollgestopfteste": "vollgestopft",
    "vollgestopftestem": "vollgestopft",
    "vollgestopftesten": "vollgestopft",
    "vollgestopftester": "vollgestopft",
    "vollgestopftestes": "vollgestopft",
    "vollgetankt": "volltanken",
    "vollgetankte": "vollgetankt",
    "vollgetanktem": "vollgetankt",
    "vollgetankten": "vollgetankt",
    "vollgetankter": "vollgetankt",
    "vollgetanktere": "vollgetankt",
    "vollgetankterem": "vollgetankt",
    "vollgetankteren": "vollgetankt",
    "vollgetankterer": "vollgetankt",
    "vollgetankteres": "vollgetankt",
    "vollgetanktes": "vollgetankt",
    "vollgetankteste": "vollgetankt",
    "vollgetanktestem": "vollgetankt",
    "vollgetanktesten": "vollgetankt",
    "vollgetanktester": "vollgetankt",
    "vollgetanktestes": "vollgetankt",
    "vollgieße": "vollgießen",
    "vollgießend": "vollgießen",
    "vollgießende": "vollgießend",
    "vollgießendem": "vollgießend",
    "vollgießenden": "vollgießend",
    "vollgießender": "vollgießend",
    "vollgießendes": "vollgießend",
    "vollgießest": "vollgießen",
    "vollgießet": "vollgießen",
    "vollgießt": "vollgießen",
    "vollgossen": "vollgießen",
    "vollgoß": "vollgießen",
    "vollgoßt": "vollgießen",
    "vollgösse": "vollgießen",
    "vollgössen": "vollgießen",
    "vollgössest": "vollgießen",
    "vollgösset": "vollgießen",
    "vollißt": "vollessen",
    "volljährige": "volljährig",
    "volljährigem": "volljährig",
    "volljährigen": "volljährig",
    "volljähriger": "volljährig",
    "volljähriges": "volljährig",
    "vollkommene": "vollkommen",
    "vollkommenem": "vollkommen",
    "vollkommenen": "vollkommen",
    "vollkommener": "vollkommen",
    "vollkommenere": "vollkommen",
    "vollkommenerem": "vollkommen",
    "vollkommeneren": "vollkommen",
    "vollkommenerer": "vollkommen",
    "vollkommeneres": "vollkommen",
    "vollkommenes": "vollkommen",
    "vollkommenste": "vollkommen",
    "vollkommenstem": "vollkommen",
    "vollkommensten": "vollkommen",
    "vollkommenster": "vollkommen",
    "vollkommenstes": "vollkommen",
    "vollkritzele": "vollkritzeln",
    "vollkritzelnd": "vollkritzeln",
    "vollkritzelnde": "vollkritzelnd",
    "vollkritzelndem": "vollkritzelnd",
    "vollkritzelnden": "vollkritzelnd",
    "vollkritzelnder": "vollkritzelnd",
    "vollkritzelndere": "vollkritzelnd",
    "vollkritzelnderem": "vollkritzelnd",
    "vollkritzelnderen": "vollkritzelnd",
    "vollkritzelnderer": "vollkritzelnd",
    "vollkritzelnderes": "vollkritzelnd",
    "vollkritzelndes": "vollkritzelnd",
    "vollkritzelndste": "vollkritzelnd",
    "vollkritzelndstem": "vollkritzelnd",
    "vollkritzelndsten": "vollkritzelnd",
    "vollkritzelndster": "vollkritzelnd",
    "vollkritzelndstes": "vollkritzelnd",
    "vollkritzelst": "vollkritzeln",
    "vollkritzelt": "vollkritzeln",
    "vollkritzelte": "vollkritzeln",
    "vollkritzelten": "vollkritzeln",
    "vollkritzeltest": "vollkritzeln",
    "vollkritzeltet": "vollkritzeln",
    "vollkritzle": "vollkritzeln",
    "volllabere": "volllabern",
    "volllabernd": "volllabern",
    "volllabernde": "volllabernd",
    "volllaberndem": "volllabernd",
    "volllabernden": "volllabernd",
    "volllabernder": "volllabernd",
    "volllaberndere": "volllabernd",
    "volllabernderem": "volllabernd",
    "volllabernderen": "volllabernd",
    "volllabernderer": "volllabernd",
    "volllabernderes": "volllabernd",
    "volllaberndes": "volllabernd",
    "volllaberndste": "volllabernd",
    "volllaberndstem": "volllabernd",
    "volllaberndsten": "volllabernd",
    "volllaberndster": "volllabernd",
    "volllaberndstes": "volllabernd",
    "volllaberst": "volllabern",
    "volllabert": "volllabern",
    "volllaberte": "volllabern",
    "volllaberten": "volllabern",
    "volllabertest": "volllabern",
    "volllabertet": "volllabern",
    "vollmache": "vollmachen",
    "vollmachend": "vollmachen",
    "vollmachende": "vollmachend",
    "vollmachendem": "vollmachend",
    "vollmachenden": "vollmachend",
    "vollmachender": "vollmachend",
    "vollmachendes": "vollmachend",
    "vollmachest": "vollmachen",
    "vollmachet": "vollmachen",
    "vollmachst": "vollmachen",
    "vollmacht": "vollmachen",
    "vollmachte": "vollmachen",
    "vollmachten": "vollmachen",
    "vollmachtest": "vollmachen",
    "vollmachtet": "vollmachen",
    "vollmale": "vollmalen",
    "vollmalend": "vollmalen",
    "vollmalende": "vollmalend",
    "vollmalendem": "vollmalend",
    "vollmalenden": "vollmalend",
    "vollmalender": "vollmalend",
    "vollmalendes": "vollmalend",
    "vollmalest": "vollmalen",
    "vollmalet": "vollmalen",
    "vollmalst": "vollmalen",
    "vollmalt": "vollmalen",
    "vollmalte": "vollmalen",
    "vollmalten": "vollmalen",
    "vollmaltest": "vollmalen",
    "vollmaltet": "vollmalen",
    "vollmundigem": "vollmundig",
    "vollmundigen": "vollmundig",
    "vollmundiger": "vollmundig",
    "vollmundigere": "vollmundig",
    "vollmundigerem": "vollmundig",
    "vollmundigeren": "vollmundig",
    "vollmundigerer": "vollmundig",
    "vollmundigeres": "vollmundig",
    "vollmundiges": "vollmundig",
    "vollmundigste": "vollmundig",
    "vollmundigstem": "vollmundig",
    "vollmundigsten": "vollmundig",
    "vollmundigster": "vollmundig",
    "vollmundigstes": "vollmundig",
    "vollpfropfe": "vollpfropfen",
    "vollpfropfend": "vollpfropfen",
    "vollpfropfende": "vollpfropfend",
    "vollpfropfendem": "vollpfropfend",
    "vollpfropfenden": "vollpfropfend",
    "vollpfropfender": "vollpfropfend",
    "vollpfropfendere": "vollpfropfend",
    "vollpfropfenderem": "vollpfropfend",
    "vollpfropfenderen": "vollpfropfend",
    "vollpfropfenderer": "vollpfropfend",
    "vollpfropfenderes": "vollpfropfend",
    "vollpfropfendes": "vollpfropfend",
    "vollpfropfendste": "vollpfropfend",
    "vollpfropfendstem": "vollpfropfend",
    "vollpfropfendsten": "vollpfropfend",
    "vollpfropfendster": "vollpfropfend",
    "vollpfropfendstes": "vollpfropfend",
    "vollpfropfest": "vollpfropfen",
    "vollpfropfet": "vollpfropfen",
    "vollpfropfst": "vollpfropfen",
    "vollpfropft": "vollpfropfen",
    "vollpfropfte": "vollpfropfen",
    "vollpfropften": "vollpfropfen",
    "vollpfropftest": "vollpfropfen",
    "vollpfropftet": "vollpfropfen",
    "vollquatsche": "vollquatschen",
    "vollquatschend": "vollquatschen",
    "vollquatschende": "vollquatschend",
    "vollquatschendem": "vollquatschend",
    "vollquatschenden": "vollquatschend",
    "vollquatschender": "vollquatschend",
    "vollquatschendere": "vollquatschend",
    "vollquatschenderem": "vollquatschend",
    "vollquatschenderen": "vollquatschend",
    "vollquatschenderer": "vollquatschend",
    "vollquatschenderes": "vollquatschend",
    "vollquatschendes": "vollquatschend",
    "vollquatschendste": "vollquatschend",
    "vollquatschendstem": "vollquatschend",
    "vollquatschendsten": "vollquatschend",
    "vollquatschendster": "vollquatschend",
    "vollquatschendstes": "vollquatschend",
    "vollquatschest": "vollquatschen",
    "vollquatschet": "vollquatschen",
    "vollquatschst": "vollquatschen",
    "vollquatscht": "vollquatschen",
    "vollquatschte": "vollquatschen",
    "vollquatschten": "vollquatschen",
    "vollquatschtest": "vollquatschen",
    "vollquatschtet": "vollquatschen",
    "vollschlage": "vollschlagen",
    "vollschlagend": "vollschlagen",
    "vollschlagende": "vollschlagend",
    "vollschlagendem": "vollschlagend",
    "vollschlagenden": "vollschlagend",
    "vollschlagender": "vollschlagend",
    "vollschlagendes": "vollschlagend",
    "vollschlagest": "vollschlagen",
    "vollschlaget": "vollschlagen",
    "vollschlagt": "vollschlagen",
    "vollschlanke": "vollschlank",
    "vollschlankem": "vollschlank",
    "vollschlanken": "vollschlank",
    "vollschlanker": "vollschlank",
    "vollschlankere": "vollschlank",
    "vollschlankerem": "vollschlank",
    "vollschlankeren": "vollschlank",
    "vollschlankerer": "vollschlank",
    "vollschlankeres": "vollschlank",
    "vollschlankes": "vollschlank",
    "vollschlankeste": "vollschlank",
    "vollschlankestem": "vollschlank",
    "vollschlankesten": "vollschlank",
    "vollschlankester": "vollschlank",
    "vollschlankestes": "vollschlank",
    "vollschlug": "vollschlagen",
    "vollschlugen": "vollschlagen",
    "vollschlugst": "vollschlagen",
    "vollschlugt": "vollschlagen",
    "vollschlägst": "vollschlagen",
    "vollschlägt": "vollschlagen",
    "vollschlüge": "vollschlagen",
    "vollschlügen": "vollschlagen",
    "vollschlügest": "vollschlagen",
    "vollschlüget": "vollschlagen",
    "vollschmiere": "vollschmieren",
    "vollschmierend": "vollschmieren",
    "vollschmierende": "vollschmierend",
    "vollschmierendem": "vollschmierend",
    "vollschmierenden": "vollschmierend",
    "vollschmierender": "vollschmierend",
    "vollschmierendere": "vollschmierend",
    "vollschmierenderem": "vollschmierend",
    "vollschmierenderen": "vollschmierend",
    "vollschmierenderer": "vollschmierend",
    "vollschmierenderes": "vollschmierend",
    "vollschmierendes": "vollschmierend",
    "vollschmierendste": "vollschmierend",
    "vollschmierendstem": "vollschmierend",
    "vollschmierendsten": "vollschmierend",
    "vollschmierendster": "vollschmierend",
    "vollschmierendstes": "vollschmierend",
    "vollschmierest": "vollschmieren",
    "vollschmieret": "vollschmieren",
    "vollschmierst": "vollschmieren",
    "vollschmiert": "vollschmieren",
    "vollschmierte": "vollschmieren",
    "vollschmierten": "vollschmieren",
    "vollschmiertest": "vollschmieren",
    "vollschmiertet": "vollschmieren",
    "vollschreibe": "vollschreiben",
    "vollschreibend": "vollschreiben",
    "vollschreibende": "vollschreibend",
    "vollschreibendem": "vollschreibend",
    "vollschreibenden": "vollschreibend",
    "vollschreibender": "vollschreibend",
    "vollschreibendes": "vollschreibend",
    "vollschreibest": "vollschreiben",
    "vollschreibet": "vollschreiben",
    "vollschreibst": "vollschreiben",
    "vollschreibt": "vollschreiben",
    "vollschrieb": "vollschreiben",
    "vollschriebe": "vollschreiben",
    "vollschrieben": "vollschreiben",
    "vollschriebest": "vollschreiben",
    "vollschriebet": "vollschreiben",
    "vollschriebst": "vollschreiben",
    "vollschriebt": "vollschreiben",
    "vollspritze": "vollspritzen",
    "vollspritzend": "vollspritzen",
    "vollspritzende": "vollspritzend",
    "vollspritzendem": "vollspritzend",
    "vollspritzenden": "vollspritzend",
    "vollspritzender": "vollspritzend",
    "vollspritzendes": "vollspritzend",
    "vollspritzest": "vollspritzen",
    "vollspritzet": "vollspritzen",
    "vollspritzt": "vollspritzen",
    "vollspritzte": "vollspritzen",
    "vollspritzten": "vollspritzen",
    "vollspritztest": "vollspritzen",
    "vollspritztet": "vollspritzen",
    "vollste": "voll",
    "vollstem": "voll",
    "vollsten": "voll",
    "vollster": "voll",
    "vollstes": "voll",
    "vollstopfe": "vollstopfen",
    "vollstopfend": "vollstopfen",
    "vollstopfende": "vollstopfend",
    "vollstopfendem": "vollstopfend",
    "vollstopfenden": "vollstopfend",
    "vollstopfender": "vollstopfend",
    "vollstopfendes": "vollstopfend",
    "vollstopfest": "vollstopfen",
    "vollstopfet": "vollstopfen",
    "vollstopfst": "vollstopfen",
    "vollstopft": "vollstopfen",
    "vollstopfte": "vollstopfen",
    "vollstopften": "vollstopfen",
    "vollstopftest": "vollstopfen",
    "vollstopftet": "vollstopfen",
    "vollständige": "vollständig",
    "vollständigem": "vollständig",
    "vollständigen": "vollständig",
    "vollständiger": "vollständig",
    "vollständigere": "vollständig",
    "vollständigerem": "vollständig",
    "vollständigeren": "vollständig",
    "vollständigerer": "vollständig",
    "vollständigeres": "vollständig",
    "vollständiges": "vollständig",
    "vollständigste": "vollständig",
    "vollständigstem": "vollständig",
    "vollständigsten": "vollständig",
    "vollständigster": "vollständig",
    "vollständigstes": "vollständig",
    "volltanke": "volltanken",
    "volltankend": "volltanken",
    "volltankende": "volltankend",
    "volltankendem": "volltankend",
    "volltankenden": "volltankend",
    "volltankender": "volltankend",
    "volltankendere": "volltankend",
    "volltankenderem": "volltankend",
    "volltankenderen": "volltankend",
    "volltankenderer": "volltankend",
    "volltankenderes": "volltankend",
    "volltankendes": "volltankend",
    "volltankendste": "volltankend",
    "volltankendstem": "volltankend",
    "volltankendsten": "volltankend",
    "volltankendster": "volltankend",
    "volltankendstes": "volltankend",
    "volltankest": "volltanken",
    "volltanket": "volltanken",
    "volltankst": "volltanken",
    "volltankt": "volltanken",
    "volltankte": "volltanken",
    "volltankten": "volltanken",
    "volltanktest": "volltanken",
    "volltanktet": "volltanken",
    "volltrunkenem": "volltrunken",
    "volltrunkenen": "volltrunken",
    "volltrunkener": "volltrunken",
    "volltrunkenes": "volltrunken",
    "vollwertigem": "vollwertig",
    "vollwertigen": "vollwertig",
    "vollwertiger": "vollwertig",
    "vollwertigere": "vollwertig",
    "vollwertigerem": "vollwertig",
    "vollwertigeren": "vollwertig",
    "vollwertigerer": "vollwertig",
    "vollwertigeres": "vollwertig",
    "vollwertiges": "vollwertig",
    "vollwertigste": "vollwertig",
    "vollwertigstem": "vollwertig",
    "vollwertigsten": "vollwertig",
    "vollwertigster": "vollwertig",
    "vollwertigstes": "vollwertig",
    "vollziehe": "vollziehen",
    "vollziehend": "vollziehen",
    "vollziehende": "vollziehend",
    "vollziehendem": "vollziehend",
    "vollziehenden": "vollziehend",
    "vollziehender": "vollziehend",
    "vollziehendes": "vollziehend",
    "vollziehest": "vollziehen",
    "vollziehet": "vollziehen",
    "vollziehst": "vollziehen",
    "vollzieht": "vollziehen",
    "vollzog": "vollziehen",
    "vollzogen": "vollziehen",
    "vollzogene": "vollzogen",
    "vollzogenem": "vollzogen",
    "vollzogenen": "vollzogen",
    "vollzogener": "vollzogen",
    "vollzogenes": "vollzogen",
    "vollzogst": "vollziehen",
    "vollzogt": "vollziehen",
    "vollzuessen": "vollessen",
    "vollzufüllen": "vollfüllen",
    "vollzugießen": "vollgießen",
    "vollzukritzeln": "vollkritzeln",
    "vollzulabern": "volllabern",
    "vollzumachen": "vollmachen",
    "vollzumalen": "vollmalen",
    "vollzupfropfen": "vollpfropfen",
    "vollzuquatschen": "vollquatschen",
    "vollzuschlagen": "vollschlagen",
    "vollzuschmieren": "vollschmieren",
    "vollzuschreiben": "vollschreiben",
    "vollzuspritzen": "vollspritzen",
    "vollzustopfen": "vollstopfen",
    "vollzutanken": "volltanken",
    "vollzählige": "vollzählig",
    "vollzähligem": "vollzählig",
    "vollzähligen": "vollzählig",
    "vollzähliger": "vollzählig",
    "vollzähliges": "vollzählig",
    "vollzöge": "vollziehen",
    "vollzögen": "vollziehen",
    "vollzögest": "vollziehen",
    "vollzöget": "vollziehen",
    "volläße": "vollessen",
    "volläßen": "vollessen",
    "volläßest": "vollessen",
    "volläßet": "vollessen",
    "voluminösem": "voluminös",
    "voluminösen": "voluminös",
    "voluminöser": "voluminös",
    "voluminösere": "voluminös",
    "voluminöserem": "voluminös",
    "voluminöseren": "voluminös",
    "voluminöserer": "voluminös",
    "voluminöseres": "voluminös",
    "voluminöses": "voluminös",
    "voluminöseste": "voluminös",
    "voluminösestem": "voluminös",
    "voluminösesten": "voluminös",
    "voluminösester": "voluminös",
    "voluminösestes": "voluminös",
    "voranbrachte": "voranbringen",
    "voranbrachten": "voranbringen",
    "voranbrachtest": "voranbringen",
    "voranbrachtet": "voranbringen",
    "voranbringe": "voranbringen",
    "voranbringend": "voranbringen",
    "voranbringende": "voranbringend",
    "voranbringendem": "voranbringend",
    "voranbringenden": "voranbringend",
    "voranbringender": "voranbringend",
    "voranbringendere": "voranbringend",
    "voranbringenderem": "voranbringend",
    "voranbringenderen": "voranbringend",
    "voranbringenderer": "voranbringend",
    "voranbringenderes": "voranbringend",
    "voranbringendes": "voranbringend",
    "voranbringendste": "voranbringend",
    "voranbringendstem": "voranbringend",
    "voranbringendsten": "voranbringend",
    "voranbringendster": "voranbringend",
    "voranbringendstes": "voranbringend",
    "voranbringest": "voranbringen",
    "voranbringet": "voranbringen",
    "voranbringst": "voranbringen",
    "voranbringt": "voranbringen",
    "voranbrächte": "voranbringen",
    "voranbrächten": "voranbringen",
    "voranbrächtest": "voranbringen",
    "voranbrächtet": "voranbringen",
    "vorangebracht": "voranbringen",
    "vorangebrachte": "vorangebracht",
    "vorangebrachtem": "vorangebracht",
    "vorangebrachten": "vorangebracht",
    "vorangebrachter": "vorangebracht",
    "vorangebrachtes": "vorangebracht",
    "vorangegangen": "vorangehen",
    "vorangegangene": "vorangegangen",
    "vorangegangenem": "vorangegangen",
    "vorangegangenen": "vorangegangen",
    "vorangegangener": "vorangegangen",
    "vorangegangenes": "vorangegangen",
    "vorangehe": "vorangehen",
    "vorangehend": "vorangehen",
    "vorangehende": "vorangehend",
    "vorangehendem": "vorangehend",
    "vorangehenden": "vorangehend",
    "vorangehender": "vorangehend",
    "vorangehendes": "vorangehend",
    "vorangehest": "vorangehen",
    "vorangehet": "vorangehen",
    "vorangehst": "vorangehen",
    "vorangeht": "vorangehen",
    "voranging": "vorangehen",
    "voranginge": "vorangehen",
    "vorangingen": "vorangehen",
    "vorangingest": "vorangehen",
    "voranginget": "vorangehen",
    "vorangingst": "vorangehen",
    "vorangingt": "vorangehen",
    "voranzubringen": "voranbringen",
    "voranzugehen": "vorangehen",
    "vorarbeite": "vorarbeiten",
    "vorarbeitend": "vorarbeiten",
    "vorarbeitende": "vorarbeitend",
    "vorarbeitendem": "vorarbeitend",
    "vorarbeitenden": "vorarbeitend",
    "vorarbeitender": "vorarbeitend",
    "vorarbeitendes": "vorarbeitend",
    "vorarbeitest": "vorarbeiten",
    "vorarbeitet": "vorarbeiten",
    "vorarbeitete": "vorarbeiten",
    "vorarbeiteten": "vorarbeiten",
    "vorarbeitetest": "vorarbeiten",
    "vorarbeitetet": "vorarbeiten",
    "vorausblicke": "vorausblicken",
    "vorausblickend": "vorausblicken",
    "vorausblickende": "vorausblickend",
    "vorausblickendem": "vorausblickend",
    "vorausblickenden": "vorausblickend",
    "vorausblickender": "vorausblickend",
    "vorausblickendere": "vorausblickend",
    "vorausblickenderem": "vorausblickend",
    "vorausblickenderen": "vorausblickend",
    "vorausblickenderer": "vorausblickend",
    "vorausblickenderes": "vorausblickend",
    "vorausblickendes": "vorausblickend",
    "vorausblickendste": "vorausblickend",
    "vorausblickendstem": "vorausblickend",
    "vorausblickendsten": "vorausblickend",
    "vorausblickendster": "vorausblickend",
    "vorausblickendstes": "vorausblickend",
    "vorausblickest": "vorausblicken",
    "vorausblicket": "vorausblicken",
    "vorausblickst": "vorausblicken",
    "vorausblickt": "vorausblicken",
    "vorausblickte": "vorausblicken",
    "vorausblickten": "vorausblicken",
    "vorausblicktest": "vorausblicken",
    "vorausblicktet": "vorausblicken",
    "vorausgeblickt": "vorausblicken",
    "vorausgeblickte": "vorausgeblickt",
    "vorausgeblicktem": "vorausgeblickt",
    "vorausgeblickten": "vorausgeblickt",
    "vorausgeblickter": "vorausgeblickt",
    "vorausgeblicktes": "vorausgeblickt",
    "vorausgegangen": "vorausgehen",
    "vorausgegangene": "vorausgegangen",
    "vorausgegangenem": "vorausgegangen",
    "vorausgegangenen": "vorausgegangen",
    "vorausgegangener": "vorausgegangen",
    "vorausgegangenes": "vorausgegangen",
    "vorausgehe": "vorausgehen",
    "vorausgehend": "vorausgehen",
    "vorausgehende": "vorausgehend",
    "vorausgehendem": "vorausgehend",
    "vorausgehenden": "vorausgehend",
    "vorausgehender": "vorausgehend",
    "vorausgehendes": "vorausgehend",
    "vorausgehest": "vorausgehen",
    "vorausgehet": "vorausgehen",
    "vorausgehst": "vorausgehen",
    "vorausgeht": "vorausgehen",
    "vorausgesagt": "voraussagen",
    "vorausgesagte": "vorausgesagt",
    "vorausgesagtem": "vorausgesagt",
    "vorausgesagten": "vorausgesagt",
    "vorausgesagter": "vorausgesagt",
    "vorausgesagtes": "vorausgesagt",
    "vorausgeschaut": "vorausschauen",
    "vorausgeschaute": "vorausgeschaut",
    "vorausgeschautem": "vorausgeschaut",
    "vorausgeschauten": "vorausgeschaut",
    "vorausgeschauter": "vorausgeschaut",
    "vorausgeschautes": "vorausgeschaut",
    "vorausgesehen": "voraussehen",
    "vorausgesehene": "vorausgesehen",
    "vorausgesehenem": "vorausgesehen",
    "vorausgesehenen": "vorausgesehen",
    "vorausgesehener": "vorausgesehen",
    "vorausgesehenes": "vorausgesehen",
    "vorausgesetzt": "voraussetzen",
    "vorausgesetzte": "vorausgesetzt",
    "vorausgesetztem": "vorausgesetzt",
    "vorausgesetzten": "vorausgesetzt",
    "vorausgesetzter": "vorausgesetzt",
    "vorausgesetztes": "vorausgesetzt",
    "vorausging": "vorausgehen",
    "vorausginge": "vorausgehen",
    "vorausgingen": "vorausgehen",
    "vorausgingest": "vorausgehen",
    "vorausginget": "vorausgehen",
    "vorausgingst": "vorausgehen",
    "vorausgingt": "vorausgehen",
    "voraussage": "voraussagen",
    "voraussagend": "voraussagen",
    "voraussagende": "voraussagend",
    "voraussagendem": "voraussagend",
    "voraussagenden": "voraussagend",
    "voraussagender": "voraussagend",
    "voraussagendes": "voraussagend",
    "voraussagest": "voraussagen",
    "voraussaget": "voraussagen",
    "voraussagst": "voraussagen",
    "voraussagt": "voraussagen",
    "voraussagte": "voraussagen",
    "voraussagten": "voraussagen",
    "voraussagtest": "voraussagen",
    "voraussagtet": "voraussagen",
    "voraussah": "voraussehen",
    "voraussahen": "voraussehen",
    "voraussahst": "voraussehen",
    "voraussaht": "voraussehen",
    "vorausschaue": "vorausschauen",
    "vorausschauend": "vorausschauen",
    "vorausschauende": "vorausschauend",
    "vorausschauendem": "vorausschauend",
    "vorausschauenden": "vorausschauend",
    "vorausschauender": "vorausschauend",
    "vorausschauendere": "vorausschauend",
    "vorausschauenderem": "vorausschauend",
    "vorausschauenderen": "vorausschauend",
    "vorausschauenderer": "vorausschauend",
    "vorausschauenderes": "vorausschauend",
    "vorausschauendes": "vorausschauend",
    "vorausschauendste": "vorausschauend",
    "vorausschauendstem": "vorausschauend",
    "vorausschauendsten": "vorausschauend",
    "vorausschauendster": "vorausschauend",
    "vorausschauendstes": "vorausschauend",
    "vorausschauest": "vorausschauen",
    "vorausschauet": "vorausschauen",
    "vorausschaust": "vorausschauen",
    "vorausschaut": "vorausschauen",
    "vorausschaute": "vorausschauen",
    "vorausschauten": "vorausschauen",
    "vorausschautest": "vorausschauen",
    "vorausschautet": "vorausschauen",
    "voraussehe": "voraussehen",
    "voraussehend": "voraussehen",
    "voraussehende": "voraussehend",
    "voraussehendem": "voraussehend",
    "voraussehenden": "voraussehend",
    "voraussehender": "voraussehend",
    "voraussehendes": "voraussehend",
    "voraussehest": "voraussehen",
    "voraussehet": "voraussehen",
    "vorausseht": "voraussehen",
    "voraussetze": "voraussetzen",
    "voraussetzend": "voraussetzen",
    "voraussetzende": "voraussetzend",
    "voraussetzendem": "voraussetzend",
    "voraussetzenden": "voraussetzend",
    "voraussetzender": "voraussetzend",
    "voraussetzendes": "voraussetzend",
    "voraussetzest": "voraussetzen",
    "voraussetzet": "voraussetzen",
    "voraussetzt": "voraussetzen",
    "voraussetzte": "voraussetzen",
    "voraussetzten": "voraussetzen",
    "voraussetztest": "voraussetzen",
    "voraussetztet": "voraussetzen",
    "voraussichtlichem": "voraussichtlich",
    "voraussichtlichen": "voraussichtlich",
    "voraussichtlicher": "voraussichtlich",
    "voraussichtliches": "voraussichtlich",
    "voraussiehst": "voraussehen",
    "voraussieht": "voraussehen",
    "voraussähe": "voraussehen",
    "voraussähen": "voraussehen",
    "voraussähest": "voraussehen",
    "voraussähet": "voraussehen",
    "vorauszublicken": "vorausblicken",
    "vorauszugehen": "vorausgehen",
    "vorauszusagen": "voraussagen",
    "vorauszuschauen": "vorausschauen",
    "vorauszusehen": "voraussehen",
    "vorauszusetzen": "voraussetzen",
    "vorband": "vorbinden",
    "vorbanden": "vorbinden",
    "vorbandest": "vorbinden",
    "vorbandet": "vorbinden",
    "vorbaue": "vorbauen",
    "vorbauend": "vorbauen",
    "vorbauende": "vorbauend",
    "vorbauendem": "vorbauend",
    "vorbauenden": "vorbauend",
    "vorbauender": "vorbauend",
    "vorbauendes": "vorbauend",
    "vorbauest": "vorbauen",
    "vorbauet": "vorbauen",
    "vorbaust": "vorbauen",
    "vorbaut": "vorbauen",
    "vorbaute": "vorbauen",
    "vorbauten": "vorbauen",
    "vorbautest": "vorbauen",
    "vorbautet": "vorbauen",
    "vorbehaltend": "vorbehalten",
    "vorbehaltende": "vorbehaltend",
    "vorbehaltendem": "vorbehaltend",
    "vorbehaltenden": "vorbehaltend",
    "vorbehaltender": "vorbehaltend",
    "vorbehaltendes": "vorbehaltend",
    "vorbehaltene": "vorbehalten",
    "vorbehaltenem": "vorbehalten",
    "vorbehaltenen": "vorbehalten",
    "vorbehaltener": "vorbehalten",
    "vorbehaltenes": "vorbehalten",
    "vorbehaltest": "vorbehalten",
    "vorbehaltet": "vorbehalten",
    "vorbehaltlose": "vorbehaltlos",
    "vorbehaltlosem": "vorbehaltlos",
    "vorbehaltlosen": "vorbehaltlos",
    "vorbehaltloser": "vorbehaltlos",
    "vorbehaltloses": "vorbehaltlos",
    "vorbehandele": "vorbehandeln",
    "vorbehandelnd": "vorbehandeln",
    "vorbehandelnde": "vorbehandelnd",
    "vorbehandelndem": "vorbehandelnd",
    "vorbehandelnden": "vorbehandelnd",
    "vorbehandelnder": "vorbehandelnd",
    "vorbehandelndes": "vorbehandelnd",
    "vorbehandelst": "vorbehandeln",
    "vorbehandelt": "vorbehandeln",
    "vorbehandelte": "vorbehandeln",
    "vorbehandeltem": "vorbehandelt",
    "vorbehandelten": "vorbehandeln",
    "vorbehandelter": "vorbehandelt",
    "vorbehandeltes": "vorbehandelt",
    "vorbehandeltest": "vorbehandeln",
    "vorbehandeltet": "vorbehandeln",
    "vorbehandle": "vorbehandeln",
    "vorbehielt": "vorbehalten",
    "vorbehielte": "vorbehalten",
    "vorbehielten": "vorbehalten",
    "vorbehieltest": "vorbehalten",
    "vorbehieltet": "vorbehalten",
    "vorbehält": "vorbehalten",
    "vorbehältst": "vorbehalten",
    "vorbeibenahm": "vorbeibenehmen",
    "vorbeibenahmen": "vorbeibenehmen",
    "vorbeibenahmst": "vorbeibenehmen",
    "vorbeibenahmt": "vorbeibenehmen",
    "vorbeibenehme": "vorbeibenehmen",
    "vorbeibenehmend": "vorbeibenehmen",
    "vorbeibenehmende": "vorbeibenehmend",
    "vorbeibenehmendem": "vorbeibenehmend",
    "vorbeibenehmenden": "vorbeibenehmend",
    "vorbeibenehmender": "vorbeibenehmend",
    "vorbeibenehmendes": "vorbeibenehmend",
    "vorbeibenehmest": "vorbeibenehmen",
    "vorbeibenehmet": "vorbeibenehmen",
    "vorbeibenehmt": "vorbeibenehmen",
    "vorbeibenimmst": "vorbeibenehmen",
    "vorbeibenimmt": "vorbeibenehmen",
    "vorbeibenommen": "vorbeibenehmen",
    "vorbeibenommene": "vorbeibenommen",
    "vorbeibenommenem": "vorbeibenommen",
    "vorbeibenommenen": "vorbeibenommen",
    "vorbeibenommener": "vorbeibenommen",
    "vorbeibenommenes": "vorbeibenommen",
    "vorbeibenähme": "vorbeibenehmen",
    "vorbeibenähmen": "vorbeibenehmen",
    "vorbeibenähmest": "vorbeibenehmen",
    "vorbeibenähmet": "vorbeibenehmen",
    "vorbeifahre": "vorbeifahren",
    "vorbeifahrend": "vorbeifahren",
    "vorbeifahrende": "vorbeifahrend",
    "vorbeifahrendem": "vorbeifahrend",
    "vorbeifahrenden": "vorbeifahrend",
    "vorbeifahrender": "vorbeifahrend",
    "vorbeifahrendes": "vorbeifahrend",
    "vorbeifahrest": "vorbeifahren",
    "vorbeifahret": "vorbeifahren",
    "vorbeifahrt": "vorbeifahren",
    "vorbeifliege": "vorbeifliegen",
    "vorbeifliegend": "vorbeifliegen",
    "vorbeifliegende": "vorbeifliegend",
    "vorbeifliegendem": "vorbeifliegend",
    "vorbeifliegenden": "vorbeifliegend",
    "vorbeifliegender": "vorbeifliegend",
    "vorbeifliegendes": "vorbeifliegend",
    "vorbeifliegest": "vorbeifliegen",
    "vorbeiflieget": "vorbeifliegen",
    "vorbeifliegst": "vorbeifliegen",
    "vorbeifliegt": "vorbeifliegen",
    "vorbeifließe": "vorbeifließen",
    "vorbeifließend": "vorbeifließen",
    "vorbeifließende": "vorbeifließend",
    "vorbeifließendem": "vorbeifließend",
    "vorbeifließenden": "vorbeifließend",
    "vorbeifließender": "vorbeifließend",
    "vorbeifließendes": "vorbeifließend",
    "vorbeifließest": "vorbeifließen",
    "vorbeifließet": "vorbeifließen",
    "vorbeifließt": "vorbeifließen",
    "vorbeiflog": "vorbeifliegen",
    "vorbeiflogen": "vorbeifliegen",
    "vorbeiflogst": "vorbeifliegen",
    "vorbeiflogt": "vorbeifliegen",
    "vorbeiflossen": "vorbeifließen",
    "vorbeifloß": "vorbeifließen",
    "vorbeifloßt": "vorbeifließen",
    "vorbeiflöge": "vorbeifliegen",
    "vorbeiflögen": "vorbeifliegen",
    "vorbeiflögest": "vorbeifliegen",
    "vorbeiflöget": "vorbeifliegen",
    "vorbeiflösse": "vorbeifließen",
    "vorbeiflössen": "vorbeifließen",
    "vorbeiflössest": "vorbeifließen",
    "vorbeiflösset": "vorbeifließen",
    "vorbeifuhr": "vorbeifahren",
    "vorbeifuhren": "vorbeifahren",
    "vorbeifuhrst": "vorbeifahren",
    "vorbeifuhrt": "vorbeifahren",
    "vorbeifährst": "vorbeifahren",
    "vorbeifährt": "vorbeifahren",
    "vorbeiführe": "vorbeiführen",
    "vorbeiführen": "vorbeifahren",
    "vorbeiführend": "vorbeiführen",
    "vorbeiführende": "vorbeiführend",
    "vorbeiführendem": "vorbeiführend",
    "vorbeiführenden": "vorbeiführend",
    "vorbeiführender": "vorbeiführend",
    "vorbeiführendes": "vorbeiführend",
    "vorbeiführest": "vorbeiführen",
    "vorbeiführet": "vorbeiführen",
    "vorbeiführst": "vorbeiführen",
    "vorbeiführt": "vorbeiführen",
    "vorbeiführte": "vorbeiführen",
    "vorbeiführten": "vorbeiführen",
    "vorbeiführtest": "vorbeiführen",
    "vorbeiführtet": "vorbeiführen",
    "vorbeigefahren": "vorbeifahren",
    "vorbeigefahrene": "vorbeigefahren",
    "vorbeigefahrenem": "vorbeigefahren",
    "vorbeigefahrenen": "vorbeigefahren",
    "vorbeigefahrener": "vorbeigefahren",
    "vorbeigefahrenes": "vorbeigefahren",
    "vorbeigeflogen": "vorbeifliegen",
    "vorbeigeflogene": "vorbeigeflogen",
    "vorbeigeflogenem": "vorbeigeflogen",
    "vorbeigeflogenen": "vorbeigeflogen",
    "vorbeigeflogener": "vorbeigeflogen",
    "vorbeigeflogenes": "vorbeigeflogen",
    "vorbeigeflossen": "vorbeifließen",
    "vorbeigeflossene": "vorbeigeflossen",
    "vorbeigeflossenem": "vorbeigeflossen",
    "vorbeigeflossenen": "vorbeigeflossen",
    "vorbeigeflossener": "vorbeigeflossen",
    "vorbeigeflossenes": "vorbeigeflossen",
    "vorbeigeführt": "vorbeiführen",
    "vorbeigeführte": "vorbeigeführt",
    "vorbeigeführtem": "vorbeigeführt",
    "vorbeigeführten": "vorbeigeführt",
    "vorbeigeführter": "vorbeigeführt",
    "vorbeigeführtes": "vorbeigeführt",
    "vorbeigegangen": "vorbeigehen",
    "vorbeigegangene": "vorbeigegangen",
    "vorbeigegangenem": "vorbeigegangen",
    "vorbeigegangenen": "vorbeigegangen",
    "vorbeigegangener": "vorbeigegangen",
    "vorbeigegangenes": "vorbeigegangen",
    "vorbeigehe": "vorbeigehen",
    "vorbeigehend": "vorbeigehen",
    "vorbeigehende": "vorbeigehend",
    "vorbeigehendem": "vorbeigehend",
    "vorbeigehenden": "vorbeigehend",
    "vorbeigehender": "vorbeigehend",
    "vorbeigehendes": "vorbeigehend",
    "vorbeigehest": "vorbeigehen",
    "vorbeigehet": "vorbeigehen",
    "vorbeigehst": "vorbeigehen",
    "vorbeigeht": "vorbeigehen",
    "vorbeigekommen": "vorbeikommen",
    "vorbeigekommene": "vorbeigekommen",
    "vorbeigekommenem": "vorbeigekommen",
    "vorbeigekommenen": "vorbeigekommen",
    "vorbeigekommener": "vorbeigekommen",
    "vorbeigekommenes": "vorbeigekommen",
    "vorbeigelassen": "vorbeilassen",
    "vorbeigelassene": "vorbeigelassen",
    "vorbeigelassenem": "vorbeigelassen",
    "vorbeigelassenen": "vorbeigelassen",
    "vorbeigelassener": "vorbeigelassen",
    "vorbeigelassenes": "vorbeigelassen",
    "vorbeigelaufen": "vorbeilaufen",
    "vorbeigelaufene": "vorbeigelaufen",
    "vorbeigelaufenem": "vorbeigelaufen",
    "vorbeigelaufenen": "vorbeigelaufen",
    "vorbeigelaufener": "vorbeigelaufen",
    "vorbeigelaufenes": "vorbeigelaufen",
    "vorbeigerannt": "vorbeirennen",
    "vorbeigerannte": "vorbeigerannt",
    "vorbeigeranntem": "vorbeigerannt",
    "vorbeigerannten": "vorbeigerannt",
    "vorbeigerannter": "vorbeigerannt",
    "vorbeigeranntes": "vorbeigerannt",
    "vorbeigeredet": "vorbeireden",
    "vorbeigeredete": "vorbeigeredet",
    "vorbeigeredetem": "vorbeigeredet",
    "vorbeigeredeten": "vorbeigeredet",
    "vorbeigeredeter": "vorbeigeredet",
    "vorbeigeredetes": "vorbeigeredet",
    "vorbeigeschossen": "vorbeischießen",
    "vorbeigeschossene": "vorbeigeschossen",
    "vorbeigeschossenem": "vorbeigeschossen",
    "vorbeigeschossenen": "vorbeigeschossen",
    "vorbeigeschossener": "vorbeigeschossen",
    "vorbeigeschossenes": "vorbeigeschossen",
    "vorbeigetroffen": "vorbeitreffen",
    "vorbeigetroffene": "vorbeigetroffen",
    "vorbeigetroffenem": "vorbeigetroffen",
    "vorbeigetroffenen": "vorbeigetroffen",
    "vorbeigetroffener": "vorbeigetroffen",
    "vorbeigetroffenes": "vorbeigetroffen",
    "vorbeiging": "vorbeigehen",
    "vorbeiginge": "vorbeigehen",
    "vorbeigingen": "vorbeigehen",
    "vorbeigingest": "vorbeigehen",
    "vorbeiginget": "vorbeigehen",
    "vorbeigingst": "vorbeigehen",
    "vorbeigingt": "vorbeigehen",
    "vorbeikam": "vorbeikommen",
    "vorbeikamen": "vorbeikommen",
    "vorbeikamst": "vorbeikommen",
    "vorbeikamt": "vorbeikommen",
    "vorbeikomme": "vorbeikommen",
    "vorbeikommend": "vorbeikommen",
    "vorbeikommende": "vorbeikommend",
    "vorbeikommendem": "vorbeikommend",
    "vorbeikommenden": "vorbeikommend",
    "vorbeikommender": "vorbeikommend",
    "vorbeikommendes": "vorbeikommend",
    "vorbeikommest": "vorbeikommen",
    "vorbeikommet": "vorbeikommen",
    "vorbeikommst": "vorbeikommen",
    "vorbeikommt": "vorbeikommen",
    "vorbeikäme": "vorbeikommen",
    "vorbeikämen": "vorbeikommen",
    "vorbeikämest": "vorbeikommen",
    "vorbeikämet": "vorbeikommen",
    "vorbeilasse": "vorbeilassen",
    "vorbeilassend": "vorbeilassen",
    "vorbeilassende": "vorbeilassend",
    "vorbeilassendem": "vorbeilassend",
    "vorbeilassenden": "vorbeilassend",
    "vorbeilassender": "vorbeilassend",
    "vorbeilassendes": "vorbeilassend",
    "vorbeilassest": "vorbeilassen",
    "vorbeilasset": "vorbeilassen",
    "vorbeilaufe": "vorbeilaufen",
    "vorbeilaufend": "vorbeilaufen",
    "vorbeilaufende": "vorbeilaufend",
    "vorbeilaufendem": "vorbeilaufend",
    "vorbeilaufenden": "vorbeilaufend",
    "vorbeilaufender": "vorbeilaufend",
    "vorbeilaufendes": "vorbeilaufend",
    "vorbeilaufest": "vorbeilaufen",
    "vorbeilaufet": "vorbeilaufen",
    "vorbeilauft": "vorbeilaufen",
    "vorbeilaßt": "vorbeilassen",
    "vorbeilief": "vorbeilaufen",
    "vorbeiliefe": "vorbeilaufen",
    "vorbeiliefen": "vorbeilaufen",
    "vorbeiliefest": "vorbeilaufen",
    "vorbeiliefet": "vorbeilaufen",
    "vorbeiliefst": "vorbeilaufen",
    "vorbeilieft": "vorbeilaufen",
    "vorbeiließ": "vorbeilassen",
    "vorbeiließe": "vorbeilassen",
    "vorbeiließen": "vorbeilassen",
    "vorbeiließest": "vorbeilassen",
    "vorbeiließet": "vorbeilassen",
    "vorbeiließt": "vorbeilassen",
    "vorbeiläufst": "vorbeilaufen",
    "vorbeiläuft": "vorbeilaufen",
    "vorbeiläßt": "vorbeilassen",
    "vorbeimarschiere": "vorbeimarschieren",
    "vorbeimarschierend": "vorbeimarschieren",
    "vorbeimarschierende": "vorbeimarschierend",
    "vorbeimarschierendem": "vorbeimarschierend",
    "vorbeimarschierenden": "vorbeimarschierend",
    "vorbeimarschierender": "vorbeimarschierend",
    "vorbeimarschierendes": "vorbeimarschierend",
    "vorbeimarschierest": "vorbeimarschieren",
    "vorbeimarschieret": "vorbeimarschieren",
    "vorbeimarschierst": "vorbeimarschieren",
    "vorbeimarschiert": "vorbeimarschieren",
    "vorbeimarschierte": "vorbeimarschieren",
    "vorbeimarschiertem": "vorbeimarschiert",
    "vorbeimarschierten": "vorbeimarschieren",
    "vorbeimarschierter": "vorbeimarschiert",
    "vorbeimarschiertes": "vorbeimarschiert",
    "vorbeimarschiertest": "vorbeimarschieren",
    "vorbeimarschiertet": "vorbeimarschieren",
    "vorbeirannte": "vorbeirennen",
    "vorbeirannten": "vorbeirennen",
    "vorbeiranntest": "vorbeirennen",
    "vorbeiranntet": "vorbeirennen",
    "vorbeirede": "vorbeireden",
    "vorbeiredend": "vorbeireden",
    "vorbeiredende": "vorbeiredend",
    "vorbeiredendem": "vorbeiredend",
    "vorbeiredenden": "vorbeiredend",
    "vorbeiredender": "vorbeiredend",
    "vorbeiredendes": "vorbeiredend",
    "vorbeiredest": "vorbeireden",
    "vorbeiredet": "vorbeireden",
    "vorbeiredete": "vorbeireden",
    "vorbeiredeten": "vorbeireden",
    "vorbeiredetest": "vorbeireden",
    "vorbeiredetet": "vorbeireden",
    "vorbeirenne": "vorbeirennen",
    "vorbeirennend": "vorbeirennen",
    "vorbeirennende": "vorbeirennend",
    "vorbeirennendem": "vorbeirennend",
    "vorbeirennenden": "vorbeirennend",
    "vorbeirennender": "vorbeirennend",
    "vorbeirennendes": "vorbeirennend",
    "vorbeirennest": "vorbeirennen",
    "vorbeirennet": "vorbeirennen",
    "vorbeirennst": "vorbeirennen",
    "vorbeirennt": "vorbeirennen",
    "vorbeischieße": "vorbeischießen",
    "vorbeischießend": "vorbeischießen",
    "vorbeischießende": "vorbeischießend",
    "vorbeischießendem": "vorbeischießend",
    "vorbeischießenden": "vorbeischießend",
    "vorbeischießender": "vorbeischießend",
    "vorbeischießendes": "vorbeischießend",
    "vorbeischießest": "vorbeischießen",
    "vorbeischießet": "vorbeischießen",
    "vorbeischießt": "vorbeischießen",
    "vorbeischossen": "vorbeischießen",
    "vorbeischoß": "vorbeischießen",
    "vorbeischoßt": "vorbeischießen",
    "vorbeischösse": "vorbeischießen",
    "vorbeischössen": "vorbeischießen",
    "vorbeischössest": "vorbeischießen",
    "vorbeischösset": "vorbeischießen",
    "vorbeitraf": "vorbeitreffen",
    "vorbeitrafen": "vorbeitreffen",
    "vorbeitrafst": "vorbeitreffen",
    "vorbeitraft": "vorbeitreffen",
    "vorbeitreffe": "vorbeitreffen",
    "vorbeitreffend": "vorbeitreffen",
    "vorbeitreffende": "vorbeitreffend",
    "vorbeitreffendem": "vorbeitreffend",
    "vorbeitreffenden": "vorbeitreffend",
    "vorbeitreffender": "vorbeitreffend",
    "vorbeitreffendes": "vorbeitreffend",
    "vorbeitreffest": "vorbeitreffen",
    "vorbeitreffet": "vorbeitreffen",
    "vorbeitrefft": "vorbeitreffen",
    "vorbeitriffst": "vorbeitreffen",
    "vorbeitrifft": "vorbeitreffen",
    "vorbeiträfe": "vorbeitreffen",
    "vorbeiträfen": "vorbeitreffen",
    "vorbeiträfest": "vorbeitreffen",
    "vorbeiträfet": "vorbeitreffen",
    "vorbeizubenehmen": "vorbeibenehmen",
    "vorbeizufahren": "vorbeifahren",
    "vorbeizufliegen": "vorbeifliegen",
    "vorbeizufließen": "vorbeifließen",
    "vorbeizuführen": "vorbeiführen",
    "vorbeizugehen": "vorbeigehen",
    "vorbeizukommen": "vorbeikommen",
    "vorbeizulassen": "vorbeilassen",
    "vorbeizulaufen": "vorbeilaufen",
    "vorbeizumarschieren": "vorbeimarschieren",
    "vorbeizureden": "vorbeireden",
    "vorbeizurennen": "vorbeirennen",
    "vorbeizuschießen": "vorbeischießen",
    "vorbeizutreffen": "vorbeitreffen",
    "vorbelastete": "vorbelastet",
    "vorbelastetem": "vorbelastet",
    "vorbelasteten": "vorbelastet",
    "vorbelasteter": "vorbelastet",
    "vorbelastetes": "vorbelastet",
    "vorbereite": "vorbereiten",
    "vorbereitend": "vorbereiten",
    "vorbereitende": "vorbereitend",
    "vorbereitendem": "vorbereitend",
    "vorbereitenden": "vorbereitend",
    "vorbereitender": "vorbereitend",
    "vorbereitendes": "vorbereitend",
    "vorbereitest": "vorbereiten",
    "vorbereitet": "vorbereiten",
    "vorbereitete": "vorbereiten",
    "vorbereitetem": "vorbereitet",
    "vorbereiteten": "vorbereiten",
    "vorbereiteter": "vorbereitet",
    "vorbereitetere": "vorbereitet",
    "vorbereiteterem": "vorbereitet",
    "vorbereiteteren": "vorbereitet",
    "vorbereiteterer": "vorbereitet",
    "vorbereiteteres": "vorbereitet",
    "vorbereitetes": "vorbereitet",
    "vorbereitetest": "vorbereiten",
    "vorbereiteteste": "vorbereitet",
    "vorbereitetestem": "vorbereitet",
    "vorbereitetesten": "vorbereitet",
    "vorbereitetester": "vorbereitet",
    "vorbereitetestes": "vorbereitet",
    "vorbereitetet": "vorbereiten",
    "vorberitt": "vorbereiten",
    "vorberitte": "vorbereiten",
    "vorberitten": "vorbereiten",
    "vorberittest": "vorbereiten",
    "vorberittet": "vorbereiten",
    "vorbestelle": "vorbestellen",
    "vorbestellend": "vorbestellen",
    "vorbestellende": "vorbestellend",
    "vorbestellendem": "vorbestellend",
    "vorbestellenden": "vorbestellend",
    "vorbestellender": "vorbestellend",
    "vorbestellendes": "vorbestellend",
    "vorbestellest": "vorbestellen",
    "vorbestellet": "vorbestellen",
    "vorbestellst": "vorbestellen",
    "vorbestellt": "vorbestellen",
    "vorbestellte": "vorbestellen",
    "vorbestelltem": "vorbestellt",
    "vorbestellten": "vorbestellen",
    "vorbestellter": "vorbestellt",
    "vorbestelltes": "vorbestellt",
    "vorbestelltest": "vorbestellen",
    "vorbestelltet": "vorbestellen",
    "vorbestimmtem": "vorbestimmt",
    "vorbestimmten": "vorbestimmt",
    "vorbestimmter": "vorbestimmt",
    "vorbestimmtes": "vorbestimmt",
    "vorbestrafte": "vorbestraft",
    "vorbestraftem": "vorbestraft",
    "vorbestraften": "vorbestraft",
    "vorbestrafter": "vorbestraft",
    "vorbestraftes": "vorbestraft",
    "vorbete": "vorbeten",
    "vorbetend": "vorbeten",
    "vorbetende": "vorbetend",
    "vorbetendem": "vorbetend",
    "vorbetenden": "vorbetend",
    "vorbetender": "vorbetend",
    "vorbetendes": "vorbetend",
    "vorbetest": "vorbeten",
    "vorbetet": "vorbeten",
    "vorbetete": "vorbeten",
    "vorbeteten": "vorbeten",
    "vorbetetest": "vorbeten",
    "vorbetetet": "vorbeten",
    "vorbeuge": "vorbeugen",
    "vorbeugend": "vorbeugen",
    "vorbeugende": "vorbeugend",
    "vorbeugendem": "vorbeugend",
    "vorbeugenden": "vorbeugend",
    "vorbeugender": "vorbeugend",
    "vorbeugendere": "vorbeugend",
    "vorbeugenderem": "vorbeugend",
    "vorbeugenderen": "vorbeugend",
    "vorbeugenderer": "vorbeugend",
    "vorbeugenderes": "vorbeugend",
    "vorbeugendes": "vorbeugend",
    "vorbeugendste": "vorbeugend",
    "vorbeugendstem": "vorbeugend",
    "vorbeugendsten": "vorbeugend",
    "vorbeugendster": "vorbeugend",
    "vorbeugendstes": "vorbeugend",
    "vorbeugest": "vorbeugen",
    "vorbeuget": "vorbeugen",
    "vorbeugst": "vorbeugen",
    "vorbeugt": "vorbeugen",
    "vorbeugte": "vorbeugen",
    "vorbeugten": "vorbeugen",
    "vorbeugtest": "vorbeugen",
    "vorbeugtet": "vorbeugen",
    "vorbildend": "vorbilden",
    "vorbildende": "vorbildend",
    "vorbildendem": "vorbildend",
    "vorbildenden": "vorbildend",
    "vorbildender": "vorbildend",
    "vorbildendes": "vorbildend",
    "vorbildest": "vorbilden",
    "vorbildet": "vorbilden",
    "vorbildete": "vorbilden",
    "vorbildeten": "vorbilden",
    "vorbildetest": "vorbilden",
    "vorbildetet": "vorbilden",
    "vorbildlichem": "vorbildlich",
    "vorbildlichen": "vorbildlich",
    "vorbildlicher": "vorbildlich",
    "vorbildlichere": "vorbildlich",
    "vorbildlicherem": "vorbildlich",
    "vorbildlicheren": "vorbildlich",
    "vorbildlicherer": "vorbildlich",
    "vorbildlicheres": "vorbildlich",
    "vorbildliches": "vorbildlich",
    "vorbildlichste": "vorbildlich",
    "vorbildlichstem": "vorbildlich",
    "vorbildlichsten": "vorbildlich",
    "vorbildlichster": "vorbildlich",
    "vorbildlichstes": "vorbildlich",
    "vorbinde": "vorbinden",
    "vorbindend": "vorbinden",
    "vorbindende": "vorbindend",
    "vorbindendem": "vorbindend",
    "vorbindenden": "vorbindend",
    "vorbindender": "vorbindend",
    "vorbindendes": "vorbindend",
    "vorbindest": "vorbinden",
    "vorbindet": "vorbinden",
    "vorbleiche": "vorbleichen",
    "vorbleichend": "vorbleichen",
    "vorbleichende": "vorbleichend",
    "vorbleichendem": "vorbleichend",
    "vorbleichenden": "vorbleichend",
    "vorbleichender": "vorbleichend",
    "vorbleichendes": "vorbleichend",
    "vorbleichest": "vorbleichen",
    "vorbleichet": "vorbleichen",
    "vorbleichst": "vorbleichen",
    "vorbleicht": "vorbleichen",
    "vorblich": "vorbleichen",
    "vorbliche": "vorbleichen",
    "vorblichen": "vorbleichen",
    "vorblichest": "vorbleichen",
    "vorblichet": "vorbleichen",
    "vorblichst": "vorbleichen",
    "vorblicht": "vorbleichen",
    "vorbohre": "vorbohren",
    "vorbohrend": "vorbohren",
    "vorbohrende": "vorbohrend",
    "vorbohrendem": "vorbohrend",
    "vorbohrenden": "vorbohrend",
    "vorbohrender": "vorbohrend",
    "vorbohrendes": "vorbohrend",
    "vorbohrest": "vorbohren",
    "vorbohret": "vorbohren",
    "vorbohrst": "vorbohren",
    "vorbohrt": "vorbohren",
    "vorbohrte": "vorbohren",
    "vorbohrten": "vorbohren",
    "vorbohrtest": "vorbohren",
    "vorbohrtet": "vorbohren",
    "vorbrachte": "vorbringen",
    "vorbrachten": "vorbringen",
    "vorbrachtest": "vorbringen",
    "vorbrachtet": "vorbringen",
    "vorbringe": "vorbringen",
    "vorbringend": "vorbringen",
    "vorbringende": "vorbringend",
    "vorbringendem": "vorbringend",
    "vorbringenden": "vorbringend",
    "vorbringender": "vorbringend",
    "vorbringendes": "vorbringend",
    "vorbringest": "vorbringen",
    "vorbringet": "vorbringen",
    "vorbringst": "vorbringen",
    "vorbringt": "vorbringen",
    "vorbrächte": "vorbringen",
    "vorbrächten": "vorbringen",
    "vorbrächtest": "vorbringen",
    "vorbrächtet": "vorbringen",
    "vorbände": "vorbinden",
    "vorbänden": "vorbinden",
    "vorbändest": "vorbinden",
    "vorbändet": "vorbinden",
    "vordachte": "vordenken",
    "vordachten": "vordenken",
    "vordachtest": "vordenken",
    "vordachtet": "vordenken",
    "vordatiere": "vordatieren",
    "vordatierend": "vordatieren",
    "vordatierende": "vordatierend",
    "vordatierendem": "vordatierend",
    "vordatierenden": "vordatierend",
    "vordatierender": "vordatierend",
    "vordatierendes": "vordatierend",
    "vordatierest": "vordatieren",
    "vordatieret": "vordatieren",
    "vordatierst": "vordatieren",
    "vordatiert": "vordatieren",
    "vordatierte": "vordatieren",
    "vordatiertem": "vordatiert",
    "vordatierten": "vordatieren",
    "vordatierter": "vordatiert",
    "vordatiertes": "vordatiert",
    "vordatiertest": "vordatieren",
    "vordatiertet": "vordatieren",
    "vordenke": "vordenken",
    "vordenkend": "vordenken",
    "vordenkende": "vordenkend",
    "vordenkendem": "vordenkend",
    "vordenkenden": "vordenkend",
    "vordenkender": "vordenkend",
    "vordenkendes": "vordenkend",
    "vordenkest": "vordenken",
    "vordenket": "vordenken",
    "vordenkst": "vordenken",
    "vordenkt": "vordenken",
    "vorderem": "vorder",
    "vorderen": "vorder",
    "vorderer": "vorder",
    "vorderere": "vorder",
    "vordererem": "vorder",
    "vordereren": "vorder",
    "vordererer": "vorder",
    "vordereres": "vorder",
    "vorderes": "vorder",
    "vordergründigem": "vordergründig",
    "vordergründigen": "vordergründig",
    "vordergründiger": "vordergründig",
    "vordergründigere": "vordergründig",
    "vordergründigerem": "vordergründig",
    "vordergründigeren": "vordergründig",
    "vordergründigerer": "vordergründig",
    "vordergründigeres": "vordergründig",
    "vordergründiges": "vordergründig",
    "vordergründigste": "vordergründig",
    "vordergründigstem": "vordergründig",
    "vordergründigsten": "vordergründig",
    "vordergründigster": "vordergründig",
    "vordergründigstes": "vordergründig",
    "vorderstem": "vorder",
    "vordersten": "vorder",
    "vorderster": "vorder",
    "vorderstes": "vorder",
    "vordrang": "vordringen",
    "vordrangen": "vordringen",
    "vordrangst": "vordringen",
    "vordrangt": "vordringen",
    "vordringe": "vordringen",
    "vordringend": "vordringen",
    "vordringende": "vordringend",
    "vordringendem": "vordringend",
    "vordringenden": "vordringend",
    "vordringender": "vordringend",
    "vordringendes": "vordringend",
    "vordringest": "vordringen",
    "vordringet": "vordringen",
    "vordringliche": "vordringlich",
    "vordringlichem": "vordringlich",
    "vordringlichen": "vordringlich",
    "vordringlicher": "vordringlich",
    "vordringliches": "vordringlich",
    "vordringst": "vordringen",
    "vordringt": "vordringen",
    "vordränge": "vordringen",
    "vordrängen": "vordringen",
    "vordrängend": "vordrängen",
    "vordrängende": "vordrängend",
    "vordrängendem": "vordrängend",
    "vordrängenden": "vordrängend",
    "vordrängender": "vordrängend",
    "vordrängendes": "vordrängend",
    "vordrängest": "vordringen",
    "vordränget": "vordringen",
    "vordrängst": "vordrängen",
    "vordrängt": "vordrängen",
    "vordrängte": "vordrängen",
    "vordrängten": "vordrängen",
    "vordrängtest": "vordrängen",
    "vordrängtet": "vordrängen",
    "vordächte": "vordenken",
    "vordächten": "vordenken",
    "vordächtest": "vordenken",
    "vordächtet": "vordenken",
    "vorehelichem": "vorehelich",
    "vorehelichen": "vorehelich",
    "vorehelicher": "vorehelich",
    "voreheliches": "vorehelich",
    "voreilige": "voreilig",
    "voreiligem": "voreilig",
    "voreiligen": "voreilig",
    "voreiliger": "voreilig",
    "voreiligere": "voreilig",
    "voreiligerem": "voreilig",
    "voreiligeren": "voreilig",
    "voreiligerer": "voreilig",
    "voreiligeres": "voreilig",
    "voreiliges": "voreilig",
    "voreiligste": "voreilig",
    "voreiligstem": "voreilig",
    "voreiligsten": "voreilig",
    "voreiligster": "voreilig",
    "voreiligstes": "voreilig",
    "voreingenommene": "voreingenommen",
    "voreingenommenem": "voreingenommen",
    "voreingenommenen": "voreingenommen",
    "voreingenommener": "voreingenommen",
    "voreingenommenere": "voreingenommen",
    "voreingenommenerem": "voreingenommen",
    "voreingenommeneren": "voreingenommen",
    "voreingenommenerer": "voreingenommen",
    "voreingenommeneres": "voreingenommen",
    "voreingenommenes": "voreingenommen",
    "voreingenommenste": "voreingenommen",
    "voreingenommenstem": "voreingenommen",
    "voreingenommensten": "voreingenommen",
    "voreingenommenster": "voreingenommen",
    "voreingenommenstes": "voreingenommen",
    "vorenthalte": "vorenthalten",
    "vorenthaltend": "vorenthalten",
    "vorenthaltende": "vorenthaltend",
    "vorenthaltendem": "vorenthaltend",
    "vorenthaltenden": "vorenthaltend",
    "vorenthaltender": "vorenthaltend",
    "vorenthaltendere": "vorenthaltend",
    "vorenthaltenderem": "vorenthaltend",
    "vorenthaltenderen": "vorenthaltend",
    "vorenthaltenderer": "vorenthaltend",
    "vorenthaltenderes": "vorenthaltend",
    "vorenthaltendes": "vorenthaltend",
    "vorenthaltendste": "vorenthaltend",
    "vorenthaltendstem": "vorenthaltend",
    "vorenthaltendsten": "vorenthaltend",
    "vorenthaltendster": "vorenthaltend",
    "vorenthaltendstes": "vorenthaltend",
    "vorenthaltene": "vorenthalten",
    "vorenthaltenem": "vorenthalten",
    "vorenthaltenen": "vorenthalten",
    "vorenthaltener": "vorenthalten",
    "vorenthaltenere": "vorenthalten",
    "vorenthaltenerem": "vorenthalten",
    "vorenthalteneren": "vorenthalten",
    "vorenthaltenerer": "vorenthalten",
    "vorenthalteneres": "vorenthalten",
    "vorenthaltenes": "vorenthalten",
    "vorenthaltenstem": "vorenthalten",
    "vorenthaltensten": "vorenthalten",
    "vorenthaltenster": "vorenthalten",
    "vorenthaltenstes": "vorenthalten",
    "vorenthaltest": "vorenthalten",
    "vorenthaltet": "vorenthalten",
    "vorenthielt": "vorenthalten",
    "vorenthielte": "vorenthalten",
    "vorenthielten": "vorenthalten",
    "vorenthieltest": "vorenthalten",
    "vorenthieltet": "vorenthalten",
    "vorenthält": "vorenthalten",
    "vorenthältst": "vorenthalten",
    "vorerzähle": "vorerzählen",
    "vorerzählend": "vorerzählen",
    "vorerzählende": "vorerzählend",
    "vorerzählendem": "vorerzählend",
    "vorerzählenden": "vorerzählend",
    "vorerzählender": "vorerzählend",
    "vorerzählendes": "vorerzählend",
    "vorerzählest": "vorerzählen",
    "vorerzählet": "vorerzählen",
    "vorerzählst": "vorerzählen",
    "vorerzählt": "vorerzählen",
    "vorerzählte": "vorerzählen",
    "vorerzähltem": "vorerzählt",
    "vorerzählten": "vorerzählen",
    "vorerzählter": "vorerzählt",
    "vorerzähltes": "vorerzählt",
    "vorerzähltest": "vorerzählen",
    "vorerzähltet": "vorerzählen",
    "vorfahre": "vorfahren",
    "vorfahrend": "vorfahren",
    "vorfahrende": "vorfahrend",
    "vorfahrendem": "vorfahrend",
    "vorfahrenden": "vorfahrend",
    "vorfahrender": "vorfahrend",
    "vorfahrendes": "vorfahrend",
    "vorfahrest": "vorfahren",
    "vorfahret": "vorfahren",
    "vorfahrt": "vorfahren",
    "vorfallend": "vorfallen",
    "vorfallende": "vorfallend",
    "vorfallendem": "vorfallend",
    "vorfallenden": "vorfallend",
    "vorfallender": "vorfallend",
    "vorfallendes": "vorfallend",
    "vorfallest": "vorfallen",
    "vorfallet": "vorfallen",
    "vorfallt": "vorfallen",
    "vorfand": "vorfinden",
    "vorfanden": "vorfinden",
    "vorfandest": "vorfinden",
    "vorfandet": "vorfinden",
    "vorfertige": "vorfertigen",
    "vorfertigend": "vorfertigen",
    "vorfertigende": "vorfertigend",
    "vorfertigendem": "vorfertigend",
    "vorfertigenden": "vorfertigend",
    "vorfertigender": "vorfertigend",
    "vorfertigendes": "vorfertigend",
    "vorfertigest": "vorfertigen",
    "vorfertiget": "vorfertigen",
    "vorfertigst": "vorfertigen",
    "vorfertigt": "vorfertigen",
    "vorfertigte": "vorfertigen",
    "vorfertigten": "vorfertigen",
    "vorfertigtest": "vorfertigen",
    "vorfertigtet": "vorfertigen",
    "vorfiel": "vorfallen",
    "vorfiele": "vorfallen",
    "vorfielen": "vorfallen",
    "vorfielest": "vorfallen",
    "vorfielet": "vorfallen",
    "vorfielst": "vorfallen",
    "vorfielt": "vorfallen",
    "vorfinanziere": "vorfinanzieren",
    "vorfinanzierend": "vorfinanzieren",
    "vorfinanzierende": "vorfinanzierend",
    "vorfinanzierendem": "vorfinanzierend",
    "vorfinanzierenden": "vorfinanzierend",
    "vorfinanzierender": "vorfinanzierend",
    "vorfinanzierendes": "vorfinanzierend",
    "vorfinanzierest": "vorfinanzieren",
    "vorfinanzieret": "vorfinanzieren",
    "vorfinanzierst": "vorfinanzieren",
    "vorfinanziert": "vorfinanzieren",
    "vorfinanzierte": "vorfinanzieren",
    "vorfinanziertem": "vorfinanziert",
    "vorfinanzierten": "vorfinanzieren",
    "vorfinanzierter": "vorfinanziert",
    "vorfinanziertes": "vorfinanziert",
    "vorfinanziertest": "vorfinanzieren",
    "vorfinanziertet": "vorfinanzieren",
    "vorfinde": "vorfinden",
    "vorfindend": "vorfinden",
    "vorfindende": "vorfindend",
    "vorfindendem": "vorfindend",
    "vorfindenden": "vorfindend",
    "vorfindender": "vorfindend",
    "vorfindendes": "vorfindend",
    "vorfindest": "vorfinden",
    "vorfindet": "vorfinden",
    "vorflunkere": "vorflunkern",
    "vorflunkernd": "vorflunkern",
    "vorflunkernde": "vorflunkernd",
    "vorflunkerndem": "vorflunkernd",
    "vorflunkernden": "vorflunkernd",
    "vorflunkernder": "vorflunkernd",
    "vorflunkerndere": "vorflunkernd",
    "vorflunkernderem": "vorflunkernd",
    "vorflunkernderen": "vorflunkernd",
    "vorflunkernderer": "vorflunkernd",
    "vorflunkernderes": "vorflunkernd",
    "vorflunkerndes": "vorflunkernd",
    "vorflunkerndste": "vorflunkernd",
    "vorflunkerndstem": "vorflunkernd",
    "vorflunkerndsten": "vorflunkernd",
    "vorflunkerndster": "vorflunkernd",
    "vorflunkerndstes": "vorflunkernd",
    "vorflunkerst": "vorflunkern",
    "vorflunkert": "vorflunkern",
    "vorflunkerte": "vorflunkern",
    "vorflunkerten": "vorflunkern",
    "vorflunkertest": "vorflunkern",
    "vorflunkertet": "vorflunkern",
    "vorforme": "vorformen",
    "vorformend": "vorformen",
    "vorformende": "vorformend",
    "vorformendem": "vorformend",
    "vorformenden": "vorformend",
    "vorformender": "vorformend",
    "vorformendes": "vorformend",
    "vorformest": "vorformen",
    "vorformet": "vorformen",
    "vorformst": "vorformen",
    "vorformt": "vorformen",
    "vorformte": "vorformen",
    "vorformten": "vorformen",
    "vorformtest": "vorformen",
    "vorformtet": "vorformen",
    "vorformuliere": "vorformulieren",
    "vorformulierend": "vorformulieren",
    "vorformulierende": "vorformulierend",
    "vorformulierendem": "vorformulierend",
    "vorformulierenden": "vorformulierend",
    "vorformulierender": "vorformulierend",
    "vorformulierendes": "vorformulierend",
    "vorformulierest": "vorformulieren",
    "vorformulieret": "vorformulieren",
    "vorformulierst": "vorformulieren",
    "vorformuliert": "vorformulieren",
    "vorformulierte": "vorformulieren",
    "vorformuliertem": "vorformuliert",
    "vorformulierten": "vorformulieren",
    "vorformulierter": "vorformuliert",
    "vorformuliertes": "vorformuliert",
    "vorformuliertest": "vorformulieren",
    "vorformuliertet": "vorformulieren",
    "vorfuhr": "vorfahren",
    "vorfuhren": "vorfahren",
    "vorfuhrst": "vorfahren",
    "vorfuhrt": "vorfahren",
    "vorfährst": "vorfahren",
    "vorfährt": "vorfahren",
    "vorfällst": "vorfallen",
    "vorfällt": "vorfallen",
    "vorfände": "vorfinden",
    "vorfänden": "vorfinden",
    "vorfändest": "vorfinden",
    "vorfändet": "vorfinden",
    "vorfühle": "vorfühlen",
    "vorfühlend": "vorfühlen",
    "vorfühlende": "vorfühlend",
    "vorfühlendem": "vorfühlend",
    "vorfühlenden": "vorfühlend",
    "vorfühlender": "vorfühlend",
    "vorfühlendes": "vorfühlend",
    "vorfühlest": "vorfühlen",
    "vorfühlet": "vorfühlen",
    "vorfühlst": "vorfühlen",
    "vorfühlt": "vorfühlen",
    "vorfühlte": "vorfühlen",
    "vorfühlten": "vorfühlen",
    "vorfühltest": "vorfühlen",
    "vorfühltet": "vorfühlen",
    "vorführe": "vorführen",
    "vorführen": "vorfahren",
    "vorführend": "vorführen",
    "vorführende": "vorführend",
    "vorführendem": "vorführend",
    "vorführenden": "vorführend",
    "vorführender": "vorführend",
    "vorführendes": "vorführend",
    "vorführest": "vorführen",
    "vorführet": "vorführen",
    "vorführst": "vorführen",
    "vorführt": "vorführen",
    "vorführte": "vorführen",
    "vorführten": "vorführen",
    "vorführtest": "vorführen",
    "vorführtet": "vorführen",
    "vorgab": "vorgeben",
    "vorgabst": "vorgeben",
    "vorgabt": "vorgeben",
    "vorgaukele": "vorgaukeln",
    "vorgaukelnd": "vorgaukeln",
    "vorgaukelnde": "vorgaukelnd",
    "vorgaukelndem": "vorgaukelnd",
    "vorgaukelnden": "vorgaukelnd",
    "vorgaukelnder": "vorgaukelnd",
    "vorgaukelndes": "vorgaukelnd",
    "vorgaukelst": "vorgaukeln",
    "vorgaukelt": "vorgaukeln",
    "vorgaukelte": "vorgaukeln",
    "vorgaukelten": "vorgaukeln",
    "vorgaukeltest": "vorgaukeln",
    "vorgaukeltet": "vorgaukeln",
    "vorgaukle": "vorgaukeln",
    "vorgearbeitet": "vorarbeiten",
    "vorgearbeitete": "vorgearbeitet",
    "vorgearbeitetem": "vorgearbeitet",
    "vorgearbeiteten": "vorgearbeitet",
    "vorgearbeiteter": "vorgearbeitet",
    "vorgearbeitetes": "vorgearbeitet",
    "vorgebaut": "vorbauen",
    "vorgebaute": "vorgebaut",
    "vorgebautem": "vorgebaut",
    "vorgebauten": "vorgebaut",
    "vorgebauter": "vorgebaut",
    "vorgebautes": "vorgebaut",
    "vorgebe": "vorgeben",
    "vorgebend": "vorgeben",
    "vorgebende": "vorgebend",
    "vorgebendem": "vorgebend",
    "vorgebenden": "vorgebend",
    "vorgebender": "vorgebend",
    "vorgebendes": "vorgebend",
    "vorgebest": "vorgeben",
    "vorgebet": "vorgeben",
    "vorgebetet": "vorbeten",
    "vorgebetete": "vorgebetet",
    "vorgebetetem": "vorgebetet",
    "vorgebeteten": "vorgebetet",
    "vorgebeteter": "vorgebetet",
    "vorgebetetes": "vorgebetet",
    "vorgebeugt": "vorbeugen",
    "vorgebeugte": "vorgebeugt",
    "vorgebeugtem": "vorgebeugt",
    "vorgebeugten": "vorgebeugt",
    "vorgebeugter": "vorgebeugt",
    "vorgebeugtes": "vorgebeugt",
    "vorgebildet": "vorbilden",
    "vorgebildete": "vorgebildet",
    "vorgebildetem": "vorgebildet",
    "vorgebildeten": "vorgebildet",
    "vorgebildeter": "vorgebildet",
    "vorgebildetes": "vorgebildet",
    "vorgeblichen": "vorbleichen",
    "vorgeblichene": "vorgeblichen",
    "vorgeblichenem": "vorgeblichen",
    "vorgeblichenen": "vorgeblichen",
    "vorgeblichener": "vorgeblichen",
    "vorgeblichenere": "vorgeblichen",
    "vorgeblichenerem": "vorgeblichen",
    "vorgeblicheneren": "vorgeblichen",
    "vorgeblichenerer": "vorgeblichen",
    "vorgeblicheneres": "vorgeblichen",
    "vorgeblichenes": "vorgeblichen",
    "vorgeblichenste": "vorgeblichen",
    "vorgeblichenstem": "vorgeblichen",
    "vorgeblichensten": "vorgeblichen",
    "vorgeblichenster": "vorgeblichen",
    "vorgeblichenstes": "vorgeblichen",
    "vorgebohrt": "vorbohren",
    "vorgebohrte": "vorgebohrt",
    "vorgebohrtem": "vorgebohrt",
    "vorgebohrten": "vorgebohrt",
    "vorgebohrter": "vorgebohrt",
    "vorgebohrtes": "vorgebohrt",
    "vorgebracht": "vorbringen",
    "vorgebrachte": "vorgebracht",
    "vorgebrachtem": "vorgebracht",
    "vorgebrachten": "vorgebracht",
    "vorgebrachter": "vorgebracht",
    "vorgebrachtes": "vorgebracht",
    "vorgebt": "vorgeben",
    "vorgebunden": "vorbinden",
    "vorgebundene": "vorgebunden",
    "vorgebundenem": "vorgebunden",
    "vorgebundenen": "vorgebunden",
    "vorgebundener": "vorgebunden",
    "vorgebundenes": "vorgebunden",
    "vorgedacht": "vordenken",
    "vorgedachte": "vorgedacht",
    "vorgedachtem": "vorgedacht",
    "vorgedachten": "vorgedacht",
    "vorgedachter": "vorgedacht",
    "vorgedachtes": "vorgedacht",
    "vorgedrungen": "vordringen",
    "vorgedrungene": "vorgedrungen",
    "vorgedrungenem": "vorgedrungen",
    "vorgedrungenen": "vorgedrungen",
    "vorgedrungener": "vorgedrungen",
    "vorgedrungenes": "vorgedrungen",
    "vorgedrängt": "vordrängen",
    "vorgedrängte": "vorgedrängt",
    "vorgedrängtem": "vorgedrängt",
    "vorgedrängten": "vorgedrängt",
    "vorgedrängter": "vorgedrängt",
    "vorgedrängtes": "vorgedrängt",
    "vorgefahren": "vorfahren",
    "vorgefahrene": "vorgefahren",
    "vorgefahrenem": "vorgefahren",
    "vorgefahrenen": "vorgefahren",
    "vorgefahrener": "vorgefahren",
    "vorgefahrenes": "vorgefahren",
    "vorgefallen": "vorfallen",
    "vorgefallene": "vorgefallen",
    "vorgefallenem": "vorgefallen",
    "vorgefallenen": "vorgefallen",
    "vorgefallener": "vorgefallen",
    "vorgefallenes": "vorgefallen",
    "vorgefertigt": "vorfertigen",
    "vorgefertigte": "vorgefertigt",
    "vorgefertigtem": "vorgefertigt",
    "vorgefertigten": "vorgefertigt",
    "vorgefertigter": "vorgefertigt",
    "vorgefertigtes": "vorgefertigt",
    "vorgeflunkert": "vorflunkern",
    "vorgeflunkerte": "vorgeflunkert",
    "vorgeflunkertem": "vorgeflunkert",
    "vorgeflunkerten": "vorgeflunkert",
    "vorgeflunkerter": "vorgeflunkert",
    "vorgeflunkertere": "vorgeflunkert",
    "vorgeflunkerterem": "vorgeflunkert",
    "vorgeflunkerteren": "vorgeflunkert",
    "vorgeflunkerterer": "vorgeflunkert",
    "vorgeflunkerteres": "vorgeflunkert",
    "vorgeflunkertes": "vorgeflunkert",
    "vorgeflunkerteste": "vorgeflunkert",
    "vorgeflunkertestem": "vorgeflunkert",
    "vorgeflunkertesten": "vorgeflunkert",
    "vorgeflunkertester": "vorgeflunkert",
    "vorgeflunkertestes": "vorgeflunkert",
    "vorgeformt": "vorformen",
    "vorgeformte": "vorgeformt",
    "vorgeformtem": "vorgeformt",
    "vorgeformten": "vorgeformt",
    "vorgeformter": "vorgeformt",
    "vorgeformtes": "vorgeformt",
    "vorgefunden": "vorfinden",
    "vorgefundene": "vorgefunden",
    "vorgefundenem": "vorgefunden",
    "vorgefundenen": "vorgefunden",
    "vorgefundener": "vorgefunden",
    "vorgefundenes": "vorgefunden",
    "vorgefühlt": "vorfühlen",
    "vorgefühlte": "vorgefühlt",
    "vorgefühltem": "vorgefühlt",
    "vorgefühlten": "vorgefühlt",
    "vorgefühlter": "vorgefühlt",
    "vorgefühltes": "vorgefühlt",
    "vorgeführt": "vorführen",
    "vorgeführte": "vorgeführt",
    "vorgeführtem": "vorgeführt",
    "vorgeführten": "vorgeführt",
    "vorgeführter": "vorgeführt",
    "vorgeführtes": "vorgeführt",
    "vorgegangen": "vorgehen",
    "vorgegangene": "vorgegangen",
    "vorgegangenem": "vorgegangen",
    "vorgegangenen": "vorgegangen",
    "vorgegangener": "vorgegangen",
    "vorgegangenes": "vorgegangen",
    "vorgegaukelt": "vorgaukeln",
    "vorgegaukelte": "vorgegaukelt",
    "vorgegaukeltem": "vorgegaukelt",
    "vorgegaukelten": "vorgegaukelt",
    "vorgegaukelter": "vorgegaukelt",
    "vorgegaukeltes": "vorgegaukelt",
    "vorgegeben": "vorgeben",
    "vorgegebene": "vorgegeben",
    "vorgegebenem": "vorgegeben",
    "vorgegebenen": "vorgegeben",
    "vorgegebener": "vorgegeben",
    "vorgegebenes": "vorgegeben",
    "vorgegriffen": "vorgreifen",
    "vorgegriffene": "vorgegriffen",
    "vorgegriffenem": "vorgegriffen",
    "vorgegriffenen": "vorgegriffen",
    "vorgegriffener": "vorgegriffen",
    "vorgegriffenere": "vorgegriffen",
    "vorgegriffenerem": "vorgegriffen",
    "vorgegriffeneren": "vorgegriffen",
    "vorgegriffenerer": "vorgegriffen",
    "vorgegriffeneres": "vorgegriffen",
    "vorgegriffenes": "vorgegriffen",
    "vorgegriffenste": "vorgegriffen",
    "vorgegriffenstem": "vorgegriffen",
    "vorgegriffensten": "vorgegriffen",
    "vorgegriffenster": "vorgegriffen",
    "vorgegriffenstes": "vorgegriffen",
    "vorgehalten": "vorhalten",
    "vorgehaltene": "vorgehalten",
    "vorgehaltenem": "vorgehalten",
    "vorgehaltenen": "vorgehalten",
    "vorgehaltener": "vorgehalten",
    "vorgehaltenes": "vorgehalten",
    "vorgehangen": "vorhängen",
    "vorgehangene": "vorgehangen",
    "vorgehangenem": "vorgehangen",
    "vorgehangenen": "vorgehangen",
    "vorgehangener": "vorgehangen",
    "vorgehangenes": "vorgehangen",
    "vorgeharrt": "vorharren",
    "vorgehe": "vorgehen",
    "vorgehend": "vorgehen",
    "vorgehende": "vorgehend",
    "vorgehendem": "vorgehend",
    "vorgehenden": "vorgehend",
    "vorgehender": "vorgehend",
    "vorgehendes": "vorgehend",
    "vorgeherrscht": "vorherrschen",
    "vorgeherrschte": "vorgeherrscht",
    "vorgeherrschtem": "vorgeherrscht",
    "vorgeherrschten": "vorgeherrscht",
    "vorgeherrschter": "vorgeherrscht",
    "vorgeherrschtes": "vorgeherrscht",
    "vorgehest": "vorgehen",
    "vorgehet": "vorgehen",
    "vorgeheuchelt": "vorheucheln",
    "vorgeheuchelte": "vorgeheuchelt",
    "vorgeheucheltem": "vorgeheuchelt",
    "vorgeheuchelten": "vorgeheuchelt",
    "vorgeheuchelter": "vorgeheuchelt",
    "vorgeheucheltere": "vorgeheuchelt",
    "vorgeheuchelterem": "vorgeheuchelt",
    "vorgeheuchelteren": "vorgeheuchelt",
    "vorgeheuchelterer": "vorgeheuchelt",
    "vorgeheuchelteres": "vorgeheuchelt",
    "vorgeheucheltes": "vorgeheuchelt",
    "vorgeheuchelteste": "vorgeheuchelt",
    "vorgeheucheltestem": "vorgeheuchelt",
    "vorgeheucheltesten": "vorgeheuchelt",
    "vorgeheucheltester": "vorgeheuchelt",
    "vorgeheucheltestes": "vorgeheuchelt",
    "vorgeheult": "vorheulen",
    "vorgeheulte": "vorgeheult",
    "vorgeheultem": "vorgeheult",
    "vorgeheulten": "vorgeheult",
    "vorgeheulter": "vorgeheult",
    "vorgeheultere": "vorgeheult",
    "vorgeheulterem": "vorgeheult",
    "vorgeheulteren": "vorgeheult",
    "vorgeheulterer": "vorgeheult",
    "vorgeheulteres": "vorgeheult",
    "vorgeheultes": "vorgeheult",
    "vorgeheulteste": "vorgeheult",
    "vorgeheultestem": "vorgeheult",
    "vorgeheultesten": "vorgeheult",
    "vorgeheultester": "vorgeheult",
    "vorgeheultestes": "vorgeheult",
    "vorgehst": "vorgehen",
    "vorgeht": "vorgehen",
    "vorgehängt": "vorhängen",
    "vorgehängte": "vorgehängt",
    "vorgehängtem": "vorgehängt",
    "vorgehängten": "vorgehängt",
    "vorgehängter": "vorgehängt",
    "vorgehängtes": "vorgehängt",
    "vorgejammert": "vorjammern",
    "vorgejammerte": "vorgejammert",
    "vorgejammertem": "vorgejammert",
    "vorgejammerten": "vorgejammert",
    "vorgejammerter": "vorgejammert",
    "vorgejammertes": "vorgejammert",
    "vorgekaut": "vorkauen",
    "vorgekaute": "vorgekaut",
    "vorgekautem": "vorgekaut",
    "vorgekauten": "vorgekaut",
    "vorgekauter": "vorgekaut",
    "vorgekautere": "vorgekaut",
    "vorgekauterem": "vorgekaut",
    "vorgekauteren": "vorgekaut",
    "vorgekauterer": "vorgekaut",
    "vorgekauteres": "vorgekaut",
    "vorgekautes": "vorgekaut",
    "vorgekauteste": "vorgekaut",
    "vorgekautestem": "vorgekaut",
    "vorgekautesten": "vorgekaut",
    "vorgekautester": "vorgekaut",
    "vorgekautestes": "vorgekaut",
    "vorgekehrt": "vorkehren",
    "vorgekehrte": "vorgekehrt",
    "vorgekehrtem": "vorgekehrt",
    "vorgekehrten": "vorgekehrt",
    "vorgekehrter": "vorgekehrt",
    "vorgekehrtes": "vorgekehrt",
    "vorgekeimt": "vorkeimen",
    "vorgekeimte": "vorgekeimt",
    "vorgekeimtem": "vorgekeimt",
    "vorgekeimten": "vorgekeimt",
    "vorgekeimter": "vorgekeimt",
    "vorgekeimtere": "vorgekeimt",
    "vorgekeimterem": "vorgekeimt",
    "vorgekeimteren": "vorgekeimt",
    "vorgekeimterer": "vorgekeimt",
    "vorgekeimteres": "vorgekeimt",
    "vorgekeimtes": "vorgekeimt",
    "vorgekeimteste": "vorgekeimt",
    "vorgekeimtestem": "vorgekeimt",
    "vorgekeimtesten": "vorgekeimt",
    "vorgekeimtester": "vorgekeimt",
    "vorgekeimtestes": "vorgekeimt",
    "vorgeknöpft": "vorknöpfen",
    "vorgeknöpfte": "vorgeknöpft",
    "vorgeknöpftem": "vorgeknöpft",
    "vorgeknöpften": "vorgeknöpft",
    "vorgeknöpfter": "vorgeknöpft",
    "vorgeknöpftes": "vorgeknöpft",
    "vorgekommen": "vorkommen",
    "vorgekommene": "vorgekommen",
    "vorgekommenem": "vorgekommen",
    "vorgekommenen": "vorgekommen",
    "vorgekommener": "vorgekommen",
    "vorgekommenes": "vorgekommen",
    "vorgeladen": "vorladen",
    "vorgeladene": "vorgeladen",
    "vorgeladenem": "vorgeladen",
    "vorgeladenen": "vorgeladen",
    "vorgeladener": "vorgeladen",
    "vorgeladenes": "vorgeladen",
    "vorgelaufen": "vorlaufen",
    "vorgelaufene": "vorgelaufen",
    "vorgelaufenem": "vorgelaufen",
    "vorgelaufenen": "vorgelaufen",
    "vorgelaufener": "vorgelaufen",
    "vorgelaufenes": "vorgelaufen",
    "vorgelebt": "vorleben",
    "vorgelebte": "vorgelebt",
    "vorgelebtem": "vorgelebt",
    "vorgelebten": "vorgelebt",
    "vorgelebter": "vorgelebt",
    "vorgelebtes": "vorgelebt",
    "vorgelegen": "vorliegen",
    "vorgelegene": "vorgelegen",
    "vorgelegenem": "vorgelegen",
    "vorgelegenen": "vorgelegen",
    "vorgelegener": "vorgelegen",
    "vorgelegenes": "vorgelegen",
    "vorgelegt": "vorlegen",
    "vorgelegte": "vorgelegt",
    "vorgelegtem": "vorgelegt",
    "vorgelegten": "vorgelegt",
    "vorgelegter": "vorgelegt",
    "vorgelegtes": "vorgelegt",
    "vorgelesen": "vorlesen",
    "vorgelesene": "vorgelesen",
    "vorgelesenem": "vorgelesen",
    "vorgelesenen": "vorgelesen",
    "vorgelesener": "vorgelesen",
    "vorgelesenes": "vorgelesen",
    "vorgelogen": "vorlügen",
    "vorgelogene": "vorgelogen",
    "vorgelogenem": "vorgelogen",
    "vorgelogenen": "vorgelogen",
    "vorgelogener": "vorgelogen",
    "vorgelogenere": "vorgelogen",
    "vorgelogenerem": "vorgelogen",
    "vorgelogeneren": "vorgelogen",
    "vorgelogenerer": "vorgelogen",
    "vorgelogeneres": "vorgelogen",
    "vorgelogenes": "vorgelogen",
    "vorgelogenste": "vorgelogen",
    "vorgelogenstem": "vorgelogen",
    "vorgelogensten": "vorgelogen",
    "vorgelogenster": "vorgelogen",
    "vorgelogenstes": "vorgelogen",
    "vorgemacht": "vormachen",
    "vorgemachte": "vorgemacht",
    "vorgemachtem": "vorgemacht",
    "vorgemachten": "vorgemacht",
    "vorgemachter": "vorgemacht",
    "vorgemachtes": "vorgemacht",
    "vorgemerkt": "vormerken",
    "vorgemerkte": "vorgemerkt",
    "vorgemerktem": "vorgemerkt",
    "vorgemerkten": "vorgemerkt",
    "vorgemerkter": "vorgemerkt",
    "vorgemerktes": "vorgemerkt",
    "vorgeneigt": "vorneigen",
    "vorgeneigte": "vorgeneigt",
    "vorgeneigtem": "vorgeneigt",
    "vorgeneigten": "vorgeneigt",
    "vorgeneigter": "vorgeneigt",
    "vorgeneigtes": "vorgeneigt",
    "vorgenommen": "vornehmen",
    "vorgenommene": "vorgenommen",
    "vorgenommenem": "vorgenommen",
    "vorgenommenen": "vorgenommen",
    "vorgenommener": "vorgenommen",
    "vorgenommenes": "vorgenommen",
    "vorgeordnet": "vorordnen",
    "vorgeordnete": "vorgeordnet",
    "vorgeordnetem": "vorgeordnet",
    "vorgeordneten": "vorgeordnet",
    "vorgeordneter": "vorgeordnet",
    "vorgeordnetes": "vorgeordnet",
    "vorgeprescht": "vorpreschen",
    "vorgepreschte": "vorgeprescht",
    "vorgepreschtem": "vorgeprescht",
    "vorgepreschten": "vorgeprescht",
    "vorgepreschter": "vorgeprescht",
    "vorgepreschtere": "vorgeprescht",
    "vorgepreschterem": "vorgeprescht",
    "vorgepreschteren": "vorgeprescht",
    "vorgepreschterer": "vorgeprescht",
    "vorgepreschteres": "vorgeprescht",
    "vorgepreschtes": "vorgeprescht",
    "vorgepreschteste": "vorgeprescht",
    "vorgepreschtestem": "vorgeprescht",
    "vorgepreschtesten": "vorgeprescht",
    "vorgepreschtester": "vorgeprescht",
    "vorgepreschtestes": "vorgeprescht",
    "vorgequellt": "vorquellen",
    "vorgequellte": "vorgequellt",
    "vorgequelltem": "vorgequellt",
    "vorgequellten": "vorgequellt",
    "vorgequellter": "vorgequellt",
    "vorgequelltes": "vorgequellt",
    "vorgequollen": "vorquellen",
    "vorgequollene": "vorgequollen",
    "vorgequollenem": "vorgequollen",
    "vorgequollenen": "vorgequollen",
    "vorgequollener": "vorgequollen",
    "vorgequollenes": "vorgequollen",
    "vorgerechnet": "vorrechnen",
    "vorgerechnete": "vorgerechnet",
    "vorgerechnetem": "vorgerechnet",
    "vorgerechneten": "vorgerechnet",
    "vorgerechneter": "vorgerechnet",
    "vorgerechnetes": "vorgerechnet",
    "vorgeredet": "vorreden",
    "vorgeredete": "vorgeredet",
    "vorgeredetem": "vorgeredet",
    "vorgeredeten": "vorgeredet",
    "vorgeredeter": "vorgeredet",
    "vorgeredetes": "vorgeredet",
    "vorgerichtet": "vorrichten",
    "vorgerichtete": "vorgerichtet",
    "vorgerichtetem": "vorgerichtet",
    "vorgerichteten": "vorgerichtet",
    "vorgerichteter": "vorgerichtet",
    "vorgerichtetes": "vorgerichtet",
    "vorgeritten": "vorreiten",
    "vorgerittene": "vorgeritten",
    "vorgerittenem": "vorgeritten",
    "vorgerittenen": "vorgeritten",
    "vorgerittener": "vorgeritten",
    "vorgerittenes": "vorgeritten",
    "vorgerückt": "vorrücken",
    "vorgerückte": "vorgerückt",
    "vorgerücktem": "vorgerückt",
    "vorgerückten": "vorgerückt",
    "vorgerückter": "vorgerückt",
    "vorgerücktes": "vorgerückt",
    "vorgesagt": "vorsagen",
    "vorgesagte": "vorgesagt",
    "vorgesagtem": "vorgesagt",
    "vorgesagten": "vorgesagt",
    "vorgesagter": "vorgesagt",
    "vorgesagtes": "vorgesagt",
    "vorgeschichtlichem": "vorgeschichtlich",
    "vorgeschichtlichen": "vorgeschichtlich",
    "vorgeschichtlicher": "vorgeschichtlich",
    "vorgeschichtliches": "vorgeschichtlich",
    "vorgeschlagen": "vorschlagen",
    "vorgeschlagene": "vorgeschlagen",
    "vorgeschlagenem": "vorgeschlagen",
    "vorgeschlagenen": "vorgeschlagen",
    "vorgeschlagener": "vorgeschlagen",
    "vorgeschlagenes": "vorgeschlagen",
    "vorgeschnitten": "vorschneiden",
    "vorgeschnittene": "vorgeschnitten",
    "vorgeschnittenem": "vorgeschnitten",
    "vorgeschnittenen": "vorgeschnitten",
    "vorgeschnittener": "vorgeschnitten",
    "vorgeschnittenes": "vorgeschnitten",
    "vorgeschoben": "vorschieben",
    "vorgeschobene": "vorgeschoben",
    "vorgeschobenem": "vorgeschoben",
    "vorgeschobenen": "vorgeschoben",
    "vorgeschobener": "vorgeschoben",
    "vorgeschobenes": "vorgeschoben",
    "vorgeschossen": "vorschießen",
    "vorgeschossene": "vorgeschossen",
    "vorgeschossenem": "vorgeschossen",
    "vorgeschossenen": "vorgeschossen",
    "vorgeschossener": "vorgeschossen",
    "vorgeschossenes": "vorgeschossen",
    "vorgeschrieben": "vorschreiben",
    "vorgeschriebene": "vorgeschrieben",
    "vorgeschriebenem": "vorgeschrieben",
    "vorgeschriebenen": "vorgeschrieben",
    "vorgeschriebener": "vorgeschrieben",
    "vorgeschriebenes": "vorgeschrieben",
    "vorgeschritten": "vorschreiten",
    "vorgeschrittene": "vorgeschritten",
    "vorgeschrittenem": "vorgeschritten",
    "vorgeschrittenen": "vorgeschritten",
    "vorgeschrittener": "vorgeschritten",
    "vorgeschrittenes": "vorgeschritten",
    "vorgeschwebt": "vorschweben",
    "vorgeschwebte": "vorgeschwebt",
    "vorgeschwebtem": "vorgeschwebt",
    "vorgeschwebten": "vorgeschwebt",
    "vorgeschwebter": "vorgeschwebt",
    "vorgeschwebtes": "vorgeschwebt",
    "vorgeschwindelt": "vorschwindeln",
    "vorgeschwindelte": "vorgeschwindelt",
    "vorgeschwindeltem": "vorgeschwindelt",
    "vorgeschwindelten": "vorgeschwindelt",
    "vorgeschwindelter": "vorgeschwindelt",
    "vorgeschwindeltes": "vorgeschwindelt",
    "vorgeschwärmt": "vorschwärmen",
    "vorgeschwärmte": "vorgeschwärmt",
    "vorgeschwärmtem": "vorgeschwärmt",
    "vorgeschwärmten": "vorgeschwärmt",
    "vorgeschwärmter": "vorgeschwärmt",
    "vorgeschwärmtes": "vorgeschwärmt",
    "vorgeschützt": "vorschützen",
    "vorgeschützte": "vorgeschützt",
    "vorgeschütztem": "vorgeschützt",
    "vorgeschützten": "vorgeschützt",
    "vorgeschützter": "vorgeschützt",
    "vorgeschütztes": "vorgeschützt",
    "vorgesehen": "vorsehen",
    "vorgesehene": "vorgesehen",
    "vorgesehenem": "vorgesehen",
    "vorgesehenen": "vorgesehen",
    "vorgesehener": "vorgesehen",
    "vorgesehenes": "vorgesehen",
    "vorgesessen": "vorsitzen",
    "vorgesessene": "vorgesessen",
    "vorgesessenem": "vorgesessen",
    "vorgesessenen": "vorgesessen",
    "vorgesessener": "vorgesessen",
    "vorgesessenes": "vorgesessen",
    "vorgesetzt": "vorsetzen",
    "vorgesetzte": "vorgesetzt",
    "vorgesetztem": "vorgesetzt",
    "vorgesetzten": "vorgesetzt",
    "vorgesetzter": "vorgesetzt",
    "vorgesetztes": "vorgesetzt",
    "vorgesorgt": "vorsorgen",
    "vorgesorgte": "vorgesorgt",
    "vorgesorgtem": "vorgesorgt",
    "vorgesorgten": "vorgesorgt",
    "vorgesorgter": "vorgesorgt",
    "vorgesorgtere": "vorgesorgt",
    "vorgesorgterem": "vorgesorgt",
    "vorgesorgteren": "vorgesorgt",
    "vorgesorgterer": "vorgesorgt",
    "vorgesorgteres": "vorgesorgt",
    "vorgesorgtes": "vorgesorgt",
    "vorgesorgteste": "vorgesorgt",
    "vorgesorgtestem": "vorgesorgt",
    "vorgesorgtesten": "vorgesorgt",
    "vorgesorgtester": "vorgesorgt",
    "vorgesorgtestes": "vorgesorgt",
    "vorgespannt": "vorspannen",
    "vorgespannte": "vorgespannt",
    "vorgespanntem": "vorgespannt",
    "vorgespannten": "vorgespannt",
    "vorgespannter": "vorgespannt",
    "vorgespanntes": "vorgespannt",
    "vorgespiegelt": "vorspiegeln",
    "vorgespiegelte": "vorgespiegelt",
    "vorgespiegeltem": "vorgespiegelt",
    "vorgespiegelten": "vorgespiegelt",
    "vorgespiegelter": "vorgespiegelt",
    "vorgespiegeltes": "vorgespiegelt",
    "vorgespielt": "vorspielen",
    "vorgespielte": "vorgespielt",
    "vorgespieltem": "vorgespielt",
    "vorgespielten": "vorgespielt",
    "vorgespielter": "vorgespielt",
    "vorgespieltes": "vorgespielt",
    "vorgesprochen": "vorsprechen",
    "vorgesprochene": "vorgesprochen",
    "vorgesprochenem": "vorgesprochen",
    "vorgesprochenen": "vorgesprochen",
    "vorgesprochener": "vorgesprochen",
    "vorgesprochenes": "vorgesprochen",
    "vorgesprungen": "vorspringen",
    "vorgesprungene": "vorgesprungen",
    "vorgesprungenem": "vorgesprungen",
    "vorgesprungenen": "vorgesprungen",
    "vorgesprungener": "vorgesprungen",
    "vorgesprungenes": "vorgesprungen",
    "vorgespult": "vorspulen",
    "vorgespulte": "vorgespult",
    "vorgespultem": "vorgespult",
    "vorgespulten": "vorgespult",
    "vorgespulter": "vorgespult",
    "vorgespultes": "vorgespult",
    "vorgestanden": "vorstehen",
    "vorgestandene": "vorgestanden",
    "vorgestandenem": "vorgestanden",
    "vorgestandenen": "vorgestanden",
    "vorgestandener": "vorgestanden",
    "vorgestandenes": "vorgestanden",
    "vorgestellt": "vorstellen",
    "vorgestellte": "vorgestellt",
    "vorgestelltem": "vorgestellt",
    "vorgestellten": "vorgestellt",
    "vorgestellter": "vorgestellt",
    "vorgestelltes": "vorgestellt",
    "vorgestoßen": "vorstoßen",
    "vorgestoßene": "vorgestoßen",
    "vorgestoßenem": "vorgestoßen",
    "vorgestoßenen": "vorgestoßen",
    "vorgestoßener": "vorgestoßen",
    "vorgestoßenes": "vorgestoßen",
    "vorgestülpt": "vorstülpen",
    "vorgestülpte": "vorgestülpt",
    "vorgestülptem": "vorgestülpt",
    "vorgestülpten": "vorgestülpt",
    "vorgestülpter": "vorgestülpt",
    "vorgestülptes": "vorgestülpt",
    "vorgestürmt": "vorstürmen",
    "vorgestürmte": "vorgestürmt",
    "vorgestürmtem": "vorgestürmt",
    "vorgestürmten": "vorgestürmt",
    "vorgestürmter": "vorgestürmt",
    "vorgestürmtes": "vorgestürmt",
    "vorgesungen": "vorsingen",
    "vorgesungene": "vorgesungen",
    "vorgesungenem": "vorgesungen",
    "vorgesungenen": "vorgesungen",
    "vorgesungener": "vorgesungen",
    "vorgesungenes": "vorgesungen",
    "vorgetanzt": "vortanzen",
    "vorgetanzte": "vorgetanzt",
    "vorgetanztem": "vorgetanzt",
    "vorgetanzten": "vorgetanzt",
    "vorgetanzter": "vorgetanzt",
    "vorgetanztes": "vorgetanzt",
    "vorgetragen": "vortragen",
    "vorgetragene": "vorgetragen",
    "vorgetragenem": "vorgetragen",
    "vorgetragenen": "vorgetragen",
    "vorgetragener": "vorgetragen",
    "vorgetragenes": "vorgetragen",
    "vorgetreten": "vortreten",
    "vorgetretene": "vorgetreten",
    "vorgetretenem": "vorgetreten",
    "vorgetretenen": "vorgetreten",
    "vorgetretener": "vorgetreten",
    "vorgetretenes": "vorgetreten",
    "vorgetrieben": "vortreiben",
    "vorgetriebene": "vorgetrieben",
    "vorgetriebenem": "vorgetrieben",
    "vorgetriebenen": "vorgetrieben",
    "vorgetriebener": "vorgetrieben",
    "vorgetriebenes": "vorgetrieben",
    "vorgeturnt": "vorturnen",
    "vorgeturnte": "vorgeturnt",
    "vorgeturntem": "vorgeturnt",
    "vorgeturnten": "vorgeturnt",
    "vorgeturnter": "vorgeturnt",
    "vorgeturntes": "vorgeturnt",
    "vorgetäuscht": "vortäuschen",
    "vorgetäuschte": "vorgetäuscht",
    "vorgetäuschtem": "vorgetäuscht",
    "vorgetäuschten": "vorgetäuscht",
    "vorgetäuschter": "vorgetäuscht",
    "vorgetäuschtes": "vorgetäuscht",
    "vorgewagt": "vorwagen",
    "vorgewagte": "vorgewagt",
    "vorgewagtem": "vorgewagt",
    "vorgewagten": "vorgewagt",
    "vorgewagter": "vorgewagt",
    "vorgewagtes": "vorgewagt",
    "vorgewarnt": "vorwarnen",
    "vorgewarnte": "vorgewarnt",
    "vorgewarntem": "vorgewarnt",
    "vorgewarnten": "vorgewarnt",
    "vorgewarnter": "vorgewarnt",
    "vorgewarntes": "vorgewarnt",
    "vorgewiesen": "vorweisen",
    "vorgewiesene": "vorgewiesen",
    "vorgewiesenem": "vorgewiesen",
    "vorgewiesenen": "vorgewiesen",
    "vorgewiesener": "vorgewiesen",
    "vorgewiesenes": "vorgewiesen",
    "vorgewogen": "vorwiegen",
    "vorgewogene": "vorgewogen",
    "vorgewogenem": "vorgewogen",
    "vorgewogenen": "vorgewogen",
    "vorgewogener": "vorgewogen",
    "vorgewogenes": "vorgewogen",
    "vorgeworfen": "vorwerfen",
    "vorgeworfene": "vorgeworfen",
    "vorgeworfenem": "vorgeworfen",
    "vorgeworfenen": "vorgeworfen",
    "vorgeworfener": "vorgeworfen",
    "vorgeworfenes": "vorgeworfen",
    "vorgewählt": "vorwählen",
    "vorgewählte": "vorgewählt",
    "vorgewähltem": "vorgewählt",
    "vorgewählten": "vorgewählt",
    "vorgewählter": "vorgewählt",
    "vorgewähltes": "vorgewählt",
    "vorgewärmt": "vorwärmen",
    "vorgewärmte": "vorgewärmt",
    "vorgewärmtem": "vorgewärmt",
    "vorgewärmten": "vorgewärmt",
    "vorgewärmter": "vorgewärmt",
    "vorgewärmtere": "vorgewärmt",
    "vorgewärmterem": "vorgewärmt",
    "vorgewärmteren": "vorgewärmt",
    "vorgewärmterer": "vorgewärmt",
    "vorgewärmteres": "vorgewärmt",
    "vorgewärmtes": "vorgewärmt",
    "vorgewärmteste": "vorgewärmt",
    "vorgewärmtestem": "vorgewärmt",
    "vorgewärmtesten": "vorgewärmt",
    "vorgewärmtester": "vorgewärmt",
    "vorgewärmtestes": "vorgewärmt",
    "vorgewölbt": "vorwölben",
    "vorgewölbte": "vorgewölbt",
    "vorgewölbtem": "vorgewölbt",
    "vorgewölbten": "vorgewölbt",
    "vorgewölbter": "vorgewölbt",
    "vorgewölbtere": "vorgewölbt",
    "vorgewölbterem": "vorgewölbt",
    "vorgewölbteren": "vorgewölbt",
    "vorgewölbterer": "vorgewölbt",
    "vorgewölbteres": "vorgewölbt",
    "vorgewölbtes": "vorgewölbt",
    "vorgewölbteste": "vorgewölbt",
    "vorgewölbtestem": "vorgewölbt",
    "vorgewölbtesten": "vorgewölbt",
    "vorgewölbtester": "vorgewölbt",
    "vorgewölbtestes": "vorgewölbt",
    "vorgezaubert": "vorzaubern",
    "vorgezauberte": "vorgezaubert",
    "vorgezaubertem": "vorgezaubert",
    "vorgezauberten": "vorgezaubert",
    "vorgezauberter": "vorgezaubert",
    "vorgezaubertes": "vorgezaubert",
    "vorgezeichnet": "vorzeichnen",
    "vorgezeichnete": "vorgezeichnet",
    "vorgezeichnetem": "vorgezeichnet",
    "vorgezeichneten": "vorgezeichnet",
    "vorgezeichneter": "vorgezeichnet",
    "vorgezeichnetes": "vorgezeichnet",
    "vorgezeigt": "vorzeigen",
    "vorgezeigte": "vorgezeigt",
    "vorgezeigtem": "vorgezeigt",
    "vorgezeigten": "vorgezeigt",
    "vorgezeigter": "vorgezeigt",
    "vorgezeigtes": "vorgezeigt",
    "vorgezogen": "vorziehen",
    "vorgezogene": "vorgezogen",
    "vorgezogenem": "vorgezogen",
    "vorgezogenen": "vorgezogen",
    "vorgezogener": "vorgezogen",
    "vorgezogenes": "vorgezogen",
    "vorgezählt": "vorzählen",
    "vorgezählte": "vorgezählt",
    "vorgezähltem": "vorgezählt",
    "vorgezählten": "vorgezählt",
    "vorgezählter": "vorgezählt",
    "vorgezähltes": "vorgezählt",
    "vorgibst": "vorgeben",
    "vorgibt": "vorgeben",
    "vorging": "vorgehen",
    "vorginge": "vorgehen",
    "vorgingen": "vorgehen",
    "vorgingest": "vorgehen",
    "vorginget": "vorgehen",
    "vorgingst": "vorgehen",
    "vorgingt": "vorgehen",
    "vorgreife": "vorgreifen",
    "vorgreifend": "vorgreifen",
    "vorgreifende": "vorgreifend",
    "vorgreifendem": "vorgreifend",
    "vorgreifenden": "vorgreifend",
    "vorgreifender": "vorgreifend",
    "vorgreifendere": "vorgreifend",
    "vorgreifenderem": "vorgreifend",
    "vorgreifenderen": "vorgreifend",
    "vorgreifenderer": "vorgreifend",
    "vorgreifenderes": "vorgreifend",
    "vorgreifendes": "vorgreifend",
    "vorgreifendste": "vorgreifend",
    "vorgreifendstem": "vorgreifend",
    "vorgreifendsten": "vorgreifend",
    "vorgreifendster": "vorgreifend",
    "vorgreifendstes": "vorgreifend",
    "vorgreifest": "vorgreifen",
    "vorgreifet": "vorgreifen",
    "vorgreifst": "vorgreifen",
    "vorgreift": "vorgreifen",
    "vorgriff": "vorgreifen",
    "vorgriffest": "vorgreifen",
    "vorgriffet": "vorgreifen",
    "vorgriffst": "vorgreifen",
    "vorgrifft": "vorgreifen",
    "vorgäbe": "vorgeben",
    "vorgäben": "vorgeben",
    "vorgäbest": "vorgeben",
    "vorgäbet": "vorgeben",
    "vorhalte": "vorhalten",
    "vorhaltend": "vorhalten",
    "vorhaltende": "vorhaltend",
    "vorhaltendem": "vorhaltend",
    "vorhaltenden": "vorhaltend",
    "vorhaltender": "vorhaltend",
    "vorhaltendes": "vorhaltend",
    "vorhaltest": "vorhalten",
    "vorhaltet": "vorhalten",
    "vorhandene": "vorhanden",
    "vorhandenem": "vorhanden",
    "vorhandenen": "vorhanden",
    "vorhandener": "vorhanden",
    "vorhandenes": "vorhanden",
    "vorharre": "vorharren",
    "vorharrend": "vorharren",
    "vorharrest": "vorharren",
    "vorharret": "vorharren",
    "vorharrst": "vorharren",
    "vorharrt": "vorharren",
    "vorharrte": "vorharren",
    "vorharrten": "vorharren",
    "vorharrtest": "vorharren",
    "vorharrtet": "vorharren",
    "vorherfahre": "vorherfahren",
    "vorherfahrend": "vorherfahren",
    "vorherfahrende": "vorherfahrend",
    "vorherfahrendem": "vorherfahrend",
    "vorherfahrenden": "vorherfahrend",
    "vorherfahrender": "vorherfahrend",
    "vorherfahrendes": "vorherfahrend",
    "vorherfahrest": "vorherfahren",
    "vorherfahret": "vorherfahren",
    "vorherfahrt": "vorherfahren",
    "vorherfuhr": "vorherfahren",
    "vorherfuhren": "vorherfahren",
    "vorherfuhrst": "vorherfahren",
    "vorherfuhrt": "vorherfahren",
    "vorherfährst": "vorherfahren",
    "vorherfährt": "vorherfahren",
    "vorherführe": "vorherfahren",
    "vorherführen": "vorherfahren",
    "vorherführest": "vorherfahren",
    "vorherführet": "vorherfahren",
    "vorhergefahren": "vorherfahren",
    "vorhergefahrene": "vorhergefahren",
    "vorhergefahrenem": "vorhergefahren",
    "vorhergefahrenen": "vorhergefahren",
    "vorhergefahrener": "vorhergefahren",
    "vorhergefahrenes": "vorhergefahren",
    "vorhergesagt": "vorhersagen",
    "vorhergesagte": "vorhergesagt",
    "vorhergesagtem": "vorhergesagt",
    "vorhergesagten": "vorhergesagt",
    "vorhergesagter": "vorhergesagt",
    "vorhergesagtes": "vorhergesagt",
    "vorhergesprungen": "vorherspringen",
    "vorhergesprungene": "vorhergesprungen",
    "vorhergesprungenem": "vorhergesprungen",
    "vorhergesprungenen": "vorhergesprungen",
    "vorhergesprungener": "vorhergesprungen",
    "vorhergesprungenes": "vorhergesprungen",
    "vorherige": "vorherig",
    "vorherigem": "vorherig",
    "vorherigen": "vorherig",
    "vorheriger": "vorherig",
    "vorheriges": "vorherig",
    "vorherrsche": "vorherrschen",
    "vorherrschend": "vorherrschen",
    "vorherrschende": "vorherrschend",
    "vorherrschendem": "vorherrschend",
    "vorherrschenden": "vorherrschend",
    "vorherrschender": "vorherrschend",
    "vorherrschendere": "vorherrschend",
    "vorherrschenderem": "vorherrschend",
    "vorherrschenderen": "vorherrschend",
    "vorherrschenderer": "vorherrschend",
    "vorherrschenderes": "vorherrschend",
    "vorherrschendes": "vorherrschend",
    "vorherrschendste": "vorherrschend",
    "vorherrschendstem": "vorherrschend",
    "vorherrschendsten": "vorherrschend",
    "vorherrschendster": "vorherrschend",
    "vorherrschendstes": "vorherrschend",
    "vorherrschest": "vorherrschen",
    "vorherrschet": "vorherrschen",
    "vorherrschst": "vorherrschen",
    "vorherrscht": "vorherrschen",
    "vorherrschte": "vorherrschen",
    "vorherrschten": "vorherrschen",
    "vorherrschtest": "vorherrschen",
    "vorherrschtet": "vorherrschen",
    "vorhersage": "vorhersagen",
    "vorhersagend": "vorhersagen",
    "vorhersagende": "vorhersagend",
    "vorhersagendem": "vorhersagend",
    "vorhersagenden": "vorhersagend",
    "vorhersagender": "vorhersagend",
    "vorhersagendes": "vorhersagend",
    "vorhersagest": "vorhersagen",
    "vorhersaget": "vorhersagen",
    "vorhersagst": "vorhersagen",
    "vorhersagt": "vorhersagen",
    "vorhersagte": "vorhersagen",
    "vorhersagten": "vorhersagen",
    "vorhersagtest": "vorhersagen",
    "vorhersagtet": "vorhersagen",
    "vorhersehbare": "vorhersehbar",
    "vorhersehbarem": "vorhersehbar",
    "vorhersehbaren": "vorhersehbar",
    "vorhersehbarer": "vorhersehbar",
    "vorhersehbarere": "vorhersehbar",
    "vorhersehbarerem": "vorhersehbar",
    "vorhersehbareren": "vorhersehbar",
    "vorhersehbarerer": "vorhersehbar",
    "vorhersehbareres": "vorhersehbar",
    "vorhersehbares": "vorhersehbar",
    "vorhersehbarste": "vorhersehbar",
    "vorhersehbarstem": "vorhersehbar",
    "vorhersehbarsten": "vorhersehbar",
    "vorhersehbarster": "vorhersehbar",
    "vorhersehbarstes": "vorhersehbar",
    "vorhersprang": "vorherspringen",
    "vorhersprangen": "vorherspringen",
    "vorhersprangst": "vorherspringen",
    "vorhersprangt": "vorherspringen",
    "vorherspringe": "vorherspringen",
    "vorherspringend": "vorherspringen",
    "vorherspringende": "vorherspringend",
    "vorherspringendem": "vorherspringend",
    "vorherspringenden": "vorherspringend",
    "vorherspringender": "vorherspringend",
    "vorherspringendes": "vorherspringend",
    "vorherspringest": "vorherspringen",
    "vorherspringet": "vorherspringen",
    "vorherspringst": "vorherspringen",
    "vorherspringt": "vorherspringen",
    "vorherspränge": "vorherspringen",
    "vorhersprängen": "vorherspringen",
    "vorhersprängest": "vorherspringen",
    "vorherspränget": "vorherspringen",
    "vorherzufahren": "vorherfahren",
    "vorherzusagen": "vorhersagen",
    "vorherzuspringen": "vorherspringen",
    "vorheuchele": "vorheucheln",
    "vorheuchelnd": "vorheucheln",
    "vorheuchelnde": "vorheuchelnd",
    "vorheuchelndem": "vorheuchelnd",
    "vorheuchelnden": "vorheuchelnd",
    "vorheuchelnder": "vorheuchelnd",
    "vorheuchelndere": "vorheuchelnd",
    "vorheuchelnderem": "vorheuchelnd",
    "vorheuchelnderen": "vorheuchelnd",
    "vorheuchelnderer": "vorheuchelnd",
    "vorheuchelnderes": "vorheuchelnd",
    "vorheuchelndes": "vorheuchelnd",
    "vorheuchelndste": "vorheuchelnd",
    "vorheuchelndstem": "vorheuchelnd",
    "vorheuchelndsten": "vorheuchelnd",
    "vorheuchelndster": "vorheuchelnd",
    "vorheuchelndstes": "vorheuchelnd",
    "vorheuchelst": "vorheucheln",
    "vorheuchelt": "vorheucheln",
    "vorheuchelte": "vorheucheln",
    "vorheuchelten": "vorheucheln",
    "vorheucheltest": "vorheucheln",
    "vorheucheltet": "vorheucheln",
    "vorheuchle": "vorheucheln",
    "vorheule": "vorheulen",
    "vorheulend": "vorheulen",
    "vorheulende": "vorheulend",
    "vorheulendem": "vorheulend",
    "vorheulenden": "vorheulend",
    "vorheulender": "vorheulend",
    "vorheulendere": "vorheulend",
    "vorheulenderem": "vorheulend",
    "vorheulenderen": "vorheulend",
    "vorheulenderer": "vorheulend",
    "vorheulenderes": "vorheulend",
    "vorheulendes": "vorheulend",
    "vorheulendste": "vorheulend",
    "vorheulendstem": "vorheulend",
    "vorheulendsten": "vorheulend",
    "vorheulendster": "vorheulend",
    "vorheulendstes": "vorheulend",
    "vorheulest": "vorheulen",
    "vorheulet": "vorheulen",
    "vorheulst": "vorheulen",
    "vorheult": "vorheulen",
    "vorheulte": "vorheulen",
    "vorheulten": "vorheulen",
    "vorheultest": "vorheulen",
    "vorheultet": "vorheulen",
    "vorhielt": "vorhalten",
    "vorhielte": "vorhalten",
    "vorhielten": "vorhalten",
    "vorhieltest": "vorhalten",
    "vorhieltet": "vorhalten",
    "vorhing": "vorhängen",
    "vorhinge": "vorhängen",
    "vorhingen": "vorhängen",
    "vorhingest": "vorhängen",
    "vorhinget": "vorhängen",
    "vorhingst": "vorhängen",
    "vorhingt": "vorhängen",
    "vorhält": "vorhalten",
    "vorhältst": "vorhalten",
    "vorhängend": "vorhängen",
    "vorhängende": "vorhängend",
    "vorhängendem": "vorhängend",
    "vorhängenden": "vorhängend",
    "vorhängender": "vorhängend",
    "vorhängendes": "vorhängend",
    "vorhängest": "vorhängen",
    "vorhänget": "vorhängen",
    "vorhängst": "vorhängen",
    "vorhängt": "vorhängen",
    "vorhängte": "vorhängen",
    "vorhängten": "vorhängen",
    "vorhängtest": "vorhängen",
    "vorhängtet": "vorhängen",
    "vorigem": "vorig",
    "vorigen": "vorig",
    "voriger": "vorig",
    "voriges": "vorig",
    "vorjammere": "vorjammern",
    "vorjammernd": "vorjammern",
    "vorjammernde": "vorjammernd",
    "vorjammerndem": "vorjammernd",
    "vorjammernden": "vorjammernd",
    "vorjammernder": "vorjammernd",
    "vorjammerndere": "vorjammernd",
    "vorjammernderem": "vorjammernd",
    "vorjammernderen": "vorjammernd",
    "vorjammernderer": "vorjammernd",
    "vorjammernderes": "vorjammernd",
    "vorjammerndes": "vorjammernd",
    "vorjammerndste": "vorjammernd",
    "vorjammerndstem": "vorjammernd",
    "vorjammerndsten": "vorjammernd",
    "vorjammerndster": "vorjammernd",
    "vorjammerndstes": "vorjammernd",
    "vorjammerst": "vorjammern",
    "vorjammert": "vorjammern",
    "vorjammerte": "vorjammern",
    "vorjammerten": "vorjammern",
    "vorjammertest": "vorjammern",
    "vorjammertet": "vorjammern",
    "vorkam": "vorkommen",
    "vorkamen": "vorkommen",
    "vorkamst": "vorkommen",
    "vorkamt": "vorkommen",
    "vorkaue": "vorkauen",
    "vorkauend": "vorkauen",
    "vorkauende": "vorkauend",
    "vorkauendem": "vorkauend",
    "vorkauenden": "vorkauend",
    "vorkauender": "vorkauend",
    "vorkauendere": "vorkauend",
    "vorkauenderem": "vorkauend",
    "vorkauenderen": "vorkauend",
    "vorkauenderer": "vorkauend",
    "vorkauenderes": "vorkauend",
    "vorkauendes": "vorkauend",
    "vorkauendste": "vorkauend",
    "vorkauendstem": "vorkauend",
    "vorkauendsten": "vorkauend",
    "vorkauendster": "vorkauend",
    "vorkauendstes": "vorkauend",
    "vorkauest": "vorkauen",
    "vorkauet": "vorkauen",
    "vorkaust": "vorkauen",
    "vorkaut": "vorkauen",
    "vorkaute": "vorkauen",
    "vorkauten": "vorkauen",
    "vorkautest": "vorkauen",
    "vorkautet": "vorkauen",
    "vorkehre": "vorkehren",
    "vorkehrend": "vorkehren",
    "vorkehrende": "vorkehrend",
    "vorkehrendem": "vorkehrend",
    "vorkehrenden": "vorkehrend",
    "vorkehrender": "vorkehrend",
    "vorkehrendes": "vorkehrend",
    "vorkehrest": "vorkehren",
    "vorkehret": "vorkehren",
    "vorkehrst": "vorkehren",
    "vorkehrt": "vorkehren",
    "vorkehrte": "vorkehren",
    "vorkehrten": "vorkehren",
    "vorkehrtest": "vorkehren",
    "vorkehrtet": "vorkehren",
    "vorkeime": "vorkeimen",
    "vorkeimend": "vorkeimen",
    "vorkeimende": "vorkeimend",
    "vorkeimendem": "vorkeimend",
    "vorkeimenden": "vorkeimend",
    "vorkeimender": "vorkeimend",
    "vorkeimendere": "vorkeimend",
    "vorkeimenderem": "vorkeimend",
    "vorkeimenderen": "vorkeimend",
    "vorkeimenderer": "vorkeimend",
    "vorkeimenderes": "vorkeimend",
    "vorkeimendes": "vorkeimend",
    "vorkeimendste": "vorkeimend",
    "vorkeimendstem": "vorkeimend",
    "vorkeimendsten": "vorkeimend",
    "vorkeimendster": "vorkeimend",
    "vorkeimendstes": "vorkeimend",
    "vorkeimest": "vorkeimen",
    "vorkeimet": "vorkeimen",
    "vorkeimst": "vorkeimen",
    "vorkeimt": "vorkeimen",
    "vorkeimte": "vorkeimen",
    "vorkeimten": "vorkeimen",
    "vorkeimtest": "vorkeimen",
    "vorkeimtet": "vorkeimen",
    "vorknöpfe": "vorknöpfen",
    "vorknöpfend": "vorknöpfen",
    "vorknöpfende": "vorknöpfend",
    "vorknöpfendem": "vorknöpfend",
    "vorknöpfenden": "vorknöpfend",
    "vorknöpfender": "vorknöpfend",
    "vorknöpfendes": "vorknöpfend",
    "vorknöpfest": "vorknöpfen",
    "vorknöpfet": "vorknöpfen",
    "vorknöpfst": "vorknöpfen",
    "vorknöpft": "vorknöpfen",
    "vorknöpfte": "vorknöpfen",
    "vorknöpften": "vorknöpfen",
    "vorknöpftest": "vorknöpfen",
    "vorknöpftet": "vorknöpfen",
    "vorkomme": "vorkommen",
    "vorkommend": "vorkommen",
    "vorkommende": "vorkommend",
    "vorkommendem": "vorkommend",
    "vorkommenden": "vorkommend",
    "vorkommender": "vorkommend",
    "vorkommendes": "vorkommend",
    "vorkommest": "vorkommen",
    "vorkommet": "vorkommen",
    "vorkommst": "vorkommen",
    "vorkommt": "vorkommen",
    "vorkäme": "vorkommen",
    "vorkämen": "vorkommen",
    "vorkämest": "vorkommen",
    "vorkämet": "vorkommen",
    "vorlade": "vorladen",
    "vorladend": "vorladen",
    "vorladende": "vorladend",
    "vorladendem": "vorladend",
    "vorladenden": "vorladend",
    "vorladender": "vorladend",
    "vorladendes": "vorladend",
    "vorladest": "vorladen",
    "vorladet": "vorladen",
    "vorlag": "vorliegen",
    "vorlagst": "vorliegen",
    "vorlagt": "vorliegen",
    "vorlas": "vorlesen",
    "vorlasen": "vorlesen",
    "vorlast": "vorlesen",
    "vorlaufend": "vorlaufen",
    "vorlaufende": "vorlaufend",
    "vorlaufendem": "vorlaufend",
    "vorlaufenden": "vorlaufend",
    "vorlaufender": "vorlaufend",
    "vorlaufendes": "vorlaufend",
    "vorlaufest": "vorlaufen",
    "vorlaufet": "vorlaufen",
    "vorlauft": "vorlaufen",
    "vorlaute": "vorlaut",
    "vorlautem": "vorlaut",
    "vorlauten": "vorlaut",
    "vorlauter": "vorlaut",
    "vorlautere": "vorlaut",
    "vorlauterem": "vorlaut",
    "vorlauteren": "vorlaut",
    "vorlauterer": "vorlaut",
    "vorlauteres": "vorlaut",
    "vorlautes": "vorlaut",
    "vorlauteste": "vorlaut",
    "vorlautestem": "vorlaut",
    "vorlautesten": "vorlaut",
    "vorlautester": "vorlaut",
    "vorlautestes": "vorlaut",
    "vorlebe": "vorleben",
    "vorlebend": "vorleben",
    "vorlebende": "vorlebend",
    "vorlebendem": "vorlebend",
    "vorlebenden": "vorlebend",
    "vorlebender": "vorlebend",
    "vorlebendes": "vorlebend",
    "vorlebest": "vorleben",
    "vorlebet": "vorleben",
    "vorlebst": "vorleben",
    "vorlebt": "vorleben",
    "vorlebte": "vorleben",
    "vorlebten": "vorleben",
    "vorlebtest": "vorleben",
    "vorlebtet": "vorleben",
    "vorlege": "vorlegen",
    "vorlegend": "vorlegen",
    "vorlegende": "vorlegend",
    "vorlegendem": "vorlegend",
    "vorlegenden": "vorlegend",
    "vorlegender": "vorlegend",
    "vorlegendes": "vorlegend",
    "vorlegest": "vorlegen",
    "vorleget": "vorlegen",
    "vorlegst": "vorlegen",
    "vorlegt": "vorlegen",
    "vorlegte": "vorlegen",
    "vorlegten": "vorlegen",
    "vorlegtest": "vorlegen",
    "vorlegtet": "vorlegen",
    "vorlesend": "vorlesen",
    "vorlesende": "vorlesend",
    "vorlesendem": "vorlesend",
    "vorlesenden": "vorlesend",
    "vorlesender": "vorlesend",
    "vorlesendes": "vorlesend",
    "vorlesest": "vorlesen",
    "vorleset": "vorlesen",
    "vorlest": "vorlesen",
    "vorletztem": "vorletzte",
    "vorletzten": "vorletzte",
    "vorletzter": "vorletzte",
    "vorletztes": "vorletzte",
    "vorlief": "vorlaufen",
    "vorliefe": "vorlaufen",
    "vorliefen": "vorlaufen",
    "vorliefest": "vorlaufen",
    "vorliefet": "vorlaufen",
    "vorliefst": "vorlaufen",
    "vorlieft": "vorlaufen",
    "vorliege": "vorliegen",
    "vorliegend": "vorliegen",
    "vorliegende": "vorliegend",
    "vorliegendem": "vorliegend",
    "vorliegenden": "vorliegend",
    "vorliegender": "vorliegend",
    "vorliegendes": "vorliegend",
    "vorliegest": "vorliegen",
    "vorlieget": "vorliegen",
    "vorliegst": "vorliegen",
    "vorliegt": "vorliegen",
    "vorliest": "vorlesen",
    "vorlog": "vorlügen",
    "vorlogen": "vorlügen",
    "vorlogst": "vorlügen",
    "vorlogt": "vorlügen",
    "vorlud": "vorladen",
    "vorluden": "vorladen",
    "vorludest": "vorladen",
    "vorludet": "vorladen",
    "vorlädst": "vorladen",
    "vorlädt": "vorladen",
    "vorläge": "vorliegen",
    "vorlägen": "vorliegen",
    "vorlägest": "vorliegen",
    "vorläget": "vorliegen",
    "vorläse": "vorlesen",
    "vorläsen": "vorlesen",
    "vorläsest": "vorlesen",
    "vorläset": "vorlesen",
    "vorläufige": "vorläufig",
    "vorläufigem": "vorläufig",
    "vorläufigen": "vorläufig",
    "vorläufiger": "vorläufig",
    "vorläufiges": "vorläufig",
    "vorläufst": "vorlaufen",
    "vorläuft": "vorlaufen",
    "vorlöge": "vorlügen",
    "vorlögen": "vorlügen",
    "vorlögest": "vorlügen",
    "vorlöget": "vorlügen",
    "vorlüde": "vorladen",
    "vorlüden": "vorladen",
    "vorlüdest": "vorladen",
    "vorlüdet": "vorladen",
    "vorlüge": "vorlügen",
    "vorlügend": "vorlügen",
    "vorlügende": "vorlügend",
    "vorlügendem": "vorlügend",
    "vorlügenden": "vorlügend",
    "vorlügender": "vorlügend",
    "vorlügendere": "vorlügend",
    "vorlügenderem": "vorlügend",
    "vorlügenderen": "vorlügend",
    "vorlügenderer": "vorlügend",
    "vorlügenderes": "vorlügend",
    "vorlügendes": "vorlügend",
    "vorlügendste": "vorlügend",
    "vorlügendstem": "vorlügend",
    "vorlügendsten": "vorlügend",
    "vorlügendster": "vorlügend",
    "vorlügendstes": "vorlügend",
    "vorlügest": "vorlügen",
    "vorlüget": "vorlügen",
    "vorlügst": "vorlügen",
    "vorlügt": "vorlügen",
    "vormache": "vormachen",
    "vormachend": "vormachen",
    "vormachende": "vormachend",
    "vormachendem": "vormachend",
    "vormachenden": "vormachend",
    "vormachender": "vormachend",
    "vormachendes": "vormachend",
    "vormachest": "vormachen",
    "vormachet": "vormachen",
    "vormachst": "vormachen",
    "vormacht": "vormachen",
    "vormachte": "vormachen",
    "vormachten": "vormachen",
    "vormachtest": "vormachen",
    "vormachtet": "vormachen",
    "vormalige": "vormalig",
    "vormaligem": "vormalig",
    "vormaligen": "vormalig",
    "vormaliger": "vormalig",
    "vormaliges": "vormalig",
    "vormerke": "vormerken",
    "vormerkend": "vormerken",
    "vormerkende": "vormerkend",
    "vormerkendem": "vormerkend",
    "vormerkenden": "vormerkend",
    "vormerkender": "vormerkend",
    "vormerkendes": "vormerkend",
    "vormerkest": "vormerken",
    "vormerket": "vormerken",
    "vormerkst": "vormerken",
    "vormerkt": "vormerken",
    "vormerkte": "vormerken",
    "vormerkten": "vormerken",
    "vormerktest": "vormerken",
    "vormerktet": "vormerken",
    "vornahm": "vornehmen",
    "vornahmen": "vornehmen",
    "vornahmst": "vornehmen",
    "vornahmt": "vornehmen",
    "vornehme": "vornehmen",
    "vornehmem": "vornehm",
    "vornehmen": "vornehm",
    "vornehmend": "vornehmen",
    "vornehmende": "vornehmend",
    "vornehmendem": "vornehmend",
    "vornehmenden": "vornehmend",
    "vornehmender": "vornehmend",
    "vornehmendes": "vornehmend",
    "vornehmer": "vornehm",
    "vornehmere": "vornehm",
    "vornehmerem": "vornehm",
    "vornehmeren": "vornehm",
    "vornehmerer": "vornehm",
    "vornehmeres": "vornehm",
    "vornehmes": "vornehm",
    "vornehmest": "vornehmen",
    "vornehmet": "vornehmen",
    "vornehmste": "vornehm",
    "vornehmstem": "vornehm",
    "vornehmsten": "vornehm",
    "vornehmster": "vornehm",
    "vornehmstes": "vornehm",
    "vornehmt": "vornehmen",
    "vorneige": "vorneigen",
    "vorneigend": "vorneigen",
    "vorneigende": "vorneigend",
    "vorneigendem": "vorneigend",
    "vorneigenden": "vorneigend",
    "vorneigender": "vorneigend",
    "vorneigendes": "vorneigend",
    "vorneigest": "vorneigen",
    "vorneiget": "vorneigen",
    "vorneigst": "vorneigen",
    "vorneigt": "vorneigen",
    "vorneigte": "vorneigen",
    "vorneigten": "vorneigen",
    "vorneigtest": "vorneigen",
    "vorneigtet": "vorneigen",
    "vornimmst": "vornehmen",
    "vornimmt": "vornehmen",
    "vornähme": "vornehmen",
    "vornähmen": "vornehmen",
    "vornähmest": "vornehmen",
    "vornähmet": "vornehmen",
    "vorordne": "vorordnen",
    "vorordnend": "vorordnen",
    "vorordnende": "vorordnend",
    "vorordnendem": "vorordnend",
    "vorordnenden": "vorordnend",
    "vorordnender": "vorordnend",
    "vorordnendes": "vorordnend",
    "vorordnest": "vorordnen",
    "vorordnet": "vorordnen",
    "vorordnete": "vorordnen",
    "vorordneten": "vorordnen",
    "vorordnetest": "vorordnen",
    "vorordnetet": "vorordnen",
    "vorpresche": "vorpreschen",
    "vorpreschend": "vorpreschen",
    "vorpreschende": "vorpreschend",
    "vorpreschendem": "vorpreschend",
    "vorpreschenden": "vorpreschend",
    "vorpreschender": "vorpreschend",
    "vorpreschendere": "vorpreschend",
    "vorpreschenderem": "vorpreschend",
    "vorpreschenderen": "vorpreschend",
    "vorpreschenderer": "vorpreschend",
    "vorpreschenderes": "vorpreschend",
    "vorpreschendes": "vorpreschend",
    "vorpreschendste": "vorpreschend",
    "vorpreschendstem": "vorpreschend",
    "vorpreschendsten": "vorpreschend",
    "vorpreschendster": "vorpreschend",
    "vorpreschendstes": "vorpreschend",
    "vorpreschest": "vorpreschen",
    "vorpreschet": "vorpreschen",
    "vorpreschst": "vorpreschen",
    "vorprescht": "vorpreschen",
    "vorpreschte": "vorpreschen",
    "vorpreschten": "vorpreschen",
    "vorpreschtest": "vorpreschen",
    "vorpreschtet": "vorpreschen",
    "vorprogrammiere": "vorprogrammieren",
    "vorprogrammierend": "vorprogrammieren",
    "vorprogrammierende": "vorprogrammierend",
    "vorprogrammierendem": "vorprogrammierend",
    "vorprogrammierenden": "vorprogrammierend",
    "vorprogrammierender": "vorprogrammierend",
    "vorprogrammierendes": "vorprogrammierend",
    "vorprogrammierest": "vorprogrammieren",
    "vorprogrammieret": "vorprogrammieren",
    "vorprogrammierst": "vorprogrammieren",
    "vorprogrammiert": "vorprogrammieren",
    "vorprogrammierte": "vorprogrammieren",
    "vorprogrammiertem": "vorprogrammiert",
    "vorprogrammierten": "vorprogrammieren",
    "vorprogrammierter": "vorprogrammiert",
    "vorprogrammiertes": "vorprogrammiert",
    "vorprogrammiertest": "vorprogrammieren",
    "vorprogrammiertet": "vorprogrammieren",
    "vorquelle": "vorquellen",
    "vorquellend": "vorquellen",
    "vorquellende": "vorquellend",
    "vorquellendem": "vorquellend",
    "vorquellenden": "vorquellend",
    "vorquellender": "vorquellend",
    "vorquellendes": "vorquellend",
    "vorquellest": "vorquellen",
    "vorquellet": "vorquellen",
    "vorquellst": "vorquellen",
    "vorquellt": "vorquellen",
    "vorquellte": "vorquellen",
    "vorquellten": "vorquellen",
    "vorquelltest": "vorquellen",
    "vorquelltet": "vorquellen",
    "vorquillst": "vorquellen",
    "vorquillt": "vorquellen",
    "vorquoll": "vorquellen",
    "vorquollen": "vorquellen",
    "vorquollst": "vorquellen",
    "vorquollt": "vorquellen",
    "vorquölle": "vorquellen",
    "vorquöllen": "vorquellen",
    "vorquöllest": "vorquellen",
    "vorquöllet": "vorquellen",
    "vorrangigem": "vorrangig",
    "vorrangigen": "vorrangig",
    "vorrangiger": "vorrangig",
    "vorrangigere": "vorrangig",
    "vorrangigerem": "vorrangig",
    "vorrangigeren": "vorrangig",
    "vorrangigerer": "vorrangig",
    "vorrangigeres": "vorrangig",
    "vorrangiges": "vorrangig",
    "vorrangigste": "vorrangig",
    "vorrangigstem": "vorrangig",
    "vorrangigsten": "vorrangig",
    "vorrangigster": "vorrangig",
    "vorrangigstes": "vorrangig",
    "vorrechne": "vorrechnen",
    "vorrechnend": "vorrechnen",
    "vorrechnende": "vorrechnend",
    "vorrechnendem": "vorrechnend",
    "vorrechnenden": "vorrechnend",
    "vorrechnender": "vorrechnend",
    "vorrechnendes": "vorrechnend",
    "vorrechnest": "vorrechnen",
    "vorrechnet": "vorrechnen",
    "vorrechnete": "vorrechnen",
    "vorrechneten": "vorrechnen",
    "vorrechnetest": "vorrechnen",
    "vorrechnetet": "vorrechnen",
    "vorredend": "vorreden",
    "vorredende": "vorredend",
    "vorredendem": "vorredend",
    "vorredenden": "vorredend",
    "vorredender": "vorredend",
    "vorredendes": "vorredend",
    "vorredest": "vorreden",
    "vorredet": "vorreden",
    "vorredete": "vorreden",
    "vorredeten": "vorreden",
    "vorredetest": "vorreden",
    "vorredetet": "vorreden",
    "vorreite": "vorreiten",
    "vorreitend": "vorreiten",
    "vorreitende": "vorreitend",
    "vorreitendem": "vorreitend",
    "vorreitenden": "vorreitend",
    "vorreitender": "vorreitend",
    "vorreitendes": "vorreitend",
    "vorreitest": "vorreiten",
    "vorreitet": "vorreiten",
    "vorrichte": "vorrichten",
    "vorrichtend": "vorrichten",
    "vorrichtende": "vorrichtend",
    "vorrichtendem": "vorrichtend",
    "vorrichtenden": "vorrichtend",
    "vorrichtender": "vorrichtend",
    "vorrichtendes": "vorrichtend",
    "vorrichtest": "vorrichten",
    "vorrichtet": "vorrichten",
    "vorrichtete": "vorrichten",
    "vorrichteten": "vorrichten",
    "vorrichtetest": "vorrichten",
    "vorrichtetet": "vorrichten",
    "vorritt": "vorreiten",
    "vorritte": "vorreiten",
    "vorritten": "vorreiten",
    "vorrittest": "vorreiten",
    "vorrittet": "vorreiten",
    "vorrätigem": "vorrätig",
    "vorrätigen": "vorrätig",
    "vorrätiger": "vorrätig",
    "vorrätiges": "vorrätig",
    "vorrücke": "vorrücken",
    "vorrückend": "vorrücken",
    "vorrückende": "vorrückend",
    "vorrückendem": "vorrückend",
    "vorrückenden": "vorrückend",
    "vorrückender": "vorrückend",
    "vorrückendes": "vorrückend",
    "vorrückest": "vorrücken",
    "vorrücket": "vorrücken",
    "vorrückst": "vorrücken",
    "vorrückt": "vorrücken",
    "vorrückte": "vorrücken",
    "vorrückten": "vorrücken",
    "vorrücktest": "vorrücken",
    "vorrücktet": "vorrücken",
    "vorsage": "vorsagen",
    "vorsagend": "vorsagen",
    "vorsagende": "vorsagend",
    "vorsagendem": "vorsagend",
    "vorsagenden": "vorsagend",
    "vorsagender": "vorsagend",
    "vorsagendes": "vorsagend",
    "vorsagest": "vorsagen",
    "vorsaget": "vorsagen",
    "vorsagst": "vorsagen",
    "vorsagt": "vorsagen",
    "vorsagte": "vorsagen",
    "vorsagten": "vorsagen",
    "vorsagtest": "vorsagen",
    "vorsagtet": "vorsagen",
    "vorsah": "vorsehen",
    "vorsahen": "vorsehen",
    "vorsahst": "vorsehen",
    "vorsaht": "vorsehen",
    "vorsang": "vorsingen",
    "vorsangen": "vorsingen",
    "vorsangst": "vorsingen",
    "vorsangt": "vorsingen",
    "vorsaß": "vorsitzen",
    "vorsaßen": "vorsitzen",
    "vorsaßt": "vorsitzen",
    "vorschiebe": "vorschieben",
    "vorschiebend": "vorschieben",
    "vorschiebende": "vorschiebend",
    "vorschiebendem": "vorschiebend",
    "vorschiebenden": "vorschiebend",
    "vorschiebender": "vorschiebend",
    "vorschiebendes": "vorschiebend",
    "vorschiebest": "vorschieben",
    "vorschiebet": "vorschieben",
    "vorschiebst": "vorschieben",
    "vorschiebt": "vorschieben",
    "vorschieße": "vorschießen",
    "vorschießend": "vorschießen",
    "vorschießende": "vorschießend",
    "vorschießendem": "vorschießend",
    "vorschießenden": "vorschießend",
    "vorschießender": "vorschießend",
    "vorschießendes": "vorschießend",
    "vorschießest": "vorschießen",
    "vorschießet": "vorschießen",
    "vorschießt": "vorschießen",
    "vorschlagend": "vorschlagen",
    "vorschlagende": "vorschlagend",
    "vorschlagendem": "vorschlagend",
    "vorschlagenden": "vorschlagend",
    "vorschlagender": "vorschlagend",
    "vorschlagendes": "vorschlagend",
    "vorschlagest": "vorschlagen",
    "vorschlaget": "vorschlagen",
    "vorschlagt": "vorschlagen",
    "vorschlug": "vorschlagen",
    "vorschlugen": "vorschlagen",
    "vorschlugst": "vorschlagen",
    "vorschlugt": "vorschlagen",
    "vorschlägst": "vorschlagen",
    "vorschlägt": "vorschlagen",
    "vorschlüge": "vorschlagen",
    "vorschlügen": "vorschlagen",
    "vorschlügest": "vorschlagen",
    "vorschlüget": "vorschlagen",
    "vorschneide": "vorschneiden",
    "vorschneidend": "vorschneiden",
    "vorschneidende": "vorschneidend",
    "vorschneidendem": "vorschneidend",
    "vorschneidenden": "vorschneidend",
    "vorschneidender": "vorschneidend",
    "vorschneidendes": "vorschneidend",
    "vorschneidest": "vorschneiden",
    "vorschneidet": "vorschneiden",
    "vorschnelle": "vorschnell",
    "vorschnellem": "vorschnell",
    "vorschnellen": "vorschnell",
    "vorschneller": "vorschnell",
    "vorschnelles": "vorschnell",
    "vorschnitt": "vorschneiden",
    "vorschnitte": "vorschneiden",
    "vorschnitten": "vorschneiden",
    "vorschnittest": "vorschneiden",
    "vorschnittet": "vorschneiden",
    "vorschob": "vorschieben",
    "vorschoben": "vorschieben",
    "vorschobst": "vorschieben",
    "vorschobt": "vorschieben",
    "vorschossen": "vorschießen",
    "vorschoß": "vorschießen",
    "vorschoßt": "vorschießen",
    "vorschreibe": "vorschreiben",
    "vorschreibend": "vorschreiben",
    "vorschreibende": "vorschreibend",
    "vorschreibendem": "vorschreibend",
    "vorschreibenden": "vorschreibend",
    "vorschreibender": "vorschreibend",
    "vorschreibendes": "vorschreibend",
    "vorschreibest": "vorschreiben",
    "vorschreibet": "vorschreiben",
    "vorschreibst": "vorschreiben",
    "vorschreibt": "vorschreiben",
    "vorschreitend": "vorschreiten",
    "vorschreitende": "vorschreitend",
    "vorschreitendem": "vorschreitend",
    "vorschreitenden": "vorschreitend",
    "vorschreitender": "vorschreitend",
    "vorschreitendes": "vorschreitend",
    "vorschrieb": "vorschreiben",
    "vorschriebe": "vorschreiben",
    "vorschrieben": "vorschreiben",
    "vorschriebest": "vorschreiben",
    "vorschriebet": "vorschreiben",
    "vorschriebst": "vorschreiben",
    "vorschriebt": "vorschreiben",
    "vorschriftsgemäßem": "vorschriftsgemäß",
    "vorschriftsgemäßen": "vorschriftsgemäß",
    "vorschriftsgemäßer": "vorschriftsgemäß",
    "vorschriftsgemäßes": "vorschriftsgemäß",
    "vorschwebe": "vorschweben",
    "vorschwebend": "vorschweben",
    "vorschwebende": "vorschwebend",
    "vorschwebendem": "vorschwebend",
    "vorschwebenden": "vorschwebend",
    "vorschwebender": "vorschwebend",
    "vorschwebendes": "vorschwebend",
    "vorschwebest": "vorschweben",
    "vorschwebet": "vorschweben",
    "vorschwebst": "vorschweben",
    "vorschwebt": "vorschweben",
    "vorschwebte": "vorschweben",
    "vorschwebten": "vorschweben",
    "vorschwebtest": "vorschweben",
    "vorschwebtet": "vorschweben",
    "vorschwindele": "vorschwindeln",
    "vorschwindelnd": "vorschwindeln",
    "vorschwindelnde": "vorschwindelnd",
    "vorschwindelndem": "vorschwindelnd",
    "vorschwindelnden": "vorschwindelnd",
    "vorschwindelnder": "vorschwindelnd",
    "vorschwindelndes": "vorschwindelnd",
    "vorschwindelst": "vorschwindeln",
    "vorschwindelt": "vorschwindeln",
    "vorschwindelte": "vorschwindeln",
    "vorschwindelten": "vorschwindeln",
    "vorschwindeltest": "vorschwindeln",
    "vorschwindeltet": "vorschwindeln",
    "vorschwindle": "vorschwindeln",
    "vorschwärme": "vorschwärmen",
    "vorschwärmend": "vorschwärmen",
    "vorschwärmende": "vorschwärmend",
    "vorschwärmendem": "vorschwärmend",
    "vorschwärmenden": "vorschwärmend",
    "vorschwärmender": "vorschwärmend",
    "vorschwärmendes": "vorschwärmend",
    "vorschwärmest": "vorschwärmen",
    "vorschwärmet": "vorschwärmen",
    "vorschwärmst": "vorschwärmen",
    "vorschwärmt": "vorschwärmen",
    "vorschwärmte": "vorschwärmen",
    "vorschwärmten": "vorschwärmen",
    "vorschwärmtest": "vorschwärmen",
    "vorschwärmtet": "vorschwärmen",
    "vorschöbe": "vorschieben",
    "vorschöben": "vorschieben",
    "vorschöbest": "vorschieben",
    "vorschöbet": "vorschieben",
    "vorschösse": "vorschießen",
    "vorschössen": "vorschießen",
    "vorschössest": "vorschießen",
    "vorschösset": "vorschießen",
    "vorschütze": "vorschützen",
    "vorschützend": "vorschützen",
    "vorschützende": "vorschützend",
    "vorschützendem": "vorschützend",
    "vorschützenden": "vorschützend",
    "vorschützender": "vorschützend",
    "vorschützendes": "vorschützend",
    "vorschützest": "vorschützen",
    "vorschützet": "vorschützen",
    "vorschützt": "vorschützen",
    "vorschützte": "vorschützen",
    "vorschützten": "vorschützen",
    "vorschütztest": "vorschützen",
    "vorschütztet": "vorschützen",
    "vorsehe": "vorsehen",
    "vorsehend": "vorsehen",
    "vorsehende": "vorsehend",
    "vorsehendem": "vorsehend",
    "vorsehenden": "vorsehend",
    "vorsehender": "vorsehend",
    "vorsehendes": "vorsehend",
    "vorsehest": "vorsehen",
    "vorsehet": "vorsehen",
    "vorseht": "vorsehen",
    "vorsetze": "vorsetzen",
    "vorsetzend": "vorsetzen",
    "vorsetzende": "vorsetzend",
    "vorsetzendem": "vorsetzend",
    "vorsetzenden": "vorsetzend",
    "vorsetzender": "vorsetzend",
    "vorsetzendes": "vorsetzend",
    "vorsetzest": "vorsetzen",
    "vorsetzet": "vorsetzen",
    "vorsetzt": "vorsetzen",
    "vorsetzte": "vorsetzen",
    "vorsetzten": "vorsetzen",
    "vorsetztest": "vorsetzen",
    "vorsetztet": "vorsetzen",
    "vorsichtige": "vorsichtig",
    "vorsichtigem": "vorsichtig",
    "vorsichtigen": "vorsichtig",
    "vorsichtiger": "vorsichtig",
    "vorsichtigere": "vorsichtig",
    "vorsichtigerem": "vorsichtig",
    "vorsichtigeren": "vorsichtig",
    "vorsichtigerer": "vorsichtig",
    "vorsichtigeres": "vorsichtig",
    "vorsichtiges": "vorsichtig",
    "vorsichtigste": "vorsichtig",
    "vorsichtigstem": "vorsichtig",
    "vorsichtigsten": "vorsichtig",
    "vorsichtigster": "vorsichtig",
    "vorsichtigstes": "vorsichtig",
    "vorsiehst": "vorsehen",
    "vorsieht": "vorsehen",
    "vorsinge": "vorsingen",
    "vorsingend": "vorsingen",
    "vorsingende": "vorsingend",
    "vorsingendem": "vorsingend",
    "vorsingenden": "vorsingend",
    "vorsingender": "vorsingend",
    "vorsingendes": "vorsingend",
    "vorsingest": "vorsingen",
    "vorsinget": "vorsingen",
    "vorsingst": "vorsingen",
    "vorsingt": "vorsingen",
    "vorsintflutliche": "vorsintflutlich",
    "vorsintflutlichem": "vorsintflutlich",
    "vorsintflutlichen": "vorsintflutlich",
    "vorsintflutlicher": "vorsintflutlich",
    "vorsintflutliches": "vorsintflutlich",
    "vorsitzend": "vorsitzen",
    "vorsitzende": "vorsitzend",
    "vorsitzendem": "vorsitzend",
    "vorsitzenden": "vorsitzend",
    "vorsitzender": "vorsitzend",
    "vorsitzendes": "vorsitzend",
    "vorsitzest": "vorsitzen",
    "vorsitzet": "vorsitzen",
    "vorsitzt": "vorsitzen",
    "vorsorgend": "vorsorgen",
    "vorsorgende": "vorsorgend",
    "vorsorgendem": "vorsorgend",
    "vorsorgenden": "vorsorgend",
    "vorsorgender": "vorsorgend",
    "vorsorgendere": "vorsorgend",
    "vorsorgenderem": "vorsorgend",
    "vorsorgenderen": "vorsorgend",
    "vorsorgenderer": "vorsorgend",
    "vorsorgenderes": "vorsorgend",
    "vorsorgendes": "vorsorgend",
    "vorsorgendste": "vorsorgend",
    "vorsorgendstem": "vorsorgend",
    "vorsorgendsten": "vorsorgend",
    "vorsorgendster": "vorsorgend",
    "vorsorgendstes": "vorsorgend",
    "vorsorgest": "vorsorgen",
    "vorsorget": "vorsorgen",
    "vorsorgliche": "vorsorglich",
    "vorsorglichem": "vorsorglich",
    "vorsorglichen": "vorsorglich",
    "vorsorglicher": "vorsorglich",
    "vorsorgliches": "vorsorglich",
    "vorsorgst": "vorsorgen",
    "vorsorgt": "vorsorgen",
    "vorsorgte": "vorsorgen",
    "vorsorgten": "vorsorgen",
    "vorsorgtest": "vorsorgen",
    "vorsorgtet": "vorsorgen",
    "vorspannend": "vorspannen",
    "vorspannende": "vorspannend",
    "vorspannendem": "vorspannend",
    "vorspannenden": "vorspannend",
    "vorspannender": "vorspannend",
    "vorspannendes": "vorspannend",
    "vorspannest": "vorspannen",
    "vorspannet": "vorspannen",
    "vorspannst": "vorspannen",
    "vorspannt": "vorspannen",
    "vorspannte": "vorspannen",
    "vorspannten": "vorspannen",
    "vorspanntest": "vorspannen",
    "vorspanntet": "vorspannen",
    "vorspiegele": "vorspiegeln",
    "vorspiegelnd": "vorspiegeln",
    "vorspiegelnde": "vorspiegelnd",
    "vorspiegelndem": "vorspiegelnd",
    "vorspiegelnden": "vorspiegelnd",
    "vorspiegelnder": "vorspiegelnd",
    "vorspiegelndes": "vorspiegelnd",
    "vorspiegelst": "vorspiegeln",
    "vorspiegelt": "vorspiegeln",
    "vorspiegelte": "vorspiegeln",
    "vorspiegelten": "vorspiegeln",
    "vorspiegeltest": "vorspiegeln",
    "vorspiegeltet": "vorspiegeln",
    "vorspiegle": "vorspiegeln",
    "vorspiele": "vorspielen",
    "vorspielend": "vorspielen",
    "vorspielende": "vorspielend",
    "vorspielendem": "vorspielend",
    "vorspielenden": "vorspielend",
    "vorspielender": "vorspielend",
    "vorspielendes": "vorspielend",
    "vorspielest": "vorspielen",
    "vorspielet": "vorspielen",
    "vorspielst": "vorspielen",
    "vorspielt": "vorspielen",
    "vorspielte": "vorspielen",
    "vorspielten": "vorspielen",
    "vorspieltest": "vorspielen",
    "vorspieltet": "vorspielen",
    "vorsprach": "vorsprechen",
    "vorsprachen": "vorsprechen",
    "vorsprachst": "vorsprechen",
    "vorspracht": "vorsprechen",
    "vorsprang": "vorspringen",
    "vorsprangen": "vorspringen",
    "vorsprangst": "vorspringen",
    "vorsprangt": "vorspringen",
    "vorspreche": "vorsprechen",
    "vorsprechend": "vorsprechen",
    "vorsprechende": "vorsprechend",
    "vorsprechendem": "vorsprechend",
    "vorsprechenden": "vorsprechend",
    "vorsprechender": "vorsprechend",
    "vorsprechendes": "vorsprechend",
    "vorsprechest": "vorsprechen",
    "vorsprechet": "vorsprechen",
    "vorsprecht": "vorsprechen",
    "vorsprichst": "vorsprechen",
    "vorspricht": "vorsprechen",
    "vorspringe": "vorspringen",
    "vorspringend": "vorspringen",
    "vorspringende": "vorspringend",
    "vorspringendem": "vorspringend",
    "vorspringenden": "vorspringend",
    "vorspringender": "vorspringend",
    "vorspringendes": "vorspringend",
    "vorspringest": "vorspringen",
    "vorspringet": "vorspringen",
    "vorspringst": "vorspringen",
    "vorspringt": "vorspringen",
    "vorspräche": "vorsprechen",
    "vorsprächen": "vorsprechen",
    "vorsprächest": "vorsprechen",
    "vorsprächet": "vorsprechen",
    "vorspränge": "vorspringen",
    "vorsprängen": "vorspringen",
    "vorsprängest": "vorspringen",
    "vorspränget": "vorspringen",
    "vorspule": "vorspulen",
    "vorspulend": "vorspulen",
    "vorspulende": "vorspulend",
    "vorspulendem": "vorspulend",
    "vorspulenden": "vorspulend",
    "vorspulender": "vorspulend",
    "vorspulendes": "vorspulend",
    "vorspulest": "vorspulen",
    "vorspulet": "vorspulen",
    "vorspulst": "vorspulen",
    "vorspult": "vorspulen",
    "vorspulte": "vorspulen",
    "vorspulten": "vorspulen",
    "vorspultest": "vorspulen",
    "vorspultet": "vorspulen",
    "vorstanden": "vorstehen",
    "vorstandest": "vorstehen",
    "vorstandet": "vorstehen",
    "vorstehe": "vorstehen",
    "vorstehend": "vorstehen",
    "vorstehende": "vorstehend",
    "vorstehendem": "vorstehend",
    "vorstehenden": "vorstehend",
    "vorstehender": "vorstehend",
    "vorstehendere": "vorstehend",
    "vorstehenderem": "vorstehend",
    "vorstehenderen": "vorstehend",
    "vorstehenderer": "vorstehend",
    "vorstehenderes": "vorstehend",
    "vorstehendes": "vorstehend",
    "vorstehendste": "vorstehend",
    "vorstehendstem": "vorstehend",
    "vorstehendsten": "vorstehend",
    "vorstehendster": "vorstehend",
    "vorstehendstes": "vorstehend",
    "vorstehest": "vorstehen",
    "vorstehet": "vorstehen",
    "vorstehst": "vorstehen",
    "vorsteht": "vorstehen",
    "vorstellbare": "vorstellbar",
    "vorstellbarem": "vorstellbar",
    "vorstellbaren": "vorstellbar",
    "vorstellbarer": "vorstellbar",
    "vorstellbarere": "vorstellbar",
    "vorstellbarerem": "vorstellbar",
    "vorstellbareren": "vorstellbar",
    "vorstellbarerer": "vorstellbar",
    "vorstellbareres": "vorstellbar",
    "vorstellbares": "vorstellbar",
    "vorstellbarste": "vorstellbar",
    "vorstellbarstem": "vorstellbar",
    "vorstellbarsten": "vorstellbar",
    "vorstellbarster": "vorstellbar",
    "vorstellbarstes": "vorstellbar",
    "vorstelle": "vorstellen",
    "vorstellend": "vorstellen",
    "vorstellende": "vorstellend",
    "vorstellendem": "vorstellend",
    "vorstellenden": "vorstellend",
    "vorstellender": "vorstellend",
    "vorstellendes": "vorstellend",
    "vorstellest": "vorstellen",
    "vorstellet": "vorstellen",
    "vorstellst": "vorstellen",
    "vorstellt": "vorstellen",
    "vorstellte": "vorstellen",
    "vorstellten": "vorstellen",
    "vorstelltest": "vorstellen",
    "vorstelltet": "vorstellen",
    "vorstieß": "vorstoßen",
    "vorstieße": "vorstoßen",
    "vorstießen": "vorstoßen",
    "vorstießest": "vorstoßen",
    "vorstießet": "vorstoßen",
    "vorstießt": "vorstoßen",
    "vorstoßend": "vorstoßen",
    "vorstoßende": "vorstoßend",
    "vorstoßendem": "vorstoßend",
    "vorstoßenden": "vorstoßend",
    "vorstoßender": "vorstoßend",
    "vorstoßendes": "vorstoßend",
    "vorstoßest": "vorstoßen",
    "vorstoßet": "vorstoßen",
    "vorstoßt": "vorstoßen",
    "vorstößt": "vorstoßen",
    "vorstülpe": "vorstülpen",
    "vorstülpend": "vorstülpen",
    "vorstülpende": "vorstülpend",
    "vorstülpendem": "vorstülpend",
    "vorstülpenden": "vorstülpend",
    "vorstülpender": "vorstülpend",
    "vorstülpendes": "vorstülpend",
    "vorstülpest": "vorstülpen",
    "vorstülpet": "vorstülpen",
    "vorstülpst": "vorstülpen",
    "vorstülpt": "vorstülpen",
    "vorstülpte": "vorstülpen",
    "vorstülpten": "vorstülpen",
    "vorstülptest": "vorstülpen",
    "vorstülptet": "vorstülpen",
    "vorstünde": "vorstehen",
    "vorstünden": "vorstehen",
    "vorstündest": "vorstehen",
    "vorstündet": "vorstehen",
    "vorstürme": "vorstürmen",
    "vorstürmend": "vorstürmen",
    "vorstürmende": "vorstürmend",
    "vorstürmendem": "vorstürmend",
    "vorstürmenden": "vorstürmend",
    "vorstürmender": "vorstürmend",
    "vorstürmendes": "vorstürmend",
    "vorstürmest": "vorstürmen",
    "vorstürmet": "vorstürmen",
    "vorstürmst": "vorstürmen",
    "vorstürmt": "vorstürmen",
    "vorstürmte": "vorstürmen",
    "vorstürmten": "vorstürmen",
    "vorstürmtest": "vorstürmen",
    "vorstürmtet": "vorstürmen",
    "vorsähe": "vorsehen",
    "vorsähen": "vorsehen",
    "vorsähest": "vorsehen",
    "vorsähet": "vorsehen",
    "vorsänge": "vorsingen",
    "vorsängen": "vorsingen",
    "vorsängest": "vorsingen",
    "vorsänget": "vorsingen",
    "vorsätzlichem": "vorsätzlich",
    "vorsätzlichen": "vorsätzlich",
    "vorsätzlicher": "vorsätzlich",
    "vorsätzliches": "vorsätzlich",
    "vorsäße": "vorsitzen",
    "vorsäßen": "vorsitzen",
    "vorsäßest": "vorsitzen",
    "vorsäßet": "vorsitzen",
    "vortanze": "vortanzen",
    "vortanzend": "vortanzen",
    "vortanzende": "vortanzend",
    "vortanzendem": "vortanzend",
    "vortanzenden": "vortanzend",
    "vortanzender": "vortanzend",
    "vortanzendes": "vortanzend",
    "vortanzest": "vortanzen",
    "vortanzet": "vortanzen",
    "vortanzt": "vortanzen",
    "vortanzte": "vortanzen",
    "vortanzten": "vortanzen",
    "vortanztest": "vortanzen",
    "vortanztet": "vortanzen",
    "vorteilhaftem": "vorteilhaft",
    "vorteilhaften": "vorteilhaft",
    "vorteilhafter": "vorteilhaft",
    "vorteilhaftere": "vorteilhaft",
    "vorteilhafterem": "vorteilhaft",
    "vorteilhafteren": "vorteilhaft",
    "vorteilhafterer": "vorteilhaft",
    "vorteilhafteres": "vorteilhaft",
    "vorteilhaftes": "vorteilhaft",
    "vorteilhafteste": "vorteilhaft",
    "vorteilhaftestem": "vorteilhaft",
    "vorteilhaftesten": "vorteilhaft",
    "vorteilhaftester": "vorteilhaft",
    "vorteilhaftestes": "vorteilhaft",
    "vortragend": "vortragen",
    "vortragende": "vortragend",
    "vortragendem": "vortragend",
    "vortragenden": "vortragend",
    "vortragender": "vortragend",
    "vortragendes": "vortragend",
    "vortragest": "vortragen",
    "vortraget": "vortragen",
    "vortragt": "vortragen",
    "vortrat": "vortreten",
    "vortraten": "vortreten",
    "vortratest": "vortreten",
    "vortratet": "vortreten",
    "vortreffliche": "vortrefflich",
    "vortrefflichem": "vortrefflich",
    "vortrefflichen": "vortrefflich",
    "vortrefflicher": "vortrefflich",
    "vortrefflichere": "vortrefflich",
    "vortrefflicherem": "vortrefflich",
    "vortrefflicheren": "vortrefflich",
    "vortrefflicherer": "vortrefflich",
    "vortrefflicheres": "vortrefflich",
    "vortreffliches": "vortrefflich",
    "vortrefflichste": "vortrefflich",
    "vortrefflichstem": "vortrefflich",
    "vortrefflichsten": "vortrefflich",
    "vortrefflichster": "vortrefflich",
    "vortrefflichstes": "vortrefflich",
    "vortreibe": "vortreiben",
    "vortreibend": "vortreiben",
    "vortreibende": "vortreibend",
    "vortreibendem": "vortreibend",
    "vortreibenden": "vortreibend",
    "vortreibender": "vortreibend",
    "vortreibendes": "vortreibend",
    "vortreibest": "vortreiben",
    "vortreibet": "vortreiben",
    "vortreibst": "vortreiben",
    "vortreibt": "vortreiben",
    "vortrete": "vortreten",
    "vortretend": "vortreten",
    "vortretende": "vortretend",
    "vortretendem": "vortretend",
    "vortretenden": "vortretend",
    "vortretender": "vortretend",
    "vortretendes": "vortretend",
    "vortretest": "vortreten",
    "vortretet": "vortreten",
    "vortrieb": "vortreiben",
    "vortriebe": "vortreiben",
    "vortrieben": "vortreiben",
    "vortriebest": "vortreiben",
    "vortriebet": "vortreiben",
    "vortriebst": "vortreiben",
    "vortriebt": "vortreiben",
    "vortritt": "vortreten",
    "vortrittst": "vortreten",
    "vortrug": "vortragen",
    "vortrugen": "vortragen",
    "vortrugst": "vortragen",
    "vortrugt": "vortragen",
    "vorträgst": "vortragen",
    "vorträgt": "vortragen",
    "vorträte": "vortreten",
    "vorträten": "vortreten",
    "vorträtest": "vortreten",
    "vorträtet": "vortreten",
    "vortrüge": "vortragen",
    "vortrügen": "vortragen",
    "vortrügest": "vortragen",
    "vortrüget": "vortragen",
    "vorturne": "vorturnen",
    "vorturnend": "vorturnen",
    "vorturnende": "vorturnend",
    "vorturnendem": "vorturnend",
    "vorturnenden": "vorturnend",
    "vorturnender": "vorturnend",
    "vorturnendes": "vorturnend",
    "vorturnest": "vorturnen",
    "vorturnet": "vorturnen",
    "vorturnst": "vorturnen",
    "vorturnt": "vorturnen",
    "vorturnte": "vorturnen",
    "vorturnten": "vorturnen",
    "vorturntest": "vorturnen",
    "vorturntet": "vorturnen",
    "vortäusche": "vortäuschen",
    "vortäuschend": "vortäuschen",
    "vortäuschende": "vortäuschend",
    "vortäuschendem": "vortäuschend",
    "vortäuschenden": "vortäuschend",
    "vortäuschender": "vortäuschend",
    "vortäuschendes": "vortäuschend",
    "vortäuschest": "vortäuschen",
    "vortäuschet": "vortäuschen",
    "vortäuschst": "vortäuschen",
    "vortäuscht": "vortäuschen",
    "vortäuschte": "vortäuschen",
    "vortäuschten": "vortäuschen",
    "vortäuschtest": "vortäuschen",
    "vortäuschtet": "vortäuschen",
    "vorurteilsfreiem": "vorurteilsfrei",
    "vorurteilsfreien": "vorurteilsfrei",
    "vorurteilsfreier": "vorurteilsfrei",
    "vorurteilsfreies": "vorurteilsfrei",
    "vorverlege": "vorverlegen",
    "vorverlegend": "vorverlegen",
    "vorverlegende": "vorverlegend",
    "vorverlegendem": "vorverlegend",
    "vorverlegenden": "vorverlegend",
    "vorverlegender": "vorverlegend",
    "vorverlegendes": "vorverlegend",
    "vorverlegest": "vorverlegen",
    "vorverleget": "vorverlegen",
    "vorverlegst": "vorverlegen",
    "vorverlegt": "vorverlegen",
    "vorverlegte": "vorverlegen",
    "vorverlegtem": "vorverlegt",
    "vorverlegten": "vorverlegen",
    "vorverlegter": "vorverlegt",
    "vorverlegtes": "vorverlegt",
    "vorverlegtest": "vorverlegen",
    "vorverlegtet": "vorverlegen",
    "vorverurteile": "vorverurteilen",
    "vorverurteilend": "vorverurteilen",
    "vorverurteilende": "vorverurteilend",
    "vorverurteilendem": "vorverurteilend",
    "vorverurteilenden": "vorverurteilend",
    "vorverurteilender": "vorverurteilend",
    "vorverurteilendes": "vorverurteilend",
    "vorverurteilest": "vorverurteilen",
    "vorverurteilet": "vorverurteilen",
    "vorverurteilst": "vorverurteilen",
    "vorverurteilt": "vorverurteilen",
    "vorverurteilte": "vorverurteilen",
    "vorverurteiltem": "vorverurteilt",
    "vorverurteilten": "vorverurteilen",
    "vorverurteilter": "vorverurteilt",
    "vorverurteiltes": "vorverurteilt",
    "vorverurteiltest": "vorverurteilen",
    "vorverurteiltet": "vorverurteilen",
    "vorwage": "vorwagen",
    "vorwagend": "vorwagen",
    "vorwagende": "vorwagend",
    "vorwagendem": "vorwagend",
    "vorwagenden": "vorwagend",
    "vorwagender": "vorwagend",
    "vorwagendes": "vorwagend",
    "vorwagest": "vorwagen",
    "vorwaget": "vorwagen",
    "vorwagst": "vorwagen",
    "vorwagt": "vorwagen",
    "vorwagte": "vorwagen",
    "vorwagten": "vorwagen",
    "vorwagtest": "vorwagen",
    "vorwagtet": "vorwagen",
    "vorwarf": "vorwerfen",
    "vorwarfen": "vorwerfen",
    "vorwarfst": "vorwerfen",
    "vorwarft": "vorwerfen",
    "vorwarne": "vorwarnen",
    "vorwarnend": "vorwarnen",
    "vorwarnende": "vorwarnend",
    "vorwarnendem": "vorwarnend",
    "vorwarnenden": "vorwarnend",
    "vorwarnender": "vorwarnend",
    "vorwarnendes": "vorwarnend",
    "vorwarnest": "vorwarnen",
    "vorwarnet": "vorwarnen",
    "vorwarnst": "vorwarnen",
    "vorwarnt": "vorwarnen",
    "vorwarnte": "vorwarnen",
    "vorwarnten": "vorwarnen",
    "vorwarntest": "vorwarnen",
    "vorwarntet": "vorwarnen",
    "vorweggenommen": "vorwegnehmen",
    "vorweggenommene": "vorweggenommen",
    "vorweggenommenem": "vorweggenommen",
    "vorweggenommenen": "vorweggenommen",
    "vorweggenommener": "vorweggenommen",
    "vorweggenommenes": "vorweggenommen",
    "vorwegnahm": "vorwegnehmen",
    "vorwegnahmst": "vorwegnehmen",
    "vorwegnahmt": "vorwegnehmen",
    "vorwegnehme": "vorwegnehmen",
    "vorwegnehmend": "vorwegnehmen",
    "vorwegnehmende": "vorwegnehmend",
    "vorwegnehmendem": "vorwegnehmend",
    "vorwegnehmenden": "vorwegnehmend",
    "vorwegnehmender": "vorwegnehmend",
    "vorwegnehmendes": "vorwegnehmend",
    "vorwegnehmest": "vorwegnehmen",
    "vorwegnehmet": "vorwegnehmen",
    "vorwegnehmt": "vorwegnehmen",
    "vorwegnimmst": "vorwegnehmen",
    "vorwegnimmt": "vorwegnehmen",
    "vorwegnähme": "vorwegnehmen",
    "vorwegnähmen": "vorwegnehmen",
    "vorwegnähmest": "vorwegnehmen",
    "vorwegnähmet": "vorwegnehmen",
    "vorwegzunehmen": "vorwegnehmen",
    "vorweise": "vorweisen",
    "vorweisend": "vorweisen",
    "vorweisende": "vorweisend",
    "vorweisendem": "vorweisend",
    "vorweisenden": "vorweisend",
    "vorweisender": "vorweisend",
    "vorweisendes": "vorweisend",
    "vorweisest": "vorweisen",
    "vorweiset": "vorweisen",
    "vorweist": "vorweisen",
    "vorwerfe": "vorwerfen",
    "vorwerfend": "vorwerfen",
    "vorwerfende": "vorwerfend",
    "vorwerfendem": "vorwerfend",
    "vorwerfenden": "vorwerfend",
    "vorwerfender": "vorwerfend",
    "vorwerfendes": "vorwerfend",
    "vorwerfest": "vorwerfen",
    "vorwerfet": "vorwerfen",
    "vorwerft": "vorwerfen",
    "vorwiege": "vorwiegen",
    "vorwiegend": "vorwiegen",
    "vorwiegende": "vorwiegend",
    "vorwiegendem": "vorwiegend",
    "vorwiegenden": "vorwiegend",
    "vorwiegender": "vorwiegend",
    "vorwiegendere": "vorwiegend",
    "vorwiegenderem": "vorwiegend",
    "vorwiegenderen": "vorwiegend",
    "vorwiegenderer": "vorwiegend",
    "vorwiegenderes": "vorwiegend",
    "vorwiegendes": "vorwiegend",
    "vorwiegendste": "vorwiegend",
    "vorwiegendstem": "vorwiegend",
    "vorwiegendsten": "vorwiegend",
    "vorwiegendster": "vorwiegend",
    "vorwiegendstes": "vorwiegend",
    "vorwiegest": "vorwiegen",
    "vorwieget": "vorwiegen",
    "vorwiegst": "vorwiegen",
    "vorwiegt": "vorwiegen",
    "vorwies": "vorweisen",
    "vorwiese": "vorweisen",
    "vorwiesen": "vorweisen",
    "vorwiesest": "vorweisen",
    "vorwieset": "vorweisen",
    "vorwiest": "vorweisen",
    "vorwirfst": "vorwerfen",
    "vorwirft": "vorwerfen",
    "vorwog": "vorwiegen",
    "vorwogen": "vorwiegen",
    "vorwogst": "vorwiegen",
    "vorwogt": "vorwiegen",
    "vorwurfsvollem": "vorwurfsvoll",
    "vorwurfsvollen": "vorwurfsvoll",
    "vorwurfsvoller": "vorwurfsvoll",
    "vorwurfsvollere": "vorwurfsvoll",
    "vorwurfsvollerem": "vorwurfsvoll",
    "vorwurfsvolleren": "vorwurfsvoll",
    "vorwurfsvollerer": "vorwurfsvoll",
    "vorwurfsvolleres": "vorwurfsvoll",
    "vorwurfsvolles": "vorwurfsvoll",
    "vorwurfsvollste": "vorwurfsvoll",
    "vorwurfsvollstem": "vorwurfsvoll",
    "vorwurfsvollsten": "vorwurfsvoll",
    "vorwurfsvollster": "vorwurfsvoll",
    "vorwurfsvollstes": "vorwurfsvoll",
    "vorwähle": "vorwählen",
    "vorwählend": "vorwählen",
    "vorwählende": "vorwählend",
    "vorwählendem": "vorwählend",
    "vorwählenden": "vorwählend",
    "vorwählender": "vorwählend",
    "vorwählendes": "vorwählend",
    "vorwählest": "vorwählen",
    "vorwählet": "vorwählen",
    "vorwählst": "vorwählen",
    "vorwählt": "vorwählen",
    "vorwählte": "vorwählen",
    "vorwählten": "vorwählen",
    "vorwähltest": "vorwählen",
    "vorwähltet": "vorwählen",
    "vorwärfe": "vorwerfen",
    "vorwärfen": "vorwerfen",
    "vorwärfest": "vorwerfen",
    "vorwärfet": "vorwerfen",
    "vorwärme": "vorwärmen",
    "vorwärmend": "vorwärmen",
    "vorwärmende": "vorwärmend",
    "vorwärmendem": "vorwärmend",
    "vorwärmenden": "vorwärmend",
    "vorwärmender": "vorwärmend",
    "vorwärmendere": "vorwärmend",
    "vorwärmenderem": "vorwärmend",
    "vorwärmenderen": "vorwärmend",
    "vorwärmenderer": "vorwärmend",
    "vorwärmenderes": "vorwärmend",
    "vorwärmendes": "vorwärmend",
    "vorwärmendste": "vorwärmend",
    "vorwärmendstem": "vorwärmend",
    "vorwärmendsten": "vorwärmend",
    "vorwärmendster": "vorwärmend",
    "vorwärmendstes": "vorwärmend",
    "vorwärmest": "vorwärmen",
    "vorwärmet": "vorwärmen",
    "vorwärmst": "vorwärmen",
    "vorwärmt": "vorwärmen",
    "vorwärmte": "vorwärmen",
    "vorwärmten": "vorwärmen",
    "vorwärmtest": "vorwärmen",
    "vorwärmtet": "vorwärmen",
    "vorwärtsgegangen": "vorwärtsgehen",
    "vorwärtsgegangene": "vorwärtsgegangen",
    "vorwärtsgegangenem": "vorwärtsgegangen",
    "vorwärtsgegangenen": "vorwärtsgegangen",
    "vorwärtsgegangener": "vorwärtsgegangen",
    "vorwärtsgegangenes": "vorwärtsgegangen",
    "vorwärtsgehe": "vorwärtsgehen",
    "vorwärtsgehend": "vorwärtsgehen",
    "vorwärtsgehende": "vorwärtsgehend",
    "vorwärtsgehendem": "vorwärtsgehend",
    "vorwärtsgehenden": "vorwärtsgehend",
    "vorwärtsgehender": "vorwärtsgehend",
    "vorwärtsgehendes": "vorwärtsgehend",
    "vorwärtsgehest": "vorwärtsgehen",
    "vorwärtsgehet": "vorwärtsgehen",
    "vorwärtsgehst": "vorwärtsgehen",
    "vorwärtsgeht": "vorwärtsgehen",
    "vorwärtsgekommen": "vorwärtskommen",
    "vorwärtsgekommene": "vorwärtsgekommen",
    "vorwärtsgekommenem": "vorwärtsgekommen",
    "vorwärtsgekommenen": "vorwärtsgekommen",
    "vorwärtsgekommener": "vorwärtsgekommen",
    "vorwärtsgekommenere": "vorwärtsgekommen",
    "vorwärtsgekommenerem": "vorwärtsgekommen",
    "vorwärtsgekommeneren": "vorwärtsgekommen",
    "vorwärtsgekommenerer": "vorwärtsgekommen",
    "vorwärtsgekommeneres": "vorwärtsgekommen",
    "vorwärtsgekommenes": "vorwärtsgekommen",
    "vorwärtsgekommenste": "vorwärtsgekommen",
    "vorwärtsgekommenstem": "vorwärtsgekommen",
    "vorwärtsgekommensten": "vorwärtsgekommen",
    "vorwärtsgekommenster": "vorwärtsgekommen",
    "vorwärtsgekommenstes": "vorwärtsgekommen",
    "vorwärtsgeschritten": "vorwärtsschreiten",
    "vorwärtsgeschrittene": "vorwärtsgeschritten",
    "vorwärtsgeschrittenem": "vorwärtsgeschritten",
    "vorwärtsgeschrittenen": "vorwärtsgeschritten",
    "vorwärtsgeschrittener": "vorwärtsgeschritten",
    "vorwärtsgeschrittenes": "vorwärtsgeschritten",
    "vorwärtsging": "vorwärtsgehen",
    "vorwärtsginge": "vorwärtsgehen",
    "vorwärtsgingen": "vorwärtsgehen",
    "vorwärtsgingest": "vorwärtsgehen",
    "vorwärtsginget": "vorwärtsgehen",
    "vorwärtsgingst": "vorwärtsgehen",
    "vorwärtsgingt": "vorwärtsgehen",
    "vorwärtskam": "vorwärtskommen",
    "vorwärtskamen": "vorwärtskommen",
    "vorwärtskamst": "vorwärtskommen",
    "vorwärtskamt": "vorwärtskommen",
    "vorwärtskomme": "vorwärtskommen",
    "vorwärtskommend": "vorwärtskommen",
    "vorwärtskommende": "vorwärtskommend",
    "vorwärtskommendem": "vorwärtskommend",
    "vorwärtskommenden": "vorwärtskommend",
    "vorwärtskommender": "vorwärtskommend",
    "vorwärtskommendere": "vorwärtskommend",
    "vorwärtskommenderem": "vorwärtskommend",
    "vorwärtskommenderen": "vorwärtskommend",
    "vorwärtskommenderer": "vorwärtskommend",
    "vorwärtskommenderes": "vorwärtskommend",
    "vorwärtskommendes": "vorwärtskommend",
    "vorwärtskommendste": "vorwärtskommend",
    "vorwärtskommendstem": "vorwärtskommend",
    "vorwärtskommendsten": "vorwärtskommend",
    "vorwärtskommendster": "vorwärtskommend",
    "vorwärtskommendstes": "vorwärtskommend",
    "vorwärtskommest": "vorwärtskommen",
    "vorwärtskommet": "vorwärtskommen",
    "vorwärtskommst": "vorwärtskommen",
    "vorwärtskommt": "vorwärtskommen",
    "vorwärtskäme": "vorwärtskommen",
    "vorwärtskämen": "vorwärtskommen",
    "vorwärtskämest": "vorwärtskommen",
    "vorwärtskämet": "vorwärtskommen",
    "vorwärtsschreitend": "vorwärtsschreiten",
    "vorwärtsschreitende": "vorwärtsschreitend",
    "vorwärtsschreitendem": "vorwärtsschreitend",
    "vorwärtsschreitenden": "vorwärtsschreitend",
    "vorwärtsschreitender": "vorwärtsschreitend",
    "vorwärtsschreitendes": "vorwärtsschreitend",
    "vorwärtszugehen": "vorwärtsgehen",
    "vorwärtszukommen": "vorwärtskommen",
    "vorwöge": "vorwiegen",
    "vorwögen": "vorwiegen",
    "vorwögest": "vorwiegen",
    "vorwöget": "vorwiegen",
    "vorwölbe": "vorwölben",
    "vorwölbend": "vorwölben",
    "vorwölbende": "vorwölbend",
    "vorwölbendem": "vorwölbend",
    "vorwölbenden": "vorwölbend",
    "vorwölbender": "vorwölbend",
    "vorwölbendere": "vorwölbend",
    "vorwölbenderem": "vorwölbend",
    "vorwölbenderen": "vorwölbend",
    "vorwölbenderer": "vorwölbend",
    "vorwölbenderes": "vorwölbend",
    "vorwölbendes": "vorwölbend",
    "vorwölbendste": "vorwölbend",
    "vorwölbendstem": "vorwölbend",
    "vorwölbendsten": "vorwölbend",
    "vorwölbendster": "vorwölbend",
    "vorwölbendstes": "vorwölbend",
    "vorwölbest": "vorwölben",
    "vorwölbet": "vorwölben",
    "vorwölbst": "vorwölben",
    "vorwölbt": "vorwölben",
    "vorwölbte": "vorwölben",
    "vorwölbten": "vorwölben",
    "vorwölbtest": "vorwölben",
    "vorwölbtet": "vorwölben",
    "vorzaubere": "vorzaubern",
    "vorzaubernd": "vorzaubern",
    "vorzaubernde": "vorzaubernd",
    "vorzauberndem": "vorzaubernd",
    "vorzaubernden": "vorzaubernd",
    "vorzaubernder": "vorzaubernd",
    "vorzauberndes": "vorzaubernd",
    "vorzauberst": "vorzaubern",
    "vorzaubert": "vorzaubern",
    "vorzauberte": "vorzaubern",
    "vorzauberten": "vorzaubern",
    "vorzaubertest": "vorzaubern",
    "vorzaubertet": "vorzaubern",
    "vorzeichne": "vorzeichnen",
    "vorzeichnend": "vorzeichnen",
    "vorzeichnende": "vorzeichnend",
    "vorzeichnendem": "vorzeichnend",
    "vorzeichnenden": "vorzeichnend",
    "vorzeichnender": "vorzeichnend",
    "vorzeichnendes": "vorzeichnend",
    "vorzeichnest": "vorzeichnen",
    "vorzeichnet": "vorzeichnen",
    "vorzeichnete": "vorzeichnen",
    "vorzeichneten": "vorzeichnen",
    "vorzeichnetest": "vorzeichnen",
    "vorzeichnetet": "vorzeichnen",
    "vorzeige": "vorzeigen",
    "vorzeigend": "vorzeigen",
    "vorzeigende": "vorzeigend",
    "vorzeigendem": "vorzeigend",
    "vorzeigenden": "vorzeigend",
    "vorzeigender": "vorzeigend",
    "vorzeigendes": "vorzeigend",
    "vorzeigest": "vorzeigen",
    "vorzeiget": "vorzeigen",
    "vorzeigst": "vorzeigen",
    "vorzeigt": "vorzeigen",
    "vorzeigte": "vorzeigen",
    "vorzeigten": "vorzeigen",
    "vorzeigtest": "vorzeigen",
    "vorzeigtet": "vorzeigen",
    "vorziehe": "vorziehen",
    "vorziehend": "vorziehen",
    "vorziehende": "vorziehend",
    "vorziehendem": "vorziehend",
    "vorziehenden": "vorziehend",
    "vorziehender": "vorziehend",
    "vorziehendes": "vorziehend",
    "vorziehest": "vorziehen",
    "vorziehet": "vorziehen",
    "vorziehst": "vorziehen",
    "vorzieht": "vorziehen",
    "vorzog": "vorziehen",
    "vorzogen": "vorziehen",
    "vorzogst": "vorziehen",
    "vorzogt": "vorziehen",
    "vorzuarbeiten": "vorarbeiten",
    "vorzubauen": "vorbauen",
    "vorzubehalten": "vorbehalten",
    "vorzubehandeln": "vorbehandeln",
    "vorzubereiten": "vorbereiten",
    "vorzubestellen": "vorbestellen",
    "vorzubeten": "vorbeten",
    "vorzubeugen": "vorbeugen",
    "vorzubilden": "vorbilden",
    "vorzubinden": "vorbinden",
    "vorzubleichen": "vorbleichen",
    "vorzubohren": "vorbohren",
    "vorzubringen": "vorbringen",
    "vorzudatieren": "vordatieren",
    "vorzudenken": "vordenken",
    "vorzudringen": "vordringen",
    "vorzudrängen": "vordrängen",
    "vorzuenthalten": "vorenthalten",
    "vorzuerzählen": "vorerzählen",
    "vorzufahren": "vorfahren",
    "vorzufallen": "vorfallen",
    "vorzufertigen": "vorfertigen",
    "vorzufinanzieren": "vorfinanzieren",
    "vorzufinden": "vorfinden",
    "vorzuflunkern": "vorflunkern",
    "vorzuformen": "vorformen",
    "vorzuformulieren": "vorformulieren",
    "vorzufühlen": "vorfühlen",
    "vorzuführen": "vorführen",
    "vorzugaukeln": "vorgaukeln",
    "vorzugeben": "vorgeben",
    "vorzugehen": "vorgehen",
    "vorzugreifen": "vorgreifen",
    "vorzuhalten": "vorhalten",
    "vorzuharren": "vorharren",
    "vorzuherrschen": "vorherrschen",
    "vorzuheucheln": "vorheucheln",
    "vorzuheulen": "vorheulen",
    "vorzuhängen": "vorhängen",
    "vorzujammern": "vorjammern",
    "vorzukauen": "vorkauen",
    "vorzukehren": "vorkehren",
    "vorzukeimen": "vorkeimen",
    "vorzuknöpfen": "vorknöpfen",
    "vorzukommen": "vorkommen",
    "vorzuladen": "vorladen",
    "vorzulaufen": "vorlaufen",
    "vorzuleben": "vorleben",
    "vorzulegen": "vorlegen",
    "vorzulesen": "vorlesen",
    "vorzuliegen": "vorliegen",
    "vorzulügen": "vorlügen",
    "vorzumachen": "vormachen",
    "vorzumerken": "vormerken",
    "vorzunehmen": "vornehmen",
    "vorzuneigen": "vorneigen",
    "vorzuordnen": "vorordnen",
    "vorzupreschen": "vorpreschen",
    "vorzuprogrammieren": "vorprogrammieren",
    "vorzuquellen": "vorquellen",
    "vorzurechnen": "vorrechnen",
    "vorzureden": "vorreden",
    "vorzureiten": "vorreiten",
    "vorzurichten": "vorrichten",
    "vorzurücken": "vorrücken",
    "vorzusagen": "vorsagen",
    "vorzuschieben": "vorschieben",
    "vorzuschießen": "vorschießen",
    "vorzuschlagen": "vorschlagen",
    "vorzuschneiden": "vorschneiden",
    "vorzuschreiben": "vorschreiben",
    "vorzuschweben": "vorschweben",
    "vorzuschwindeln": "vorschwindeln",
    "vorzuschwärmen": "vorschwärmen",
    "vorzuschützen": "vorschützen",
    "vorzusehen": "vorsehen",
    "vorzusetzen": "vorsetzen",
    "vorzusingen": "vorsingen",
    "vorzusitzen": "vorsitzen",
    "vorzusorgen": "vorsorgen",
    "vorzuspannen": "vorspannen",
    "vorzuspiegeln": "vorspiegeln",
    "vorzuspielen": "vorspielen",
    "vorzusprechen": "vorsprechen",
    "vorzuspringen": "vorspringen",
    "vorzuspulen": "vorspulen",
    "vorzustehen": "vorstehen",
    "vorzustellen": "vorstellen",
    "vorzustoßen": "vorstoßen",
    "vorzustülpen": "vorstülpen",
    "vorzustürmen": "vorstürmen",
    "vorzutanzen": "vortanzen",
    "vorzutragen": "vortragen",
    "vorzutreiben": "vortreiben",
    "vorzutreten": "vortreten",
    "vorzuturnen": "vorturnen",
    "vorzutäuschen": "vortäuschen",
    "vorzuverlegen": "vorverlegen",
    "vorzuwagen": "vorwagen",
    "vorzuwarnen": "vorwarnen",
    "vorzuweisen": "vorweisen",
    "vorzuwerfen": "vorwerfen",
    "vorzuwiegen": "vorwiegen",
    "vorzuwählen": "vorwählen",
    "vorzuwärmen": "vorwärmen",
    "vorzuwölben": "vorwölben",
    "vorzuzaubern": "vorzaubern",
    "vorzuzeichnen": "vorzeichnen",
    "vorzuzeigen": "vorzeigen",
    "vorzuziehen": "vorziehen",
    "vorzuzählen": "vorzählen",
    "vorzähle": "vorzählen",
    "vorzählend": "vorzählen",
    "vorzählende": "vorzählend",
    "vorzählendem": "vorzählend",
    "vorzählenden": "vorzählend",
    "vorzählender": "vorzählend",
    "vorzählendes": "vorzählend",
    "vorzählest": "vorzählen",
    "vorzählet": "vorzählen",
    "vorzählst": "vorzählen",
    "vorzählt": "vorzählen",
    "vorzählte": "vorzählen",
    "vorzählten": "vorzählen",
    "vorzähltest": "vorzählen",
    "vorzähltet": "vorzählen",
    "vorzöge": "vorziehen",
    "vorzögen": "vorziehen",
    "vorzögest": "vorziehen",
    "vorzöget": "vorziehen",
    "vorzüglichem": "vorzüglich",
    "vorzüglichen": "vorzüglich",
    "vorzüglicher": "vorzüglich",
    "vorzüglichere": "vorzüglich",
    "vorzüglicherem": "vorzüglich",
    "vorzüglicheren": "vorzüglich",
    "vorzüglicherer": "vorzüglich",
    "vorzüglicheres": "vorzüglich",
    "vorzügliches": "vorzüglich",
    "vorzüglichste": "vorzüglich",
    "vorzüglichstem": "vorzüglich",
    "vorzüglichsten": "vorzüglich",
    "vorzüglichster": "vorzüglich",
    "vorzüglichstes": "vorzüglich",
    "vorübergegangen": "vorübergehen",
    "vorübergegangene": "vorübergegangen",
    "vorübergegangenem": "vorübergegangen",
    "vorübergegangenen": "vorübergegangen",
    "vorübergegangener": "vorübergegangen",
    "vorübergegangenes": "vorübergegangen",
    "vorübergehe": "vorübergehen",
    "vorübergehend": "vorübergehen",
    "vorübergehende": "vorübergehend",
    "vorübergehendem": "vorübergehend",
    "vorübergehenden": "vorübergehend",
    "vorübergehender": "vorübergehend",
    "vorübergehendes": "vorübergehend",
    "vorübergehest": "vorübergehen",
    "vorübergehet": "vorübergehen",
    "vorübergehst": "vorübergehen",
    "vorübergeht": "vorübergehen",
    "vorüberging": "vorübergehen",
    "vorüberginge": "vorübergehen",
    "vorübergingen": "vorübergehen",
    "vorübergingest": "vorübergehen",
    "vorüberginget": "vorübergehen",
    "vorübergingst": "vorübergehen",
    "vorübergingt": "vorübergehen",
    "vorüberzugehen": "vorübergehen",
    "väterlichem": "väterlich",
    "väterlichen": "väterlich",
    "väterlicher": "väterlich",
    "väterlichere": "väterlich",
    "väterlicherem": "väterlich",
    "väterlicheren": "väterlich",
    "väterlicherer": "väterlich",
    "väterlicheres": "väterlich",
    "väterliches": "väterlich",
    "väterlichste": "väterlich",
    "väterlichstem": "väterlich",
    "väterlichsten": "väterlich",
    "väterlichster": "väterlich",
    "väterlichstes": "väterlich",
    "vögele": "vögeln",
    "vögelnd": "vögeln",
    "vögelnde": "vögelnd",
    "vögelndem": "vögelnd",
    "vögelnden": "vögelnd",
    "vögelnder": "vögelnd",
    "vögelndes": "vögelnd",
    "vögelst": "vögeln",
    "vögelt": "vögeln",
    "vögelte": "vögeln",
    "vögelten": "vögeln",
    "vögeltest": "vögeln",
    "vögeltet": "vögeln",
    "vögle": "vögeln",
    "völkerkundlichem": "völkerkundlich",
    "völkerkundlichen": "völkerkundlich",
    "völkerkundlicher": "völkerkundlich",
    "völkerkundliches": "völkerkundlich",
    "völkerrechtlichem": "völkerrechtlich",
    "völkerrechtlichen": "völkerrechtlich",
    "völkerrechtlicher": "völkerrechtlich",
    "völkerrechtliches": "völkerrechtlich",
    "völlige": "völlig",
    "völligem": "völlig",
    "völligen": "völlig",
    "völliger": "völlig",
    "völliges": "völlig",
    "waagerechtem": "waagerecht",
    "waagerechten": "waagerecht",
    "waagerechter": "waagerecht",
    "waagerechtes": "waagerecht",
    "wabbele": "wabbeln",
    "wabbelige": "wabbelig",
    "wabbeligem": "wabbelig",
    "wabbeligen": "wabbelig",
    "wabbeliger": "wabbelig",
    "wabbeligere": "wabbelig",
    "wabbeligerem": "wabbelig",
    "wabbeligeren": "wabbelig",
    "wabbeligerer": "wabbelig",
    "wabbeligeres": "wabbelig",
    "wabbeliges": "wabbelig",
    "wabbeligste": "wabbelig",
    "wabbeligstem": "wabbelig",
    "wabbeligsten": "wabbelig",
    "wabbeligster": "wabbelig",
    "wabbeligstes": "wabbelig",
    "wabbelnd": "wabbeln",
    "wabbelnde": "wabbelnd",
    "wabbelndem": "wabbelnd",
    "wabbelnden": "wabbelnd",
    "wabbelnder": "wabbelnd",
    "wabbelndere": "wabbelnd",
    "wabbelnderem": "wabbelnd",
    "wabbelnderen": "wabbelnd",
    "wabbelnderer": "wabbelnd",
    "wabbelnderes": "wabbelnd",
    "wabbelndes": "wabbelnd",
    "wabbelndste": "wabbelnd",
    "wabbelndstem": "wabbelnd",
    "wabbelndsten": "wabbelnd",
    "wabbelndster": "wabbelnd",
    "wabbelndstes": "wabbelnd",
    "wabbelst": "wabbeln",
    "wabbelt": "wabbeln",
    "wabbelte": "wabbeln",
    "wabbelten": "wabbeln",
    "wabbeltest": "wabbeln",
    "wabbeltet": "wabbeln",
    "wabble": "wabbeln",
    "wachend": "wachen",
    "wachende": "wachend",
    "wachendem": "wachend",
    "wachenden": "wachend",
    "wachender": "wachend",
    "wachendes": "wachend",
    "wachest": "wachen",
    "wachet": "wachen",
    "wachgehalten": "wachhalten",
    "wachgehaltene": "wachgehalten",
    "wachgehaltenem": "wachgehalten",
    "wachgehaltenen": "wachgehalten",
    "wachgehaltener": "wachgehalten",
    "wachgehaltenere": "wachgehalten",
    "wachgehaltenerem": "wachgehalten",
    "wachgehalteneren": "wachgehalten",
    "wachgehaltenerer": "wachgehalten",
    "wachgehalteneres": "wachgehalten",
    "wachgehaltenes": "wachgehalten",
    "wachgehaltenste": "wachgehalten",
    "wachgehaltenstem": "wachgehalten",
    "wachgehaltensten": "wachgehalten",
    "wachgehaltenster": "wachgehalten",
    "wachgehaltenstes": "wachgehalten",
    "wachgerufen": "wachrufen",
    "wachgerufene": "wachgerufen",
    "wachgerufenem": "wachgerufen",
    "wachgerufenen": "wachgerufen",
    "wachgerufener": "wachgerufen",
    "wachgerufenes": "wachgerufen",
    "wachgerüttelt": "wachrütteln",
    "wachgerüttelte": "wachgerüttelt",
    "wachgerütteltem": "wachgerüttelt",
    "wachgerüttelten": "wachgerüttelt",
    "wachgerüttelter": "wachgerüttelt",
    "wachgerütteltere": "wachgerüttelt",
    "wachgerüttelterem": "wachgerüttelt",
    "wachgerüttelteren": "wachgerüttelt",
    "wachgerüttelterer": "wachgerüttelt",
    "wachgerüttelteres": "wachgerüttelt",
    "wachgerütteltes": "wachgerüttelt",
    "wachgerüttelteste": "wachgerüttelt",
    "wachgerütteltestem": "wachgerüttelt",
    "wachgerütteltesten": "wachgerüttelt",
    "wachgerütteltester": "wachgerüttelt",
    "wachgerütteltestes": "wachgerüttelt",
    "wachhalte": "wachhalten",
    "wachhaltend": "wachhalten",
    "wachhaltende": "wachhaltend",
    "wachhaltendem": "wachhaltend",
    "wachhaltenden": "wachhaltend",
    "wachhaltender": "wachhaltend",
    "wachhaltendere": "wachhaltend",
    "wachhaltenderem": "wachhaltend",
    "wachhaltenderen": "wachhaltend",
    "wachhaltenderer": "wachhaltend",
    "wachhaltenderes": "wachhaltend",
    "wachhaltendes": "wachhaltend",
    "wachhaltendste": "wachhaltend",
    "wachhaltendstem": "wachhaltend",
    "wachhaltendsten": "wachhaltend",
    "wachhaltendster": "wachhaltend",
    "wachhaltendstes": "wachhaltend",
    "wachhaltest": "wachhalten",
    "wachhaltet": "wachhalten",
    "wachhielt": "wachhalten",
    "wachhielte": "wachhalten",
    "wachhielten": "wachhalten",
    "wachhieltest": "wachhalten",
    "wachhieltet": "wachhalten",
    "wachhält": "wachhalten",
    "wachhältst": "wachhalten",
    "wachrief": "wachrufen",
    "wachriefe": "wachrufen",
    "wachriefen": "wachrufen",
    "wachriefest": "wachrufen",
    "wachriefet": "wachrufen",
    "wachriefst": "wachrufen",
    "wachrieft": "wachrufen",
    "wachrufe": "wachrufen",
    "wachrufend": "wachrufen",
    "wachrufende": "wachrufend",
    "wachrufendem": "wachrufend",
    "wachrufenden": "wachrufend",
    "wachrufender": "wachrufend",
    "wachrufendes": "wachrufend",
    "wachrufest": "wachrufen",
    "wachrufet": "wachrufen",
    "wachrufst": "wachrufen",
    "wachruft": "wachrufen",
    "wachrüttele": "wachrütteln",
    "wachrüttelnd": "wachrütteln",
    "wachrüttelnde": "wachrüttelnd",
    "wachrüttelndem": "wachrüttelnd",
    "wachrüttelnden": "wachrüttelnd",
    "wachrüttelnder": "wachrüttelnd",
    "wachrüttelndere": "wachrüttelnd",
    "wachrüttelnderem": "wachrüttelnd",
    "wachrüttelnderen": "wachrüttelnd",
    "wachrüttelnderer": "wachrüttelnd",
    "wachrüttelnderes": "wachrüttelnd",
    "wachrüttelndes": "wachrüttelnd",
    "wachrüttelndste": "wachrüttelnd",
    "wachrüttelndstem": "wachrüttelnd",
    "wachrüttelndsten": "wachrüttelnd",
    "wachrüttelndster": "wachrüttelnd",
    "wachrüttelndstes": "wachrüttelnd",
    "wachrüttelst": "wachrütteln",
    "wachrüttelt": "wachrütteln",
    "wachrüttelte": "wachrütteln",
    "wachrüttelten": "wachrütteln",
    "wachrütteltest": "wachrütteln",
    "wachrütteltet": "wachrütteln",
    "wachrüttle": "wachrütteln",
    "wachsame": "wachsam",
    "wachsamem": "wachsam",
    "wachsamen": "wachsam",
    "wachsamer": "wachsam",
    "wachsamere": "wachsam",
    "wachsamerem": "wachsam",
    "wachsameren": "wachsam",
    "wachsamerer": "wachsam",
    "wachsameres": "wachsam",
    "wachsames": "wachsam",
    "wachsamste": "wachsam",
    "wachsamstem": "wachsam",
    "wachsamsten": "wachsam",
    "wachsamster": "wachsam",
    "wachsamstes": "wachsam",
    "wachse": "wachsen",
    "wachsend": "wachsen",
    "wachsende": "wachsend",
    "wachsendem": "wachsend",
    "wachsenden": "wachsend",
    "wachsender": "wachsend",
    "wachsendes": "wachsend",
    "wachsest": "wachsen",
    "wachset": "wachsen",
    "wachst": "wachsen",
    "wachste": "wachsen",
    "wachsten": "wachsen",
    "wachstest": "wachsen",
    "wachstet": "wachsen",
    "wacht": "wachen",
    "wachte": "wachen",
    "wachten": "wachen",
    "wachtest": "wachen",
    "wachtet": "wachen",
    "wachzuhalten": "wachhalten",
    "wachzurufen": "wachrufen",
    "wachzurütteln": "wachrütteln",
    "wackere": "wacker",
    "wackerem": "wacker",
    "wackeren": "wacker",
    "wackerer": "wacker",
    "wackerere": "wacker",
    "wackererem": "wacker",
    "wackereren": "wacker",
    "wackererer": "wacker",
    "wackereres": "wacker",
    "wackeres": "wacker",
    "wackerstem": "wacker",
    "wackersten": "wacker",
    "wackerster": "wacker",
    "wackerstes": "wacker",
    "wacklige": "wacklig",
    "wackligem": "wacklig",
    "wackligen": "wacklig",
    "wackliger": "wacklig",
    "wackligere": "wacklig",
    "wackligerem": "wacklig",
    "wackligeren": "wacklig",
    "wackligerer": "wacklig",
    "wackligeres": "wacklig",
    "wackliges": "wacklig",
    "wackligste": "wacklig",
    "wackligstem": "wacklig",
    "wackligsten": "wacklig",
    "wackligster": "wacklig",
    "wackligstes": "wacklig",
    "waffne": "waffnen",
    "waffnend": "waffnen",
    "waffnende": "waffnend",
    "waffnendem": "waffnend",
    "waffnenden": "waffnend",
    "waffnender": "waffnend",
    "waffnendes": "waffnend",
    "waffnest": "waffnen",
    "waffnet": "waffnen",
    "waffnete": "waffnen",
    "waffneten": "waffnen",
    "waffnetest": "waffnen",
    "waffnetet": "waffnen",
    "wage": "wagen",
    "wagemutigem": "wagemutig",
    "wagemutigen": "wagemutig",
    "wagemutiger": "wagemutig",
    "wagemutigere": "wagemutig",
    "wagemutigerem": "wagemutig",
    "wagemutigeren": "wagemutig",
    "wagemutigerer": "wagemutig",
    "wagemutigeres": "wagemutig",
    "wagemutiges": "wagemutig",
    "wagemutigste": "wagemutig",
    "wagemutigstem": "wagemutig",
    "wagemutigsten": "wagemutig",
    "wagemutigster": "wagemutig",
    "wagemutigstes": "wagemutig",
    "wagend": "wagen",
    "wagende": "wagend",
    "wagendem": "wagend",
    "wagenden": "wagend",
    "wagender": "wagend",
    "wagendes": "wagend",
    "wagest": "wagen",
    "waget": "wagen",
    "waghalsigem": "waghalsig",
    "waghalsigen": "waghalsig",
    "waghalsiger": "waghalsig",
    "waghalsigere": "waghalsig",
    "waghalsigerem": "waghalsig",
    "waghalsigeren": "waghalsig",
    "waghalsigerer": "waghalsig",
    "waghalsigeres": "waghalsig",
    "waghalsiges": "waghalsig",
    "waghalsigste": "waghalsig",
    "waghalsigstem": "waghalsig",
    "waghalsigsten": "waghalsig",
    "waghalsigster": "waghalsig",
    "waghalsigstes": "waghalsig",
    "wagst": "wagen",
    "wagt": "wagen",
    "wagte": "wagen",
    "wagten": "wagen",
    "wagtest": "wagen",
    "wagtet": "wagen",
    "wahlberechtigte": "wahlberechtigt",
    "wahlberechtigtem": "wahlberechtigt",
    "wahlberechtigten": "wahlberechtigt",
    "wahlberechtigter": "wahlberechtigt",
    "wahlberechtigtes": "wahlberechtigt",
    "wahlfreie": "wahlfrei",
    "wahlfreiem": "wahlfrei",
    "wahlfreien": "wahlfrei",
    "wahlfreier": "wahlfrei",
    "wahlfreies": "wahlfrei",
    "wahllose": "wahllos",
    "wahllosem": "wahllos",
    "wahllosen": "wahllos",
    "wahlloser": "wahllos",
    "wahllosere": "wahllos",
    "wahlloserem": "wahllos",
    "wahlloseren": "wahllos",
    "wahlloserer": "wahllos",
    "wahlloseres": "wahllos",
    "wahlloses": "wahllos",
    "wahlloseste": "wahllos",
    "wahllosestem": "wahllos",
    "wahllosesten": "wahllos",
    "wahllosester": "wahllos",
    "wahllosestes": "wahllos",
    "wahlweisem": "wahlweise",
    "wahlweisen": "wahlweise",
    "wahlweiser": "wahlweise",
    "wahlweises": "wahlweise",
    "wahnsinnige": "wahnsinnig",
    "wahnsinnigem": "wahnsinnig",
    "wahnsinnigen": "wahnsinnig",
    "wahnsinniger": "wahnsinnig",
    "wahnsinnigere": "wahnsinnig",
    "wahnsinnigerem": "wahnsinnig",
    "wahnsinnigeren": "wahnsinnig",
    "wahnsinnigerer": "wahnsinnig",
    "wahnsinnigeres": "wahnsinnig",
    "wahnsinniges": "wahnsinnig",
    "wahnsinnigste": "wahnsinnig",
    "wahnsinnigstem": "wahnsinnig",
    "wahnsinnigsten": "wahnsinnig",
    "wahnsinnigster": "wahnsinnig",
    "wahnsinnigstes": "wahnsinnig",
    "wahnwitzige": "wahnwitzig",
    "wahnwitzigem": "wahnwitzig",
    "wahnwitzigen": "wahnwitzig",
    "wahnwitziger": "wahnwitzig",
    "wahnwitzigere": "wahnwitzig",
    "wahnwitzigerem": "wahnwitzig",
    "wahnwitzigeren": "wahnwitzig",
    "wahnwitzigerer": "wahnwitzig",
    "wahnwitzigeres": "wahnwitzig",
    "wahnwitziges": "wahnwitzig",
    "wahnwitzigste": "wahnwitzig",
    "wahnwitzigstem": "wahnwitzig",
    "wahnwitzigsten": "wahnwitzig",
    "wahnwitzigster": "wahnwitzig",
    "wahnwitzigstes": "wahnwitzig",
    "wahr": "wahren",
    "wahre": "wahr",
    "wahrem": "wahr",
    "wahren": "wahr",
    "wahrend": "wahren",
    "wahrende": "wahrend",
    "wahrendem": "wahrend",
    "wahrenden": "wahrend",
    "wahrender": "wahrend",
    "wahrendes": "wahrend",
    "wahrer": "wahr",
    "wahres": "wahr",
    "wahrest": "wahren",
    "wahret": "wahren",
    "wahrgenommen": "wahrnehmen",
    "wahrgenommene": "wahrgenommen",
    "wahrgenommenem": "wahrgenommen",
    "wahrgenommenen": "wahrgenommen",
    "wahrgenommener": "wahrgenommen",
    "wahrgenommenes": "wahrgenommen",
    "wahrgesagt": "wahrsagen",
    "wahrgesagte": "wahrgesagt",
    "wahrgesagtem": "wahrgesagt",
    "wahrgesagten": "wahrgesagt",
    "wahrgesagter": "wahrgesagt",
    "wahrgesagtes": "wahrgesagt",
    "wahrhafte": "wahrhaft",
    "wahrhaftem": "wahrhaft",
    "wahrhaften": "wahrhaft",
    "wahrhafter": "wahrhaft",
    "wahrhaftere": "wahrhaft",
    "wahrhafterem": "wahrhaft",
    "wahrhafteren": "wahrhaft",
    "wahrhafterer": "wahrhaft",
    "wahrhafteres": "wahrhaft",
    "wahrhaftes": "wahrhaft",
    "wahrhafteste": "wahrhaft",
    "wahrhaftestem": "wahrhaft",
    "wahrhaftesten": "wahrhaft",
    "wahrhaftester": "wahrhaft",
    "wahrhaftestes": "wahrhaft",
    "wahrhaftige": "wahrhaftig",
    "wahrhaftigem": "wahrhaftig",
    "wahrhaftigen": "wahrhaftig",
    "wahrhaftiger": "wahrhaftig",
    "wahrhaftigere": "wahrhaftig",
    "wahrhaftigerem": "wahrhaftig",
    "wahrhaftigeren": "wahrhaftig",
    "wahrhaftigerer": "wahrhaftig",
    "wahrhaftigeres": "wahrhaftig",
    "wahrhaftiges": "wahrhaftig",
    "wahrhaftigste": "wahrhaftig",
    "wahrhaftigstem": "wahrhaftig",
    "wahrhaftigsten": "wahrhaftig",
    "wahrhaftigster": "wahrhaftig",
    "wahrhaftigstes": "wahrhaftig",
    "wahrheitsgemäßem": "wahrheitsgemäß",
    "wahrheitsgemäßen": "wahrheitsgemäß",
    "wahrheitsgemäßer": "wahrheitsgemäß",
    "wahrheitsgemäßes": "wahrheitsgemäß",
    "wahrheitsliebende": "wahrheitsliebend",
    "wahrheitsliebendem": "wahrheitsliebend",
    "wahrheitsliebenden": "wahrheitsliebend",
    "wahrheitsliebender": "wahrheitsliebend",
    "wahrheitsliebendes": "wahrheitsliebend",
    "wahrnahm": "wahrnehmen",
    "wahrnahmen": "wahrnehmen",
    "wahrnahmst": "wahrnehmen",
    "wahrnahmt": "wahrnehmen",
    "wahrnehmbare": "wahrnehmbar",
    "wahrnehmbarem": "wahrnehmbar",
    "wahrnehmbaren": "wahrnehmbar",
    "wahrnehmbarer": "wahrnehmbar",
    "wahrnehmbares": "wahrnehmbar",
    "wahrnehme": "wahrnehmen",
    "wahrnehmend": "wahrnehmen",
    "wahrnehmende": "wahrnehmend",
    "wahrnehmendem": "wahrnehmend",
    "wahrnehmenden": "wahrnehmend",
    "wahrnehmender": "wahrnehmend",
    "wahrnehmendes": "wahrnehmend",
    "wahrnehmest": "wahrnehmen",
    "wahrnehmet": "wahrnehmen",
    "wahrnehmt": "wahrnehmen",
    "wahrnimmst": "wahrnehmen",
    "wahrnimmt": "wahrnehmen",
    "wahrnähme": "wahrnehmen",
    "wahrnähmen": "wahrnehmen",
    "wahrnähmest": "wahrnehmen",
    "wahrnähmet": "wahrnehmen",
    "wahrsage": "wahrsagen",
    "wahrsagend": "wahrsagen",
    "wahrsagende": "wahrsagend",
    "wahrsagendem": "wahrsagend",
    "wahrsagenden": "wahrsagend",
    "wahrsagender": "wahrsagend",
    "wahrsagendes": "wahrsagend",
    "wahrsagest": "wahrsagen",
    "wahrsaget": "wahrsagen",
    "wahrsagst": "wahrsagen",
    "wahrsagt": "wahrsagen",
    "wahrsagte": "wahrsagen",
    "wahrsagten": "wahrsagen",
    "wahrsagtest": "wahrsagen",
    "wahrsagtet": "wahrsagen",
    "wahrst": "wahren",
    "wahrt": "wahren",
    "wahrte": "wahren",
    "wahrten": "wahren",
    "wahrtest": "wahren",
    "wahrtet": "wahren",
    "wahrzunehmen": "wahrnehmen",
    "wahrzusagen": "wahrsagen",
    "walisischem": "walisisch",
    "walisischen": "walisisch",
    "walisischer": "walisisch",
    "walisisches": "walisisch",
    "walle": "wallen",
    "wallend": "wallen",
    "wallende": "wallend",
    "wallendem": "wallend",
    "wallenden": "wallend",
    "wallender": "wallend",
    "wallendes": "wallend",
    "wallest": "wallen",
    "wallet": "wallen",
    "wallst": "wallen",
    "wallt": "wallen",
    "wallte": "wallen",
    "wallten": "wallen",
    "walltest": "wallen",
    "walltet": "wallen",
    "walte": "walten",
    "waltend": "walten",
    "waltende": "waltend",
    "waltendem": "waltend",
    "waltenden": "waltend",
    "waltender": "waltend",
    "waltendes": "waltend",
    "waltest": "walten",
    "waltet": "walten",
    "waltete": "walten",
    "walteten": "walten",
    "waltetest": "walten",
    "waltetet": "walten",
    "walzend": "walzen",
    "walzende": "walzend",
    "walzendem": "walzend",
    "walzenden": "walzend",
    "walzender": "walzend",
    "walzendere": "walzend",
    "walzenderem": "walzend",
    "walzenderen": "walzend",
    "walzenderer": "walzend",
    "walzenderes": "walzend",
    "walzendes": "walzend",
    "walzendste": "walzend",
    "walzendstem": "walzend",
    "walzendsten": "walzend",
    "walzendster": "walzend",
    "walzendstes": "walzend",
    "walzest": "walzen",
    "walzet": "walzen",
    "walzt": "walzen",
    "walzte": "walzen",
    "walzten": "walzen",
    "walztest": "walzen",
    "walztet": "walzen",
    "wand": "winden",
    "wandele": "wandeln",
    "wandelnd": "wandeln",
    "wandelnde": "wandelnd",
    "wandelndem": "wandelnd",
    "wandelnden": "wandelnd",
    "wandelnder": "wandelnd",
    "wandelndere": "wandelnd",
    "wandelnderem": "wandelnd",
    "wandelnderen": "wandelnd",
    "wandelnderer": "wandelnd",
    "wandelnderes": "wandelnd",
    "wandelndes": "wandelnd",
    "wandelndste": "wandelnd",
    "wandelndstem": "wandelnd",
    "wandelndsten": "wandelnd",
    "wandelndster": "wandelnd",
    "wandelndstes": "wandelnd",
    "wandelst": "wandeln",
    "wandelt": "wandeln",
    "wandelte": "wandeln",
    "wandelten": "wandeln",
    "wandeltest": "wandeln",
    "wandeltet": "wandeln",
    "wanden": "winden",
    "wandere": "wandern",
    "wandernd": "wandern",
    "wandernde": "wandernd",
    "wanderndem": "wandernd",
    "wandernden": "wandernd",
    "wandernder": "wandernd",
    "wanderndes": "wandernd",
    "wanderst": "wandern",
    "wandert": "wandern",
    "wanderte": "wandern",
    "wanderten": "wandern",
    "wandertest": "wandern",
    "wandertet": "wandern",
    "wandest": "winden",
    "wandet": "winden",
    "wandle": "wandeln",
    "wandlungsfähigem": "wandlungsfähig",
    "wandlungsfähigen": "wandlungsfähig",
    "wandlungsfähiger": "wandlungsfähig",
    "wandlungsfähigere": "wandlungsfähig",
    "wandlungsfähigerem": "wandlungsfähig",
    "wandlungsfähigeren": "wandlungsfähig",
    "wandlungsfähigerer": "wandlungsfähig",
    "wandlungsfähigeres": "wandlungsfähig",
    "wandlungsfähiges": "wandlungsfähig",
    "wandlungsfähigste": "wandlungsfähig",
    "wandlungsfähigstem": "wandlungsfähig",
    "wandlungsfähigsten": "wandlungsfähig",
    "wandlungsfähigster": "wandlungsfähig",
    "wandlungsfähigstes": "wandlungsfähig",
    "wandte": "wenden",
    "wandten": "wenden",
    "wandtest": "wenden",
    "wandtet": "wenden",
    "wanke": "wanken",
    "wankelmütigem": "wankelmütig",
    "wankelmütigen": "wankelmütig",
    "wankelmütiger": "wankelmütig",
    "wankelmütigere": "wankelmütig",
    "wankelmütigerem": "wankelmütig",
    "wankelmütigeren": "wankelmütig",
    "wankelmütigerer": "wankelmütig",
    "wankelmütigeres": "wankelmütig",
    "wankelmütiges": "wankelmütig",
    "wankelmütigste": "wankelmütig",
    "wankelmütigstem": "wankelmütig",
    "wankelmütigsten": "wankelmütig",
    "wankelmütigster": "wankelmütig",
    "wankelmütigstes": "wankelmütig",
    "wankend": "wanken",
    "wankende": "wankend",
    "wankendem": "wankend",
    "wankenden": "wankend",
    "wankender": "wankend",
    "wankendere": "wankend",
    "wankenderem": "wankend",
    "wankenderen": "wankend",
    "wankenderer": "wankend",
    "wankenderes": "wankend",
    "wankendes": "wankend",
    "wankendste": "wankend",
    "wankendstem": "wankend",
    "wankendsten": "wankend",
    "wankendster": "wankend",
    "wankendstes": "wankend",
    "wankest": "wanken",
    "wanket": "wanken",
    "wankst": "wanken",
    "wankt": "wanken",
    "wankte": "wanken",
    "wankten": "wanken",
    "wanktest": "wanken",
    "wanktet": "wanken",
    "wappne": "wappnen",
    "wappnend": "wappnen",
    "wappnende": "wappnend",
    "wappnendem": "wappnend",
    "wappnenden": "wappnend",
    "wappnender": "wappnend",
    "wappnendes": "wappnend",
    "wappnest": "wappnen",
    "wappnet": "wappnen",
    "wappnete": "wappnen",
    "wappneten": "wappnen",
    "wappnetest": "wappnen",
    "wappnetet": "wappnen",
    "war": "sein",
    "warb": "werben",
    "warben": "werben",
    "warbst": "werben",
    "warbt": "werben",
    "waren": "sein",
    "warenkundliche": "warenkundlich",
    "warenkundlichem": "warenkundlich",
    "warenkundlichen": "warenkundlich",
    "warenkundlicher": "warenkundlich",
    "warenkundliches": "warenkundlich",
    "warf": "werfen",
    "warfen": "werfen",
    "warfst": "werfen",
    "warft": "werfen",
    "warmblütigem": "warmblütig",
    "warmblütigen": "warmblütig",
    "warmblütiger": "warmblütig",
    "warmblütiges": "warmblütig",
    "warmem": "warm",
    "warmen": "warm",
    "warmer": "warm",
    "warmes": "warm",
    "warmgehalten": "warmhalten",
    "warmgehaltene": "warmgehalten",
    "warmgehaltenem": "warmgehalten",
    "warmgehaltenen": "warmgehalten",
    "warmgehaltener": "warmgehalten",
    "warmgehaltenere": "warmgehalten",
    "warmgehaltenerem": "warmgehalten",
    "warmgehalteneren": "warmgehalten",
    "warmgehaltenerer": "warmgehalten",
    "warmgehalteneres": "warmgehalten",
    "warmgehaltenes": "warmgehalten",
    "warmgehaltenste": "warmgehalten",
    "warmgehaltenstem": "warmgehalten",
    "warmgehaltensten": "warmgehalten",
    "warmgehaltenster": "warmgehalten",
    "warmgehaltenstes": "warmgehalten",
    "warmhalte": "warmhalten",
    "warmhaltend": "warmhalten",
    "warmhaltende": "warmhaltend",
    "warmhaltendem": "warmhaltend",
    "warmhaltenden": "warmhaltend",
    "warmhaltender": "warmhaltend",
    "warmhaltendere": "warmhaltend",
    "warmhaltenderem": "warmhaltend",
    "warmhaltenderen": "warmhaltend",
    "warmhaltenderer": "warmhaltend",
    "warmhaltenderes": "warmhaltend",
    "warmhaltendes": "warmhaltend",
    "warmhaltendste": "warmhaltend",
    "warmhaltendstem": "warmhaltend",
    "warmhaltendsten": "warmhaltend",
    "warmhaltendster": "warmhaltend",
    "warmhaltendstes": "warmhaltend",
    "warmhaltest": "warmhalten",
    "warmhaltet": "warmhalten",
    "warmherzige": "warmherzig",
    "warmherzigem": "warmherzig",
    "warmherzigen": "warmherzig",
    "warmherziger": "warmherzig",
    "warmherzigere": "warmherzig",
    "warmherzigerem": "warmherzig",
    "warmherzigeren": "warmherzig",
    "warmherzigerer": "warmherzig",
    "warmherzigeres": "warmherzig",
    "warmherziges": "warmherzig",
    "warmherzigste": "warmherzig",
    "warmherzigstem": "warmherzig",
    "warmherzigsten": "warmherzig",
    "warmherzigster": "warmherzig",
    "warmherzigstes": "warmherzig",
    "warmhielt": "warmhalten",
    "warmhielte": "warmhalten",
    "warmhielten": "warmhalten",
    "warmhieltest": "warmhalten",
    "warmhieltet": "warmhalten",
    "warmhält": "warmhalten",
    "warmhältst": "warmhalten",
    "warmzuhalten": "warmhalten",
    "warne": "warnen",
    "warnend": "warnen",
    "warnende": "warnend",
    "warnendem": "warnend",
    "warnenden": "warnend",
    "warnender": "warnend",
    "warnendes": "warnend",
    "warnest": "warnen",
    "warnet": "warnen",
    "warnst": "warnen",
    "warnt": "warnen",
    "warnte": "warnen",
    "warnten": "warnen",
    "warntest": "warnen",
    "warntet": "warnen",
    "warst": "sein",
    "wart": "sein",
    "warte": "warten",
    "wartend": "warten",
    "wartende": "wartend",
    "wartendem": "wartend",
    "wartenden": "wartend",
    "wartender": "wartend",
    "wartendes": "wartend",
    "wartest": "warten",
    "wartet": "warten",
    "wartete": "warten",
    "warteten": "warten",
    "wartetest": "warten",
    "wartetet": "warten",
    "wartungsfreiem": "wartungsfrei",
    "wartungsfreien": "wartungsfrei",
    "wartungsfreier": "wartungsfrei",
    "wartungsfreies": "wartungsfrei",
    "was": "wer",
    "waschbarem": "waschbar",
    "waschbaren": "waschbar",
    "waschbarer": "waschbar",
    "waschbares": "waschbar",
    "wasche": "waschen",
    "waschechte": "waschecht",
    "waschechtem": "waschecht",
    "waschechten": "waschecht",
    "waschechter": "waschecht",
    "waschechtes": "waschecht",
    "waschend": "waschen",
    "waschende": "waschend",
    "waschendem": "waschend",
    "waschenden": "waschend",
    "waschender": "waschend",
    "waschendes": "waschend",
    "waschest": "waschen",
    "waschet": "waschen",
    "wascht": "waschen",
    "wasserdichtem": "wasserdicht",
    "wasserdichten": "wasserdicht",
    "wasserdichter": "wasserdicht",
    "wasserdichtere": "wasserdicht",
    "wasserdichterem": "wasserdicht",
    "wasserdichteren": "wasserdicht",
    "wasserdichterer": "wasserdicht",
    "wasserdichteres": "wasserdicht",
    "wasserdichtes": "wasserdicht",
    "wasserdichteste": "wasserdicht",
    "wasserdichtestem": "wasserdicht",
    "wasserdichtesten": "wasserdicht",
    "wasserdichtester": "wasserdicht",
    "wasserdichtestes": "wasserdicht",
    "wasserfeste": "wasserfest",
    "wasserfestem": "wasserfest",
    "wasserfesten": "wasserfest",
    "wasserfester": "wasserfest",
    "wasserfestere": "wasserfest",
    "wasserfesterem": "wasserfest",
    "wasserfesteren": "wasserfest",
    "wasserfesterer": "wasserfest",
    "wasserfesteres": "wasserfest",
    "wasserfestes": "wasserfest",
    "wasserfesteste": "wasserfest",
    "wasserfestestem": "wasserfest",
    "wasserfestesten": "wasserfest",
    "wasserfestester": "wasserfest",
    "wasserfestestes": "wasserfest",
    "wasserlösliche": "wasserlöslich",
    "wasserlöslichem": "wasserlöslich",
    "wasserlöslichen": "wasserlöslich",
    "wasserlöslicher": "wasserlöslich",
    "wasserlöslichere": "wasserlöslich",
    "wasserlöslicherem": "wasserlöslich",
    "wasserlöslicheren": "wasserlöslich",
    "wasserlöslicherer": "wasserlöslich",
    "wasserlöslicheres": "wasserlöslich",
    "wasserlösliches": "wasserlöslich",
    "wasserlöslichste": "wasserlöslich",
    "wasserlöslichstem": "wasserlöslich",
    "wasserlöslichsten": "wasserlöslich",
    "wasserlöslichster": "wasserlöslich",
    "wasserlöslichstes": "wasserlöslich",
    "wasserscheuem": "wasserscheu",
    "wasserscheuen": "wasserscheu",
    "wasserscheuer": "wasserscheu",
    "wasserscheuere": "wasserscheu",
    "wasserscheuerem": "wasserscheu",
    "wasserscheueren": "wasserscheu",
    "wasserscheuerer": "wasserscheu",
    "wasserscheueres": "wasserscheu",
    "wasserscheues": "wasserscheu",
    "wasserscheuste": "wasserscheu",
    "wasserscheustem": "wasserscheu",
    "wasserscheusten": "wasserscheu",
    "wasserscheuster": "wasserscheu",
    "wasserscheustes": "wasserscheu",
    "wassersparende": "wassersparend",
    "wassersparendem": "wassersparend",
    "wassersparenden": "wassersparend",
    "wassersparender": "wassersparend",
    "wassersparendes": "wassersparend",
    "wate": "waten",
    "watend": "waten",
    "watende": "watend",
    "watendem": "watend",
    "watenden": "watend",
    "watender": "watend",
    "watendere": "watend",
    "watenderem": "watend",
    "watenderen": "watend",
    "watenderer": "watend",
    "watenderes": "watend",
    "watendes": "watend",
    "watendste": "watend",
    "watendstem": "watend",
    "watendsten": "watend",
    "watendster": "watend",
    "watendstes": "watend",
    "watest": "waten",
    "watet": "waten",
    "watete": "waten",
    "wateten": "waten",
    "watetest": "waten",
    "watetet": "waten",
    "watschele": "watscheln",
    "watschelnd": "watscheln",
    "watschelnde": "watschelnd",
    "watschelndem": "watschelnd",
    "watschelnden": "watschelnd",
    "watschelnder": "watschelnd",
    "watschelndere": "watschelnd",
    "watschelnderem": "watschelnd",
    "watschelnderen": "watschelnd",
    "watschelnderer": "watschelnd",
    "watschelnderes": "watschelnd",
    "watschelndes": "watschelnd",
    "watschelndste": "watschelnd",
    "watschelndstem": "watschelnd",
    "watschelndsten": "watschelnd",
    "watschelndster": "watschelnd",
    "watschelndstes": "watschelnd",
    "watschelst": "watscheln",
    "watschelt": "watscheln",
    "watschelte": "watscheln",
    "watschelten": "watscheln",
    "watscheltest": "watscheln",
    "watscheltet": "watscheln",
    "watschle": "watscheln",
    "webe": "weben",
    "webend": "weben",
    "webende": "webend",
    "webendem": "webend",
    "webenden": "webend",
    "webender": "webend",
    "webendes": "webend",
    "webest": "weben",
    "webet": "weben",
    "webst": "weben",
    "webt": "weben",
    "webte": "weben",
    "webten": "weben",
    "webtest": "weben",
    "webtet": "weben",
    "wechsele": "wechseln",
    "wechselnd": "wechseln",
    "wechselnde": "wechselnd",
    "wechselndem": "wechselnd",
    "wechselnden": "wechselnd",
    "wechselnder": "wechselnd",
    "wechselndes": "wechselnd",
    "wechselst": "wechseln",
    "wechselt": "wechseln",
    "wechselte": "wechseln",
    "wechselten": "wechseln",
    "wechseltest": "wechseln",
    "wechseltet": "wechseln",
    "wechsle": "wechseln",
    "wecke": "wecken",
    "weckend": "wecken",
    "weckende": "weckend",
    "weckendem": "weckend",
    "weckenden": "weckend",
    "weckender": "weckend",
    "weckendes": "weckend",
    "weckest": "wecken",
    "wecket": "wecken",
    "weckst": "wecken",
    "weckt": "wecken",
    "weckte": "wecken",
    "weckten": "wecken",
    "wecktest": "wecken",
    "wecktet": "wecken",
    "wedele": "wedeln",
    "wedelnd": "wedeln",
    "wedelnde": "wedelnd",
    "wedelndem": "wedelnd",
    "wedelnden": "wedelnd",
    "wedelnder": "wedelnd",
    "wedelndere": "wedelnd",
    "wedelnderem": "wedelnd",
    "wedelnderen": "wedelnd",
    "wedelnderer": "wedelnd",
    "wedelnderes": "wedelnd",
    "wedelndes": "wedelnd",
    "wedelndste": "wedelnd",
    "wedelndstem": "wedelnd",
    "wedelndsten": "wedelnd",
    "wedelndster": "wedelnd",
    "wedelndstes": "wedelnd",
    "wedelst": "wedeln",
    "wedelt": "wedeln",
    "wedelte": "wedeln",
    "wedelten": "wedeln",
    "wedeltest": "wedeln",
    "wedeltet": "wedeln",
    "wedle": "wedeln",
    "wegaß": "wegessen",
    "wegaßen": "wegessen",
    "wegaßt": "wegessen",
    "wegbekam": "wegbekommen",
    "wegbekamen": "wegbekommen",
    "wegbekamst": "wegbekommen",
    "wegbekamt": "wegbekommen",
    "wegbekomme": "wegbekommen",
    "wegbekommend": "wegbekommen",
    "wegbekommende": "wegbekommend",
    "wegbekommendem": "wegbekommend",
    "wegbekommenden": "wegbekommend",
    "wegbekommender": "wegbekommend",
    "wegbekommendes": "wegbekommend",
    "wegbekommene": "wegbekommen",
    "wegbekommenem": "wegbekommen",
    "wegbekommenen": "wegbekommen",
    "wegbekommener": "wegbekommen",
    "wegbekommenes": "wegbekommen",
    "wegbekommest": "wegbekommen",
    "wegbekommet": "wegbekommen",
    "wegbekommst": "wegbekommen",
    "wegbekommt": "wegbekommen",
    "wegbekäme": "wegbekommen",
    "wegbekämen": "wegbekommen",
    "wegbekämest": "wegbekommen",
    "wegbekämet": "wegbekommen",
    "wegblase": "wegblasen",
    "wegblasend": "wegblasen",
    "wegblasende": "wegblasend",
    "wegblasendem": "wegblasend",
    "wegblasenden": "wegblasend",
    "wegblasender": "wegblasend",
    "wegblasendes": "wegblasend",
    "wegblasest": "wegblasen",
    "wegblaset": "wegblasen",
    "wegblast": "wegblasen",
    "wegbleibe": "wegbleiben",
    "wegbleibend": "wegbleiben",
    "wegbleibende": "wegbleibend",
    "wegbleibendem": "wegbleibend",
    "wegbleibenden": "wegbleibend",
    "wegbleibender": "wegbleibend",
    "wegbleibendes": "wegbleibend",
    "wegbleibest": "wegbleiben",
    "wegbleibet": "wegbleiben",
    "wegbleibst": "wegbleiben",
    "wegbleibt": "wegbleiben",
    "wegblicke": "wegblicken",
    "wegblickend": "wegblicken",
    "wegblickende": "wegblickend",
    "wegblickendem": "wegblickend",
    "wegblickenden": "wegblickend",
    "wegblickender": "wegblickend",
    "wegblickendere": "wegblickend",
    "wegblickenderem": "wegblickend",
    "wegblickenderen": "wegblickend",
    "wegblickenderer": "wegblickend",
    "wegblickenderes": "wegblickend",
    "wegblickendes": "wegblickend",
    "wegblickendste": "wegblickend",
    "wegblickendstem": "wegblickend",
    "wegblickendsten": "wegblickend",
    "wegblickendster": "wegblickend",
    "wegblickendstes": "wegblickend",
    "wegblickest": "wegblicken",
    "wegblicket": "wegblicken",
    "wegblickst": "wegblicken",
    "wegblickt": "wegblicken",
    "wegblickte": "wegblicken",
    "wegblickten": "wegblicken",
    "wegblicktest": "wegblicken",
    "wegblicktet": "wegblicken",
    "wegblieb": "wegbleiben",
    "wegbliebe": "wegbleiben",
    "wegblieben": "wegbleiben",
    "wegbliebest": "wegbleiben",
    "wegbliebet": "wegbleiben",
    "wegbliebst": "wegbleiben",
    "wegbliebt": "wegbleiben",
    "wegblies": "wegblasen",
    "wegbliese": "wegblasen",
    "wegbliesen": "wegblasen",
    "wegbliesest": "wegblasen",
    "wegblieset": "wegblasen",
    "wegbliest": "wegblasen",
    "wegbläst": "wegblasen",
    "wegbrachte": "wegbringen",
    "wegbrachten": "wegbringen",
    "wegbrachtest": "wegbringen",
    "wegbrachtet": "wegbringen",
    "wegbrannte": "wegbrennen",
    "wegbrannten": "wegbrennen",
    "wegbranntest": "wegbrennen",
    "wegbranntet": "wegbrennen",
    "wegbrenne": "wegbrennen",
    "wegbrennend": "wegbrennen",
    "wegbrennende": "wegbrennend",
    "wegbrennendem": "wegbrennend",
    "wegbrennenden": "wegbrennend",
    "wegbrennender": "wegbrennend",
    "wegbrennendes": "wegbrennend",
    "wegbrennest": "wegbrennen",
    "wegbrennet": "wegbrennen",
    "wegbrennst": "wegbrennen",
    "wegbrennt": "wegbrennen",
    "wegbringe": "wegbringen",
    "wegbringend": "wegbringen",
    "wegbringende": "wegbringend",
    "wegbringendem": "wegbringend",
    "wegbringenden": "wegbringend",
    "wegbringender": "wegbringend",
    "wegbringendes": "wegbringend",
    "wegbringest": "wegbringen",
    "wegbringet": "wegbringen",
    "wegbringst": "wegbringen",
    "wegbringt": "wegbringen",
    "wegbrächte": "wegbringen",
    "wegbrächten": "wegbringen",
    "wegbrächtest": "wegbringen",
    "wegbrächtet": "wegbringen",
    "wegdachte": "wegdenken",
    "wegdachten": "wegdenken",
    "wegdachtest": "wegdenken",
    "wegdachtet": "wegdenken",
    "wegdenke": "wegdenken",
    "wegdenkend": "wegdenken",
    "wegdenkende": "wegdenkend",
    "wegdenkendem": "wegdenkend",
    "wegdenkenden": "wegdenkend",
    "wegdenkender": "wegdenkend",
    "wegdenkendes": "wegdenkend",
    "wegdenkest": "wegdenken",
    "wegdenket": "wegdenken",
    "wegdenkst": "wegdenken",
    "wegdenkt": "wegdenken",
    "wegdrücke": "wegdrücken",
    "wegdrückend": "wegdrücken",
    "wegdrückende": "wegdrückend",
    "wegdrückendem": "wegdrückend",
    "wegdrückenden": "wegdrückend",
    "wegdrückender": "wegdrückend",
    "wegdrückendes": "wegdrückend",
    "wegdrückest": "wegdrücken",
    "wegdrücket": "wegdrücken",
    "wegdrückst": "wegdrücken",
    "wegdrückt": "wegdrücken",
    "wegdrückte": "wegdrücken",
    "wegdrückten": "wegdrücken",
    "wegdrücktest": "wegdrücken",
    "wegdrücktet": "wegdrücken",
    "wegdächte": "wegdenken",
    "wegdächten": "wegdenken",
    "wegdächtest": "wegdenken",
    "wegdächtet": "wegdenken",
    "wegesse": "wegessen",
    "wegessend": "wegessen",
    "wegessende": "wegessend",
    "wegessendem": "wegessend",
    "wegessenden": "wegessend",
    "wegessender": "wegessend",
    "wegessendes": "wegessend",
    "wegessest": "wegessen",
    "wegesset": "wegessen",
    "wegeßt": "wegessen",
    "wegfahre": "wegfahren",
    "wegfahrend": "wegfahren",
    "wegfahrende": "wegfahrend",
    "wegfahrendem": "wegfahrend",
    "wegfahrenden": "wegfahrend",
    "wegfahrender": "wegfahrend",
    "wegfahrendes": "wegfahrend",
    "wegfahrest": "wegfahren",
    "wegfahret": "wegfahren",
    "wegfahrt": "wegfahren",
    "wegfalle": "wegfallen",
    "wegfallend": "wegfallen",
    "wegfallende": "wegfallend",
    "wegfallendem": "wegfallend",
    "wegfallenden": "wegfallend",
    "wegfallender": "wegfallend",
    "wegfallendes": "wegfallend",
    "wegfallest": "wegfallen",
    "wegfallet": "wegfallen",
    "wegfallt": "wegfallen",
    "wegfange": "wegfangen",
    "wegfangend": "wegfangen",
    "wegfangende": "wegfangend",
    "wegfangendem": "wegfangend",
    "wegfangenden": "wegfangend",
    "wegfangender": "wegfangend",
    "wegfangendes": "wegfangend",
    "wegfangest": "wegfangen",
    "wegfanget": "wegfangen",
    "wegfangt": "wegfangen",
    "wegfege": "wegfegen",
    "wegfegend": "wegfegen",
    "wegfegende": "wegfegend",
    "wegfegendem": "wegfegend",
    "wegfegenden": "wegfegend",
    "wegfegender": "wegfegend",
    "wegfegendes": "wegfegend",
    "wegfegest": "wegfegen",
    "wegfeget": "wegfegen",
    "wegfegst": "wegfegen",
    "wegfegt": "wegfegen",
    "wegfegte": "wegfegen",
    "wegfegten": "wegfegen",
    "wegfegtest": "wegfegen",
    "wegfegtet": "wegfegen",
    "wegfiel": "wegfallen",
    "wegfiele": "wegfallen",
    "wegfielen": "wegfallen",
    "wegfielest": "wegfallen",
    "wegfielet": "wegfallen",
    "wegfielst": "wegfallen",
    "wegfielt": "wegfallen",
    "wegfing": "wegfangen",
    "wegfinge": "wegfangen",
    "wegfingen": "wegfangen",
    "wegfingest": "wegfangen",
    "wegfinget": "wegfangen",
    "wegfingst": "wegfangen",
    "wegfingt": "wegfangen",
    "wegfliege": "wegfliegen",
    "wegfliegend": "wegfliegen",
    "wegfliegende": "wegfliegend",
    "wegfliegendem": "wegfliegend",
    "wegfliegenden": "wegfliegend",
    "wegfliegender": "wegfliegend",
    "wegfliegendes": "wegfliegend",
    "wegfliegest": "wegfliegen",
    "wegflieget": "wegfliegen",
    "wegfliegst": "wegfliegen",
    "wegfliegt": "wegfliegen",
    "wegfließe": "wegfließen",
    "wegfließend": "wegfließen",
    "wegfließende": "wegfließend",
    "wegfließendem": "wegfließend",
    "wegfließenden": "wegfließend",
    "wegfließender": "wegfließend",
    "wegfließendes": "wegfließend",
    "wegfließest": "wegfließen",
    "wegfließet": "wegfließen",
    "wegfließt": "wegfließen",
    "wegflog": "wegfliegen",
    "wegflogen": "wegfliegen",
    "wegflogst": "wegfliegen",
    "wegflogt": "wegfliegen",
    "wegflossen": "wegfließen",
    "wegfloß": "wegfließen",
    "wegfloßt": "wegfließen",
    "wegflöge": "wegfliegen",
    "wegflögen": "wegfliegen",
    "wegflögest": "wegfliegen",
    "wegflöget": "wegfliegen",
    "wegflösse": "wegfließen",
    "wegflössen": "wegfließen",
    "wegflössest": "wegfließen",
    "wegflösset": "wegfließen",
    "wegfraß": "wegfressen",
    "wegfraßen": "wegfressen",
    "wegfraßt": "wegfressen",
    "wegfresse": "wegfressen",
    "wegfressend": "wegfressen",
    "wegfressende": "wegfressend",
    "wegfressendem": "wegfressend",
    "wegfressenden": "wegfressend",
    "wegfressender": "wegfressend",
    "wegfressendes": "wegfressend",
    "wegfressest": "wegfressen",
    "wegfresset": "wegfressen",
    "wegfreßt": "wegfressen",
    "wegfrißt": "wegfressen",
    "wegfräße": "wegfressen",
    "wegfräßen": "wegfressen",
    "wegfräßest": "wegfressen",
    "wegfräßet": "wegfressen",
    "wegfuhr": "wegfahren",
    "wegfuhren": "wegfahren",
    "wegfuhrst": "wegfahren",
    "wegfuhrt": "wegfahren",
    "wegfährst": "wegfahren",
    "wegfährt": "wegfahren",
    "wegfällst": "wegfallen",
    "wegfällt": "wegfallen",
    "wegfängst": "wegfangen",
    "wegfängt": "wegfangen",
    "wegführe": "wegführen",
    "wegführen": "wegfahren",
    "wegführend": "wegführen",
    "wegführende": "wegführend",
    "wegführendem": "wegführend",
    "wegführenden": "wegführend",
    "wegführender": "wegführend",
    "wegführendere": "wegführend",
    "wegführenderem": "wegführend",
    "wegführenderen": "wegführend",
    "wegführenderer": "wegführend",
    "wegführenderes": "wegführend",
    "wegführendes": "wegführend",
    "wegführendste": "wegführend",
    "wegführendstem": "wegführend",
    "wegführendsten": "wegführend",
    "wegführendster": "wegführend",
    "wegführendstes": "wegführend",
    "wegführest": "wegführen",
    "wegführet": "wegführen",
    "wegführst": "wegführen",
    "wegführt": "wegführen",
    "wegführte": "wegführen",
    "wegführten": "wegführen",
    "wegführtest": "wegführen",
    "wegführtet": "wegführen",
    "weggab": "weggeben",
    "weggaben": "weggeben",
    "weggabst": "weggeben",
    "weggabt": "weggeben",
    "weggebe": "weggeben",
    "weggebend": "weggeben",
    "weggebende": "weggebend",
    "weggebendem": "weggebend",
    "weggebenden": "weggebend",
    "weggebender": "weggebend",
    "weggebendes": "weggebend",
    "weggebest": "weggeben",
    "weggebet": "weggeben",
    "weggeblasen": "wegblasen",
    "weggeblasene": "weggeblasen",
    "weggeblasenem": "weggeblasen",
    "weggeblasenen": "weggeblasen",
    "weggeblasener": "weggeblasen",
    "weggeblasenes": "weggeblasen",
    "weggeblickt": "wegblicken",
    "weggeblickte": "weggeblickt",
    "weggeblicktem": "weggeblickt",
    "weggeblickten": "weggeblickt",
    "weggeblickter": "weggeblickt",
    "weggeblicktes": "weggeblickt",
    "weggeblieben": "wegbleiben",
    "weggebliebene": "weggeblieben",
    "weggebliebenem": "weggeblieben",
    "weggebliebenen": "weggeblieben",
    "weggebliebener": "weggeblieben",
    "weggebliebenes": "weggeblieben",
    "weggebracht": "wegbringen",
    "weggebrachte": "weggebracht",
    "weggebrachtem": "weggebracht",
    "weggebrachten": "weggebracht",
    "weggebrachter": "weggebracht",
    "weggebrachtes": "weggebracht",
    "weggebrannt": "wegbrennen",
    "weggebrannte": "weggebrannt",
    "weggebranntem": "weggebrannt",
    "weggebrannten": "weggebrannt",
    "weggebrannter": "weggebrannt",
    "weggebranntes": "weggebrannt",
    "weggebt": "weggeben",
    "weggedacht": "wegdenken",
    "weggedachte": "weggedacht",
    "weggedachtem": "weggedacht",
    "weggedachten": "weggedacht",
    "weggedachter": "weggedacht",
    "weggedachtes": "weggedacht",
    "weggedrückt": "wegdrücken",
    "weggedrückte": "weggedrückt",
    "weggedrücktem": "weggedrückt",
    "weggedrückten": "weggedrückt",
    "weggedrückter": "weggedrückt",
    "weggedrücktes": "weggedrückt",
    "weggefahren": "wegfahren",
    "weggefahrene": "weggefahren",
    "weggefahrenem": "weggefahren",
    "weggefahrenen": "weggefahren",
    "weggefahrener": "weggefahren",
    "weggefahrenes": "weggefahren",
    "weggefallen": "wegfallen",
    "weggefallene": "weggefallen",
    "weggefallenem": "weggefallen",
    "weggefallenen": "weggefallen",
    "weggefallener": "weggefallen",
    "weggefallenes": "weggefallen",
    "weggefangen": "wegfangen",
    "weggefangene": "weggefangen",
    "weggefangenem": "weggefangen",
    "weggefangenen": "weggefangen",
    "weggefangener": "weggefangen",
    "weggefangenes": "weggefangen",
    "weggefegt": "wegfegen",
    "weggefegte": "weggefegt",
    "weggefegtem": "weggefegt",
    "weggefegten": "weggefegt",
    "weggefegter": "weggefegt",
    "weggefegtes": "weggefegt",
    "weggeflogen": "wegfliegen",
    "weggeflogene": "weggeflogen",
    "weggeflogenem": "weggeflogen",
    "weggeflogenen": "weggeflogen",
    "weggeflogener": "weggeflogen",
    "weggeflogenes": "weggeflogen",
    "weggeflossen": "wegfließen",
    "weggeflossene": "weggeflossen",
    "weggeflossenem": "weggeflossen",
    "weggeflossenen": "weggeflossen",
    "weggeflossener": "weggeflossen",
    "weggeflossenes": "weggeflossen",
    "weggefressen": "wegfressen",
    "weggefressene": "weggefressen",
    "weggefressenem": "weggefressen",
    "weggefressenen": "weggefressen",
    "weggefressener": "weggefressen",
    "weggefressenes": "weggefressen",
    "weggeführt": "wegführen",
    "weggeführte": "weggeführt",
    "weggeführtem": "weggeführt",
    "weggeführten": "weggeführt",
    "weggeführter": "weggeführt",
    "weggeführtes": "weggeführt",
    "weggegangen": "weggehen",
    "weggegangene": "weggegangen",
    "weggegangenem": "weggegangen",
    "weggegangenen": "weggegangen",
    "weggegangener": "weggegangen",
    "weggegangenes": "weggegangen",
    "weggegeben": "weggeben",
    "weggegebene": "weggegeben",
    "weggegebenem": "weggegeben",
    "weggegebenen": "weggegeben",
    "weggegebener": "weggegeben",
    "weggegebenes": "weggegeben",
    "weggegessen": "wegessen",
    "weggegessene": "weggegessen",
    "weggegessenem": "weggegessen",
    "weggegessenen": "weggegessen",
    "weggegessener": "weggegessen",
    "weggegessenes": "weggegessen",
    "weggehalten": "weghalten",
    "weggehaltene": "weggehalten",
    "weggehaltenem": "weggehalten",
    "weggehaltenen": "weggehalten",
    "weggehaltener": "weggehalten",
    "weggehaltenes": "weggehalten",
    "weggehangen": "weghängen",
    "weggehe": "weggehen",
    "weggehend": "weggehen",
    "weggehende": "weggehend",
    "weggehendem": "weggehend",
    "weggehenden": "weggehend",
    "weggehender": "weggehend",
    "weggehendes": "weggehend",
    "weggehest": "weggehen",
    "weggehet": "weggehen",
    "weggehoben": "wegheben",
    "weggehobene": "weggehoben",
    "weggehobenem": "weggehoben",
    "weggehobenen": "weggehoben",
    "weggehobener": "weggehoben",
    "weggehobenes": "weggehoben",
    "weggeholt": "wegholen",
    "weggeholte": "weggeholt",
    "weggeholtem": "weggeholt",
    "weggeholten": "weggeholt",
    "weggeholter": "weggeholt",
    "weggeholtes": "weggeholt",
    "weggehst": "weggehen",
    "weggeht": "weggehen",
    "weggehängt": "weghängen",
    "weggehängte": "weggehängt",
    "weggehängtem": "weggehängt",
    "weggehängten": "weggehängt",
    "weggehängter": "weggehängt",
    "weggehängtes": "weggehängt",
    "weggejagt": "wegjagen",
    "weggejagte": "weggejagt",
    "weggejagtem": "weggejagt",
    "weggejagten": "weggejagt",
    "weggejagter": "weggejagt",
    "weggejagtes": "weggejagt",
    "weggekehrt": "wegkehren",
    "weggekehrte": "weggekehrt",
    "weggekehrtem": "weggekehrt",
    "weggekehrten": "weggekehrt",
    "weggekehrter": "weggekehrt",
    "weggekehrtes": "weggekehrt",
    "weggekommen": "wegkommen",
    "weggekommene": "weggekommen",
    "weggekommenem": "weggekommen",
    "weggekommenen": "weggekommen",
    "weggekommener": "weggekommen",
    "weggekommenes": "weggekommen",
    "weggekratzt": "wegkratzen",
    "weggekratzte": "weggekratzt",
    "weggekratztem": "weggekratzt",
    "weggekratzten": "weggekratzt",
    "weggekratzter": "weggekratzt",
    "weggekratztes": "weggekratzt",
    "weggelassen": "weglassen",
    "weggelassene": "weggelassen",
    "weggelassenem": "weggelassen",
    "weggelassenen": "weggelassen",
    "weggelassener": "weggelassen",
    "weggelassenes": "weggelassen",
    "weggelaufen": "weglaufen",
    "weggelaufene": "weggelaufen",
    "weggelaufenem": "weggelaufen",
    "weggelaufenen": "weggelaufen",
    "weggelaufener": "weggelaufen",
    "weggelaufenes": "weggelaufen",
    "weggelegt": "weglegen",
    "weggelegte": "weggelegt",
    "weggelegtem": "weggelegt",
    "weggelegten": "weggelegt",
    "weggelegter": "weggelegt",
    "weggelegtes": "weggelegt",
    "weggemacht": "wegmachen",
    "weggemachte": "weggemacht",
    "weggemachtem": "weggemacht",
    "weggemachten": "weggemacht",
    "weggemachter": "weggemacht",
    "weggemachtes": "weggemacht",
    "weggenommen": "wegnehmen",
    "weggenommene": "weggenommen",
    "weggenommenem": "weggenommen",
    "weggenommenen": "weggenommen",
    "weggenommener": "weggenommen",
    "weggenommenes": "weggenommen",
    "weggerafft": "wegraffen",
    "weggeraffte": "weggerafft",
    "weggerafftem": "weggerafft",
    "weggerafften": "weggerafft",
    "weggeraffter": "weggerafft",
    "weggerafftes": "weggerafft",
    "weggerannte": "weggerannt",
    "weggeranntem": "weggerannt",
    "weggerannten": "weggerannt",
    "weggerannter": "weggerannt",
    "weggeranntes": "weggerannt",
    "weggerissen": "wegreißen",
    "weggerissene": "weggerissen",
    "weggerissenem": "weggerissen",
    "weggerissenen": "weggerissen",
    "weggerissener": "weggerissen",
    "weggerissenes": "weggerissen",
    "weggerollt": "wegrollen",
    "weggerollte": "weggerollt",
    "weggerolltem": "weggerollt",
    "weggerollten": "weggerollt",
    "weggerollter": "weggerollt",
    "weggerolltes": "weggerollt",
    "weggerufen": "wegrufen",
    "weggerufene": "weggerufen",
    "weggerufenem": "weggerufen",
    "weggerufenen": "weggerufen",
    "weggerufener": "weggerufen",
    "weggerufenes": "weggerufen",
    "weggeräumt": "wegräumen",
    "weggeräumte": "weggeräumt",
    "weggeräumtem": "weggeräumt",
    "weggeräumten": "weggeräumt",
    "weggeräumter": "weggeräumt",
    "weggeräumtes": "weggeräumt",
    "weggeschafft": "wegschaffen",
    "weggeschaffte": "weggeschafft",
    "weggeschafftem": "weggeschafft",
    "weggeschafften": "weggeschafft",
    "weggeschaffter": "weggeschafft",
    "weggeschafftes": "weggeschafft",
    "weggeschaufelt": "wegschaufeln",
    "weggeschaufelte": "weggeschaufelt",
    "weggeschaufeltem": "weggeschaufelt",
    "weggeschaufelten": "weggeschaufelt",
    "weggeschaufelter": "weggeschaufelt",
    "weggeschaufeltes": "weggeschaufelt",
    "weggeschaut": "wegschauen",
    "weggeschaute": "weggeschaut",
    "weggeschautem": "weggeschaut",
    "weggeschauten": "weggeschaut",
    "weggeschauter": "weggeschaut",
    "weggeschautes": "weggeschaut",
    "weggeschenkt": "wegschenken",
    "weggeschenkte": "weggeschenkt",
    "weggeschenktem": "weggeschenkt",
    "weggeschenkten": "weggeschenkt",
    "weggeschenkter": "weggeschenkt",
    "weggeschenktes": "weggeschenkt",
    "weggeschert": "wegscheren",
    "weggescherte": "weggeschert",
    "weggeschertem": "weggeschert",
    "weggescherten": "weggeschert",
    "weggescherter": "weggeschert",
    "weggeschertes": "weggeschert",
    "weggeschickt": "wegschicken",
    "weggeschickte": "weggeschickt",
    "weggeschicktem": "weggeschickt",
    "weggeschickten": "weggeschickt",
    "weggeschickter": "weggeschickt",
    "weggeschicktes": "weggeschickt",
    "weggeschlichen": "wegschleichen",
    "weggeschlichene": "weggeschlichen",
    "weggeschlichenem": "weggeschlichen",
    "weggeschlichenen": "weggeschlichen",
    "weggeschlichener": "weggeschlichen",
    "weggeschlichenes": "weggeschlichen",
    "weggeschlossen": "wegschließen",
    "weggeschlossene": "weggeschlossen",
    "weggeschlossenem": "weggeschlossen",
    "weggeschlossenen": "weggeschlossen",
    "weggeschlossener": "weggeschlossen",
    "weggeschlossenes": "weggeschlossen",
    "weggeschmissen": "wegschmeißen",
    "weggeschmissene": "weggeschmissen",
    "weggeschmissenem": "weggeschmissen",
    "weggeschmissenen": "weggeschmissen",
    "weggeschmissener": "weggeschmissen",
    "weggeschmissenere": "weggeschmissen",
    "weggeschmissenerem": "weggeschmissen",
    "weggeschmisseneren": "weggeschmissen",
    "weggeschmissenerer": "weggeschmissen",
    "weggeschmisseneres": "weggeschmissen",
    "weggeschmissenes": "weggeschmissen",
    "weggeschmissenste": "weggeschmissen",
    "weggeschmissenstem": "weggeschmissen",
    "weggeschmissensten": "weggeschmissen",
    "weggeschmissenster": "weggeschmissen",
    "weggeschmissenstes": "weggeschmissen",
    "weggeschmolzen": "wegschmelzen",
    "weggeschmolzene": "weggeschmolzen",
    "weggeschmolzenem": "weggeschmolzen",
    "weggeschmolzenen": "weggeschmolzen",
    "weggeschmolzener": "weggeschmolzen",
    "weggeschmolzenere": "weggeschmolzen",
    "weggeschmolzenerem": "weggeschmolzen",
    "weggeschmolzeneren": "weggeschmolzen",
    "weggeschmolzenerer": "weggeschmolzen",
    "weggeschmolzeneres": "weggeschmolzen",
    "weggeschmolzenes": "weggeschmolzen",
    "weggeschmolzenste": "weggeschmolzen",
    "weggeschmolzenstem": "weggeschmolzen",
    "weggeschmolzensten": "weggeschmolzen",
    "weggeschmolzenster": "weggeschmolzen",
    "weggeschmolzenstes": "weggeschmolzen",
    "weggeschnappt": "wegschnappen",
    "weggeschnappte": "weggeschnappt",
    "weggeschnapptem": "weggeschnappt",
    "weggeschnappten": "weggeschnappt",
    "weggeschnappter": "weggeschnappt",
    "weggeschnapptes": "weggeschnappt",
    "weggeschnitten": "wegschneiden",
    "weggeschnittene": "weggeschnitten",
    "weggeschnittenem": "weggeschnitten",
    "weggeschnittenen": "weggeschnitten",
    "weggeschnittener": "weggeschnitten",
    "weggeschnittenes": "weggeschnitten",
    "weggeschoben": "wegschieben",
    "weggeschobene": "weggeschoben",
    "weggeschobenem": "weggeschoben",
    "weggeschobenen": "weggeschoben",
    "weggeschobener": "weggeschoben",
    "weggeschobenes": "weggeschoben",
    "weggeschoren": "wegscheren",
    "weggeschorene": "weggeschoren",
    "weggeschorenem": "weggeschoren",
    "weggeschorenen": "weggeschoren",
    "weggeschorener": "weggeschoren",
    "weggeschorenes": "weggeschoren",
    "weggeschüttet": "wegschütten",
    "weggeschüttete": "weggeschüttet",
    "weggeschüttetem": "weggeschüttet",
    "weggeschütteten": "weggeschüttet",
    "weggeschütteter": "weggeschüttet",
    "weggeschüttetes": "weggeschüttet",
    "weggesehen": "wegsehen",
    "weggesehene": "weggesehen",
    "weggesehenem": "weggesehen",
    "weggesehenen": "weggesehen",
    "weggesehener": "weggesehen",
    "weggesehenes": "weggesehen",
    "weggesetzt": "wegsetzen",
    "weggesetzte": "weggesetzt",
    "weggesetztem": "weggesetzt",
    "weggesetzten": "weggesetzt",
    "weggesetzter": "weggesetzt",
    "weggesetztes": "weggesetzt",
    "weggesoffen": "wegsaufen",
    "weggesoffene": "weggesoffen",
    "weggesoffenem": "weggesoffen",
    "weggesoffenen": "weggesoffen",
    "weggesoffener": "weggesoffen",
    "weggesoffenes": "weggesoffen",
    "weggespielt": "wegspielen",
    "weggespielte": "weggespielt",
    "weggespieltem": "weggespielt",
    "weggespielten": "weggespielt",
    "weggespielter": "weggespielt",
    "weggespieltes": "weggespielt",
    "weggesprengt": "wegsprengen",
    "weggesprengte": "weggesprengt",
    "weggesprengtem": "weggesprengt",
    "weggesprengten": "weggesprengt",
    "weggesprengter": "weggesprengt",
    "weggesprengtes": "weggesprengt",
    "weggespült": "wegspülen",
    "weggespülte": "weggespült",
    "weggespültem": "weggespült",
    "weggespülten": "weggespült",
    "weggespülter": "weggespült",
    "weggespültes": "weggespült",
    "weggesteckt": "wegstecken",
    "weggesteckte": "weggesteckt",
    "weggestecktem": "weggesteckt",
    "weggesteckten": "weggesteckt",
    "weggesteckter": "weggesteckt",
    "weggestecktes": "weggesteckt",
    "weggestohlen": "wegstehlen",
    "weggestohlene": "weggestohlen",
    "weggestohlenem": "weggestohlen",
    "weggestohlenen": "weggestohlen",
    "weggestohlener": "weggestohlen",
    "weggestohlenere": "weggestohlen",
    "weggestohlenerem": "weggestohlen",
    "weggestohleneren": "weggestohlen",
    "weggestohlenerer": "weggestohlen",
    "weggestohleneres": "weggestohlen",
    "weggestohlenes": "weggestohlen",
    "weggestohlenste": "weggestohlen",
    "weggestohlenstem": "weggestohlen",
    "weggestohlensten": "weggestohlen",
    "weggestohlenster": "weggestohlen",
    "weggestohlenstes": "weggestohlen",
    "weggestorben": "wegsterben",
    "weggestorbene": "weggestorben",
    "weggestorbenem": "weggestorben",
    "weggestorbenen": "weggestorben",
    "weggestorbener": "weggestorben",
    "weggestorbenes": "weggestorben",
    "weggestoßen": "wegstoßen",
    "weggestoßene": "weggestoßen",
    "weggestoßenem": "weggestoßen",
    "weggestoßenen": "weggestoßen",
    "weggestoßener": "weggestoßen",
    "weggestoßenes": "weggestoßen",
    "weggestrichen": "wegstreichen",
    "weggestrichene": "weggestrichen",
    "weggestrichenem": "weggestrichen",
    "weggestrichenen": "weggestrichen",
    "weggestrichener": "weggestrichen",
    "weggestrichenes": "weggestrichen",
    "weggetaucht": "wegtauchen",
    "weggetauchte": "weggetaucht",
    "weggetauchtem": "weggetaucht",
    "weggetauchten": "weggetaucht",
    "weggetauchter": "weggetaucht",
    "weggetauchtes": "weggetaucht",
    "weggetragen": "wegtragen",
    "weggetragene": "weggetragen",
    "weggetragenem": "weggetragen",
    "weggetragenen": "weggetragen",
    "weggetragener": "weggetragen",
    "weggetragenes": "weggetragen",
    "weggetreten": "wegtreten",
    "weggetretene": "weggetreten",
    "weggetretenem": "weggetreten",
    "weggetretenen": "weggetreten",
    "weggetretener": "weggetreten",
    "weggetretenes": "weggetreten",
    "weggetrieben": "wegtreiben",
    "weggetriebene": "weggetrieben",
    "weggetriebenem": "weggetrieben",
    "weggetriebenen": "weggetrieben",
    "weggetriebener": "weggetrieben",
    "weggetriebenes": "weggetrieben",
    "weggewandt": "wegwenden",
    "weggewandte": "weggewandt",
    "weggewandtem": "weggewandt",
    "weggewandten": "weggewandt",
    "weggewandter": "weggewandt",
    "weggewandtes": "weggewandt",
    "weggewendet": "wegwenden",
    "weggewendete": "weggewendet",
    "weggewendetem": "weggewendet",
    "weggewendeten": "weggewendet",
    "weggewendeter": "weggewendet",
    "weggewendetes": "weggewendet",
    "weggewischt": "wegwischen",
    "weggewischte": "weggewischt",
    "weggewischtem": "weggewischt",
    "weggewischten": "weggewischt",
    "weggewischter": "weggewischt",
    "weggewischtes": "weggewischt",
    "weggeworfen": "wegwerfen",
    "weggeworfene": "weggeworfen",
    "weggeworfenem": "weggeworfen",
    "weggeworfenen": "weggeworfen",
    "weggeworfener": "weggeworfen",
    "weggeworfenes": "weggeworfen",
    "weggezaubert": "wegzaubern",
    "weggezauberte": "weggezaubert",
    "weggezaubertem": "weggezaubert",
    "weggezauberten": "weggezaubert",
    "weggezauberter": "weggezaubert",
    "weggezaubertes": "weggezaubert",
    "weggezogen": "wegziehen",
    "weggezogene": "weggezogen",
    "weggezogenem": "weggezogen",
    "weggezogenen": "weggezogen",
    "weggezogener": "weggezogen",
    "weggezogenes": "weggezogen",
    "weggibst": "weggeben",
    "weggibt": "weggeben",
    "wegging": "weggehen",
    "wegginge": "weggehen",
    "weggingen": "weggehen",
    "weggingest": "weggehen",
    "wegginget": "weggehen",
    "weggingst": "weggehen",
    "weggingt": "weggehen",
    "weggäbe": "weggeben",
    "weggäben": "weggeben",
    "weggäbest": "weggeben",
    "weggäbet": "weggeben",
    "weghalte": "weghalten",
    "weghaltend": "weghalten",
    "weghaltende": "weghaltend",
    "weghaltendem": "weghaltend",
    "weghaltenden": "weghaltend",
    "weghaltender": "weghaltend",
    "weghaltendes": "weghaltend",
    "weghaltest": "weghalten",
    "weghaltet": "weghalten",
    "weghebe": "wegheben",
    "weghebend": "wegheben",
    "weghebende": "weghebend",
    "weghebendem": "weghebend",
    "weghebenden": "weghebend",
    "weghebender": "weghebend",
    "weghebendes": "weghebend",
    "weghebest": "wegheben",
    "weghebet": "wegheben",
    "weghebst": "wegheben",
    "weghebt": "wegheben",
    "weghielt": "weghalten",
    "weghielte": "weghalten",
    "weghielten": "weghalten",
    "weghieltest": "weghalten",
    "weghieltet": "weghalten",
    "weghing": "weghängen",
    "weghinge": "weghängen",
    "weghingen": "weghängen",
    "weghingest": "weghängen",
    "weghinget": "weghängen",
    "weghingst": "weghängen",
    "weghingt": "weghängen",
    "weghob": "wegheben",
    "weghoben": "wegheben",
    "weghobst": "wegheben",
    "weghobt": "wegheben",
    "weghole": "wegholen",
    "wegholend": "wegholen",
    "wegholende": "wegholend",
    "wegholendem": "wegholend",
    "wegholenden": "wegholend",
    "wegholender": "wegholend",
    "wegholendes": "wegholend",
    "wegholest": "wegholen",
    "wegholet": "wegholen",
    "wegholst": "wegholen",
    "wegholt": "wegholen",
    "wegholte": "wegholen",
    "wegholten": "wegholen",
    "wegholtest": "wegholen",
    "wegholtet": "wegholen",
    "weghält": "weghalten",
    "weghältst": "weghalten",
    "weghänge": "weghängen",
    "weghängend": "weghängen",
    "weghängende": "weghängend",
    "weghängendem": "weghängend",
    "weghängenden": "weghängend",
    "weghängender": "weghängend",
    "weghängendes": "weghängend",
    "weghängest": "weghängen",
    "weghänget": "weghängen",
    "weghängst": "weghängen",
    "weghängt": "weghängen",
    "weghängte": "weghängen",
    "weghängten": "weghängen",
    "weghängtest": "weghängen",
    "weghängtet": "weghängen",
    "weghöbe": "wegheben",
    "weghöben": "wegheben",
    "weghöbest": "wegheben",
    "weghöbet": "wegheben",
    "wegißt": "wegessen",
    "wegjage": "wegjagen",
    "wegjagend": "wegjagen",
    "wegjagende": "wegjagend",
    "wegjagendem": "wegjagend",
    "wegjagenden": "wegjagend",
    "wegjagender": "wegjagend",
    "wegjagendes": "wegjagend",
    "wegjagest": "wegjagen",
    "wegjaget": "wegjagen",
    "wegjagst": "wegjagen",
    "wegjagt": "wegjagen",
    "wegjagte": "wegjagen",
    "wegjagten": "wegjagen",
    "wegjagtest": "wegjagen",
    "wegjagtet": "wegjagen",
    "wegkam": "wegkommen",
    "wegkamen": "wegkommen",
    "wegkamst": "wegkommen",
    "wegkamt": "wegkommen",
    "wegkehre": "wegkehren",
    "wegkehrend": "wegkehren",
    "wegkehrende": "wegkehrend",
    "wegkehrendem": "wegkehrend",
    "wegkehrenden": "wegkehrend",
    "wegkehrender": "wegkehrend",
    "wegkehrendes": "wegkehrend",
    "wegkehrest": "wegkehren",
    "wegkehret": "wegkehren",
    "wegkehrst": "wegkehren",
    "wegkehrt": "wegkehren",
    "wegkehrte": "wegkehren",
    "wegkehrten": "wegkehren",
    "wegkehrtest": "wegkehren",
    "wegkehrtet": "wegkehren",
    "wegkomme": "wegkommen",
    "wegkommend": "wegkommen",
    "wegkommende": "wegkommend",
    "wegkommendem": "wegkommend",
    "wegkommenden": "wegkommend",
    "wegkommender": "wegkommend",
    "wegkommendes": "wegkommend",
    "wegkommest": "wegkommen",
    "wegkommet": "wegkommen",
    "wegkommst": "wegkommen",
    "wegkommt": "wegkommen",
    "wegkratze": "wegkratzen",
    "wegkratzend": "wegkratzen",
    "wegkratzende": "wegkratzend",
    "wegkratzendem": "wegkratzend",
    "wegkratzenden": "wegkratzend",
    "wegkratzender": "wegkratzend",
    "wegkratzendes": "wegkratzend",
    "wegkratzest": "wegkratzen",
    "wegkratzet": "wegkratzen",
    "wegkratzt": "wegkratzen",
    "wegkratzte": "wegkratzen",
    "wegkratzten": "wegkratzen",
    "wegkratztest": "wegkratzen",
    "wegkratztet": "wegkratzen",
    "wegkäme": "wegkommen",
    "wegkämen": "wegkommen",
    "wegkämest": "wegkommen",
    "wegkämet": "wegkommen",
    "weglasse": "weglassen",
    "weglassend": "weglassen",
    "weglassende": "weglassend",
    "weglassendem": "weglassend",
    "weglassenden": "weglassend",
    "weglassender": "weglassend",
    "weglassendes": "weglassend",
    "weglassest": "weglassen",
    "weglasset": "weglassen",
    "weglaufe": "weglaufen",
    "weglaufend": "weglaufen",
    "weglaufende": "weglaufend",
    "weglaufendem": "weglaufend",
    "weglaufenden": "weglaufend",
    "weglaufender": "weglaufend",
    "weglaufendes": "weglaufend",
    "weglaufest": "weglaufen",
    "weglaufet": "weglaufen",
    "weglauft": "weglaufen",
    "weglaßt": "weglassen",
    "weglege": "weglegen",
    "weglegend": "weglegen",
    "weglegende": "weglegend",
    "weglegendem": "weglegend",
    "weglegenden": "weglegend",
    "weglegender": "weglegend",
    "weglegendes": "weglegend",
    "weglegest": "weglegen",
    "wegleget": "weglegen",
    "weglegst": "weglegen",
    "weglegt": "weglegen",
    "weglegte": "weglegen",
    "weglegten": "weglegen",
    "weglegtest": "weglegen",
    "weglegtet": "weglegen",
    "weglief": "weglaufen",
    "wegliefe": "weglaufen",
    "wegliefen": "weglaufen",
    "wegliefest": "weglaufen",
    "wegliefet": "weglaufen",
    "wegliefst": "weglaufen",
    "weglieft": "weglaufen",
    "wegließ": "weglassen",
    "wegließe": "weglassen",
    "wegließen": "weglassen",
    "wegließest": "weglassen",
    "wegließet": "weglassen",
    "wegließt": "weglassen",
    "wegläufst": "weglaufen",
    "wegläuft": "weglaufen",
    "wegläßt": "weglassen",
    "wegmache": "wegmachen",
    "wegmachend": "wegmachen",
    "wegmachende": "wegmachend",
    "wegmachendem": "wegmachend",
    "wegmachenden": "wegmachend",
    "wegmachender": "wegmachend",
    "wegmachendes": "wegmachend",
    "wegmachest": "wegmachen",
    "wegmachet": "wegmachen",
    "wegmachst": "wegmachen",
    "wegmacht": "wegmachen",
    "wegmachte": "wegmachen",
    "wegmachten": "wegmachen",
    "wegmachtest": "wegmachen",
    "wegmachtet": "wegmachen",
    "wegnahm": "wegnehmen",
    "wegnahmen": "wegnehmen",
    "wegnahmst": "wegnehmen",
    "wegnahmt": "wegnehmen",
    "wegnehme": "wegnehmen",
    "wegnehmend": "wegnehmen",
    "wegnehmende": "wegnehmend",
    "wegnehmendem": "wegnehmend",
    "wegnehmenden": "wegnehmend",
    "wegnehmender": "wegnehmend",
    "wegnehmendes": "wegnehmend",
    "wegnehmest": "wegnehmen",
    "wegnehmet": "wegnehmen",
    "wegnehmt": "wegnehmen",
    "wegnimmst": "wegnehmen",
    "wegnimmt": "wegnehmen",
    "wegnähme": "wegnehmen",
    "wegnähmen": "wegnehmen",
    "wegnähmest": "wegnehmen",
    "wegnähmet": "wegnehmen",
    "wegradiere": "wegradieren",
    "wegradierend": "wegradieren",
    "wegradierende": "wegradierend",
    "wegradierendem": "wegradierend",
    "wegradierenden": "wegradierend",
    "wegradierender": "wegradierend",
    "wegradierendes": "wegradierend",
    "wegradierest": "wegradieren",
    "wegradieret": "wegradieren",
    "wegradierst": "wegradieren",
    "wegradiert": "wegradieren",
    "wegradierte": "wegradieren",
    "wegradiertem": "wegradiert",
    "wegradierten": "wegradieren",
    "wegradierter": "wegradiert",
    "wegradiertes": "wegradiert",
    "wegradiertest": "wegradieren",
    "wegradiertet": "wegradieren",
    "wegraffe": "wegraffen",
    "wegraffend": "wegraffen",
    "wegraffende": "wegraffend",
    "wegraffendem": "wegraffend",
    "wegraffenden": "wegraffend",
    "wegraffender": "wegraffend",
    "wegraffendes": "wegraffend",
    "wegraffest": "wegraffen",
    "wegraffet": "wegraffen",
    "wegraffst": "wegraffen",
    "wegrafft": "wegraffen",
    "wegraffte": "wegraffen",
    "wegrafften": "wegraffen",
    "wegrafftest": "wegraffen",
    "wegrafftet": "wegraffen",
    "wegreiße": "wegreißen",
    "wegreißend": "wegreißen",
    "wegreißende": "wegreißend",
    "wegreißendem": "wegreißend",
    "wegreißenden": "wegreißend",
    "wegreißender": "wegreißend",
    "wegreißendes": "wegreißend",
    "wegreißest": "wegreißen",
    "wegreißet": "wegreißen",
    "wegreißt": "wegreißen",
    "wegrennende": "wegrennend",
    "wegrennendem": "wegrennend",
    "wegrennenden": "wegrennend",
    "wegrennender": "wegrennend",
    "wegrennendes": "wegrennend",
    "wegrief": "wegrufen",
    "wegriefe": "wegrufen",
    "wegriefen": "wegrufen",
    "wegriefest": "wegrufen",
    "wegriefet": "wegrufen",
    "wegriefst": "wegrufen",
    "wegrieft": "wegrufen",
    "wegrisse": "wegreißen",
    "wegrissen": "wegreißen",
    "wegrissest": "wegreißen",
    "wegrisset": "wegreißen",
    "wegriß": "wegreißen",
    "wegrißt": "wegreißen",
    "wegrolle": "wegrollen",
    "wegrollend": "wegrollen",
    "wegrollende": "wegrollend",
    "wegrollendem": "wegrollend",
    "wegrollenden": "wegrollend",
    "wegrollender": "wegrollend",
    "wegrollendes": "wegrollend",
    "wegrollest": "wegrollen",
    "wegrollet": "wegrollen",
    "wegrollst": "wegrollen",
    "wegrollt": "wegrollen",
    "wegrollte": "wegrollen",
    "wegrollten": "wegrollen",
    "wegrolltest": "wegrollen",
    "wegrolltet": "wegrollen",
    "wegrufe": "wegrufen",
    "wegrufend": "wegrufen",
    "wegrufende": "wegrufend",
    "wegrufendem": "wegrufend",
    "wegrufenden": "wegrufend",
    "wegrufender": "wegrufend",
    "wegrufendes": "wegrufend",
    "wegrufest": "wegrufen",
    "wegrufet": "wegrufen",
    "wegrufst": "wegrufen",
    "wegruft": "wegrufen",
    "wegräume": "wegräumen",
    "wegräumend": "wegräumen",
    "wegräumende": "wegräumend",
    "wegräumendem": "wegräumend",
    "wegräumenden": "wegräumend",
    "wegräumender": "wegräumend",
    "wegräumendes": "wegräumend",
    "wegräumest": "wegräumen",
    "wegräumet": "wegräumen",
    "wegräumst": "wegräumen",
    "wegräumt": "wegräumen",
    "wegräumte": "wegräumen",
    "wegräumten": "wegräumen",
    "wegräumtest": "wegräumen",
    "wegräumtet": "wegräumen",
    "wegsah": "wegsehen",
    "wegsahen": "wegsehen",
    "wegsahst": "wegsehen",
    "wegsaht": "wegsehen",
    "wegsaufe": "wegsaufen",
    "wegsaufend": "wegsaufen",
    "wegsaufende": "wegsaufend",
    "wegsaufendem": "wegsaufend",
    "wegsaufenden": "wegsaufend",
    "wegsaufender": "wegsaufend",
    "wegsaufendes": "wegsaufend",
    "wegsaufest": "wegsaufen",
    "wegsaufet": "wegsaufen",
    "wegsauft": "wegsaufen",
    "wegschaffe": "wegschaffen",
    "wegschaffend": "wegschaffen",
    "wegschaffende": "wegschaffend",
    "wegschaffendem": "wegschaffend",
    "wegschaffenden": "wegschaffend",
    "wegschaffender": "wegschaffend",
    "wegschaffendes": "wegschaffend",
    "wegschaffest": "wegschaffen",
    "wegschaffet": "wegschaffen",
    "wegschaffst": "wegschaffen",
    "wegschafft": "wegschaffen",
    "wegschaffte": "wegschaffen",
    "wegschafften": "wegschaffen",
    "wegschafftest": "wegschaffen",
    "wegschafftet": "wegschaffen",
    "wegschaue": "wegschauen",
    "wegschauend": "wegschauen",
    "wegschauende": "wegschauend",
    "wegschauendem": "wegschauend",
    "wegschauenden": "wegschauend",
    "wegschauender": "wegschauend",
    "wegschauendes": "wegschauend",
    "wegschauest": "wegschauen",
    "wegschauet": "wegschauen",
    "wegschaufele": "wegschaufeln",
    "wegschaufelnd": "wegschaufeln",
    "wegschaufelnde": "wegschaufelnd",
    "wegschaufelndem": "wegschaufelnd",
    "wegschaufelnden": "wegschaufelnd",
    "wegschaufelnder": "wegschaufelnd",
    "wegschaufelndes": "wegschaufelnd",
    "wegschaufelst": "wegschaufeln",
    "wegschaufelt": "wegschaufeln",
    "wegschaufelte": "wegschaufeln",
    "wegschaufelten": "wegschaufeln",
    "wegschaufeltest": "wegschaufeln",
    "wegschaufeltet": "wegschaufeln",
    "wegschaufle": "wegschaufeln",
    "wegschaust": "wegschauen",
    "wegschaut": "wegschauen",
    "wegschaute": "wegschauen",
    "wegschauten": "wegschauen",
    "wegschautest": "wegschauen",
    "wegschautet": "wegschauen",
    "wegschenke": "wegschenken",
    "wegschenkend": "wegschenken",
    "wegschenkende": "wegschenkend",
    "wegschenkendem": "wegschenkend",
    "wegschenkenden": "wegschenkend",
    "wegschenkender": "wegschenkend",
    "wegschenkendes": "wegschenkend",
    "wegschenkest": "wegschenken",
    "wegschenket": "wegschenken",
    "wegschenkst": "wegschenken",
    "wegschenkt": "wegschenken",
    "wegschenkte": "wegschenken",
    "wegschenkten": "wegschenken",
    "wegschenktest": "wegschenken",
    "wegschenktet": "wegschenken",
    "wegschere": "wegscheren",
    "wegscherend": "wegscheren",
    "wegscherende": "wegscherend",
    "wegscherendem": "wegscherend",
    "wegscherenden": "wegscherend",
    "wegscherender": "wegscherend",
    "wegscherendes": "wegscherend",
    "wegscherest": "wegscheren",
    "wegscheret": "wegscheren",
    "wegscherst": "wegscheren",
    "wegschert": "wegscheren",
    "wegscherte": "wegscheren",
    "wegscherten": "wegscheren",
    "wegschertest": "wegscheren",
    "wegschertet": "wegscheren",
    "wegschicke": "wegschicken",
    "wegschickend": "wegschicken",
    "wegschickende": "wegschickend",
    "wegschickendem": "wegschickend",
    "wegschickenden": "wegschickend",
    "wegschickender": "wegschickend",
    "wegschickendes": "wegschickend",
    "wegschickest": "wegschicken",
    "wegschicket": "wegschicken",
    "wegschickst": "wegschicken",
    "wegschickt": "wegschicken",
    "wegschickte": "wegschicken",
    "wegschickten": "wegschicken",
    "wegschicktest": "wegschicken",
    "wegschicktet": "wegschicken",
    "wegschiebe": "wegschieben",
    "wegschiebend": "wegschieben",
    "wegschiebende": "wegschiebend",
    "wegschiebendem": "wegschiebend",
    "wegschiebenden": "wegschiebend",
    "wegschiebender": "wegschiebend",
    "wegschiebendes": "wegschiebend",
    "wegschiebest": "wegschieben",
    "wegschiebet": "wegschieben",
    "wegschiebst": "wegschieben",
    "wegschiebt": "wegschieben",
    "wegschleiche": "wegschleichen",
    "wegschleichend": "wegschleichen",
    "wegschleichende": "wegschleichend",
    "wegschleichendem": "wegschleichend",
    "wegschleichenden": "wegschleichend",
    "wegschleichender": "wegschleichend",
    "wegschleichendes": "wegschleichend",
    "wegschleichest": "wegschleichen",
    "wegschleichet": "wegschleichen",
    "wegschleichst": "wegschleichen",
    "wegschleicht": "wegschleichen",
    "wegschlich": "wegschleichen",
    "wegschliche": "wegschleichen",
    "wegschlichen": "wegschleichen",
    "wegschlichest": "wegschleichen",
    "wegschlichet": "wegschleichen",
    "wegschlichst": "wegschleichen",
    "wegschlicht": "wegschleichen",
    "wegschließe": "wegschließen",
    "wegschließend": "wegschließen",
    "wegschließende": "wegschließend",
    "wegschließendem": "wegschließend",
    "wegschließenden": "wegschließend",
    "wegschließender": "wegschließend",
    "wegschließendes": "wegschließend",
    "wegschließest": "wegschließen",
    "wegschließet": "wegschließen",
    "wegschließt": "wegschließen",
    "wegschlossen": "wegschließen",
    "wegschloß": "wegschließen",
    "wegschloßt": "wegschließen",
    "wegschlösse": "wegschließen",
    "wegschlössen": "wegschließen",
    "wegschlössest": "wegschließen",
    "wegschlösset": "wegschließen",
    "wegschmeiße": "wegschmeißen",
    "wegschmeißend": "wegschmeißen",
    "wegschmeißende": "wegschmeißend",
    "wegschmeißendem": "wegschmeißend",
    "wegschmeißenden": "wegschmeißend",
    "wegschmeißender": "wegschmeißend",
    "wegschmeißendes": "wegschmeißend",
    "wegschmeißest": "wegschmeißen",
    "wegschmeißet": "wegschmeißen",
    "wegschmeißt": "wegschmeißen",
    "wegschmelze": "wegschmelzen",
    "wegschmelzend": "wegschmelzen",
    "wegschmelzende": "wegschmelzend",
    "wegschmelzendem": "wegschmelzend",
    "wegschmelzenden": "wegschmelzend",
    "wegschmelzender": "wegschmelzend",
    "wegschmelzendere": "wegschmelzend",
    "wegschmelzenderem": "wegschmelzend",
    "wegschmelzenderen": "wegschmelzend",
    "wegschmelzenderer": "wegschmelzend",
    "wegschmelzenderes": "wegschmelzend",
    "wegschmelzendes": "wegschmelzend",
    "wegschmelzendste": "wegschmelzend",
    "wegschmelzendstem": "wegschmelzend",
    "wegschmelzendsten": "wegschmelzend",
    "wegschmelzendster": "wegschmelzend",
    "wegschmelzendstes": "wegschmelzend",
    "wegschmelzest": "wegschmelzen",
    "wegschmelzet": "wegschmelzen",
    "wegschmelzt": "wegschmelzen",
    "wegschmilzt": "wegschmelzen",
    "wegschmisse": "wegschmeißen",
    "wegschmissen": "wegschmeißen",
    "wegschmissest": "wegschmeißen",
    "wegschmisset": "wegschmeißen",
    "wegschmiß": "wegschmeißen",
    "wegschmißt": "wegschmeißen",
    "wegschmolz": "wegschmelzen",
    "wegschmolzen": "wegschmelzen",
    "wegschmolzst": "wegschmelzen",
    "wegschmolzt": "wegschmelzen",
    "wegschmölze": "wegschmelzen",
    "wegschmölzen": "wegschmelzen",
    "wegschmölzest": "wegschmelzen",
    "wegschmölzet": "wegschmelzen",
    "wegschnappe": "wegschnappen",
    "wegschnappend": "wegschnappen",
    "wegschnappende": "wegschnappend",
    "wegschnappendem": "wegschnappend",
    "wegschnappenden": "wegschnappend",
    "wegschnappender": "wegschnappend",
    "wegschnappendes": "wegschnappend",
    "wegschnappest": "wegschnappen",
    "wegschnappet": "wegschnappen",
    "wegschnappst": "wegschnappen",
    "wegschnappt": "wegschnappen",
    "wegschnappte": "wegschnappen",
    "wegschnappten": "wegschnappen",
    "wegschnapptest": "wegschnappen",
    "wegschnapptet": "wegschnappen",
    "wegschneide": "wegschneiden",
    "wegschneidend": "wegschneiden",
    "wegschneidende": "wegschneidend",
    "wegschneidendem": "wegschneidend",
    "wegschneidenden": "wegschneidend",
    "wegschneidender": "wegschneidend",
    "wegschneidendes": "wegschneidend",
    "wegschneidest": "wegschneiden",
    "wegschneidet": "wegschneiden",
    "wegschnitt": "wegschneiden",
    "wegschnitte": "wegschneiden",
    "wegschnitten": "wegschneiden",
    "wegschnittest": "wegschneiden",
    "wegschnittet": "wegschneiden",
    "wegschob": "wegschieben",
    "wegschoben": "wegschieben",
    "wegschobst": "wegschieben",
    "wegschobt": "wegschieben",
    "wegschor": "wegscheren",
    "wegschoren": "wegscheren",
    "wegschorst": "wegscheren",
    "wegschort": "wegscheren",
    "wegschöbe": "wegschieben",
    "wegschöben": "wegschieben",
    "wegschöbest": "wegschieben",
    "wegschöbet": "wegschieben",
    "wegschöre": "wegscheren",
    "wegschören": "wegscheren",
    "wegschörest": "wegscheren",
    "wegschöret": "wegscheren",
    "wegschütte": "wegschütten",
    "wegschüttend": "wegschütten",
    "wegschüttende": "wegschüttend",
    "wegschüttendem": "wegschüttend",
    "wegschüttenden": "wegschüttend",
    "wegschüttender": "wegschüttend",
    "wegschüttendes": "wegschüttend",
    "wegschüttest": "wegschütten",
    "wegschüttet": "wegschütten",
    "wegschüttete": "wegschütten",
    "wegschütteten": "wegschütten",
    "wegschüttetest": "wegschütten",
    "wegschüttetet": "wegschütten",
    "wegsehe": "wegsehen",
    "wegsehend": "wegsehen",
    "wegsehende": "wegsehend",
    "wegsehendem": "wegsehend",
    "wegsehenden": "wegsehend",
    "wegsehender": "wegsehend",
    "wegsehendes": "wegsehend",
    "wegsehest": "wegsehen",
    "wegsehet": "wegsehen",
    "wegseht": "wegsehen",
    "wegsetze": "wegsetzen",
    "wegsetzend": "wegsetzen",
    "wegsetzende": "wegsetzend",
    "wegsetzendem": "wegsetzend",
    "wegsetzenden": "wegsetzend",
    "wegsetzender": "wegsetzend",
    "wegsetzendes": "wegsetzend",
    "wegsetzest": "wegsetzen",
    "wegsetzet": "wegsetzen",
    "wegsetzt": "wegsetzen",
    "wegsetzte": "wegsetzen",
    "wegsetzten": "wegsetzen",
    "wegsetztest": "wegsetzen",
    "wegsetztet": "wegsetzen",
    "wegsiehst": "wegsehen",
    "wegsieht": "wegsehen",
    "wegsoff": "wegsaufen",
    "wegsoffen": "wegsaufen",
    "wegsoffst": "wegsaufen",
    "wegsofft": "wegsaufen",
    "wegspiele": "wegspielen",
    "wegspielend": "wegspielen",
    "wegspielende": "wegspielend",
    "wegspielendem": "wegspielend",
    "wegspielenden": "wegspielend",
    "wegspielender": "wegspielend",
    "wegspielendes": "wegspielend",
    "wegspielest": "wegspielen",
    "wegspielet": "wegspielen",
    "wegspielst": "wegspielen",
    "wegspielt": "wegspielen",
    "wegspielte": "wegspielen",
    "wegspielten": "wegspielen",
    "wegspieltest": "wegspielen",
    "wegspieltet": "wegspielen",
    "wegsprenge": "wegsprengen",
    "wegsprengend": "wegsprengen",
    "wegsprengende": "wegsprengend",
    "wegsprengendem": "wegsprengend",
    "wegsprengenden": "wegsprengend",
    "wegsprengender": "wegsprengend",
    "wegsprengendes": "wegsprengend",
    "wegsprengest": "wegsprengen",
    "wegsprenget": "wegsprengen",
    "wegsprengst": "wegsprengen",
    "wegsprengt": "wegsprengen",
    "wegsprengte": "wegsprengen",
    "wegsprengten": "wegsprengen",
    "wegsprengtest": "wegsprengen",
    "wegsprengtet": "wegsprengen",
    "wegspüle": "wegspülen",
    "wegspülend": "wegspülen",
    "wegspülende": "wegspülend",
    "wegspülendem": "wegspülend",
    "wegspülenden": "wegspülend",
    "wegspülender": "wegspülend",
    "wegspülendes": "wegspülend",
    "wegspülest": "wegspülen",
    "wegspület": "wegspülen",
    "wegspülst": "wegspülen",
    "wegspült": "wegspülen",
    "wegspülte": "wegspülen",
    "wegspülten": "wegspülen",
    "wegspültest": "wegspülen",
    "wegspültet": "wegspülen",
    "wegstahl": "wegstehlen",
    "wegstahlen": "wegstehlen",
    "wegstahlst": "wegstehlen",
    "wegstahlt": "wegstehlen",
    "wegstarb": "wegsterben",
    "wegstarben": "wegsterben",
    "wegstarbst": "wegsterben",
    "wegstarbt": "wegsterben",
    "wegstecke": "wegstecken",
    "wegsteckend": "wegstecken",
    "wegsteckende": "wegsteckend",
    "wegsteckendem": "wegsteckend",
    "wegsteckenden": "wegsteckend",
    "wegsteckender": "wegsteckend",
    "wegsteckendes": "wegsteckend",
    "wegsteckest": "wegstecken",
    "wegstecket": "wegstecken",
    "wegsteckst": "wegstecken",
    "wegsteckt": "wegstecken",
    "wegsteckte": "wegstecken",
    "wegsteckten": "wegstecken",
    "wegstecktest": "wegstecken",
    "wegstecktet": "wegstecken",
    "wegstehle": "wegstehlen",
    "wegstehlend": "wegstehlen",
    "wegstehlende": "wegstehlend",
    "wegstehlendem": "wegstehlend",
    "wegstehlenden": "wegstehlend",
    "wegstehlender": "wegstehlend",
    "wegstehlendere": "wegstehlend",
    "wegstehlenderem": "wegstehlend",
    "wegstehlenderen": "wegstehlend",
    "wegstehlenderer": "wegstehlend",
    "wegstehlenderes": "wegstehlend",
    "wegstehlendes": "wegstehlend",
    "wegstehlendste": "wegstehlend",
    "wegstehlendstem": "wegstehlend",
    "wegstehlendsten": "wegstehlend",
    "wegstehlendster": "wegstehlend",
    "wegstehlendstes": "wegstehlend",
    "wegstehlest": "wegstehlen",
    "wegstehlet": "wegstehlen",
    "wegstehlt": "wegstehlen",
    "wegsterbe": "wegsterben",
    "wegsterbend": "wegsterben",
    "wegsterbende": "wegsterbend",
    "wegsterbendem": "wegsterbend",
    "wegsterbenden": "wegsterbend",
    "wegsterbender": "wegsterbend",
    "wegsterbendes": "wegsterbend",
    "wegsterbest": "wegsterben",
    "wegsterbet": "wegsterben",
    "wegsterbt": "wegsterben",
    "wegstiehlst": "wegstehlen",
    "wegstiehlt": "wegstehlen",
    "wegstieß": "wegstoßen",
    "wegstieße": "wegstoßen",
    "wegstießen": "wegstoßen",
    "wegstießest": "wegstoßen",
    "wegstießet": "wegstoßen",
    "wegstießt": "wegstoßen",
    "wegstirbst": "wegsterben",
    "wegstirbt": "wegsterben",
    "wegstoße": "wegstoßen",
    "wegstoßend": "wegstoßen",
    "wegstoßende": "wegstoßend",
    "wegstoßendem": "wegstoßend",
    "wegstoßenden": "wegstoßend",
    "wegstoßender": "wegstoßend",
    "wegstoßendes": "wegstoßend",
    "wegstoßest": "wegstoßen",
    "wegstoßet": "wegstoßen",
    "wegstoßt": "wegstoßen",
    "wegstreiche": "wegstreichen",
    "wegstreichend": "wegstreichen",
    "wegstreichende": "wegstreichend",
    "wegstreichendem": "wegstreichend",
    "wegstreichenden": "wegstreichend",
    "wegstreichender": "wegstreichend",
    "wegstreichendes": "wegstreichend",
    "wegstreichest": "wegstreichen",
    "wegstreichet": "wegstreichen",
    "wegstreichst": "wegstreichen",
    "wegstreicht": "wegstreichen",
    "wegstrich": "wegstreichen",
    "wegstriche": "wegstreichen",
    "wegstrichen": "wegstreichen",
    "wegstrichest": "wegstreichen",
    "wegstrichet": "wegstreichen",
    "wegstrichst": "wegstreichen",
    "wegstricht": "wegstreichen",
    "wegstähle": "wegstehlen",
    "wegstählen": "wegstehlen",
    "wegstählest": "wegstehlen",
    "wegstählet": "wegstehlen",
    "wegstärbe": "wegsterben",
    "wegstärben": "wegsterben",
    "wegstärbest": "wegsterben",
    "wegstärbet": "wegsterben",
    "wegstößt": "wegstoßen",
    "wegsähe": "wegsehen",
    "wegsähen": "wegsehen",
    "wegsähest": "wegsehen",
    "wegsähet": "wegsehen",
    "wegsäufst": "wegsaufen",
    "wegsäuft": "wegsaufen",
    "wegsöffe": "wegsaufen",
    "wegsöffen": "wegsaufen",
    "wegsöffest": "wegsaufen",
    "wegsöffet": "wegsaufen",
    "wegtauche": "wegtauchen",
    "wegtauchend": "wegtauchen",
    "wegtauchende": "wegtauchend",
    "wegtauchendem": "wegtauchend",
    "wegtauchenden": "wegtauchend",
    "wegtauchender": "wegtauchend",
    "wegtauchendes": "wegtauchend",
    "wegtauchest": "wegtauchen",
    "wegtauchet": "wegtauchen",
    "wegtauchst": "wegtauchen",
    "wegtaucht": "wegtauchen",
    "wegtauchte": "wegtauchen",
    "wegtauchten": "wegtauchen",
    "wegtauchtest": "wegtauchen",
    "wegtauchtet": "wegtauchen",
    "wegtrage": "wegtragen",
    "wegtragend": "wegtragen",
    "wegtragende": "wegtragend",
    "wegtragendem": "wegtragend",
    "wegtragenden": "wegtragend",
    "wegtragender": "wegtragend",
    "wegtragendes": "wegtragend",
    "wegtragest": "wegtragen",
    "wegtraget": "wegtragen",
    "wegtragt": "wegtragen",
    "wegtrat": "wegtreten",
    "wegtraten": "wegtreten",
    "wegtratest": "wegtreten",
    "wegtratet": "wegtreten",
    "wegtreibe": "wegtreiben",
    "wegtreibend": "wegtreiben",
    "wegtreibende": "wegtreibend",
    "wegtreibendem": "wegtreibend",
    "wegtreibenden": "wegtreibend",
    "wegtreibender": "wegtreibend",
    "wegtreibendes": "wegtreibend",
    "wegtreibest": "wegtreiben",
    "wegtreibet": "wegtreiben",
    "wegtreibst": "wegtreiben",
    "wegtreibt": "wegtreiben",
    "wegtrete": "wegtreten",
    "wegtretend": "wegtreten",
    "wegtretende": "wegtretend",
    "wegtretendem": "wegtretend",
    "wegtretenden": "wegtretend",
    "wegtretender": "wegtretend",
    "wegtretendes": "wegtretend",
    "wegtretest": "wegtreten",
    "wegtretet": "wegtreten",
    "wegtrieb": "wegtreiben",
    "wegtriebe": "wegtreiben",
    "wegtrieben": "wegtreiben",
    "wegtriebest": "wegtreiben",
    "wegtriebet": "wegtreiben",
    "wegtriebst": "wegtreiben",
    "wegtriebt": "wegtreiben",
    "wegtritt": "wegtreten",
    "wegtrittst": "wegtreten",
    "wegtrug": "wegtragen",
    "wegtrugen": "wegtragen",
    "wegtrugst": "wegtragen",
    "wegtrugt": "wegtragen",
    "wegträgst": "wegtragen",
    "wegträgt": "wegtragen",
    "wegträte": "wegtreten",
    "wegträten": "wegtreten",
    "wegträtest": "wegtreten",
    "wegträtet": "wegtreten",
    "wegtrüge": "wegtragen",
    "wegtrügen": "wegtragen",
    "wegtrügest": "wegtragen",
    "wegtrüget": "wegtragen",
    "wegwandte": "wegwenden",
    "wegwandten": "wegwenden",
    "wegwandtest": "wegwenden",
    "wegwandtet": "wegwenden",
    "wegwarf": "wegwerfen",
    "wegwarfen": "wegwerfen",
    "wegwarfst": "wegwerfen",
    "wegwarft": "wegwerfen",
    "wegweisende": "wegweisend",
    "wegweisendem": "wegweisend",
    "wegweisenden": "wegweisend",
    "wegweisender": "wegweisend",
    "wegweisendes": "wegweisend",
    "wegwende": "wegwenden",
    "wegwendend": "wegwenden",
    "wegwendende": "wegwendend",
    "wegwendendem": "wegwendend",
    "wegwendenden": "wegwendend",
    "wegwendender": "wegwendend",
    "wegwendendes": "wegwendend",
    "wegwendest": "wegwenden",
    "wegwendet": "wegwenden",
    "wegwendete": "wegwenden",
    "wegwendeten": "wegwenden",
    "wegwendetest": "wegwenden",
    "wegwendetet": "wegwenden",
    "wegwerfe": "wegwerfen",
    "wegwerfend": "wegwerfen",
    "wegwerfende": "wegwerfend",
    "wegwerfendem": "wegwerfend",
    "wegwerfenden": "wegwerfend",
    "wegwerfender": "wegwerfend",
    "wegwerfendes": "wegwerfend",
    "wegwerfest": "wegwerfen",
    "wegwerfet": "wegwerfen",
    "wegwerft": "wegwerfen",
    "wegwirfst": "wegwerfen",
    "wegwirft": "wegwerfen",
    "wegwische": "wegwischen",
    "wegwischend": "wegwischen",
    "wegwischende": "wegwischend",
    "wegwischendem": "wegwischend",
    "wegwischenden": "wegwischend",
    "wegwischender": "wegwischend",
    "wegwischendes": "wegwischend",
    "wegwischest": "wegwischen",
    "wegwischet": "wegwischen",
    "wegwischst": "wegwischen",
    "wegwischt": "wegwischen",
    "wegwischte": "wegwischen",
    "wegwischten": "wegwischen",
    "wegwischtest": "wegwischen",
    "wegwischtet": "wegwischen",
    "wegwärfe": "wegwerfen",
    "wegwärfen": "wegwerfen",
    "wegwärfest": "wegwerfen",
    "wegwärfet": "wegwerfen",
    "wegzaubere": "wegzaubern",
    "wegzaubernd": "wegzaubern",
    "wegzaubernde": "wegzaubernd",
    "wegzauberndem": "wegzaubernd",
    "wegzaubernden": "wegzaubernd",
    "wegzaubernder": "wegzaubernd",
    "wegzauberndes": "wegzaubernd",
    "wegzauberst": "wegzaubern",
    "wegzaubert": "wegzaubern",
    "wegzauberte": "wegzaubern",
    "wegzauberten": "wegzaubern",
    "wegzaubertest": "wegzaubern",
    "wegzaubertet": "wegzaubern",
    "wegziehe": "wegziehen",
    "wegziehend": "wegziehen",
    "wegziehende": "wegziehend",
    "wegziehendem": "wegziehend",
    "wegziehenden": "wegziehend",
    "wegziehender": "wegziehend",
    "wegziehendes": "wegziehend",
    "wegziehest": "wegziehen",
    "wegziehet": "wegziehen",
    "wegziehst": "wegziehen",
    "wegzieht": "wegziehen",
    "wegzog": "wegziehen",
    "wegzogen": "wegziehen",
    "wegzogst": "wegziehen",
    "wegzogt": "wegziehen",
    "wegzubekommen": "wegbekommen",
    "wegzublasen": "wegblasen",
    "wegzubleiben": "wegbleiben",
    "wegzublicken": "wegblicken",
    "wegzubrennen": "wegbrennen",
    "wegzubringen": "wegbringen",
    "wegzudenken": "wegdenken",
    "wegzudrücken": "wegdrücken",
    "wegzuessen": "wegessen",
    "wegzufahren": "wegfahren",
    "wegzufallen": "wegfallen",
    "wegzufangen": "wegfangen",
    "wegzufegen": "wegfegen",
    "wegzufliegen": "wegfliegen",
    "wegzufließen": "wegfließen",
    "wegzufressen": "wegfressen",
    "wegzuführen": "wegführen",
    "wegzugeben": "weggeben",
    "wegzugehen": "weggehen",
    "wegzuhalten": "weghalten",
    "wegzuheben": "wegheben",
    "wegzuholen": "wegholen",
    "wegzuhängen": "weghängen",
    "wegzujagen": "wegjagen",
    "wegzukehren": "wegkehren",
    "wegzukommen": "wegkommen",
    "wegzukratzen": "wegkratzen",
    "wegzulassen": "weglassen",
    "wegzulaufen": "weglaufen",
    "wegzulegen": "weglegen",
    "wegzumachen": "wegmachen",
    "wegzunehmen": "wegnehmen",
    "wegzuradieren": "wegradieren",
    "wegzuraffen": "wegraffen",
    "wegzureißen": "wegreißen",
    "wegzurollen": "wegrollen",
    "wegzurufen": "wegrufen",
    "wegzuräumen": "wegräumen",
    "wegzusaufen": "wegsaufen",
    "wegzuschaffen": "wegschaffen",
    "wegzuschauen": "wegschauen",
    "wegzuschaufeln": "wegschaufeln",
    "wegzuschenken": "wegschenken",
    "wegzuscheren": "wegscheren",
    "wegzuschicken": "wegschicken",
    "wegzuschieben": "wegschieben",
    "wegzuschleichen": "wegschleichen",
    "wegzuschließen": "wegschließen",
    "wegzuschmeißen": "wegschmeißen",
    "wegzuschmelzen": "wegschmelzen",
    "wegzuschnappen": "wegschnappen",
    "wegzuschneiden": "wegschneiden",
    "wegzuschütten": "wegschütten",
    "wegzusehen": "wegsehen",
    "wegzusetzen": "wegsetzen",
    "wegzuspielen": "wegspielen",
    "wegzusprengen": "wegsprengen",
    "wegzuspülen": "wegspülen",
    "wegzustecken": "wegstecken",
    "wegzustehlen": "wegstehlen",
    "wegzusterben": "wegsterben",
    "wegzustoßen": "wegstoßen",
    "wegzustreichen": "wegstreichen",
    "wegzutauchen": "wegtauchen",
    "wegzutragen": "wegtragen",
    "wegzutreiben": "wegtreiben",
    "wegzutreten": "wegtreten",
    "wegzuwenden": "wegwenden",
    "wegzuwerfen": "wegwerfen",
    "wegzuwischen": "wegwischen",
    "wegzuzaubern": "wegzaubern",
    "wegzuziehen": "wegziehen",
    "wegzöge": "wegziehen",
    "wegzögen": "wegziehen",
    "wegzögest": "wegziehen",
    "wegzöget": "wegziehen",
    "wegäße": "wegessen",
    "wegäßen": "wegessen",
    "wegäßest": "wegessen",
    "wegäßet": "wegessen",
    "wehend": "wehen",
    "wehende": "wehend",
    "wehendem": "wehend",
    "wehenden": "wehend",
    "wehender": "wehend",
    "wehendes": "wehend",
    "wehest": "wehen",
    "wehet": "wehen",
    "wehleidigem": "wehleidig",
    "wehleidigen": "wehleidig",
    "wehleidiger": "wehleidig",
    "wehleidigere": "wehleidig",
    "wehleidigerem": "wehleidig",
    "wehleidigeren": "wehleidig",
    "wehleidigerer": "wehleidig",
    "wehleidigeres": "wehleidig",
    "wehleidiges": "wehleidig",
    "wehleidigste": "wehleidig",
    "wehleidigstem": "wehleidig",
    "wehleidigsten": "wehleidig",
    "wehleidigster": "wehleidig",
    "wehleidigstes": "wehleidig",
    "wehmutsvolle": "wehmutsvoll",
    "wehmutsvollem": "wehmutsvoll",
    "wehmutsvollen": "wehmutsvoll",
    "wehmutsvoller": "wehmutsvoll",
    "wehmutsvollere": "wehmutsvoll",
    "wehmutsvollerem": "wehmutsvoll",
    "wehmutsvolleren": "wehmutsvoll",
    "wehmutsvollerer": "wehmutsvoll",
    "wehmutsvolleres": "wehmutsvoll",
    "wehmutsvolles": "wehmutsvoll",
    "wehmutsvollste": "wehmutsvoll",
    "wehmutsvollstem": "wehmutsvoll",
    "wehmutsvollsten": "wehmutsvoll",
    "wehmutsvollster": "wehmutsvoll",
    "wehmutsvollstes": "wehmutsvoll",
    "wehmütige": "wehmütig",
    "wehmütigem": "wehmütig",
    "wehmütigen": "wehmütig",
    "wehmütiger": "wehmütig",
    "wehmütigere": "wehmütig",
    "wehmütigerem": "wehmütig",
    "wehmütigeren": "wehmütig",
    "wehmütigerer": "wehmütig",
    "wehmütigeres": "wehmütig",
    "wehmütiges": "wehmütig",
    "wehmütigste": "wehmütig",
    "wehmütigstem": "wehmütig",
    "wehmütigsten": "wehmütig",
    "wehmütigster": "wehmütig",
    "wehmütigstes": "wehmütig",
    "wehrdienstpflichtigem": "wehrdienstpflichtig",
    "wehrdienstpflichtigen": "wehrdienstpflichtig",
    "wehrdienstpflichtiger": "wehrdienstpflichtig",
    "wehrdienstpflichtiges": "wehrdienstpflichtig",
    "wehre": "wehren",
    "wehrend": "wehren",
    "wehrende": "wehrend",
    "wehrendem": "wehrend",
    "wehrenden": "wehrend",
    "wehrender": "wehrend",
    "wehrendere": "wehrend",
    "wehrenderem": "wehrend",
    "wehrenderen": "wehrend",
    "wehrenderer": "wehrend",
    "wehrenderes": "wehrend",
    "wehrendes": "wehrend",
    "wehrendste": "wehrend",
    "wehrendstem": "wehrend",
    "wehrendsten": "wehrend",
    "wehrendster": "wehrend",
    "wehrendstes": "wehrend",
    "wehrest": "wehren",
    "wehret": "wehren",
    "wehrlosem": "wehrlos",
    "wehrlosen": "wehrlos",
    "wehrloser": "wehrlos",
    "wehrlosere": "wehrlos",
    "wehrloserem": "wehrlos",
    "wehrloseren": "wehrlos",
    "wehrloserer": "wehrlos",
    "wehrloseres": "wehrlos",
    "wehrloses": "wehrlos",
    "wehrloseste": "wehrlos",
    "wehrlosestem": "wehrlos",
    "wehrlosesten": "wehrlos",
    "wehrlosester": "wehrlos",
    "wehrlosestes": "wehrlos",
    "wehrpflichtige": "wehrpflichtig",
    "wehrpflichtigem": "wehrpflichtig",
    "wehrpflichtigen": "wehrpflichtig",
    "wehrpflichtiger": "wehrpflichtig",
    "wehrpflichtiges": "wehrpflichtig",
    "wehrst": "wehren",
    "wehrt": "wehren",
    "wehrte": "wehren",
    "wehrten": "wehren",
    "wehrtest": "wehren",
    "wehrtet": "wehren",
    "wehst": "wehen",
    "weht": "wehen",
    "wehte": "wehen",
    "wehten": "wehen",
    "wehtest": "wehen",
    "wehtet": "wehen",
    "weibischem": "weibisch",
    "weibischen": "weibisch",
    "weibischer": "weibisch",
    "weibischere": "weibisch",
    "weibischerem": "weibisch",
    "weibischeren": "weibisch",
    "weibischerer": "weibisch",
    "weibischeres": "weibisch",
    "weibisches": "weibisch",
    "weibischste": "weibisch",
    "weibischstem": "weibisch",
    "weibischsten": "weibisch",
    "weibischster": "weibisch",
    "weibischstes": "weibisch",
    "weiblichem": "weiblich",
    "weiblichen": "weiblich",
    "weiblicher": "weiblich",
    "weiblichere": "weiblich",
    "weiblicherem": "weiblich",
    "weiblicheren": "weiblich",
    "weiblicherer": "weiblich",
    "weiblicheres": "weiblich",
    "weibliches": "weiblich",
    "weiblichste": "weiblich",
    "weiblichstem": "weiblich",
    "weiblichsten": "weiblich",
    "weiblichster": "weiblich",
    "weiblichstes": "weiblich",
    "weich": "weichen",
    "weiche": "weich",
    "weichem": "weich",
    "weichen": "weich",
    "weichend": "weichen",
    "weichende": "weichend",
    "weichendem": "weichend",
    "weichenden": "weichend",
    "weichender": "weichend",
    "weichendes": "weichend",
    "weicher": "weich",
    "weichere": "weich",
    "weicherem": "weich",
    "weicheren": "weich",
    "weicherer": "weich",
    "weicheres": "weich",
    "weiches": "weich",
    "weichest": "weichen",
    "weichet": "weichen",
    "weichgekochte": "weichgekocht",
    "weichgekochtem": "weichgekocht",
    "weichgekochten": "weichgekocht",
    "weichgekochter": "weichgekocht",
    "weichgekochtes": "weichgekocht",
    "weichst": "weichen",
    "weichste": "weich",
    "weichstem": "weich",
    "weichsten": "weich",
    "weichster": "weich",
    "weichstes": "weich",
    "weicht": "weichen",
    "weichte": "weichen",
    "weichten": "weichen",
    "weichtest": "weichen",
    "weichtet": "weichen",
    "weide": "weiden",
    "weidend": "weiden",
    "weidende": "weidend",
    "weidendem": "weidend",
    "weidenden": "weidend",
    "weidender": "weidend",
    "weidendere": "weidend",
    "weidenderem": "weidend",
    "weidenderen": "weidend",
    "weidenderer": "weidend",
    "weidenderes": "weidend",
    "weidendes": "weidend",
    "weidendste": "weidend",
    "weidendstem": "weidend",
    "weidendsten": "weidend",
    "weidendster": "weidend",
    "weidendstes": "weidend",
    "weidest": "weiden",
    "weidet": "weiden",
    "weidete": "weiden",
    "weideten": "weiden",
    "weidetest": "weiden",
    "weidetet": "weiden",
    "weidmännische": "weidmännisch",
    "weidmännischem": "weidmännisch",
    "weidmännischen": "weidmännisch",
    "weidmännischer": "weidmännisch",
    "weidmännisches": "weidmännisch",
    "weigere": "weigern",
    "weigernd": "weigern",
    "weigernde": "weigernd",
    "weigerndem": "weigernd",
    "weigernden": "weigernd",
    "weigernder": "weigernd",
    "weigerndere": "weigernd",
    "weigernderem": "weigernd",
    "weigernderen": "weigernd",
    "weigernderer": "weigernd",
    "weigernderes": "weigernd",
    "weigerndes": "weigernd",
    "weigerndste": "weigernd",
    "weigerndstem": "weigernd",
    "weigerndsten": "weigernd",
    "weigerndster": "weigernd",
    "weigerndstes": "weigernd",
    "weigerst": "weigern",
    "weigert": "weigern",
    "weigerte": "weigern",
    "weigerten": "weigern",
    "weigertest": "weigern",
    "weigertet": "weigern",
    "weihend": "weihen",
    "weihende": "weihend",
    "weihendem": "weihend",
    "weihenden": "weihend",
    "weihender": "weihend",
    "weihendere": "weihend",
    "weihenderem": "weihend",
    "weihenderen": "weihend",
    "weihenderer": "weihend",
    "weihenderes": "weihend",
    "weihendes": "weihend",
    "weihendste": "weihend",
    "weihendstem": "weihend",
    "weihendsten": "weihend",
    "weihendster": "weihend",
    "weihendstes": "weihend",
    "weihest": "weihen",
    "weihet": "weihen",
    "weihnachte": "weihnachten",
    "weihnachtend": "weihnachten",
    "weihnachtende": "weihnachtend",
    "weihnachtendem": "weihnachtend",
    "weihnachtenden": "weihnachtend",
    "weihnachtender": "weihnachtend",
    "weihnachtendes": "weihnachtend",
    "weihnachtest": "weihnachten",
    "weihnachtet": "weihnachten",
    "weihnachtete": "weihnachten",
    "weihnachteten": "weihnachten",
    "weihnachtetest": "weihnachten",
    "weihnachtetet": "weihnachten",
    "weihnachtliche": "weihnachtlich",
    "weihnachtlichem": "weihnachtlich",
    "weihnachtlichen": "weihnachtlich",
    "weihnachtlicher": "weihnachtlich",
    "weihnachtliches": "weihnachtlich",
    "weihst": "weihen",
    "weiht": "weihen",
    "weihte": "weihen",
    "weihten": "weihen",
    "weihtest": "weihen",
    "weihtet": "weihen",
    "weilend": "weilen",
    "weilende": "weilend",
    "weilendem": "weilend",
    "weilenden": "weilend",
    "weilender": "weilend",
    "weilendes": "weilend",
    "weilest": "weilen",
    "weilet": "weilen",
    "weilst": "weilen",
    "weilt": "weilen",
    "weilte": "weilen",
    "weilten": "weilen",
    "weiltest": "weilen",
    "weiltet": "weilen",
    "weinend": "weinen",
    "weinende": "weinend",
    "weinendem": "weinend",
    "weinenden": "weinend",
    "weinender": "weinend",
    "weinendere": "weinend",
    "weinenderem": "weinend",
    "weinenderen": "weinend",
    "weinenderer": "weinend",
    "weinenderes": "weinend",
    "weinendes": "weinend",
    "weinendste": "weinend",
    "weinendstem": "weinend",
    "weinendsten": "weinend",
    "weinendster": "weinend",
    "weinendstes": "weinend",
    "weinerlichem": "weinerlich",
    "weinerlichen": "weinerlich",
    "weinerlicher": "weinerlich",
    "weinerlichere": "weinerlich",
    "weinerlicherem": "weinerlich",
    "weinerlicheren": "weinerlich",
    "weinerlicherer": "weinerlich",
    "weinerlicheres": "weinerlich",
    "weinerliches": "weinerlich",
    "weinerlichste": "weinerlich",
    "weinerlichstem": "weinerlich",
    "weinerlichsten": "weinerlich",
    "weinerlichster": "weinerlich",
    "weinerlichstes": "weinerlich",
    "weinest": "weinen",
    "weinet": "weinen",
    "weinst": "weinen",
    "weint": "weinen",
    "weinte": "weinen",
    "weinten": "weinen",
    "weintest": "weinen",
    "weintet": "weinen",
    "weise": "weisen",
    "weisem": "weise",
    "weisen": "weise",
    "weisend": "weisen",
    "weisende": "weisend",
    "weisendem": "weisend",
    "weisenden": "weisend",
    "weisender": "weisend",
    "weisendes": "weisend",
    "weisere": "weise",
    "weiserem": "weise",
    "weiseren": "weise",
    "weiserer": "weise",
    "weiseres": "weise",
    "weises": "weise",
    "weisest": "weisen",
    "weiseste": "weise",
    "weisestem": "weise",
    "weisesten": "weise",
    "weisester": "weise",
    "weisestes": "weise",
    "weiset": "weisen",
    "weisgesagt": "weissagen",
    "weisgesagte": "weisgesagt",
    "weisgesagtem": "weisgesagt",
    "weisgesagten": "weisgesagt",
    "weisgesagter": "weisgesagt",
    "weisgesagtes": "weisgesagt",
    "weissage": "weissagen",
    "weissagend": "weissagen",
    "weissagende": "weissagend",
    "weissagendem": "weissagend",
    "weissagenden": "weissagend",
    "weissagender": "weissagend",
    "weissagendes": "weissagend",
    "weissagest": "weissagen",
    "weissaget": "weissagen",
    "weissagst": "weissagen",
    "weissagt": "weissagen",
    "weissagte": "weissagen",
    "weissagten": "weissagen",
    "weissagtest": "weissagen",
    "weissagtet": "weissagen",
    "weist": "weisen",
    "weisungsgebundenem": "weisungsgebunden",
    "weisungsgebundenen": "weisungsgebunden",
    "weisungsgebundener": "weisungsgebunden",
    "weisungsgebundenes": "weisungsgebunden",
    "weisungsgemäße": "weisungsgemäß",
    "weisungsgemäßem": "weisungsgemäß",
    "weisungsgemäßen": "weisungsgemäß",
    "weisungsgemäßer": "weisungsgemäß",
    "weisungsgemäßes": "weisungsgemäß",
    "weiszusagen": "weissagen",
    "weite": "weit",
    "weitem": "weit",
    "weiten": "weit",
    "weitend": "weiten",
    "weitende": "weitend",
    "weitendem": "weitend",
    "weitenden": "weitend",
    "weitender": "weitend",
    "weitendere": "weitend",
    "weitenderem": "weitend",
    "weitenderen": "weitend",
    "weitenderer": "weitend",
    "weitenderes": "weitend",
    "weitendes": "weitend",
    "weitendste": "weitend",
    "weitendstem": "weitend",
    "weitendsten": "weitend",
    "weitendster": "weitend",
    "weitendstes": "weitend",
    "weiter": "weit",
    "weiterarbeite": "weiterarbeiten",
    "weiterarbeitend": "weiterarbeiten",
    "weiterarbeitende": "weiterarbeitend",
    "weiterarbeitendem": "weiterarbeitend",
    "weiterarbeitenden": "weiterarbeitend",
    "weiterarbeitender": "weiterarbeitend",
    "weiterarbeitendes": "weiterarbeitend",
    "weiterarbeitest": "weiterarbeiten",
    "weiterarbeitet": "weiterarbeiten",
    "weiterarbeitete": "weiterarbeiten",
    "weiterarbeiteten": "weiterarbeiten",
    "weiterarbeitetest": "weiterarbeiten",
    "weiterarbeitetet": "weiterarbeiten",
    "weiterbestand": "weiterbestehen",
    "weiterbestanden": "weiterbestehen",
    "weiterbestandene": "weiterbestanden",
    "weiterbestandenem": "weiterbestanden",
    "weiterbestandenen": "weiterbestanden",
    "weiterbestandener": "weiterbestanden",
    "weiterbestandenes": "weiterbestanden",
    "weiterbestandest": "weiterbestehen",
    "weiterbestandet": "weiterbestehen",
    "weiterbestehe": "weiterbestehen",
    "weiterbestehend": "weiterbestehen",
    "weiterbestehende": "weiterbestehend",
    "weiterbestehendem": "weiterbestehend",
    "weiterbestehenden": "weiterbestehend",
    "weiterbestehender": "weiterbestehend",
    "weiterbestehendes": "weiterbestehend",
    "weiterbestehest": "weiterbestehen",
    "weiterbestehet": "weiterbestehen",
    "weiterbestehst": "weiterbestehen",
    "weiterbesteht": "weiterbestehen",
    "weiterbestünde": "weiterbestehen",
    "weiterbestünden": "weiterbestehen",
    "weiterbestündest": "weiterbestehen",
    "weiterbestündet": "weiterbestehen",
    "weiterbilde": "weiterbilden",
    "weiterbildend": "weiterbilden",
    "weiterbildende": "weiterbildend",
    "weiterbildendem": "weiterbildend",
    "weiterbildenden": "weiterbildend",
    "weiterbildender": "weiterbildend",
    "weiterbildendes": "weiterbildend",
    "weiterbildest": "weiterbilden",
    "weiterbildet": "weiterbilden",
    "weiterbildete": "weiterbilden",
    "weiterbildeten": "weiterbilden",
    "weiterbildetest": "weiterbilden",
    "weiterbildetet": "weiterbilden",
    "weiterbrachte": "weiterbringen",
    "weiterbrachten": "weiterbringen",
    "weiterbrachtest": "weiterbringen",
    "weiterbrachtet": "weiterbringen",
    "weiterbringe": "weiterbringen",
    "weiterbringend": "weiterbringen",
    "weiterbringende": "weiterbringend",
    "weiterbringendem": "weiterbringend",
    "weiterbringenden": "weiterbringend",
    "weiterbringender": "weiterbringend",
    "weiterbringendes": "weiterbringend",
    "weiterbringest": "weiterbringen",
    "weiterbringet": "weiterbringen",
    "weiterbringst": "weiterbringen",
    "weiterbringt": "weiterbringen",
    "weiterbrächte": "weiterbringen",
    "weiterbrächten": "weiterbringen",
    "weiterbrächtest": "weiterbringen",
    "weiterbrächtet": "weiterbringen",
    "weiterdachte": "weiterdenken",
    "weiterdachten": "weiterdenken",
    "weiterdachtest": "weiterdenken",
    "weiterdachtet": "weiterdenken",
    "weiterdenke": "weiterdenken",
    "weiterdenkend": "weiterdenken",
    "weiterdenkende": "weiterdenkend",
    "weiterdenkendem": "weiterdenkend",
    "weiterdenkenden": "weiterdenkend",
    "weiterdenkender": "weiterdenkend",
    "weiterdenkendes": "weiterdenkend",
    "weiterdenkest": "weiterdenken",
    "weiterdenket": "weiterdenken",
    "weiterdenkst": "weiterdenken",
    "weiterdenkt": "weiterdenken",
    "weiterdächte": "weiterdenken",
    "weiterdächten": "weiterdenken",
    "weiterdächtest": "weiterdenken",
    "weiterdächtet": "weiterdenken",
    "weitere": "weit",
    "weiterem": "weit",
    "weiterempfahl": "weiterempfehlen",
    "weiterempfahlen": "weiterempfehlen",
    "weiterempfahlst": "weiterempfehlen",
    "weiterempfahlt": "weiterempfehlen",
    "weiterempfehle": "weiterempfehlen",
    "weiterempfehlend": "weiterempfehlen",
    "weiterempfehlende": "weiterempfehlend",
    "weiterempfehlendem": "weiterempfehlend",
    "weiterempfehlenden": "weiterempfehlend",
    "weiterempfehlender": "weiterempfehlend",
    "weiterempfehlendes": "weiterempfehlend",
    "weiterempfehlest": "weiterempfehlen",
    "weiterempfehlet": "weiterempfehlen",
    "weiterempfehlt": "weiterempfehlen",
    "weiterempfiehlst": "weiterempfehlen",
    "weiterempfiehlt": "weiterempfehlen",
    "weiterempfohlen": "weiterempfehlen",
    "weiterempfohlene": "weiterempfohlen",
    "weiterempfohlenem": "weiterempfohlen",
    "weiterempfohlenen": "weiterempfohlen",
    "weiterempfohlener": "weiterempfohlen",
    "weiterempfohlenes": "weiterempfohlen",
    "weiterempfähle": "weiterempfehlen",
    "weiterempfählen": "weiterempfehlen",
    "weiterempfählest": "weiterempfehlen",
    "weiterempfählet": "weiterempfehlen",
    "weiteren": "weit",
    "weiterentwickele": "weiterentwickel",
    "weiterentwickeln": "weiterentwickel",
    "weiterentwickelnd": "weiterentwickel",
    "weiterentwickelnde": "weiterentwickelnd",
    "weiterentwickelndem": "weiterentwickelnd",
    "weiterentwickelnden": "weiterentwickelnd",
    "weiterentwickelnder": "weiterentwickelnd",
    "weiterentwickelndes": "weiterentwickelnd",
    "weiterentwickelst": "weiterentwickel",
    "weiterentwickelt": "weiterentwickel",
    "weiterentwickelte": "weiterentwickel",
    "weiterentwickeltem": "weiterentwickelt",
    "weiterentwickelten": "weiterentwickel",
    "weiterentwickelter": "weiterentwickelt",
    "weiterentwickeltere": "weiterentwickelt",
    "weiterentwickelterem": "weiterentwickelt",
    "weiterentwickelteren": "weiterentwickelt",
    "weiterentwickelterer": "weiterentwickelt",
    "weiterentwickelteres": "weiterentwickelt",
    "weiterentwickeltes": "weiterentwickelt",
    "weiterentwickeltest": "weiterentwickel",
    "weiterentwickelteste": "weiterentwickelt",
    "weiterentwickeltestem": "weiterentwickelt",
    "weiterentwickeltesten": "weiterentwickelt",
    "weiterentwickeltester": "weiterentwickelt",
    "weiterentwickeltestes": "weiterentwickelt",
    "weiterentwickeltet": "weiterentwickel",
    "weiterentwickle": "weiterentwickel",
    "weiterer": "weit",
    "weitererzähle": "weitererzählen",
    "weitererzählend": "weitererzählen",
    "weitererzählende": "weitererzählend",
    "weitererzählendem": "weitererzählend",
    "weitererzählenden": "weitererzählend",
    "weitererzählender": "weitererzählend",
    "weitererzählendes": "weitererzählend",
    "weitererzählest": "weitererzählen",
    "weitererzählet": "weitererzählen",
    "weitererzählst": "weitererzählen",
    "weitererzählt": "weitererzählen",
    "weitererzählte": "weitererzählen",
    "weitererzähltem": "weitererzählt",
    "weitererzählten": "weitererzählen",
    "weitererzählter": "weitererzählt",
    "weitererzähltes": "weitererzählt",
    "weitererzähltest": "weitererzählen",
    "weitererzähltet": "weitererzählen",
    "weiteres": "weit",
    "weiterfahre": "weiterfahren",
    "weiterfahrend": "weiterfahren",
    "weiterfahrende": "weiterfahrend",
    "weiterfahrendem": "weiterfahrend",
    "weiterfahrenden": "weiterfahrend",
    "weiterfahrender": "weiterfahrend",
    "weiterfahrendes": "weiterfahrend",
    "weiterfahrest": "weiterfahren",
    "weiterfahret": "weiterfahren",
    "weiterfahrt": "weiterfahren",
    "weiterfliege": "weiterfliegen",
    "weiterfliegend": "weiterfliegen",
    "weiterfliegende": "weiterfliegend",
    "weiterfliegendem": "weiterfliegend",
    "weiterfliegenden": "weiterfliegend",
    "weiterfliegender": "weiterfliegend",
    "weiterfliegendes": "weiterfliegend",
    "weiterfliegest": "weiterfliegen",
    "weiterflieget": "weiterfliegen",
    "weiterfliegst": "weiterfliegen",
    "weiterfliegt": "weiterfliegen",
    "weiterflog": "weiterfliegen",
    "weiterflogen": "weiterfliegen",
    "weiterflogst": "weiterfliegen",
    "weiterflogt": "weiterfliegen",
    "weiterflöge": "weiterfliegen",
    "weiterflögen": "weiterfliegen",
    "weiterflögest": "weiterfliegen",
    "weiterflöget": "weiterfliegen",
    "weiterfuhr": "weiterfahren",
    "weiterfuhren": "weiterfahren",
    "weiterfuhrst": "weiterfahren",
    "weiterfuhrt": "weiterfahren",
    "weiterfährst": "weiterfahren",
    "weiterfährt": "weiterfahren",
    "weiterführe": "weiterführen",
    "weiterführen": "weiterfahren",
    "weiterführend": "weiterführen",
    "weiterführende": "weiterführend",
    "weiterführendem": "weiterführend",
    "weiterführenden": "weiterführend",
    "weiterführender": "weiterführend",
    "weiterführendes": "weiterführend",
    "weiterführest": "weiterführen",
    "weiterführet": "weiterführen",
    "weiterführst": "weiterführen",
    "weiterführt": "weiterführen",
    "weiterführte": "weiterführen",
    "weiterführten": "weiterführen",
    "weiterführtest": "weiterführen",
    "weiterführtet": "weiterführen",
    "weitergab": "weitergeben",
    "weitergaben": "weitergeben",
    "weitergabst": "weitergeben",
    "weitergabt": "weitergeben",
    "weitergearbeitet": "weiterarbeiten",
    "weitergearbeitete": "weitergearbeitet",
    "weitergearbeitetem": "weitergearbeitet",
    "weitergearbeiteten": "weitergearbeitet",
    "weitergearbeiteter": "weitergearbeitet",
    "weitergearbeitetes": "weitergearbeitet",
    "weitergebe": "weitergeben",
    "weitergebend": "weitergeben",
    "weitergebende": "weitergebend",
    "weitergebendem": "weitergebend",
    "weitergebenden": "weitergebend",
    "weitergebender": "weitergebend",
    "weitergebendes": "weitergebend",
    "weitergebest": "weitergeben",
    "weitergebet": "weitergeben",
    "weitergebildet": "weiterbilden",
    "weitergebildete": "weitergebildet",
    "weitergebildetem": "weitergebildet",
    "weitergebildeten": "weitergebildet",
    "weitergebildeter": "weitergebildet",
    "weitergebildetere": "weitergebildet",
    "weitergebildeterem": "weitergebildet",
    "weitergebildeteren": "weitergebildet",
    "weitergebildeterer": "weitergebildet",
    "weitergebildeteres": "weitergebildet",
    "weitergebildetes": "weitergebildet",
    "weitergebildeteste": "weitergebildet",
    "weitergebildetestem": "weitergebildet",
    "weitergebildetesten": "weitergebildet",
    "weitergebildetester": "weitergebildet",
    "weitergebildetestes": "weitergebildet",
    "weitergebracht": "weiterbringen",
    "weitergebrachte": "weitergebracht",
    "weitergebrachtem": "weitergebracht",
    "weitergebrachten": "weitergebracht",
    "weitergebrachter": "weitergebracht",
    "weitergebrachtes": "weitergebracht",
    "weitergebt": "weitergeben",
    "weitergedacht": "weiterdenken",
    "weitergedachte": "weitergedacht",
    "weitergedachtem": "weitergedacht",
    "weitergedachten": "weitergedacht",
    "weitergedachter": "weitergedacht",
    "weitergedachtes": "weitergedacht",
    "weitergefahren": "weiterfahren",
    "weitergefahrene": "weitergefahren",
    "weitergefahrenem": "weitergefahren",
    "weitergefahrenen": "weitergefahren",
    "weitergefahrener": "weitergefahren",
    "weitergefahrenes": "weitergefahren",
    "weitergeflogen": "weiterfliegen",
    "weitergeflogene": "weitergeflogen",
    "weitergeflogenem": "weitergeflogen",
    "weitergeflogenen": "weitergeflogen",
    "weitergeflogener": "weitergeflogen",
    "weitergeflogenes": "weitergeflogen",
    "weitergeführt": "weiterführen",
    "weitergeführte": "weitergeführt",
    "weitergeführtem": "weitergeführt",
    "weitergeführten": "weitergeführt",
    "weitergeführter": "weitergeführt",
    "weitergeführtes": "weitergeführt",
    "weitergegangen": "weitergehen",
    "weitergegangene": "weitergegangen",
    "weitergegangenem": "weitergegangen",
    "weitergegangenen": "weitergegangen",
    "weitergegangener": "weitergegangen",
    "weitergegangenes": "weitergegangen",
    "weitergegeben": "weitergeben",
    "weitergegebene": "weitergegeben",
    "weitergegebenem": "weitergegeben",
    "weitergegebenen": "weitergegeben",
    "weitergegebener": "weitergegeben",
    "weitergegebenes": "weitergegeben",
    "weitergehe": "weitergehen",
    "weitergehend": "weitergehen",
    "weitergehende": "weitergehend",
    "weitergehendem": "weitergehend",
    "weitergehenden": "weitergehend",
    "weitergehender": "weitergehend",
    "weitergehendes": "weitergehend",
    "weitergehest": "weitergehen",
    "weitergehet": "weitergehen",
    "weitergeholfen": "weiterhelfen",
    "weitergeholfene": "weitergeholfen",
    "weitergeholfenem": "weitergeholfen",
    "weitergeholfenen": "weitergeholfen",
    "weitergeholfener": "weitergeholfen",
    "weitergeholfenes": "weitergeholfen",
    "weitergehst": "weitergehen",
    "weitergeht": "weitergehen",
    "weitergekommen": "weiterkommen",
    "weitergekommene": "weitergekommen",
    "weitergekommenem": "weitergekommen",
    "weitergekommenen": "weitergekommen",
    "weitergekommener": "weitergekommen",
    "weitergekommenere": "weitergekommen",
    "weitergekommenerem": "weitergekommen",
    "weitergekommeneren": "weitergekommen",
    "weitergekommenerer": "weitergekommen",
    "weitergekommeneres": "weitergekommen",
    "weitergekommenes": "weitergekommen",
    "weitergekommenste": "weitergekommen",
    "weitergekommenstem": "weitergekommen",
    "weitergekommensten": "weitergekommen",
    "weitergekommenster": "weitergekommen",
    "weitergekommenstes": "weitergekommen",
    "weitergelaufen": "weiterlaufen",
    "weitergelaufene": "weitergelaufen",
    "weitergelaufenem": "weitergelaufen",
    "weitergelaufenen": "weitergelaufen",
    "weitergelaufener": "weitergelaufen",
    "weitergelaufenes": "weitergelaufen",
    "weitergeleitet": "weiterleiten",
    "weitergeleitete": "weitergeleitet",
    "weitergeleitetem": "weitergeleitet",
    "weitergeleiteten": "weitergeleitet",
    "weitergeleiteter": "weitergeleitet",
    "weitergeleitetes": "weitergeleitet",
    "weitergemacht": "weitermachen",
    "weitergemachte": "weitergemacht",
    "weitergemachtem": "weitergemacht",
    "weitergemachten": "weitergemacht",
    "weitergemachter": "weitergemacht",
    "weitergemachtes": "weitergemacht",
    "weitergereist": "weiterreisen",
    "weitergereiste": "weitergereist",
    "weitergereistem": "weitergereist",
    "weitergereisten": "weitergereist",
    "weitergereister": "weitergereist",
    "weitergereistes": "weitergereist",
    "weitergesagt": "weitersagen",
    "weitergesagte": "weitergesagt",
    "weitergesagtem": "weitergesagt",
    "weitergesagten": "weitergesagt",
    "weitergesagter": "weitergesagt",
    "weitergesagtes": "weitergesagt",
    "weitergesponnen": "weiterspinnen",
    "weitergesponnene": "weitergesponnen",
    "weitergesponnenem": "weitergesponnen",
    "weitergesponnenen": "weitergesponnen",
    "weitergesponnener": "weitergesponnen",
    "weitergesponnenes": "weitergesponnen",
    "weitergetragen": "weitertragen",
    "weitergetragene": "weitergetragen",
    "weitergetragenem": "weitergetragen",
    "weitergetragenen": "weitergetragen",
    "weitergetragener": "weitergetragen",
    "weitergetragenere": "weitergetragen",
    "weitergetragenerem": "weitergetragen",
    "weitergetrageneren": "weitergetragen",
    "weitergetragenerer": "weitergetragen",
    "weitergetrageneres": "weitergetragen",
    "weitergetragenes": "weitergetragen",
    "weitergetragenste": "weitergetragen",
    "weitergetragenstem": "weitergetragen",
    "weitergetragensten": "weitergetragen",
    "weitergetragenster": "weitergetragen",
    "weitergetragenstes": "weitergetragen",
    "weitergibst": "weitergeben",
    "weitergibt": "weitergeben",
    "weiterging": "weitergehen",
    "weiterginge": "weitergehen",
    "weitergingen": "weitergehen",
    "weitergingest": "weitergehen",
    "weiterginget": "weitergehen",
    "weitergingst": "weitergehen",
    "weitergingt": "weitergehen",
    "weitergäbe": "weitergeben",
    "weitergäben": "weitergeben",
    "weitergäbest": "weitergeben",
    "weitergäbet": "weitergeben",
    "weiterhalf": "weiterhelfen",
    "weiterhalfen": "weiterhelfen",
    "weiterhalfst": "weiterhelfen",
    "weiterhalft": "weiterhelfen",
    "weiterhelfe": "weiterhelfen",
    "weiterhelfend": "weiterhelfen",
    "weiterhelfende": "weiterhelfend",
    "weiterhelfendem": "weiterhelfend",
    "weiterhelfenden": "weiterhelfend",
    "weiterhelfender": "weiterhelfend",
    "weiterhelfendes": "weiterhelfend",
    "weiterhelfest": "weiterhelfen",
    "weiterhelfet": "weiterhelfen",
    "weiterhelft": "weiterhelfen",
    "weiterhilfst": "weiterhelfen",
    "weiterhilft": "weiterhelfen",
    "weiterhälfe": "weiterhelfen",
    "weiterhälfen": "weiterhelfen",
    "weiterhälfest": "weiterhelfen",
    "weiterhälfet": "weiterhelfen",
    "weiterkam": "weiterkommen",
    "weiterkamen": "weiterkommen",
    "weiterkamst": "weiterkommen",
    "weiterkamt": "weiterkommen",
    "weiterkomme": "weiterkommen",
    "weiterkommend": "weiterkommen",
    "weiterkommende": "weiterkommend",
    "weiterkommendem": "weiterkommend",
    "weiterkommenden": "weiterkommend",
    "weiterkommender": "weiterkommend",
    "weiterkommendere": "weiterkommend",
    "weiterkommenderem": "weiterkommend",
    "weiterkommenderen": "weiterkommend",
    "weiterkommenderer": "weiterkommend",
    "weiterkommenderes": "weiterkommend",
    "weiterkommendes": "weiterkommend",
    "weiterkommendste": "weiterkommend",
    "weiterkommendstem": "weiterkommend",
    "weiterkommendsten": "weiterkommend",
    "weiterkommendster": "weiterkommend",
    "weiterkommendstes": "weiterkommend",
    "weiterkommest": "weiterkommen",
    "weiterkommet": "weiterkommen",
    "weiterkommst": "weiterkommen",
    "weiterkommt": "weiterkommen",
    "weiterkäme": "weiterkommen",
    "weiterkämen": "weiterkommen",
    "weiterkämest": "weiterkommen",
    "weiterkämet": "weiterkommen",
    "weiterlaufe": "weiterlaufen",
    "weiterlaufend": "weiterlaufen",
    "weiterlaufende": "weiterlaufend",
    "weiterlaufendem": "weiterlaufend",
    "weiterlaufenden": "weiterlaufend",
    "weiterlaufender": "weiterlaufend",
    "weiterlaufendes": "weiterlaufend",
    "weiterlaufest": "weiterlaufen",
    "weiterlaufet": "weiterlaufen",
    "weiterlauft": "weiterlaufen",
    "weiterleite": "weiterleiten",
    "weiterleitend": "weiterleiten",
    "weiterleitende": "weiterleitend",
    "weiterleitendem": "weiterleitend",
    "weiterleitenden": "weiterleitend",
    "weiterleitender": "weiterleitend",
    "weiterleitendes": "weiterleitend",
    "weiterleitest": "weiterleiten",
    "weiterleitet": "weiterleiten",
    "weiterleitete": "weiterleiten",
    "weiterleiteten": "weiterleiten",
    "weiterleitetest": "weiterleiten",
    "weiterleitetet": "weiterleiten",
    "weiterlief": "weiterlaufen",
    "weiterliefe": "weiterlaufen",
    "weiterliefen": "weiterlaufen",
    "weiterliefest": "weiterlaufen",
    "weiterliefet": "weiterlaufen",
    "weiterliefst": "weiterlaufen",
    "weiterlieft": "weiterlaufen",
    "weiterläufst": "weiterlaufen",
    "weiterläuft": "weiterlaufen",
    "weitermache": "weitermachen",
    "weitermachend": "weitermachen",
    "weitermachende": "weitermachend",
    "weitermachendem": "weitermachend",
    "weitermachenden": "weitermachend",
    "weitermachender": "weitermachend",
    "weitermachendes": "weitermachend",
    "weitermachest": "weitermachen",
    "weitermachet": "weitermachen",
    "weitermachst": "weitermachen",
    "weitermacht": "weitermachen",
    "weitermachte": "weitermachen",
    "weitermachten": "weitermachen",
    "weitermachtest": "weitermachen",
    "weitermachtet": "weitermachen",
    "weitermarschiere": "weitermarschieren",
    "weitermarschierend": "weitermarschieren",
    "weitermarschierende": "weitermarschierend",
    "weitermarschierendem": "weitermarschierend",
    "weitermarschierenden": "weitermarschierend",
    "weitermarschierender": "weitermarschierend",
    "weitermarschierendes": "weitermarschierend",
    "weitermarschierest": "weitermarschieren",
    "weitermarschieret": "weitermarschieren",
    "weitermarschierst": "weitermarschieren",
    "weitermarschiert": "weitermarschieren",
    "weitermarschierte": "weitermarschieren",
    "weitermarschiertem": "weitermarschiert",
    "weitermarschierten": "weitermarschieren",
    "weitermarschierter": "weitermarschiert",
    "weitermarschiertes": "weitermarschiert",
    "weitermarschiertest": "weitermarschieren",
    "weitermarschiertet": "weitermarschieren",
    "weiterreise": "weiterreisen",
    "weiterreisend": "weiterreisen",
    "weiterreisende": "weiterreisend",
    "weiterreisendem": "weiterreisend",
    "weiterreisenden": "weiterreisend",
    "weiterreisender": "weiterreisend",
    "weiterreisendes": "weiterreisend",
    "weiterreisest": "weiterreisen",
    "weiterreiset": "weiterreisen",
    "weiterreist": "weiterreisen",
    "weiterreiste": "weiterreisen",
    "weiterreisten": "weiterreisen",
    "weiterreistest": "weiterreisen",
    "weiterreistet": "weiterreisen",
    "weitersage": "weitersagen",
    "weitersagend": "weitersagen",
    "weitersagende": "weitersagend",
    "weitersagendem": "weitersagend",
    "weitersagenden": "weitersagend",
    "weitersagender": "weitersagend",
    "weitersagendes": "weitersagend",
    "weitersagest": "weitersagen",
    "weitersaget": "weitersagen",
    "weitersagst": "weitersagen",
    "weitersagt": "weitersagen",
    "weitersagte": "weitersagen",
    "weitersagten": "weitersagen",
    "weitersagtest": "weitersagen",
    "weitersagtet": "weitersagen",
    "weiterspann": "weiterspinnen",
    "weiterspannen": "weiterspinnen",
    "weiterspannst": "weiterspinnen",
    "weiterspannt": "weiterspinnen",
    "weiterspinne": "weiterspinnen",
    "weiterspinnend": "weiterspinnen",
    "weiterspinnende": "weiterspinnend",
    "weiterspinnendem": "weiterspinnend",
    "weiterspinnenden": "weiterspinnend",
    "weiterspinnender": "weiterspinnend",
    "weiterspinnendes": "weiterspinnend",
    "weiterspinnest": "weiterspinnen",
    "weiterspinnet": "weiterspinnen",
    "weiterspinnst": "weiterspinnen",
    "weiterspinnt": "weiterspinnen",
    "weiterspänne": "weiterspinnen",
    "weiterspännen": "weiterspinnen",
    "weiterspännest": "weiterspinnen",
    "weiterspännet": "weiterspinnen",
    "weitertrage": "weitertragen",
    "weitertragend": "weitertragen",
    "weitertragende": "weitertragend",
    "weitertragendem": "weitertragend",
    "weitertragenden": "weitertragend",
    "weitertragender": "weitertragend",
    "weitertragendere": "weitertragend",
    "weitertragenderem": "weitertragend",
    "weitertragenderen": "weitertragend",
    "weitertragenderer": "weitertragend",
    "weitertragenderes": "weitertragend",
    "weitertragendes": "weitertragend",
    "weitertragendste": "weitertragend",
    "weitertragendstem": "weitertragend",
    "weitertragendsten": "weitertragend",
    "weitertragendster": "weitertragend",
    "weitertragendstes": "weitertragend",
    "weitertragest": "weitertragen",
    "weitertraget": "weitertragen",
    "weitertragt": "weitertragen",
    "weitertrug": "weitertragen",
    "weitertrugen": "weitertragen",
    "weitertrugst": "weitertragen",
    "weitertrugt": "weitertragen",
    "weiterträgst": "weitertragen",
    "weiterträgt": "weitertragen",
    "weitertrüge": "weitertragen",
    "weitertrügen": "weitertragen",
    "weitertrügest": "weitertragen",
    "weitertrüget": "weitertragen",
    "weiterverbreite": "weiterverbreiten",
    "weiterverbreitend": "weiterverbreiten",
    "weiterverbreitende": "weiterverbreitend",
    "weiterverbreitendem": "weiterverbreitend",
    "weiterverbreitenden": "weiterverbreitend",
    "weiterverbreitender": "weiterverbreitend",
    "weiterverbreitendes": "weiterverbreitend",
    "weiterverbreitest": "weiterverbreiten",
    "weiterverbreitet": "weiterverbreiten",
    "weiterverbreitete": "weiterverbreiten",
    "weiterverbreitetem": "weiterverbreitet",
    "weiterverbreiteten": "weiterverbreiten",
    "weiterverbreiteter": "weiterverbreitet",
    "weiterverbreitetes": "weiterverbreitet",
    "weiterverbreitetest": "weiterverbreiten",
    "weiterverbreitetet": "weiterverbreiten",
    "weiterverfolge": "weiterverfolgen",
    "weiterverfolgend": "weiterverfolgen",
    "weiterverfolgende": "weiterverfolgend",
    "weiterverfolgendem": "weiterverfolgend",
    "weiterverfolgenden": "weiterverfolgend",
    "weiterverfolgender": "weiterverfolgend",
    "weiterverfolgendes": "weiterverfolgend",
    "weiterverfolgest": "weiterverfolgen",
    "weiterverfolget": "weiterverfolgen",
    "weiterverfolgst": "weiterverfolgen",
    "weiterverfolgt": "weiterverfolgen",
    "weiterverfolgte": "weiterverfolgen",
    "weiterverfolgtem": "weiterverfolgt",
    "weiterverfolgten": "weiterverfolgen",
    "weiterverfolgter": "weiterverfolgt",
    "weiterverfolgtes": "weiterverfolgt",
    "weiterverfolgtest": "weiterverfolgen",
    "weiterverfolgtet": "weiterverfolgen",
    "weiterverkaufe": "weiterverkaufen",
    "weiterverkaufend": "weiterverkaufen",
    "weiterverkaufende": "weiterverkaufend",
    "weiterverkaufendem": "weiterverkaufend",
    "weiterverkaufenden": "weiterverkaufend",
    "weiterverkaufender": "weiterverkaufend",
    "weiterverkaufendes": "weiterverkaufend",
    "weiterverkaufest": "weiterverkaufen",
    "weiterverkaufet": "weiterverkaufen",
    "weiterverkaufst": "weiterverkaufen",
    "weiterverkauft": "weiterverkaufen",
    "weiterverkaufte": "weiterverkaufen",
    "weiterverkauftem": "weiterverkauft",
    "weiterverkauften": "weiterverkaufen",
    "weiterverkaufter": "weiterverkauft",
    "weiterverkauftes": "weiterverkauft",
    "weiterverkauftest": "weiterverkaufen",
    "weiterverkauftet": "weiterverkaufen",
    "weitervermiete": "weitervermieten",
    "weitervermietend": "weitervermieten",
    "weitervermietende": "weitervermietend",
    "weitervermietendem": "weitervermietend",
    "weitervermietenden": "weitervermietend",
    "weitervermietender": "weitervermietend",
    "weitervermietendes": "weitervermietend",
    "weitervermietest": "weitervermieten",
    "weitervermietet": "weitervermieten",
    "weitervermietete": "weitervermieten",
    "weitervermietetem": "weitervermietet",
    "weitervermieteten": "weitervermieten",
    "weitervermieteter": "weitervermietet",
    "weitervermietetes": "weitervermietet",
    "weitervermietetest": "weitervermieten",
    "weitervermietetet": "weitervermieten",
    "weiterzuarbeiten": "weiterarbeiten",
    "weiterzubestehen": "weiterbestehen",
    "weiterzubilden": "weiterbilden",
    "weiterzubringen": "weiterbringen",
    "weiterzudenken": "weiterdenken",
    "weiterzuempfehlen": "weiterempfehlen",
    "weiterzuentwickeln": "weiterentwickeln",
    "weiterzuerzählen": "weitererzählen",
    "weiterzufahren": "weiterfahren",
    "weiterzufliegen": "weiterfliegen",
    "weiterzuführen": "weiterführen",
    "weiterzugeben": "weitergeben",
    "weiterzugehen": "weitergehen",
    "weiterzuhelfen": "weiterhelfen",
    "weiterzukommen": "weiterkommen",
    "weiterzulaufen": "weiterlaufen",
    "weiterzuleiten": "weiterleiten",
    "weiterzumachen": "weitermachen",
    "weiterzumarschieren": "weitermarschieren",
    "weiterzureisen": "weiterreisen",
    "weiterzusagen": "weitersagen",
    "weiterzuspinnen": "weiterspinnen",
    "weiterzutragen": "weitertragen",
    "weiterzuverbreiten": "weiterverbreiten",
    "weiterzuverfolgen": "weiterverfolgen",
    "weiterzuverkaufen": "weiterverkaufen",
    "weiterzuvermieten": "weitervermieten",
    "weites": "weit",
    "weitest": "weiten",
    "weiteste": "weit",
    "weitestem": "weit",
    "weitesten": "weit",
    "weitester": "weit",
    "weitestes": "weit",
    "weitet": "weiten",
    "weitete": "weiten",
    "weiteten": "weiten",
    "weitetest": "weiten",
    "weitetet": "weiten",
    "weithergeholte": "weithergeholt",
    "weithergeholtem": "weithergeholt",
    "weithergeholten": "weithergeholt",
    "weithergeholter": "weithergeholt",
    "weithergeholtes": "weithergeholt",
    "weitläufige": "weitläufig",
    "weitläufigem": "weitläufig",
    "weitläufigen": "weitläufig",
    "weitläufiger": "weitläufig",
    "weitläufigere": "weitläufig",
    "weitläufigerem": "weitläufig",
    "weitläufigeren": "weitläufig",
    "weitläufigerer": "weitläufig",
    "weitläufigeres": "weitläufig",
    "weitläufiges": "weitläufig",
    "weitläufigste": "weitläufig",
    "weitläufigstem": "weitläufig",
    "weitläufigsten": "weitläufig",
    "weitläufigster": "weitläufig",
    "weitläufigstes": "weitläufig",
    "weitreichende": "weitreichend",
    "weitreichendem": "weitreichend",
    "weitreichenden": "weitreichend",
    "weitreichender": "weitreichend",
    "weitreichendere": "weitreichend",
    "weitreichenderem": "weitreichend",
    "weitreichenderen": "weitreichend",
    "weitreichenderer": "weitreichend",
    "weitreichenderes": "weitreichend",
    "weitreichendes": "weitreichend",
    "weitreichendste": "weitreichend",
    "weitreichendstem": "weitreichend",
    "weitreichendsten": "weitreichend",
    "weitreichendster": "weitreichend",
    "weitreichendstes": "weitreichend",
    "weitschweifige": "weitschweifig",
    "weitschweifigem": "weitschweifig",
    "weitschweifigen": "weitschweifig",
    "weitschweifiger": "weitschweifig",
    "weitschweifigere": "weitschweifig",
    "weitschweifigerem": "weitschweifig",
    "weitschweifigeren": "weitschweifig",
    "weitschweifigerer": "weitschweifig",
    "weitschweifigeres": "weitschweifig",
    "weitschweifiges": "weitschweifig",
    "weitschweifigste": "weitschweifig",
    "weitschweifigstem": "weitschweifig",
    "weitschweifigsten": "weitschweifig",
    "weitschweifigster": "weitschweifig",
    "weitschweifigstes": "weitschweifig",
    "weitsichtige": "weitsichtig",
    "weitsichtigem": "weitsichtig",
    "weitsichtigen": "weitsichtig",
    "weitsichtiger": "weitsichtig",
    "weitsichtigere": "weitsichtig",
    "weitsichtigerem": "weitsichtig",
    "weitsichtigeren": "weitsichtig",
    "weitsichtigerer": "weitsichtig",
    "weitsichtigeres": "weitsichtig",
    "weitsichtiges": "weitsichtig",
    "weitsichtigste": "weitsichtig",
    "weitsichtigstem": "weitsichtig",
    "weitsichtigsten": "weitsichtig",
    "weitsichtigster": "weitsichtig",
    "weitsichtigstes": "weitsichtig",
    "weitverbreitetem": "weitverbreitet",
    "weitverbreiteten": "weitverbreitet",
    "weitverbreiteter": "weitverbreitet",
    "weitverbreitetere": "weitverbreitet",
    "weitverbreiteterem": "weitverbreitet",
    "weitverbreiteteren": "weitverbreitet",
    "weitverbreiteterer": "weitverbreitet",
    "weitverbreiteteres": "weitverbreitet",
    "weitverbreitetes": "weitverbreitet",
    "weitverbreitetste": "weitverbreitet",
    "weitverbreitetstem": "weitverbreitet",
    "weitverbreitetsten": "weitverbreitet",
    "weitverbreitetster": "weitverbreitet",
    "weitverbreitetstes": "weitverbreitet",
    "weitverzweigte": "weitverzweigt",
    "weitverzweigtem": "weitverzweigt",
    "weitverzweigten": "weitverzweigt",
    "weitverzweigter": "weitverzweigt",
    "weitverzweigtere": "weitverzweigt",
    "weitverzweigterem": "weitverzweigt",
    "weitverzweigteren": "weitverzweigt",
    "weitverzweigterer": "weitverzweigt",
    "weitverzweigteres": "weitverzweigt",
    "weitverzweigtes": "weitverzweigt",
    "weitverzweigteste": "weitverzweigt",
    "weitverzweigtestem": "weitverzweigt",
    "weitverzweigtesten": "weitverzweigt",
    "weitverzweigtester": "weitverzweigt",
    "weitverzweigtestes": "weitverzweigt",
    "weißem": "weiß",
    "weißen": "weiß",
    "weißer": "weiß",
    "weißere": "weiß",
    "weißerem": "weiß",
    "weißeren": "weiß",
    "weißerer": "weiß",
    "weißeres": "weiß",
    "weißes": "weiß",
    "weißestem": "weiß",
    "weißesten": "weiß",
    "weißester": "weiß",
    "weißestes": "weiß",
    "weißt": "wissen",
    "welche": "welch",
    "welchem": "welch",
    "welchen": "welch",
    "welcher": "welch",
    "welches": "welch",
    "welke": "welken",
    "welkend": "welken",
    "welkende": "welkend",
    "welkendem": "welkend",
    "welkenden": "welkend",
    "welkender": "welkend",
    "welkendere": "welkend",
    "welkenderem": "welkend",
    "welkenderen": "welkend",
    "welkenderer": "welkend",
    "welkenderes": "welkend",
    "welkendes": "welkend",
    "welkendste": "welkend",
    "welkendstem": "welkend",
    "welkendsten": "welkend",
    "welkendster": "welkend",
    "welkendstes": "welkend",
    "welkest": "welken",
    "welket": "welken",
    "welkst": "welken",
    "welkt": "welken",
    "welkte": "welken",
    "welkten": "welken",
    "welktest": "welken",
    "welktet": "welken",
    "welle": "wellen",
    "wellend": "wellen",
    "wellende": "wellend",
    "wellendem": "wellend",
    "wellenden": "wellend",
    "wellender": "wellend",
    "wellendere": "wellend",
    "wellenderem": "wellend",
    "wellenderen": "wellend",
    "wellenderer": "wellend",
    "wellenderes": "wellend",
    "wellendes": "wellend",
    "wellendste": "wellend",
    "wellendstem": "wellend",
    "wellendsten": "wellend",
    "wellendster": "wellend",
    "wellendstes": "wellend",
    "wellest": "wellen",
    "wellet": "wellen",
    "wellige": "wellig",
    "welligem": "wellig",
    "welligen": "wellig",
    "welliger": "wellig",
    "welligere": "wellig",
    "welligerem": "wellig",
    "welligeren": "wellig",
    "welligerer": "wellig",
    "welligeres": "wellig",
    "welliges": "wellig",
    "welligste": "wellig",
    "welligstem": "wellig",
    "welligsten": "wellig",
    "welligster": "wellig",
    "welligstes": "wellig",
    "wellst": "wellen",
    "wellt": "wellen",
    "wellte": "wellen",
    "wellten": "wellen",
    "welltest": "wellen",
    "welltet": "wellen",
    "weltbekannte": "weltbekannt",
    "weltbekanntem": "weltbekannt",
    "weltbekannten": "weltbekannt",
    "weltbekannter": "weltbekannt",
    "weltbekanntes": "weltbekannt",
    "weltberühmte": "weltberühmt",
    "weltberühmtem": "weltberühmt",
    "weltberühmten": "weltberühmt",
    "weltberühmter": "weltberühmt",
    "weltberühmtes": "weltberühmt",
    "weltbewegende": "weltbewegend",
    "weltbewegendem": "weltbewegend",
    "weltbewegenden": "weltbewegend",
    "weltbewegender": "weltbewegend",
    "weltbewegendes": "weltbewegend",
    "weltbürgerliche": "weltbürgerlich",
    "weltbürgerlichem": "weltbürgerlich",
    "weltbürgerlichen": "weltbürgerlich",
    "weltbürgerlicher": "weltbürgerlich",
    "weltbürgerliches": "weltbürgerlich",
    "weltfremdem": "weltfremd",
    "weltfremden": "weltfremd",
    "weltfremder": "weltfremd",
    "weltfremdere": "weltfremd",
    "weltfremderem": "weltfremd",
    "weltfremderen": "weltfremd",
    "weltfremderer": "weltfremd",
    "weltfremderes": "weltfremd",
    "weltfremdes": "weltfremd",
    "weltfremdeste": "weltfremd",
    "weltfremdestem": "weltfremd",
    "weltfremdesten": "weltfremd",
    "weltfremdester": "weltfremd",
    "weltfremdestes": "weltfremd",
    "weltgeschichtliche": "weltgeschichtlich",
    "weltgeschichtlichem": "weltgeschichtlich",
    "weltgeschichtlichen": "weltgeschichtlich",
    "weltgeschichtlicher": "weltgeschichtlich",
    "weltgeschichtliches": "weltgeschichtlich",
    "weltgewandte": "weltgewandt",
    "weltgewandtem": "weltgewandt",
    "weltgewandten": "weltgewandt",
    "weltgewandter": "weltgewandt",
    "weltgewandtes": "weltgewandt",
    "weltklugem": "weltklug",
    "weltklugen": "weltklug",
    "weltkluger": "weltklug",
    "weltkluges": "weltklug",
    "weltliche": "weltlich",
    "weltlichem": "weltlich",
    "weltlichen": "weltlich",
    "weltlicher": "weltlich",
    "weltlichere": "weltlich",
    "weltlicherem": "weltlich",
    "weltlicheren": "weltlich",
    "weltlicherer": "weltlich",
    "weltlicheres": "weltlich",
    "weltliches": "weltlich",
    "weltlichste": "weltlich",
    "weltlichstem": "weltlich",
    "weltlichsten": "weltlich",
    "weltlichster": "weltlich",
    "weltlichstes": "weltlich",
    "weltmännische": "weltmännisch",
    "weltmännischem": "weltmännisch",
    "weltmännischen": "weltmännisch",
    "weltmännischer": "weltmännisch",
    "weltmännischere": "weltmännisch",
    "weltmännischerem": "weltmännisch",
    "weltmännischeren": "weltmännisch",
    "weltmännischerer": "weltmännisch",
    "weltmännischeres": "weltmännisch",
    "weltmännisches": "weltmännisch",
    "weltmännischste": "weltmännisch",
    "weltmännischstem": "weltmännisch",
    "weltmännischsten": "weltmännisch",
    "weltmännischster": "weltmännisch",
    "weltmännischstes": "weltmännisch",
    "weltweitem": "weltweit",
    "weltweiten": "weltweit",
    "weltweiter": "weltweit",
    "weltweites": "weltweit",
    "wem": "wer",
    "wen": "wer",
    "wende": "wenden",
    "wendend": "wenden",
    "wendende": "wendend",
    "wendendem": "wendend",
    "wendenden": "wendend",
    "wendender": "wendend",
    "wendendes": "wendend",
    "wendest": "wenden",
    "wendet": "wenden",
    "wendete": "wenden",
    "wendeten": "wenden",
    "wendetest": "wenden",
    "wendetet": "wenden",
    "wendige": "wendig",
    "wendigem": "wendig",
    "wendigen": "wendig",
    "wendiger": "wendig",
    "wendigere": "wendig",
    "wendigerem": "wendig",
    "wendigeren": "wendig",
    "wendigerer": "wendig",
    "wendigeres": "wendig",
    "wendiges": "wendig",
    "wendigstem": "wendig",
    "wendigsten": "wendig",
    "wendigster": "wendig",
    "wendigstes": "wendig",
    "wenige": "wenig",
    "wenigem": "wenig",
    "wenigen": "wenig",
    "weniger": "wenig",
    "wenigere": "wenig",
    "wenigerem": "wenig",
    "wenigeren": "wenig",
    "wenigerer": "wenig",
    "wenigeres": "wenig",
    "weniges": "wenig",
    "wenigste": "wenig",
    "wenigstem": "wenig",
    "wenigsten": "wenig",
    "wenigster": "wenig",
    "wenigstes": "wenig",
    "werbe": "werben",
    "werbend": "werben",
    "werbende": "werbend",
    "werbendem": "werbend",
    "werbenden": "werbend",
    "werbender": "werbend",
    "werbendes": "werbend",
    "werbest": "werben",
    "werbet": "werben",
    "werbewirksamem": "werbewirksam",
    "werbewirksamen": "werbewirksam",
    "werbewirksamer": "werbewirksam",
    "werbewirksamere": "werbewirksam",
    "werbewirksamerem": "werbewirksam",
    "werbewirksameren": "werbewirksam",
    "werbewirksamerer": "werbewirksam",
    "werbewirksameres": "werbewirksam",
    "werbewirksames": "werbewirksam",
    "werbewirksamste": "werbewirksam",
    "werbewirksamstem": "werbewirksam",
    "werbewirksamsten": "werbewirksam",
    "werbewirksamster": "werbewirksam",
    "werbewirksamstes": "werbewirksam",
    "werbt": "werben",
    "werde": "werden",
    "werdend": "werden",
    "werdest": "werden",
    "werdet": "werden",
    "werfe": "werfen",
    "werfend": "werfen",
    "werfende": "werfend",
    "werfendem": "werfend",
    "werfenden": "werfend",
    "werfender": "werfend",
    "werfendes": "werfend",
    "werfest": "werfen",
    "werfet": "werfen",
    "werft": "werfen",
    "werkele": "werkeln",
    "werkelnd": "werkeln",
    "werkelnde": "werkelnd",
    "werkelndem": "werkelnd",
    "werkelnden": "werkelnd",
    "werkelnder": "werkelnd",
    "werkelndere": "werkelnd",
    "werkelnderem": "werkelnd",
    "werkelnderen": "werkelnd",
    "werkelnderer": "werkelnd",
    "werkelnderes": "werkelnd",
    "werkelndes": "werkelnd",
    "werkelndste": "werkelnd",
    "werkelndstem": "werkelnd",
    "werkelndsten": "werkelnd",
    "werkelndster": "werkelnd",
    "werkelndstes": "werkelnd",
    "werkelst": "werkeln",
    "werkelt": "werkeln",
    "werkelte": "werkeln",
    "werkelten": "werkeln",
    "werkeltest": "werkeln",
    "werkeltet": "werkeln",
    "werkend": "werken",
    "werkende": "werkend",
    "werkendem": "werkend",
    "werkenden": "werkend",
    "werkender": "werkend",
    "werkendes": "werkend",
    "werkest": "werken",
    "werket": "werken",
    "werkle": "werkeln",
    "werkseigenem": "werkseigen",
    "werkseigenen": "werkseigen",
    "werkseigener": "werkseigen",
    "werkseigenes": "werkseigen",
    "werkst": "werken",
    "werkt": "werken",
    "werkte": "werken",
    "werkten": "werken",
    "werktest": "werken",
    "werktet": "werken",
    "werktägliche": "werktäglich",
    "werktäglichem": "werktäglich",
    "werktäglichen": "werktäglich",
    "werktäglicher": "werktäglich",
    "werktägliches": "werktäglich",
    "wertbeständigem": "wertbeständig",
    "wertbeständigen": "wertbeständig",
    "wertbeständiger": "wertbeständig",
    "wertbeständigere": "wertbeständig",
    "wertbeständigerem": "wertbeständig",
    "wertbeständigeren": "wertbeständig",
    "wertbeständigerer": "wertbeständig",
    "wertbeständigeres": "wertbeständig",
    "wertbeständiges": "wertbeständig",
    "wertbeständigste": "wertbeständig",
    "wertbeständigstem": "wertbeständig",
    "wertbeständigsten": "wertbeständig",
    "wertbeständigster": "wertbeständig",
    "wertbeständigstes": "wertbeständig",
    "wertend": "werten",
    "wertende": "wertend",
    "wertendem": "wertend",
    "wertenden": "wertend",
    "wertender": "wertend",
    "wertendes": "wertend",
    "wertest": "werten",
    "wertet": "werten",
    "wertete": "werten",
    "werteten": "werten",
    "wertetest": "werten",
    "wertetet": "werten",
    "wertfreie": "wertfrei",
    "wertfreiem": "wertfrei",
    "wertfreien": "wertfrei",
    "wertfreier": "wertfrei",
    "wertfreiere": "wertfrei",
    "wertfreierem": "wertfrei",
    "wertfreieren": "wertfrei",
    "wertfreierer": "wertfrei",
    "wertfreieres": "wertfrei",
    "wertfreies": "wertfrei",
    "wertfreieste": "wertfrei",
    "wertfreiestem": "wertfrei",
    "wertfreiesten": "wertfrei",
    "wertfreiester": "wertfrei",
    "wertfreiestes": "wertfrei",
    "wertlose": "wertlos",
    "wertlosem": "wertlos",
    "wertlosen": "wertlos",
    "wertloser": "wertlos",
    "wertlosere": "wertlos",
    "wertloserem": "wertlos",
    "wertloseren": "wertlos",
    "wertloserer": "wertlos",
    "wertloseres": "wertlos",
    "wertloses": "wertlos",
    "wertloseste": "wertlos",
    "wertlosestem": "wertlos",
    "wertlosesten": "wertlos",
    "wertlosester": "wertlos",
    "wertlosestes": "wertlos",
    "wertvollem": "wertvoll",
    "wertvollen": "wertvoll",
    "wertvoller": "wertvoll",
    "wertvollere": "wertvoll",
    "wertvollerem": "wertvoll",
    "wertvolleren": "wertvoll",
    "wertvollerer": "wertvoll",
    "wertvolleres": "wertvoll",
    "wertvolles": "wertvoll",
    "wertvollste": "wertvoll",
    "wertvollstem": "wertvoll",
    "wertvollsten": "wertvoll",
    "wertvollster": "wertvoll",
    "wertvollstes": "wertvoll",
    "wesensfremdem": "wesensfremd",
    "wesensfremden": "wesensfremd",
    "wesensfremder": "wesensfremd",
    "wesensfremdes": "wesensfremd",
    "wesentliche": "wesentlich",
    "wesentlichem": "wesentlich",
    "wesentlichen": "wesentlich",
    "wesentlicher": "wesentlich",
    "wesentlichere": "wesentlich",
    "wesentlicherem": "wesentlich",
    "wesentlicheren": "wesentlich",
    "wesentlicherer": "wesentlich",
    "wesentlicheres": "wesentlich",
    "wesentliches": "wesentlich",
    "wesentlichste": "wesentlich",
    "wesentlichstem": "wesentlich",
    "wesentlichsten": "wesentlich",
    "wesentlichster": "wesentlich",
    "wesentlichstes": "wesentlich",
    "wessen": "wer",
    "westdeutsche": "westdeutsch",
    "westdeutschem": "westdeutsch",
    "westdeutschen": "westdeutsch",
    "westdeutscher": "westdeutsch",
    "westdeutsches": "westdeutsch",
    "westeuropäischem": "westeuropäisch",
    "westeuropäischen": "westeuropäisch",
    "westeuropäischer": "westeuropäisch",
    "westeuropäisches": "westeuropäisch",
    "westfälischem": "westfälisch",
    "westfälischen": "westfälisch",
    "westfälischer": "westfälisch",
    "westfälischere": "westfälisch",
    "westfälischerem": "westfälisch",
    "westfälischeren": "westfälisch",
    "westfälischerer": "westfälisch",
    "westfälischeres": "westfälisch",
    "westfälisches": "westfälisch",
    "westfälischste": "westfälisch",
    "westfälischstem": "westfälisch",
    "westfälischsten": "westfälisch",
    "westfälischster": "westfälisch",
    "westfälischstes": "westfälisch",
    "westlichem": "westlich",
    "westlichen": "westlich",
    "westlicher": "westlich",
    "westlichere": "westlich",
    "westlicherem": "westlich",
    "westlicheren": "westlich",
    "westlicherer": "westlich",
    "westlicheres": "westlich",
    "westliches": "westlich",
    "westlichste": "westlich",
    "westlichstem": "westlich",
    "westlichsten": "westlich",
    "westlichster": "westlich",
    "westlichstes": "westlich",
    "wettend": "wetten",
    "wettende": "wettend",
    "wettendem": "wettend",
    "wettenden": "wettend",
    "wettender": "wettend",
    "wettendere": "wettend",
    "wettenderem": "wettend",
    "wettenderen": "wettend",
    "wettenderer": "wettend",
    "wettenderes": "wettend",
    "wettendes": "wettend",
    "wettendste": "wettend",
    "wettendstem": "wettend",
    "wettendsten": "wettend",
    "wettendster": "wettend",
    "wettendstes": "wettend",
    "wetterbeständigem": "wetterbeständig",
    "wetterbeständigen": "wetterbeständig",
    "wetterbeständiger": "wetterbeständig",
    "wetterbeständigere": "wetterbeständig",
    "wetterbeständigerem": "wetterbeständig",
    "wetterbeständigeren": "wetterbeständig",
    "wetterbeständigerer": "wetterbeständig",
    "wetterbeständigeres": "wetterbeständig",
    "wetterbeständiges": "wetterbeständig",
    "wetterbeständigste": "wetterbeständig",
    "wetterbeständigstem": "wetterbeständig",
    "wetterbeständigsten": "wetterbeständig",
    "wetterbeständigster": "wetterbeständig",
    "wetterbeständigstes": "wetterbeständig",
    "wettere": "wettern",
    "wetterfeste": "wetterfest",
    "wetterfestem": "wetterfest",
    "wetterfesten": "wetterfest",
    "wetterfester": "wetterfest",
    "wetterfestere": "wetterfest",
    "wetterfesterem": "wetterfest",
    "wetterfesteren": "wetterfest",
    "wetterfesterer": "wetterfest",
    "wetterfesteres": "wetterfest",
    "wetterfestes": "wetterfest",
    "wetterfesteste": "wetterfest",
    "wetterfestestem": "wetterfest",
    "wetterfestesten": "wetterfest",
    "wetterfestester": "wetterfest",
    "wetterfestestes": "wetterfest",
    "wetterfühlige": "wetterfühlig",
    "wetterfühligem": "wetterfühlig",
    "wetterfühligen": "wetterfühlig",
    "wetterfühliger": "wetterfühlig",
    "wetterfühligere": "wetterfühlig",
    "wetterfühligerem": "wetterfühlig",
    "wetterfühligeren": "wetterfühlig",
    "wetterfühligerer": "wetterfühlig",
    "wetterfühligeres": "wetterfühlig",
    "wetterfühliges": "wetterfühlig",
    "wetterfühligste": "wetterfühlig",
    "wetterfühligstem": "wetterfühlig",
    "wetterfühligsten": "wetterfühlig",
    "wetterfühligster": "wetterfühlig",
    "wetterfühligstes": "wetterfühlig",
    "wetternd": "wettern",
    "wetternde": "wetternd",
    "wetterndem": "wetternd",
    "wetternden": "wetternd",
    "wetternder": "wetternd",
    "wetterndere": "wetternd",
    "wetternderem": "wetternd",
    "wetternderen": "wetternd",
    "wetternderer": "wetternd",
    "wetternderes": "wetternd",
    "wetterndes": "wetternd",
    "wetterndste": "wetternd",
    "wetterndstem": "wetternd",
    "wetterndsten": "wetternd",
    "wetterndster": "wetternd",
    "wetterndstes": "wetternd",
    "wetterst": "wettern",
    "wettert": "wettern",
    "wetterte": "wettern",
    "wetterten": "wettern",
    "wettertest": "wettern",
    "wettertet": "wettern",
    "wettest": "wetten",
    "wettet": "wetten",
    "wettete": "wetten",
    "wetteten": "wetten",
    "wettetest": "wetten",
    "wettetet": "wetten",
    "wettgemacht": "wettmachen",
    "wettgemachte": "wettgemacht",
    "wettgemachtem": "wettgemacht",
    "wettgemachten": "wettgemacht",
    "wettgemachter": "wettgemacht",
    "wettgemachtes": "wettgemacht",
    "wettmache": "wettmachen",
    "wettmachend": "wettmachen",
    "wettmachende": "wettmachend",
    "wettmachendem": "wettmachend",
    "wettmachenden": "wettmachend",
    "wettmachender": "wettmachend",
    "wettmachendes": "wettmachend",
    "wettmachest": "wettmachen",
    "wettmachet": "wettmachen",
    "wettmachst": "wettmachen",
    "wettmacht": "wettmachen",
    "wettmachte": "wettmachen",
    "wettmachten": "wettmachen",
    "wettmachtest": "wettmachen",
    "wettmachtet": "wettmachen",
    "wettzumachen": "wettmachen",
    "wetze": "wetzen",
    "wetzend": "wetzen",
    "wetzende": "wetzend",
    "wetzendem": "wetzend",
    "wetzenden": "wetzend",
    "wetzender": "wetzend",
    "wetzendes": "wetzend",
    "wetzest": "wetzen",
    "wetzet": "wetzen",
    "wetzt": "wetzen",
    "wetzte": "wetzen",
    "wetzten": "wetzen",
    "wetztest": "wetzen",
    "wetztet": "wetzen",
    "wich": "weichen",
    "wiche": "weichen",
    "wichen": "weichen",
    "wichest": "weichen",
    "wichet": "weichen",
    "wichst": "weichen",
    "wicht": "weichen",
    "wichtele": "wichteln",
    "wichtelnd": "wichteln",
    "wichtelnde": "wichtelnd",
    "wichtelndem": "wichtelnd",
    "wichtelnden": "wichtelnd",
    "wichtelnder": "wichtelnd",
    "wichtelndere": "wichtelnd",
    "wichtelnderem": "wichtelnd",
    "wichtelnderen": "wichtelnd",
    "wichtelnderer": "wichtelnd",
    "wichtelnderes": "wichtelnd",
    "wichtelndes": "wichtelnd",
    "wichtelndste": "wichtelnd",
    "wichtelndstem": "wichtelnd",
    "wichtelndsten": "wichtelnd",
    "wichtelndster": "wichtelnd",
    "wichtelndstes": "wichtelnd",
    "wichtelst": "wichteln",
    "wichtelt": "wichteln",
    "wichtelte": "wichteln",
    "wichtelten": "wichteln",
    "wichteltest": "wichteln",
    "wichteltet": "wichteln",
    "wichtige": "wichtig",
    "wichtigem": "wichtig",
    "wichtigen": "wichtig",
    "wichtiger": "wichtig",
    "wichtigere": "wichtig",
    "wichtigerem": "wichtig",
    "wichtigeren": "wichtig",
    "wichtigerer": "wichtig",
    "wichtigeres": "wichtig",
    "wichtiges": "wichtig",
    "wichtigstem": "wichtig",
    "wichtigsten": "wichtig",
    "wichtigster": "wichtig",
    "wichtigstes": "wichtig",
    "wichtle": "wichteln",
    "wickele": "wickeln",
    "wickelnd": "wickeln",
    "wickelnde": "wickelnd",
    "wickelndem": "wickelnd",
    "wickelnden": "wickelnd",
    "wickelnder": "wickelnd",
    "wickelndes": "wickelnd",
    "wickelst": "wickeln",
    "wickelt": "wickeln",
    "wickelte": "wickeln",
    "wickelten": "wickeln",
    "wickeltest": "wickeln",
    "wickeltet": "wickeln",
    "wickle": "wickeln",
    "wider": "widern",
    "widere": "widern",
    "widerfahre": "widerfahren",
    "widerfahrend": "widerfahren",
    "widerfahrende": "widerfahrend",
    "widerfahrendem": "widerfahrend",
    "widerfahrenden": "widerfahrend",
    "widerfahrender": "widerfahrend",
    "widerfahrendes": "widerfahrend",
    "widerfahrene": "widerfahren",
    "widerfahrenem": "widerfahren",
    "widerfahrenen": "widerfahren",
    "widerfahrener": "widerfahren",
    "widerfahrenes": "widerfahren",
    "widerfahrest": "widerfahren",
    "widerfahret": "widerfahren",
    "widerfahrt": "widerfahren",
    "widerfuhr": "widerfahren",
    "widerfuhren": "widerfahren",
    "widerfuhrst": "widerfahren",
    "widerfuhrt": "widerfahren",
    "widerfährst": "widerfahren",
    "widerfährt": "widerfahren",
    "widerführe": "widerfahren",
    "widerführen": "widerfahren",
    "widerführest": "widerfahren",
    "widerführet": "widerfahren",
    "widergehallt": "widerhallen",
    "widergehallte": "widergehallt",
    "widergehalltem": "widergehallt",
    "widergehallten": "widergehallt",
    "widergehallter": "widergehallt",
    "widergehalltes": "widergehallt",
    "widergeklungen": "widerklingen",
    "widergeklungene": "widergeklungen",
    "widergeklungenem": "widergeklungen",
    "widergeklungenen": "widergeklungen",
    "widergeklungener": "widergeklungen",
    "widergeklungenes": "widergeklungen",
    "widergeschienen": "widerscheinen",
    "widergeschienene": "widergeschienen",
    "widergeschienenem": "widergeschienen",
    "widergeschienenen": "widergeschienen",
    "widergeschienener": "widergeschienen",
    "widergeschienenes": "widergeschienen",
    "widergespiegelt": "widerspiegeln",
    "widergespiegelte": "widergespiegelt",
    "widergespiegeltem": "widergespiegelt",
    "widergespiegelten": "widergespiegelt",
    "widergespiegelter": "widergespiegelt",
    "widergespiegeltes": "widergespiegelt",
    "widerhalle": "widerhallen",
    "widerhallend": "widerhallen",
    "widerhallende": "widerhallend",
    "widerhallendem": "widerhallend",
    "widerhallenden": "widerhallend",
    "widerhallender": "widerhallend",
    "widerhallendere": "widerhallend",
    "widerhallenderem": "widerhallend",
    "widerhallenderen": "widerhallend",
    "widerhallenderer": "widerhallend",
    "widerhallenderes": "widerhallend",
    "widerhallendes": "widerhallend",
    "widerhallendste": "widerhallend",
    "widerhallendstem": "widerhallend",
    "widerhallendsten": "widerhallend",
    "widerhallendster": "widerhallend",
    "widerhallendstes": "widerhallend",
    "widerhallest": "widerhallen",
    "widerhallet": "widerhallen",
    "widerhallst": "widerhallen",
    "widerhallt": "widerhallen",
    "widerhallte": "widerhallen",
    "widerhallten": "widerhallen",
    "widerhalltest": "widerhallen",
    "widerhalltet": "widerhallen",
    "widerklang": "widerklingen",
    "widerklangen": "widerklingen",
    "widerklangst": "widerklingen",
    "widerklangt": "widerklingen",
    "widerklinge": "widerklingen",
    "widerklingend": "widerklingen",
    "widerklingende": "widerklingend",
    "widerklingendem": "widerklingend",
    "widerklingenden": "widerklingend",
    "widerklingender": "widerklingend",
    "widerklingendes": "widerklingend",
    "widerklingest": "widerklingen",
    "widerklinget": "widerklingen",
    "widerklingst": "widerklingen",
    "widerklingt": "widerklingen",
    "widerklänge": "widerklingen",
    "widerklängen": "widerklingen",
    "widerklängest": "widerklingen",
    "widerklänget": "widerklingen",
    "widerlegbare": "widerlegbar",
    "widerlegbarem": "widerlegbar",
    "widerlegbaren": "widerlegbar",
    "widerlegbarer": "widerlegbar",
    "widerlegbares": "widerlegbar",
    "widerlege": "widerlegen",
    "widerlegend": "widerlegen",
    "widerlegende": "widerlegend",
    "widerlegendem": "widerlegend",
    "widerlegenden": "widerlegend",
    "widerlegender": "widerlegend",
    "widerlegendes": "widerlegend",
    "widerlegest": "widerlegen",
    "widerleget": "widerlegen",
    "widerlegst": "widerlegen",
    "widerlegt": "widerlegen",
    "widerlegte": "widerlegen",
    "widerlegtem": "widerlegt",
    "widerlegten": "widerlegen",
    "widerlegter": "widerlegt",
    "widerlegtere": "widerlegt",
    "widerlegterem": "widerlegt",
    "widerlegteren": "widerlegt",
    "widerlegterer": "widerlegt",
    "widerlegteres": "widerlegt",
    "widerlegtes": "widerlegt",
    "widerlegtest": "widerlegen",
    "widerlegteste": "widerlegt",
    "widerlegtestem": "widerlegt",
    "widerlegtesten": "widerlegt",
    "widerlegtester": "widerlegt",
    "widerlegtestes": "widerlegt",
    "widerlegtet": "widerlegen",
    "widerlichem": "widerlich",
    "widerlichen": "widerlich",
    "widerlicher": "widerlich",
    "widerlichere": "widerlich",
    "widerlicherem": "widerlich",
    "widerlicheren": "widerlich",
    "widerlicherer": "widerlich",
    "widerlicheres": "widerlich",
    "widerliches": "widerlich",
    "widerlichste": "widerlich",
    "widerlichstem": "widerlich",
    "widerlichsten": "widerlich",
    "widerlichster": "widerlich",
    "widerlichstes": "widerlich",
    "widernd": "widern",
    "widernde": "widernd",
    "widerndem": "widernd",
    "widernden": "widernd",
    "widernder": "widernd",
    "widerndes": "widernd",
    "widerrechtlichem": "widerrechtlich",
    "widerrechtlichen": "widerrechtlich",
    "widerrechtlicher": "widerrechtlich",
    "widerrechtliches": "widerrechtlich",
    "widerrief": "widerrufen",
    "widerriefe": "widerrufen",
    "widerriefen": "widerrufen",
    "widerriefest": "widerrufen",
    "widerriefet": "widerrufen",
    "widerriefst": "widerrufen",
    "widerrieft": "widerrufen",
    "widerrufend": "widerrufen",
    "widerrufende": "widerrufend",
    "widerrufendem": "widerrufend",
    "widerrufenden": "widerrufend",
    "widerrufender": "widerrufend",
    "widerrufendes": "widerrufend",
    "widerrufene": "widerrufen",
    "widerrufenem": "widerrufen",
    "widerrufenen": "widerrufen",
    "widerrufener": "widerrufen",
    "widerrufenes": "widerrufen",
    "widerrufest": "widerrufen",
    "widerrufet": "widerrufen",
    "widerrufliche": "widerruflich",
    "widerruflichem": "widerruflich",
    "widerruflichen": "widerruflich",
    "widerruflicher": "widerruflich",
    "widerrufliches": "widerruflich",
    "widerrufst": "widerrufen",
    "widerruft": "widerrufen",
    "widerscheinend": "widerscheinen",
    "widerscheinende": "widerscheinend",
    "widerscheinendem": "widerscheinend",
    "widerscheinenden": "widerscheinend",
    "widerscheinender": "widerscheinend",
    "widerscheinendes": "widerscheinend",
    "widerscheinest": "widerscheinen",
    "widerscheinet": "widerscheinen",
    "widerscheinst": "widerscheinen",
    "widerscheint": "widerscheinen",
    "widerschien": "widerscheinen",
    "widerschiene": "widerscheinen",
    "widerschienen": "widerscheinen",
    "widerschienest": "widerscheinen",
    "widerschienet": "widerscheinen",
    "widerschienst": "widerscheinen",
    "widerschient": "widerscheinen",
    "widersetze": "widersetzen",
    "widersetzend": "widersetzen",
    "widersetzende": "widersetzend",
    "widersetzendem": "widersetzend",
    "widersetzenden": "widersetzend",
    "widersetzender": "widersetzend",
    "widersetzendes": "widersetzend",
    "widersetzest": "widersetzen",
    "widersetzet": "widersetzen",
    "widersetzt": "widersetzen",
    "widersetzte": "widersetzen",
    "widersetztem": "widersetzt",
    "widersetzten": "widersetzen",
    "widersetzter": "widersetzt",
    "widersetztes": "widersetzt",
    "widersetztest": "widersetzen",
    "widersetztet": "widersetzen",
    "widersinnige": "widersinnig",
    "widersinnigem": "widersinnig",
    "widersinnigen": "widersinnig",
    "widersinniger": "widersinnig",
    "widersinnigere": "widersinnig",
    "widersinnigerem": "widersinnig",
    "widersinnigeren": "widersinnig",
    "widersinnigerer": "widersinnig",
    "widersinnigeres": "widersinnig",
    "widersinniges": "widersinnig",
    "widersinnigste": "widersinnig",
    "widersinnigstem": "widersinnig",
    "widersinnigsten": "widersinnig",
    "widersinnigster": "widersinnig",
    "widersinnigstes": "widersinnig",
    "widerspenstigem": "widerspenstig",
    "widerspenstigen": "widerspenstig",
    "widerspenstiger": "widerspenstig",
    "widerspenstigere": "widerspenstig",
    "widerspenstigerem": "widerspenstig",
    "widerspenstigeren": "widerspenstig",
    "widerspenstigerer": "widerspenstig",
    "widerspenstigeres": "widerspenstig",
    "widerspenstiges": "widerspenstig",
    "widerspenstigste": "widerspenstig",
    "widerspenstigstem": "widerspenstig",
    "widerspenstigsten": "widerspenstig",
    "widerspenstigster": "widerspenstig",
    "widerspenstigstes": "widerspenstig",
    "widerspiegele": "widerspiegeln",
    "widerspiegelnd": "widerspiegeln",
    "widerspiegelnde": "widerspiegelnd",
    "widerspiegelndem": "widerspiegelnd",
    "widerspiegelnden": "widerspiegelnd",
    "widerspiegelnder": "widerspiegelnd",
    "widerspiegelndes": "widerspiegelnd",
    "widerspiegelst": "widerspiegeln",
    "widerspiegelt": "widerspiegeln",
    "widerspiegelte": "widerspiegeln",
    "widerspiegelten": "widerspiegeln",
    "widerspiegeltest": "widerspiegeln",
    "widerspiegeltet": "widerspiegeln",
    "widerspiegle": "widerspiegeln",
    "widersprach": "widersprechen",
    "widersprachen": "widersprechen",
    "widersprachst": "widersprechen",
    "widerspracht": "widersprechen",
    "widerspreche": "widersprechen",
    "widersprechend": "widersprechen",
    "widersprechende": "widersprechend",
    "widersprechendem": "widersprechend",
    "widersprechenden": "widersprechend",
    "widersprechender": "widersprechend",
    "widersprechendere": "widersprechend",
    "widersprechenderem": "widersprechend",
    "widersprechenderen": "widersprechend",
    "widersprechenderer": "widersprechend",
    "widersprechenderes": "widersprechend",
    "widersprechendes": "widersprechend",
    "widersprechendste": "widersprechend",
    "widersprechendstem": "widersprechend",
    "widersprechendsten": "widersprechend",
    "widersprechendster": "widersprechend",
    "widersprechendstes": "widersprechend",
    "widersprechest": "widersprechen",
    "widersprechet": "widersprechen",
    "widersprecht": "widersprechen",
    "widersprich": "widersprechen",
    "widersprichst": "widersprechen",
    "widerspricht": "widersprechen",
    "widersprochen": "widersprechen",
    "widersprochene": "widersprochen",
    "widersprochenem": "widersprochen",
    "widersprochenen": "widersprochen",
    "widersprochener": "widersprochen",
    "widersprochenes": "widersprochen",
    "widerspruchslosem": "widerspruchslos",
    "widerspruchslosen": "widerspruchslos",
    "widerspruchsloser": "widerspruchslos",
    "widerspruchsloses": "widerspruchslos",
    "widerspräche": "widersprechen",
    "widersprächen": "widersprechen",
    "widersprächest": "widersprechen",
    "widersprächet": "widersprechen",
    "widersprüchlichem": "widersprüchlich",
    "widersprüchlichen": "widersprüchlich",
    "widersprüchlicher": "widersprüchlich",
    "widersprüchlichere": "widersprüchlich",
    "widersprüchlicherem": "widersprüchlich",
    "widersprüchlicheren": "widersprüchlich",
    "widersprüchlicherer": "widersprüchlich",
    "widersprüchlicheres": "widersprüchlich",
    "widersprüchliches": "widersprüchlich",
    "widersprüchlichste": "widersprüchlich",
    "widersprüchlichstem": "widersprüchlich",
    "widersprüchlichsten": "widersprüchlich",
    "widersprüchlichster": "widersprüchlich",
    "widersprüchlichstes": "widersprüchlich",
    "widerst": "widern",
    "widerstand": "widerstehen",
    "widerstanden": "widerstehen",
    "widerstandenem": "widerstanden",
    "widerstandenen": "widerstanden",
    "widerstandener": "widerstanden",
    "widerstandenere": "widerstanden",
    "widerstandenerem": "widerstanden",
    "widerstandeneren": "widerstanden",
    "widerstandenerer": "widerstanden",
    "widerstandeneres": "widerstanden",
    "widerstandenes": "widerstanden",
    "widerstandenste": "widerstanden",
    "widerstandenstem": "widerstanden",
    "widerstandensten": "widerstanden",
    "widerstandenster": "widerstanden",
    "widerstandenstes": "widerstanden",
    "widerstandest": "widerstehen",
    "widerstandet": "widerstehen",
    "widerstandsfähigem": "widerstandsfähig",
    "widerstandsfähigen": "widerstandsfähig",
    "widerstandsfähiger": "widerstandsfähig",
    "widerstandsfähigere": "widerstandsfähig",
    "widerstandsfähigerem": "widerstandsfähig",
    "widerstandsfähigeren": "widerstandsfähig",
    "widerstandsfähigerer": "widerstandsfähig",
    "widerstandsfähigeres": "widerstandsfähig",
    "widerstandsfähiges": "widerstandsfähig",
    "widerstandsfähigste": "widerstandsfähig",
    "widerstandsfähigstem": "widerstandsfähig",
    "widerstandsfähigsten": "widerstandsfähig",
    "widerstandsfähigster": "widerstandsfähig",
    "widerstandsfähigstes": "widerstandsfähig",
    "widerstandslose": "widerstandslos",
    "widerstandslosem": "widerstandslos",
    "widerstandslosen": "widerstandslos",
    "widerstandsloser": "widerstandslos",
    "widerstandslosere": "widerstandslos",
    "widerstandsloserem": "widerstandslos",
    "widerstandsloseren": "widerstandslos",
    "widerstandsloserer": "widerstandslos",
    "widerstandsloseres": "widerstandslos",
    "widerstandsloses": "widerstandslos",
    "widerstandsloseste": "widerstandslos",
    "widerstandslosestem": "widerstandslos",
    "widerstandslosesten": "widerstandslos",
    "widerstandslosester": "widerstandslos",
    "widerstandslosestes": "widerstandslos",
    "widerstehe": "widerstehen",
    "widerstehend": "widerstehen",
    "widerstehende": "widerstehend",
    "widerstehendem": "widerstehend",
    "widerstehenden": "widerstehend",
    "widerstehender": "widerstehend",
    "widerstehendere": "widerstehend",
    "widerstehenderem": "widerstehend",
    "widerstehenderen": "widerstehend",
    "widerstehenderer": "widerstehend",
    "widerstehenderes": "widerstehend",
    "widerstehendes": "widerstehend",
    "widerstehendste": "widerstehend",
    "widerstehendstem": "widerstehend",
    "widerstehendsten": "widerstehend",
    "widerstehendster": "widerstehend",
    "widerstehendstes": "widerstehend",
    "widerstehest": "widerstehen",
    "widerstehet": "widerstehen",
    "widerstehst": "widerstehen",
    "widersteht": "widerstehen",
    "widerstrebe": "widerstreben",
    "widerstrebend": "widerstreben",
    "widerstrebende": "widerstrebend",
    "widerstrebendem": "widerstrebend",
    "widerstrebenden": "widerstrebend",
    "widerstrebender": "widerstrebend",
    "widerstrebendere": "widerstrebend",
    "widerstrebenderem": "widerstrebend",
    "widerstrebenderen": "widerstrebend",
    "widerstrebenderer": "widerstrebend",
    "widerstrebenderes": "widerstrebend",
    "widerstrebendes": "widerstrebend",
    "widerstrebendste": "widerstrebend",
    "widerstrebendstem": "widerstrebend",
    "widerstrebendsten": "widerstrebend",
    "widerstrebendster": "widerstrebend",
    "widerstrebendstes": "widerstrebend",
    "widerstrebest": "widerstreben",
    "widerstrebet": "widerstreben",
    "widerstrebst": "widerstreben",
    "widerstrebt": "widerstreben",
    "widerstrebte": "widerstreben",
    "widerstrebtem": "widerstrebt",
    "widerstrebten": "widerstreben",
    "widerstrebter": "widerstrebt",
    "widerstrebtes": "widerstrebt",
    "widerstrebtest": "widerstreben",
    "widerstrebtet": "widerstreben",
    "widerstünde": "widerstehen",
    "widerstünden": "widerstehen",
    "widerstündest": "widerstehen",
    "widerstündet": "widerstehen",
    "widert": "widern",
    "widerte": "widern",
    "widerten": "widern",
    "widertest": "widern",
    "widertet": "widern",
    "widerwillige": "widerwillig",
    "widerwilligem": "widerwillig",
    "widerwilligen": "widerwillig",
    "widerwilliger": "widerwillig",
    "widerwilligere": "widerwillig",
    "widerwilligerem": "widerwillig",
    "widerwilligeren": "widerwillig",
    "widerwilligerer": "widerwillig",
    "widerwilligeres": "widerwillig",
    "widerwilliges": "widerwillig",
    "widerwilligste": "widerwillig",
    "widerwilligstem": "widerwillig",
    "widerwilligsten": "widerwillig",
    "widerwilligster": "widerwillig",
    "widerwilligstes": "widerwillig",
    "widerwärtige": "widerwärtig",
    "widerwärtigem": "widerwärtig",
    "widerwärtigen": "widerwärtig",
    "widerwärtiger": "widerwärtig",
    "widerwärtigere": "widerwärtig",
    "widerwärtigerem": "widerwärtig",
    "widerwärtigeren": "widerwärtig",
    "widerwärtigerer": "widerwärtig",
    "widerwärtigeres": "widerwärtig",
    "widerwärtiges": "widerwärtig",
    "widerwärtigstem": "widerwärtig",
    "widerwärtigsten": "widerwärtig",
    "widerwärtigster": "widerwärtig",
    "widerwärtigstes": "widerwärtig",
    "widerzuhallen": "widerhallen",
    "widerzuklingen": "widerklingen",
    "widerzuscheinen": "widerscheinen",
    "widerzuspiegeln": "widerspiegeln",
    "widme": "widmen",
    "widmend": "widmen",
    "widmende": "widmend",
    "widmendem": "widmend",
    "widmenden": "widmend",
    "widmender": "widmend",
    "widmendes": "widmend",
    "widmest": "widmen",
    "widmet": "widmen",
    "widmete": "widmen",
    "widmeten": "widmen",
    "widmetest": "widmen",
    "widmetet": "widmen",
    "widrigem": "widrig",
    "widrigen": "widrig",
    "widriger": "widrig",
    "widriges": "widrig",
    "wiederaufgetaucht": "wiederauftauchen",
    "wiederaufgetauchte": "wiederaufgetaucht",
    "wiederaufgetauchtem": "wiederaufgetaucht",
    "wiederaufgetauchten": "wiederaufgetaucht",
    "wiederaufgetauchter": "wiederaufgetaucht",
    "wiederaufgetauchtes": "wiederaufgetaucht",
    "wiederauftauche": "wiederauftauchen",
    "wiederauftauchend": "wiederauftauchen",
    "wiederauftauchende": "wiederauftauchend",
    "wiederauftauchendem": "wiederauftauchend",
    "wiederauftauchenden": "wiederauftauchend",
    "wiederauftauchender": "wiederauftauchend",
    "wiederauftauchendes": "wiederauftauchend",
    "wiederauftauchest": "wiederauftauchen",
    "wiederauftauchet": "wiederauftauchen",
    "wiederauftauchst": "wiederauftauchen",
    "wiederauftaucht": "wiederauftauchen",
    "wiederauftauchte": "wiederauftauchen",
    "wiederauftauchten": "wiederauftauchen",
    "wiederauftauchtest": "wiederauftauchen",
    "wiederauftauchtet": "wiederauftauchen",
    "wiederaufzutauchen": "wiederauftauchen",
    "wiederbekam": "wiederbekommen",
    "wiederbekamen": "wiederbekommen",
    "wiederbekamst": "wiederbekommen",
    "wiederbekamt": "wiederbekommen",
    "wiederbekomme": "wiederbekommen",
    "wiederbekommend": "wiederbekommen",
    "wiederbekommende": "wiederbekommend",
    "wiederbekommendem": "wiederbekommend",
    "wiederbekommenden": "wiederbekommend",
    "wiederbekommender": "wiederbekommend",
    "wiederbekommendes": "wiederbekommend",
    "wiederbekommene": "wiederbekommen",
    "wiederbekommenem": "wiederbekommen",
    "wiederbekommenen": "wiederbekommen",
    "wiederbekommener": "wiederbekommen",
    "wiederbekommenes": "wiederbekommen",
    "wiederbekommest": "wiederbekommen",
    "wiederbekommet": "wiederbekommen",
    "wiederbekommst": "wiederbekommen",
    "wiederbekommt": "wiederbekommen",
    "wiederbekäme": "wiederbekommen",
    "wiederbekämen": "wiederbekommen",
    "wiederbekämest": "wiederbekommen",
    "wiederbekämet": "wiederbekommen",
    "wiederbelebe": "wiederbeleben",
    "wiederbelebend": "wiederbeleben",
    "wiederbelebende": "wiederbelebend",
    "wiederbelebendem": "wiederbelebend",
    "wiederbelebenden": "wiederbelebend",
    "wiederbelebender": "wiederbelebend",
    "wiederbelebendes": "wiederbelebend",
    "wiederbelebest": "wiederbeleben",
    "wiederbelebet": "wiederbeleben",
    "wiederbelebst": "wiederbeleben",
    "wiederbelebt": "wiederbeleben",
    "wiederbelebte": "wiederbeleben",
    "wiederbelebtem": "wiederbelebt",
    "wiederbelebten": "wiederbeleben",
    "wiederbelebter": "wiederbelebt",
    "wiederbelebtes": "wiederbelebt",
    "wiederbelebtest": "wiederbeleben",
    "wiederbelebtet": "wiederbeleben",
    "wiederbrachte": "wiederbringen",
    "wiederbrachten": "wiederbringen",
    "wiederbrachtest": "wiederbringen",
    "wiederbrachtet": "wiederbringen",
    "wiederbringe": "wiederbringen",
    "wiederbringend": "wiederbringen",
    "wiederbringende": "wiederbringend",
    "wiederbringendem": "wiederbringend",
    "wiederbringenden": "wiederbringend",
    "wiederbringender": "wiederbringend",
    "wiederbringendes": "wiederbringend",
    "wiederbringest": "wiederbringen",
    "wiederbringet": "wiederbringen",
    "wiederbringst": "wiederbringen",
    "wiederbringt": "wiederbringen",
    "wiederbrächte": "wiederbringen",
    "wiederbrächten": "wiederbringen",
    "wiederbrächtest": "wiederbringen",
    "wiederbrächtet": "wiederbringen",
    "wiederergreife": "wiederergreifen",
    "wiederergreifend": "wiederergreifen",
    "wiederergreifende": "wiederergreifend",
    "wiederergreifendem": "wiederergreifend",
    "wiederergreifenden": "wiederergreifend",
    "wiederergreifender": "wiederergreifend",
    "wiederergreifendes": "wiederergreifend",
    "wiederergreifest": "wiederergreifen",
    "wiederergreifet": "wiederergreifen",
    "wiederergreifst": "wiederergreifen",
    "wiederergreift": "wiederergreifen",
    "wiederergriff": "wiederergreifen",
    "wiederergriffe": "wiederergreifen",
    "wiederergriffen": "wiederergreifen",
    "wiederergriffene": "wiederergriffen",
    "wiederergriffenem": "wiederergriffen",
    "wiederergriffenen": "wiederergriffen",
    "wiederergriffener": "wiederergriffen",
    "wiederergriffenes": "wiederergriffen",
    "wiederergriffest": "wiederergreifen",
    "wiederergriffet": "wiederergreifen",
    "wiederergriffst": "wiederergreifen",
    "wiederergrifft": "wiederergreifen",
    "wiedererhalte": "wiedererhalten",
    "wiedererhaltend": "wiedererhalten",
    "wiedererhaltende": "wiedererhaltend",
    "wiedererhaltendem": "wiedererhaltend",
    "wiedererhaltenden": "wiedererhaltend",
    "wiedererhaltender": "wiedererhaltend",
    "wiedererhaltendes": "wiedererhaltend",
    "wiedererhaltene": "wiedererhalten",
    "wiedererhaltenem": "wiedererhalten",
    "wiedererhaltenen": "wiedererhalten",
    "wiedererhaltener": "wiedererhalten",
    "wiedererhaltenes": "wiedererhalten",
    "wiedererhaltest": "wiedererhalten",
    "wiedererhaltet": "wiedererhalten",
    "wiedererhielt": "wiedererhalten",
    "wiedererhielte": "wiedererhalten",
    "wiedererhielten": "wiedererhalten",
    "wiedererhieltest": "wiedererhalten",
    "wiedererhieltet": "wiedererhalten",
    "wiedererhält": "wiedererhalten",
    "wiedererhältst": "wiedererhalten",
    "wiedererkannt": "wiedererkennen",
    "wiedererkannte": "wiedererkannt",
    "wiedererkanntem": "wiedererkannt",
    "wiedererkannten": "wiedererkannt",
    "wiedererkannter": "wiedererkannt",
    "wiedererkanntes": "wiedererkannt",
    "wiedererkanntest": "wiedererkennen",
    "wiedererkanntet": "wiedererkennen",
    "wiedererkenne": "wiedererkennen",
    "wiedererkennend": "wiedererkennen",
    "wiedererkennende": "wiedererkennend",
    "wiedererkennendem": "wiedererkennend",
    "wiedererkennenden": "wiedererkennend",
    "wiedererkennender": "wiedererkennend",
    "wiedererkennendes": "wiedererkennend",
    "wiedererkennest": "wiedererkennen",
    "wiedererkennet": "wiedererkennen",
    "wiedererkennst": "wiedererkennen",
    "wiedererkennt": "wiedererkennen",
    "wiedererlange": "wiedererlangen",
    "wiedererlangend": "wiedererlangen",
    "wiedererlangende": "wiedererlangend",
    "wiedererlangendem": "wiedererlangend",
    "wiedererlangenden": "wiedererlangend",
    "wiedererlangender": "wiedererlangend",
    "wiedererlangendes": "wiedererlangend",
    "wiedererlangest": "wiedererlangen",
    "wiedererlanget": "wiedererlangen",
    "wiedererlangst": "wiedererlangen",
    "wiedererlangt": "wiedererlangen",
    "wiedererlangte": "wiedererlangen",
    "wiedererlangtem": "wiedererlangt",
    "wiedererlangten": "wiedererlangen",
    "wiedererlangter": "wiedererlangt",
    "wiedererlangtes": "wiedererlangt",
    "wiedererlangtest": "wiedererlangen",
    "wiedererlangtet": "wiedererlangen",
    "wiedererstatte": "wiedererstatten",
    "wiedererstattend": "wiedererstatten",
    "wiedererstattende": "wiedererstattend",
    "wiedererstattendem": "wiedererstattend",
    "wiedererstattenden": "wiedererstattend",
    "wiedererstattender": "wiedererstattend",
    "wiedererstattendes": "wiedererstattend",
    "wiedererstattest": "wiedererstatten",
    "wiedererstattet": "wiedererstatten",
    "wiedererstattete": "wiedererstatten",
    "wiedererstattetem": "wiedererstattet",
    "wiedererstatteten": "wiedererstatten",
    "wiedererstatteter": "wiedererstattet",
    "wiedererstattetes": "wiedererstattet",
    "wiedererstattetest": "wiedererstatten",
    "wiedererstattetet": "wiedererstatten",
    "wiedererzähle": "wiedererzählen",
    "wiedererzählend": "wiedererzählen",
    "wiedererzählende": "wiedererzählend",
    "wiedererzählendem": "wiedererzählend",
    "wiedererzählenden": "wiedererzählend",
    "wiedererzählender": "wiedererzählend",
    "wiedererzählendes": "wiedererzählend",
    "wiedererzählest": "wiedererzählen",
    "wiedererzählet": "wiedererzählen",
    "wiedererzählst": "wiedererzählen",
    "wiedererzählt": "wiedererzählen",
    "wiedererzählte": "wiedererzählen",
    "wiedererzähltem": "wiedererzählt",
    "wiedererzählten": "wiedererzählen",
    "wiedererzählter": "wiedererzählt",
    "wiedererzähltes": "wiedererzählt",
    "wiedererzähltest": "wiedererzählen",
    "wiedererzähltet": "wiedererzählen",
    "wiederfand": "wiederfinden",
    "wiederfanden": "wiederfinden",
    "wiederfandest": "wiederfinden",
    "wiederfandet": "wiederfinden",
    "wiederfinde": "wiederfinden",
    "wiederfindend": "wiederfinden",
    "wiederfindende": "wiederfindend",
    "wiederfindendem": "wiederfindend",
    "wiederfindenden": "wiederfindend",
    "wiederfindender": "wiederfindend",
    "wiederfindendes": "wiederfindend",
    "wiederfindest": "wiederfinden",
    "wiederfindet": "wiederfinden",
    "wiederfände": "wiederfinden",
    "wiederfänden": "wiederfinden",
    "wiederfändest": "wiederfinden",
    "wiederfändet": "wiederfinden",
    "wiedergab": "wiedergeben",
    "wiedergabst": "wiedergeben",
    "wiedergabt": "wiedergeben",
    "wiedergebe": "wiedergeben",
    "wiedergebend": "wiedergeben",
    "wiedergebende": "wiedergebend",
    "wiedergebendem": "wiedergebend",
    "wiedergebenden": "wiedergebend",
    "wiedergebender": "wiedergebend",
    "wiedergebendes": "wiedergebend",
    "wiedergebest": "wiedergeben",
    "wiedergebet": "wiedergeben",
    "wiedergeborene": "wiedergeboren",
    "wiedergeborenem": "wiedergeboren",
    "wiedergeborenen": "wiedergeboren",
    "wiedergeborener": "wiedergeboren",
    "wiedergeborenes": "wiedergeboren",
    "wiedergebracht": "wiederbringen",
    "wiedergebrachte": "wiedergebracht",
    "wiedergebrachtem": "wiedergebracht",
    "wiedergebrachten": "wiedergebracht",
    "wiedergebrachter": "wiedergebracht",
    "wiedergebrachtes": "wiedergebracht",
    "wiedergebt": "wiedergeben",
    "wiedergefunden": "wiederfinden",
    "wiedergefundene": "wiedergefunden",
    "wiedergefundenem": "wiedergefunden",
    "wiedergefundenen": "wiedergefunden",
    "wiedergefundener": "wiedergefunden",
    "wiedergefundenes": "wiedergefunden",
    "wiedergegeben": "wiedergeben",
    "wiedergegebene": "wiedergegeben",
    "wiedergegebenem": "wiedergegeben",
    "wiedergegebenen": "wiedergegeben",
    "wiedergegebener": "wiedergegeben",
    "wiedergegebenes": "wiedergegeben",
    "wiedergeimpft": "wiederimpfen",
    "wiedergeimpfte": "wiedergeimpft",
    "wiedergeimpftem": "wiedergeimpft",
    "wiedergeimpften": "wiedergeimpft",
    "wiedergeimpfter": "wiedergeimpft",
    "wiedergeimpftes": "wiedergeimpft",
    "wiedergekehrt": "wiederkehren",
    "wiedergekehrte": "wiedergekehrt",
    "wiedergekehrtem": "wiedergekehrt",
    "wiedergekehrten": "wiedergekehrt",
    "wiedergekehrter": "wiedergekehrt",
    "wiedergekehrtes": "wiedergekehrt",
    "wiedergekommen": "wiederkommen",
    "wiedergekommene": "wiedergekommen",
    "wiedergekommenem": "wiedergekommen",
    "wiedergekommenen": "wiedergekommen",
    "wiedergekommener": "wiedergekommen",
    "wiedergekommenes": "wiedergekommen",
    "wiedergekriegt": "wiederkriegen",
    "wiedergekriegte": "wiedergekriegt",
    "wiedergekriegtem": "wiedergekriegt",
    "wiedergekriegten": "wiedergekriegt",
    "wiedergekriegter": "wiedergekriegt",
    "wiedergekriegtes": "wiedergekriegt",
    "wiedergekäut": "wiederkäuen",
    "wiedergekäute": "wiedergekäut",
    "wiedergekäutem": "wiedergekäut",
    "wiedergekäuten": "wiedergekäut",
    "wiedergekäuter": "wiedergekäut",
    "wiedergekäutes": "wiedergekäut",
    "wiedergeliebt": "wiederlieben",
    "wiedergeliebte": "wiedergeliebt",
    "wiedergeliebtem": "wiedergeliebt",
    "wiedergeliebten": "wiedergeliebt",
    "wiedergeliebter": "wiedergeliebt",
    "wiedergeliebtere": "wiedergeliebt",
    "wiedergeliebterem": "wiedergeliebt",
    "wiedergeliebteren": "wiedergeliebt",
    "wiedergeliebterer": "wiedergeliebt",
    "wiedergeliebteres": "wiedergeliebt",
    "wiedergeliebtes": "wiedergeliebt",
    "wiedergeliebteste": "wiedergeliebt",
    "wiedergeliebtestem": "wiedergeliebt",
    "wiedergeliebtesten": "wiedergeliebt",
    "wiedergeliebtester": "wiedergeliebt",
    "wiedergeliebtestes": "wiedergeliebt",
    "wiedergesagt": "wiedersagen",
    "wiedergesagte": "wiedergesagt",
    "wiedergesagtem": "wiedergesagt",
    "wiedergesagten": "wiedergesagt",
    "wiedergesagter": "wiedergesagt",
    "wiedergesagtes": "wiedergesagt",
    "wiedergesehen": "wiedersehen",
    "wiedergesehene": "wiedergesehen",
    "wiedergesehenem": "wiedergesehen",
    "wiedergesehenen": "wiedergesehen",
    "wiedergesehener": "wiedergesehen",
    "wiedergesehenes": "wiedergesehen",
    "wiedergewann": "wiedergewinnen",
    "wiedergewannen": "wiedergewinnen",
    "wiedergewannst": "wiedergewinnen",
    "wiedergewannt": "wiedergewinnen",
    "wiedergewinne": "wiedergewinnen",
    "wiedergewinnend": "wiedergewinnen",
    "wiedergewinnende": "wiedergewinnend",
    "wiedergewinnendem": "wiedergewinnend",
    "wiedergewinnenden": "wiedergewinnend",
    "wiedergewinnender": "wiedergewinnend",
    "wiedergewinnendes": "wiedergewinnend",
    "wiedergewinnest": "wiedergewinnen",
    "wiedergewinnet": "wiedergewinnen",
    "wiedergewinnst": "wiedergewinnen",
    "wiedergewinnt": "wiedergewinnen",
    "wiedergewonnen": "wiedergewinnen",
    "wiedergewonnene": "wiedergewonnen",
    "wiedergewonnenem": "wiedergewonnen",
    "wiedergewonnenen": "wiedergewonnen",
    "wiedergewonnener": "wiedergewonnen",
    "wiedergewonnenes": "wiedergewonnen",
    "wiedergewänne": "wiedergewinnen",
    "wiedergewännen": "wiedergewinnen",
    "wiedergewännest": "wiedergewinnen",
    "wiedergewännet": "wiedergewinnen",
    "wiedergibst": "wiedergeben",
    "wiedergibt": "wiedergeben",
    "wiedergäbe": "wiedergeben",
    "wiedergäben": "wiedergeben",
    "wiedergäbest": "wiedergeben",
    "wiedergäbet": "wiedergeben",
    "wiederhergestellt": "wiederherstellen",
    "wiederhergestellte": "wiederhergestellt",
    "wiederhergestelltem": "wiederhergestellt",
    "wiederhergestellten": "wiederhergestellt",
    "wiederhergestellter": "wiederhergestellt",
    "wiederhergestelltes": "wiederhergestellt",
    "wiederherstelle": "wiederherstellen",
    "wiederherstellend": "wiederherstellen",
    "wiederherstellende": "wiederherstellend",
    "wiederherstellendem": "wiederherstellend",
    "wiederherstellenden": "wiederherstellend",
    "wiederherstellender": "wiederherstellend",
    "wiederherstellendes": "wiederherstellend",
    "wiederherstellest": "wiederherstellen",
    "wiederherstellet": "wiederherstellen",
    "wiederherstellst": "wiederherstellen",
    "wiederherstellt": "wiederherstellen",
    "wiederherstellte": "wiederherstellen",
    "wiederherstellten": "wiederherstellen",
    "wiederherstelltest": "wiederherstellen",
    "wiederherstelltet": "wiederherstellen",
    "wiederherzustellen": "wiederherstellen",
    "wiederhole": "wiederholen",
    "wiederholend": "wiederholen",
    "wiederholende": "wiederholend",
    "wiederholendem": "wiederholend",
    "wiederholenden": "wiederholend",
    "wiederholender": "wiederholend",
    "wiederholendes": "wiederholend",
    "wiederholest": "wiederholen",
    "wiederholet": "wiederholen",
    "wiederholst": "wiederholen",
    "wiederholt": "wiederholen",
    "wiederholte": "wiederholen",
    "wiederholtem": "wiederholt",
    "wiederholten": "wiederholen",
    "wiederholter": "wiederholt",
    "wiederholtes": "wiederholt",
    "wiederholtest": "wiederholen",
    "wiederholtet": "wiederholen",
    "wiederimpfe": "wiederimpfen",
    "wiederimpfend": "wiederimpfen",
    "wiederimpfende": "wiederimpfend",
    "wiederimpfendem": "wiederimpfend",
    "wiederimpfenden": "wiederimpfend",
    "wiederimpfender": "wiederimpfend",
    "wiederimpfendes": "wiederimpfend",
    "wiederimpfest": "wiederimpfen",
    "wiederimpfet": "wiederimpfen",
    "wiederimpfst": "wiederimpfen",
    "wiederimpft": "wiederimpfen",
    "wiederimpfte": "wiederimpfen",
    "wiederimpften": "wiederimpfen",
    "wiederimpftest": "wiederimpfen",
    "wiederimpftet": "wiederimpfen",
    "wiederkam": "wiederkommen",
    "wiederkamen": "wiederkommen",
    "wiederkamst": "wiederkommen",
    "wiederkamt": "wiederkommen",
    "wiederkehre": "wiederkehren",
    "wiederkehrend": "wiederkehren",
    "wiederkehrende": "wiederkehrend",
    "wiederkehrendem": "wiederkehrend",
    "wiederkehrenden": "wiederkehrend",
    "wiederkehrender": "wiederkehrend",
    "wiederkehrendes": "wiederkehrend",
    "wiederkehrest": "wiederkehren",
    "wiederkehret": "wiederkehren",
    "wiederkehrst": "wiederkehren",
    "wiederkehrt": "wiederkehren",
    "wiederkehrte": "wiederkehren",
    "wiederkehrten": "wiederkehren",
    "wiederkehrtest": "wiederkehren",
    "wiederkehrtet": "wiederkehren",
    "wiederkomme": "wiederkommen",
    "wiederkommend": "wiederkommen",
    "wiederkommende": "wiederkommend",
    "wiederkommendem": "wiederkommend",
    "wiederkommenden": "wiederkommend",
    "wiederkommender": "wiederkommend",
    "wiederkommendes": "wiederkommend",
    "wiederkommest": "wiederkommen",
    "wiederkommet": "wiederkommen",
    "wiederkommst": "wiederkommen",
    "wiederkommt": "wiederkommen",
    "wiederkriege": "wiederkriegen",
    "wiederkriegend": "wiederkriegen",
    "wiederkriegende": "wiederkriegend",
    "wiederkriegendem": "wiederkriegend",
    "wiederkriegenden": "wiederkriegend",
    "wiederkriegender": "wiederkriegend",
    "wiederkriegendes": "wiederkriegend",
    "wiederkriegest": "wiederkriegen",
    "wiederkrieget": "wiederkriegen",
    "wiederkriegst": "wiederkriegen",
    "wiederkriegt": "wiederkriegen",
    "wiederkriegte": "wiederkriegen",
    "wiederkriegten": "wiederkriegen",
    "wiederkriegtest": "wiederkriegen",
    "wiederkriegtet": "wiederkriegen",
    "wiederkäme": "wiederkommen",
    "wiederkämen": "wiederkommen",
    "wiederkämest": "wiederkommen",
    "wiederkämet": "wiederkommen",
    "wiederkäue": "wiederkäuen",
    "wiederkäuend": "wiederkäuen",
    "wiederkäuende": "wiederkäuend",
    "wiederkäuendem": "wiederkäuend",
    "wiederkäuenden": "wiederkäuend",
    "wiederkäuender": "wiederkäuend",
    "wiederkäuendes": "wiederkäuend",
    "wiederkäuest": "wiederkäuen",
    "wiederkäuet": "wiederkäuen",
    "wiederkäust": "wiederkäuen",
    "wiederkäut": "wiederkäuen",
    "wiederkäute": "wiederkäuen",
    "wiederkäuten": "wiederkäuen",
    "wiederkäutest": "wiederkäuen",
    "wiederkäutet": "wiederkäuen",
    "wiederliebe": "wiederlieben",
    "wiederliebend": "wiederlieben",
    "wiederliebende": "wiederliebend",
    "wiederliebendem": "wiederliebend",
    "wiederliebenden": "wiederliebend",
    "wiederliebender": "wiederliebend",
    "wiederliebendere": "wiederliebend",
    "wiederliebenderem": "wiederliebend",
    "wiederliebenderen": "wiederliebend",
    "wiederliebenderer": "wiederliebend",
    "wiederliebenderes": "wiederliebend",
    "wiederliebendes": "wiederliebend",
    "wiederliebendste": "wiederliebend",
    "wiederliebendstem": "wiederliebend",
    "wiederliebendsten": "wiederliebend",
    "wiederliebendster": "wiederliebend",
    "wiederliebendstes": "wiederliebend",
    "wiederliebest": "wiederlieben",
    "wiederliebet": "wiederlieben",
    "wiederliebst": "wiederlieben",
    "wiederliebt": "wiederlieben",
    "wiederliebte": "wiederlieben",
    "wiederliebten": "wiederlieben",
    "wiederliebtest": "wiederlieben",
    "wiederliebtet": "wiederlieben",
    "wiedersage": "wiedersagen",
    "wiedersagend": "wiedersagen",
    "wiedersagende": "wiedersagend",
    "wiedersagendem": "wiedersagend",
    "wiedersagenden": "wiedersagend",
    "wiedersagender": "wiedersagend",
    "wiedersagendes": "wiedersagend",
    "wiedersagest": "wiedersagen",
    "wiedersaget": "wiedersagen",
    "wiedersagst": "wiedersagen",
    "wiedersagt": "wiedersagen",
    "wiedersagte": "wiedersagen",
    "wiedersagten": "wiedersagen",
    "wiedersagtest": "wiedersagen",
    "wiedersagtet": "wiedersagen",
    "wiedersah": "wiedersehen",
    "wiedersahen": "wiedersehen",
    "wiedersahst": "wiedersehen",
    "wiedersaht": "wiedersehen",
    "wiedersehe": "wiedersehen",
    "wiedersehend": "wiedersehen",
    "wiedersehende": "wiedersehend",
    "wiedersehendem": "wiedersehend",
    "wiedersehenden": "wiedersehend",
    "wiedersehender": "wiedersehend",
    "wiedersehendes": "wiedersehend",
    "wiedersehest": "wiedersehen",
    "wiedersehet": "wiedersehen",
    "wiederseht": "wiedersehen",
    "wiedersiehst": "wiedersehen",
    "wiedersieht": "wiedersehen",
    "wiedersähe": "wiedersehen",
    "wiedersähen": "wiedersehen",
    "wiedersähest": "wiedersehen",
    "wiedersähet": "wiedersehen",
    "wiedervereinigend": "wiedervereinige",
    "wiedervereinigende": "wiedervereinigend",
    "wiedervereinigendem": "wiedervereinigend",
    "wiedervereinigenden": "wiedervereinigend",
    "wiedervereinigender": "wiedervereinigend",
    "wiedervereinigendes": "wiedervereinigend",
    "wiedervereinigest": "wiedervereinige",
    "wiedervereiniget": "wiedervereinige",
    "wiedervereinigst": "wiedervereinige",
    "wiedervereinigt": "wiedervereinige",
    "wiedervereinigte": "wiedervereinige",
    "wiedervereinigtem": "wiedervereinigt",
    "wiedervereinigten": "wiedervereinige",
    "wiedervereinigter": "wiedervereinigt",
    "wiedervereinigtes": "wiedervereinigt",
    "wiedervereinigtest": "wiedervereinige",
    "wiedervereinigtet": "wiedervereinige",
    "wiederverkaufe": "wiederverkaufen",
    "wiederverkaufend": "wiederverkaufen",
    "wiederverkaufende": "wiederverkaufend",
    "wiederverkaufendem": "wiederverkaufend",
    "wiederverkaufenden": "wiederverkaufend",
    "wiederverkaufender": "wiederverkaufend",
    "wiederverkaufendes": "wiederverkaufend",
    "wiederverkaufest": "wiederverkaufen",
    "wiederverkaufet": "wiederverkaufen",
    "wiederverkaufst": "wiederverkaufen",
    "wiederverkauft": "wiederverkaufen",
    "wiederverkaufte": "wiederverkaufen",
    "wiederverkauftem": "wiederverkauft",
    "wiederverkauften": "wiederverkaufen",
    "wiederverkaufter": "wiederverkauft",
    "wiederverkauftes": "wiederverkauft",
    "wiederverkauftest": "wiederverkaufen",
    "wiederverkauftet": "wiederverkaufen",
    "wiederzubekommen": "wiederbekommen",
    "wiederzubeleben": "wiederbeleben",
    "wiederzubringen": "wiederbringen",
    "wiederzuergreifen": "wiederergreifen",
    "wiederzuerhalten": "wiedererhalten",
    "wiederzuerkennen": "wiedererkennen",
    "wiederzuerlangen": "wiedererlangen",
    "wiederzuerstatten": "wiedererstatten",
    "wiederzuerzählen": "wiedererzählen",
    "wiederzufinden": "wiederfinden",
    "wiederzugeben": "wiedergeben",
    "wiederzugewinnen": "wiedergewinnen",
    "wiederzuimpfen": "wiederimpfen",
    "wiederzukehren": "wiederkehren",
    "wiederzukommen": "wiederkommen",
    "wiederzukriegen": "wiederkriegen",
    "wiederzukäuen": "wiederkäuen",
    "wiederzulieben": "wiederlieben",
    "wiederzusagen": "wiedersagen",
    "wiederzusehen": "wiedersehen",
    "wiederzuvereinigen": "wiedervereinigen",
    "wiederzuverkaufen": "wiederverkaufen",
    "wiegele": "wiegeln",
    "wiegelnd": "wiegeln",
    "wiegelnde": "wiegelnd",
    "wiegelndem": "wiegelnd",
    "wiegelnden": "wiegelnd",
    "wiegelnder": "wiegelnd",
    "wiegelndes": "wiegelnd",
    "wiegelst": "wiegeln",
    "wiegelt": "wiegeln",
    "wiegelte": "wiegeln",
    "wiegelten": "wiegeln",
    "wiegeltest": "wiegeln",
    "wiegeltet": "wiegeln",
    "wiegend": "wiegen",
    "wiegende": "wiegend",
    "wiegendem": "wiegend",
    "wiegenden": "wiegend",
    "wiegender": "wiegend",
    "wiegendes": "wiegend",
    "wiegest": "wiegen",
    "wieget": "wiegen",
    "wiegle": "wiegeln",
    "wiegst": "wiegen",
    "wiegt": "wiegen",
    "wiehere": "wiehern",
    "wiehernd": "wiehern",
    "wiehernde": "wiehernd",
    "wieherndem": "wiehernd",
    "wiehernden": "wiehernd",
    "wiehernder": "wiehernd",
    "wieherndere": "wiehernd",
    "wiehernderem": "wiehernd",
    "wiehernderen": "wiehernd",
    "wiehernderer": "wiehernd",
    "wiehernderes": "wiehernd",
    "wieherndes": "wiehernd",
    "wieherndste": "wiehernd",
    "wieherndstem": "wiehernd",
    "wieherndsten": "wiehernd",
    "wieherndster": "wiehernd",
    "wieherndstes": "wiehernd",
    "wieherst": "wiehern",
    "wiehert": "wiehern",
    "wieherte": "wiehern",
    "wieherten": "wiehern",
    "wiehertest": "wiehern",
    "wiehertet": "wiehern",
    "wienere": "wienern",
    "wienernd": "wienern",
    "wienernde": "wienernd",
    "wienerndem": "wienernd",
    "wienernden": "wienernd",
    "wienernder": "wienernd",
    "wienerndes": "wienernd",
    "wienerst": "wienern",
    "wienert": "wienern",
    "wienerte": "wienern",
    "wienerten": "wienern",
    "wienertest": "wienern",
    "wienertet": "wienern",
    "wies": "weisen",
    "wiesen": "weisen",
    "wiesest": "weisen",
    "wieset": "weisen",
    "wiest": "weisen",
    "wildem": "wild",
    "wilden": "wild",
    "wilder": "wildern",
    "wildere": "wild",
    "wilderem": "wild",
    "wilderen": "wild",
    "wilderes": "wild",
    "wildernd": "wildern",
    "wildernde": "wildernd",
    "wilderndem": "wildernd",
    "wildernden": "wildernd",
    "wildernder": "wildernd",
    "wilderndes": "wildernd",
    "wilderst": "wildern",
    "wildert": "wildern",
    "wilderte": "wildern",
    "wilderten": "wildern",
    "wildertest": "wildern",
    "wildertet": "wildern",
    "wildes": "wild",
    "wildeste": "wild",
    "wildestem": "wild",
    "wildesten": "wild",
    "wildester": "wild",
    "wildestes": "wild",
    "wildfremde": "wildfremd",
    "wildfremdem": "wildfremd",
    "wildfremden": "wildfremd",
    "wildfremder": "wildfremd",
    "wildfremdes": "wildfremd",
    "wildlebendem": "wildlebend",
    "wildlebenden": "wildlebend",
    "wildlebender": "wildlebend",
    "wildlebendes": "wildlebend",
    "wilhelminischem": "wilhelminisch",
    "wilhelminischen": "wilhelminisch",
    "wilhelminischer": "wilhelminisch",
    "wilhelminisches": "wilhelminisch",
    "will": "wollen",
    "willenlosem": "willenlos",
    "willenlosen": "willenlos",
    "willenloser": "willenlos",
    "willenlosere": "willenlos",
    "willenloserem": "willenlos",
    "willenloseren": "willenlos",
    "willenloserer": "willenlos",
    "willenloseres": "willenlos",
    "willenloses": "willenlos",
    "willenloseste": "willenlos",
    "willenlosestem": "willenlos",
    "willenlosesten": "willenlos",
    "willenlosester": "willenlos",
    "willenlosestes": "willenlos",
    "willensschwachem": "willensschwach",
    "willensschwachen": "willensschwach",
    "willensschwacher": "willensschwach",
    "willensschwaches": "willensschwach",
    "willensstarke": "willensstark",
    "willensstarkem": "willensstark",
    "willensstarken": "willensstark",
    "willensstarker": "willensstark",
    "willensstarkes": "willensstark",
    "willentliche": "willentlich",
    "willentlichem": "willentlich",
    "willentlichen": "willentlich",
    "willentlicher": "willentlich",
    "willentliches": "willentlich",
    "willige": "willigen",
    "willigend": "willigen",
    "willigende": "willigend",
    "willigendem": "willigend",
    "willigenden": "willigend",
    "willigender": "willigend",
    "willigendes": "willigend",
    "willigest": "willigen",
    "williget": "willigen",
    "willigst": "willigen",
    "willigt": "willigen",
    "willigte": "willigen",
    "willigten": "willigen",
    "willigtest": "willigen",
    "willigtet": "willigen",
    "willkürlichem": "willkürlich",
    "willkürlichen": "willkürlich",
    "willkürlicher": "willkürlich",
    "willkürlichere": "willkürlich",
    "willkürlicherem": "willkürlich",
    "willkürlicheren": "willkürlich",
    "willkürlicherer": "willkürlich",
    "willkürlicheres": "willkürlich",
    "willkürliches": "willkürlich",
    "willkürlichste": "willkürlich",
    "willkürlichstem": "willkürlich",
    "willkürlichsten": "willkürlich",
    "willkürlichster": "willkürlich",
    "willkürlichstes": "willkürlich",
    "willst": "wollen",
    "wimmele": "wimmeln",
    "wimmelnd": "wimmeln",
    "wimmelnde": "wimmelnd",
    "wimmelndem": "wimmelnd",
    "wimmelnden": "wimmelnd",
    "wimmelnder": "wimmelnd",
    "wimmelndes": "wimmelnd",
    "wimmelst": "wimmeln",
    "wimmelt": "wimmeln",
    "wimmelte": "wimmeln",
    "wimmelten": "wimmeln",
    "wimmeltest": "wimmeln",
    "wimmeltet": "wimmeln",
    "wimmere": "wimmern",
    "wimmernd": "wimmern",
    "wimmernde": "wimmernd",
    "wimmerndem": "wimmernd",
    "wimmernden": "wimmernd",
    "wimmernder": "wimmernd",
    "wimmerndere": "wimmernd",
    "wimmernderem": "wimmernd",
    "wimmernderen": "wimmernd",
    "wimmernderer": "wimmernd",
    "wimmernderes": "wimmernd",
    "wimmerndes": "wimmernd",
    "wimmerndste": "wimmernd",
    "wimmerndstem": "wimmernd",
    "wimmerndsten": "wimmernd",
    "wimmerndster": "wimmernd",
    "wimmerndstes": "wimmernd",
    "wimmerst": "wimmern",
    "wimmert": "wimmern",
    "wimmerte": "wimmern",
    "wimmerten": "wimmern",
    "wimmertest": "wimmern",
    "wimmertet": "wimmern",
    "wimmle": "wimmeln",
    "windelweichem": "windelweich",
    "windelweichen": "windelweich",
    "windelweicher": "windelweich",
    "windelweiches": "windelweich",
    "windend": "winden",
    "windende": "windend",
    "windendem": "windend",
    "windenden": "windend",
    "windender": "windend",
    "windendes": "windend",
    "windest": "winden",
    "windet": "winden",
    "windigem": "windig",
    "windigen": "windig",
    "windiger": "windig",
    "windigere": "windig",
    "windigerem": "windig",
    "windigeren": "windig",
    "windigerer": "windig",
    "windigeres": "windig",
    "windiges": "windig",
    "windigste": "windig",
    "windigstem": "windig",
    "windigsten": "windig",
    "windigster": "windig",
    "windigstes": "windig",
    "windschiefem": "windschief",
    "windschiefen": "windschief",
    "windschiefer": "windschief",
    "windschiefes": "windschief",
    "winke": "winken",
    "winkele": "winkeln",
    "winkelförmige": "winkelförmig",
    "winkelförmigem": "winkelförmig",
    "winkelförmigen": "winkelförmig",
    "winkelförmiger": "winkelförmig",
    "winkelförmigere": "winkelförmig",
    "winkelförmigerem": "winkelförmig",
    "winkelförmigeren": "winkelförmig",
    "winkelförmigerer": "winkelförmig",
    "winkelförmigeres": "winkelförmig",
    "winkelförmiges": "winkelförmig",
    "winkelförmigste": "winkelförmig",
    "winkelförmigstem": "winkelförmig",
    "winkelförmigsten": "winkelförmig",
    "winkelförmigster": "winkelförmig",
    "winkelförmigstes": "winkelförmig",
    "winkelnd": "winkeln",
    "winkelnde": "winkelnd",
    "winkelndem": "winkelnd",
    "winkelnden": "winkelnd",
    "winkelnder": "winkelnd",
    "winkelndes": "winkelnd",
    "winkelst": "winkeln",
    "winkelt": "winkeln",
    "winkelte": "winkeln",
    "winkelten": "winkeln",
    "winkeltest": "winkeln",
    "winkeltet": "winkeln",
    "winkend": "winken",
    "winkende": "winkend",
    "winkendem": "winkend",
    "winkenden": "winkend",
    "winkender": "winkend",
    "winkendes": "winkend",
    "winkest": "winken",
    "winket": "winken",
    "winkle": "winkeln",
    "winkst": "winken",
    "winkt": "winken",
    "winkte": "winken",
    "winkten": "winken",
    "winktest": "winken",
    "winktet": "winken",
    "winsele": "winseln",
    "winselnd": "winseln",
    "winselnde": "winselnd",
    "winselndem": "winselnd",
    "winselnden": "winselnd",
    "winselnder": "winselnd",
    "winselndere": "winselnd",
    "winselnderem": "winselnd",
    "winselnderen": "winselnd",
    "winselnderer": "winselnd",
    "winselnderes": "winselnd",
    "winselndes": "winselnd",
    "winselndste": "winselnd",
    "winselndstem": "winselnd",
    "winselndsten": "winselnd",
    "winselndster": "winselnd",
    "winselndstes": "winselnd",
    "winselst": "winseln",
    "winselt": "winseln",
    "winselte": "winseln",
    "winselten": "winseln",
    "winseltest": "winseln",
    "winseltet": "winseln",
    "winsle": "winseln",
    "winterfeste": "winterfest",
    "winterfestem": "winterfest",
    "winterfesten": "winterfest",
    "winterfester": "winterfest",
    "winterfestere": "winterfest",
    "winterfesterem": "winterfest",
    "winterfesteren": "winterfest",
    "winterfesterer": "winterfest",
    "winterfesteres": "winterfest",
    "winterfestes": "winterfest",
    "winterfesteste": "winterfest",
    "winterfestestem": "winterfest",
    "winterfestesten": "winterfest",
    "winterfestester": "winterfest",
    "winterfestestes": "winterfest",
    "winterliche": "winterlich",
    "winterlichem": "winterlich",
    "winterlichen": "winterlich",
    "winterlicher": "winterlich",
    "winterlichere": "winterlich",
    "winterlicherem": "winterlich",
    "winterlicheren": "winterlich",
    "winterlicherer": "winterlich",
    "winterlicheres": "winterlich",
    "winterliches": "winterlich",
    "winterlichste": "winterlich",
    "winterlichstem": "winterlich",
    "winterlichsten": "winterlich",
    "winterlichster": "winterlich",
    "winterlichstes": "winterlich",
    "winzigem": "winzig",
    "winzigen": "winzig",
    "winziger": "winzig",
    "winzigere": "winzig",
    "winzigerem": "winzig",
    "winzigeren": "winzig",
    "winzigerer": "winzig",
    "winzigeres": "winzig",
    "winziges": "winzig",
    "winzigste": "winzig",
    "winzigstem": "winzig",
    "winzigsten": "winzig",
    "winzigster": "winzig",
    "winzigstes": "winzig",
    "wippe": "wippen",
    "wippend": "wippen",
    "wippende": "wippend",
    "wippendem": "wippend",
    "wippenden": "wippend",
    "wippender": "wippend",
    "wippendere": "wippend",
    "wippenderem": "wippend",
    "wippenderen": "wippend",
    "wippenderer": "wippend",
    "wippenderes": "wippend",
    "wippendes": "wippend",
    "wippendste": "wippend",
    "wippendstem": "wippend",
    "wippendsten": "wippend",
    "wippendster": "wippend",
    "wippendstes": "wippend",
    "wippest": "wippen",
    "wippet": "wippen",
    "wippst": "wippen",
    "wippt": "wippen",
    "wippte": "wippen",
    "wippten": "wippen",
    "wipptest": "wippen",
    "wipptet": "wippen",
    "wir": "ich",
    "wirb": "werben",
    "wirbele": "wirbeln",
    "wirbelnd": "wirbeln",
    "wirbelnde": "wirbelnd",
    "wirbelndem": "wirbelnd",
    "wirbelnden": "wirbelnd",
    "wirbelnder": "wirbelnd",
    "wirbelndere": "wirbelnd",
    "wirbelnderem": "wirbelnd",
    "wirbelnderen": "wirbelnd",
    "wirbelnderer": "wirbelnd",
    "wirbelnderes": "wirbelnd",
    "wirbelndes": "wirbelnd",
    "wirbelndste": "wirbelnd",
    "wirbelndstem": "wirbelnd",
    "wirbelndsten": "wirbelnd",
    "wirbelndster": "wirbelnd",
    "wirbelndstes": "wirbelnd",
    "wirbelst": "wirbeln",
    "wirbelt": "wirbeln",
    "wirbelte": "wirbeln",
    "wirbelten": "wirbeln",
    "wirbeltest": "wirbeln",
    "wirbeltet": "wirbeln",
    "wirble": "wirbeln",
    "wirbst": "werben",
    "wirbt": "werben",
    "wird": "werden",
    "wirf": "werfen",
    "wirfst": "werfen",
    "wirft": "werfen",
    "wirke": "wirken",
    "wirkend": "wirken",
    "wirkende": "wirkend",
    "wirkendem": "wirkend",
    "wirkenden": "wirkend",
    "wirkender": "wirkend",
    "wirkendere": "wirkend",
    "wirkenderem": "wirkend",
    "wirkenderen": "wirkend",
    "wirkenderer": "wirkend",
    "wirkenderes": "wirkend",
    "wirkendes": "wirkend",
    "wirkendste": "wirkend",
    "wirkendstem": "wirkend",
    "wirkendsten": "wirkend",
    "wirkendster": "wirkend",
    "wirkendstes": "wirkend",
    "wirkest": "wirken",
    "wirket": "wirken",
    "wirkliche": "wirklich",
    "wirklichem": "wirklich",
    "wirklichen": "wirklich",
    "wirklicher": "wirklich",
    "wirklichere": "wirklich",
    "wirklicherem": "wirklich",
    "wirklicheren": "wirklich",
    "wirklicherer": "wirklich",
    "wirklicheres": "wirklich",
    "wirkliches": "wirklich",
    "wirklichkeitsfremdem": "wirklichkeitsfremd",
    "wirklichkeitsfremden": "wirklichkeitsfremd",
    "wirklichkeitsfremder": "wirklichkeitsfremd",
    "wirklichkeitsfremdes": "wirklichkeitsfremd",
    "wirklichkeitsgetreue": "wirklichkeitsgetreu",
    "wirklichkeitsgetreuem": "wirklichkeitsgetreu",
    "wirklichkeitsgetreuen": "wirklichkeitsgetreu",
    "wirklichkeitsgetreuer": "wirklichkeitsgetreu",
    "wirklichkeitsgetreues": "wirklichkeitsgetreu",
    "wirklichste": "wirklich",
    "wirklichstem": "wirklich",
    "wirklichsten": "wirklich",
    "wirklichster": "wirklich",
    "wirklichstes": "wirklich",
    "wirksame": "wirksam",
    "wirksamem": "wirksam",
    "wirksamen": "wirksam",
    "wirksamer": "wirksam",
    "wirksamere": "wirksam",
    "wirksamerem": "wirksam",
    "wirksameren": "wirksam",
    "wirksamerer": "wirksam",
    "wirksameres": "wirksam",
    "wirksames": "wirksam",
    "wirksamstem": "wirksam",
    "wirksamsten": "wirksam",
    "wirksamster": "wirksam",
    "wirksamstes": "wirksam",
    "wirkst": "wirken",
    "wirkt": "wirken",
    "wirkte": "wirken",
    "wirkten": "wirken",
    "wirktest": "wirken",
    "wirktet": "wirken",
    "wirkungslosem": "wirkungslos",
    "wirkungslosen": "wirkungslos",
    "wirkungsloser": "wirkungslos",
    "wirkungslosere": "wirkungslos",
    "wirkungsloserem": "wirkungslos",
    "wirkungsloseren": "wirkungslos",
    "wirkungsloserer": "wirkungslos",
    "wirkungsloseres": "wirkungslos",
    "wirkungsloses": "wirkungslos",
    "wirkungsloseste": "wirkungslos",
    "wirkungslosestem": "wirkungslos",
    "wirkungslosesten": "wirkungslos",
    "wirkungslosester": "wirkungslos",
    "wirkungslosestes": "wirkungslos",
    "wirkungsvolle": "wirkungsvoll",
    "wirkungsvollem": "wirkungsvoll",
    "wirkungsvollen": "wirkungsvoll",
    "wirkungsvoller": "wirkungsvoll",
    "wirkungsvollere": "wirkungsvoll",
    "wirkungsvollerem": "wirkungsvoll",
    "wirkungsvolleren": "wirkungsvoll",
    "wirkungsvollerer": "wirkungsvoll",
    "wirkungsvolleres": "wirkungsvoll",
    "wirkungsvolles": "wirkungsvoll",
    "wirkungsvollste": "wirkungsvoll",
    "wirkungsvollstem": "wirkungsvoll",
    "wirkungsvollsten": "wirkungsvoll",
    "wirkungsvollster": "wirkungsvoll",
    "wirkungsvollstes": "wirkungsvoll",
    "wirre": "wirr",
    "wirrem": "wirr",
    "wirren": "wirr",
    "wirrer": "wirr",
    "wirrere": "wirr",
    "wirrerem": "wirr",
    "wirreren": "wirr",
    "wirrerer": "wirr",
    "wirreres": "wirr",
    "wirres": "wirr",
    "wirrstem": "wirr",
    "wirrsten": "wirr",
    "wirrster": "wirr",
    "wirrstes": "wirr",
    "wirsche": "wirsch",
    "wirschem": "wirsch",
    "wirschen": "wirsch",
    "wirscher": "wirsch",
    "wirschere": "wirsch",
    "wirscherem": "wirsch",
    "wirscheren": "wirsch",
    "wirscherer": "wirsch",
    "wirscheres": "wirsch",
    "wirsches": "wirsch",
    "wirschste": "wirsch",
    "wirschstem": "wirsch",
    "wirschsten": "wirsch",
    "wirschster": "wirsch",
    "wirschstes": "wirsch",
    "wirst": "werden",
    "wirtend": "wirten",
    "wirtende": "wirtend",
    "wirtendem": "wirtend",
    "wirtenden": "wirtend",
    "wirtender": "wirtend",
    "wirtendes": "wirtend",
    "wirtest": "wirten",
    "wirtet": "wirten",
    "wirtete": "wirten",
    "wirteten": "wirten",
    "wirtetest": "wirten",
    "wirtetet": "wirten",
    "wirtschafte": "wirtschaften",
    "wirtschaftend": "wirtschaften",
    "wirtschaftende": "wirtschaftend",
    "wirtschaftendem": "wirtschaftend",
    "wirtschaftenden": "wirtschaftend",
    "wirtschaftender": "wirtschaftend",
    "wirtschaftendes": "wirtschaftend",
    "wirtschaftest": "wirtschaften",
    "wirtschaftet": "wirtschaften",
    "wirtschaftete": "wirtschaften",
    "wirtschafteten": "wirtschaften",
    "wirtschaftetest": "wirtschaften",
    "wirtschaftetet": "wirtschaften",
    "wirtschaftliche": "wirtschaftlich",
    "wirtschaftlichem": "wirtschaftlich",
    "wirtschaftlichen": "wirtschaftlich",
    "wirtschaftlicher": "wirtschaftlich",
    "wirtschaftlichere": "wirtschaftlich",
    "wirtschaftlicherem": "wirtschaftlich",
    "wirtschaftlicheren": "wirtschaftlich",
    "wirtschaftlicherer": "wirtschaftlich",
    "wirtschaftlicheres": "wirtschaftlich",
    "wirtschaftliches": "wirtschaftlich",
    "wirtschaftlichste": "wirtschaftlich",
    "wirtschaftlichstem": "wirtschaftlich",
    "wirtschaftlichsten": "wirtschaftlich",
    "wirtschaftlichster": "wirtschaftlich",
    "wirtschaftlichstes": "wirtschaftlich",
    "wirtschaftspolitische": "wirtschaftspolitisch",
    "wirtschaftspolitischem": "wirtschaftspolitisch",
    "wirtschaftspolitischen": "wirtschaftspolitisch",
    "wirtschaftspolitischer": "wirtschaftspolitisch",
    "wirtschaftspolitisches": "wirtschaftspolitisch",
    "wische": "wischen",
    "wischend": "wischen",
    "wischende": "wischend",
    "wischendem": "wischend",
    "wischenden": "wischend",
    "wischender": "wischend",
    "wischendes": "wischend",
    "wischest": "wischen",
    "wischet": "wischen",
    "wischst": "wischen",
    "wischt": "wischen",
    "wischte": "wischen",
    "wischten": "wischen",
    "wischtest": "wischen",
    "wischtet": "wischen",
    "wispere": "wispern",
    "wispernd": "wispern",
    "wispernde": "wispernd",
    "wisperndem": "wispernd",
    "wispernden": "wispernd",
    "wispernder": "wispernd",
    "wisperndere": "wispernd",
    "wispernderem": "wispernd",
    "wispernderen": "wispernd",
    "wispernderer": "wispernd",
    "wispernderes": "wispernd",
    "wisperndes": "wispernd",
    "wisperndste": "wispernd",
    "wisperndstem": "wispernd",
    "wisperndsten": "wispernd",
    "wisperndster": "wispernd",
    "wisperndstes": "wispernd",
    "wisperst": "wispern",
    "wispert": "wispern",
    "wisperte": "wispern",
    "wisperten": "wispern",
    "wispertest": "wispern",
    "wispertet": "wispern",
    "wisse": "wissen",
    "wissend": "wissen",
    "wissende": "wissend",
    "wissendem": "wissend",
    "wissenden": "wissend",
    "wissender": "wissend",
    "wissendere": "wissend",
    "wissenderem": "wissend",
    "wissenderen": "wissend",
    "wissenderer": "wissend",
    "wissenderes": "wissend",
    "wissendes": "wissend",
    "wissendste": "wissend",
    "wissendstem": "wissend",
    "wissendsten": "wissend",
    "wissendster": "wissend",
    "wissendstes": "wissend",
    "wissenschaftlichem": "wissenschaftlich",
    "wissenschaftlichen": "wissenschaftlich",
    "wissenschaftlicher": "wissenschaftlich",
    "wissenschaftlichere": "wissenschaftlich",
    "wissenschaftlicherem": "wissenschaftlich",
    "wissenschaftlicheren": "wissenschaftlich",
    "wissenschaftlicherer": "wissenschaftlich",
    "wissenschaftlicheres": "wissenschaftlich",
    "wissenschaftliches": "wissenschaftlich",
    "wissenschaftlichste": "wissenschaftlich",
    "wissenschaftlichstem": "wissenschaftlich",
    "wissenschaftlichsten": "wissenschaftlich",
    "wissenschaftlichster": "wissenschaftlich",
    "wissenschaftlichstes": "wissenschaftlich",
    "wissenswerte": "wissenswert",
    "wissenswertem": "wissenswert",
    "wissenswerten": "wissenswert",
    "wissenswerter": "wissenswert",
    "wissenswertere": "wissenswert",
    "wissenswerterem": "wissenswert",
    "wissenswerteren": "wissenswert",
    "wissenswerterer": "wissenswert",
    "wissenswerteres": "wissenswert",
    "wissenswertes": "wissenswert",
    "wissenswerteste": "wissenswert",
    "wissenswertestem": "wissenswert",
    "wissenswertesten": "wissenswert",
    "wissenswertester": "wissenswert",
    "wissenswertestes": "wissenswert",
    "wissentliche": "wissentlich",
    "wissentlichem": "wissentlich",
    "wissentlichen": "wissentlich",
    "wissentlicher": "wissentlich",
    "wissentliches": "wissentlich",
    "wissest": "wissen",
    "wisset": "wissen",
    "wittere": "wittern",
    "witternd": "wittern",
    "witternde": "witternd",
    "witterndem": "witternd",
    "witternden": "witternd",
    "witternder": "witternd",
    "witterndere": "witternd",
    "witternderem": "witternd",
    "witternderen": "witternd",
    "witternderer": "witternd",
    "witternderes": "witternd",
    "witterndes": "witternd",
    "witterndste": "witternd",
    "witterndstem": "witternd",
    "witterndsten": "witternd",
    "witterndster": "witternd",
    "witterndstes": "witternd",
    "witterst": "wittern",
    "wittert": "wittern",
    "witterte": "wittern",
    "witterten": "wittern",
    "wittertest": "wittern",
    "wittertet": "wittern",
    "witzele": "witzeln",
    "witzelnd": "witzeln",
    "witzelnde": "witzelnd",
    "witzelndem": "witzelnd",
    "witzelnden": "witzelnd",
    "witzelnder": "witzelnd",
    "witzelndere": "witzelnd",
    "witzelnderem": "witzelnd",
    "witzelnderen": "witzelnd",
    "witzelnderer": "witzelnd",
    "witzelnderes": "witzelnd",
    "witzelndes": "witzelnd",
    "witzelndste": "witzelnd",
    "witzelndstem": "witzelnd",
    "witzelndsten": "witzelnd",
    "witzelndster": "witzelnd",
    "witzelndstes": "witzelnd",
    "witzelst": "witzeln",
    "witzelt": "witzeln",
    "witzelte": "witzeln",
    "witzelten": "witzeln",
    "witzeltest": "witzeln",
    "witzeltet": "witzeln",
    "witzigem": "witzig",
    "witzigen": "witzig",
    "witziger": "witzig",
    "witzigere": "witzig",
    "witzigerem": "witzig",
    "witzigeren": "witzig",
    "witzigerer": "witzig",
    "witzigeres": "witzig",
    "witziges": "witzig",
    "witzigste": "witzig",
    "witzigstem": "witzig",
    "witzigsten": "witzig",
    "witzigster": "witzig",
    "witzigstes": "witzig",
    "witzle": "witzeln",
    "witzlose": "witzlos",
    "witzlosem": "witzlos",
    "witzlosen": "witzlos",
    "witzloser": "witzlos",
    "witzlosere": "witzlos",
    "witzloserem": "witzlos",
    "witzloseren": "witzlos",
    "witzloserer": "witzlos",
    "witzloseres": "witzlos",
    "witzloses": "witzlos",
    "witzloseste": "witzlos",
    "witzlosestem": "witzlos",
    "witzlosesten": "witzlos",
    "witzlosester": "witzlos",
    "witzlosestes": "witzlos",
    "wißbegierige": "wißbegierig",
    "wißbegierigem": "wißbegierig",
    "wißbegierigen": "wißbegierig",
    "wißbegieriger": "wißbegierig",
    "wißbegierigere": "wißbegierig",
    "wißbegierigerem": "wißbegierig",
    "wißbegierigeren": "wißbegierig",
    "wißbegierigerer": "wißbegierig",
    "wißbegierigeres": "wißbegierig",
    "wißbegieriges": "wißbegierig",
    "wißbegierigste": "wißbegierig",
    "wißbegierigstem": "wißbegierig",
    "wißbegierigsten": "wißbegierig",
    "wißbegierigster": "wißbegierig",
    "wißbegierigstes": "wißbegierig",
    "wißt": "wissen",
    "wob": "weben",
    "woben": "weben",
    "wobst": "weben",
    "wobt": "weben",
    "wochenlangem": "wochenlang",
    "wochenlangen": "wochenlang",
    "wochenlanger": "wochenlang",
    "wochenlanges": "wochenlang",
    "wog": "wiegen",
    "wogen": "wiegen",
    "wogst": "wiegen",
    "wogt": "wiegen",
    "wohlanständige": "wohlanständig",
    "wohlanständigem": "wohlanständig",
    "wohlanständigen": "wohlanständig",
    "wohlanständiger": "wohlanständig",
    "wohlanständigere": "wohlanständig",
    "wohlanständigerem": "wohlanständig",
    "wohlanständigeren": "wohlanständig",
    "wohlanständigerer": "wohlanständig",
    "wohlanständigeres": "wohlanständig",
    "wohlanständiges": "wohlanständig",
    "wohlanständigste": "wohlanständig",
    "wohlanständigstem": "wohlanständig",
    "wohlanständigsten": "wohlanständig",
    "wohlanständigster": "wohlanständig",
    "wohlanständigstes": "wohlanständig",
    "wohlbedachte": "wohlbedacht",
    "wohlbedachtem": "wohlbedacht",
    "wohlbedachten": "wohlbedacht",
    "wohlbedachter": "wohlbedacht",
    "wohlbedachtes": "wohlbedacht",
    "wohlbehütetem": "wohlbehütet",
    "wohlbehüteten": "wohlbehütet",
    "wohlbehüteter": "wohlbehütet",
    "wohlbehütetes": "wohlbehütet",
    "wohle": "wohl",
    "wohlem": "wohl",
    "wohlen": "wohl",
    "wohler": "wohl",
    "wohlere": "wohl",
    "wohlerem": "wohl",
    "wohleren": "wohl",
    "wohlerer": "wohl",
    "wohleres": "wohl",
    "wohlgenährtem": "wohlgenährt",
    "wohlgenährten": "wohlgenährt",
    "wohlgenährter": "wohlgenährt",
    "wohlgenährtere": "wohlgenährt",
    "wohlgenährterem": "wohlgenährt",
    "wohlgenährteren": "wohlgenährt",
    "wohlgenährterer": "wohlgenährt",
    "wohlgenährteres": "wohlgenährt",
    "wohlgenährtes": "wohlgenährt",
    "wohlgenährteste": "wohlgenährt",
    "wohlgenährtestem": "wohlgenährt",
    "wohlgenährtesten": "wohlgenährt",
    "wohlgenährtester": "wohlgenährt",
    "wohlgenährtestes": "wohlgenährt",
    "wohlhabendem": "wohlhabend",
    "wohlhabenden": "wohlhabend",
    "wohlhabender": "wohlhabend",
    "wohlhabendere": "wohlhabend",
    "wohlhabenderem": "wohlhabend",
    "wohlhabenderen": "wohlhabend",
    "wohlhabenderer": "wohlhabend",
    "wohlhabenderes": "wohlhabend",
    "wohlhabendes": "wohlhabend",
    "wohlhabendste": "wohlhabend",
    "wohlhabendstem": "wohlhabend",
    "wohlhabendsten": "wohlhabend",
    "wohlhabendster": "wohlhabend",
    "wohlhabendstes": "wohlhabend",
    "wohlige": "wohlig",
    "wohligem": "wohlig",
    "wohligen": "wohlig",
    "wohliger": "wohlig",
    "wohliges": "wohlig",
    "wohlklingende": "wohlklingend",
    "wohlklingendem": "wohlklingend",
    "wohlklingenden": "wohlklingend",
    "wohlklingender": "wohlklingend",
    "wohlklingendes": "wohlklingend",
    "wohllautende": "wohllautend",
    "wohllautendem": "wohllautend",
    "wohllautenden": "wohllautend",
    "wohllautender": "wohllautend",
    "wohllautendes": "wohllautend",
    "wohlriechende": "wohlriechend",
    "wohlriechendem": "wohlriechend",
    "wohlriechenden": "wohlriechend",
    "wohlriechender": "wohlriechend",
    "wohlriechendere": "wohlriechend",
    "wohlriechenderem": "wohlriechend",
    "wohlriechenderen": "wohlriechend",
    "wohlriechenderer": "wohlriechend",
    "wohlriechenderes": "wohlriechend",
    "wohlriechendes": "wohlriechend",
    "wohlriechendste": "wohlriechend",
    "wohlriechendstem": "wohlriechend",
    "wohlriechendsten": "wohlriechend",
    "wohlriechendster": "wohlriechend",
    "wohlriechendstes": "wohlriechend",
    "wohlstem": "wohl",
    "wohlsten": "wohl",
    "wohlster": "wohl",
    "wohlstes": "wohl",
    "wohltemperierte": "wohltemperiert",
    "wohltemperiertem": "wohltemperiert",
    "wohltemperierten": "wohltemperiert",
    "wohltemperierter": "wohltemperiert",
    "wohltemperiertes": "wohltemperiert",
    "wohltuende": "wohltuend",
    "wohltuendem": "wohltuend",
    "wohltuenden": "wohltuend",
    "wohltuender": "wohltuend",
    "wohltuendere": "wohltuend",
    "wohltuenderem": "wohltuend",
    "wohltuenderen": "wohltuend",
    "wohltuenderer": "wohltuend",
    "wohltuenderes": "wohltuend",
    "wohltuendes": "wohltuend",
    "wohltuendste": "wohltuend",
    "wohltuendstem": "wohltuend",
    "wohltuendsten": "wohltuend",
    "wohltuendster": "wohltuend",
    "wohltuendstes": "wohltuend",
    "wohltätige": "wohltätig",
    "wohltätigem": "wohltätig",
    "wohltätigen": "wohltätig",
    "wohltätiger": "wohltätig",
    "wohltätiges": "wohltätig",
    "wohlverdiente": "wohlverdient",
    "wohlverdientem": "wohlverdient",
    "wohlverdienten": "wohlverdient",
    "wohlverdienter": "wohlverdient",
    "wohlverdientes": "wohlverdient",
    "wohnberechtigtem": "wohnberechtigt",
    "wohnberechtigten": "wohnberechtigt",
    "wohnberechtigter": "wohnberechtigt",
    "wohnberechtigtes": "wohnberechtigt",
    "wohne": "wohnen",
    "wohnend": "wohnen",
    "wohnende": "wohnend",
    "wohnendem": "wohnend",
    "wohnenden": "wohnend",
    "wohnender": "wohnend",
    "wohnendes": "wohnend",
    "wohnest": "wohnen",
    "wohnet": "wohnen",
    "wohnlichem": "wohnlich",
    "wohnlichen": "wohnlich",
    "wohnlicher": "wohnlich",
    "wohnlichere": "wohnlich",
    "wohnlicherem": "wohnlich",
    "wohnlicheren": "wohnlich",
    "wohnlicherer": "wohnlich",
    "wohnlicheres": "wohnlich",
    "wohnliches": "wohnlich",
    "wohnlichste": "wohnlich",
    "wohnlichstem": "wohnlich",
    "wohnlichsten": "wohnlich",
    "wohnlichster": "wohnlich",
    "wohnlichstes": "wohnlich",
    "wohnsitzlosem": "wohnsitzlos",
    "wohnsitzlosen": "wohnsitzlos",
    "wohnsitzloser": "wohnsitzlos",
    "wohnsitzloses": "wohnsitzlos",
    "wohnst": "wohnen",
    "wohnt": "wohnen",
    "wohnte": "wohnen",
    "wohnten": "wohnen",
    "wohntest": "wohnen",
    "wohntet": "wohnen",
    "wolkenlosem": "wolkenlos",
    "wolkenlosen": "wolkenlos",
    "wolkenloser": "wolkenlos",
    "wolkenloses": "wolkenlos",
    "wolkenverhangene": "wolkenverhangen",
    "wolkenverhangenem": "wolkenverhangen",
    "wolkenverhangenen": "wolkenverhangen",
    "wolkenverhangener": "wolkenverhangen",
    "wolkenverhangenes": "wolkenverhangen",
    "wolkige": "wolkig",
    "wolkigem": "wolkig",
    "wolkigen": "wolkig",
    "wolkiger": "wolkig",
    "wolkiges": "wolkig",
    "wollest": "wollen",
    "wollet": "wollen",
    "wollt": "wollen",
    "wollte": "wollen",
    "wollten": "wollen",
    "wolltest": "wollen",
    "wolltet": "wollen",
    "wollüstigem": "wollüstig",
    "wollüstigen": "wollüstig",
    "wollüstiger": "wollüstig",
    "wollüstigere": "wollüstig",
    "wollüstigerem": "wollüstig",
    "wollüstigeren": "wollüstig",
    "wollüstigerer": "wollüstig",
    "wollüstigeres": "wollüstig",
    "wollüstiges": "wollüstig",
    "wollüstigste": "wollüstig",
    "wollüstigstem": "wollüstig",
    "wollüstigsten": "wollüstig",
    "wollüstigster": "wollüstig",
    "wollüstigstes": "wollüstig",
    "wonnevollem": "wonnevoll",
    "wonnevollen": "wonnevoll",
    "wonnevoller": "wonnevoll",
    "wonnevollere": "wonnevoll",
    "wonnevollerem": "wonnevoll",
    "wonnevolleren": "wonnevoll",
    "wonnevollerer": "wonnevoll",
    "wonnevolleres": "wonnevoll",
    "wonnevolles": "wonnevoll",
    "wonnevollste": "wonnevoll",
    "wonnevollstem": "wonnevoll",
    "wonnevollsten": "wonnevoll",
    "wonnevollster": "wonnevoll",
    "wonnevollstes": "wonnevoll",
    "worden": "werden",
    "wortbrüchigem": "wortbrüchig",
    "wortbrüchigen": "wortbrüchig",
    "wortbrüchiger": "wortbrüchig",
    "wortbrüchigere": "wortbrüchig",
    "wortbrüchigerem": "wortbrüchig",
    "wortbrüchigeren": "wortbrüchig",
    "wortbrüchigerer": "wortbrüchig",
    "wortbrüchigeres": "wortbrüchig",
    "wortbrüchiges": "wortbrüchig",
    "wortbrüchigste": "wortbrüchig",
    "wortbrüchigstem": "wortbrüchig",
    "wortbrüchigsten": "wortbrüchig",
    "wortbrüchigster": "wortbrüchig",
    "wortbrüchigstes": "wortbrüchig",
    "wortgetreuem": "wortgetreu",
    "wortgetreuen": "wortgetreu",
    "wortgetreuer": "wortgetreu",
    "wortgetreues": "wortgetreu",
    "wortkarge": "wortkarg",
    "wortkargem": "wortkarg",
    "wortkargen": "wortkarg",
    "wortkarger": "wortkarg",
    "wortkarges": "wortkarg",
    "wortkärger": "wortkarg",
    "wortkärgere": "wortkarg",
    "wortkärgerem": "wortkarg",
    "wortkärgeren": "wortkarg",
    "wortkärgerer": "wortkarg",
    "wortkärgeres": "wortkarg",
    "wortkärgsten": "wortkarg",
    "wortlose": "wortlos",
    "wortlosem": "wortlos",
    "wortlosen": "wortlos",
    "wortloser": "wortlos",
    "wortloses": "wortlos",
    "wortwörtlichem": "wortwörtlich",
    "wortwörtlichen": "wortwörtlich",
    "wortwörtlicher": "wortwörtlich",
    "wortwörtliches": "wortwörtlich",
    "wrang": "wringen",
    "wrangen": "wringen",
    "wrangst": "wringen",
    "wrangt": "wringen",
    "wringe": "wringen",
    "wringend": "wringen",
    "wringende": "wringend",
    "wringendem": "wringend",
    "wringenden": "wringend",
    "wringender": "wringend",
    "wringendes": "wringend",
    "wringest": "wringen",
    "wringet": "wringen",
    "wringst": "wringen",
    "wringt": "wringen",
    "wränge": "wringen",
    "wrängen": "wringen",
    "wrängest": "wringen",
    "wränget": "wringen",
    "wuchere": "wuchern",
    "wuchernd": "wuchern",
    "wuchernde": "wuchernd",
    "wucherndem": "wuchernd",
    "wuchernden": "wuchernd",
    "wuchernder": "wuchernd",
    "wucherndere": "wuchernd",
    "wuchernderem": "wuchernd",
    "wuchernderen": "wuchernd",
    "wuchernderer": "wuchernd",
    "wuchernderes": "wuchernd",
    "wucherndes": "wuchernd",
    "wucherndste": "wuchernd",
    "wucherndstem": "wuchernd",
    "wucherndsten": "wuchernd",
    "wucherndster": "wuchernd",
    "wucherndstes": "wuchernd",
    "wucherst": "wuchern",
    "wuchert": "wuchern",
    "wucherte": "wuchern",
    "wucherten": "wuchern",
    "wuchertest": "wuchern",
    "wuchertet": "wuchern",
    "wuchs": "wachsen",
    "wuchsen": "wachsen",
    "wuchst": "wachsen",
    "wuchte": "wuchten",
    "wuchtend": "wuchten",
    "wuchtende": "wuchtend",
    "wuchtendem": "wuchtend",
    "wuchtenden": "wuchtend",
    "wuchtender": "wuchtend",
    "wuchtendere": "wuchtend",
    "wuchtenderem": "wuchtend",
    "wuchtenderen": "wuchtend",
    "wuchtenderer": "wuchtend",
    "wuchtenderes": "wuchtend",
    "wuchtendes": "wuchtend",
    "wuchtendste": "wuchtend",
    "wuchtendstem": "wuchtend",
    "wuchtendsten": "wuchtend",
    "wuchtendster": "wuchtend",
    "wuchtendstes": "wuchtend",
    "wuchtest": "wuchten",
    "wuchtet": "wuchten",
    "wuchtete": "wuchten",
    "wuchteten": "wuchten",
    "wuchtetest": "wuchten",
    "wuchtetet": "wuchten",
    "wuchtige": "wuchtig",
    "wuchtigem": "wuchtig",
    "wuchtigen": "wuchtig",
    "wuchtiger": "wuchtig",
    "wuchtigere": "wuchtig",
    "wuchtigerem": "wuchtig",
    "wuchtigeren": "wuchtig",
    "wuchtigerer": "wuchtig",
    "wuchtigeres": "wuchtig",
    "wuchtiges": "wuchtig",
    "wuchtigste": "wuchtig",
    "wuchtigstem": "wuchtig",
    "wuchtigsten": "wuchtig",
    "wuchtigster": "wuchtig",
    "wuchtigstes": "wuchtig",
    "wulstigem": "wulstig",
    "wulstigen": "wulstig",
    "wulstiger": "wulstig",
    "wulstigere": "wulstig",
    "wulstigerem": "wulstig",
    "wulstigeren": "wulstig",
    "wulstigerer": "wulstig",
    "wulstigeres": "wulstig",
    "wulstiges": "wulstig",
    "wulstigste": "wulstig",
    "wulstigstem": "wulstig",
    "wulstigsten": "wulstig",
    "wulstigster": "wulstig",
    "wulstigstes": "wulstig",
    "wundem": "wund",
    "wunden": "wund",
    "wunder": "wundern",
    "wunderbarem": "wunderbar",
    "wunderbaren": "wunderbar",
    "wunderbarer": "wunderbar",
    "wunderbarere": "wunderbar",
    "wunderbarerem": "wunderbar",
    "wunderbareren": "wunderbar",
    "wunderbarerer": "wunderbar",
    "wunderbareres": "wunderbar",
    "wunderbares": "wunderbar",
    "wunderbarste": "wunderbar",
    "wunderbarstem": "wunderbar",
    "wunderbarsten": "wunderbar",
    "wunderbarster": "wunderbar",
    "wunderbarstes": "wunderbar",
    "wundere": "wund",
    "wunderem": "wund",
    "wunderen": "wund",
    "wunderer": "wund",
    "wunderes": "wund",
    "wunderhübsche": "wunderhübsch",
    "wunderhübschem": "wunderhübsch",
    "wunderhübschen": "wunderhübsch",
    "wunderhübscher": "wunderhübsch",
    "wunderhübsches": "wunderhübsch",
    "wundernd": "wundern",
    "wundernde": "wundernd",
    "wunderndem": "wundernd",
    "wundernden": "wundernd",
    "wundernder": "wundernd",
    "wunderndere": "wundernd",
    "wundernderem": "wundernd",
    "wundernderen": "wundernd",
    "wundernderer": "wundernd",
    "wundernderes": "wundernd",
    "wunderndes": "wundernd",
    "wunderndste": "wundernd",
    "wunderndstem": "wundernd",
    "wunderndsten": "wundernd",
    "wunderndster": "wundernd",
    "wunderndstes": "wundernd",
    "wundersamem": "wundersam",
    "wundersamen": "wundersam",
    "wundersamer": "wundersam",
    "wundersamere": "wundersam",
    "wundersamerem": "wundersam",
    "wundersameren": "wundersam",
    "wundersamerer": "wundersam",
    "wundersameres": "wundersam",
    "wundersames": "wundersam",
    "wundersamste": "wundersam",
    "wundersamstem": "wundersam",
    "wundersamsten": "wundersam",
    "wundersamster": "wundersam",
    "wundersamstes": "wundersam",
    "wunderschöne": "wunderschön",
    "wunderschönem": "wunderschön",
    "wunderschönen": "wunderschön",
    "wunderschöner": "wunderschön",
    "wunderschönere": "wunderschön",
    "wunderschönerem": "wunderschön",
    "wunderschöneren": "wunderschön",
    "wunderschönerer": "wunderschön",
    "wunderschöneres": "wunderschön",
    "wunderschönes": "wunderschön",
    "wunderschönste": "wunderschön",
    "wunderschönstem": "wunderschön",
    "wunderschönsten": "wunderschön",
    "wunderschönster": "wunderschön",
    "wunderschönstes": "wunderschön",
    "wunderst": "wundern",
    "wundert": "wundern",
    "wunderte": "wundern",
    "wunderten": "wundern",
    "wundertest": "wundern",
    "wundertet": "wundern",
    "wundervolle": "wundervoll",
    "wundervollem": "wundervoll",
    "wundervollen": "wundervoll",
    "wundervoller": "wundervoll",
    "wundervollere": "wundervoll",
    "wundervollerem": "wundervoll",
    "wundervolleren": "wundervoll",
    "wundervollerer": "wundervoll",
    "wundervolleres": "wundervoll",
    "wundervolles": "wundervoll",
    "wundervollste": "wundervoll",
    "wundervollstem": "wundervoll",
    "wundervollsten": "wundervoll",
    "wundervollster": "wundervoll",
    "wundervollstes": "wundervoll",
    "wundes": "wund",
    "wundeste": "wund",
    "wundestem": "wund",
    "wundesten": "wund",
    "wundester": "wund",
    "wundestes": "wund",
    "wunschgemäße": "wunschgemäß",
    "wunschgemäßem": "wunschgemäß",
    "wunschgemäßen": "wunschgemäß",
    "wunschgemäßer": "wunschgemäß",
    "wunschgemäßes": "wunschgemäß",
    "wunschlose": "wunschlos",
    "wunschlosem": "wunschlos",
    "wunschlosen": "wunschlos",
    "wunschloser": "wunschlos",
    "wunschloses": "wunschlos",
    "wurde": "werden",
    "wurden": "werden",
    "wurdest": "werden",
    "wurdet": "werden",
    "wurmend": "wurmen",
    "wurmende": "wurmend",
    "wurmendem": "wurmend",
    "wurmenden": "wurmend",
    "wurmender": "wurmend",
    "wurmendere": "wurmend",
    "wurmenderem": "wurmend",
    "wurmenderen": "wurmend",
    "wurmenderer": "wurmend",
    "wurmenderes": "wurmend",
    "wurmendes": "wurmend",
    "wurmendste": "wurmend",
    "wurmendstem": "wurmend",
    "wurmendsten": "wurmend",
    "wurmendster": "wurmend",
    "wurmendstes": "wurmend",
    "wurmest": "wurmen",
    "wurmet": "wurmen",
    "wurmst": "wurmen",
    "wurmstichige": "wurmstichig",
    "wurmstichigem": "wurmstichig",
    "wurmstichigen": "wurmstichig",
    "wurmstichiger": "wurmstichig",
    "wurmstichiges": "wurmstichig",
    "wurmt": "wurmen",
    "wurmte": "wurmen",
    "wurmten": "wurmen",
    "wurmtest": "wurmen",
    "wurmtet": "wurmen",
    "wurste": "wursten",
    "wurstele": "wursteln",
    "wurstelnd": "wursteln",
    "wurstelnde": "wurstelnd",
    "wurstelndem": "wurstelnd",
    "wurstelnden": "wurstelnd",
    "wurstelnder": "wurstelnd",
    "wurstelndere": "wurstelnd",
    "wurstelnderem": "wurstelnd",
    "wurstelnderen": "wurstelnd",
    "wurstelnderer": "wurstelnd",
    "wurstelnderes": "wurstelnd",
    "wurstelndes": "wurstelnd",
    "wurstelndste": "wurstelnd",
    "wurstelndstem": "wurstelnd",
    "wurstelndsten": "wurstelnd",
    "wurstelndster": "wurstelnd",
    "wurstelndstes": "wurstelnd",
    "wurstelst": "wursteln",
    "wurstelt": "wursteln",
    "wurstelte": "wursteln",
    "wurstelten": "wursteln",
    "wursteltest": "wursteln",
    "wursteltet": "wursteln",
    "wurstend": "wursten",
    "wurstende": "wurstend",
    "wurstendem": "wurstend",
    "wurstenden": "wurstend",
    "wurstender": "wurstend",
    "wurstendere": "wurstend",
    "wurstenderem": "wurstend",
    "wurstenderen": "wurstend",
    "wurstenderer": "wurstend",
    "wurstenderes": "wurstend",
    "wurstendes": "wurstend",
    "wurstendste": "wurstend",
    "wurstendstem": "wurstend",
    "wurstendsten": "wurstend",
    "wurstendster": "wurstend",
    "wurstendstes": "wurstend",
    "wurstest": "wursten",
    "wurstet": "wursten",
    "wurstete": "wursten",
    "wursteten": "wursten",
    "wurstetest": "wursten",
    "wurstetet": "wursten",
    "wurstle": "wursteln",
    "wurzele": "wurzeln",
    "wurzelnd": "wurzeln",
    "wurzelnde": "wurzelnd",
    "wurzelndem": "wurzelnd",
    "wurzelnden": "wurzelnd",
    "wurzelnder": "wurzelnd",
    "wurzelndes": "wurzelnd",
    "wurzelst": "wurzeln",
    "wurzelt": "wurzeln",
    "wurzelte": "wurzeln",
    "wurzelten": "wurzeln",
    "wurzeltest": "wurzeln",
    "wurzeltet": "wurzeln",
    "wurzle": "wurzeln",
    "wusch": "waschen",
    "wuschelige": "wuschelig",
    "wuscheligem": "wuschelig",
    "wuscheligen": "wuschelig",
    "wuscheliger": "wuschelig",
    "wuscheligere": "wuschelig",
    "wuscheligerem": "wuschelig",
    "wuscheligeren": "wuschelig",
    "wuscheligerer": "wuschelig",
    "wuscheligeres": "wuschelig",
    "wuscheliges": "wuschelig",
    "wuscheligste": "wuschelig",
    "wuscheligstem": "wuschelig",
    "wuscheligsten": "wuschelig",
    "wuscheligster": "wuschelig",
    "wuscheligstes": "wuschelig",
    "wuschen": "waschen",
    "wuschst": "waschen",
    "wuscht": "waschen",
    "wusele": "wuseln",
    "wuselige": "wuselig",
    "wuseligem": "wuselig",
    "wuseligen": "wuselig",
    "wuseliger": "wuselig",
    "wuseligere": "wuselig",
    "wuseligerem": "wuselig",
    "wuseligeren": "wuselig",
    "wuseligerer": "wuselig",
    "wuseligeres": "wuselig",
    "wuseliges": "wuselig",
    "wuseligste": "wuselig",
    "wuseligstem": "wuselig",
    "wuseligsten": "wuselig",
    "wuseligster": "wuselig",
    "wuseligstes": "wuselig",
    "wuselnd": "wuseln",
    "wuselnde": "wuselnd",
    "wuselndem": "wuselnd",
    "wuselnden": "wuselnd",
    "wuselnder": "wuselnd",
    "wuselndere": "wuselnd",
    "wuselnderem": "wuselnd",
    "wuselnderen": "wuselnd",
    "wuselnderer": "wuselnd",
    "wuselnderes": "wuselnd",
    "wuselndes": "wuselnd",
    "wuselndste": "wuselnd",
    "wuselndstem": "wuselnd",
    "wuselndsten": "wuselnd",
    "wuselndster": "wuselnd",
    "wuselndstes": "wuselnd",
    "wuselst": "wuseln",
    "wuselt": "wuseln",
    "wuselte": "wuseln",
    "wuselten": "wuseln",
    "wuseltest": "wuseln",
    "wuseltet": "wuseln",
    "wusle": "wuseln",
    "wutentbranntem": "wutentbrannt",
    "wutentbrannten": "wutentbrannt",
    "wutentbrannter": "wutentbrannt",
    "wutentbranntes": "wutentbrannt",
    "wutschäumende": "wutschäumend",
    "wutschäumendem": "wutschäumend",
    "wutschäumenden": "wutschäumend",
    "wutschäumender": "wutschäumend",
    "wutschäumendere": "wutschäumend",
    "wutschäumenderem": "wutschäumend",
    "wutschäumenderen": "wutschäumend",
    "wutschäumenderer": "wutschäumend",
    "wutschäumenderes": "wutschäumend",
    "wutschäumendes": "wutschäumend",
    "wutschäumendste": "wutschäumend",
    "wutschäumendstem": "wutschäumend",
    "wutschäumendsten": "wutschäumend",
    "wutschäumendster": "wutschäumend",
    "wutschäumendstes": "wutschäumend",
    "wußte": "wissen",
    "wußten": "wissen",
    "wußtest": "wissen",
    "wußtet": "wissen",
    "wächst": "wachsen",
    "wäge": "wägen",
    "wägend": "wägen",
    "wägendem": "wägend",
    "wägender": "wägend",
    "wägendes": "wägend",
    "wägest": "wägen",
    "wäget": "wägen",
    "wägst": "wägen",
    "wägt": "wägen",
    "wählbare": "wählbar",
    "wählbarem": "wählbar",
    "wählbaren": "wählbar",
    "wählbarer": "wählbar",
    "wählbares": "wählbar",
    "wähle": "wählen",
    "wählend": "wählen",
    "wählende": "wählend",
    "wählendem": "wählend",
    "wählenden": "wählend",
    "wählender": "wählend",
    "wählendes": "wählend",
    "wählerischem": "wählerisch",
    "wählerischen": "wählerisch",
    "wählerischer": "wählerisch",
    "wählerischere": "wählerisch",
    "wählerischerem": "wählerisch",
    "wählerischeren": "wählerisch",
    "wählerischerer": "wählerisch",
    "wählerischeres": "wählerisch",
    "wählerisches": "wählerisch",
    "wählerischste": "wählerisch",
    "wählerischstem": "wählerisch",
    "wählerischsten": "wählerisch",
    "wählerischster": "wählerisch",
    "wählerischstes": "wählerisch",
    "wählest": "wählen",
    "wählet": "wählen",
    "wählst": "wählen",
    "wählt": "wählen",
    "wählte": "wählen",
    "wählten": "wählen",
    "wähltest": "wählen",
    "wähltet": "wählen",
    "wähne": "wähnen",
    "wähnend": "wähnen",
    "wähnende": "wähnend",
    "wähnendem": "wähnend",
    "wähnenden": "wähnend",
    "wähnender": "wähnend",
    "wähnendes": "wähnend",
    "wähnest": "wähnen",
    "wähnet": "wähnen",
    "wähnst": "wähnen",
    "wähnt": "wähnen",
    "wähnte": "wähnen",
    "wähnten": "wähnen",
    "wähntest": "wähnen",
    "wähntet": "wähnen",
    "währe": "währen",
    "währendem": "während",
    "währender": "während",
    "währendes": "während",
    "währest": "währen",
    "währet": "währen",
    "währst": "währen",
    "währt": "währen",
    "währte": "währen",
    "währten": "währen",
    "währtest": "währen",
    "währtet": "währen",
    "wälze": "wälzen",
    "wälzend": "wälzen",
    "wälzendem": "wälzend",
    "wälzender": "wälzend",
    "wälzenderem": "wälzend",
    "wälzenderer": "wälzend",
    "wälzenderes": "wälzend",
    "wälzendes": "wälzend",
    "wälzendstem": "wälzend",
    "wälzendster": "wälzend",
    "wälzendstes": "wälzend",
    "wälzest": "wälzen",
    "wälzet": "wälzen",
    "wälzt": "wälzen",
    "wälzte": "wälzen",
    "wälzten": "wälzen",
    "wälztest": "wälzen",
    "wälztet": "wälzen",
    "wändest": "winden",
    "wändet": "winden",
    "wärbe": "werben",
    "wärben": "werben",
    "wärbest": "werben",
    "wärbet": "werben",
    "wäre": "sein",
    "wären": "sein",
    "wärest": "sein",
    "wäret": "sein",
    "wärfe": "werfen",
    "wärfen": "werfen",
    "wärfest": "werfen",
    "wärfet": "werfen",
    "wärme": "wärmen",
    "wärmend": "wärmen",
    "wärmende": "wärmend",
    "wärmendem": "wärmend",
    "wärmenden": "wärmend",
    "wärmender": "wärmend",
    "wärmendere": "wärmend",
    "wärmenderem": "wärmend",
    "wärmenderen": "wärmend",
    "wärmenderer": "wärmend",
    "wärmenderes": "wärmend",
    "wärmendes": "wärmend",
    "wärmendste": "wärmend",
    "wärmendstem": "wärmend",
    "wärmendsten": "wärmend",
    "wärmendster": "wärmend",
    "wärmendstes": "wärmend",
    "wärmer": "warm",
    "wärmere": "warm",
    "wärmerem": "warm",
    "wärmeren": "warm",
    "wärmerer": "warm",
    "wärmeres": "warm",
    "wärmest": "wärmen",
    "wärmet": "wärmen",
    "wärmetechnische": "wärmetechnisch",
    "wärmetechnischem": "wärmetechnisch",
    "wärmetechnischen": "wärmetechnisch",
    "wärmetechnischer": "wärmetechnisch",
    "wärmetechnisches": "wärmetechnisch",
    "wärmst": "wärmen",
    "wärmste": "warm",
    "wärmstem": "warm",
    "wärmsten": "warm",
    "wärmster": "warm",
    "wärmstes": "warm",
    "wärmt": "wärmen",
    "wärmte": "wärmen",
    "wärmten": "wärmen",
    "wärmtest": "wärmen",
    "wärmtet": "wärmen",
    "wärst": "sein",
    "wärt": "sein",
    "wäschst": "waschen",
    "wäscht": "waschen",
    "wässere": "wässern",
    "wässerige": "wässerig",
    "wässerigem": "wässerig",
    "wässerigen": "wässerig",
    "wässeriger": "wässerig",
    "wässerigere": "wässerig",
    "wässerigerem": "wässerig",
    "wässerigeren": "wässerig",
    "wässerigerer": "wässerig",
    "wässerigeres": "wässerig",
    "wässeriges": "wässerig",
    "wässerigste": "wässerig",
    "wässerigstem": "wässerig",
    "wässerigsten": "wässerig",
    "wässerigster": "wässerig",
    "wässerigstes": "wässerig",
    "wässernd": "wässern",
    "wässernde": "wässernd",
    "wässerndem": "wässernd",
    "wässernden": "wässernd",
    "wässernder": "wässernd",
    "wässerndere": "wässernd",
    "wässernderem": "wässernd",
    "wässernderen": "wässernd",
    "wässernderer": "wässernd",
    "wässernderes": "wässernd",
    "wässerndes": "wässernd",
    "wässerndste": "wässernd",
    "wässerndstem": "wässernd",
    "wässerndsten": "wässernd",
    "wässerndster": "wässernd",
    "wässerndstes": "wässernd",
    "wässerst": "wässern",
    "wässert": "wässern",
    "wässerte": "wässern",
    "wässerten": "wässern",
    "wässertest": "wässern",
    "wässertet": "wässern",
    "wässrige": "wässrig",
    "wässrigen": "wässrig",
    "wässrigere": "wässrig",
    "wässrigeren": "wässrig",
    "wässrigeres": "wässrig",
    "wässrigste": "wässrig",
    "wässrigsten": "wässrig",
    "wässrigstes": "wässrig",
    "wäßrigem": "wäßrig",
    "wäßriger": "wäßrig",
    "wäßrigerem": "wäßrig",
    "wäßrigerer": "wäßrig",
    "wäßriges": "wäßrig",
    "wäßrigstem": "wäßrig",
    "wäßrigster": "wäßrig",
    "wöbe": "weben",
    "wöben": "weben",
    "wöbest": "weben",
    "wöbet": "weben",
    "wöchentlichem": "wöchentlich",
    "wöchentlichen": "wöchentlich",
    "wöchentlicher": "wöchentlich",
    "wöchentliches": "wöchentlich",
    "wöge": "wiegen",
    "wögen": "wiegen",
    "wögest": "wiegen",
    "wöget": "wiegen",
    "wölbe": "wölben",
    "wölbend": "wölben",
    "wölbende": "wölbend",
    "wölbendem": "wölbend",
    "wölbenden": "wölbend",
    "wölbender": "wölbend",
    "wölbendes": "wölbend",
    "wölbest": "wölben",
    "wölbet": "wölben",
    "wölbst": "wölben",
    "wölbt": "wölben",
    "wölbte": "wölben",
    "wölbten": "wölben",
    "wölbtest": "wölben",
    "wölbtet": "wölben",
    "wölfischem": "wölfisch",
    "wölfischen": "wölfisch",
    "wölfischer": "wölfisch",
    "wölfisches": "wölfisch",
    "wörtlichem": "wörtlich",
    "wörtlichen": "wörtlich",
    "wörtlicher": "wörtlich",
    "wörtliches": "wörtlich",
    "wüchsen": "wachsen",
    "wüchsest": "wachsen",
    "wüchset": "wachsen",
    "wühle": "wühlen",
    "wühlend": "wühlen",
    "wühlende": "wühlend",
    "wühlendem": "wühlend",
    "wühlenden": "wühlend",
    "wühlender": "wühlend",
    "wühlendere": "wühlend",
    "wühlenderem": "wühlend",
    "wühlenderen": "wühlend",
    "wühlenderer": "wühlend",
    "wühlenderes": "wühlend",
    "wühlendes": "wühlend",
    "wühlendste": "wühlend",
    "wühlendstem": "wühlend",
    "wühlendsten": "wühlend",
    "wühlendster": "wühlend",
    "wühlendstes": "wühlend",
    "wühlest": "wühlen",
    "wühlet": "wühlen",
    "wühlst": "wühlen",
    "wühlt": "wühlen",
    "wühlte": "wühlen",
    "wühlten": "wühlen",
    "wühltest": "wühlen",
    "wühltet": "wühlen",
    "wünschend": "wünschen",
    "wünschende": "wünschend",
    "wünschendem": "wünschend",
    "wünschenden": "wünschend",
    "wünschender": "wünschend",
    "wünschendes": "wünschend",
    "wünschenswertem": "wünschenswert",
    "wünschenswerten": "wünschenswert",
    "wünschenswerter": "wünschenswert",
    "wünschenswertere": "wünschenswert",
    "wünschenswerterem": "wünschenswert",
    "wünschenswerteren": "wünschenswert",
    "wünschenswerterer": "wünschenswert",
    "wünschenswerteres": "wünschenswert",
    "wünschenswertes": "wünschenswert",
    "wünschenswerteste": "wünschenswert",
    "wünschenswertestem": "wünschenswert",
    "wünschenswertesten": "wünschenswert",
    "wünschenswertester": "wünschenswert",
    "wünschenswertestes": "wünschenswert",
    "wünschest": "wünschen",
    "wünschet": "wünschen",
    "wünschst": "wünschen",
    "wünscht": "wünschen",
    "wünschte": "wünschen",
    "wünschten": "wünschen",
    "wünschtest": "wünschen",
    "wünschtet": "wünschen",
    "würde": "werden",
    "würdelosem": "würdelos",
    "würdelosen": "würdelos",
    "würdeloser": "würdelos",
    "würdelosere": "würdelos",
    "würdeloserem": "würdelos",
    "würdeloseren": "würdelos",
    "würdeloserer": "würdelos",
    "würdeloseres": "würdelos",
    "würdeloses": "würdelos",
    "würdeloseste": "würdelos",
    "würdelosestem": "würdelos",
    "würdelosesten": "würdelos",
    "würdelosester": "würdelos",
    "würdelosestes": "würdelos",
    "würden": "werden",
    "würdest": "werden",
    "würdet": "werden",
    "würdevolle": "würdevoll",
    "würdevollem": "würdevoll",
    "würdevollen": "würdevoll",
    "würdevoller": "würdevoll",
    "würdevollere": "würdevoll",
    "würdevollerem": "würdevoll",
    "würdevolleren": "würdevoll",
    "würdevollerer": "würdevoll",
    "würdevolleres": "würdevoll",
    "würdevolles": "würdevoll",
    "würdevollste": "würdevoll",
    "würdevollstem": "würdevoll",
    "würdevollsten": "würdevoll",
    "würdevollster": "würdevoll",
    "würdevollstes": "würdevoll",
    "würdige": "würdigen",
    "würdigend": "würdigen",
    "würdigende": "würdigend",
    "würdigendem": "würdigend",
    "würdigenden": "würdigend",
    "würdigender": "würdigend",
    "würdigendes": "würdigend",
    "würdigest": "würdigen",
    "würdiget": "würdigen",
    "würdigst": "würdigen",
    "würdigt": "würdigen",
    "würdigte": "würdigen",
    "würdigten": "würdigen",
    "würdigtest": "würdigen",
    "würdigtet": "würdigen",
    "würfele": "würfeln",
    "würfelnd": "würfeln",
    "würfelnde": "würfelnd",
    "würfelndem": "würfelnd",
    "würfelnden": "würfelnd",
    "würfelnder": "würfelnd",
    "würfelndere": "würfelnd",
    "würfelnderem": "würfelnd",
    "würfelnderen": "würfelnd",
    "würfelnderer": "würfelnd",
    "würfelnderes": "würfelnd",
    "würfelndes": "würfelnd",
    "würfelndste": "würfelnd",
    "würfelndstem": "würfelnd",
    "würfelndsten": "würfelnd",
    "würfelndster": "würfelnd",
    "würfelndstes": "würfelnd",
    "würfelst": "würfeln",
    "würfelt": "würfeln",
    "würfelte": "würfeln",
    "würfelten": "würfeln",
    "würfeltest": "würfeln",
    "würfeltet": "würfeln",
    "würfle": "würfeln",
    "würge": "würgen",
    "würgend": "würgen",
    "würgende": "würgend",
    "würgendem": "würgend",
    "würgenden": "würgend",
    "würgender": "würgend",
    "würgendere": "würgend",
    "würgenderem": "würgend",
    "würgenderen": "würgend",
    "würgenderer": "würgend",
    "würgenderes": "würgend",
    "würgendes": "würgend",
    "würgendste": "würgend",
    "würgendstem": "würgend",
    "würgendsten": "würgend",
    "würgendster": "würgend",
    "würgendstes": "würgend",
    "würgest": "würgen",
    "würget": "würgen",
    "würgst": "würgen",
    "würgt": "würgen",
    "würgte": "würgen",
    "würgten": "würgen",
    "würgtest": "würgen",
    "würgtet": "würgen",
    "württembergische": "württembergisch",
    "württembergischem": "württembergisch",
    "württembergischen": "württembergisch",
    "württembergischer": "württembergisch",
    "württembergisches": "württembergisch",
    "würze": "würzen",
    "würzend": "würzen",
    "würzende": "würzend",
    "würzendem": "würzend",
    "würzenden": "würzend",
    "würzender": "würzend",
    "würzendere": "würzend",
    "würzenderem": "würzend",
    "würzenderen": "würzend",
    "würzenderer": "würzend",
    "würzenderes": "würzend",
    "würzendes": "würzend",
    "würzendste": "würzend",
    "würzendstem": "würzend",
    "würzendsten": "würzend",
    "würzendster": "würzend",
    "würzendstes": "würzend",
    "würzest": "würzen",
    "würzet": "würzen",
    "würzige": "würzig",
    "würzigem": "würzig",
    "würzigen": "würzig",
    "würziger": "würzig",
    "würzigere": "würzig",
    "würzigerem": "würzig",
    "würzigeren": "würzig",
    "würzigerer": "würzig",
    "würzigeres": "würzig",
    "würziges": "würzig",
    "würzigste": "würzig",
    "würzigstem": "würzig",
    "würzigsten": "würzig",
    "würzigster": "würzig",
    "würzigstes": "würzig",
    "würzt": "würzen",
    "würzte": "würzen",
    "würzten": "würzen",
    "würztest": "würzen",
    "würztet": "würzen",
    "wüsche": "waschen",
    "wüschen": "waschen",
    "wüschest": "waschen",
    "wüschet": "waschen",
    "wüste": "wüst",
    "wüstem": "wüst",
    "wüsten": "wüst",
    "wüster": "wüst",
    "wüstere": "wüst",
    "wüsterem": "wüst",
    "wüsteren": "wüst",
    "wüsterer": "wüst",
    "wüsteres": "wüst",
    "wüstes": "wüst",
    "wüsteste": "wüst",
    "wüstestem": "wüst",
    "wüstesten": "wüst",
    "wüstester": "wüst",
    "wüstestes": "wüst",
    "wüte": "wüten",
    "wütend": "wüten",
    "wütende": "wütend",
    "wütendem": "wütend",
    "wütenden": "wütend",
    "wütender": "wütend",
    "wütendere": "wütend",
    "wütenderem": "wütend",
    "wütenderen": "wütend",
    "wütenderer": "wütend",
    "wütenderes": "wütend",
    "wütendes": "wütend",
    "wütendste": "wütend",
    "wütendstem": "wütend",
    "wütendsten": "wütend",
    "wütendster": "wütend",
    "wütendstes": "wütend",
    "wütest": "wüten",
    "wütet": "wüten",
    "wütete": "wüten",
    "wüteten": "wüten",
    "wütetest": "wüten",
    "wütetet": "wüten",
    "wüßte": "wissen",
    "wüßten": "wissen",
    "wüßtest": "wissen",
    "wüßtet": "wissen",
    "zage": "zagen",
    "zagend": "zagen",
    "zagende": "zagend",
    "zagendem": "zagend",
    "zagenden": "zagend",
    "zagender": "zagend",
    "zagendere": "zagend",
    "zagenderem": "zagend",
    "zagenderen": "zagend",
    "zagenderer": "zagend",
    "zagenderes": "zagend",
    "zagendes": "zagend",
    "zagendste": "zagend",
    "zagendstem": "zagend",
    "zagendsten": "zagend",
    "zagendster": "zagend",
    "zagendstes": "zagend",
    "zagest": "zagen",
    "zaget": "zagen",
    "zaghafte": "zaghaft",
    "zaghaftem": "zaghaft",
    "zaghaften": "zaghaft",
    "zaghafter": "zaghaft",
    "zaghaftere": "zaghaft",
    "zaghafterem": "zaghaft",
    "zaghafteren": "zaghaft",
    "zaghafterer": "zaghaft",
    "zaghafteres": "zaghaft",
    "zaghaftes": "zaghaft",
    "zaghafteste": "zaghaft",
    "zaghaftestem": "zaghaft",
    "zaghaftesten": "zaghaft",
    "zaghaftester": "zaghaft",
    "zaghaftestes": "zaghaft",
    "zagst": "zagen",
    "zagt": "zagen",
    "zagte": "zagen",
    "zagten": "zagen",
    "zagtest": "zagen",
    "zagtet": "zagen",
    "zahle": "zahlen",
    "zahlend": "zahlen",
    "zahlende": "zahlend",
    "zahlendem": "zahlend",
    "zahlenden": "zahlend",
    "zahlender": "zahlend",
    "zahlendes": "zahlend",
    "zahlest": "zahlen",
    "zahlet": "zahlen",
    "zahllose": "zahllos",
    "zahllosem": "zahllos",
    "zahllosen": "zahllos",
    "zahlloser": "zahllos",
    "zahlloses": "zahllos",
    "zahlreichem": "zahlreich",
    "zahlreichen": "zahlreich",
    "zahlreicher": "zahlreich",
    "zahlreichere": "zahlreich",
    "zahlreicherem": "zahlreich",
    "zahlreicheren": "zahlreich",
    "zahlreicherer": "zahlreich",
    "zahlreicheres": "zahlreich",
    "zahlreiches": "zahlreich",
    "zahlreichste": "zahlreich",
    "zahlreichstem": "zahlreich",
    "zahlreichsten": "zahlreich",
    "zahlreichster": "zahlreich",
    "zahlreichstes": "zahlreich",
    "zahlst": "zahlen",
    "zahlt": "zahlen",
    "zahlte": "zahlen",
    "zahlten": "zahlen",
    "zahltest": "zahlen",
    "zahltet": "zahlen",
    "zahlungsfähigem": "zahlungsfähig",
    "zahlungsfähigen": "zahlungsfähig",
    "zahlungsfähiger": "zahlungsfähig",
    "zahlungsfähigere": "zahlungsfähig",
    "zahlungsfähigerem": "zahlungsfähig",
    "zahlungsfähigeren": "zahlungsfähig",
    "zahlungsfähigerer": "zahlungsfähig",
    "zahlungsfähigeres": "zahlungsfähig",
    "zahlungsfähiges": "zahlungsfähig",
    "zahlungsfähigste": "zahlungsfähig",
    "zahlungsfähigstem": "zahlungsfähig",
    "zahlungsfähigsten": "zahlungsfähig",
    "zahlungsfähigster": "zahlungsfähig",
    "zahlungsfähigstes": "zahlungsfähig",
    "zahlungsunfähige": "zahlungsunfähig",
    "zahlungsunfähigem": "zahlungsunfähig",
    "zahlungsunfähigen": "zahlungsunfähig",
    "zahlungsunfähiger": "zahlungsunfähig",
    "zahlungsunfähigere": "zahlungsunfähig",
    "zahlungsunfähigerem": "zahlungsunfähig",
    "zahlungsunfähigeren": "zahlungsunfähig",
    "zahlungsunfähigerer": "zahlungsunfähig",
    "zahlungsunfähigeres": "zahlungsunfähig",
    "zahlungsunfähiges": "zahlungsunfähig",
    "zahlungsunfähigste": "zahlungsunfähig",
    "zahlungsunfähigstem": "zahlungsunfähig",
    "zahlungsunfähigsten": "zahlungsunfähig",
    "zahlungsunfähigster": "zahlungsunfähig",
    "zahlungsunfähigstes": "zahlungsunfähig",
    "zahme": "zahm",
    "zahmem": "zahm",
    "zahmen": "zahm",
    "zahmer": "zahm",
    "zahmere": "zahm",
    "zahmerem": "zahm",
    "zahmeren": "zahm",
    "zahmerer": "zahm",
    "zahmeres": "zahm",
    "zahmes": "zahm",
    "zahmste": "zahm",
    "zahmstem": "zahm",
    "zahmsten": "zahm",
    "zahmster": "zahm",
    "zahmstes": "zahm",
    "zahnend": "zahnen",
    "zahnende": "zahnend",
    "zahnendem": "zahnend",
    "zahnenden": "zahnend",
    "zahnender": "zahnend",
    "zahnendere": "zahnend",
    "zahnenderem": "zahnend",
    "zahnenderen": "zahnend",
    "zahnenderer": "zahnend",
    "zahnenderes": "zahnend",
    "zahnendes": "zahnend",
    "zahnendste": "zahnend",
    "zahnendstem": "zahnend",
    "zahnendsten": "zahnend",
    "zahnendster": "zahnend",
    "zahnendstes": "zahnend",
    "zahnest": "zahnen",
    "zahnet": "zahnen",
    "zahnlose": "zahnlos",
    "zahnlosem": "zahnlos",
    "zahnlosen": "zahnlos",
    "zahnloser": "zahnlos",
    "zahnloses": "zahnlos",
    "zahnst": "zahnen",
    "zahnt": "zahnen",
    "zahnte": "zahnen",
    "zahnten": "zahnen",
    "zahntest": "zahnen",
    "zahntet": "zahnen",
    "zahnärztlichem": "zahnärztlich",
    "zahnärztlichen": "zahnärztlich",
    "zahnärztlicher": "zahnärztlich",
    "zahnärztliches": "zahnärztlich",
    "zanke": "zanken",
    "zankend": "zanken",
    "zankende": "zankend",
    "zankendem": "zankend",
    "zankenden": "zankend",
    "zankender": "zankend",
    "zankendere": "zankend",
    "zankenderem": "zankend",
    "zankenderen": "zankend",
    "zankenderer": "zankend",
    "zankenderes": "zankend",
    "zankendes": "zankend",
    "zankendste": "zankend",
    "zankendstem": "zankend",
    "zankendsten": "zankend",
    "zankendster": "zankend",
    "zankendstes": "zankend",
    "zankest": "zanken",
    "zanket": "zanken",
    "zankst": "zanken",
    "zanksüchtige": "zanksüchtig",
    "zanksüchtigem": "zanksüchtig",
    "zanksüchtigen": "zanksüchtig",
    "zanksüchtiger": "zanksüchtig",
    "zanksüchtigere": "zanksüchtig",
    "zanksüchtigerem": "zanksüchtig",
    "zanksüchtigeren": "zanksüchtig",
    "zanksüchtigerer": "zanksüchtig",
    "zanksüchtigeres": "zanksüchtig",
    "zanksüchtiges": "zanksüchtig",
    "zanksüchtigste": "zanksüchtig",
    "zanksüchtigstem": "zanksüchtig",
    "zanksüchtigsten": "zanksüchtig",
    "zanksüchtigster": "zanksüchtig",
    "zanksüchtigstes": "zanksüchtig",
    "zankt": "zanken",
    "zankte": "zanken",
    "zankten": "zanken",
    "zanktest": "zanken",
    "zanktet": "zanken",
    "zapfe": "zapfen",
    "zapfend": "zapfen",
    "zapfende": "zapfend",
    "zapfendem": "zapfend",
    "zapfenden": "zapfend",
    "zapfender": "zapfend",
    "zapfendes": "zapfend",
    "zapfest": "zapfen",
    "zapfet": "zapfen",
    "zapfst": "zapfen",
    "zapft": "zapfen",
    "zapfte": "zapfen",
    "zapften": "zapfen",
    "zapftest": "zapfen",
    "zapftet": "zapfen",
    "zappele": "zappeln",
    "zappelige": "zappelig",
    "zappeligem": "zappelig",
    "zappeligen": "zappelig",
    "zappeliger": "zappelig",
    "zappeligere": "zappelig",
    "zappeligerem": "zappelig",
    "zappeligeren": "zappelig",
    "zappeligerer": "zappelig",
    "zappeligeres": "zappelig",
    "zappeliges": "zappelig",
    "zappeligste": "zappelig",
    "zappeligstem": "zappelig",
    "zappeligsten": "zappelig",
    "zappeligster": "zappelig",
    "zappeligstes": "zappelig",
    "zappelnd": "zappeln",
    "zappelnde": "zappelnd",
    "zappelndem": "zappelnd",
    "zappelnden": "zappelnd",
    "zappelnder": "zappelnd",
    "zappelndere": "zappelnd",
    "zappelnderem": "zappelnd",
    "zappelnderen": "zappelnd",
    "zappelnderer": "zappelnd",
    "zappelnderes": "zappelnd",
    "zappelndes": "zappelnd",
    "zappelndste": "zappelnd",
    "zappelndstem": "zappelnd",
    "zappelndsten": "zappelnd",
    "zappelndster": "zappelnd",
    "zappelndstes": "zappelnd",
    "zappelst": "zappeln",
    "zappelt": "zappeln",
    "zappelte": "zappeln",
    "zappelten": "zappeln",
    "zappeltest": "zappeln",
    "zappeltet": "zappeln",
    "zapple": "zappeln",
    "zartem": "zart",
    "zarten": "zart",
    "zarter": "zart",
    "zartere": "zart",
    "zarterem": "zart",
    "zarteren": "zart",
    "zarterer": "zart",
    "zarteres": "zart",
    "zartes": "zart",
    "zarteste": "zart",
    "zartestem": "zart",
    "zartesten": "zart",
    "zartester": "zart",
    "zartestes": "zart",
    "zaubere": "zaubern",
    "zauberhafte": "zauberhaft",
    "zauberhaftem": "zauberhaft",
    "zauberhaften": "zauberhaft",
    "zauberhafter": "zauberhaft",
    "zauberhaftere": "zauberhaft",
    "zauberhafterem": "zauberhaft",
    "zauberhafteren": "zauberhaft",
    "zauberhafterer": "zauberhaft",
    "zauberhafteres": "zauberhaft",
    "zauberhaftes": "zauberhaft",
    "zauberhafteste": "zauberhaft",
    "zauberhaftestem": "zauberhaft",
    "zauberhaftesten": "zauberhaft",
    "zauberhaftester": "zauberhaft",
    "zauberhaftestes": "zauberhaft",
    "zaubernd": "zaubern",
    "zaubernde": "zaubernd",
    "zauberndem": "zaubernd",
    "zaubernden": "zaubernd",
    "zaubernder": "zaubernd",
    "zauberndes": "zaubernd",
    "zauberst": "zaubern",
    "zaubert": "zaubern",
    "zauberte": "zaubern",
    "zauberten": "zaubern",
    "zaubertest": "zaubern",
    "zaubertet": "zaubern",
    "zaudere": "zaudern",
    "zaudernd": "zaudern",
    "zaudernde": "zaudernd",
    "zauderndem": "zaudernd",
    "zaudernden": "zaudernd",
    "zaudernder": "zaudernd",
    "zauderndere": "zaudernd",
    "zaudernderem": "zaudernd",
    "zaudernderen": "zaudernd",
    "zaudernderer": "zaudernd",
    "zaudernderes": "zaudernd",
    "zauderndes": "zaudernd",
    "zauderndste": "zaudernd",
    "zauderndstem": "zaudernd",
    "zauderndsten": "zaudernd",
    "zauderndster": "zaudernd",
    "zauderndstes": "zaudernd",
    "zauderst": "zaudern",
    "zaudert": "zaudern",
    "zauderte": "zaudern",
    "zauderten": "zaudern",
    "zaudertest": "zaudern",
    "zaudertet": "zaudern",
    "zause": "zausen",
    "zausend": "zausen",
    "zausende": "zausend",
    "zausendem": "zausend",
    "zausenden": "zausend",
    "zausender": "zausend",
    "zausendes": "zausend",
    "zausest": "zausen",
    "zauset": "zausen",
    "zaust": "zausen",
    "zauste": "zausen",
    "zausten": "zausen",
    "zaustest": "zausen",
    "zaustet": "zausen",
    "zeche": "zechen",
    "zechend": "zechen",
    "zechende": "zechend",
    "zechendem": "zechend",
    "zechenden": "zechend",
    "zechender": "zechend",
    "zechendere": "zechend",
    "zechenderem": "zechend",
    "zechenderen": "zechend",
    "zechenderer": "zechend",
    "zechenderes": "zechend",
    "zechendes": "zechend",
    "zechendste": "zechend",
    "zechendstem": "zechend",
    "zechendsten": "zechend",
    "zechendster": "zechend",
    "zechendstes": "zechend",
    "zechest": "zechen",
    "zechet": "zechen",
    "zechst": "zechen",
    "zecht": "zechen",
    "zechte": "zechen",
    "zechten": "zechen",
    "zechtest": "zechen",
    "zechtet": "zechen",
    "zehre": "zehren",
    "zehrend": "zehren",
    "zehrende": "zehrend",
    "zehrendem": "zehrend",
    "zehrenden": "zehrend",
    "zehrender": "zehrend",
    "zehrendere": "zehrend",
    "zehrenderem": "zehrend",
    "zehrenderen": "zehrend",
    "zehrenderer": "zehrend",
    "zehrenderes": "zehrend",
    "zehrendes": "zehrend",
    "zehrendste": "zehrend",
    "zehrendstem": "zehrend",
    "zehrendsten": "zehrend",
    "zehrendster": "zehrend",
    "zehrendstes": "zehrend",
    "zehrest": "zehren",
    "zehret": "zehren",
    "zehrst": "zehren",
    "zehrt": "zehren",
    "zehrte": "zehren",
    "zehrten": "zehren",
    "zehrtest": "zehren",
    "zehrtet": "zehren",
    "zeichne": "zeichnen",
    "zeichnend": "zeichnen",
    "zeichnende": "zeichnend",
    "zeichnendem": "zeichnend",
    "zeichnenden": "zeichnend",
    "zeichnender": "zeichnend",
    "zeichnendes": "zeichnend",
    "zeichnerischem": "zeichnerisch",
    "zeichnerischen": "zeichnerisch",
    "zeichnerischer": "zeichnerisch",
    "zeichnerisches": "zeichnerisch",
    "zeichnest": "zeichnen",
    "zeichnet": "zeichnen",
    "zeichnete": "zeichnen",
    "zeichneten": "zeichnen",
    "zeichnetest": "zeichnen",
    "zeichnetet": "zeichnen",
    "zeige": "zeigen",
    "zeigend": "zeigen",
    "zeigende": "zeigend",
    "zeigendem": "zeigend",
    "zeigenden": "zeigend",
    "zeigender": "zeigend",
    "zeigendes": "zeigend",
    "zeigest": "zeigen",
    "zeiget": "zeigen",
    "zeigst": "zeigen",
    "zeigt": "zeigen",
    "zeigte": "zeigen",
    "zeigten": "zeigen",
    "zeigtest": "zeigen",
    "zeigtet": "zeigen",
    "zeitgebundenem": "zeitgebunden",
    "zeitgebundenen": "zeitgebunden",
    "zeitgebundener": "zeitgebunden",
    "zeitgebundenes": "zeitgebunden",
    "zeitgemäße": "zeitgemäß",
    "zeitgemäßem": "zeitgemäß",
    "zeitgemäßen": "zeitgemäß",
    "zeitgemäßer": "zeitgemäß",
    "zeitgemäßere": "zeitgemäß",
    "zeitgemäßerem": "zeitgemäß",
    "zeitgemäßeren": "zeitgemäß",
    "zeitgemäßerer": "zeitgemäß",
    "zeitgemäßeres": "zeitgemäß",
    "zeitgemäßes": "zeitgemäß",
    "zeitgemäßeste": "zeitgemäß",
    "zeitgemäßestem": "zeitgemäß",
    "zeitgemäßesten": "zeitgemäß",
    "zeitgemäßester": "zeitgemäß",
    "zeitgemäßestes": "zeitgemäß",
    "zeitgenössische": "zeitgenössisch",
    "zeitgenössischem": "zeitgenössisch",
    "zeitgenössischen": "zeitgenössisch",
    "zeitgenössischer": "zeitgenössisch",
    "zeitgenössischere": "zeitgenössisch",
    "zeitgenössischerem": "zeitgenössisch",
    "zeitgenössischeren": "zeitgenössisch",
    "zeitgenössischerer": "zeitgenössisch",
    "zeitgenössischeres": "zeitgenössisch",
    "zeitgenössisches": "zeitgenössisch",
    "zeitgenössischste": "zeitgenössisch",
    "zeitgenössischstem": "zeitgenössisch",
    "zeitgenössischsten": "zeitgenössisch",
    "zeitgenössischster": "zeitgenössisch",
    "zeitgenössischstes": "zeitgenössisch",
    "zeitgeschichtliche": "zeitgeschichtlich",
    "zeitgeschichtlichem": "zeitgeschichtlich",
    "zeitgeschichtlichen": "zeitgeschichtlich",
    "zeitgeschichtlicher": "zeitgeschichtlich",
    "zeitgeschichtliches": "zeitgeschichtlich",
    "zeitgleiche": "zeitgleich",
    "zeitgleichem": "zeitgleich",
    "zeitgleichen": "zeitgleich",
    "zeitgleicher": "zeitgleich",
    "zeitgleiches": "zeitgleich",
    "zeitige": "zeitig",
    "zeitigem": "zeitig",
    "zeitigen": "zeitig",
    "zeitiger": "zeitig",
    "zeitiges": "zeitig",
    "zeitliche": "zeitlich",
    "zeitlichem": "zeitlich",
    "zeitlichen": "zeitlich",
    "zeitlicher": "zeitlich",
    "zeitliches": "zeitlich",
    "zeitlose": "zeitlos",
    "zeitlosem": "zeitlos",
    "zeitlosen": "zeitlos",
    "zeitloser": "zeitlos",
    "zeitlosere": "zeitlos",
    "zeitloserem": "zeitlos",
    "zeitloseren": "zeitlos",
    "zeitloserer": "zeitlos",
    "zeitloseres": "zeitlos",
    "zeitloses": "zeitlos",
    "zeitloseste": "zeitlos",
    "zeitlosestem": "zeitlos",
    "zeitlosesten": "zeitlos",
    "zeitlosester": "zeitlos",
    "zeitlosestes": "zeitlos",
    "zeitraubende": "zeitraubend",
    "zeitraubendem": "zeitraubend",
    "zeitraubenden": "zeitraubend",
    "zeitraubender": "zeitraubend",
    "zeitraubendes": "zeitraubend",
    "zeitweiligem": "zeitweilig",
    "zeitweiligen": "zeitweilig",
    "zeitweiliger": "zeitweilig",
    "zeitweiliges": "zeitweilig",
    "zellularem": "zellular",
    "zellularen": "zellular",
    "zellularer": "zellular",
    "zellulares": "zellular",
    "zeltend": "zelten",
    "zeltende": "zeltend",
    "zeltendem": "zeltend",
    "zeltenden": "zeltend",
    "zeltender": "zeltend",
    "zeltendere": "zeltend",
    "zeltenderem": "zeltend",
    "zeltenderen": "zeltend",
    "zeltenderer": "zeltend",
    "zeltenderes": "zeltend",
    "zeltendes": "zeltend",
    "zeltendste": "zeltend",
    "zeltendstem": "zeltend",
    "zeltendsten": "zeltend",
    "zeltendster": "zeltend",
    "zeltendstes": "zeltend",
    "zeltest": "zelten",
    "zeltet": "zelten",
    "zeltete": "zelten",
    "zelteten": "zelten",
    "zeltetest": "zelten",
    "zeltetet": "zelten",
    "zementiere": "zementieren",
    "zementierend": "zementieren",
    "zementierende": "zementierend",
    "zementierendem": "zementierend",
    "zementierenden": "zementierend",
    "zementierender": "zementierend",
    "zementierendere": "zementierend",
    "zementierenderem": "zementierend",
    "zementierenderen": "zementierend",
    "zementierenderer": "zementierend",
    "zementierenderes": "zementierend",
    "zementierendes": "zementierend",
    "zementierendste": "zementierend",
    "zementierendstem": "zementierend",
    "zementierendsten": "zementierend",
    "zementierendster": "zementierend",
    "zementierendstes": "zementierend",
    "zementierest": "zementieren",
    "zementieret": "zementieren",
    "zementierst": "zementieren",
    "zementiert": "zementieren",
    "zementierte": "zementieren",
    "zementiertem": "zementiert",
    "zementierten": "zementieren",
    "zementierter": "zementiert",
    "zementiertere": "zementiert",
    "zementierterem": "zementiert",
    "zementierteren": "zementiert",
    "zementierterer": "zementiert",
    "zementierteres": "zementiert",
    "zementiertes": "zementiert",
    "zementiertest": "zementieren",
    "zementierteste": "zementiert",
    "zementiertestem": "zementiert",
    "zementiertesten": "zementiert",
    "zementiertester": "zementiert",
    "zementiertestes": "zementiert",
    "zementiertet": "zementieren",
    "zensiere": "zensieren",
    "zensierend": "zensieren",
    "zensierende": "zensierend",
    "zensierendem": "zensierend",
    "zensierenden": "zensierend",
    "zensierender": "zensierend",
    "zensierendes": "zensierend",
    "zensierest": "zensieren",
    "zensieret": "zensieren",
    "zensierst": "zensieren",
    "zensiert": "zensieren",
    "zensierte": "zensieren",
    "zensiertem": "zensiert",
    "zensierten": "zensieren",
    "zensierter": "zensiert",
    "zensiertes": "zensiert",
    "zensiertest": "zensieren",
    "zensiertet": "zensieren",
    "zentnerschwerem": "zentnerschwer",
    "zentnerschweren": "zentnerschwer",
    "zentnerschwerer": "zentnerschwer",
    "zentnerschweres": "zentnerschwer",
    "zentralem": "zentral",
    "zentralen": "zentral",
    "zentraler": "zentral",
    "zentralere": "zentral",
    "zentralerem": "zentral",
    "zentraleren": "zentral",
    "zentralerer": "zentral",
    "zentraleres": "zentral",
    "zentrales": "zentral",
    "zentralisiere": "zentralisieren",
    "zentralisierend": "zentralisieren",
    "zentralisierende": "zentralisierend",
    "zentralisierendem": "zentralisierend",
    "zentralisierenden": "zentralisierend",
    "zentralisierender": "zentralisierend",
    "zentralisierendere": "zentralisierend",
    "zentralisierenderem": "zentralisierend",
    "zentralisierenderen": "zentralisierend",
    "zentralisierenderer": "zentralisierend",
    "zentralisierenderes": "zentralisierend",
    "zentralisierendes": "zentralisierend",
    "zentralisierendste": "zentralisierend",
    "zentralisierendstem": "zentralisierend",
    "zentralisierendsten": "zentralisierend",
    "zentralisierendster": "zentralisierend",
    "zentralisierendstes": "zentralisierend",
    "zentralisierest": "zentralisieren",
    "zentralisieret": "zentralisieren",
    "zentralisierst": "zentralisieren",
    "zentralisiert": "zentralisieren",
    "zentralisierte": "zentralisieren",
    "zentralisiertem": "zentralisiert",
    "zentralisierten": "zentralisieren",
    "zentralisierter": "zentralisiert",
    "zentralisiertere": "zentralisiert",
    "zentralisierterem": "zentralisiert",
    "zentralisierteren": "zentralisiert",
    "zentralisierterer": "zentralisiert",
    "zentralisierteres": "zentralisiert",
    "zentralisiertes": "zentralisiert",
    "zentralisiertest": "zentralisieren",
    "zentralisiertestem": "zentralisiert",
    "zentralisiertesten": "zentralisiert",
    "zentralisiertester": "zentralisiert",
    "zentralisiertestes": "zentralisiert",
    "zentralisiertet": "zentralisieren",
    "zentralistischem": "zentralistisch",
    "zentralistischen": "zentralistisch",
    "zentralistischer": "zentralistisch",
    "zentralistisches": "zentralistisch",
    "zentralstem": "zentral",
    "zentralsten": "zentral",
    "zentralster": "zentral",
    "zentralstes": "zentral",
    "zentriere": "zentrieren",
    "zentrierend": "zentrieren",
    "zentrierende": "zentrierend",
    "zentrierendem": "zentrierend",
    "zentrierenden": "zentrierend",
    "zentrierender": "zentrierend",
    "zentrierendere": "zentrierend",
    "zentrierenderem": "zentrierend",
    "zentrierenderen": "zentrierend",
    "zentrierenderer": "zentrierend",
    "zentrierenderes": "zentrierend",
    "zentrierendes": "zentrierend",
    "zentrierendste": "zentrierend",
    "zentrierendstem": "zentrierend",
    "zentrierendsten": "zentrierend",
    "zentrierendster": "zentrierend",
    "zentrierendstes": "zentrierend",
    "zentrierest": "zentrieren",
    "zentrieret": "zentrieren",
    "zentrierst": "zentrieren",
    "zentriert": "zentrieren",
    "zentrierte": "zentrieren",
    "zentriertem": "zentriert",
    "zentrierten": "zentrieren",
    "zentrierter": "zentriert",
    "zentriertere": "zentriert",
    "zentrierterem": "zentriert",
    "zentrierteren": "zentriert",
    "zentrierterer": "zentriert",
    "zentrierteres": "zentriert",
    "zentriertes": "zentriert",
    "zentriertest": "zentrieren",
    "zentrierteste": "zentriert",
    "zentriertestem": "zentriert",
    "zentriertesten": "zentriert",
    "zentriertester": "zentriert",
    "zentriertestes": "zentriert",
    "zentriertet": "zentrieren",
    "zentrifugale": "zentrifugal",
    "zentrifugalem": "zentrifugal",
    "zentrifugalen": "zentrifugal",
    "zentrifugaler": "zentrifugal",
    "zentrifugales": "zentrifugal",
    "zentrifugiere": "zentrifugieren",
    "zentrifugierend": "zentrifugieren",
    "zentrifugierende": "zentrifugierend",
    "zentrifugierendem": "zentrifugierend",
    "zentrifugierenden": "zentrifugierend",
    "zentrifugierender": "zentrifugierend",
    "zentrifugierendes": "zentrifugierend",
    "zentrifugierest": "zentrifugieren",
    "zentrifugieret": "zentrifugieren",
    "zentrifugierst": "zentrifugieren",
    "zentrifugiert": "zentrifugieren",
    "zentrifugierte": "zentrifugieren",
    "zentrifugiertem": "zentrifugiert",
    "zentrifugierten": "zentrifugieren",
    "zentrifugierter": "zentrifugiert",
    "zentrifugiertes": "zentrifugiert",
    "zentrifugiertest": "zentrifugieren",
    "zentrifugiertet": "zentrifugieren",
    "zentrische": "zentrisch",
    "zentrischem": "zentrisch",
    "zentrischen": "zentrisch",
    "zentrischer": "zentrisch",
    "zentrisches": "zentrisch",
    "zerbeiße": "zerbeißen",
    "zerbeißend": "zerbeißen",
    "zerbeißende": "zerbeißend",
    "zerbeißendem": "zerbeißend",
    "zerbeißenden": "zerbeißend",
    "zerbeißender": "zerbeißend",
    "zerbeißendere": "zerbeißend",
    "zerbeißenderem": "zerbeißend",
    "zerbeißenderen": "zerbeißend",
    "zerbeißenderer": "zerbeißend",
    "zerbeißenderes": "zerbeißend",
    "zerbeißendes": "zerbeißend",
    "zerbeißendste": "zerbeißend",
    "zerbeißendstem": "zerbeißend",
    "zerbeißendsten": "zerbeißend",
    "zerbeißendster": "zerbeißend",
    "zerbeißendstes": "zerbeißend",
    "zerbeißest": "zerbeißen",
    "zerbeißet": "zerbeißen",
    "zerbeißt": "zerbeißen",
    "zerbeule": "zerbeulen",
    "zerbeulend": "zerbeulen",
    "zerbeulende": "zerbeulend",
    "zerbeulendem": "zerbeulend",
    "zerbeulenden": "zerbeulend",
    "zerbeulender": "zerbeulend",
    "zerbeulendes": "zerbeulend",
    "zerbeulest": "zerbeulen",
    "zerbeulet": "zerbeulen",
    "zerbeulst": "zerbeulen",
    "zerbeult": "zerbeulen",
    "zerbeulte": "zerbeulen",
    "zerbeultem": "zerbeult",
    "zerbeulten": "zerbeulen",
    "zerbeulter": "zerbeult",
    "zerbeultere": "zerbeult",
    "zerbeulterem": "zerbeult",
    "zerbeulteren": "zerbeult",
    "zerbeulterer": "zerbeult",
    "zerbeulteres": "zerbeult",
    "zerbeultes": "zerbeult",
    "zerbeultest": "zerbeulen",
    "zerbeulteste": "zerbeult",
    "zerbeultestem": "zerbeult",
    "zerbeultesten": "zerbeult",
    "zerbeultester": "zerbeult",
    "zerbeultestes": "zerbeult",
    "zerbeultet": "zerbeulen",
    "zerbiege": "zerbiegen",
    "zerbiegend": "zerbiegen",
    "zerbiegende": "zerbiegend",
    "zerbiegendem": "zerbiegend",
    "zerbiegenden": "zerbiegend",
    "zerbiegender": "zerbiegend",
    "zerbiegendes": "zerbiegend",
    "zerbiegest": "zerbiegen",
    "zerbieget": "zerbiegen",
    "zerbiegst": "zerbiegen",
    "zerbiegt": "zerbiegen",
    "zerbisse": "zerbeißen",
    "zerbissen": "zerbeißen",
    "zerbissene": "zerbissen",
    "zerbissenem": "zerbissen",
    "zerbissenen": "zerbissen",
    "zerbissener": "zerbissen",
    "zerbissenere": "zerbissen",
    "zerbissenerem": "zerbissen",
    "zerbisseneren": "zerbissen",
    "zerbissenerer": "zerbissen",
    "zerbisseneres": "zerbissen",
    "zerbissenes": "zerbissen",
    "zerbissenste": "zerbissen",
    "zerbissenstem": "zerbissen",
    "zerbissensten": "zerbissen",
    "zerbissenster": "zerbissen",
    "zerbissenstes": "zerbissen",
    "zerbissest": "zerbeißen",
    "zerbisset": "zerbeißen",
    "zerbiß": "zerbeißen",
    "zerbißt": "zerbeißen",
    "zerblase": "zerblasen",
    "zerblasend": "zerblasen",
    "zerblasende": "zerblasend",
    "zerblasendem": "zerblasend",
    "zerblasenden": "zerblasend",
    "zerblasender": "zerblasend",
    "zerblasendes": "zerblasend",
    "zerblasene": "zerblasen",
    "zerblasenem": "zerblasen",
    "zerblasenen": "zerblasen",
    "zerblasener": "zerblasen",
    "zerblasenes": "zerblasen",
    "zerblasest": "zerblasen",
    "zerblaset": "zerblasen",
    "zerblast": "zerblasen",
    "zerblies": "zerblasen",
    "zerbliese": "zerblasen",
    "zerbliesen": "zerblasen",
    "zerbliesest": "zerblasen",
    "zerblieset": "zerblasen",
    "zerbliest": "zerblasen",
    "zerbläst": "zerblasen",
    "zerbog": "zerbiegen",
    "zerbogen": "zerbiegen",
    "zerbogene": "zerbogen",
    "zerbogenem": "zerbogen",
    "zerbogenen": "zerbogen",
    "zerbogener": "zerbogen",
    "zerbogenere": "zerbogen",
    "zerbogenerem": "zerbogen",
    "zerbogeneren": "zerbogen",
    "zerbogenerer": "zerbogen",
    "zerbogeneres": "zerbogen",
    "zerbogenes": "zerbogen",
    "zerbogenste": "zerbogen",
    "zerbogenstem": "zerbogen",
    "zerbogensten": "zerbogen",
    "zerbogenster": "zerbogen",
    "zerbogenstes": "zerbogen",
    "zerbogst": "zerbiegen",
    "zerbogt": "zerbiegen",
    "zerbombe": "zerbomben",
    "zerbombend": "zerbomben",
    "zerbombende": "zerbombend",
    "zerbombendem": "zerbombend",
    "zerbombenden": "zerbombend",
    "zerbombender": "zerbombend",
    "zerbombendere": "zerbombend",
    "zerbombenderem": "zerbombend",
    "zerbombenderen": "zerbombend",
    "zerbombenderer": "zerbombend",
    "zerbombenderes": "zerbombend",
    "zerbombendes": "zerbombend",
    "zerbombendste": "zerbombend",
    "zerbombendstem": "zerbombend",
    "zerbombendsten": "zerbombend",
    "zerbombendster": "zerbombend",
    "zerbombendstes": "zerbombend",
    "zerbombest": "zerbomben",
    "zerbombet": "zerbomben",
    "zerbombst": "zerbomben",
    "zerbombt": "zerbomben",
    "zerbombte": "zerbomben",
    "zerbombtem": "zerbombt",
    "zerbombten": "zerbomben",
    "zerbombter": "zerbombt",
    "zerbombtere": "zerbombt",
    "zerbombterem": "zerbombt",
    "zerbombteren": "zerbombt",
    "zerbombterer": "zerbombt",
    "zerbombteres": "zerbombt",
    "zerbombtes": "zerbombt",
    "zerbombtest": "zerbomben",
    "zerbombteste": "zerbombt",
    "zerbombtestem": "zerbombt",
    "zerbombtesten": "zerbombt",
    "zerbombtester": "zerbombt",
    "zerbombtestes": "zerbombt",
    "zerbombtet": "zerbomben",
    "zerbrach": "zerbrechen",
    "zerbrachen": "zerbrechen",
    "zerbrachst": "zerbrechen",
    "zerbracht": "zerbrechen",
    "zerbreche": "zerbrechen",
    "zerbrechend": "zerbrechen",
    "zerbrechende": "zerbrechend",
    "zerbrechendem": "zerbrechend",
    "zerbrechenden": "zerbrechend",
    "zerbrechender": "zerbrechend",
    "zerbrechendes": "zerbrechend",
    "zerbrechest": "zerbrechen",
    "zerbrechet": "zerbrechen",
    "zerbrechliche": "zerbrechlich",
    "zerbrechlichem": "zerbrechlich",
    "zerbrechlichen": "zerbrechlich",
    "zerbrechlicher": "zerbrechlich",
    "zerbrechlichere": "zerbrechlich",
    "zerbrechlicherem": "zerbrechlich",
    "zerbrechlicheren": "zerbrechlich",
    "zerbrechlicherer": "zerbrechlich",
    "zerbrechlicheres": "zerbrechlich",
    "zerbrechliches": "zerbrechlich",
    "zerbrechlichste": "zerbrechlich",
    "zerbrechlichstem": "zerbrechlich",
    "zerbrechlichsten": "zerbrechlich",
    "zerbrechlichster": "zerbrechlich",
    "zerbrechlichstes": "zerbrechlich",
    "zerbrecht": "zerbrechen",
    "zerbrich": "zerbrechen",
    "zerbrichst": "zerbrechen",
    "zerbricht": "zerbrechen",
    "zerbrochen": "zerbrechen",
    "zerbrochene": "zerbrochen",
    "zerbrochenem": "zerbrochen",
    "zerbrochenen": "zerbrochen",
    "zerbrochener": "zerbrochen",
    "zerbrochenere": "zerbrochen",
    "zerbrochenerem": "zerbrochen",
    "zerbrocheneren": "zerbrochen",
    "zerbrochenerer": "zerbrochen",
    "zerbrocheneres": "zerbrochen",
    "zerbrochenes": "zerbrochen",
    "zerbrochenste": "zerbrochen",
    "zerbrochenstem": "zerbrochen",
    "zerbrochensten": "zerbrochen",
    "zerbrochenster": "zerbrochen",
    "zerbrochenstes": "zerbrochen",
    "zerbräche": "zerbrechen",
    "zerbrächen": "zerbrechen",
    "zerbrächest": "zerbrechen",
    "zerbrächet": "zerbrechen",
    "zerbröckele": "zerbröckeln",
    "zerbröckelnd": "zerbröckeln",
    "zerbröckelnde": "zerbröckelnd",
    "zerbröckelndem": "zerbröckelnd",
    "zerbröckelnden": "zerbröckelnd",
    "zerbröckelnder": "zerbröckelnd",
    "zerbröckelndere": "zerbröckelnd",
    "zerbröckelnderem": "zerbröckelnd",
    "zerbröckelnderen": "zerbröckelnd",
    "zerbröckelnderer": "zerbröckelnd",
    "zerbröckelnderes": "zerbröckelnd",
    "zerbröckelndes": "zerbröckelnd",
    "zerbröckelndste": "zerbröckelnd",
    "zerbröckelndstem": "zerbröckelnd",
    "zerbröckelndsten": "zerbröckelnd",
    "zerbröckelndster": "zerbröckelnd",
    "zerbröckelndstes": "zerbröckelnd",
    "zerbröckelst": "zerbröckeln",
    "zerbröckelt": "zerbröckeln",
    "zerbröckelte": "zerbröckeln",
    "zerbröckeltem": "zerbröckelt",
    "zerbröckelten": "zerbröckeln",
    "zerbröckelter": "zerbröckelt",
    "zerbröckeltere": "zerbröckelt",
    "zerbröckelterem": "zerbröckelt",
    "zerbröckelteren": "zerbröckelt",
    "zerbröckelterer": "zerbröckelt",
    "zerbröckelteres": "zerbröckelt",
    "zerbröckeltes": "zerbröckelt",
    "zerbröckeltest": "zerbröckeln",
    "zerbröckelteste": "zerbröckelt",
    "zerbröckeltestem": "zerbröckelt",
    "zerbröckeltesten": "zerbröckelt",
    "zerbröckeltester": "zerbröckelt",
    "zerbröckeltestes": "zerbröckelt",
    "zerbröckeltet": "zerbröckeln",
    "zerbröckle": "zerbröckeln",
    "zerböge": "zerbiegen",
    "zerbögen": "zerbiegen",
    "zerbögest": "zerbiegen",
    "zerböget": "zerbiegen",
    "zerdampfe": "zerdampfen",
    "zerdampfend": "zerdampfen",
    "zerdampfende": "zerdampfend",
    "zerdampfendem": "zerdampfend",
    "zerdampfenden": "zerdampfend",
    "zerdampfender": "zerdampfend",
    "zerdampfendere": "zerdampfend",
    "zerdampfenderem": "zerdampfend",
    "zerdampfenderen": "zerdampfend",
    "zerdampfenderer": "zerdampfend",
    "zerdampfenderes": "zerdampfend",
    "zerdampfendes": "zerdampfend",
    "zerdampfendste": "zerdampfend",
    "zerdampfendstem": "zerdampfend",
    "zerdampfendsten": "zerdampfend",
    "zerdampfendster": "zerdampfend",
    "zerdampfendstes": "zerdampfend",
    "zerdampfest": "zerdampfen",
    "zerdampfet": "zerdampfen",
    "zerdampfst": "zerdampfen",
    "zerdampft": "zerdampfen",
    "zerdampfte": "zerdampfen",
    "zerdampftem": "zerdampft",
    "zerdampften": "zerdampfen",
    "zerdampfter": "zerdampft",
    "zerdampftere": "zerdampft",
    "zerdampfterem": "zerdampft",
    "zerdampfteren": "zerdampft",
    "zerdampfterer": "zerdampft",
    "zerdampfteres": "zerdampft",
    "zerdampftes": "zerdampft",
    "zerdampftest": "zerdampfen",
    "zerdampfteste": "zerdampft",
    "zerdampftestem": "zerdampft",
    "zerdampftesten": "zerdampft",
    "zerdampftester": "zerdampft",
    "zerdampftestes": "zerdampft",
    "zerdampftet": "zerdampfen",
    "zerdelle": "zerdellen",
    "zerdellend": "zerdellen",
    "zerdellende": "zerdellend",
    "zerdellendem": "zerdellend",
    "zerdellenden": "zerdellend",
    "zerdellender": "zerdellend",
    "zerdellendere": "zerdellend",
    "zerdellenderem": "zerdellend",
    "zerdellenderen": "zerdellend",
    "zerdellenderer": "zerdellend",
    "zerdellenderes": "zerdellend",
    "zerdellendes": "zerdellend",
    "zerdellendste": "zerdellend",
    "zerdellendstem": "zerdellend",
    "zerdellendsten": "zerdellend",
    "zerdellendster": "zerdellend",
    "zerdellendstes": "zerdellend",
    "zerdellest": "zerdellen",
    "zerdellet": "zerdellen",
    "zerdellst": "zerdellen",
    "zerdellt": "zerdellen",
    "zerdellte": "zerdellen",
    "zerdelltem": "zerdellt",
    "zerdellten": "zerdellen",
    "zerdellter": "zerdellt",
    "zerdelltere": "zerdellt",
    "zerdellterem": "zerdellt",
    "zerdellteren": "zerdellt",
    "zerdellterer": "zerdellt",
    "zerdellteres": "zerdellt",
    "zerdelltes": "zerdellt",
    "zerdelltest": "zerdellen",
    "zerdellteste": "zerdellt",
    "zerdelltestem": "zerdellt",
    "zerdelltesten": "zerdellt",
    "zerdelltester": "zerdellt",
    "zerdelltestes": "zerdellt",
    "zerdelltet": "zerdellen",
    "zerdonnere": "zerdonnern",
    "zerdonnernd": "zerdonnern",
    "zerdonnernde": "zerdonnernd",
    "zerdonnerndem": "zerdonnernd",
    "zerdonnernden": "zerdonnernd",
    "zerdonnernder": "zerdonnernd",
    "zerdonnerndere": "zerdonnernd",
    "zerdonnernderem": "zerdonnernd",
    "zerdonnernderen": "zerdonnernd",
    "zerdonnernderer": "zerdonnernd",
    "zerdonnernderes": "zerdonnernd",
    "zerdonnerndes": "zerdonnernd",
    "zerdonnerndste": "zerdonnernd",
    "zerdonnerndstem": "zerdonnernd",
    "zerdonnerndsten": "zerdonnernd",
    "zerdonnerndster": "zerdonnernd",
    "zerdonnerndstes": "zerdonnernd",
    "zerdonnerst": "zerdonnern",
    "zerdonnert": "zerdonnern",
    "zerdonnerte": "zerdonnern",
    "zerdonnertem": "zerdonnert",
    "zerdonnerten": "zerdonnern",
    "zerdonnerter": "zerdonnert",
    "zerdonnertere": "zerdonnert",
    "zerdonnerterem": "zerdonnert",
    "zerdonnerteren": "zerdonnert",
    "zerdonnerterer": "zerdonnert",
    "zerdonnerteres": "zerdonnert",
    "zerdonnertes": "zerdonnert",
    "zerdonnertest": "zerdonnern",
    "zerdonnerteste": "zerdonnert",
    "zerdonnertestem": "zerdonnert",
    "zerdonnertesten": "zerdonnert",
    "zerdonnertester": "zerdonnert",
    "zerdonnertestes": "zerdonnert",
    "zerdonnertet": "zerdonnern",
    "zerdrösele": "zerdröseln",
    "zerdröselnd": "zerdröseln",
    "zerdröselnde": "zerdröselnd",
    "zerdröselndem": "zerdröselnd",
    "zerdröselnden": "zerdröselnd",
    "zerdröselnder": "zerdröselnd",
    "zerdröselndere": "zerdröselnd",
    "zerdröselnderem": "zerdröselnd",
    "zerdröselnderen": "zerdröselnd",
    "zerdröselnderer": "zerdröselnd",
    "zerdröselnderes": "zerdröselnd",
    "zerdröselndes": "zerdröselnd",
    "zerdröselndste": "zerdröselnd",
    "zerdröselndstem": "zerdröselnd",
    "zerdröselndsten": "zerdröselnd",
    "zerdröselndster": "zerdröselnd",
    "zerdröselndstes": "zerdröselnd",
    "zerdröselst": "zerdröseln",
    "zerdröselt": "zerdröseln",
    "zerdröselte": "zerdröseln",
    "zerdröseltem": "zerdröselt",
    "zerdröselten": "zerdröseln",
    "zerdröselter": "zerdröselt",
    "zerdröseltere": "zerdröselt",
    "zerdröselterem": "zerdröselt",
    "zerdröselteren": "zerdröselt",
    "zerdröselterer": "zerdröselt",
    "zerdröselteres": "zerdröselt",
    "zerdröseltes": "zerdröselt",
    "zerdröseltest": "zerdröseln",
    "zerdröselteste": "zerdröselt",
    "zerdröseltestem": "zerdröselt",
    "zerdröseltesten": "zerdröselt",
    "zerdröseltester": "zerdröselt",
    "zerdröseltestes": "zerdröselt",
    "zerdröseltet": "zerdröseln",
    "zerdrösle": "zerdröseln",
    "zerdrücke": "zerdrücken",
    "zerdrückend": "zerdrücken",
    "zerdrückende": "zerdrückend",
    "zerdrückendem": "zerdrückend",
    "zerdrückenden": "zerdrückend",
    "zerdrückender": "zerdrückend",
    "zerdrückendes": "zerdrückend",
    "zerdrückest": "zerdrücken",
    "zerdrücket": "zerdrücken",
    "zerdrückst": "zerdrücken",
    "zerdrückt": "zerdrücken",
    "zerdrückte": "zerdrücken",
    "zerdrücktem": "zerdrückt",
    "zerdrückten": "zerdrücken",
    "zerdrückter": "zerdrückt",
    "zerdrücktere": "zerdrückt",
    "zerdrückterem": "zerdrückt",
    "zerdrückteren": "zerdrückt",
    "zerdrückterer": "zerdrückt",
    "zerdrückteres": "zerdrückt",
    "zerdrücktes": "zerdrückt",
    "zerdrücktest": "zerdrücken",
    "zerdrückteste": "zerdrückt",
    "zerdrücktestem": "zerdrückt",
    "zerdrücktesten": "zerdrückt",
    "zerdrücktester": "zerdrückt",
    "zerdrücktestes": "zerdrückt",
    "zerdrücktet": "zerdrücken",
    "zerfahrenem": "zerfahren",
    "zerfahrenen": "zerfahren",
    "zerfahrener": "zerfahren",
    "zerfahrenere": "zerfahren",
    "zerfahrenerem": "zerfahren",
    "zerfahreneren": "zerfahren",
    "zerfahrenerer": "zerfahren",
    "zerfahreneres": "zerfahren",
    "zerfahrenes": "zerfahren",
    "zerfahrenste": "zerfahren",
    "zerfahrenstem": "zerfahren",
    "zerfahrensten": "zerfahren",
    "zerfahrenster": "zerfahren",
    "zerfahrenstes": "zerfahren",
    "zerfalle": "zerfallen",
    "zerfallend": "zerfallen",
    "zerfallende": "zerfallend",
    "zerfallendem": "zerfallend",
    "zerfallenden": "zerfallend",
    "zerfallender": "zerfallend",
    "zerfallendes": "zerfallend",
    "zerfallene": "zerfallen",
    "zerfallenem": "zerfallen",
    "zerfallenen": "zerfallen",
    "zerfallener": "zerfallen",
    "zerfallenere": "zerfallen",
    "zerfallenerem": "zerfallen",
    "zerfalleneren": "zerfallen",
    "zerfallenerer": "zerfallen",
    "zerfalleneres": "zerfallen",
    "zerfallenes": "zerfallen",
    "zerfallenstem": "zerfallen",
    "zerfallensten": "zerfallen",
    "zerfallenster": "zerfallen",
    "zerfallenstes": "zerfallen",
    "zerfallest": "zerfallen",
    "zerfallet": "zerfallen",
    "zerfallt": "zerfallen",
    "zerfasere": "zerfasern",
    "zerfasernd": "zerfasern",
    "zerfasernde": "zerfasernd",
    "zerfaserndem": "zerfasernd",
    "zerfasernden": "zerfasernd",
    "zerfasernder": "zerfasernd",
    "zerfaserndere": "zerfasernd",
    "zerfasernderem": "zerfasernd",
    "zerfasernderen": "zerfasernd",
    "zerfasernderer": "zerfasernd",
    "zerfasernderes": "zerfasernd",
    "zerfaserndes": "zerfasernd",
    "zerfaserndste": "zerfasernd",
    "zerfaserndstem": "zerfasernd",
    "zerfaserndsten": "zerfasernd",
    "zerfaserndster": "zerfasernd",
    "zerfaserndstes": "zerfasernd",
    "zerfaserst": "zerfasern",
    "zerfasert": "zerfasern",
    "zerfaserte": "zerfasern",
    "zerfasertem": "zerfasert",
    "zerfaserten": "zerfasern",
    "zerfaserter": "zerfasert",
    "zerfasertere": "zerfasert",
    "zerfaserterem": "zerfasert",
    "zerfaserteren": "zerfasert",
    "zerfaserterer": "zerfasert",
    "zerfaserteres": "zerfasert",
    "zerfasertes": "zerfasert",
    "zerfasertest": "zerfasern",
    "zerfaserteste": "zerfasert",
    "zerfasertestem": "zerfasert",
    "zerfasertesten": "zerfasert",
    "zerfasertester": "zerfasert",
    "zerfasertestes": "zerfasert",
    "zerfasertet": "zerfasern",
    "zerfetze": "zerfetzen",
    "zerfetzend": "zerfetzen",
    "zerfetzende": "zerfetzend",
    "zerfetzendem": "zerfetzend",
    "zerfetzenden": "zerfetzend",
    "zerfetzender": "zerfetzend",
    "zerfetzendere": "zerfetzend",
    "zerfetzenderem": "zerfetzend",
    "zerfetzenderen": "zerfetzend",
    "zerfetzenderer": "zerfetzend",
    "zerfetzenderes": "zerfetzend",
    "zerfetzendes": "zerfetzend",
    "zerfetzendste": "zerfetzend",
    "zerfetzendstem": "zerfetzend",
    "zerfetzendsten": "zerfetzend",
    "zerfetzendster": "zerfetzend",
    "zerfetzendstes": "zerfetzend",
    "zerfetzest": "zerfetzen",
    "zerfetzet": "zerfetzen",
    "zerfetzt": "zerfetzen",
    "zerfetzte": "zerfetzen",
    "zerfetztem": "zerfetzt",
    "zerfetzten": "zerfetzen",
    "zerfetzter": "zerfetzt",
    "zerfetztere": "zerfetzt",
    "zerfetzterem": "zerfetzt",
    "zerfetzteren": "zerfetzt",
    "zerfetzterer": "zerfetzt",
    "zerfetzteres": "zerfetzt",
    "zerfetztes": "zerfetzt",
    "zerfetztest": "zerfetzen",
    "zerfetzteste": "zerfetzt",
    "zerfetztestem": "zerfetzt",
    "zerfetztesten": "zerfetzt",
    "zerfetztester": "zerfetzt",
    "zerfetztestes": "zerfetzt",
    "zerfetztet": "zerfetzen",
    "zerfiel": "zerfallen",
    "zerfiele": "zerfallen",
    "zerfielen": "zerfallen",
    "zerfielest": "zerfallen",
    "zerfielet": "zerfallen",
    "zerfielst": "zerfallen",
    "zerfielt": "zerfallen",
    "zerflattere": "zerflattern",
    "zerflatternd": "zerflattern",
    "zerflatternde": "zerflatternd",
    "zerflatterndem": "zerflatternd",
    "zerflatternden": "zerflatternd",
    "zerflatternder": "zerflatternd",
    "zerflatterndes": "zerflatternd",
    "zerflatterst": "zerflattern",
    "zerflattert": "zerflattern",
    "zerflatterte": "zerflattern",
    "zerflattertem": "zerflattert",
    "zerflatterten": "zerflattern",
    "zerflatterter": "zerflattert",
    "zerflattertes": "zerflattert",
    "zerflattertest": "zerflattern",
    "zerflattertet": "zerflattern",
    "zerfleddere": "zerfleddern",
    "zerfleddernd": "zerfleddern",
    "zerfleddernde": "zerfleddernd",
    "zerfledderndem": "zerfleddernd",
    "zerfleddernden": "zerfleddernd",
    "zerfleddernder": "zerfleddernd",
    "zerfledderndere": "zerfleddernd",
    "zerfleddernderem": "zerfleddernd",
    "zerfleddernderen": "zerfleddernd",
    "zerfleddernderer": "zerfleddernd",
    "zerfleddernderes": "zerfleddernd",
    "zerfledderndes": "zerfleddernd",
    "zerfledderndste": "zerfleddernd",
    "zerfledderndstem": "zerfleddernd",
    "zerfledderndsten": "zerfleddernd",
    "zerfledderndster": "zerfleddernd",
    "zerfledderndstes": "zerfleddernd",
    "zerfledderst": "zerfleddern",
    "zerfleddert": "zerfleddern",
    "zerfledderte": "zerfleddern",
    "zerfleddertem": "zerfleddert",
    "zerfledderten": "zerfleddern",
    "zerfledderter": "zerfleddert",
    "zerfleddertere": "zerfleddert",
    "zerfledderterem": "zerfleddert",
    "zerfledderteren": "zerfleddert",
    "zerfledderterer": "zerfleddert",
    "zerfledderteres": "zerfleddert",
    "zerfleddertes": "zerfleddert",
    "zerfleddertest": "zerfleddern",
    "zerfledderteste": "zerfleddert",
    "zerfleddertestem": "zerfleddert",
    "zerfleddertesten": "zerfleddert",
    "zerfleddertester": "zerfleddert",
    "zerfleddertestes": "zerfleddert",
    "zerfleddertet": "zerfleddern",
    "zerfleische": "zerfleischen",
    "zerfleischend": "zerfleischen",
    "zerfleischende": "zerfleischend",
    "zerfleischendem": "zerfleischend",
    "zerfleischenden": "zerfleischend",
    "zerfleischender": "zerfleischend",
    "zerfleischendes": "zerfleischend",
    "zerfleischest": "zerfleischen",
    "zerfleischet": "zerfleischen",
    "zerfleischst": "zerfleischen",
    "zerfleischt": "zerfleischen",
    "zerfleischte": "zerfleischen",
    "zerfleischtem": "zerfleischt",
    "zerfleischten": "zerfleischen",
    "zerfleischter": "zerfleischt",
    "zerfleischtes": "zerfleischt",
    "zerfleischtest": "zerfleischen",
    "zerfleischtet": "zerfleischen",
    "zerfließe": "zerfließen",
    "zerfließend": "zerfließen",
    "zerfließende": "zerfließend",
    "zerfließendem": "zerfließend",
    "zerfließenden": "zerfließend",
    "zerfließender": "zerfließend",
    "zerfließendes": "zerfließend",
    "zerfließest": "zerfließen",
    "zerfließet": "zerfließen",
    "zerfließt": "zerfließen",
    "zerflossen": "zerfließen",
    "zerflossene": "zerflossen",
    "zerflossenem": "zerflossen",
    "zerflossenen": "zerflossen",
    "zerflossener": "zerflossen",
    "zerflossenere": "zerflossen",
    "zerflossenerem": "zerflossen",
    "zerflosseneren": "zerflossen",
    "zerflossenerer": "zerflossen",
    "zerflosseneres": "zerflossen",
    "zerflossenes": "zerflossen",
    "zerflossenste": "zerflossen",
    "zerflossenstem": "zerflossen",
    "zerflossensten": "zerflossen",
    "zerflossenster": "zerflossen",
    "zerflossenstes": "zerflossen",
    "zerfloß": "zerfließen",
    "zerfloßt": "zerfließen",
    "zerflösse": "zerfließen",
    "zerflössen": "zerfließen",
    "zerflössest": "zerfließen",
    "zerflösset": "zerfließen",
    "zerfranse": "zerfransen",
    "zerfransend": "zerfransen",
    "zerfransende": "zerfransend",
    "zerfransendem": "zerfransend",
    "zerfransenden": "zerfransend",
    "zerfransender": "zerfransend",
    "zerfransendere": "zerfransend",
    "zerfransenderem": "zerfransend",
    "zerfransenderen": "zerfransend",
    "zerfransenderer": "zerfransend",
    "zerfransenderes": "zerfransend",
    "zerfransendes": "zerfransend",
    "zerfransendste": "zerfransend",
    "zerfransendstem": "zerfransend",
    "zerfransendsten": "zerfransend",
    "zerfransendster": "zerfransend",
    "zerfransendstes": "zerfransend",
    "zerfransest": "zerfransen",
    "zerfranset": "zerfransen",
    "zerfranst": "zerfransen",
    "zerfranste": "zerfransen",
    "zerfranstem": "zerfranst",
    "zerfransten": "zerfransen",
    "zerfranster": "zerfranst",
    "zerfranstere": "zerfranst",
    "zerfransterem": "zerfranst",
    "zerfransteren": "zerfranst",
    "zerfransterer": "zerfranst",
    "zerfransteres": "zerfranst",
    "zerfranstes": "zerfranst",
    "zerfranstest": "zerfransen",
    "zerfransteste": "zerfranst",
    "zerfranstestem": "zerfranst",
    "zerfranstesten": "zerfranst",
    "zerfranstester": "zerfranst",
    "zerfranstestes": "zerfranst",
    "zerfranstet": "zerfransen",
    "zerfraß": "zerfressen",
    "zerfraßen": "zerfressen",
    "zerfraßt": "zerfressen",
    "zerfresse": "zerfressen",
    "zerfressend": "zerfressen",
    "zerfressende": "zerfressend",
    "zerfressendem": "zerfressend",
    "zerfressenden": "zerfressend",
    "zerfressender": "zerfressend",
    "zerfressendere": "zerfressend",
    "zerfressenderem": "zerfressend",
    "zerfressenderen": "zerfressend",
    "zerfressenderer": "zerfressend",
    "zerfressenderes": "zerfressend",
    "zerfressendes": "zerfressend",
    "zerfressendste": "zerfressend",
    "zerfressendstem": "zerfressend",
    "zerfressendsten": "zerfressend",
    "zerfressendster": "zerfressend",
    "zerfressendstes": "zerfressend",
    "zerfressene": "zerfressen",
    "zerfressenem": "zerfressen",
    "zerfressenen": "zerfressen",
    "zerfressener": "zerfressen",
    "zerfressenere": "zerfressen",
    "zerfressenerem": "zerfressen",
    "zerfresseneren": "zerfressen",
    "zerfressenerer": "zerfressen",
    "zerfresseneres": "zerfressen",
    "zerfressenes": "zerfressen",
    "zerfressenstem": "zerfressen",
    "zerfressensten": "zerfressen",
    "zerfressenster": "zerfressen",
    "zerfressenstes": "zerfressen",
    "zerfressest": "zerfressen",
    "zerfresset": "zerfressen",
    "zerfreßt": "zerfressen",
    "zerfriß": "zerfressen",
    "zerfrißt": "zerfressen",
    "zerfräße": "zerfressen",
    "zerfräßen": "zerfressen",
    "zerfräßest": "zerfressen",
    "zerfräßet": "zerfressen",
    "zerfällst": "zerfallen",
    "zerfällt": "zerfallen",
    "zergangen": "zergehen",
    "zergangene": "zergangen",
    "zergangenem": "zergangen",
    "zergangenen": "zergangen",
    "zergangener": "zergangen",
    "zergangenes": "zergangen",
    "zergefallen": "zerfallen",
    "zergehe": "zergehen",
    "zergehend": "zergehen",
    "zergehende": "zergehend",
    "zergehendem": "zergehend",
    "zergehenden": "zergehend",
    "zergehender": "zergehend",
    "zergehendes": "zergehend",
    "zergehest": "zergehen",
    "zergehet": "zergehen",
    "zergehst": "zergehen",
    "zergeht": "zergehen",
    "zerging": "zergehen",
    "zerginge": "zergehen",
    "zergingen": "zergehen",
    "zergingest": "zergehen",
    "zerginget": "zergehen",
    "zergingst": "zergehen",
    "zergingt": "zergehen",
    "zergliedere": "zergliedern",
    "zergliedernd": "zergliedern",
    "zergliedernde": "zergliedernd",
    "zergliederndem": "zergliedernd",
    "zergliedernden": "zergliedernd",
    "zergliedernder": "zergliedernd",
    "zergliederndere": "zergliedernd",
    "zergliedernderem": "zergliedernd",
    "zergliedernderen": "zergliedernd",
    "zergliedernderer": "zergliedernd",
    "zergliedernderes": "zergliedernd",
    "zergliederndes": "zergliedernd",
    "zergliederndste": "zergliedernd",
    "zergliederndstem": "zergliedernd",
    "zergliederndsten": "zergliedernd",
    "zergliederndster": "zergliedernd",
    "zergliederndstes": "zergliedernd",
    "zergliederst": "zergliedern",
    "zergliedert": "zergliedern",
    "zergliederte": "zergliedern",
    "zergliedertem": "zergliedert",
    "zergliederten": "zergliedern",
    "zergliederter": "zergliedert",
    "zergliedertere": "zergliedert",
    "zergliederterem": "zergliedert",
    "zergliederteren": "zergliedert",
    "zergliederterer": "zergliedert",
    "zergliederteres": "zergliedert",
    "zergliedertes": "zergliedert",
    "zergliedertest": "zergliedern",
    "zergliederteste": "zergliedert",
    "zergliedertestem": "zergliedert",
    "zergliedertesten": "zergliedert",
    "zergliedertester": "zergliedert",
    "zergliedertestes": "zergliedert",
    "zergliedertet": "zergliedern",
    "zerhacke": "zerhacken",
    "zerhackend": "zerhacken",
    "zerhackende": "zerhackend",
    "zerhackendem": "zerhackend",
    "zerhackenden": "zerhackend",
    "zerhackender": "zerhackend",
    "zerhackendere": "zerhackend",
    "zerhackenderem": "zerhackend",
    "zerhackenderen": "zerhackend",
    "zerhackenderer": "zerhackend",
    "zerhackenderes": "zerhackend",
    "zerhackendes": "zerhackend",
    "zerhackendste": "zerhackend",
    "zerhackendstem": "zerhackend",
    "zerhackendsten": "zerhackend",
    "zerhackendster": "zerhackend",
    "zerhackendstes": "zerhackend",
    "zerhackest": "zerhacken",
    "zerhacket": "zerhacken",
    "zerhackst": "zerhacken",
    "zerhackt": "zerhacken",
    "zerhackte": "zerhacken",
    "zerhacktem": "zerhackt",
    "zerhackten": "zerhacken",
    "zerhackter": "zerhackt",
    "zerhacktere": "zerhackt",
    "zerhackterem": "zerhackt",
    "zerhackteren": "zerhackt",
    "zerhackterer": "zerhackt",
    "zerhackteres": "zerhackt",
    "zerhacktes": "zerhackt",
    "zerhacktest": "zerhacken",
    "zerhackteste": "zerhackt",
    "zerhacktestem": "zerhackt",
    "zerhacktesten": "zerhackt",
    "zerhacktester": "zerhackt",
    "zerhacktestes": "zerhackt",
    "zerhacktet": "zerhacken",
    "zerhagele": "zerhageln",
    "zerhagelnd": "zerhageln",
    "zerhagelnde": "zerhagelnd",
    "zerhagelndem": "zerhagelnd",
    "zerhagelnden": "zerhagelnd",
    "zerhagelnder": "zerhagelnd",
    "zerhagelndere": "zerhagelnd",
    "zerhagelnderem": "zerhagelnd",
    "zerhagelnderen": "zerhagelnd",
    "zerhagelnderer": "zerhagelnd",
    "zerhagelnderes": "zerhagelnd",
    "zerhagelndes": "zerhagelnd",
    "zerhagelndste": "zerhagelnd",
    "zerhagelndstem": "zerhagelnd",
    "zerhagelndsten": "zerhagelnd",
    "zerhagelndster": "zerhagelnd",
    "zerhagelndstes": "zerhagelnd",
    "zerhagelst": "zerhageln",
    "zerhagelt": "zerhageln",
    "zerhagelte": "zerhageln",
    "zerhageltem": "zerhagelt",
    "zerhagelten": "zerhageln",
    "zerhagelter": "zerhagelt",
    "zerhageltere": "zerhagelt",
    "zerhagelterem": "zerhagelt",
    "zerhagelteren": "zerhagelt",
    "zerhagelterer": "zerhagelt",
    "zerhagelteres": "zerhagelt",
    "zerhageltes": "zerhagelt",
    "zerhageltest": "zerhageln",
    "zerhagelteste": "zerhagelt",
    "zerhageltestem": "zerhagelt",
    "zerhageltesten": "zerhagelt",
    "zerhageltester": "zerhagelt",
    "zerhageltestes": "zerhagelt",
    "zerhageltet": "zerhageln",
    "zerhagle": "zerhageln",
    "zerhaue": "zerhauen",
    "zerhauend": "zerhauen",
    "zerhauende": "zerhauend",
    "zerhauendem": "zerhauend",
    "zerhauenden": "zerhauend",
    "zerhauender": "zerhauend",
    "zerhauendes": "zerhauend",
    "zerhauene": "zerhauen",
    "zerhauenem": "zerhauen",
    "zerhauenen": "zerhauen",
    "zerhauener": "zerhauen",
    "zerhauenere": "zerhauen",
    "zerhauenerem": "zerhauen",
    "zerhaueneren": "zerhauen",
    "zerhauenerer": "zerhauen",
    "zerhaueneres": "zerhauen",
    "zerhauenes": "zerhauen",
    "zerhauenstem": "zerhauen",
    "zerhauensten": "zerhauen",
    "zerhauenster": "zerhauen",
    "zerhauenstes": "zerhauen",
    "zerhauest": "zerhauen",
    "zerhauet": "zerhauen",
    "zerhaust": "zerhauen",
    "zerhaut": "zerhauen",
    "zerhaute": "zerhauen",
    "zerhauten": "zerhauen",
    "zerhautest": "zerhauen",
    "zerhautet": "zerhauen",
    "zerhäcksele": "zerhäckseln",
    "zerhäckselnd": "zerhäckseln",
    "zerhäckselnde": "zerhäckselnd",
    "zerhäckselndem": "zerhäckselnd",
    "zerhäckselnden": "zerhäckselnd",
    "zerhäckselnder": "zerhäckselnd",
    "zerhäckselndes": "zerhäckselnd",
    "zerhäckselst": "zerhäckseln",
    "zerhäckselt": "zerhäckseln",
    "zerhäckselte": "zerhäckseln",
    "zerhäckseltem": "zerhäckselt",
    "zerhäckselten": "zerhäckseln",
    "zerhäckselter": "zerhäckselt",
    "zerhäckseltes": "zerhäckselt",
    "zerhäckseltest": "zerhäckseln",
    "zerhäckseltet": "zerhäckseln",
    "zerhäcksle": "zerhäckseln",
    "zerkaue": "zerkauen",
    "zerkauend": "zerkauen",
    "zerkauende": "zerkauend",
    "zerkauendem": "zerkauend",
    "zerkauenden": "zerkauend",
    "zerkauender": "zerkauend",
    "zerkauendes": "zerkauend",
    "zerkauest": "zerkauen",
    "zerkauet": "zerkauen",
    "zerkaust": "zerkauen",
    "zerkaut": "zerkauen",
    "zerkaute": "zerkauen",
    "zerkautem": "zerkaut",
    "zerkauten": "zerkauen",
    "zerkauter": "zerkaut",
    "zerkautes": "zerkaut",
    "zerkautest": "zerkauen",
    "zerkautet": "zerkauen",
    "zerklebe": "zerkleben",
    "zerklebend": "zerkleben",
    "zerklebende": "zerklebend",
    "zerklebendem": "zerklebend",
    "zerklebenden": "zerklebend",
    "zerklebender": "zerklebend",
    "zerklebendere": "zerklebend",
    "zerklebenderem": "zerklebend",
    "zerklebenderen": "zerklebend",
    "zerklebenderer": "zerklebend",
    "zerklebenderes": "zerklebend",
    "zerklebendes": "zerklebend",
    "zerklebendste": "zerklebend",
    "zerklebendstem": "zerklebend",
    "zerklebendsten": "zerklebend",
    "zerklebendster": "zerklebend",
    "zerklebendstes": "zerklebend",
    "zerklebest": "zerkleben",
    "zerklebet": "zerkleben",
    "zerklebst": "zerkleben",
    "zerklebt": "zerkleben",
    "zerklebte": "zerkleben",
    "zerklebtem": "zerklebt",
    "zerklebten": "zerkleben",
    "zerklebter": "zerklebt",
    "zerklebtere": "zerklebt",
    "zerklebterem": "zerklebt",
    "zerklebteren": "zerklebt",
    "zerklebterer": "zerklebt",
    "zerklebteres": "zerklebt",
    "zerklebtes": "zerklebt",
    "zerklebtest": "zerkleben",
    "zerklebteste": "zerklebt",
    "zerklebtestem": "zerklebt",
    "zerklebtesten": "zerklebt",
    "zerklebtester": "zerklebt",
    "zerklebtestes": "zerklebt",
    "zerklebtet": "zerkleben",
    "zerkleinere": "zerkleinern",
    "zerkleinernd": "zerkleinern",
    "zerkleinernde": "zerkleinernd",
    "zerkleinerndem": "zerkleinernd",
    "zerkleinernden": "zerkleinernd",
    "zerkleinernder": "zerkleinernd",
    "zerkleinerndere": "zerkleinernd",
    "zerkleinernderem": "zerkleinernd",
    "zerkleinernderen": "zerkleinernd",
    "zerkleinernderer": "zerkleinernd",
    "zerkleinernderes": "zerkleinernd",
    "zerkleinerndes": "zerkleinernd",
    "zerkleinerndste": "zerkleinernd",
    "zerkleinerndstem": "zerkleinernd",
    "zerkleinerndsten": "zerkleinernd",
    "zerkleinerndster": "zerkleinernd",
    "zerkleinerndstes": "zerkleinernd",
    "zerkleinerst": "zerkleinern",
    "zerkleinert": "zerkleinern",
    "zerkleinerte": "zerkleinern",
    "zerkleinertem": "zerkleinert",
    "zerkleinerten": "zerkleinern",
    "zerkleinerter": "zerkleinert",
    "zerkleinertere": "zerkleinert",
    "zerkleinerterem": "zerkleinert",
    "zerkleinerteren": "zerkleinert",
    "zerkleinerterer": "zerkleinert",
    "zerkleinerteres": "zerkleinert",
    "zerkleinertes": "zerkleinert",
    "zerkleinertest": "zerkleinern",
    "zerkleinerteste": "zerkleinert",
    "zerkleinertestem": "zerkleinert",
    "zerkleinertesten": "zerkleinert",
    "zerkleinertester": "zerkleinert",
    "zerkleinertestes": "zerkleinert",
    "zerkleinertet": "zerkleinern",
    "zerklumpe": "zerklumpen",
    "zerklumpend": "zerklumpen",
    "zerklumpende": "zerklumpend",
    "zerklumpendem": "zerklumpend",
    "zerklumpenden": "zerklumpend",
    "zerklumpender": "zerklumpend",
    "zerklumpendere": "zerklumpend",
    "zerklumpenderem": "zerklumpend",
    "zerklumpenderen": "zerklumpend",
    "zerklumpenderer": "zerklumpend",
    "zerklumpenderes": "zerklumpend",
    "zerklumpendes": "zerklumpend",
    "zerklumpendste": "zerklumpend",
    "zerklumpendstem": "zerklumpend",
    "zerklumpendsten": "zerklumpend",
    "zerklumpendster": "zerklumpend",
    "zerklumpendstes": "zerklumpend",
    "zerklumpest": "zerklumpen",
    "zerklumpet": "zerklumpen",
    "zerklumpst": "zerklumpen",
    "zerklumpt": "zerklumpen",
    "zerklumpte": "zerklumpen",
    "zerklumptem": "zerklumpt",
    "zerklumpten": "zerklumpen",
    "zerklumpter": "zerklumpt",
    "zerklumptere": "zerklumpt",
    "zerklumpterem": "zerklumpt",
    "zerklumpteren": "zerklumpt",
    "zerklumpterer": "zerklumpt",
    "zerklumpteres": "zerklumpt",
    "zerklumptes": "zerklumpt",
    "zerklumptest": "zerklumpen",
    "zerklumpteste": "zerklumpt",
    "zerklumptestem": "zerklumpt",
    "zerklumptesten": "zerklumpt",
    "zerklumptester": "zerklumpt",
    "zerklumptestes": "zerklumpt",
    "zerklumptet": "zerklumpen",
    "zerknacke": "zerknacken",
    "zerknackend": "zerknacken",
    "zerknackende": "zerknackend",
    "zerknackendem": "zerknackend",
    "zerknackenden": "zerknackend",
    "zerknackender": "zerknackend",
    "zerknackendere": "zerknackend",
    "zerknackenderem": "zerknackend",
    "zerknackenderen": "zerknackend",
    "zerknackenderer": "zerknackend",
    "zerknackenderes": "zerknackend",
    "zerknackendes": "zerknackend",
    "zerknackendste": "zerknackend",
    "zerknackendstem": "zerknackend",
    "zerknackendsten": "zerknackend",
    "zerknackendster": "zerknackend",
    "zerknackendstes": "zerknackend",
    "zerknackest": "zerknacken",
    "zerknacket": "zerknacken",
    "zerknackst": "zerknacken",
    "zerknackt": "zerknacken",
    "zerknackte": "zerknacken",
    "zerknacktem": "zerknackt",
    "zerknackten": "zerknacken",
    "zerknackter": "zerknackt",
    "zerknacktere": "zerknackt",
    "zerknackterem": "zerknackt",
    "zerknackteren": "zerknackt",
    "zerknackterer": "zerknackt",
    "zerknackteres": "zerknackt",
    "zerknacktes": "zerknackt",
    "zerknacktest": "zerknacken",
    "zerknackteste": "zerknackt",
    "zerknacktestem": "zerknackt",
    "zerknacktesten": "zerknackt",
    "zerknacktester": "zerknackt",
    "zerknacktestes": "zerknackt",
    "zerknacktet": "zerknacken",
    "zerknalle": "zerknallen",
    "zerknallend": "zerknallen",
    "zerknallende": "zerknallend",
    "zerknallendem": "zerknallend",
    "zerknallenden": "zerknallend",
    "zerknallender": "zerknallend",
    "zerknallendere": "zerknallend",
    "zerknallenderem": "zerknallend",
    "zerknallenderen": "zerknallend",
    "zerknallenderer": "zerknallend",
    "zerknallenderes": "zerknallend",
    "zerknallendes": "zerknallend",
    "zerknallendste": "zerknallend",
    "zerknallendstem": "zerknallend",
    "zerknallendsten": "zerknallend",
    "zerknallendster": "zerknallend",
    "zerknallendstes": "zerknallend",
    "zerknallest": "zerknallen",
    "zerknallet": "zerknallen",
    "zerknallst": "zerknallen",
    "zerknallt": "zerknallen",
    "zerknallte": "zerknallen",
    "zerknalltem": "zerknallt",
    "zerknallten": "zerknallen",
    "zerknallter": "zerknallt",
    "zerknalltere": "zerknallt",
    "zerknallterem": "zerknallt",
    "zerknallteren": "zerknallt",
    "zerknallterer": "zerknallt",
    "zerknallteres": "zerknallt",
    "zerknalltes": "zerknallt",
    "zerknalltest": "zerknallen",
    "zerknallteste": "zerknallt",
    "zerknalltestem": "zerknallt",
    "zerknalltesten": "zerknallt",
    "zerknalltester": "zerknallt",
    "zerknalltestes": "zerknallt",
    "zerknalltet": "zerknallen",
    "zerknautsche": "zerknautschen",
    "zerknautschend": "zerknautschen",
    "zerknautschende": "zerknautschend",
    "zerknautschendem": "zerknautschend",
    "zerknautschenden": "zerknautschend",
    "zerknautschender": "zerknautschend",
    "zerknautschendere": "zerknautschend",
    "zerknautschenderem": "zerknautschend",
    "zerknautschenderen": "zerknautschend",
    "zerknautschenderer": "zerknautschend",
    "zerknautschenderes": "zerknautschend",
    "zerknautschendes": "zerknautschend",
    "zerknautschendste": "zerknautschend",
    "zerknautschendstem": "zerknautschend",
    "zerknautschendsten": "zerknautschend",
    "zerknautschendster": "zerknautschend",
    "zerknautschendstes": "zerknautschend",
    "zerknautschest": "zerknautschen",
    "zerknautschet": "zerknautschen",
    "zerknautschst": "zerknautschen",
    "zerknautscht": "zerknautschen",
    "zerknautschte": "zerknautschen",
    "zerknautschtem": "zerknautscht",
    "zerknautschten": "zerknautschen",
    "zerknautschter": "zerknautscht",
    "zerknautschtere": "zerknautscht",
    "zerknautschterem": "zerknautscht",
    "zerknautschteren": "zerknautscht",
    "zerknautschterer": "zerknautscht",
    "zerknautschteres": "zerknautscht",
    "zerknautschtes": "zerknautscht",
    "zerknautschtest": "zerknautschen",
    "zerknautschteste": "zerknautscht",
    "zerknautschtestem": "zerknautscht",
    "zerknautschtesten": "zerknautscht",
    "zerknautschtester": "zerknautscht",
    "zerknautschtestes": "zerknautscht",
    "zerknautschtet": "zerknautschen",
    "zerkneife": "zerkneifen",
    "zerkneifend": "zerkneifen",
    "zerkneifende": "zerkneifend",
    "zerkneifendem": "zerkneifend",
    "zerkneifenden": "zerkneifend",
    "zerkneifender": "zerkneifend",
    "zerkneifendes": "zerkneifend",
    "zerkneifest": "zerkneifen",
    "zerkneifet": "zerkneifen",
    "zerkneifst": "zerkneifen",
    "zerkneift": "zerkneifen",
    "zerkniff": "zerkneifen",
    "zerkniffe": "zerkneifen",
    "zerkniffen": "zerkneifen",
    "zerkniffene": "zerkniffen",
    "zerkniffenem": "zerkniffen",
    "zerkniffenen": "zerkniffen",
    "zerkniffener": "zerkniffen",
    "zerkniffenes": "zerkniffen",
    "zerkniffest": "zerkneifen",
    "zerkniffet": "zerkneifen",
    "zerkniffst": "zerkneifen",
    "zerknifft": "zerkneifen",
    "zerknirsche": "zerknirschen",
    "zerknirschend": "zerknirschen",
    "zerknirschende": "zerknirschend",
    "zerknirschendem": "zerknirschend",
    "zerknirschenden": "zerknirschend",
    "zerknirschender": "zerknirschend",
    "zerknirschendere": "zerknirschend",
    "zerknirschenderem": "zerknirschend",
    "zerknirschenderen": "zerknirschend",
    "zerknirschenderer": "zerknirschend",
    "zerknirschenderes": "zerknirschend",
    "zerknirschendes": "zerknirschend",
    "zerknirschendste": "zerknirschend",
    "zerknirschendstem": "zerknirschend",
    "zerknirschendsten": "zerknirschend",
    "zerknirschendster": "zerknirschend",
    "zerknirschendstes": "zerknirschend",
    "zerknirschest": "zerknirschen",
    "zerknirschet": "zerknirschen",
    "zerknirschst": "zerknirschen",
    "zerknirscht": "zerknirschen",
    "zerknirschte": "zerknirschen",
    "zerknirschtem": "zerknirscht",
    "zerknirschten": "zerknirschen",
    "zerknirschter": "zerknirscht",
    "zerknirschtere": "zerknirscht",
    "zerknirschterem": "zerknirscht",
    "zerknirschteren": "zerknirscht",
    "zerknirschterer": "zerknirscht",
    "zerknirschteres": "zerknirscht",
    "zerknirschtes": "zerknirscht",
    "zerknirschtest": "zerknirschen",
    "zerknirschteste": "zerknirscht",
    "zerknirschtestem": "zerknirscht",
    "zerknirschtesten": "zerknirscht",
    "zerknirschtester": "zerknirscht",
    "zerknirschtestes": "zerknirscht",
    "zerknirschtet": "zerknirschen",
    "zerknittere": "zerknittern",
    "zerknitternd": "zerknittern",
    "zerknitternde": "zerknitternd",
    "zerknitterndem": "zerknitternd",
    "zerknitternden": "zerknitternd",
    "zerknitternder": "zerknitternd",
    "zerknitterndere": "zerknitternd",
    "zerknitternderem": "zerknitternd",
    "zerknitternderen": "zerknitternd",
    "zerknitternderer": "zerknitternd",
    "zerknitternderes": "zerknitternd",
    "zerknitterndes": "zerknitternd",
    "zerknitterndste": "zerknitternd",
    "zerknitterndstem": "zerknitternd",
    "zerknitterndsten": "zerknitternd",
    "zerknitterndster": "zerknitternd",
    "zerknitterndstes": "zerknitternd",
    "zerknitterst": "zerknittern",
    "zerknittert": "zerknittern",
    "zerknitterte": "zerknittern",
    "zerknittertem": "zerknittert",
    "zerknitterten": "zerknittern",
    "zerknitterter": "zerknittert",
    "zerknittertere": "zerknittert",
    "zerknitterterem": "zerknittert",
    "zerknitterteren": "zerknittert",
    "zerknitterterer": "zerknittert",
    "zerknitterteres": "zerknittert",
    "zerknittertes": "zerknittert",
    "zerknittertest": "zerknittern",
    "zerknitterteste": "zerknittert",
    "zerknittertestem": "zerknittert",
    "zerknittertesten": "zerknittert",
    "zerknittertester": "zerknittert",
    "zerknittertestes": "zerknittert",
    "zerknittertet": "zerknittern",
    "zerknülle": "zerknüllen",
    "zerknüllend": "zerknüllen",
    "zerknüllende": "zerknüllend",
    "zerknüllendem": "zerknüllend",
    "zerknüllenden": "zerknüllend",
    "zerknüllender": "zerknüllend",
    "zerknüllendere": "zerknüllend",
    "zerknüllenderem": "zerknüllend",
    "zerknüllenderen": "zerknüllend",
    "zerknüllenderer": "zerknüllend",
    "zerknüllenderes": "zerknüllend",
    "zerknüllendes": "zerknüllend",
    "zerknüllendste": "zerknüllend",
    "zerknüllendstem": "zerknüllend",
    "zerknüllendsten": "zerknüllend",
    "zerknüllendster": "zerknüllend",
    "zerknüllendstes": "zerknüllend",
    "zerknüllest": "zerknüllen",
    "zerknüllet": "zerknüllen",
    "zerknüllst": "zerknüllen",
    "zerknüllt": "zerknüllen",
    "zerknüllte": "zerknüllen",
    "zerknülltem": "zerknüllt",
    "zerknüllten": "zerknüllen",
    "zerknüllter": "zerknüllt",
    "zerknülltere": "zerknüllt",
    "zerknüllterem": "zerknüllt",
    "zerknüllteren": "zerknüllt",
    "zerknüllterer": "zerknüllt",
    "zerknüllteres": "zerknüllt",
    "zerknülltes": "zerknüllt",
    "zerknülltest": "zerknüllen",
    "zerknüllteste": "zerknüllt",
    "zerknülltestem": "zerknüllt",
    "zerknülltesten": "zerknüllt",
    "zerknülltester": "zerknüllt",
    "zerknülltestes": "zerknüllt",
    "zerknülltet": "zerknüllen",
    "zerkoche": "zerkochen",
    "zerkochend": "zerkochen",
    "zerkochende": "zerkochend",
    "zerkochendem": "zerkochend",
    "zerkochenden": "zerkochend",
    "zerkochender": "zerkochend",
    "zerkochendes": "zerkochend",
    "zerkochest": "zerkochen",
    "zerkochet": "zerkochen",
    "zerkochst": "zerkochen",
    "zerkocht": "zerkochen",
    "zerkochte": "zerkochen",
    "zerkochtem": "zerkocht",
    "zerkochten": "zerkochen",
    "zerkochter": "zerkocht",
    "zerkochtere": "zerkocht",
    "zerkochterem": "zerkocht",
    "zerkochteren": "zerkocht",
    "zerkochterer": "zerkocht",
    "zerkochteres": "zerkocht",
    "zerkochtes": "zerkocht",
    "zerkochtest": "zerkochen",
    "zerkochteste": "zerkocht",
    "zerkochtestem": "zerkocht",
    "zerkochtesten": "zerkocht",
    "zerkochtester": "zerkocht",
    "zerkochtestes": "zerkocht",
    "zerkochtet": "zerkochen",
    "zerkrache": "zerkrachen",
    "zerkrachend": "zerkrachen",
    "zerkrachende": "zerkrachend",
    "zerkrachendem": "zerkrachend",
    "zerkrachenden": "zerkrachend",
    "zerkrachender": "zerkrachend",
    "zerkrachendere": "zerkrachend",
    "zerkrachenderem": "zerkrachend",
    "zerkrachenderen": "zerkrachend",
    "zerkrachenderer": "zerkrachend",
    "zerkrachenderes": "zerkrachend",
    "zerkrachendes": "zerkrachend",
    "zerkrachendste": "zerkrachend",
    "zerkrachendstem": "zerkrachend",
    "zerkrachendsten": "zerkrachend",
    "zerkrachendster": "zerkrachend",
    "zerkrachendstes": "zerkrachend",
    "zerkrachest": "zerkrachen",
    "zerkrachet": "zerkrachen",
    "zerkrachst": "zerkrachen",
    "zerkracht": "zerkrachen",
    "zerkrachte": "zerkrachen",
    "zerkrachtem": "zerkracht",
    "zerkrachten": "zerkrachen",
    "zerkrachter": "zerkracht",
    "zerkrachtere": "zerkracht",
    "zerkrachterem": "zerkracht",
    "zerkrachteren": "zerkracht",
    "zerkrachterer": "zerkracht",
    "zerkrachteres": "zerkracht",
    "zerkrachtes": "zerkracht",
    "zerkrachtest": "zerkrachen",
    "zerkrachteste": "zerkracht",
    "zerkrachtestem": "zerkracht",
    "zerkrachtesten": "zerkracht",
    "zerkrachtester": "zerkracht",
    "zerkrachtestes": "zerkracht",
    "zerkrachtet": "zerkrachen",
    "zerkratze": "zerkratzen",
    "zerkratzend": "zerkratzen",
    "zerkratzende": "zerkratzend",
    "zerkratzendem": "zerkratzend",
    "zerkratzenden": "zerkratzend",
    "zerkratzender": "zerkratzend",
    "zerkratzendere": "zerkratzend",
    "zerkratzenderem": "zerkratzend",
    "zerkratzenderen": "zerkratzend",
    "zerkratzenderer": "zerkratzend",
    "zerkratzenderes": "zerkratzend",
    "zerkratzendes": "zerkratzend",
    "zerkratzendste": "zerkratzend",
    "zerkratzendstem": "zerkratzend",
    "zerkratzendsten": "zerkratzend",
    "zerkratzendster": "zerkratzend",
    "zerkratzendstes": "zerkratzend",
    "zerkratzest": "zerkratzen",
    "zerkratzet": "zerkratzen",
    "zerkratzt": "zerkratzen",
    "zerkratzte": "zerkratzen",
    "zerkratztem": "zerkratzt",
    "zerkratzten": "zerkratzen",
    "zerkratzter": "zerkratzt",
    "zerkratztere": "zerkratzt",
    "zerkratzterem": "zerkratzt",
    "zerkratzteren": "zerkratzt",
    "zerkratzterer": "zerkratzt",
    "zerkratzteres": "zerkratzt",
    "zerkratztes": "zerkratzt",
    "zerkratztest": "zerkratzen",
    "zerkratzteste": "zerkratzt",
    "zerkratztestem": "zerkratzt",
    "zerkratztesten": "zerkratzt",
    "zerkratztester": "zerkratzt",
    "zerkratztestes": "zerkratzt",
    "zerkratztet": "zerkratzen",
    "zerkräusele": "zerkräuseln",
    "zerkräuselnd": "zerkräuseln",
    "zerkräuselnde": "zerkräuselnd",
    "zerkräuselndem": "zerkräuselnd",
    "zerkräuselnden": "zerkräuselnd",
    "zerkräuselnder": "zerkräuselnd",
    "zerkräuselndere": "zerkräuselnd",
    "zerkräuselnderem": "zerkräuselnd",
    "zerkräuselnderen": "zerkräuselnd",
    "zerkräuselnderer": "zerkräuselnd",
    "zerkräuselnderes": "zerkräuselnd",
    "zerkräuselndes": "zerkräuselnd",
    "zerkräuselndste": "zerkräuselnd",
    "zerkräuselndstem": "zerkräuselnd",
    "zerkräuselndsten": "zerkräuselnd",
    "zerkräuselndster": "zerkräuselnd",
    "zerkräuselndstes": "zerkräuselnd",
    "zerkräuselst": "zerkräuseln",
    "zerkräuselt": "zerkräuseln",
    "zerkräuselte": "zerkräuseln",
    "zerkräuseltem": "zerkräuselt",
    "zerkräuselten": "zerkräuseln",
    "zerkräuselter": "zerkräuselt",
    "zerkräuseltere": "zerkräuselt",
    "zerkräuselterem": "zerkräuselt",
    "zerkräuselteren": "zerkräuselt",
    "zerkräuselterer": "zerkräuselt",
    "zerkräuselteres": "zerkräuselt",
    "zerkräuseltes": "zerkräuselt",
    "zerkräuseltest": "zerkräuseln",
    "zerkräuselteste": "zerkräuselt",
    "zerkräuseltestem": "zerkräuselt",
    "zerkräuseltesten": "zerkräuselt",
    "zerkräuseltester": "zerkräuselt",
    "zerkräuseltestes": "zerkräuselt",
    "zerkräuseltet": "zerkräuseln",
    "zerkräusle": "zerkräuseln",
    "zerkrümele": "zerkrümeln",
    "zerkrümelnd": "zerkrümeln",
    "zerkrümelnde": "zerkrümelnd",
    "zerkrümelndem": "zerkrümelnd",
    "zerkrümelnden": "zerkrümelnd",
    "zerkrümelnder": "zerkrümelnd",
    "zerkrümelndes": "zerkrümelnd",
    "zerkrümelst": "zerkrümeln",
    "zerkrümelt": "zerkrümeln",
    "zerkrümelte": "zerkrümeln",
    "zerkrümeltem": "zerkrümelt",
    "zerkrümelten": "zerkrümeln",
    "zerkrümelter": "zerkrümelt",
    "zerkrümeltes": "zerkrümelt",
    "zerkrümeltest": "zerkrümeln",
    "zerkrümeltet": "zerkrümeln",
    "zerkrümle": "zerkrümeln",
    "zerlatsche": "zerlatschen",
    "zerlatschend": "zerlatschen",
    "zerlatschende": "zerlatschend",
    "zerlatschendem": "zerlatschend",
    "zerlatschenden": "zerlatschend",
    "zerlatschender": "zerlatschend",
    "zerlatschendere": "zerlatschend",
    "zerlatschenderem": "zerlatschend",
    "zerlatschenderen": "zerlatschend",
    "zerlatschenderer": "zerlatschend",
    "zerlatschenderes": "zerlatschend",
    "zerlatschendes": "zerlatschend",
    "zerlatschendste": "zerlatschend",
    "zerlatschendstem": "zerlatschend",
    "zerlatschendsten": "zerlatschend",
    "zerlatschendster": "zerlatschend",
    "zerlatschendstes": "zerlatschend",
    "zerlatschest": "zerlatschen",
    "zerlatschet": "zerlatschen",
    "zerlatschst": "zerlatschen",
    "zerlatscht": "zerlatschen",
    "zerlatschte": "zerlatschen",
    "zerlatschtem": "zerlatscht",
    "zerlatschten": "zerlatschen",
    "zerlatschter": "zerlatscht",
    "zerlatschtere": "zerlatscht",
    "zerlatschterem": "zerlatscht",
    "zerlatschteren": "zerlatscht",
    "zerlatschterer": "zerlatscht",
    "zerlatschteres": "zerlatscht",
    "zerlatschtes": "zerlatscht",
    "zerlatschtest": "zerlatschen",
    "zerlatschteste": "zerlatscht",
    "zerlatschtestem": "zerlatscht",
    "zerlatschtesten": "zerlatscht",
    "zerlatschtester": "zerlatscht",
    "zerlatschtestes": "zerlatscht",
    "zerlatschtet": "zerlatschen",
    "zerlaufe": "zerlaufen",
    "zerlaufend": "zerlaufen",
    "zerlaufende": "zerlaufend",
    "zerlaufendem": "zerlaufend",
    "zerlaufenden": "zerlaufend",
    "zerlaufender": "zerlaufend",
    "zerlaufendes": "zerlaufend",
    "zerlaufene": "zerlaufen",
    "zerlaufenem": "zerlaufen",
    "zerlaufenen": "zerlaufen",
    "zerlaufener": "zerlaufen",
    "zerlaufenere": "zerlaufen",
    "zerlaufenerem": "zerlaufen",
    "zerlaufeneren": "zerlaufen",
    "zerlaufenerer": "zerlaufen",
    "zerlaufeneres": "zerlaufen",
    "zerlaufenes": "zerlaufen",
    "zerlaufenstem": "zerlaufen",
    "zerlaufensten": "zerlaufen",
    "zerlaufenster": "zerlaufen",
    "zerlaufenstes": "zerlaufen",
    "zerlaufest": "zerlaufen",
    "zerlaufet": "zerlaufen",
    "zerlauft": "zerlaufen",
    "zerlege": "zerlegen",
    "zerlegend": "zerlegen",
    "zerlegende": "zerlegend",
    "zerlegendem": "zerlegend",
    "zerlegenden": "zerlegend",
    "zerlegender": "zerlegend",
    "zerlegendes": "zerlegend",
    "zerlegest": "zerlegen",
    "zerleget": "zerlegen",
    "zerlegst": "zerlegen",
    "zerlegt": "zerlegen",
    "zerlegte": "zerlegen",
    "zerlegtem": "zerlegt",
    "zerlegten": "zerlegen",
    "zerlegter": "zerlegt",
    "zerlegtere": "zerlegt",
    "zerlegterem": "zerlegt",
    "zerlegteren": "zerlegt",
    "zerlegterer": "zerlegt",
    "zerlegteres": "zerlegt",
    "zerlegtes": "zerlegt",
    "zerlegtest": "zerlegen",
    "zerlegteste": "zerlegt",
    "zerlegtestem": "zerlegt",
    "zerlegtesten": "zerlegt",
    "zerlegtester": "zerlegt",
    "zerlegtestes": "zerlegt",
    "zerlegtet": "zerlegen",
    "zerlief": "zerlaufen",
    "zerliefe": "zerlaufen",
    "zerliefen": "zerlaufen",
    "zerliefest": "zerlaufen",
    "zerliefet": "zerlaufen",
    "zerliefst": "zerlaufen",
    "zerlieft": "zerlaufen",
    "zerläufst": "zerlaufen",
    "zerläuft": "zerlaufen",
    "zermahle": "zermahlen",
    "zermahlend": "zermahlen",
    "zermahlende": "zermahlend",
    "zermahlendem": "zermahlend",
    "zermahlenden": "zermahlend",
    "zermahlender": "zermahlend",
    "zermahlendes": "zermahlend",
    "zermahlene": "zermahlen",
    "zermahlenem": "zermahlen",
    "zermahlenen": "zermahlen",
    "zermahlener": "zermahlen",
    "zermahlenere": "zermahlen",
    "zermahlenerem": "zermahlen",
    "zermahleneren": "zermahlen",
    "zermahlenerer": "zermahlen",
    "zermahleneres": "zermahlen",
    "zermahlenes": "zermahlen",
    "zermahlenstem": "zermahlen",
    "zermahlensten": "zermahlen",
    "zermahlenster": "zermahlen",
    "zermahlenstes": "zermahlen",
    "zermahlest": "zermahlen",
    "zermahlet": "zermahlen",
    "zermahlst": "zermahlen",
    "zermahlt": "zermahlen",
    "zermahlte": "zermahlen",
    "zermahlten": "zermahlen",
    "zermahltest": "zermahlen",
    "zermahltet": "zermahlen",
    "zermalme": "zermalmen",
    "zermalmend": "zermalmen",
    "zermalmende": "zermalmend",
    "zermalmendem": "zermalmend",
    "zermalmenden": "zermalmend",
    "zermalmender": "zermalmend",
    "zermalmendere": "zermalmend",
    "zermalmenderem": "zermalmend",
    "zermalmenderen": "zermalmend",
    "zermalmenderer": "zermalmend",
    "zermalmenderes": "zermalmend",
    "zermalmendes": "zermalmend",
    "zermalmendste": "zermalmend",
    "zermalmendstem": "zermalmend",
    "zermalmendsten": "zermalmend",
    "zermalmendster": "zermalmend",
    "zermalmendstes": "zermalmend",
    "zermalmest": "zermalmen",
    "zermalmet": "zermalmen",
    "zermalmst": "zermalmen",
    "zermalmt": "zermalmen",
    "zermalmte": "zermalmen",
    "zermalmtem": "zermalmt",
    "zermalmten": "zermalmen",
    "zermalmter": "zermalmt",
    "zermalmtere": "zermalmt",
    "zermalmterem": "zermalmt",
    "zermalmteren": "zermalmt",
    "zermalmterer": "zermalmt",
    "zermalmteres": "zermalmt",
    "zermalmtes": "zermalmt",
    "zermalmtest": "zermalmen",
    "zermalmteste": "zermalmt",
    "zermalmtestem": "zermalmt",
    "zermalmtesten": "zermalmt",
    "zermalmtester": "zermalmt",
    "zermalmtestes": "zermalmt",
    "zermalmtet": "zermalmen",
    "zermartere": "zermartern",
    "zermarternd": "zermartern",
    "zermarternde": "zermarternd",
    "zermarterndem": "zermarternd",
    "zermarternden": "zermarternd",
    "zermarternder": "zermarternd",
    "zermarterndere": "zermarternd",
    "zermarternderem": "zermarternd",
    "zermarternderen": "zermarternd",
    "zermarternderer": "zermarternd",
    "zermarternderes": "zermarternd",
    "zermarterndes": "zermarternd",
    "zermarterndste": "zermarternd",
    "zermarterndstem": "zermarternd",
    "zermarterndsten": "zermarternd",
    "zermarterndster": "zermarternd",
    "zermarterndstes": "zermarternd",
    "zermarterst": "zermartern",
    "zermartert": "zermartern",
    "zermarterte": "zermartern",
    "zermartertem": "zermartert",
    "zermarterten": "zermartern",
    "zermarterter": "zermartert",
    "zermartertere": "zermartert",
    "zermarterterem": "zermartert",
    "zermarterteren": "zermartert",
    "zermarterterer": "zermartert",
    "zermarterteres": "zermartert",
    "zermartertes": "zermartert",
    "zermartertest": "zermartern",
    "zermarterteste": "zermartert",
    "zermartertestem": "zermartert",
    "zermartertesten": "zermartert",
    "zermartertester": "zermartert",
    "zermartertestes": "zermartert",
    "zermartertet": "zermartern",
    "zermetzele": "zermetzeln",
    "zermetzelnd": "zermetzeln",
    "zermetzelnde": "zermetzelnd",
    "zermetzelndem": "zermetzelnd",
    "zermetzelnden": "zermetzelnd",
    "zermetzelnder": "zermetzelnd",
    "zermetzelndere": "zermetzelnd",
    "zermetzelnderem": "zermetzelnd",
    "zermetzelnderen": "zermetzelnd",
    "zermetzelnderer": "zermetzelnd",
    "zermetzelnderes": "zermetzelnd",
    "zermetzelndes": "zermetzelnd",
    "zermetzelndste": "zermetzelnd",
    "zermetzelndstem": "zermetzelnd",
    "zermetzelndsten": "zermetzelnd",
    "zermetzelndster": "zermetzelnd",
    "zermetzelndstes": "zermetzelnd",
    "zermetzelst": "zermetzeln",
    "zermetzelt": "zermetzeln",
    "zermetzelte": "zermetzeln",
    "zermetzeltem": "zermetzelt",
    "zermetzelten": "zermetzeln",
    "zermetzelter": "zermetzelt",
    "zermetzeltere": "zermetzelt",
    "zermetzelterem": "zermetzelt",
    "zermetzelteren": "zermetzelt",
    "zermetzelterer": "zermetzelt",
    "zermetzelteres": "zermetzelt",
    "zermetzeltes": "zermetzelt",
    "zermetzeltest": "zermetzeln",
    "zermetzelteste": "zermetzelt",
    "zermetzeltestem": "zermetzelt",
    "zermetzeltesten": "zermetzelt",
    "zermetzeltester": "zermetzelt",
    "zermetzeltestes": "zermetzelt",
    "zermetzeltet": "zermetzeln",
    "zermetzle": "zermetzeln",
    "zermürbe": "zermürben",
    "zermürbend": "zermürben",
    "zermürbende": "zermürbend",
    "zermürbendem": "zermürbend",
    "zermürbenden": "zermürbend",
    "zermürbender": "zermürbend",
    "zermürbendere": "zermürbend",
    "zermürbenderem": "zermürbend",
    "zermürbenderen": "zermürbend",
    "zermürbenderer": "zermürbend",
    "zermürbenderes": "zermürbend",
    "zermürbendes": "zermürbend",
    "zermürbendste": "zermürbend",
    "zermürbendstem": "zermürbend",
    "zermürbendsten": "zermürbend",
    "zermürbendster": "zermürbend",
    "zermürbendstes": "zermürbend",
    "zermürbest": "zermürben",
    "zermürbet": "zermürben",
    "zermürbst": "zermürben",
    "zermürbt": "zermürben",
    "zermürbte": "zermürben",
    "zermürbtem": "zermürbt",
    "zermürbten": "zermürben",
    "zermürbter": "zermürbt",
    "zermürbtere": "zermürbt",
    "zermürbterem": "zermürbt",
    "zermürbteren": "zermürbt",
    "zermürbterer": "zermürbt",
    "zermürbteres": "zermürbt",
    "zermürbtes": "zermürbt",
    "zermürbtest": "zermürben",
    "zermürbteste": "zermürbt",
    "zermürbtestem": "zermürbt",
    "zermürbtesten": "zermürbt",
    "zermürbtester": "zermürbt",
    "zermürbtestes": "zermürbt",
    "zermürbtet": "zermürben",
    "zernage": "zernagen",
    "zernagend": "zernagen",
    "zernagende": "zernagend",
    "zernagendem": "zernagend",
    "zernagenden": "zernagend",
    "zernagender": "zernagend",
    "zernagendere": "zernagend",
    "zernagenderem": "zernagend",
    "zernagenderen": "zernagend",
    "zernagenderer": "zernagend",
    "zernagenderes": "zernagend",
    "zernagendes": "zernagend",
    "zernagendste": "zernagend",
    "zernagendstem": "zernagend",
    "zernagendsten": "zernagend",
    "zernagendster": "zernagend",
    "zernagendstes": "zernagend",
    "zernagest": "zernagen",
    "zernaget": "zernagen",
    "zernagst": "zernagen",
    "zernagt": "zernagen",
    "zernagte": "zernagen",
    "zernagtem": "zernagt",
    "zernagten": "zernagen",
    "zernagter": "zernagt",
    "zernagtere": "zernagt",
    "zernagterem": "zernagt",
    "zernagteren": "zernagt",
    "zernagterer": "zernagt",
    "zernagteres": "zernagt",
    "zernagtes": "zernagt",
    "zernagtest": "zernagen",
    "zernagteste": "zernagt",
    "zernagtestem": "zernagt",
    "zernagtesten": "zernagt",
    "zernagtester": "zernagt",
    "zernagtestes": "zernagt",
    "zernagtet": "zernagen",
    "zernarbe": "zernarben",
    "zernarbend": "zernarben",
    "zernarbende": "zernarbend",
    "zernarbendem": "zernarbend",
    "zernarbenden": "zernarbend",
    "zernarbender": "zernarbend",
    "zernarbendere": "zernarbend",
    "zernarbenderem": "zernarbend",
    "zernarbenderen": "zernarbend",
    "zernarbenderer": "zernarbend",
    "zernarbenderes": "zernarbend",
    "zernarbendes": "zernarbend",
    "zernarbendste": "zernarbend",
    "zernarbendstem": "zernarbend",
    "zernarbendsten": "zernarbend",
    "zernarbendster": "zernarbend",
    "zernarbendstes": "zernarbend",
    "zernarbest": "zernarben",
    "zernarbet": "zernarben",
    "zernarbst": "zernarben",
    "zernarbt": "zernarben",
    "zernarbte": "zernarben",
    "zernarbtem": "zernarbt",
    "zernarbten": "zernarben",
    "zernarbter": "zernarbt",
    "zernarbtere": "zernarbt",
    "zernarbterem": "zernarbt",
    "zernarbteren": "zernarbt",
    "zernarbterer": "zernarbt",
    "zernarbteres": "zernarbt",
    "zernarbtes": "zernarbt",
    "zernarbtest": "zernarben",
    "zernarbteste": "zernarbt",
    "zernarbtestem": "zernarbt",
    "zernarbtesten": "zernarbt",
    "zernarbtester": "zernarbt",
    "zernarbtestes": "zernarbt",
    "zernarbtet": "zernarben",
    "zerpfeife": "zerpfeifen",
    "zerpfeifend": "zerpfeifen",
    "zerpfeifende": "zerpfeifend",
    "zerpfeifendem": "zerpfeifend",
    "zerpfeifenden": "zerpfeifend",
    "zerpfeifender": "zerpfeifend",
    "zerpfeifendere": "zerpfeifend",
    "zerpfeifenderem": "zerpfeifend",
    "zerpfeifenderen": "zerpfeifend",
    "zerpfeifenderer": "zerpfeifend",
    "zerpfeifenderes": "zerpfeifend",
    "zerpfeifendes": "zerpfeifend",
    "zerpfeifendste": "zerpfeifend",
    "zerpfeifendstem": "zerpfeifend",
    "zerpfeifendsten": "zerpfeifend",
    "zerpfeifendster": "zerpfeifend",
    "zerpfeifendstes": "zerpfeifend",
    "zerpfeifest": "zerpfeifen",
    "zerpfeifet": "zerpfeifen",
    "zerpfeifst": "zerpfeifen",
    "zerpfeift": "zerpfeifen",
    "zerpfiff": "zerpfeifen",
    "zerpfiffe": "zerpfeifen",
    "zerpfiffen": "zerpfeifen",
    "zerpfiffene": "zerpfiffen",
    "zerpfiffenem": "zerpfiffen",
    "zerpfiffenen": "zerpfiffen",
    "zerpfiffener": "zerpfiffen",
    "zerpfiffenere": "zerpfiffen",
    "zerpfiffenerem": "zerpfiffen",
    "zerpfiffeneren": "zerpfiffen",
    "zerpfiffenerer": "zerpfiffen",
    "zerpfiffeneres": "zerpfiffen",
    "zerpfiffenes": "zerpfiffen",
    "zerpfiffenste": "zerpfiffen",
    "zerpfiffenstem": "zerpfiffen",
    "zerpfiffensten": "zerpfiffen",
    "zerpfiffenster": "zerpfiffen",
    "zerpfiffenstes": "zerpfiffen",
    "zerpfiffest": "zerpfeifen",
    "zerpfiffet": "zerpfeifen",
    "zerpfiffst": "zerpfeifen",
    "zerpfifft": "zerpfeifen",
    "zerpflücke": "zerpflücken",
    "zerpflückend": "zerpflücken",
    "zerpflückende": "zerpflückend",
    "zerpflückendem": "zerpflückend",
    "zerpflückenden": "zerpflückend",
    "zerpflückender": "zerpflückend",
    "zerpflückendere": "zerpflückend",
    "zerpflückenderem": "zerpflückend",
    "zerpflückenderen": "zerpflückend",
    "zerpflückenderer": "zerpflückend",
    "zerpflückenderes": "zerpflückend",
    "zerpflückendes": "zerpflückend",
    "zerpflückendste": "zerpflückend",
    "zerpflückendstem": "zerpflückend",
    "zerpflückendsten": "zerpflückend",
    "zerpflückendster": "zerpflückend",
    "zerpflückendstes": "zerpflückend",
    "zerpflückest": "zerpflücken",
    "zerpflücket": "zerpflücken",
    "zerpflückst": "zerpflücken",
    "zerpflückt": "zerpflücken",
    "zerpflückte": "zerpflücken",
    "zerpflücktem": "zerpflückt",
    "zerpflückten": "zerpflücken",
    "zerpflückter": "zerpflückt",
    "zerpflücktere": "zerpflückt",
    "zerpflückterem": "zerpflückt",
    "zerpflückteren": "zerpflückt",
    "zerpflückterer": "zerpflückt",
    "zerpflückteres": "zerpflückt",
    "zerpflücktes": "zerpflückt",
    "zerpflücktest": "zerpflücken",
    "zerpflückteste": "zerpflückt",
    "zerpflücktestem": "zerpflückt",
    "zerpflücktesten": "zerpflückt",
    "zerpflücktester": "zerpflückt",
    "zerpflücktestes": "zerpflückt",
    "zerpflücktet": "zerpflücken",
    "zerpflüge": "zerpflügen",
    "zerpflügend": "zerpflügen",
    "zerpflügende": "zerpflügend",
    "zerpflügendem": "zerpflügend",
    "zerpflügenden": "zerpflügend",
    "zerpflügender": "zerpflügend",
    "zerpflügendes": "zerpflügend",
    "zerpflügest": "zerpflügen",
    "zerpflüget": "zerpflügen",
    "zerpflügst": "zerpflügen",
    "zerpflügt": "zerpflügen",
    "zerpflügte": "zerpflügen",
    "zerpflügtem": "zerpflügt",
    "zerpflügten": "zerpflügen",
    "zerpflügter": "zerpflügt",
    "zerpflügtes": "zerpflügt",
    "zerpflügtest": "zerpflügen",
    "zerpflügtet": "zerpflügen",
    "zerpicke": "zerpicken",
    "zerpickend": "zerpicken",
    "zerpickende": "zerpickend",
    "zerpickendem": "zerpickend",
    "zerpickenden": "zerpickend",
    "zerpickender": "zerpickend",
    "zerpickendes": "zerpickend",
    "zerpickest": "zerpicken",
    "zerpicket": "zerpicken",
    "zerpickst": "zerpicken",
    "zerpickt": "zerpicken",
    "zerpickte": "zerpicken",
    "zerpicktem": "zerpickt",
    "zerpickten": "zerpicken",
    "zerpickter": "zerpickt",
    "zerpicktes": "zerpickt",
    "zerpicktest": "zerpicken",
    "zerpicktet": "zerpicken",
    "zerplatze": "zerplatzen",
    "zerplatzend": "zerplatzen",
    "zerplatzende": "zerplatzend",
    "zerplatzendem": "zerplatzend",
    "zerplatzenden": "zerplatzend",
    "zerplatzender": "zerplatzend",
    "zerplatzendes": "zerplatzend",
    "zerplatzest": "zerplatzen",
    "zerplatzet": "zerplatzen",
    "zerplatzt": "zerplatzen",
    "zerplatzte": "zerplatzen",
    "zerplatztem": "zerplatzt",
    "zerplatzten": "zerplatzen",
    "zerplatzter": "zerplatzt",
    "zerplatztes": "zerplatzt",
    "zerplatztest": "zerplatzen",
    "zerplatztet": "zerplatzen",
    "zerpresse": "zerpressen",
    "zerpressend": "zerpressen",
    "zerpressende": "zerpressend",
    "zerpressendem": "zerpressend",
    "zerpressenden": "zerpressend",
    "zerpressender": "zerpressend",
    "zerpressendes": "zerpressend",
    "zerpressest": "zerpressen",
    "zerpresset": "zerpressen",
    "zerpreßt": "zerpressen",
    "zerpreßte": "zerpressen",
    "zerpreßtem": "zerpreßt",
    "zerpreßten": "zerpressen",
    "zerpreßter": "zerpreßt",
    "zerpreßtes": "zerpreßt",
    "zerpreßtest": "zerpressen",
    "zerpreßtet": "zerpressen",
    "zerquetsche": "zerquetschen",
    "zerquetschend": "zerquetschen",
    "zerquetschende": "zerquetschend",
    "zerquetschendem": "zerquetschend",
    "zerquetschenden": "zerquetschend",
    "zerquetschender": "zerquetschend",
    "zerquetschendere": "zerquetschend",
    "zerquetschenderem": "zerquetschend",
    "zerquetschenderen": "zerquetschend",
    "zerquetschenderer": "zerquetschend",
    "zerquetschenderes": "zerquetschend",
    "zerquetschendes": "zerquetschend",
    "zerquetschendste": "zerquetschend",
    "zerquetschendstem": "zerquetschend",
    "zerquetschendsten": "zerquetschend",
    "zerquetschendster": "zerquetschend",
    "zerquetschendstes": "zerquetschend",
    "zerquetschest": "zerquetschen",
    "zerquetschet": "zerquetschen",
    "zerquetschst": "zerquetschen",
    "zerquetscht": "zerquetschen",
    "zerquetschte": "zerquetschen",
    "zerquetschtem": "zerquetscht",
    "zerquetschten": "zerquetschen",
    "zerquetschter": "zerquetscht",
    "zerquetschtere": "zerquetscht",
    "zerquetschterem": "zerquetscht",
    "zerquetschteren": "zerquetscht",
    "zerquetschterer": "zerquetscht",
    "zerquetschteres": "zerquetscht",
    "zerquetschtes": "zerquetscht",
    "zerquetschtest": "zerquetschen",
    "zerquetschteste": "zerquetscht",
    "zerquetschtestem": "zerquetscht",
    "zerquetschtesten": "zerquetscht",
    "zerquetschtester": "zerquetscht",
    "zerquetschtestes": "zerquetscht",
    "zerquetschtet": "zerquetschen",
    "zerrann": "zerrinnen",
    "zerrannen": "zerrinnen",
    "zerrannst": "zerrinnen",
    "zerrannt": "zerrinnen",
    "zerre": "zerren",
    "zerrede": "zerreden",
    "zerredend": "zerreden",
    "zerredende": "zerredend",
    "zerredendem": "zerredend",
    "zerredenden": "zerredend",
    "zerredender": "zerredend",
    "zerredendes": "zerredend",
    "zerredest": "zerreden",
    "zerredet": "zerreden",
    "zerredete": "zerreden",
    "zerredetem": "zerredet",
    "zerredeten": "zerreden",
    "zerredeter": "zerredet",
    "zerredetes": "zerredet",
    "zerredetest": "zerreden",
    "zerredetet": "zerreden",
    "zerreibe": "zerreiben",
    "zerreibend": "zerreiben",
    "zerreibende": "zerreibend",
    "zerreibendem": "zerreibend",
    "zerreibenden": "zerreibend",
    "zerreibender": "zerreibend",
    "zerreibendere": "zerreibend",
    "zerreibenderem": "zerreibend",
    "zerreibenderen": "zerreibend",
    "zerreibenderer": "zerreibend",
    "zerreibenderes": "zerreibend",
    "zerreibendes": "zerreibend",
    "zerreibendste": "zerreibend",
    "zerreibendstem": "zerreibend",
    "zerreibendsten": "zerreibend",
    "zerreibendster": "zerreibend",
    "zerreibendstes": "zerreibend",
    "zerreibest": "zerreiben",
    "zerreibet": "zerreiben",
    "zerreibst": "zerreiben",
    "zerreibt": "zerreiben",
    "zerreißbare": "zerreißbar",
    "zerreißbarem": "zerreißbar",
    "zerreißbaren": "zerreißbar",
    "zerreißbarer": "zerreißbar",
    "zerreißbarere": "zerreißbar",
    "zerreißbarerem": "zerreißbar",
    "zerreißbareren": "zerreißbar",
    "zerreißbarerer": "zerreißbar",
    "zerreißbareres": "zerreißbar",
    "zerreißbares": "zerreißbar",
    "zerreißbarste": "zerreißbar",
    "zerreißbarstem": "zerreißbar",
    "zerreißbarsten": "zerreißbar",
    "zerreißbarster": "zerreißbar",
    "zerreißbarstes": "zerreißbar",
    "zerreiße": "zerreißen",
    "zerreißend": "zerreißen",
    "zerreißende": "zerreißend",
    "zerreißendem": "zerreißend",
    "zerreißenden": "zerreißend",
    "zerreißender": "zerreißend",
    "zerreißendere": "zerreißend",
    "zerreißenderem": "zerreißend",
    "zerreißenderen": "zerreißend",
    "zerreißenderer": "zerreißend",
    "zerreißenderes": "zerreißend",
    "zerreißendes": "zerreißend",
    "zerreißendste": "zerreißend",
    "zerreißendstem": "zerreißend",
    "zerreißendsten": "zerreißend",
    "zerreißendster": "zerreißend",
    "zerreißendstes": "zerreißend",
    "zerreißest": "zerreißen",
    "zerreißet": "zerreißen",
    "zerreißt": "zerreißen",
    "zerrend": "zerren",
    "zerrende": "zerrend",
    "zerrendem": "zerrend",
    "zerrenden": "zerrend",
    "zerrender": "zerrend",
    "zerrendes": "zerrend",
    "zerrest": "zerren",
    "zerret": "zerren",
    "zerrieb": "zerreiben",
    "zerriebe": "zerreiben",
    "zerrieben": "zerreiben",
    "zerriebene": "zerrieben",
    "zerriebenem": "zerrieben",
    "zerriebenen": "zerrieben",
    "zerriebener": "zerrieben",
    "zerriebenere": "zerrieben",
    "zerriebenerem": "zerrieben",
    "zerriebeneren": "zerrieben",
    "zerriebenerer": "zerrieben",
    "zerriebeneres": "zerrieben",
    "zerriebenes": "zerrieben",
    "zerriebenste": "zerrieben",
    "zerriebenstem": "zerrieben",
    "zerriebensten": "zerrieben",
    "zerriebenster": "zerrieben",
    "zerriebenstes": "zerrieben",
    "zerriebest": "zerreiben",
    "zerriebet": "zerreiben",
    "zerriebst": "zerreiben",
    "zerriebt": "zerreiben",
    "zerrinne": "zerrinnen",
    "zerrinnend": "zerrinnen",
    "zerrinnende": "zerrinnend",
    "zerrinnendem": "zerrinnend",
    "zerrinnenden": "zerrinnend",
    "zerrinnender": "zerrinnend",
    "zerrinnendes": "zerrinnend",
    "zerrinnest": "zerrinnen",
    "zerrinnet": "zerrinnen",
    "zerrinnst": "zerrinnen",
    "zerrinnt": "zerrinnen",
    "zerrisse": "zerreißen",
    "zerrissen": "zerreißen",
    "zerrissene": "zerrissen",
    "zerrissenem": "zerrissen",
    "zerrissenen": "zerrissen",
    "zerrissener": "zerrissen",
    "zerrissenere": "zerrissen",
    "zerrissenerem": "zerrissen",
    "zerrisseneren": "zerrissen",
    "zerrissenerer": "zerrissen",
    "zerrisseneres": "zerrissen",
    "zerrissenes": "zerrissen",
    "zerrissenste": "zerrissen",
    "zerrissenstem": "zerrissen",
    "zerrissensten": "zerrissen",
    "zerrissenster": "zerrissen",
    "zerrissenstes": "zerrissen",
    "zerrissest": "zerreißen",
    "zerrisset": "zerreißen",
    "zerriß": "zerreißen",
    "zerrißt": "zerreißen",
    "zerronnen": "zerrinnen",
    "zerronnene": "zerronnen",
    "zerronnenem": "zerronnen",
    "zerronnenen": "zerronnen",
    "zerronnener": "zerronnen",
    "zerronnenere": "zerronnen",
    "zerronnenerem": "zerronnen",
    "zerronneneren": "zerronnen",
    "zerronnenerer": "zerronnen",
    "zerronneneres": "zerronnen",
    "zerronnenes": "zerronnen",
    "zerronnenste": "zerronnen",
    "zerronnenstem": "zerronnen",
    "zerronnensten": "zerronnen",
    "zerronnenster": "zerronnen",
    "zerronnenstes": "zerronnen",
    "zerrst": "zerren",
    "zerrt": "zerren",
    "zerrte": "zerren",
    "zerrten": "zerren",
    "zerrtest": "zerren",
    "zerrtet": "zerren",
    "zerrupfe": "zerrupfen",
    "zerrupfend": "zerrupfen",
    "zerrupfende": "zerrupfend",
    "zerrupfendem": "zerrupfend",
    "zerrupfenden": "zerrupfend",
    "zerrupfender": "zerrupfend",
    "zerrupfendere": "zerrupfend",
    "zerrupfenderem": "zerrupfend",
    "zerrupfenderen": "zerrupfend",
    "zerrupfenderer": "zerrupfend",
    "zerrupfenderes": "zerrupfend",
    "zerrupfendes": "zerrupfend",
    "zerrupfendste": "zerrupfend",
    "zerrupfendstem": "zerrupfend",
    "zerrupfendsten": "zerrupfend",
    "zerrupfendster": "zerrupfend",
    "zerrupfendstes": "zerrupfend",
    "zerrupfest": "zerrupfen",
    "zerrupfet": "zerrupfen",
    "zerrupfst": "zerrupfen",
    "zerrupft": "zerrupfen",
    "zerrupfte": "zerrupfen",
    "zerrupftem": "zerrupft",
    "zerrupften": "zerrupfen",
    "zerrupfter": "zerrupft",
    "zerrupftere": "zerrupft",
    "zerrupfterem": "zerrupft",
    "zerrupfteren": "zerrupft",
    "zerrupfterer": "zerrupft",
    "zerrupfteres": "zerrupft",
    "zerrupftes": "zerrupft",
    "zerrupftest": "zerrupfen",
    "zerrupfteste": "zerrupft",
    "zerrupftestem": "zerrupft",
    "zerrupftesten": "zerrupft",
    "zerrupftester": "zerrupft",
    "zerrupftestes": "zerrupft",
    "zerrupftet": "zerrupfen",
    "zerränne": "zerrinnen",
    "zerrännen": "zerrinnen",
    "zerrännest": "zerrinnen",
    "zerrännet": "zerrinnen",
    "zerrütte": "zerrütten",
    "zerrüttele": "zerrütteln",
    "zerrüttelnd": "zerrütteln",
    "zerrüttelnde": "zerrüttelnd",
    "zerrüttelndem": "zerrüttelnd",
    "zerrüttelnden": "zerrüttelnd",
    "zerrüttelnder": "zerrüttelnd",
    "zerrüttelndes": "zerrüttelnd",
    "zerrüttelst": "zerrütteln",
    "zerrüttelt": "zerrütteln",
    "zerrüttelte": "zerrütteln",
    "zerrütteltem": "zerrüttelt",
    "zerrüttelten": "zerrütteln",
    "zerrüttelter": "zerrüttelt",
    "zerrütteltere": "zerrüttelt",
    "zerrüttelterem": "zerrüttelt",
    "zerrüttelteren": "zerrüttelt",
    "zerrüttelterer": "zerrüttelt",
    "zerrüttelteres": "zerrüttelt",
    "zerrütteltes": "zerrüttelt",
    "zerrütteltest": "zerrütteln",
    "zerrüttelteste": "zerrüttelt",
    "zerrütteltestem": "zerrüttelt",
    "zerrütteltesten": "zerrüttelt",
    "zerrütteltester": "zerrüttelt",
    "zerrütteltestes": "zerrüttelt",
    "zerrütteltet": "zerrütteln",
    "zerrüttend": "zerrütten",
    "zerrüttende": "zerrüttend",
    "zerrüttendem": "zerrüttend",
    "zerrüttenden": "zerrüttend",
    "zerrüttender": "zerrüttend",
    "zerrüttendere": "zerrüttend",
    "zerrüttenderem": "zerrüttend",
    "zerrüttenderen": "zerrüttend",
    "zerrüttenderer": "zerrüttend",
    "zerrüttenderes": "zerrüttend",
    "zerrüttendes": "zerrüttend",
    "zerrüttendste": "zerrüttend",
    "zerrüttendstem": "zerrüttend",
    "zerrüttendsten": "zerrüttend",
    "zerrüttendster": "zerrüttend",
    "zerrüttendstes": "zerrüttend",
    "zerrüttest": "zerrütten",
    "zerrüttet": "zerrütten",
    "zerrüttete": "zerrütten",
    "zerrüttetem": "zerrüttet",
    "zerrütteten": "zerrütten",
    "zerrütteter": "zerrüttet",
    "zerrüttetere": "zerrüttet",
    "zerrütteterem": "zerrüttet",
    "zerrütteteren": "zerrüttet",
    "zerrütteterer": "zerrüttet",
    "zerrütteteres": "zerrüttet",
    "zerrüttetes": "zerrüttet",
    "zerrüttetest": "zerrütten",
    "zerrütteteste": "zerrüttet",
    "zerrüttetestem": "zerrüttet",
    "zerrüttetesten": "zerrüttet",
    "zerrüttetester": "zerrüttet",
    "zerrüttetestes": "zerrüttet",
    "zerrüttetet": "zerrütten",
    "zerrüttle": "zerrütteln",
    "zersalze": "zersalzen",
    "zersalzend": "zersalzen",
    "zersalzende": "zersalzend",
    "zersalzendem": "zersalzend",
    "zersalzenden": "zersalzend",
    "zersalzender": "zersalzend",
    "zersalzendes": "zersalzend",
    "zersalzene": "zersalzen",
    "zersalzenem": "zersalzen",
    "zersalzenen": "zersalzen",
    "zersalzener": "zersalzen",
    "zersalzenere": "zersalzen",
    "zersalzenerem": "zersalzen",
    "zersalzeneren": "zersalzen",
    "zersalzenerer": "zersalzen",
    "zersalzeneres": "zersalzen",
    "zersalzenes": "zersalzen",
    "zersalzenstem": "zersalzen",
    "zersalzensten": "zersalzen",
    "zersalzenster": "zersalzen",
    "zersalzenstes": "zersalzen",
    "zersalzest": "zersalzen",
    "zersalzet": "zersalzen",
    "zersalzt": "zersalzen",
    "zersalzte": "zersalzen",
    "zersalzten": "zersalzen",
    "zersalztest": "zersalzen",
    "zersalztet": "zersalzen",
    "zerschelle": "zerschellen",
    "zerschellend": "zerschellen",
    "zerschellende": "zerschellend",
    "zerschellendem": "zerschellend",
    "zerschellenden": "zerschellend",
    "zerschellender": "zerschellend",
    "zerschellendere": "zerschellend",
    "zerschellenderem": "zerschellend",
    "zerschellenderen": "zerschellend",
    "zerschellenderer": "zerschellend",
    "zerschellenderes": "zerschellend",
    "zerschellendes": "zerschellend",
    "zerschellendste": "zerschellend",
    "zerschellendstem": "zerschellend",
    "zerschellendsten": "zerschellend",
    "zerschellendster": "zerschellend",
    "zerschellendstes": "zerschellend",
    "zerschellest": "zerschellen",
    "zerschellet": "zerschellen",
    "zerschellst": "zerschellen",
    "zerschellt": "zerschellen",
    "zerschellte": "zerschellen",
    "zerschelltem": "zerschellt",
    "zerschellten": "zerschellen",
    "zerschellter": "zerschellt",
    "zerschelltere": "zerschellt",
    "zerschellterem": "zerschellt",
    "zerschellteren": "zerschellt",
    "zerschellterer": "zerschellt",
    "zerschellteres": "zerschellt",
    "zerschelltes": "zerschellt",
    "zerschelltest": "zerschellen",
    "zerschellteste": "zerschellt",
    "zerschelltestem": "zerschellt",
    "zerschelltesten": "zerschellt",
    "zerschelltester": "zerschellt",
    "zerschelltestes": "zerschellt",
    "zerschelltet": "zerschellen",
    "zerschere": "zerscheren",
    "zerscherend": "zerscheren",
    "zerscherende": "zerscherend",
    "zerscherendem": "zerscherend",
    "zerscherenden": "zerscherend",
    "zerscherender": "zerscherend",
    "zerscherendere": "zerscherend",
    "zerscherenderem": "zerscherend",
    "zerscherenderen": "zerscherend",
    "zerscherenderer": "zerscherend",
    "zerscherenderes": "zerscherend",
    "zerscherendes": "zerscherend",
    "zerscherendste": "zerscherend",
    "zerscherendstem": "zerscherend",
    "zerscherendsten": "zerscherend",
    "zerscherendster": "zerscherend",
    "zerscherendstes": "zerscherend",
    "zerscherest": "zerscheren",
    "zerscheret": "zerscheren",
    "zerscherst": "zerscheren",
    "zerschert": "zerscheren",
    "zerscheuere": "zerscheuern",
    "zerscheuernd": "zerscheuern",
    "zerscheuernde": "zerscheuernd",
    "zerscheuerndem": "zerscheuernd",
    "zerscheuernden": "zerscheuernd",
    "zerscheuernder": "zerscheuernd",
    "zerscheuerndere": "zerscheuernd",
    "zerscheuernderem": "zerscheuernd",
    "zerscheuernderen": "zerscheuernd",
    "zerscheuernderer": "zerscheuernd",
    "zerscheuernderes": "zerscheuernd",
    "zerscheuerndes": "zerscheuernd",
    "zerscheuerndste": "zerscheuernd",
    "zerscheuerndstem": "zerscheuernd",
    "zerscheuerndsten": "zerscheuernd",
    "zerscheuerndster": "zerscheuernd",
    "zerscheuerndstes": "zerscheuernd",
    "zerscheuerst": "zerscheuern",
    "zerscheuert": "zerscheuern",
    "zerscheuerte": "zerscheuern",
    "zerscheuertem": "zerscheuert",
    "zerscheuerten": "zerscheuern",
    "zerscheuerter": "zerscheuert",
    "zerscheuertere": "zerscheuert",
    "zerscheuerterem": "zerscheuert",
    "zerscheuerteren": "zerscheuert",
    "zerscheuerterer": "zerscheuert",
    "zerscheuerteres": "zerscheuert",
    "zerscheuertes": "zerscheuert",
    "zerscheuertest": "zerscheuern",
    "zerscheuerteste": "zerscheuert",
    "zerscheuertestem": "zerscheuert",
    "zerscheuertesten": "zerscheuert",
    "zerscheuertester": "zerscheuert",
    "zerscheuertestes": "zerscheuert",
    "zerscheuertet": "zerscheuern",
    "zerschieße": "zerschießen",
    "zerschießend": "zerschießen",
    "zerschießende": "zerschießend",
    "zerschießendem": "zerschießend",
    "zerschießenden": "zerschießend",
    "zerschießender": "zerschießend",
    "zerschießendes": "zerschießend",
    "zerschießest": "zerschießen",
    "zerschießet": "zerschießen",
    "zerschießt": "zerschießen",
    "zerschinde": "zerschinden",
    "zerschindend": "zerschinden",
    "zerschindende": "zerschindend",
    "zerschindendem": "zerschindend",
    "zerschindenden": "zerschindend",
    "zerschindender": "zerschindend",
    "zerschindendere": "zerschindend",
    "zerschindenderem": "zerschindend",
    "zerschindenderen": "zerschindend",
    "zerschindenderer": "zerschindend",
    "zerschindenderes": "zerschindend",
    "zerschindendes": "zerschindend",
    "zerschindendste": "zerschindend",
    "zerschindendstem": "zerschindend",
    "zerschindendsten": "zerschindend",
    "zerschindendster": "zerschindend",
    "zerschindendstes": "zerschindend",
    "zerschindest": "zerschinden",
    "zerschindet": "zerschinden",
    "zerschindete": "zerschinden",
    "zerschindeten": "zerschinden",
    "zerschindetest": "zerschinden",
    "zerschindetet": "zerschinden",
    "zerschlage": "zerschlagen",
    "zerschlagend": "zerschlagen",
    "zerschlagende": "zerschlagend",
    "zerschlagendem": "zerschlagend",
    "zerschlagenden": "zerschlagend",
    "zerschlagender": "zerschlagend",
    "zerschlagendes": "zerschlagend",
    "zerschlagene": "zerschlagen",
    "zerschlagenem": "zerschlagen",
    "zerschlagenen": "zerschlagen",
    "zerschlagener": "zerschlagen",
    "zerschlagenere": "zerschlagen",
    "zerschlagenerem": "zerschlagen",
    "zerschlageneren": "zerschlagen",
    "zerschlagenerer": "zerschlagen",
    "zerschlageneres": "zerschlagen",
    "zerschlagenes": "zerschlagen",
    "zerschlagenstem": "zerschlagen",
    "zerschlagensten": "zerschlagen",
    "zerschlagenster": "zerschlagen",
    "zerschlagenstes": "zerschlagen",
    "zerschlagest": "zerschlagen",
    "zerschlaget": "zerschlagen",
    "zerschlagt": "zerschlagen",
    "zerschlissene": "zerschlissen",
    "zerschlissenem": "zerschlissen",
    "zerschlissenen": "zerschlissen",
    "zerschlissener": "zerschlissen",
    "zerschlissenere": "zerschlissen",
    "zerschlissenerem": "zerschlissen",
    "zerschlisseneren": "zerschlissen",
    "zerschlissenerer": "zerschlissen",
    "zerschlisseneres": "zerschlissen",
    "zerschlissenes": "zerschlissen",
    "zerschlissenste": "zerschlissen",
    "zerschlissenstem": "zerschlissen",
    "zerschlissensten": "zerschlissen",
    "zerschlissenster": "zerschlissen",
    "zerschlissenstes": "zerschlissen",
    "zerschlug": "zerschlagen",
    "zerschlugen": "zerschlagen",
    "zerschlugst": "zerschlagen",
    "zerschlugt": "zerschlagen",
    "zerschlägst": "zerschlagen",
    "zerschlägt": "zerschlagen",
    "zerschlüge": "zerschlagen",
    "zerschlügen": "zerschlagen",
    "zerschlügest": "zerschlagen",
    "zerschlüget": "zerschlagen",
    "zerschmeiße": "zerschmeißen",
    "zerschmeißend": "zerschmeißen",
    "zerschmeißende": "zerschmeißend",
    "zerschmeißendem": "zerschmeißend",
    "zerschmeißenden": "zerschmeißend",
    "zerschmeißender": "zerschmeißend",
    "zerschmeißendes": "zerschmeißend",
    "zerschmeißest": "zerschmeißen",
    "zerschmeißet": "zerschmeißen",
    "zerschmeißt": "zerschmeißen",
    "zerschmelze": "zerschmelzen",
    "zerschmelzend": "zerschmelzen",
    "zerschmelzende": "zerschmelzend",
    "zerschmelzendem": "zerschmelzend",
    "zerschmelzenden": "zerschmelzend",
    "zerschmelzender": "zerschmelzend",
    "zerschmelzendere": "zerschmelzend",
    "zerschmelzenderem": "zerschmelzend",
    "zerschmelzenderen": "zerschmelzend",
    "zerschmelzenderer": "zerschmelzend",
    "zerschmelzenderes": "zerschmelzend",
    "zerschmelzendes": "zerschmelzend",
    "zerschmelzendste": "zerschmelzend",
    "zerschmelzendstem": "zerschmelzend",
    "zerschmelzendsten": "zerschmelzend",
    "zerschmelzendster": "zerschmelzend",
    "zerschmelzendstes": "zerschmelzend",
    "zerschmelzest": "zerschmelzen",
    "zerschmelzet": "zerschmelzen",
    "zerschmelzt": "zerschmelzen",
    "zerschmettere": "zerschmettern",
    "zerschmetternd": "zerschmettern",
    "zerschmetternde": "zerschmetternd",
    "zerschmetterndem": "zerschmetternd",
    "zerschmetternden": "zerschmetternd",
    "zerschmetternder": "zerschmetternd",
    "zerschmetterndere": "zerschmetternd",
    "zerschmetternderem": "zerschmetternd",
    "zerschmetternderen": "zerschmetternd",
    "zerschmetternderer": "zerschmetternd",
    "zerschmetternderes": "zerschmetternd",
    "zerschmetterndes": "zerschmetternd",
    "zerschmetterndste": "zerschmetternd",
    "zerschmetterndstem": "zerschmetternd",
    "zerschmetterndsten": "zerschmetternd",
    "zerschmetterndster": "zerschmetternd",
    "zerschmetterndstes": "zerschmetternd",
    "zerschmetterst": "zerschmettern",
    "zerschmettert": "zerschmettern",
    "zerschmetterte": "zerschmettern",
    "zerschmettertem": "zerschmettert",
    "zerschmetterten": "zerschmettern",
    "zerschmetterter": "zerschmettert",
    "zerschmettertere": "zerschmettert",
    "zerschmetterterem": "zerschmettert",
    "zerschmetterteren": "zerschmettert",
    "zerschmetterterer": "zerschmettert",
    "zerschmetterteres": "zerschmettert",
    "zerschmettertes": "zerschmettert",
    "zerschmettertest": "zerschmettern",
    "zerschmettertestem": "zerschmettert",
    "zerschmettertesten": "zerschmettert",
    "zerschmettertester": "zerschmettert",
    "zerschmettertestes": "zerschmettert",
    "zerschmettertet": "zerschmettern",
    "zerschmilz": "zerschmelzen",
    "zerschmilzt": "zerschmelzen",
    "zerschmisse": "zerschmeißen",
    "zerschmissen": "zerschmeißen",
    "zerschmissene": "zerschmissen",
    "zerschmissenem": "zerschmissen",
    "zerschmissenen": "zerschmissen",
    "zerschmissener": "zerschmissen",
    "zerschmissenere": "zerschmissen",
    "zerschmissenerem": "zerschmissen",
    "zerschmisseneren": "zerschmissen",
    "zerschmissenerer": "zerschmissen",
    "zerschmisseneres": "zerschmissen",
    "zerschmissenes": "zerschmissen",
    "zerschmissenste": "zerschmissen",
    "zerschmissenstem": "zerschmissen",
    "zerschmissensten": "zerschmissen",
    "zerschmissenster": "zerschmissen",
    "zerschmissenstes": "zerschmissen",
    "zerschmissest": "zerschmeißen",
    "zerschmisset": "zerschmeißen",
    "zerschmiß": "zerschmeißen",
    "zerschmißt": "zerschmeißen",
    "zerschmolz": "zerschmelzen",
    "zerschmolzen": "zerschmelzen",
    "zerschmolzene": "zerschmolzen",
    "zerschmolzenem": "zerschmolzen",
    "zerschmolzenen": "zerschmolzen",
    "zerschmolzener": "zerschmolzen",
    "zerschmolzenere": "zerschmolzen",
    "zerschmolzenerem": "zerschmolzen",
    "zerschmolzeneren": "zerschmolzen",
    "zerschmolzenerer": "zerschmolzen",
    "zerschmolzeneres": "zerschmolzen",
    "zerschmolzenes": "zerschmolzen",
    "zerschmolzenste": "zerschmolzen",
    "zerschmolzenstem": "zerschmolzen",
    "zerschmolzensten": "zerschmolzen",
    "zerschmolzenster": "zerschmolzen",
    "zerschmolzenstes": "zerschmolzen",
    "zerschmolzst": "zerschmelzen",
    "zerschmolzt": "zerschmelzen",
    "zerschmölze": "zerschmelzen",
    "zerschmölzen": "zerschmelzen",
    "zerschmölzest": "zerschmelzen",
    "zerschmölzet": "zerschmelzen",
    "zerschneide": "zerschneiden",
    "zerschneidend": "zerschneiden",
    "zerschneidende": "zerschneidend",
    "zerschneidendem": "zerschneidend",
    "zerschneidenden": "zerschneidend",
    "zerschneidender": "zerschneidend",
    "zerschneidendere": "zerschneidend",
    "zerschneidenderem": "zerschneidend",
    "zerschneidenderen": "zerschneidend",
    "zerschneidenderer": "zerschneidend",
    "zerschneidenderes": "zerschneidend",
    "zerschneidendes": "zerschneidend",
    "zerschneidendste": "zerschneidend",
    "zerschneidendstem": "zerschneidend",
    "zerschneidendsten": "zerschneidend",
    "zerschneidendster": "zerschneidend",
    "zerschneidendstes": "zerschneidend",
    "zerschneidest": "zerschneiden",
    "zerschneidet": "zerschneiden",
    "zerschnitt": "zerschneiden",
    "zerschnitte": "zerschneiden",
    "zerschnitten": "zerschneiden",
    "zerschnittene": "zerschnitten",
    "zerschnittenem": "zerschnitten",
    "zerschnittenen": "zerschnitten",
    "zerschnittener": "zerschnitten",
    "zerschnittenere": "zerschnitten",
    "zerschnittenerem": "zerschnitten",
    "zerschnitteneren": "zerschnitten",
    "zerschnittenerer": "zerschnitten",
    "zerschnitteneres": "zerschnitten",
    "zerschnittenes": "zerschnitten",
    "zerschnittenste": "zerschnitten",
    "zerschnittenstem": "zerschnitten",
    "zerschnittensten": "zerschnitten",
    "zerschnittenster": "zerschnitten",
    "zerschnittenstes": "zerschnitten",
    "zerschnittest": "zerschneiden",
    "zerschnittet": "zerschneiden",
    "zerschor": "zerscheren",
    "zerschoren": "zerscheren",
    "zerschorene": "zerschoren",
    "zerschorenem": "zerschoren",
    "zerschorenen": "zerschoren",
    "zerschorener": "zerschoren",
    "zerschorenere": "zerschoren",
    "zerschorenerem": "zerschoren",
    "zerschoreneren": "zerschoren",
    "zerschorenerer": "zerschoren",
    "zerschoreneres": "zerschoren",
    "zerschorenes": "zerschoren",
    "zerschorenste": "zerschoren",
    "zerschorenstem": "zerschoren",
    "zerschorensten": "zerschoren",
    "zerschorenster": "zerschoren",
    "zerschorenstes": "zerschoren",
    "zerschorst": "zerscheren",
    "zerschort": "zerscheren",
    "zerschossen": "zerschießen",
    "zerschossene": "zerschossen",
    "zerschossenem": "zerschossen",
    "zerschossenen": "zerschossen",
    "zerschossener": "zerschossen",
    "zerschossenere": "zerschossen",
    "zerschossenerem": "zerschossen",
    "zerschosseneren": "zerschossen",
    "zerschossenerer": "zerschossen",
    "zerschosseneres": "zerschossen",
    "zerschossenes": "zerschossen",
    "zerschossenste": "zerschossen",
    "zerschossenstem": "zerschossen",
    "zerschossensten": "zerschossen",
    "zerschossenster": "zerschossen",
    "zerschossenstes": "zerschossen",
    "zerschoß": "zerschießen",
    "zerschoßt": "zerschießen",
    "zerschunden": "zerschinden",
    "zerschundene": "zerschunden",
    "zerschundenem": "zerschunden",
    "zerschundenen": "zerschunden",
    "zerschundener": "zerschunden",
    "zerschundenere": "zerschunden",
    "zerschundenerem": "zerschunden",
    "zerschundeneren": "zerschunden",
    "zerschundenerer": "zerschunden",
    "zerschundeneres": "zerschunden",
    "zerschundenes": "zerschunden",
    "zerschundenste": "zerschunden",
    "zerschundenstem": "zerschunden",
    "zerschundensten": "zerschunden",
    "zerschundenster": "zerschunden",
    "zerschundenstes": "zerschunden",
    "zerschöre": "zerscheren",
    "zerschören": "zerscheren",
    "zerschörest": "zerscheren",
    "zerschöret": "zerscheren",
    "zerschösse": "zerschießen",
    "zerschössen": "zerschießen",
    "zerschössest": "zerschießen",
    "zerschösset": "zerschießen",
    "zersetze": "zersetzen",
    "zersetzend": "zersetzen",
    "zersetzende": "zersetzend",
    "zersetzendem": "zersetzend",
    "zersetzenden": "zersetzend",
    "zersetzender": "zersetzend",
    "zersetzendere": "zersetzend",
    "zersetzenderem": "zersetzend",
    "zersetzenderen": "zersetzend",
    "zersetzenderer": "zersetzend",
    "zersetzenderes": "zersetzend",
    "zersetzendes": "zersetzend",
    "zersetzendste": "zersetzend",
    "zersetzendstem": "zersetzend",
    "zersetzendsten": "zersetzend",
    "zersetzendster": "zersetzend",
    "zersetzendstes": "zersetzend",
    "zersetzest": "zersetzen",
    "zersetzet": "zersetzen",
    "zersetzt": "zersetzen",
    "zersetzte": "zersetzen",
    "zersetztem": "zersetzt",
    "zersetzten": "zersetzen",
    "zersetzter": "zersetzt",
    "zersetztere": "zersetzt",
    "zersetzterem": "zersetzt",
    "zersetzteren": "zersetzt",
    "zersetzterer": "zersetzt",
    "zersetzteres": "zersetzt",
    "zersetztes": "zersetzt",
    "zersetztest": "zersetzen",
    "zersetzteste": "zersetzt",
    "zersetztestem": "zersetzt",
    "zersetztesten": "zersetzt",
    "zersetztester": "zersetzt",
    "zersetztestes": "zersetzt",
    "zersetztet": "zersetzen",
    "zersiede": "zersieden",
    "zersiedele": "zersiedeln",
    "zersiedelnd": "zersiedeln",
    "zersiedelnde": "zersiedelnd",
    "zersiedelndem": "zersiedelnd",
    "zersiedelnden": "zersiedelnd",
    "zersiedelnder": "zersiedelnd",
    "zersiedelndere": "zersiedelnd",
    "zersiedelnderem": "zersiedelnd",
    "zersiedelnderen": "zersiedelnd",
    "zersiedelnderer": "zersiedelnd",
    "zersiedelnderes": "zersiedelnd",
    "zersiedelndes": "zersiedelnd",
    "zersiedelndste": "zersiedelnd",
    "zersiedelndstem": "zersiedelnd",
    "zersiedelndsten": "zersiedelnd",
    "zersiedelndster": "zersiedelnd",
    "zersiedelndstes": "zersiedelnd",
    "zersiedelst": "zersiedeln",
    "zersiedelt": "zersiedeln",
    "zersiedelte": "zersiedeln",
    "zersiedeltem": "zersiedelt",
    "zersiedelten": "zersiedeln",
    "zersiedelter": "zersiedelt",
    "zersiedeltere": "zersiedelt",
    "zersiedelterem": "zersiedelt",
    "zersiedelteren": "zersiedelt",
    "zersiedelterer": "zersiedelt",
    "zersiedelteres": "zersiedelt",
    "zersiedeltes": "zersiedelt",
    "zersiedeltest": "zersiedeln",
    "zersiedelteste": "zersiedelt",
    "zersiedeltestem": "zersiedelt",
    "zersiedeltesten": "zersiedelt",
    "zersiedeltester": "zersiedelt",
    "zersiedeltestes": "zersiedelt",
    "zersiedeltet": "zersiedeln",
    "zersiedend": "zersieden",
    "zersiedende": "zersiedend",
    "zersiedendem": "zersiedend",
    "zersiedenden": "zersiedend",
    "zersiedender": "zersiedend",
    "zersiedendes": "zersiedend",
    "zersiedest": "zersieden",
    "zersiedet": "zersieden",
    "zersiedete": "zersieden",
    "zersiedetem": "zersiedet",
    "zersiedeten": "zersieden",
    "zersiedeter": "zersiedet",
    "zersiedetes": "zersiedet",
    "zersiedetest": "zersieden",
    "zersiedetet": "zersieden",
    "zersiedle": "zersiedeln",
    "zersott": "zersieden",
    "zersotten": "zersieden",
    "zersottene": "zersotten",
    "zersottenem": "zersotten",
    "zersottenen": "zersotten",
    "zersottener": "zersotten",
    "zersottenes": "zersotten",
    "zersottest": "zersieden",
    "zersottet": "zersieden",
    "zerspalte": "zerspalten",
    "zerspaltend": "zerspalten",
    "zerspaltende": "zerspaltend",
    "zerspaltendem": "zerspaltend",
    "zerspaltenden": "zerspaltend",
    "zerspaltender": "zerspaltend",
    "zerspaltendere": "zerspaltend",
    "zerspaltenderem": "zerspaltend",
    "zerspaltenderen": "zerspaltend",
    "zerspaltenderer": "zerspaltend",
    "zerspaltenderes": "zerspaltend",
    "zerspaltendes": "zerspaltend",
    "zerspaltendste": "zerspaltend",
    "zerspaltendstem": "zerspaltend",
    "zerspaltendsten": "zerspaltend",
    "zerspaltendster": "zerspaltend",
    "zerspaltendstes": "zerspaltend",
    "zerspaltene": "zerspalten",
    "zerspaltenem": "zerspalten",
    "zerspaltenen": "zerspalten",
    "zerspaltener": "zerspalten",
    "zerspaltenere": "zerspalten",
    "zerspaltenerem": "zerspalten",
    "zerspalteneren": "zerspalten",
    "zerspaltenerer": "zerspalten",
    "zerspalteneres": "zerspalten",
    "zerspaltenes": "zerspalten",
    "zerspaltenstem": "zerspalten",
    "zerspaltensten": "zerspalten",
    "zerspaltenster": "zerspalten",
    "zerspaltenstes": "zerspalten",
    "zerspaltest": "zerspalten",
    "zerspaltet": "zerspalten",
    "zerspaltete": "zerspalten",
    "zerspalteten": "zerspalten",
    "zerspaltetest": "zerspalten",
    "zerspaltetet": "zerspalten",
    "zersplittere": "zersplittern",
    "zersplitternd": "zersplittern",
    "zersplitternde": "zersplitternd",
    "zersplitterndem": "zersplitternd",
    "zersplitternden": "zersplitternd",
    "zersplitternder": "zersplitternd",
    "zersplitterndere": "zersplitternd",
    "zersplitternderem": "zersplitternd",
    "zersplitternderen": "zersplitternd",
    "zersplitternderer": "zersplitternd",
    "zersplitternderes": "zersplitternd",
    "zersplitterndes": "zersplitternd",
    "zersplitterndste": "zersplitternd",
    "zersplitterndstem": "zersplitternd",
    "zersplitterndsten": "zersplitternd",
    "zersplitterndster": "zersplitternd",
    "zersplitterndstes": "zersplitternd",
    "zersplitterst": "zersplittern",
    "zersplittert": "zersplittern",
    "zersplitterte": "zersplittern",
    "zersplittertem": "zersplittert",
    "zersplitterten": "zersplittern",
    "zersplitterter": "zersplittert",
    "zersplittertere": "zersplittert",
    "zersplitterterem": "zersplittert",
    "zersplitterteren": "zersplittert",
    "zersplitterterer": "zersplittert",
    "zersplitterteres": "zersplittert",
    "zersplittertes": "zersplittert",
    "zersplittertest": "zersplittern",
    "zersplitterteste": "zersplittert",
    "zersplittertestem": "zersplittert",
    "zersplittertesten": "zersplittert",
    "zersplittertester": "zersplittert",
    "zersplittertestes": "zersplittert",
    "zersplittertet": "zersplittern",
    "zersprang": "zerspringen",
    "zersprangen": "zerspringen",
    "zersprangst": "zerspringen",
    "zersprangt": "zerspringen",
    "zersprenge": "zersprengen",
    "zersprengend": "zersprengen",
    "zersprengende": "zersprengend",
    "zersprengendem": "zersprengend",
    "zersprengenden": "zersprengend",
    "zersprengender": "zersprengend",
    "zersprengendes": "zersprengend",
    "zersprengest": "zersprengen",
    "zersprenget": "zersprengen",
    "zersprengst": "zersprengen",
    "zersprengt": "zersprengen",
    "zersprengte": "zersprengen",
    "zersprengtem": "zersprengt",
    "zersprengten": "zersprengen",
    "zersprengter": "zersprengt",
    "zersprengtes": "zersprengt",
    "zersprengtest": "zersprengen",
    "zersprengtet": "zersprengen",
    "zerspringe": "zerspringen",
    "zerspringend": "zerspringen",
    "zerspringende": "zerspringend",
    "zerspringendem": "zerspringend",
    "zerspringenden": "zerspringend",
    "zerspringender": "zerspringend",
    "zerspringendes": "zerspringend",
    "zerspringest": "zerspringen",
    "zerspringet": "zerspringen",
    "zerspringst": "zerspringen",
    "zerspringt": "zerspringen",
    "zersprungen": "zerspringen",
    "zersprungene": "zersprungen",
    "zersprungenem": "zersprungen",
    "zersprungenen": "zersprungen",
    "zersprungener": "zersprungen",
    "zersprungenere": "zersprungen",
    "zersprungenerem": "zersprungen",
    "zersprungeneren": "zersprungen",
    "zersprungenerer": "zersprungen",
    "zersprungeneres": "zersprungen",
    "zersprungenes": "zersprungen",
    "zersprungenste": "zersprungen",
    "zersprungenstem": "zersprungen",
    "zersprungensten": "zersprungen",
    "zersprungenster": "zersprungen",
    "zersprungenstes": "zersprungen",
    "zerspränge": "zerspringen",
    "zersprängen": "zerspringen",
    "zersprängest": "zerspringen",
    "zerspränget": "zerspringen",
    "zerstach": "zerstechen",
    "zerstachen": "zerstechen",
    "zerstachst": "zerstechen",
    "zerstacht": "zerstechen",
    "zerstampfe": "zerstampfen",
    "zerstampfend": "zerstampfen",
    "zerstampfende": "zerstampfend",
    "zerstampfendem": "zerstampfend",
    "zerstampfenden": "zerstampfend",
    "zerstampfender": "zerstampfend",
    "zerstampfendere": "zerstampfend",
    "zerstampfenderem": "zerstampfend",
    "zerstampfenderen": "zerstampfend",
    "zerstampfenderer": "zerstampfend",
    "zerstampfenderes": "zerstampfend",
    "zerstampfendes": "zerstampfend",
    "zerstampfendste": "zerstampfend",
    "zerstampfendstem": "zerstampfend",
    "zerstampfendsten": "zerstampfend",
    "zerstampfendster": "zerstampfend",
    "zerstampfendstes": "zerstampfend",
    "zerstampfest": "zerstampfen",
    "zerstampfet": "zerstampfen",
    "zerstampfst": "zerstampfen",
    "zerstampft": "zerstampfen",
    "zerstampfte": "zerstampfen",
    "zerstampftem": "zerstampft",
    "zerstampften": "zerstampfen",
    "zerstampfter": "zerstampft",
    "zerstampftere": "zerstampft",
    "zerstampfterem": "zerstampft",
    "zerstampfteren": "zerstampft",
    "zerstampfterer": "zerstampft",
    "zerstampfteres": "zerstampft",
    "zerstampftes": "zerstampft",
    "zerstampftest": "zerstampfen",
    "zerstampfteste": "zerstampft",
    "zerstampftestem": "zerstampft",
    "zerstampftesten": "zerstampft",
    "zerstampftester": "zerstampft",
    "zerstampftestes": "zerstampft",
    "zerstampftet": "zerstampfen",
    "zersteche": "zerstechen",
    "zerstechend": "zerstechen",
    "zerstechende": "zerstechend",
    "zerstechendem": "zerstechend",
    "zerstechenden": "zerstechend",
    "zerstechender": "zerstechend",
    "zerstechendes": "zerstechend",
    "zerstechest": "zerstechen",
    "zerstechet": "zerstechen",
    "zerstecht": "zerstechen",
    "zerstich": "zerstechen",
    "zerstichst": "zerstechen",
    "zersticht": "zerstechen",
    "zerstochen": "zerstechen",
    "zerstochene": "zerstochen",
    "zerstochenem": "zerstochen",
    "zerstochenen": "zerstochen",
    "zerstochener": "zerstochen",
    "zerstochenere": "zerstochen",
    "zerstochenerem": "zerstochen",
    "zerstocheneren": "zerstochen",
    "zerstochenerer": "zerstochen",
    "zerstocheneres": "zerstochen",
    "zerstochenes": "zerstochen",
    "zerstochenste": "zerstochen",
    "zerstochenstem": "zerstochen",
    "zerstochensten": "zerstochen",
    "zerstochenster": "zerstochen",
    "zerstochenstes": "zerstochen",
    "zerstreite": "zerstreiten",
    "zerstreitend": "zerstreiten",
    "zerstreitende": "zerstreitend",
    "zerstreitendem": "zerstreitend",
    "zerstreitenden": "zerstreitend",
    "zerstreitender": "zerstreitend",
    "zerstreitendes": "zerstreitend",
    "zerstreitest": "zerstreiten",
    "zerstreitet": "zerstreiten",
    "zerstreue": "zerstreuen",
    "zerstreuend": "zerstreuen",
    "zerstreuende": "zerstreuend",
    "zerstreuendem": "zerstreuend",
    "zerstreuenden": "zerstreuend",
    "zerstreuender": "zerstreuend",
    "zerstreuendes": "zerstreuend",
    "zerstreuest": "zerstreuen",
    "zerstreuet": "zerstreuen",
    "zerstreust": "zerstreuen",
    "zerstreut": "zerstreuen",
    "zerstreute": "zerstreuen",
    "zerstreutem": "zerstreut",
    "zerstreuten": "zerstreuen",
    "zerstreuter": "zerstreut",
    "zerstreutes": "zerstreut",
    "zerstreutest": "zerstreuen",
    "zerstreutet": "zerstreuen",
    "zerstritt": "zerstreiten",
    "zerstritte": "zerstreiten",
    "zerstritten": "zerstreiten",
    "zerstrittene": "zerstritten",
    "zerstrittenem": "zerstritten",
    "zerstrittenen": "zerstritten",
    "zerstrittener": "zerstritten",
    "zerstrittenere": "zerstritten",
    "zerstrittenerem": "zerstritten",
    "zerstritteneren": "zerstritten",
    "zerstrittenerer": "zerstritten",
    "zerstritteneres": "zerstritten",
    "zerstrittenes": "zerstritten",
    "zerstrittenste": "zerstritten",
    "zerstrittenstem": "zerstritten",
    "zerstrittensten": "zerstritten",
    "zerstrittenster": "zerstritten",
    "zerstrittenstes": "zerstritten",
    "zerstrittest": "zerstreiten",
    "zerstrittet": "zerstreiten",
    "zerstäche": "zerstechen",
    "zerstächen": "zerstechen",
    "zerstächest": "zerstechen",
    "zerstächet": "zerstechen",
    "zerstäube": "zerstäuben",
    "zerstäubend": "zerstäuben",
    "zerstäubende": "zerstäubend",
    "zerstäubendem": "zerstäubend",
    "zerstäubenden": "zerstäubend",
    "zerstäubender": "zerstäubend",
    "zerstäubendes": "zerstäubend",
    "zerstäubest": "zerstäuben",
    "zerstäubet": "zerstäuben",
    "zerstäubst": "zerstäuben",
    "zerstäubt": "zerstäuben",
    "zerstäubte": "zerstäuben",
    "zerstäubtem": "zerstäubt",
    "zerstäubten": "zerstäuben",
    "zerstäubter": "zerstäubt",
    "zerstäubtes": "zerstäubt",
    "zerstäubtest": "zerstäuben",
    "zerstäubtet": "zerstäuben",
    "zerstöre": "zerstören",
    "zerstörend": "zerstören",
    "zerstörende": "zerstörend",
    "zerstörendem": "zerstörend",
    "zerstörenden": "zerstörend",
    "zerstörender": "zerstörend",
    "zerstörendes": "zerstörend",
    "zerstörest": "zerstören",
    "zerstöret": "zerstören",
    "zerstörst": "zerstören",
    "zerstört": "zerstören",
    "zerstörte": "zerstören",
    "zerstörtem": "zerstört",
    "zerstörten": "zerstören",
    "zerstörter": "zerstört",
    "zerstörtere": "zerstört",
    "zerstörterem": "zerstört",
    "zerstörteren": "zerstört",
    "zerstörterer": "zerstört",
    "zerstörteres": "zerstört",
    "zerstörtes": "zerstört",
    "zerstörtest": "zerstören",
    "zerstörteste": "zerstört",
    "zerstörtestem": "zerstört",
    "zerstörtesten": "zerstört",
    "zerstörtester": "zerstört",
    "zerstörtestes": "zerstört",
    "zerstörtet": "zerstören",
    "zerstückele": "zerstückeln",
    "zerstückelnd": "zerstückeln",
    "zerstückelnde": "zerstückelnd",
    "zerstückelndem": "zerstückelnd",
    "zerstückelnden": "zerstückelnd",
    "zerstückelnder": "zerstückelnd",
    "zerstückelndere": "zerstückelnd",
    "zerstückelnderem": "zerstückelnd",
    "zerstückelnderen": "zerstückelnd",
    "zerstückelnderer": "zerstückelnd",
    "zerstückelnderes": "zerstückelnd",
    "zerstückelndes": "zerstückelnd",
    "zerstückelndste": "zerstückelnd",
    "zerstückelndstem": "zerstückelnd",
    "zerstückelndsten": "zerstückelnd",
    "zerstückelndster": "zerstückelnd",
    "zerstückelndstes": "zerstückelnd",
    "zerstückelst": "zerstückeln",
    "zerstückelt": "zerstückeln",
    "zerstückelte": "zerstückeln",
    "zerstückeltem": "zerstückelt",
    "zerstückelten": "zerstückeln",
    "zerstückelter": "zerstückelt",
    "zerstückeltere": "zerstückelt",
    "zerstückelterem": "zerstückelt",
    "zerstückelteren": "zerstückelt",
    "zerstückelterer": "zerstückelt",
    "zerstückelteres": "zerstückelt",
    "zerstückeltes": "zerstückelt",
    "zerstückeltest": "zerstückeln",
    "zerstückelteste": "zerstückelt",
    "zerstückeltestem": "zerstückelt",
    "zerstückeltesten": "zerstückelt",
    "zerstückeltester": "zerstückelt",
    "zerstückeltestes": "zerstückelt",
    "zerstückeltet": "zerstückeln",
    "zerstückle": "zerstückeln",
    "zerstümmele": "zerstümmeln",
    "zerstümmelnd": "zerstümmeln",
    "zerstümmelnde": "zerstümmelnd",
    "zerstümmelndem": "zerstümmelnd",
    "zerstümmelnden": "zerstümmelnd",
    "zerstümmelnder": "zerstümmelnd",
    "zerstümmelndere": "zerstümmelnd",
    "zerstümmelnderem": "zerstümmelnd",
    "zerstümmelnderen": "zerstümmelnd",
    "zerstümmelnderer": "zerstümmelnd",
    "zerstümmelnderes": "zerstümmelnd",
    "zerstümmelndes": "zerstümmelnd",
    "zerstümmelndste": "zerstümmelnd",
    "zerstümmelndstem": "zerstümmelnd",
    "zerstümmelndsten": "zerstümmelnd",
    "zerstümmelndster": "zerstümmelnd",
    "zerstümmelndstes": "zerstümmelnd",
    "zerstümmelst": "zerstümmeln",
    "zerstümmelt": "zerstümmeln",
    "zerstümmelte": "zerstümmeln",
    "zerstümmeltem": "zerstümmelt",
    "zerstümmelten": "zerstümmeln",
    "zerstümmelter": "zerstümmelt",
    "zerstümmeltere": "zerstümmelt",
    "zerstümmelterem": "zerstümmelt",
    "zerstümmelteren": "zerstümmelt",
    "zerstümmelterer": "zerstümmelt",
    "zerstümmelteres": "zerstümmelt",
    "zerstümmeltes": "zerstümmelt",
    "zerstümmeltest": "zerstümmeln",
    "zerstümmelteste": "zerstümmelt",
    "zerstümmeltestem": "zerstümmelt",
    "zerstümmeltesten": "zerstümmelt",
    "zerstümmeltester": "zerstümmelt",
    "zerstümmeltestes": "zerstümmelt",
    "zerstümmeltet": "zerstümmeln",
    "zerstümmle": "zerstümmeln",
    "zersäge": "zersägen",
    "zersägend": "zersägen",
    "zersägende": "zersägend",
    "zersägendem": "zersägend",
    "zersägenden": "zersägend",
    "zersägender": "zersägend",
    "zersägendes": "zersägend",
    "zersägest": "zersägen",
    "zersäget": "zersägen",
    "zersägst": "zersägen",
    "zersägt": "zersägen",
    "zersägte": "zersägen",
    "zersägtem": "zersägt",
    "zersägten": "zersägen",
    "zersägter": "zersägt",
    "zersägtes": "zersägt",
    "zersägtest": "zersägen",
    "zersägtet": "zersägen",
    "zersötte": "zersieden",
    "zersötten": "zersieden",
    "zersöttest": "zersieden",
    "zersöttet": "zersieden",
    "zerteile": "zerteilen",
    "zerteilend": "zerteilen",
    "zerteilende": "zerteilend",
    "zerteilendem": "zerteilend",
    "zerteilenden": "zerteilend",
    "zerteilender": "zerteilend",
    "zerteilendes": "zerteilend",
    "zerteilest": "zerteilen",
    "zerteilet": "zerteilen",
    "zerteilst": "zerteilen",
    "zerteilt": "zerteilen",
    "zerteilte": "zerteilen",
    "zerteiltem": "zerteilt",
    "zerteilten": "zerteilen",
    "zerteilter": "zerteilt",
    "zerteiltere": "zerteilt",
    "zerteilterem": "zerteilt",
    "zerteilteren": "zerteilt",
    "zerteilterer": "zerteilt",
    "zerteilteres": "zerteilt",
    "zerteiltes": "zerteilt",
    "zerteiltest": "zerteilen",
    "zerteilteste": "zerteilt",
    "zerteiltestem": "zerteilt",
    "zerteiltesten": "zerteilt",
    "zerteiltester": "zerteilt",
    "zerteiltestes": "zerteilt",
    "zerteiltet": "zerteilen",
    "zertrampele": "zertrampeln",
    "zertrampelnd": "zertrampeln",
    "zertrampelnde": "zertrampelnd",
    "zertrampelndem": "zertrampelnd",
    "zertrampelnden": "zertrampelnd",
    "zertrampelnder": "zertrampelnd",
    "zertrampelndere": "zertrampelnd",
    "zertrampelnderem": "zertrampelnd",
    "zertrampelnderen": "zertrampelnd",
    "zertrampelnderer": "zertrampelnd",
    "zertrampelnderes": "zertrampelnd",
    "zertrampelndes": "zertrampelnd",
    "zertrampelndste": "zertrampelnd",
    "zertrampelndstem": "zertrampelnd",
    "zertrampelndsten": "zertrampelnd",
    "zertrampelndster": "zertrampelnd",
    "zertrampelndstes": "zertrampelnd",
    "zertrampelst": "zertrampeln",
    "zertrampelt": "zertrampeln",
    "zertrampelte": "zertrampeln",
    "zertrampeltem": "zertrampelt",
    "zertrampelten": "zertrampeln",
    "zertrampelter": "zertrampelt",
    "zertrampeltere": "zertrampelt",
    "zertrampelterem": "zertrampelt",
    "zertrampelteren": "zertrampelt",
    "zertrampelterer": "zertrampelt",
    "zertrampelteres": "zertrampelt",
    "zertrampeltes": "zertrampelt",
    "zertrampeltest": "zertrampeln",
    "zertrampelteste": "zertrampelt",
    "zertrampeltestem": "zertrampelt",
    "zertrampeltesten": "zertrampelt",
    "zertrampeltester": "zertrampelt",
    "zertrampeltestes": "zertrampelt",
    "zertrampeltet": "zertrampeln",
    "zertrample": "zertrampeln",
    "zertrat": "zertreten",
    "zertraten": "zertreten",
    "zertratest": "zertreten",
    "zertratet": "zertreten",
    "zertrenne": "zertrennen",
    "zertrennend": "zertrennen",
    "zertrennende": "zertrennend",
    "zertrennendem": "zertrennend",
    "zertrennenden": "zertrennend",
    "zertrennender": "zertrennend",
    "zertrennendes": "zertrennend",
    "zertrennest": "zertrennen",
    "zertrennet": "zertrennen",
    "zertrennst": "zertrennen",
    "zertrennt": "zertrennen",
    "zertrennte": "zertrennen",
    "zertrenntem": "zertrennt",
    "zertrennten": "zertrennen",
    "zertrennter": "zertrennt",
    "zertrenntes": "zertrennt",
    "zertrenntest": "zertrennen",
    "zertrenntet": "zertrennen",
    "zertrete": "zertreten",
    "zertretend": "zertreten",
    "zertretende": "zertretend",
    "zertretendem": "zertretend",
    "zertretenden": "zertretend",
    "zertretender": "zertretend",
    "zertretendes": "zertretend",
    "zertretene": "zertreten",
    "zertretenem": "zertreten",
    "zertretenen": "zertreten",
    "zertretener": "zertreten",
    "zertretenere": "zertreten",
    "zertretenerem": "zertreten",
    "zertreteneren": "zertreten",
    "zertretenerer": "zertreten",
    "zertreteneres": "zertreten",
    "zertretenes": "zertreten",
    "zertretenstem": "zertreten",
    "zertretensten": "zertreten",
    "zertretenster": "zertreten",
    "zertretenstes": "zertreten",
    "zertretest": "zertreten",
    "zertretet": "zertreten",
    "zertritt": "zertreten",
    "zertrittst": "zertreten",
    "zerträte": "zertreten",
    "zerträten": "zertreten",
    "zerträtest": "zertreten",
    "zerträtet": "zertreten",
    "zertrümmere": "zertrümmern",
    "zertrümmernd": "zertrümmern",
    "zertrümmernde": "zertrümmernd",
    "zertrümmerndem": "zertrümmernd",
    "zertrümmernden": "zertrümmernd",
    "zertrümmernder": "zertrümmernd",
    "zertrümmerndere": "zertrümmernd",
    "zertrümmernderem": "zertrümmernd",
    "zertrümmernderen": "zertrümmernd",
    "zertrümmernderer": "zertrümmernd",
    "zertrümmernderes": "zertrümmernd",
    "zertrümmerndes": "zertrümmernd",
    "zertrümmerndste": "zertrümmernd",
    "zertrümmerndstem": "zertrümmernd",
    "zertrümmerndsten": "zertrümmernd",
    "zertrümmerndster": "zertrümmernd",
    "zertrümmerndstes": "zertrümmernd",
    "zertrümmerst": "zertrümmern",
    "zertrümmert": "zertrümmern",
    "zertrümmerte": "zertrümmern",
    "zertrümmertem": "zertrümmert",
    "zertrümmerten": "zertrümmern",
    "zertrümmerter": "zertrümmert",
    "zertrümmertere": "zertrümmert",
    "zertrümmerterem": "zertrümmert",
    "zertrümmerteren": "zertrümmert",
    "zertrümmerterer": "zertrümmert",
    "zertrümmerteres": "zertrümmert",
    "zertrümmertes": "zertrümmert",
    "zertrümmertest": "zertrümmern",
    "zertrümmerteste": "zertrümmert",
    "zertrümmertestem": "zertrümmert",
    "zertrümmertesten": "zertrümmert",
    "zertrümmertester": "zertrümmert",
    "zertrümmertestes": "zertrümmert",
    "zertrümmertet": "zertrümmern",
    "zerwühle": "zerwühlen",
    "zerwühlend": "zerwühlen",
    "zerwühlende": "zerwühlend",
    "zerwühlendem": "zerwühlend",
    "zerwühlenden": "zerwühlend",
    "zerwühlender": "zerwühlend",
    "zerwühlendere": "zerwühlend",
    "zerwühlenderem": "zerwühlend",
    "zerwühlenderen": "zerwühlend",
    "zerwühlenderer": "zerwühlend",
    "zerwühlenderes": "zerwühlend",
    "zerwühlendes": "zerwühlend",
    "zerwühlendste": "zerwühlend",
    "zerwühlendstem": "zerwühlend",
    "zerwühlendsten": "zerwühlend",
    "zerwühlendster": "zerwühlend",
    "zerwühlendstes": "zerwühlend",
    "zerwühlest": "zerwühlen",
    "zerwühlet": "zerwühlen",
    "zerwühlst": "zerwühlen",
    "zerwühlt": "zerwühlen",
    "zerwühlte": "zerwühlen",
    "zerwühltem": "zerwühlt",
    "zerwühlten": "zerwühlen",
    "zerwühlter": "zerwühlt",
    "zerwühltere": "zerwühlt",
    "zerwühlterem": "zerwühlt",
    "zerwühlteren": "zerwühlt",
    "zerwühlterer": "zerwühlt",
    "zerwühlteres": "zerwühlt",
    "zerwühltes": "zerwühlt",
    "zerwühltest": "zerwühlen",
    "zerwühlteste": "zerwühlt",
    "zerwühltestem": "zerwühlt",
    "zerwühltesten": "zerwühlt",
    "zerwühltester": "zerwühlt",
    "zerwühltestes": "zerwühlt",
    "zerwühltet": "zerwühlen",
    "zerzause": "zerzausen",
    "zerzausend": "zerzausen",
    "zerzausende": "zerzausend",
    "zerzausendem": "zerzausend",
    "zerzausenden": "zerzausend",
    "zerzausender": "zerzausend",
    "zerzausendere": "zerzausend",
    "zerzausenderem": "zerzausend",
    "zerzausenderen": "zerzausend",
    "zerzausenderer": "zerzausend",
    "zerzausenderes": "zerzausend",
    "zerzausendes": "zerzausend",
    "zerzausendste": "zerzausend",
    "zerzausendstem": "zerzausend",
    "zerzausendsten": "zerzausend",
    "zerzausendster": "zerzausend",
    "zerzausendstes": "zerzausend",
    "zerzausest": "zerzausen",
    "zerzauset": "zerzausen",
    "zerzaust": "zerzausen",
    "zerzauste": "zerzausen",
    "zerzaustem": "zerzaust",
    "zerzausten": "zerzausen",
    "zerzauster": "zerzaust",
    "zerzaustere": "zerzaust",
    "zerzausterem": "zerzaust",
    "zerzausteren": "zerzaust",
    "zerzausterer": "zerzaust",
    "zerzausteres": "zerzaust",
    "zerzaustes": "zerzaust",
    "zerzaustest": "zerzausen",
    "zerzausteste": "zerzaust",
    "zerzaustestem": "zerzaust",
    "zerzaustesten": "zerzaust",
    "zerzaustester": "zerzaust",
    "zerzaustestes": "zerzaust",
    "zerzaustet": "zerzausen",
    "zerzupfe": "zerzupfen",
    "zerzupfend": "zerzupfen",
    "zerzupfende": "zerzupfend",
    "zerzupfendem": "zerzupfend",
    "zerzupfenden": "zerzupfend",
    "zerzupfender": "zerzupfend",
    "zerzupfendes": "zerzupfend",
    "zerzupfest": "zerzupfen",
    "zerzupfet": "zerzupfen",
    "zerzupfst": "zerzupfen",
    "zerzupft": "zerzupfen",
    "zerzupfte": "zerzupfen",
    "zerzupftem": "zerzupft",
    "zerzupften": "zerzupfen",
    "zerzupfter": "zerzupft",
    "zerzupftere": "zerzupft",
    "zerzupfterem": "zerzupft",
    "zerzupfteren": "zerzupft",
    "zerzupfterer": "zerzupft",
    "zerzupfteres": "zerzupft",
    "zerzupftes": "zerzupft",
    "zerzupftest": "zerzupfen",
    "zerzupfteste": "zerzupft",
    "zerzupftestem": "zerzupft",
    "zerzupftesten": "zerzupft",
    "zerzupftester": "zerzupft",
    "zerzupftestes": "zerzupft",
    "zerzupftet": "zerzupfen",
    "zettele": "zetteln",
    "zettelnd": "zetteln",
    "zettelnde": "zettelnd",
    "zettelndem": "zettelnd",
    "zettelnden": "zettelnd",
    "zettelnder": "zettelnd",
    "zettelndes": "zettelnd",
    "zettelst": "zetteln",
    "zettelt": "zetteln",
    "zettelte": "zetteln",
    "zettelten": "zetteln",
    "zetteltest": "zetteln",
    "zetteltet": "zetteln",
    "zettle": "zetteln",
    "zeugend": "zeugen",
    "zeugende": "zeugend",
    "zeugendem": "zeugend",
    "zeugenden": "zeugend",
    "zeugender": "zeugend",
    "zeugendes": "zeugend",
    "zeugest": "zeugen",
    "zeuget": "zeugen",
    "zeugst": "zeugen",
    "zeugt": "zeugen",
    "zeugte": "zeugen",
    "zeugten": "zeugen",
    "zeugtest": "zeugen",
    "zeugtet": "zeugen",
    "zeugungsfähigem": "zeugungsfähig",
    "zeugungsfähigen": "zeugungsfähig",
    "zeugungsfähiger": "zeugungsfähig",
    "zeugungsfähigere": "zeugungsfähig",
    "zeugungsfähigerem": "zeugungsfähig",
    "zeugungsfähigeren": "zeugungsfähig",
    "zeugungsfähigerer": "zeugungsfähig",
    "zeugungsfähigeres": "zeugungsfähig",
    "zeugungsfähiges": "zeugungsfähig",
    "zeugungsfähigste": "zeugungsfähig",
    "zeugungsfähigstem": "zeugungsfähig",
    "zeugungsfähigsten": "zeugungsfähig",
    "zeugungsfähigster": "zeugungsfähig",
    "zeugungsfähigstes": "zeugungsfähig",
    "zeugungsunfähige": "zeugungsunfähig",
    "zeugungsunfähigem": "zeugungsunfähig",
    "zeugungsunfähigen": "zeugungsunfähig",
    "zeugungsunfähiger": "zeugungsunfähig",
    "zeugungsunfähigere": "zeugungsunfähig",
    "zeugungsunfähigerem": "zeugungsunfähig",
    "zeugungsunfähigeren": "zeugungsunfähig",
    "zeugungsunfähigerer": "zeugungsunfähig",
    "zeugungsunfähigeres": "zeugungsunfähig",
    "zeugungsunfähiges": "zeugungsunfähig",
    "zeugungsunfähigste": "zeugungsunfähig",
    "zeugungsunfähigstem": "zeugungsunfähig",
    "zeugungsunfähigsten": "zeugungsunfähig",
    "zeugungsunfähigster": "zeugungsunfähig",
    "zeugungsunfähigstes": "zeugungsunfähig",
    "ziehe": "ziehen",
    "ziehend": "ziehen",
    "ziehende": "ziehend",
    "ziehendem": "ziehend",
    "ziehenden": "ziehend",
    "ziehender": "ziehend",
    "ziehendes": "ziehend",
    "ziehest": "ziehen",
    "ziehet": "ziehen",
    "ziehst": "ziehen",
    "zieht": "ziehen",
    "zielend": "zielen",
    "zielende": "zielend",
    "zielendem": "zielend",
    "zielenden": "zielend",
    "zielender": "zielend",
    "zielendes": "zielend",
    "zielest": "zielen",
    "zielet": "zielen",
    "ziellose": "ziellos",
    "ziellosem": "ziellos",
    "ziellosen": "ziellos",
    "zielloser": "ziellos",
    "zielloses": "ziellos",
    "zielsicherem": "zielsicher",
    "zielsicheren": "zielsicher",
    "zielsicherer": "zielsicher",
    "zielsicherere": "zielsicher",
    "zielsichererem": "zielsicher",
    "zielsichereren": "zielsicher",
    "zielsichererer": "zielsicher",
    "zielsichereres": "zielsicher",
    "zielsicheres": "zielsicher",
    "zielsicherste": "zielsicher",
    "zielsicherstem": "zielsicher",
    "zielsichersten": "zielsicher",
    "zielsicherster": "zielsicher",
    "zielsicherstes": "zielsicher",
    "zielst": "zielen",
    "zielstrebige": "zielstrebig",
    "zielstrebigem": "zielstrebig",
    "zielstrebigen": "zielstrebig",
    "zielstrebiger": "zielstrebig",
    "zielstrebigere": "zielstrebig",
    "zielstrebigerem": "zielstrebig",
    "zielstrebigeren": "zielstrebig",
    "zielstrebigerer": "zielstrebig",
    "zielstrebigeres": "zielstrebig",
    "zielstrebiges": "zielstrebig",
    "zielstrebigste": "zielstrebig",
    "zielstrebigstem": "zielstrebig",
    "zielstrebigsten": "zielstrebig",
    "zielstrebigster": "zielstrebig",
    "zielstrebigstes": "zielstrebig",
    "zielt": "zielen",
    "zielte": "zielen",
    "zielten": "zielen",
    "zieltest": "zielen",
    "zieltet": "zielen",
    "zieme": "ziemen",
    "ziemend": "ziemen",
    "ziemende": "ziemend",
    "ziemendem": "ziemend",
    "ziemenden": "ziemend",
    "ziemender": "ziemend",
    "ziemendes": "ziemend",
    "ziemest": "ziemen",
    "ziemet": "ziemen",
    "ziemliche": "ziemlich",
    "ziemlichem": "ziemlich",
    "ziemlichen": "ziemlich",
    "ziemlicher": "ziemlich",
    "ziemliches": "ziemlich",
    "ziemst": "ziemen",
    "ziemt": "ziemen",
    "ziemte": "ziemen",
    "ziemten": "ziemen",
    "ziemtest": "ziemen",
    "ziemtet": "ziemen",
    "ziere": "zieren",
    "zierend": "zieren",
    "zierende": "zierend",
    "zierendem": "zierend",
    "zierenden": "zierend",
    "zierender": "zierend",
    "zierendere": "zierend",
    "zierenderem": "zierend",
    "zierenderen": "zierend",
    "zierenderer": "zierend",
    "zierenderes": "zierend",
    "zierendes": "zierend",
    "zierendste": "zierend",
    "zierendstem": "zierend",
    "zierendsten": "zierend",
    "zierendster": "zierend",
    "zierendstes": "zierend",
    "zierest": "zieren",
    "zieret": "zieren",
    "zierlichem": "zierlich",
    "zierlichen": "zierlich",
    "zierlicher": "zierlich",
    "zierlichere": "zierlich",
    "zierlicherem": "zierlich",
    "zierlicheren": "zierlich",
    "zierlicherer": "zierlich",
    "zierlicheres": "zierlich",
    "zierliches": "zierlich",
    "zierlichste": "zierlich",
    "zierlichstem": "zierlich",
    "zierlichsten": "zierlich",
    "zierlichster": "zierlich",
    "zierlichstes": "zierlich",
    "zierst": "zieren",
    "ziert": "zieren",
    "zierte": "zieren",
    "zierten": "zieren",
    "ziertest": "zieren",
    "ziertet": "zieren",
    "zigeunere": "zigeunern",
    "zigeunerische": "zigeunerisch",
    "zigeunerischem": "zigeunerisch",
    "zigeunerischen": "zigeunerisch",
    "zigeunerischer": "zigeunerisch",
    "zigeunerisches": "zigeunerisch",
    "zigeunernd": "zigeunern",
    "zigeunernde": "zigeunernd",
    "zigeunerndem": "zigeunernd",
    "zigeunernden": "zigeunernd",
    "zigeunernder": "zigeunernd",
    "zigeunerndes": "zigeunernd",
    "zigeunerst": "zigeunern",
    "zigeunert": "zigeunern",
    "zigeunerte": "zigeunern",
    "zigeunertem": "zigeunert",
    "zigeunerten": "zigeunern",
    "zigeunerter": "zigeunert",
    "zigeunertes": "zigeunert",
    "zigeunertest": "zigeunern",
    "zigeunertet": "zigeunern",
    "zigfache": "zigfach",
    "zigfachem": "zigfach",
    "zigfachen": "zigfach",
    "zigfacher": "zigfach",
    "zigfaches": "zigfach",
    "zimmere": "zimmern",
    "zimmernd": "zimmern",
    "zimmernde": "zimmernd",
    "zimmerndem": "zimmernd",
    "zimmernden": "zimmernd",
    "zimmernder": "zimmernd",
    "zimmerndes": "zimmernd",
    "zimmerst": "zimmern",
    "zimmert": "zimmern",
    "zimmerte": "zimmern",
    "zimmerten": "zimmern",
    "zimmertest": "zimmern",
    "zimmertet": "zimmern",
    "zimperliche": "zimperlich",
    "zimperlichem": "zimperlich",
    "zimperlichen": "zimperlich",
    "zimperlicher": "zimperlich",
    "zimperlichere": "zimperlich",
    "zimperlicherem": "zimperlich",
    "zimperlicheren": "zimperlich",
    "zimperlicherer": "zimperlich",
    "zimperlicheres": "zimperlich",
    "zimperliches": "zimperlich",
    "zimperlichste": "zimperlich",
    "zimperlichstem": "zimperlich",
    "zimperlichsten": "zimperlich",
    "zimperlichster": "zimperlich",
    "zimperlichstes": "zimperlich",
    "zinkend": "zinken",
    "zinkende": "zinkend",
    "zinkendem": "zinkend",
    "zinkenden": "zinkend",
    "zinkender": "zinkend",
    "zinkendere": "zinkend",
    "zinkenderem": "zinkend",
    "zinkenderen": "zinkend",
    "zinkenderer": "zinkend",
    "zinkenderes": "zinkend",
    "zinkendes": "zinkend",
    "zinkendste": "zinkend",
    "zinkendstem": "zinkend",
    "zinkendsten": "zinkend",
    "zinkendster": "zinkend",
    "zinkendstes": "zinkend",
    "zinkest": "zinken",
    "zinket": "zinken",
    "zinkst": "zinken",
    "zinkt": "zinken",
    "zinkte": "zinken",
    "zinkten": "zinken",
    "zinktest": "zinken",
    "zinktet": "zinken",
    "zinslosem": "zinslos",
    "zinslosen": "zinslos",
    "zinsloser": "zinslos",
    "zinsloses": "zinslos",
    "zinspflichtige": "zinspflichtig",
    "zinspflichtigem": "zinspflichtig",
    "zinspflichtigen": "zinspflichtig",
    "zinspflichtiger": "zinspflichtig",
    "zinspflichtiges": "zinspflichtig",
    "zionistischem": "zionistisch",
    "zionistischen": "zionistisch",
    "zionistischer": "zionistisch",
    "zionistisches": "zionistisch",
    "zirkele": "zirkeln",
    "zirkelnd": "zirkeln",
    "zirkelnde": "zirkelnd",
    "zirkelndem": "zirkelnd",
    "zirkelnden": "zirkelnd",
    "zirkelnder": "zirkelnd",
    "zirkelndere": "zirkelnd",
    "zirkelnderem": "zirkelnd",
    "zirkelnderen": "zirkelnd",
    "zirkelnderer": "zirkelnd",
    "zirkelnderes": "zirkelnd",
    "zirkelndes": "zirkelnd",
    "zirkelndste": "zirkelnd",
    "zirkelndstem": "zirkelnd",
    "zirkelndsten": "zirkelnd",
    "zirkelndster": "zirkelnd",
    "zirkelndstes": "zirkelnd",
    "zirkelst": "zirkeln",
    "zirkelt": "zirkeln",
    "zirkelte": "zirkeln",
    "zirkelten": "zirkeln",
    "zirkeltest": "zirkeln",
    "zirkeltet": "zirkeln",
    "zirkle": "zirkeln",
    "zirkulare": "zirkular",
    "zirkularem": "zirkular",
    "zirkularen": "zirkular",
    "zirkularer": "zirkular",
    "zirkulares": "zirkular",
    "zirkuliere": "zirkulieren",
    "zirkulierend": "zirkulieren",
    "zirkulierende": "zirkulierend",
    "zirkulierendem": "zirkulierend",
    "zirkulierenden": "zirkulierend",
    "zirkulierender": "zirkulierend",
    "zirkulierendes": "zirkulierend",
    "zirkulierest": "zirkulieren",
    "zirkulieret": "zirkulieren",
    "zirkulierst": "zirkulieren",
    "zirkuliert": "zirkulieren",
    "zirkulierte": "zirkulieren",
    "zirkuliertem": "zirkuliert",
    "zirkulierten": "zirkulieren",
    "zirkulierter": "zirkuliert",
    "zirkuliertes": "zirkuliert",
    "zirkuliertest": "zirkulieren",
    "zirkuliertet": "zirkulieren",
    "zische": "zischen",
    "zischend": "zischen",
    "zischende": "zischend",
    "zischendem": "zischend",
    "zischenden": "zischend",
    "zischender": "zischend",
    "zischendere": "zischend",
    "zischenderem": "zischend",
    "zischenderen": "zischend",
    "zischenderer": "zischend",
    "zischenderes": "zischend",
    "zischendes": "zischend",
    "zischendste": "zischend",
    "zischendstem": "zischend",
    "zischendsten": "zischend",
    "zischendster": "zischend",
    "zischendstes": "zischend",
    "zischest": "zischen",
    "zischet": "zischen",
    "zischst": "zischen",
    "zischt": "zischen",
    "zischte": "zischen",
    "zischten": "zischen",
    "zischtest": "zischen",
    "zischtet": "zischen",
    "zitiere": "zitieren",
    "zitierend": "zitieren",
    "zitierende": "zitierend",
    "zitierendem": "zitierend",
    "zitierenden": "zitierend",
    "zitierender": "zitierend",
    "zitierendes": "zitierend",
    "zitierest": "zitieren",
    "zitieret": "zitieren",
    "zitierst": "zitieren",
    "zitiert": "zitieren",
    "zitierte": "zitieren",
    "zitiertem": "zitiert",
    "zitierten": "zitieren",
    "zitierter": "zitiert",
    "zitiertere": "zitiert",
    "zitierterem": "zitiert",
    "zitierteren": "zitiert",
    "zitierterer": "zitiert",
    "zitierteres": "zitiert",
    "zitiertes": "zitiert",
    "zitiertest": "zitieren",
    "zitierteste": "zitiert",
    "zitiertestem": "zitiert",
    "zitiertesten": "zitiert",
    "zitiertester": "zitiert",
    "zitiertestes": "zitiert",
    "zitiertet": "zitieren",
    "zittere": "zittern",
    "zitterige": "zitterig",
    "zitterigem": "zitterig",
    "zitterigen": "zitterig",
    "zitteriger": "zitterig",
    "zitterigere": "zitterig",
    "zitterigerem": "zitterig",
    "zitterigeren": "zitterig",
    "zitterigerer": "zitterig",
    "zitterigeres": "zitterig",
    "zitteriges": "zitterig",
    "zitterigste": "zitterig",
    "zitterigstem": "zitterig",
    "zitterigsten": "zitterig",
    "zitterigster": "zitterig",
    "zitterigstes": "zitterig",
    "zitternd": "zittern",
    "zitternde": "zitternd",
    "zitterndem": "zitternd",
    "zitternden": "zitternd",
    "zitternder": "zitternd",
    "zitterndere": "zitternd",
    "zitternderem": "zitternd",
    "zitternderen": "zitternd",
    "zitternderer": "zitternd",
    "zitternderes": "zitternd",
    "zitterndes": "zitternd",
    "zitterndste": "zitternd",
    "zitterndstem": "zitternd",
    "zitterndsten": "zitternd",
    "zitterndster": "zitternd",
    "zitterndstes": "zitternd",
    "zitterst": "zittern",
    "zittert": "zittern",
    "zitterte": "zittern",
    "zitterten": "zittern",
    "zittertest": "zittern",
    "zittertet": "zittern",
    "zittrige": "zittrig",
    "zittrigem": "zittrig",
    "zittrigen": "zittrig",
    "zittriger": "zittrig",
    "zittrigere": "zittrig",
    "zittrigerem": "zittrig",
    "zittrigeren": "zittrig",
    "zittrigerer": "zittrig",
    "zittrigeres": "zittrig",
    "zittriges": "zittrig",
    "zittrigste": "zittrig",
    "zittrigstem": "zittrig",
    "zittrigsten": "zittrig",
    "zittrigster": "zittrig",
    "zittrigstes": "zittrig",
    "zivilem": "zivil",
    "zivilen": "zivil",
    "ziviler": "zivil",
    "zivilere": "zivil",
    "zivilerem": "zivil",
    "zivileren": "zivil",
    "zivilerer": "zivil",
    "zivileres": "zivil",
    "ziviles": "zivil",
    "zivilstem": "zivil",
    "zivilsten": "zivil",
    "zivilster": "zivil",
    "zivilstes": "zivil",
    "zog": "ziehen",
    "zogen": "ziehen",
    "zogst": "ziehen",
    "zogt": "ziehen",
    "zollamtlichem": "zollamtlich",
    "zollamtlichen": "zollamtlich",
    "zollamtlicher": "zollamtlich",
    "zollamtliches": "zollamtlich",
    "zollend": "zollen",
    "zollende": "zollend",
    "zollendem": "zollend",
    "zollenden": "zollend",
    "zollender": "zollend",
    "zollendes": "zollend",
    "zollest": "zollen",
    "zollet": "zollen",
    "zollfreie": "zollfrei",
    "zollfreiem": "zollfrei",
    "zollfreien": "zollfrei",
    "zollfreier": "zollfrei",
    "zollfreies": "zollfrei",
    "zollpflichtigem": "zollpflichtig",
    "zollpflichtigen": "zollpflichtig",
    "zollpflichtiger": "zollpflichtig",
    "zollpflichtiges": "zollpflichtig",
    "zollst": "zollen",
    "zollt": "zollen",
    "zollte": "zollen",
    "zollten": "zollen",
    "zolltest": "zollen",
    "zolltet": "zollen",
    "zornigem": "zornig",
    "zornigen": "zornig",
    "zorniger": "zornig",
    "zornigere": "zornig",
    "zornigerem": "zornig",
    "zornigeren": "zornig",
    "zornigerer": "zornig",
    "zornigeres": "zornig",
    "zorniges": "zornig",
    "zornigste": "zornig",
    "zornigstem": "zornig",
    "zornigsten": "zornig",
    "zornigster": "zornig",
    "zornigstes": "zornig",
    "zotteligem": "zottelig",
    "zotteligen": "zottelig",
    "zotteliger": "zottelig",
    "zotteligere": "zottelig",
    "zotteligerem": "zottelig",
    "zotteligeren": "zottelig",
    "zotteligerer": "zottelig",
    "zotteligeres": "zottelig",
    "zotteliges": "zottelig",
    "zotteligste": "zottelig",
    "zotteligstem": "zottelig",
    "zotteligsten": "zottelig",
    "zotteligster": "zottelig",
    "zotteligstes": "zottelig",
    "zuarbeite": "zuarbeiten",
    "zuarbeitend": "zuarbeiten",
    "zuarbeitende": "zuarbeitend",
    "zuarbeitendem": "zuarbeitend",
    "zuarbeitenden": "zuarbeitend",
    "zuarbeitender": "zuarbeitend",
    "zuarbeitendes": "zuarbeitend",
    "zuarbeitest": "zuarbeiten",
    "zuarbeitet": "zuarbeiten",
    "zuarbeitete": "zuarbeiten",
    "zuarbeiteten": "zuarbeiten",
    "zuarbeitetest": "zuarbeiten",
    "zuarbeitetet": "zuarbeiten",
    "zuballere": "zuballern",
    "zuballernd": "zuballern",
    "zuballernde": "zuballernd",
    "zuballerndem": "zuballernd",
    "zuballernden": "zuballernd",
    "zuballernder": "zuballernd",
    "zuballerndes": "zuballernd",
    "zuballerst": "zuballern",
    "zuballert": "zuballern",
    "zuballerte": "zuballern",
    "zuballerten": "zuballern",
    "zuballertest": "zuballern",
    "zuballertet": "zuballern",
    "zuband": "zubinden",
    "zubanden": "zubinden",
    "zubandest": "zubinden",
    "zubandet": "zubinden",
    "zubaue": "zubauen",
    "zubauend": "zubauen",
    "zubauende": "zubauend",
    "zubauendem": "zubauend",
    "zubauenden": "zubauend",
    "zubauender": "zubauend",
    "zubauendes": "zubauend",
    "zubauest": "zubauen",
    "zubauet": "zubauen",
    "zubaust": "zubauen",
    "zubaut": "zubauen",
    "zubaute": "zubauen",
    "zubauten": "zubauen",
    "zubautest": "zubauen",
    "zubautet": "zubauen",
    "zubeiße": "zubeißen",
    "zubeißend": "zubeißen",
    "zubeißende": "zubeißend",
    "zubeißendem": "zubeißend",
    "zubeißenden": "zubeißend",
    "zubeißender": "zubeißend",
    "zubeißendes": "zubeißend",
    "zubeißest": "zubeißen",
    "zubeißet": "zubeißen",
    "zubeißt": "zubeißen",
    "zubekam": "zubekommen",
    "zubekamen": "zubekommen",
    "zubekamst": "zubekommen",
    "zubekamt": "zubekommen",
    "zubekomme": "zubekommen",
    "zubekommend": "zubekommen",
    "zubekommende": "zubekommend",
    "zubekommendem": "zubekommend",
    "zubekommenden": "zubekommend",
    "zubekommender": "zubekommend",
    "zubekommendes": "zubekommend",
    "zubekommene": "zubekommen",
    "zubekommenem": "zubekommen",
    "zubekommenen": "zubekommen",
    "zubekommener": "zubekommen",
    "zubekommenes": "zubekommen",
    "zubekommest": "zubekommen",
    "zubekommet": "zubekommen",
    "zubekommst": "zubekommen",
    "zubekommt": "zubekommen",
    "zubekäme": "zubekommen",
    "zubekämen": "zubekommen",
    "zubekämest": "zubekommen",
    "zubekämet": "zubekommen",
    "zubereite": "zubereiten",
    "zubereitend": "zubereiten",
    "zubereitende": "zubereitend",
    "zubereitendem": "zubereitend",
    "zubereitenden": "zubereitend",
    "zubereitender": "zubereitend",
    "zubereitendes": "zubereitend",
    "zubereitest": "zubereiten",
    "zubereitet": "zubereiten",
    "zubereitete": "zubereiten",
    "zubereitetem": "zubereitet",
    "zubereiteten": "zubereiten",
    "zubereiteter": "zubereitet",
    "zubereitetes": "zubereitet",
    "zubereitetest": "zubereiten",
    "zubereitetet": "zubereiten",
    "zuberitt": "zubereiten",
    "zuberitte": "zubereiten",
    "zuberitten": "zubereiten",
    "zuberittene": "zuberitten",
    "zuberittenem": "zuberitten",
    "zuberittenen": "zuberitten",
    "zuberittener": "zuberitten",
    "zuberittenes": "zuberitten",
    "zuberittest": "zubereiten",
    "zuberittet": "zubereiten",
    "zubetoniere": "zubetonieren",
    "zubetonierend": "zubetonieren",
    "zubetonierende": "zubetonierend",
    "zubetonierendem": "zubetonierend",
    "zubetonierenden": "zubetonierend",
    "zubetonierender": "zubetonierend",
    "zubetonierendere": "zubetonierend",
    "zubetonierenderem": "zubetonierend",
    "zubetonierenderen": "zubetonierend",
    "zubetonierenderer": "zubetonierend",
    "zubetonierenderes": "zubetonierend",
    "zubetonierendes": "zubetonierend",
    "zubetonierendste": "zubetonierend",
    "zubetonierendstem": "zubetonierend",
    "zubetonierendsten": "zubetonierend",
    "zubetonierendster": "zubetonierend",
    "zubetonierendstes": "zubetonierend",
    "zubetonierest": "zubetonieren",
    "zubetonieret": "zubetonieren",
    "zubetonierst": "zubetonieren",
    "zubetoniert": "zubetonieren",
    "zubetonierte": "zubetonieren",
    "zubetoniertem": "zubetoniert",
    "zubetonierten": "zubetonieren",
    "zubetonierter": "zubetoniert",
    "zubetoniertere": "zubetoniert",
    "zubetonierterem": "zubetoniert",
    "zubetonierteren": "zubetoniert",
    "zubetonierterer": "zubetoniert",
    "zubetonierteres": "zubetoniert",
    "zubetoniertes": "zubetoniert",
    "zubetoniertest": "zubetonieren",
    "zubetonierteste": "zubetoniert",
    "zubetoniertestem": "zubetoniert",
    "zubetoniertesten": "zubetoniert",
    "zubetoniertester": "zubetoniert",
    "zubetoniertestes": "zubetoniert",
    "zubetoniertet": "zubetonieren",
    "zubillige": "zubilligen",
    "zubilligend": "zubilligen",
    "zubilligende": "zubilligend",
    "zubilligendem": "zubilligend",
    "zubilligenden": "zubilligend",
    "zubilligender": "zubilligend",
    "zubilligendes": "zubilligend",
    "zubilligest": "zubilligen",
    "zubilliget": "zubilligen",
    "zubilligst": "zubilligen",
    "zubilligt": "zubilligen",
    "zubilligte": "zubilligen",
    "zubilligten": "zubilligen",
    "zubilligtest": "zubilligen",
    "zubilligtet": "zubilligen",
    "zubinde": "zubinden",
    "zubindend": "zubinden",
    "zubindende": "zubindend",
    "zubindendem": "zubindend",
    "zubindenden": "zubindend",
    "zubindender": "zubindend",
    "zubindendes": "zubindend",
    "zubindest": "zubinden",
    "zubindet": "zubinden",
    "zubisse": "zubeißen",
    "zubissen": "zubeißen",
    "zubissest": "zubeißen",
    "zubisset": "zubeißen",
    "zubiß": "zubeißen",
    "zubißt": "zubeißen",
    "zublinzele": "zublinzeln",
    "zublinzelnd": "zublinzeln",
    "zublinzelnde": "zublinzelnd",
    "zublinzelndem": "zublinzelnd",
    "zublinzelnden": "zublinzelnd",
    "zublinzelnder": "zublinzelnd",
    "zublinzelndes": "zublinzelnd",
    "zublinzelst": "zublinzeln",
    "zublinzelt": "zublinzeln",
    "zublinzelte": "zublinzeln",
    "zublinzelten": "zublinzeln",
    "zublinzeltest": "zublinzeln",
    "zublinzeltet": "zublinzeln",
    "zublinzle": "zublinzeln",
    "zubrachte": "zubringen",
    "zubrachten": "zubringen",
    "zubrachtest": "zubringen",
    "zubrachtet": "zubringen",
    "zubringe": "zubringen",
    "zubringend": "zubringen",
    "zubringende": "zubringend",
    "zubringendem": "zubringend",
    "zubringenden": "zubringend",
    "zubringender": "zubringend",
    "zubringendes": "zubringend",
    "zubringest": "zubringen",
    "zubringet": "zubringen",
    "zubringst": "zubringen",
    "zubringt": "zubringen",
    "zubrächte": "zubringen",
    "zubrächten": "zubringen",
    "zubrächtest": "zubringen",
    "zubrächtet": "zubringen",
    "zubuttere": "zubuttern",
    "zubutternd": "zubuttern",
    "zubutternde": "zubutternd",
    "zubutterndem": "zubutternd",
    "zubutternden": "zubutternd",
    "zubutternder": "zubutternd",
    "zubutterndes": "zubutternd",
    "zubutterst": "zubuttern",
    "zubuttert": "zubuttern",
    "zubutterte": "zubuttern",
    "zubutterten": "zubuttern",
    "zubuttertest": "zubuttern",
    "zubuttertet": "zubuttern",
    "zubände": "zubinden",
    "zubänden": "zubinden",
    "zubändest": "zubinden",
    "zubändet": "zubinden",
    "zuchtlose": "zuchtlos",
    "zuchtlosem": "zuchtlos",
    "zuchtlosen": "zuchtlos",
    "zuchtloser": "zuchtlos",
    "zuchtlosere": "zuchtlos",
    "zuchtloserem": "zuchtlos",
    "zuchtloseren": "zuchtlos",
    "zuchtloserer": "zuchtlos",
    "zuchtloseres": "zuchtlos",
    "zuchtloses": "zuchtlos",
    "zuchtloseste": "zuchtlos",
    "zuchtlosestem": "zuchtlos",
    "zuchtlosesten": "zuchtlos",
    "zuchtlosester": "zuchtlos",
    "zuchtlosestes": "zuchtlos",
    "zucke": "zucken",
    "zuckend": "zucken",
    "zuckende": "zuckend",
    "zuckendem": "zuckend",
    "zuckenden": "zuckend",
    "zuckender": "zuckend",
    "zuckendere": "zuckend",
    "zuckenderem": "zuckend",
    "zuckenderen": "zuckend",
    "zuckenderer": "zuckend",
    "zuckenderes": "zuckend",
    "zuckendes": "zuckend",
    "zuckendste": "zuckend",
    "zuckendstem": "zuckend",
    "zuckendsten": "zuckend",
    "zuckendster": "zuckend",
    "zuckendstes": "zuckend",
    "zuckest": "zucken",
    "zucket": "zucken",
    "zuckst": "zucken",
    "zuckt": "zucken",
    "zuckte": "zucken",
    "zuckten": "zucken",
    "zucktest": "zucken",
    "zucktet": "zucken",
    "zudachte": "zudenken",
    "zudachten": "zudenken",
    "zudachtest": "zudenken",
    "zudachtet": "zudenken",
    "zudenke": "zudenken",
    "zudenkend": "zudenken",
    "zudenkende": "zudenkend",
    "zudenkendem": "zudenkend",
    "zudenkenden": "zudenkend",
    "zudenkender": "zudenkend",
    "zudenkendes": "zudenkend",
    "zudenkest": "zudenken",
    "zudenket": "zudenken",
    "zudenkst": "zudenken",
    "zudenkt": "zudenken",
    "zudiene": "zudienen",
    "zudienend": "zudienen",
    "zudienende": "zudienend",
    "zudienendem": "zudienend",
    "zudienenden": "zudienend",
    "zudienender": "zudienend",
    "zudienendes": "zudienend",
    "zudienest": "zudienen",
    "zudienet": "zudienen",
    "zudienst": "zudienen",
    "zudient": "zudienen",
    "zudiente": "zudienen",
    "zudienten": "zudienen",
    "zudientest": "zudienen",
    "zudientet": "zudienen",
    "zudiktiere": "zudiktieren",
    "zudiktierend": "zudiktieren",
    "zudiktierende": "zudiktierend",
    "zudiktierendem": "zudiktierend",
    "zudiktierenden": "zudiktierend",
    "zudiktierender": "zudiktierend",
    "zudiktierendes": "zudiktierend",
    "zudiktierest": "zudiktieren",
    "zudiktieret": "zudiktieren",
    "zudiktierst": "zudiktieren",
    "zudiktiert": "zudiktieren",
    "zudiktierte": "zudiktieren",
    "zudiktiertem": "zudiktiert",
    "zudiktierten": "zudiktieren",
    "zudiktierter": "zudiktiert",
    "zudiktiertes": "zudiktiert",
    "zudiktiertest": "zudiktieren",
    "zudiktiertet": "zudiktieren",
    "zudrehe": "zudrehen",
    "zudrehend": "zudrehen",
    "zudrehende": "zudrehend",
    "zudrehendem": "zudrehend",
    "zudrehenden": "zudrehend",
    "zudrehender": "zudrehend",
    "zudrehendes": "zudrehend",
    "zudrehest": "zudrehen",
    "zudrehet": "zudrehen",
    "zudrehst": "zudrehen",
    "zudreht": "zudrehen",
    "zudrehte": "zudrehen",
    "zudrehten": "zudrehen",
    "zudrehtest": "zudrehen",
    "zudrehtet": "zudrehen",
    "zudringliche": "zudringlich",
    "zudringlichem": "zudringlich",
    "zudringlichen": "zudringlich",
    "zudringlicher": "zudringlich",
    "zudringliches": "zudringlich",
    "zudrücke": "zudrücken",
    "zudrückend": "zudrücken",
    "zudrückende": "zudrückend",
    "zudrückendem": "zudrückend",
    "zudrückenden": "zudrückend",
    "zudrückender": "zudrückend",
    "zudrückendere": "zudrückend",
    "zudrückenderem": "zudrückend",
    "zudrückenderen": "zudrückend",
    "zudrückenderer": "zudrückend",
    "zudrückenderes": "zudrückend",
    "zudrückendes": "zudrückend",
    "zudrückendste": "zudrückend",
    "zudrückendstem": "zudrückend",
    "zudrückendsten": "zudrückend",
    "zudrückendster": "zudrückend",
    "zudrückendstes": "zudrückend",
    "zudrückest": "zudrücken",
    "zudrücket": "zudrücken",
    "zudrückst": "zudrücken",
    "zudrückt": "zudrücken",
    "zudrückte": "zudrücken",
    "zudrückten": "zudrücken",
    "zudrücktest": "zudrücken",
    "zudrücktet": "zudrücken",
    "zudächte": "zudenken",
    "zudächten": "zudenken",
    "zudächtest": "zudenken",
    "zudächtet": "zudenken",
    "zueigne": "zueignen",
    "zueignend": "zueignen",
    "zueignende": "zueignend",
    "zueignendem": "zueignend",
    "zueignenden": "zueignend",
    "zueignender": "zueignend",
    "zueignendes": "zueignend",
    "zueignest": "zueignen",
    "zueignet": "zueignen",
    "zueignete": "zueignen",
    "zueigneten": "zueignen",
    "zueignetest": "zueignen",
    "zueignetet": "zueignen",
    "zuerkannt": "zuerkennen",
    "zuerkannte": "zuerkannt",
    "zuerkanntem": "zuerkannt",
    "zuerkannten": "zuerkannt",
    "zuerkannter": "zuerkannt",
    "zuerkanntes": "zuerkannt",
    "zuerkanntest": "zuerkennen",
    "zuerkanntet": "zuerkennen",
    "zuerkenne": "zuerkennen",
    "zuerkennend": "zuerkennen",
    "zuerkennende": "zuerkennend",
    "zuerkennendem": "zuerkennend",
    "zuerkennenden": "zuerkennend",
    "zuerkennender": "zuerkennend",
    "zuerkennendes": "zuerkennend",
    "zuerkennest": "zuerkennen",
    "zuerkennet": "zuerkennen",
    "zuerkennst": "zuerkennen",
    "zuerkennt": "zuerkennen",
    "zufallend": "zufallen",
    "zufallende": "zufallend",
    "zufallendem": "zufallend",
    "zufallenden": "zufallend",
    "zufallender": "zufallend",
    "zufallendes": "zufallend",
    "zufallest": "zufallen",
    "zufallet": "zufallen",
    "zufallt": "zufallen",
    "zufasse": "zufassen",
    "zufassend": "zufassen",
    "zufassende": "zufassend",
    "zufassendem": "zufassend",
    "zufassenden": "zufassend",
    "zufassender": "zufassend",
    "zufassendes": "zufassend",
    "zufassest": "zufassen",
    "zufasset": "zufassen",
    "zufaxe": "zufaxen",
    "zufaxend": "zufaxen",
    "zufaxende": "zufaxend",
    "zufaxendem": "zufaxend",
    "zufaxenden": "zufaxend",
    "zufaxender": "zufaxend",
    "zufaxendes": "zufaxend",
    "zufaxest": "zufaxen",
    "zufaxet": "zufaxen",
    "zufaxt": "zufaxen",
    "zufaxte": "zufaxen",
    "zufaxten": "zufaxen",
    "zufaxtest": "zufaxen",
    "zufaxtet": "zufaxen",
    "zufaßt": "zufassen",
    "zufaßte": "zufassen",
    "zufaßten": "zufassen",
    "zufaßtest": "zufassen",
    "zufaßtet": "zufassen",
    "zufiel": "zufallen",
    "zufiele": "zufallen",
    "zufielen": "zufallen",
    "zufielest": "zufallen",
    "zufielet": "zufallen",
    "zufielst": "zufallen",
    "zufielt": "zufallen",
    "zufliege": "zufliegen",
    "zufliegend": "zufliegen",
    "zufliegende": "zufliegend",
    "zufliegendem": "zufliegend",
    "zufliegenden": "zufliegend",
    "zufliegender": "zufliegend",
    "zufliegendes": "zufliegend",
    "zufliegest": "zufliegen",
    "zuflieget": "zufliegen",
    "zufliegst": "zufliegen",
    "zufliegt": "zufliegen",
    "zufließe": "zufließen",
    "zufließend": "zufließen",
    "zufließende": "zufließend",
    "zufließendem": "zufließend",
    "zufließenden": "zufließend",
    "zufließender": "zufließend",
    "zufließendes": "zufließend",
    "zufließest": "zufließen",
    "zufließet": "zufließen",
    "zufließt": "zufließen",
    "zuflog": "zufliegen",
    "zuflogen": "zufliegen",
    "zuflogst": "zufliegen",
    "zuflogt": "zufliegen",
    "zuflossen": "zufließen",
    "zufloß": "zufließen",
    "zufloßt": "zufließen",
    "zuflöge": "zufliegen",
    "zuflögen": "zufliegen",
    "zuflögest": "zufliegen",
    "zuflöget": "zufliegen",
    "zuflösse": "zufließen",
    "zuflössen": "zufließen",
    "zuflössest": "zufließen",
    "zuflösset": "zufließen",
    "zuflüstere": "zuflüstern",
    "zuflüsternd": "zuflüstern",
    "zuflüsternde": "zuflüsternd",
    "zuflüsterndem": "zuflüsternd",
    "zuflüsternden": "zuflüsternd",
    "zuflüsternder": "zuflüsternd",
    "zuflüsterndes": "zuflüsternd",
    "zuflüsterst": "zuflüstern",
    "zuflüstert": "zuflüstern",
    "zuflüsterte": "zuflüstern",
    "zuflüsterten": "zuflüstern",
    "zuflüstertest": "zuflüstern",
    "zuflüstertet": "zuflüstern",
    "zufriedene": "zufrieden",
    "zufriedenem": "zufrieden",
    "zufriedenen": "zufrieden",
    "zufriedener": "zufrieden",
    "zufriedenere": "zufrieden",
    "zufriedenerem": "zufrieden",
    "zufriedeneren": "zufrieden",
    "zufriedenerer": "zufrieden",
    "zufriedeneres": "zufrieden",
    "zufriedenes": "zufrieden",
    "zufriedengab": "zufriedengeben",
    "zufriedengaben": "zufriedengeben",
    "zufriedengabst": "zufriedengeben",
    "zufriedengabt": "zufriedengeben",
    "zufriedengebe": "zufriedengeben",
    "zufriedengebend": "zufriedengeben",
    "zufriedengebende": "zufriedengebend",
    "zufriedengebendem": "zufriedengebend",
    "zufriedengebenden": "zufriedengebend",
    "zufriedengebender": "zufriedengebend",
    "zufriedengebendere": "zufriedengebend",
    "zufriedengebenderem": "zufriedengebend",
    "zufriedengebenderen": "zufriedengebend",
    "zufriedengebenderer": "zufriedengebend",
    "zufriedengebenderes": "zufriedengebend",
    "zufriedengebendes": "zufriedengebend",
    "zufriedengebendste": "zufriedengebend",
    "zufriedengebendstem": "zufriedengebend",
    "zufriedengebendsten": "zufriedengebend",
    "zufriedengebendster": "zufriedengebend",
    "zufriedengebendstes": "zufriedengebend",
    "zufriedengebest": "zufriedengeben",
    "zufriedengebet": "zufriedengeben",
    "zufriedengebt": "zufriedengeben",
    "zufriedengegeben": "zufriedengeben",
    "zufriedengegebene": "zufriedengegeben",
    "zufriedengegebenem": "zufriedengegeben",
    "zufriedengegebenen": "zufriedengegeben",
    "zufriedengegebener": "zufriedengegeben",
    "zufriedengegebenere": "zufriedengegeben",
    "zufriedengegebenerem": "zufriedengegeben",
    "zufriedengegebeneren": "zufriedengegeben",
    "zufriedengegebenerer": "zufriedengegeben",
    "zufriedengegebeneres": "zufriedengegeben",
    "zufriedengegebenes": "zufriedengegeben",
    "zufriedengegebenste": "zufriedengegeben",
    "zufriedengegebenstem": "zufriedengegeben",
    "zufriedengegebensten": "zufriedengegeben",
    "zufriedengegebenster": "zufriedengegeben",
    "zufriedengegebenstes": "zufriedengegeben",
    "zufriedengelassen": "zufriedenlassen",
    "zufriedengelassene": "zufriedengelassen",
    "zufriedengelassenem": "zufriedengelassen",
    "zufriedengelassenen": "zufriedengelassen",
    "zufriedengelassener": "zufriedengelassen",
    "zufriedengelassenes": "zufriedengelassen",
    "zufriedengestellt": "zufriedenstellen",
    "zufriedengestellte": "zufriedengestellt",
    "zufriedengestelltem": "zufriedengestellt",
    "zufriedengestellten": "zufriedengestellt",
    "zufriedengestellter": "zufriedengestellt",
    "zufriedengestelltere": "zufriedengestellt",
    "zufriedengestellterem": "zufriedengestellt",
    "zufriedengestellteren": "zufriedengestellt",
    "zufriedengestellterer": "zufriedengestellt",
    "zufriedengestellteres": "zufriedengestellt",
    "zufriedengestelltes": "zufriedengestellt",
    "zufriedengestellteste": "zufriedengestellt",
    "zufriedengestelltestem": "zufriedengestellt",
    "zufriedengestelltesten": "zufriedengestellt",
    "zufriedengestelltester": "zufriedengestellt",
    "zufriedengestelltestes": "zufriedengestellt",
    "zufriedengibst": "zufriedengeben",
    "zufriedengibt": "zufriedengeben",
    "zufriedengäbe": "zufriedengeben",
    "zufriedengäben": "zufriedengeben",
    "zufriedengäbest": "zufriedengeben",
    "zufriedengäbet": "zufriedengeben",
    "zufriedenlasse": "zufriedenlassen",
    "zufriedenlassend": "zufriedenlassen",
    "zufriedenlassende": "zufriedenlassend",
    "zufriedenlassendem": "zufriedenlassend",
    "zufriedenlassenden": "zufriedenlassend",
    "zufriedenlassender": "zufriedenlassend",
    "zufriedenlassendes": "zufriedenlassend",
    "zufriedenlassest": "zufriedenlassen",
    "zufriedenlasset": "zufriedenlassen",
    "zufriedenlaßt": "zufriedenlassen",
    "zufriedenließ": "zufriedenlassen",
    "zufriedenließe": "zufriedenlassen",
    "zufriedenließen": "zufriedenlassen",
    "zufriedenließest": "zufriedenlassen",
    "zufriedenließet": "zufriedenlassen",
    "zufriedenließt": "zufriedenlassen",
    "zufriedenläßt": "zufriedenlassen",
    "zufriedenste": "zufrieden",
    "zufriedenstelle": "zufriedenstellen",
    "zufriedenstellend": "zufriedenstellen",
    "zufriedenstellende": "zufriedenstellend",
    "zufriedenstellendem": "zufriedenstellend",
    "zufriedenstellenden": "zufriedenstellend",
    "zufriedenstellender": "zufriedenstellend",
    "zufriedenstellendere": "zufriedenstellend",
    "zufriedenstellenderem": "zufriedenstellend",
    "zufriedenstellenderen": "zufriedenstellend",
    "zufriedenstellenderer": "zufriedenstellend",
    "zufriedenstellenderes": "zufriedenstellend",
    "zufriedenstellendes": "zufriedenstellend",
    "zufriedenstellendste": "zufriedenstellend",
    "zufriedenstellendstem": "zufriedenstellend",
    "zufriedenstellendsten": "zufriedenstellend",
    "zufriedenstellendster": "zufriedenstellend",
    "zufriedenstellendstes": "zufriedenstellend",
    "zufriedenstellest": "zufriedenstellen",
    "zufriedenstellet": "zufriedenstellen",
    "zufriedenstellst": "zufriedenstellen",
    "zufriedenstellt": "zufriedenstellen",
    "zufriedenstellte": "zufriedenstellen",
    "zufriedenstellten": "zufriedenstellen",
    "zufriedenstelltest": "zufriedenstellen",
    "zufriedenstelltet": "zufriedenstellen",
    "zufriedenstem": "zufrieden",
    "zufriedensten": "zufrieden",
    "zufriedenster": "zufrieden",
    "zufriedenstes": "zufrieden",
    "zufriedenzugeben": "zufriedengeben",
    "zufriedenzulassen": "zufriedenlassen",
    "zufriedenzustellen": "zufriedenstellen",
    "zufriere": "zufrieren",
    "zufrierend": "zufrieren",
    "zufrierende": "zufrierend",
    "zufrierendem": "zufrierend",
    "zufrierenden": "zufrierend",
    "zufrierender": "zufrierend",
    "zufrierendere": "zufrierend",
    "zufrierenderem": "zufrierend",
    "zufrierenderen": "zufrierend",
    "zufrierenderer": "zufrierend",
    "zufrierenderes": "zufrierend",
    "zufrierendes": "zufrierend",
    "zufrierendste": "zufrierend",
    "zufrierendstem": "zufrierend",
    "zufrierendsten": "zufrierend",
    "zufrierendster": "zufrierend",
    "zufrierendstes": "zufrierend",
    "zufrierest": "zufrieren",
    "zufrieret": "zufrieren",
    "zufrierst": "zufrieren",
    "zufriert": "zufrieren",
    "zufror": "zufrieren",
    "zufroren": "zufrieren",
    "zufrorst": "zufrieren",
    "zufrort": "zufrieren",
    "zufröre": "zufrieren",
    "zufrören": "zufrieren",
    "zufrörest": "zufrieren",
    "zufröret": "zufrieren",
    "zufächele": "zufächeln",
    "zufächelnd": "zufächeln",
    "zufächelnde": "zufächelnd",
    "zufächelndem": "zufächelnd",
    "zufächelnden": "zufächelnd",
    "zufächelnder": "zufächelnd",
    "zufächelndes": "zufächelnd",
    "zufächelst": "zufächeln",
    "zufächelt": "zufächeln",
    "zufächelte": "zufächeln",
    "zufächelten": "zufächeln",
    "zufächeltest": "zufächeln",
    "zufächeltet": "zufächeln",
    "zufächle": "zufächeln",
    "zufällige": "zufällig",
    "zufälligem": "zufällig",
    "zufälligen": "zufällig",
    "zufälliger": "zufällig",
    "zufälligere": "zufällig",
    "zufälligerem": "zufällig",
    "zufälligeren": "zufällig",
    "zufälligerer": "zufällig",
    "zufälligeres": "zufällig",
    "zufälliges": "zufällig",
    "zufälligste": "zufällig",
    "zufälligstem": "zufällig",
    "zufälligsten": "zufällig",
    "zufälligster": "zufällig",
    "zufälligstes": "zufällig",
    "zufällst": "zufallen",
    "zufällt": "zufallen",
    "zufüge": "zufügen",
    "zufügend": "zufügen",
    "zufügende": "zufügend",
    "zufügendem": "zufügend",
    "zufügenden": "zufügend",
    "zufügender": "zufügend",
    "zufügendes": "zufügend",
    "zufügest": "zufügen",
    "zufüget": "zufügen",
    "zufügst": "zufügen",
    "zufügt": "zufügen",
    "zufügte": "zufügen",
    "zufügten": "zufügen",
    "zufügtest": "zufügen",
    "zufügtet": "zufügen",
    "zuführe": "zuführen",
    "zuführend": "zuführen",
    "zuführende": "zuführend",
    "zuführendem": "zuführend",
    "zuführenden": "zuführend",
    "zuführender": "zuführend",
    "zuführendere": "zuführend",
    "zuführenderem": "zuführend",
    "zuführenderen": "zuführend",
    "zuführenderer": "zuführend",
    "zuführenderes": "zuführend",
    "zuführendes": "zuführend",
    "zuführendste": "zuführend",
    "zuführendstem": "zuführend",
    "zuführendsten": "zuführend",
    "zuführendster": "zuführend",
    "zuführendstes": "zuführend",
    "zuführest": "zuführen",
    "zuführet": "zuführen",
    "zuführst": "zuführen",
    "zuführt": "zuführen",
    "zuführte": "zuführen",
    "zuführten": "zuführen",
    "zuführtest": "zuführen",
    "zuführtet": "zuführen",
    "zugab": "zugeben",
    "zugaben": "zugeben",
    "zugabst": "zugeben",
    "zugabt": "zugeben",
    "zugearbeitet": "zuarbeiten",
    "zugearbeitete": "zugearbeitet",
    "zugearbeitetem": "zugearbeitet",
    "zugearbeiteten": "zugearbeitet",
    "zugearbeiteter": "zugearbeitet",
    "zugearbeitetes": "zugearbeitet",
    "zugeballert": "zuballern",
    "zugeballerte": "zugeballert",
    "zugeballertem": "zugeballert",
    "zugeballerten": "zugeballert",
    "zugeballerter": "zugeballert",
    "zugeballertes": "zugeballert",
    "zugebaut": "zubauen",
    "zugebaute": "zugebaut",
    "zugebautem": "zugebaut",
    "zugebauten": "zugebaut",
    "zugebauter": "zugebaut",
    "zugebautere": "zugebaut",
    "zugebauterem": "zugebaut",
    "zugebauteren": "zugebaut",
    "zugebauterer": "zugebaut",
    "zugebauteres": "zugebaut",
    "zugebautes": "zugebaut",
    "zugebauteste": "zugebaut",
    "zugebautestem": "zugebaut",
    "zugebautesten": "zugebaut",
    "zugebautester": "zugebaut",
    "zugebautestes": "zugebaut",
    "zugebe": "zugeben",
    "zugebend": "zugeben",
    "zugebende": "zugebend",
    "zugebendem": "zugebend",
    "zugebenden": "zugebend",
    "zugebender": "zugebend",
    "zugebendes": "zugebend",
    "zugebest": "zugeben",
    "zugebet": "zugeben",
    "zugebilligt": "zubilligen",
    "zugebilligte": "zugebilligt",
    "zugebilligtem": "zugebilligt",
    "zugebilligten": "zugebilligt",
    "zugebilligter": "zugebilligt",
    "zugebilligtes": "zugebilligt",
    "zugebissen": "zubeißen",
    "zugebissene": "zugebissen",
    "zugebissenem": "zugebissen",
    "zugebissenen": "zugebissen",
    "zugebissener": "zugebissen",
    "zugebissenes": "zugebissen",
    "zugeblinzelt": "zublinzeln",
    "zugeblinzelte": "zugeblinzelt",
    "zugeblinzeltem": "zugeblinzelt",
    "zugeblinzelten": "zugeblinzelt",
    "zugeblinzelter": "zugeblinzelt",
    "zugeblinzeltes": "zugeblinzelt",
    "zugebracht": "zubringen",
    "zugebrachte": "zugebracht",
    "zugebrachtem": "zugebracht",
    "zugebrachten": "zugebracht",
    "zugebrachter": "zugebracht",
    "zugebrachtes": "zugebracht",
    "zugebt": "zugeben",
    "zugebunden": "zubinden",
    "zugebundene": "zugebunden",
    "zugebundenem": "zugebunden",
    "zugebundenen": "zugebunden",
    "zugebundener": "zugebunden",
    "zugebundenere": "zugebunden",
    "zugebundenerem": "zugebunden",
    "zugebundeneren": "zugebunden",
    "zugebundenerer": "zugebunden",
    "zugebundeneres": "zugebunden",
    "zugebundenes": "zugebunden",
    "zugebundenste": "zugebunden",
    "zugebundenstem": "zugebunden",
    "zugebundensten": "zugebunden",
    "zugebundenster": "zugebunden",
    "zugebundenstes": "zugebunden",
    "zugebuttert": "zubuttern",
    "zugebutterte": "zugebuttert",
    "zugebuttertem": "zugebuttert",
    "zugebutterten": "zugebuttert",
    "zugebutterter": "zugebuttert",
    "zugebuttertes": "zugebuttert",
    "zugedacht": "zudenken",
    "zugedachte": "zugedacht",
    "zugedachtem": "zugedacht",
    "zugedachten": "zugedacht",
    "zugedachter": "zugedacht",
    "zugedachtes": "zugedacht",
    "zugedient": "zudienen",
    "zugediente": "zugedient",
    "zugedientem": "zugedient",
    "zugedienten": "zugedient",
    "zugedienter": "zugedient",
    "zugedientes": "zugedient",
    "zugedreht": "zudrehen",
    "zugedrehte": "zugedreht",
    "zugedrehtem": "zugedreht",
    "zugedrehten": "zugedreht",
    "zugedrehter": "zugedreht",
    "zugedrehtes": "zugedreht",
    "zugedrückt": "zudrücken",
    "zugedrückte": "zugedrückt",
    "zugedrücktem": "zugedrückt",
    "zugedrückten": "zugedrückt",
    "zugedrückter": "zugedrückt",
    "zugedrücktes": "zugedrückt",
    "zugeeignet": "zueignen",
    "zugeeignete": "zugeeignet",
    "zugeeignetem": "zugeeignet",
    "zugeeigneten": "zugeeignet",
    "zugeeigneter": "zugeeignet",
    "zugeeignetes": "zugeeignet",
    "zugefallen": "zufallen",
    "zugefallene": "zugefallen",
    "zugefallenem": "zugefallen",
    "zugefallenen": "zugefallen",
    "zugefallener": "zugefallen",
    "zugefallenes": "zugefallen",
    "zugefaxt": "zufaxen",
    "zugefaxte": "zugefaxt",
    "zugefaxtem": "zugefaxt",
    "zugefaxten": "zugefaxt",
    "zugefaxter": "zugefaxt",
    "zugefaxtes": "zugefaxt",
    "zugefaßt": "zufassen",
    "zugefaßte": "zugefaßt",
    "zugefaßtem": "zugefaßt",
    "zugefaßten": "zugefaßt",
    "zugefaßter": "zugefaßt",
    "zugefaßtes": "zugefaßt",
    "zugeflogen": "zufliegen",
    "zugeflogene": "zugeflogen",
    "zugeflogenem": "zugeflogen",
    "zugeflogenen": "zugeflogen",
    "zugeflogener": "zugeflogen",
    "zugeflogenes": "zugeflogen",
    "zugeflossen": "zufließen",
    "zugeflossene": "zugeflossen",
    "zugeflossenem": "zugeflossen",
    "zugeflossenen": "zugeflossen",
    "zugeflossener": "zugeflossen",
    "zugeflossenes": "zugeflossen",
    "zugeflüstert": "zuflüstern",
    "zugeflüsterte": "zugeflüstert",
    "zugeflüstertem": "zugeflüstert",
    "zugeflüsterten": "zugeflüstert",
    "zugeflüsterter": "zugeflüstert",
    "zugeflüstertes": "zugeflüstert",
    "zugefroren": "zufrieren",
    "zugefrorene": "zugefroren",
    "zugefrorenem": "zugefroren",
    "zugefrorenen": "zugefroren",
    "zugefrorener": "zugefroren",
    "zugefrorenere": "zugefroren",
    "zugefrorenerem": "zugefroren",
    "zugefroreneren": "zugefroren",
    "zugefrorenerer": "zugefroren",
    "zugefroreneres": "zugefroren",
    "zugefrorenes": "zugefroren",
    "zugefrorenste": "zugefroren",
    "zugefrorenstem": "zugefroren",
    "zugefrorensten": "zugefroren",
    "zugefrorenster": "zugefroren",
    "zugefrorenstes": "zugefroren",
    "zugefächelt": "zufächeln",
    "zugefächelte": "zugefächelt",
    "zugefächeltem": "zugefächelt",
    "zugefächelten": "zugefächelt",
    "zugefächelter": "zugefächelt",
    "zugefächeltes": "zugefächelt",
    "zugefügt": "zufügen",
    "zugefügte": "zugefügt",
    "zugefügtem": "zugefügt",
    "zugefügten": "zugefügt",
    "zugefügter": "zugefügt",
    "zugefügtes": "zugefügt",
    "zugeführt": "zuführen",
    "zugeführte": "zugeführt",
    "zugeführtem": "zugeführt",
    "zugeführten": "zugeführt",
    "zugeführter": "zugeführt",
    "zugeführtes": "zugeführt",
    "zugegangen": "zugehen",
    "zugegangene": "zugegangen",
    "zugegangenem": "zugegangen",
    "zugegangenen": "zugegangen",
    "zugegangener": "zugegangen",
    "zugegangenes": "zugegangen",
    "zugegeben": "zugeben",
    "zugegebene": "zugegeben",
    "zugegebenem": "zugegeben",
    "zugegebenen": "zugegeben",
    "zugegebener": "zugegeben",
    "zugegebenes": "zugegeben",
    "zugegossen": "zugießen",
    "zugegossene": "zugegossen",
    "zugegossenem": "zugegossen",
    "zugegossenen": "zugegossen",
    "zugegossener": "zugegossen",
    "zugegossenes": "zugegossen",
    "zugegriffen": "zugreifen",
    "zugegriffene": "zugegriffen",
    "zugegriffenem": "zugegriffen",
    "zugegriffenen": "zugegriffen",
    "zugegriffener": "zugegriffen",
    "zugegriffenere": "zugegriffen",
    "zugegriffenerem": "zugegriffen",
    "zugegriffeneren": "zugegriffen",
    "zugegriffenerer": "zugegriffen",
    "zugegriffeneres": "zugegriffen",
    "zugegriffenes": "zugegriffen",
    "zugegriffenste": "zugegriffen",
    "zugegriffenstem": "zugegriffen",
    "zugegriffensten": "zugegriffen",
    "zugegriffenster": "zugegriffen",
    "zugegriffenstes": "zugegriffen",
    "zugehakt": "zuhaken",
    "zugehakte": "zugehakt",
    "zugehaktem": "zugehakt",
    "zugehakten": "zugehakt",
    "zugehakter": "zugehakt",
    "zugehaktes": "zugehakt",
    "zugehalten": "zuhalten",
    "zugehaltene": "zugehalten",
    "zugehaltenem": "zugehalten",
    "zugehaltenen": "zugehalten",
    "zugehaltener": "zugehalten",
    "zugehaltenes": "zugehalten",
    "zugehangen": "zuhängen",
    "zugehauen": "zuhauen",
    "zugehauene": "zugehauen",
    "zugehauenem": "zugehauen",
    "zugehauenen": "zugehauen",
    "zugehauener": "zugehauen",
    "zugehauenes": "zugehauen",
    "zugehe": "zugehen",
    "zugeheilt": "zuheilen",
    "zugeheilte": "zugeheilt",
    "zugeheiltem": "zugeheilt",
    "zugeheilten": "zugeheilt",
    "zugeheilter": "zugeheilt",
    "zugeheiltere": "zugeheilt",
    "zugeheilterem": "zugeheilt",
    "zugeheilteren": "zugeheilt",
    "zugeheilterer": "zugeheilt",
    "zugeheilteres": "zugeheilt",
    "zugeheiltes": "zugeheilt",
    "zugeheilteste": "zugeheilt",
    "zugeheiltestem": "zugeheilt",
    "zugeheiltesten": "zugeheilt",
    "zugeheiltester": "zugeheilt",
    "zugeheiltestes": "zugeheilt",
    "zugehend": "zugehen",
    "zugehende": "zugehend",
    "zugehendem": "zugehend",
    "zugehenden": "zugehend",
    "zugehender": "zugehend",
    "zugehendes": "zugehend",
    "zugehest": "zugehen",
    "zugehet": "zugehen",
    "zugehst": "zugehen",
    "zugeht": "zugehen",
    "zugehängt": "zuhängen",
    "zugehängte": "zugehängt",
    "zugehängtem": "zugehängt",
    "zugehängten": "zugehängt",
    "zugehängter": "zugehängt",
    "zugehängtes": "zugehängt",
    "zugehöre": "zugehören",
    "zugehörend": "zugehören",
    "zugehörende": "zugehörend",
    "zugehörendem": "zugehörend",
    "zugehörenden": "zugehörend",
    "zugehörender": "zugehörend",
    "zugehörendes": "zugehörend",
    "zugehörest": "zugehören",
    "zugehöret": "zugehören",
    "zugehörige": "zugehörig",
    "zugehörigem": "zugehörig",
    "zugehörigen": "zugehörig",
    "zugehöriger": "zugehörig",
    "zugehöriges": "zugehörig",
    "zugehörst": "zugehören",
    "zugehört": "zuhören",
    "zugehörte": "zugehören",
    "zugehörtem": "zugehört",
    "zugehörten": "zugehören",
    "zugehörter": "zugehört",
    "zugehörtes": "zugehört",
    "zugehörtest": "zugehören",
    "zugehörtet": "zugehören",
    "zugejauchzt": "zujauchzen",
    "zugejauchzte": "zugejauchzt",
    "zugejauchztem": "zugejauchzt",
    "zugejauchzten": "zugejauchzt",
    "zugejauchzter": "zugejauchzt",
    "zugejauchztere": "zugejauchzt",
    "zugejauchzterem": "zugejauchzt",
    "zugejauchzteren": "zugejauchzt",
    "zugejauchzterer": "zugejauchzt",
    "zugejauchzteres": "zugejauchzt",
    "zugejauchztes": "zugejauchzt",
    "zugejauchzteste": "zugejauchzt",
    "zugejauchztestem": "zugejauchzt",
    "zugejauchztesten": "zugejauchzt",
    "zugejauchztester": "zugejauchzt",
    "zugejauchztestes": "zugejauchzt",
    "zugejubelt": "zujubeln",
    "zugejubelte": "zugejubelt",
    "zugejubeltem": "zugejubelt",
    "zugejubelten": "zugejubelt",
    "zugejubelter": "zugejubelt",
    "zugejubeltere": "zugejubelt",
    "zugejubelterem": "zugejubelt",
    "zugejubelteren": "zugejubelt",
    "zugejubelterer": "zugejubelt",
    "zugejubelteres": "zugejubelt",
    "zugejubeltes": "zugejubelt",
    "zugejubelteste": "zugejubelt",
    "zugejubeltestem": "zugejubelt",
    "zugejubeltesten": "zugejubelt",
    "zugejubeltester": "zugejubelt",
    "zugejubeltestes": "zugejubelt",
    "zugekehrt": "zukehren",
    "zugekehrte": "zugekehrt",
    "zugekehrtem": "zugekehrt",
    "zugekehrten": "zugekehrt",
    "zugekehrter": "zugekehrt",
    "zugekehrtes": "zugekehrt",
    "zugeklappt": "zuklappen",
    "zugeklappte": "zugeklappt",
    "zugeklapptem": "zugeklappt",
    "zugeklappten": "zugeklappt",
    "zugeklappter": "zugeklappt",
    "zugeklapptes": "zugeklappt",
    "zugeklebt": "zukleben",
    "zugeklebte": "zugeklebt",
    "zugeklebtem": "zugeklebt",
    "zugeklebten": "zugeklebt",
    "zugeklebter": "zugeklebt",
    "zugeklebtes": "zugeklebt",
    "zugeklinkt": "zuklinken",
    "zugeklinkte": "zugeklinkt",
    "zugeklinktem": "zugeklinkt",
    "zugeklinkten": "zugeklinkt",
    "zugeklinkter": "zugeklinkt",
    "zugeklinktes": "zugeklinkt",
    "zugeknallt": "zuknallen",
    "zugeknallte": "zugeknallt",
    "zugeknalltem": "zugeknallt",
    "zugeknallten": "zugeknallt",
    "zugeknallter": "zugeknallt",
    "zugeknalltes": "zugeknallt",
    "zugeknöpft": "zuknöpfen",
    "zugeknöpfte": "zugeknöpft",
    "zugeknöpftem": "zugeknöpft",
    "zugeknöpften": "zugeknöpft",
    "zugeknöpfter": "zugeknöpft",
    "zugeknöpftes": "zugeknöpft",
    "zugekommen": "zukommen",
    "zugekommene": "zugekommen",
    "zugekommenem": "zugekommen",
    "zugekommenen": "zugekommen",
    "zugekommener": "zugekommen",
    "zugekommenes": "zugekommen",
    "zugekorkt": "zukorken",
    "zugekorkte": "zugekorkt",
    "zugekorktem": "zugekorkt",
    "zugekorkten": "zugekorkt",
    "zugekorkter": "zugekorkt",
    "zugekorktes": "zugekorkt",
    "zugekriegt": "zukriegen",
    "zugekriegte": "zugekriegt",
    "zugekriegtem": "zugekriegt",
    "zugekriegten": "zugekriegt",
    "zugekriegter": "zugekriegt",
    "zugekriegtes": "zugekriegt",
    "zugelacht": "zulachen",
    "zugelachte": "zugelacht",
    "zugelachtem": "zugelacht",
    "zugelachten": "zugelacht",
    "zugelachter": "zugelacht",
    "zugelachtes": "zugelacht",
    "zugeladen": "zuladen",
    "zugeladene": "zugeladen",
    "zugeladenem": "zugeladen",
    "zugeladenen": "zugeladen",
    "zugeladener": "zugeladen",
    "zugeladenes": "zugeladen",
    "zugelangt": "zulangen",
    "zugelangte": "zugelangt",
    "zugelangtem": "zugelangt",
    "zugelangten": "zugelangt",
    "zugelangter": "zugelangt",
    "zugelangtes": "zugelangt",
    "zugelassen": "zulassen",
    "zugelassene": "zugelassen",
    "zugelassenem": "zugelassen",
    "zugelassenen": "zugelassen",
    "zugelassener": "zugelassen",
    "zugelassenes": "zugelassen",
    "zugelaufen": "zulaufen",
    "zugelaufene": "zugelaufen",
    "zugelaufenem": "zugelaufen",
    "zugelaufenen": "zugelaufen",
    "zugelaufener": "zugelaufen",
    "zugelaufenes": "zugelaufen",
    "zugelegt": "zulegen",
    "zugelegte": "zugelegt",
    "zugelegtem": "zugelegt",
    "zugelegten": "zugelegt",
    "zugelegter": "zugelegt",
    "zugelegtes": "zugelegt",
    "zugeleitet": "zuleiten",
    "zugeleitete": "zugeleitet",
    "zugeleitetem": "zugeleitet",
    "zugeleiteten": "zugeleitet",
    "zugeleiteter": "zugeleitet",
    "zugeleitetes": "zugeleitet",
    "zugelächelt": "zulächeln",
    "zugelächelte": "zugelächelt",
    "zugelächeltem": "zugelächelt",
    "zugelächelten": "zugelächelt",
    "zugelächelter": "zugelächelt",
    "zugelächeltere": "zugelächelt",
    "zugelächelterem": "zugelächelt",
    "zugelächelteren": "zugelächelt",
    "zugelächelterer": "zugelächelt",
    "zugelächelteres": "zugelächelt",
    "zugelächeltes": "zugelächelt",
    "zugelächelteste": "zugelächelt",
    "zugelächeltestem": "zugelächelt",
    "zugelächeltesten": "zugelächelt",
    "zugelächeltester": "zugelächelt",
    "zugelächeltestes": "zugelächelt",
    "zugelötet": "zulöten",
    "zugelötete": "zugelötet",
    "zugelötetem": "zugelötet",
    "zugelöteten": "zugelötet",
    "zugelöteter": "zugelötet",
    "zugelötetes": "zugelötet",
    "zugemacht": "zumachen",
    "zugemachte": "zugemacht",
    "zugemachtem": "zugemacht",
    "zugemachten": "zugemacht",
    "zugemachter": "zugemacht",
    "zugemachtes": "zugemacht",
    "zugemauert": "zumauern",
    "zugemauerte": "zugemauert",
    "zugemauertem": "zugemauert",
    "zugemauerten": "zugemauert",
    "zugemauerter": "zugemauert",
    "zugemauertere": "zugemauert",
    "zugemauerterem": "zugemauert",
    "zugemauerteren": "zugemauert",
    "zugemauerterer": "zugemauert",
    "zugemauerteres": "zugemauert",
    "zugemauertes": "zugemauert",
    "zugemauerteste": "zugemauert",
    "zugemauertestem": "zugemauert",
    "zugemauertesten": "zugemauert",
    "zugemauertester": "zugemauert",
    "zugemauertestes": "zugemauert",
    "zugemessen": "zumessen",
    "zugemessene": "zugemessen",
    "zugemessenem": "zugemessen",
    "zugemessenen": "zugemessen",
    "zugemessener": "zugemessen",
    "zugemessenes": "zugemessen",
    "zugemutet": "zumuten",
    "zugemutete": "zugemutet",
    "zugemutetem": "zugemutet",
    "zugemuteten": "zugemutet",
    "zugemuteter": "zugemutet",
    "zugemutetes": "zugemutet",
    "zugenagelt": "zunageln",
    "zugenagelte": "zugenagelt",
    "zugenageltem": "zugenagelt",
    "zugenagelten": "zugenagelt",
    "zugenagelter": "zugenagelt",
    "zugenageltes": "zugenagelt",
    "zugeneigt": "zuneigen",
    "zugeneigte": "zugeneigt",
    "zugeneigtem": "zugeneigt",
    "zugeneigten": "zugeneigt",
    "zugeneigter": "zugeneigt",
    "zugeneigtere": "zugeneigt",
    "zugeneigterem": "zugeneigt",
    "zugeneigteren": "zugeneigt",
    "zugeneigterer": "zugeneigt",
    "zugeneigteres": "zugeneigt",
    "zugeneigtes": "zugeneigt",
    "zugeneigteste": "zugeneigt",
    "zugeneigtestem": "zugeneigt",
    "zugeneigtesten": "zugeneigt",
    "zugeneigtester": "zugeneigt",
    "zugeneigtestes": "zugeneigt",
    "zugenommen": "zunehmen",
    "zugenommene": "zugenommen",
    "zugenommenem": "zugenommen",
    "zugenommenen": "zugenommen",
    "zugenommener": "zugenommen",
    "zugenommenere": "zugenommen",
    "zugenommenerem": "zugenommen",
    "zugenommeneren": "zugenommen",
    "zugenommenerer": "zugenommen",
    "zugenommeneres": "zugenommen",
    "zugenommenes": "zugenommen",
    "zugenommenste": "zugenommen",
    "zugenommenstem": "zugenommen",
    "zugenommensten": "zugenommen",
    "zugenommenster": "zugenommen",
    "zugenommenstes": "zugenommen",
    "zugenäht": "zunähen",
    "zugenähte": "zugenäht",
    "zugenähtem": "zugenäht",
    "zugenähten": "zugenäht",
    "zugenähter": "zugenäht",
    "zugenähtes": "zugenäht",
    "zugeordnet": "zuordnen",
    "zugeordnete": "zugeordnet",
    "zugeordnetem": "zugeordnet",
    "zugeordneten": "zugeordnet",
    "zugeordneter": "zugeordnet",
    "zugeordnetes": "zugeordnet",
    "zugepackt": "zupacken",
    "zugepackte": "zugepackt",
    "zugepacktem": "zugepackt",
    "zugepackten": "zugepackt",
    "zugepackter": "zugepackt",
    "zugepacktes": "zugepackt",
    "zugepfropft": "zupfropfen",
    "zugepfropfte": "zugepfropft",
    "zugepfropftem": "zugepfropft",
    "zugepfropften": "zugepfropft",
    "zugepfropfter": "zugepfropft",
    "zugepfropftere": "zugepfropft",
    "zugepfropfterem": "zugepfropft",
    "zugepfropfteren": "zugepfropft",
    "zugepfropfterer": "zugepfropft",
    "zugepfropfteres": "zugepfropft",
    "zugepfropftes": "zugepfropft",
    "zugepfropfteste": "zugepfropft",
    "zugepfropftestem": "zugepfropft",
    "zugepfropftesten": "zugepfropft",
    "zugepfropftester": "zugepfropft",
    "zugepfropftestes": "zugepfropft",
    "zugeprostet": "zuprosten",
    "zugeprostete": "zugeprostet",
    "zugeprostetem": "zugeprostet",
    "zugeprosteten": "zugeprostet",
    "zugeprosteter": "zugeprostet",
    "zugeprostetes": "zugeprostet",
    "zugeraten": "zuraten",
    "zugeratene": "zugeraten",
    "zugeratenem": "zugeraten",
    "zugeratenen": "zugeraten",
    "zugeratener": "zugeraten",
    "zugeratenes": "zugeraten",
    "zugeraunt": "zuraunen",
    "zugeraunte": "zugeraunt",
    "zugerauntem": "zugeraunt",
    "zugeraunten": "zugeraunt",
    "zugeraunter": "zugeraunt",
    "zugerauntes": "zugeraunt",
    "zugerechnet": "zurechnen",
    "zugerechnete": "zugerechnet",
    "zugerechnetem": "zugerechnet",
    "zugerechneten": "zugerechnet",
    "zugerechneter": "zugerechnet",
    "zugerechnetes": "zugerechnet",
    "zugeredet": "zureden",
    "zugeredete": "zugeredet",
    "zugeredetem": "zugeredet",
    "zugeredeten": "zugeredet",
    "zugeredeter": "zugeredet",
    "zugeredetes": "zugeredet",
    "zugereicht": "zureichen",
    "zugereichte": "zugereicht",
    "zugereichtem": "zugereicht",
    "zugereichten": "zugereicht",
    "zugereichter": "zugereicht",
    "zugereichtes": "zugereicht",
    "zugereiste": "zugereist",
    "zugereistem": "zugereist",
    "zugereisten": "zugereist",
    "zugereister": "zugereist",
    "zugereistes": "zugereist",
    "zugerichtet": "zurichten",
    "zugerichtete": "zugerichtet",
    "zugerichtetem": "zugerichtet",
    "zugerichteten": "zugerichtet",
    "zugerichteter": "zugerichtet",
    "zugerichtetes": "zugerichtet",
    "zugeriegelt": "zuriegeln",
    "zugeriegelte": "zugeriegelt",
    "zugeriegeltem": "zugeriegelt",
    "zugeriegelten": "zugeriegelt",
    "zugeriegelter": "zugeriegelt",
    "zugeriegeltes": "zugeriegelt",
    "zugeritten": "zureiten",
    "zugerittene": "zugeritten",
    "zugerittenem": "zugeritten",
    "zugerittenen": "zugeritten",
    "zugerittener": "zugeritten",
    "zugerittenes": "zugeritten",
    "zugerollt": "zurollen",
    "zugerollte": "zugerollt",
    "zugerolltem": "zugerollt",
    "zugerollten": "zugerollt",
    "zugerollter": "zugerollt",
    "zugerolltes": "zugerollt",
    "zugerufen": "zurufen",
    "zugerufene": "zugerufen",
    "zugerufenem": "zugerufen",
    "zugerufenen": "zugerufen",
    "zugerufener": "zugerufen",
    "zugerufenes": "zugerufen",
    "zugerüstet": "zurüsten",
    "zugerüstete": "zugerüstet",
    "zugerüstetem": "zugerüstet",
    "zugerüsteten": "zugerüstet",
    "zugerüsteter": "zugerüstet",
    "zugerüstetes": "zugerüstet",
    "zugesagt": "zusagen",
    "zugesagte": "zugesagt",
    "zugesagtem": "zugesagt",
    "zugesagten": "zugesagt",
    "zugesagter": "zugesagt",
    "zugesagtes": "zugesagt",
    "zugesandt": "zusenden",
    "zugesandte": "zugesandt",
    "zugesandtem": "zugesandt",
    "zugesandten": "zugesandt",
    "zugesandter": "zugesandt",
    "zugesandtes": "zugesandt",
    "zugeschanzt": "zuschanzen",
    "zugeschanzte": "zugeschanzt",
    "zugeschanztem": "zugeschanzt",
    "zugeschanzten": "zugeschanzt",
    "zugeschanzter": "zugeschanzt",
    "zugeschanztes": "zugeschanzt",
    "zugeschaufelt": "zuschaufeln",
    "zugeschaufelte": "zugeschaufelt",
    "zugeschaufeltem": "zugeschaufelt",
    "zugeschaufelten": "zugeschaufelt",
    "zugeschaufelter": "zugeschaufelt",
    "zugeschaufeltes": "zugeschaufelt",
    "zugeschaut": "zuschauen",
    "zugeschaute": "zugeschaut",
    "zugeschautem": "zugeschaut",
    "zugeschauten": "zugeschaut",
    "zugeschauter": "zugeschaut",
    "zugeschautes": "zugeschaut",
    "zugeschlagen": "zuschlagen",
    "zugeschlagene": "zugeschlagen",
    "zugeschlagenem": "zugeschlagen",
    "zugeschlagenen": "zugeschlagen",
    "zugeschlagener": "zugeschlagen",
    "zugeschlagenes": "zugeschlagen",
    "zugeschlossen": "zuschließen",
    "zugeschlossene": "zugeschlossen",
    "zugeschlossenem": "zugeschlossen",
    "zugeschlossenen": "zugeschlossen",
    "zugeschlossener": "zugeschlossen",
    "zugeschlossenes": "zugeschlossen",
    "zugeschmissen": "zuschmeißen",
    "zugeschmissene": "zugeschmissen",
    "zugeschmissenem": "zugeschmissen",
    "zugeschmissenen": "zugeschmissen",
    "zugeschmissener": "zugeschmissen",
    "zugeschmissenes": "zugeschmissen",
    "zugeschnallt": "zuschnallen",
    "zugeschnallte": "zugeschnallt",
    "zugeschnalltem": "zugeschnallt",
    "zugeschnallten": "zugeschnallt",
    "zugeschnallter": "zugeschnallt",
    "zugeschnalltes": "zugeschnallt",
    "zugeschnappt": "zuschnappen",
    "zugeschnappte": "zugeschnappt",
    "zugeschnapptem": "zugeschnappt",
    "zugeschnappten": "zugeschnappt",
    "zugeschnappter": "zugeschnappt",
    "zugeschnapptes": "zugeschnappt",
    "zugeschneit": "zuschneien",
    "zugeschneite": "zugeschneit",
    "zugeschneitem": "zugeschneit",
    "zugeschneiten": "zugeschneit",
    "zugeschneiter": "zugeschneit",
    "zugeschneitere": "zugeschneit",
    "zugeschneiterem": "zugeschneit",
    "zugeschneiteren": "zugeschneit",
    "zugeschneiterer": "zugeschneit",
    "zugeschneiteres": "zugeschneit",
    "zugeschneites": "zugeschneit",
    "zugeschneiteste": "zugeschneit",
    "zugeschneitestem": "zugeschneit",
    "zugeschneitesten": "zugeschneit",
    "zugeschneitester": "zugeschneit",
    "zugeschneitestes": "zugeschneit",
    "zugeschnitten": "zuschneiden",
    "zugeschnittene": "zugeschnitten",
    "zugeschnittenem": "zugeschnitten",
    "zugeschnittenen": "zugeschnitten",
    "zugeschnittener": "zugeschnitten",
    "zugeschnittenes": "zugeschnitten",
    "zugeschnürt": "zuschnüren",
    "zugeschnürte": "zugeschnürt",
    "zugeschnürtem": "zugeschnürt",
    "zugeschnürten": "zugeschnürt",
    "zugeschnürter": "zugeschnürt",
    "zugeschnürtes": "zugeschnürt",
    "zugeschoben": "zuschieben",
    "zugeschobene": "zugeschoben",
    "zugeschobenem": "zugeschoben",
    "zugeschobenen": "zugeschoben",
    "zugeschobener": "zugeschoben",
    "zugeschobenes": "zugeschoben",
    "zugeschossen": "zuschießen",
    "zugeschossene": "zugeschossen",
    "zugeschossenem": "zugeschossen",
    "zugeschossenen": "zugeschossen",
    "zugeschossener": "zugeschossen",
    "zugeschossenes": "zugeschossen",
    "zugeschraubt": "zuschrauben",
    "zugeschraubte": "zugeschraubt",
    "zugeschraubtem": "zugeschraubt",
    "zugeschraubten": "zugeschraubt",
    "zugeschraubter": "zugeschraubt",
    "zugeschraubtes": "zugeschraubt",
    "zugeschrieben": "zuschreiben",
    "zugeschriebene": "zugeschrieben",
    "zugeschriebenem": "zugeschrieben",
    "zugeschriebenen": "zugeschrieben",
    "zugeschriebener": "zugeschrieben",
    "zugeschriebenes": "zugeschrieben",
    "zugeschustert": "zuschustern",
    "zugeschusterte": "zugeschustert",
    "zugeschustertem": "zugeschustert",
    "zugeschusterten": "zugeschustert",
    "zugeschusterter": "zugeschustert",
    "zugeschustertes": "zugeschustert",
    "zugeschüttet": "zuschütten",
    "zugeschüttete": "zugeschüttet",
    "zugeschüttetem": "zugeschüttet",
    "zugeschütteten": "zugeschüttet",
    "zugeschütteter": "zugeschüttet",
    "zugeschüttetere": "zugeschüttet",
    "zugeschütteterem": "zugeschüttet",
    "zugeschütteteren": "zugeschüttet",
    "zugeschütteterer": "zugeschüttet",
    "zugeschütteteres": "zugeschüttet",
    "zugeschüttetes": "zugeschüttet",
    "zugeschütteteste": "zugeschüttet",
    "zugeschüttetestem": "zugeschüttet",
    "zugeschüttetesten": "zugeschüttet",
    "zugeschüttetester": "zugeschüttet",
    "zugeschüttetestes": "zugeschüttet",
    "zugesehen": "zusehen",
    "zugesehene": "zugesehen",
    "zugesehenem": "zugesehen",
    "zugesehenen": "zugesehen",
    "zugesehener": "zugesehen",
    "zugesehenes": "zugesehen",
    "zugeselle": "zugesellen",
    "zugesellend": "zugesellen",
    "zugesellende": "zugesellend",
    "zugesellendem": "zugesellend",
    "zugesellenden": "zugesellend",
    "zugesellender": "zugesellend",
    "zugesellendes": "zugesellend",
    "zugesellest": "zugesellen",
    "zugesellet": "zugesellen",
    "zugesellst": "zugesellen",
    "zugesellt": "zugesellen",
    "zugesellte": "zugesellen",
    "zugeselltem": "zugesellt",
    "zugesellten": "zugesellen",
    "zugesellter": "zugesellt",
    "zugeselltes": "zugesellt",
    "zugeselltest": "zugesellen",
    "zugeselltet": "zugesellen",
    "zugesendet": "zusenden",
    "zugesendete": "zugesendet",
    "zugesendetem": "zugesendet",
    "zugesendeten": "zugesendet",
    "zugesendeter": "zugesendet",
    "zugesendetes": "zugesendet",
    "zugesessen": "zusitzen",
    "zugesessene": "zugesessen",
    "zugesessenem": "zugesessen",
    "zugesessenen": "zugesessen",
    "zugesessener": "zugesessen",
    "zugesessenes": "zugesessen",
    "zugesetzt": "zusetzen",
    "zugesetzte": "zugesetzt",
    "zugesetztem": "zugesetzt",
    "zugesetzten": "zugesetzt",
    "zugesetzter": "zugesetzt",
    "zugesetztes": "zugesetzt",
    "zugesichert": "zusichern",
    "zugesicherte": "zugesichert",
    "zugesichertem": "zugesichert",
    "zugesicherten": "zugesichert",
    "zugesicherter": "zugesichert",
    "zugesichertes": "zugesichert",
    "zugesperrt": "zusperren",
    "zugesperrte": "zugesperrt",
    "zugesperrtem": "zugesperrt",
    "zugesperrten": "zugesperrt",
    "zugesperrter": "zugesperrt",
    "zugesperrtes": "zugesperrt",
    "zugespielt": "zuspielen",
    "zugespielte": "zugespielt",
    "zugespieltem": "zugespielt",
    "zugespielten": "zugespielt",
    "zugespielter": "zugespielt",
    "zugespieltes": "zugespielt",
    "zugespitzt": "zuspitzen",
    "zugespitzte": "zugespitzt",
    "zugespitztem": "zugespitzt",
    "zugespitzten": "zugespitzt",
    "zugespitzter": "zugespitzt",
    "zugespitztes": "zugespitzt",
    "zugesprochen": "zusprechen",
    "zugesprochene": "zugesprochen",
    "zugesprochenem": "zugesprochen",
    "zugesprochenen": "zugesprochen",
    "zugesprochener": "zugesprochen",
    "zugesprochenes": "zugesprochen",
    "zugesprungen": "zuspringen",
    "zugesprungene": "zugesprungen",
    "zugesprungenem": "zugesprungen",
    "zugesprungenen": "zugesprungen",
    "zugesprungener": "zugesprungen",
    "zugesprungenes": "zugesprungen",
    "zugestand": "zugestehen",
    "zugestanden": "zustehen",
    "zugestandene": "zugestanden",
    "zugestandenem": "zugestanden",
    "zugestandenen": "zugestanden",
    "zugestandener": "zugestanden",
    "zugestandenere": "zugestanden",
    "zugestandenerem": "zugestanden",
    "zugestandeneren": "zugestanden",
    "zugestandenerer": "zugestanden",
    "zugestandeneres": "zugestanden",
    "zugestandenes": "zugestanden",
    "zugestandenste": "zugestanden",
    "zugestandenstem": "zugestanden",
    "zugestandensten": "zugestanden",
    "zugestandenster": "zugestanden",
    "zugestandenstes": "zugestanden",
    "zugestandest": "zugestehen",
    "zugestandet": "zugestehen",
    "zugesteckt": "zustecken",
    "zugesteckte": "zugesteckt",
    "zugestecktem": "zugesteckt",
    "zugesteckten": "zugesteckt",
    "zugesteckter": "zugesteckt",
    "zugestecktes": "zugesteckt",
    "zugestehe": "zugestehen",
    "zugestehend": "zugestehen",
    "zugestehende": "zugestehend",
    "zugestehendem": "zugestehend",
    "zugestehenden": "zugestehend",
    "zugestehender": "zugestehend",
    "zugestehendere": "zugestehend",
    "zugestehenderem": "zugestehend",
    "zugestehenderen": "zugestehend",
    "zugestehenderer": "zugestehend",
    "zugestehenderes": "zugestehend",
    "zugestehendes": "zugestehend",
    "zugestehendste": "zugestehend",
    "zugestehendstem": "zugestehend",
    "zugestehendsten": "zugestehend",
    "zugestehendster": "zugestehend",
    "zugestehendstes": "zugestehend",
    "zugestehest": "zugestehen",
    "zugestehet": "zugestehen",
    "zugestehst": "zugestehen",
    "zugesteht": "zugestehen",
    "zugestellt": "zustellen",
    "zugestellte": "zugestellt",
    "zugestelltem": "zugestellt",
    "zugestellten": "zugestellt",
    "zugestellter": "zugestellt",
    "zugestelltes": "zugestellt",
    "zugesteuert": "zusteuern",
    "zugesteuerte": "zugesteuert",
    "zugesteuertem": "zugesteuert",
    "zugesteuerten": "zugesteuert",
    "zugesteuerter": "zugesteuert",
    "zugesteuertes": "zugesteuert",
    "zugestiegen": "zusteigen",
    "zugestiegene": "zugestiegen",
    "zugestiegenem": "zugestiegen",
    "zugestiegenen": "zugestiegen",
    "zugestiegener": "zugestiegen",
    "zugestiegenes": "zugestiegen",
    "zugestimmt": "zustimmen",
    "zugestimmte": "zugestimmt",
    "zugestimmtem": "zugestimmt",
    "zugestimmten": "zugestimmt",
    "zugestimmter": "zugestimmt",
    "zugestimmtes": "zugestimmt",
    "zugestochen": "zustechen",
    "zugestochene": "zugestochen",
    "zugestochenem": "zugestochen",
    "zugestochenen": "zugestochen",
    "zugestochener": "zugestochen",
    "zugestochenes": "zugestochen",
    "zugestopft": "zustopfen",
    "zugestopfte": "zugestopft",
    "zugestopftem": "zugestopft",
    "zugestopften": "zugestopft",
    "zugestopfter": "zugestopft",
    "zugestopftere": "zugestopft",
    "zugestopfterem": "zugestopft",
    "zugestopfteren": "zugestopft",
    "zugestopfterer": "zugestopft",
    "zugestopfteres": "zugestopft",
    "zugestopftes": "zugestopft",
    "zugestopfteste": "zugestopft",
    "zugestopftestem": "zugestopft",
    "zugestopftesten": "zugestopft",
    "zugestopftester": "zugestopft",
    "zugestopftestes": "zugestopft",
    "zugestoßen": "zustoßen",
    "zugestoßene": "zugestoßen",
    "zugestoßenem": "zugestoßen",
    "zugestoßenen": "zugestoßen",
    "zugestoßener": "zugestoßen",
    "zugestoßenes": "zugestoßen",
    "zugestrebt": "zustreben",
    "zugestrebte": "zugestrebt",
    "zugestrebtem": "zugestrebt",
    "zugestrebten": "zugestrebt",
    "zugestrebter": "zugestrebt",
    "zugestrebtes": "zugestrebt",
    "zugeströmt": "zuströmen",
    "zugeströmte": "zugeströmt",
    "zugeströmtem": "zugeströmt",
    "zugeströmten": "zugeströmt",
    "zugeströmter": "zugeströmt",
    "zugeströmtes": "zugeströmt",
    "zugestutzt": "zustutzen",
    "zugestutzte": "zugestutzt",
    "zugestutztem": "zugestutzt",
    "zugestutzten": "zugestutzt",
    "zugestutzter": "zugestutzt",
    "zugestutztes": "zugestutzt",
    "zugestände": "zugestehen",
    "zugeständen": "zugestehen",
    "zugeständest": "zugestehen",
    "zugeständet": "zugestehen",
    "zugestöpselt": "zustöpseln",
    "zugestöpselte": "zugestöpselt",
    "zugestöpseltem": "zugestöpselt",
    "zugestöpselten": "zugestöpselt",
    "zugestöpselter": "zugestöpselt",
    "zugestöpseltes": "zugestöpselt",
    "zugestürzt": "zustürzen",
    "zugestürzte": "zugestürzt",
    "zugestürztem": "zugestürzt",
    "zugestürzten": "zugestürzt",
    "zugestürzter": "zugestürzt",
    "zugestürztes": "zugestürzt",
    "zugeteilt": "zuteilen",
    "zugeteilte": "zugeteilt",
    "zugeteiltem": "zugeteilt",
    "zugeteilten": "zugeteilt",
    "zugeteilter": "zugeteilt",
    "zugeteiltes": "zugeteilt",
    "zugetragen": "zutragen",
    "zugetragene": "zugetragen",
    "zugetragenem": "zugetragen",
    "zugetragenen": "zugetragen",
    "zugetragener": "zugetragen",
    "zugetragenes": "zugetragen",
    "zugetraut": "zutrauen",
    "zugetraute": "zugetraut",
    "zugetrautem": "zugetraut",
    "zugetrauten": "zugetraut",
    "zugetrauter": "zugetraut",
    "zugetrautes": "zugetraut",
    "zugetrieben": "zutreiben",
    "zugetriebene": "zugetrieben",
    "zugetriebenem": "zugetrieben",
    "zugetriebenen": "zugetrieben",
    "zugetriebener": "zugetrieben",
    "zugetriebenes": "zugetrieben",
    "zugetroffen": "zutreffen",
    "zugetroffene": "zugetroffen",
    "zugetroffenem": "zugetroffen",
    "zugetroffenen": "zugetroffen",
    "zugetroffener": "zugetroffen",
    "zugetroffenes": "zugetroffen",
    "zugetrunken": "zutrinken",
    "zugetrunkene": "zugetrunken",
    "zugetrunkenem": "zugetrunken",
    "zugetrunkenen": "zugetrunken",
    "zugetrunkener": "zugetrunken",
    "zugetrunkenes": "zugetrunken",
    "zugewandert": "zuwandern",
    "zugewanderte": "zugewandert",
    "zugewandertem": "zugewandert",
    "zugewanderten": "zugewandert",
    "zugewanderter": "zugewandert",
    "zugewandertes": "zugewandert",
    "zugewandt": "zuwenden",
    "zugeweht": "zuwehen",
    "zugewehte": "zugeweht",
    "zugewehtem": "zugeweht",
    "zugewehten": "zugeweht",
    "zugewehter": "zugeweht",
    "zugewehtere": "zugeweht",
    "zugewehterem": "zugeweht",
    "zugewehteren": "zugeweht",
    "zugewehterer": "zugeweht",
    "zugewehteres": "zugeweht",
    "zugewehtes": "zugeweht",
    "zugewehteste": "zugeweht",
    "zugewehtestem": "zugeweht",
    "zugewehtesten": "zugeweht",
    "zugewehtester": "zugeweht",
    "zugewehtestes": "zugeweht",
    "zugewendet": "zuwenden",
    "zugewendete": "zugewendet",
    "zugewendetem": "zugewendet",
    "zugewendeten": "zugewendet",
    "zugewendeter": "zugewendet",
    "zugewendetes": "zugewendet",
    "zugewiesen": "zuweisen",
    "zugewiesene": "zugewiesen",
    "zugewiesenem": "zugewiesen",
    "zugewiesenen": "zugewiesen",
    "zugewiesener": "zugewiesen",
    "zugewiesenes": "zugewiesen",
    "zugewinkt": "zuwinken",
    "zugewinkte": "zugewinkt",
    "zugewinktem": "zugewinkt",
    "zugewinkten": "zugewinkt",
    "zugewinkter": "zugewinkt",
    "zugewinktes": "zugewinkt",
    "zugeworfen": "zuwerfen",
    "zugeworfene": "zugeworfen",
    "zugeworfenem": "zugeworfen",
    "zugeworfenen": "zugeworfen",
    "zugeworfener": "zugeworfen",
    "zugeworfenes": "zugeworfen",
    "zugezahlt": "zuzahlen",
    "zugezahlte": "zugezahlt",
    "zugezahltem": "zugezahlt",
    "zugezahlten": "zugezahlt",
    "zugezahlter": "zugezahlt",
    "zugezahltes": "zugezahlt",
    "zugezogen": "zuziehen",
    "zugezogene": "zugezogen",
    "zugezogenem": "zugezogen",
    "zugezogenen": "zugezogen",
    "zugezogener": "zugezogen",
    "zugezogenes": "zugezogen",
    "zugezwinkert": "zuzwinkern",
    "zugezwinkerte": "zugezwinkert",
    "zugezwinkertem": "zugezwinkert",
    "zugezwinkerten": "zugezwinkert",
    "zugezwinkerter": "zugezwinkert",
    "zugezwinkertes": "zugezwinkert",
    "zugezählt": "zuzählen",
    "zugezähltem": "zugezählt",
    "zugezählter": "zugezählt",
    "zugezähltes": "zugezählt",
    "zugibst": "zugeben",
    "zugibt": "zugeben",
    "zugieße": "zugießen",
    "zugießend": "zugießen",
    "zugießende": "zugießend",
    "zugießendem": "zugießend",
    "zugießenden": "zugießend",
    "zugießender": "zugießend",
    "zugießendes": "zugießend",
    "zugießest": "zugießen",
    "zugießet": "zugießen",
    "zugießt": "zugießen",
    "zuging": "zugehen",
    "zuginge": "zugehen",
    "zugingen": "zugehen",
    "zugingest": "zugehen",
    "zuginget": "zugehen",
    "zugingst": "zugehen",
    "zugingt": "zugehen",
    "zugkräftige": "zugkräftig",
    "zugkräftigem": "zugkräftig",
    "zugkräftigen": "zugkräftig",
    "zugkräftiger": "zugkräftig",
    "zugkräftigere": "zugkräftig",
    "zugkräftigerem": "zugkräftig",
    "zugkräftigeren": "zugkräftig",
    "zugkräftigerer": "zugkräftig",
    "zugkräftigeres": "zugkräftig",
    "zugkräftiges": "zugkräftig",
    "zugkräftigste": "zugkräftig",
    "zugkräftigstem": "zugkräftig",
    "zugkräftigsten": "zugkräftig",
    "zugkräftigster": "zugkräftig",
    "zugkräftigstes": "zugkräftig",
    "zugossen": "zugießen",
    "zugoß": "zugießen",
    "zugoßt": "zugießen",
    "zugreife": "zugreifen",
    "zugreifend": "zugreifen",
    "zugreifende": "zugreifend",
    "zugreifendem": "zugreifend",
    "zugreifenden": "zugreifend",
    "zugreifender": "zugreifend",
    "zugreifendere": "zugreifend",
    "zugreifenderem": "zugreifend",
    "zugreifenderen": "zugreifend",
    "zugreifenderer": "zugreifend",
    "zugreifenderes": "zugreifend",
    "zugreifendes": "zugreifend",
    "zugreifendste": "zugreifend",
    "zugreifendstem": "zugreifend",
    "zugreifendsten": "zugreifend",
    "zugreifendster": "zugreifend",
    "zugreifendstes": "zugreifend",
    "zugreifest": "zugreifen",
    "zugreifet": "zugreifen",
    "zugreifst": "zugreifen",
    "zugreift": "zugreifen",
    "zugriff": "zugreifen",
    "zugriffe": "zugreifen",
    "zugriffen": "zugreifen",
    "zugriffest": "zugreifen",
    "zugriffet": "zugreifen",
    "zugriffsbereite": "zugriffsbereit",
    "zugriffsbereitem": "zugriffsbereit",
    "zugriffsbereiten": "zugriffsbereit",
    "zugriffsbereiter": "zugriffsbereit",
    "zugriffsbereitere": "zugriffsbereit",
    "zugriffsbereiterem": "zugriffsbereit",
    "zugriffsbereiteren": "zugriffsbereit",
    "zugriffsbereiterer": "zugriffsbereit",
    "zugriffsbereiteres": "zugriffsbereit",
    "zugriffsbereites": "zugriffsbereit",
    "zugriffsbereiteste": "zugriffsbereit",
    "zugriffsbereitestem": "zugriffsbereit",
    "zugriffsbereitesten": "zugriffsbereit",
    "zugriffsbereitester": "zugriffsbereit",
    "zugriffsbereitestes": "zugriffsbereit",
    "zugriffst": "zugreifen",
    "zugrifft": "zugreifen",
    "zugäbe": "zugeben",
    "zugäben": "zugeben",
    "zugäbest": "zugeben",
    "zugäbet": "zugeben",
    "zugänglichem": "zugänglich",
    "zugänglichen": "zugänglich",
    "zugänglicher": "zugänglich",
    "zugänglichere": "zugänglich",
    "zugänglicherem": "zugänglich",
    "zugänglicheren": "zugänglich",
    "zugänglicherer": "zugänglich",
    "zugänglicheres": "zugänglich",
    "zugängliches": "zugänglich",
    "zugänglichste": "zugänglich",
    "zugänglichstem": "zugänglich",
    "zugänglichsten": "zugänglich",
    "zugänglichster": "zugänglich",
    "zugänglichstes": "zugänglich",
    "zugösse": "zugießen",
    "zugössen": "zugießen",
    "zugössest": "zugießen",
    "zugösset": "zugießen",
    "zuhake": "zuhaken",
    "zuhakend": "zuhaken",
    "zuhakende": "zuhakend",
    "zuhakendem": "zuhakend",
    "zuhakenden": "zuhakend",
    "zuhakender": "zuhakend",
    "zuhakendes": "zuhakend",
    "zuhakest": "zuhaken",
    "zuhaket": "zuhaken",
    "zuhakst": "zuhaken",
    "zuhakt": "zuhaken",
    "zuhakte": "zuhaken",
    "zuhakten": "zuhaken",
    "zuhaktest": "zuhaken",
    "zuhaktet": "zuhaken",
    "zuhalte": "zuhalten",
    "zuhaltend": "zuhalten",
    "zuhaltende": "zuhaltend",
    "zuhaltendem": "zuhaltend",
    "zuhaltenden": "zuhaltend",
    "zuhaltender": "zuhaltend",
    "zuhaltendes": "zuhaltend",
    "zuhaltest": "zuhalten",
    "zuhaltet": "zuhalten",
    "zuhaue": "zuhauen",
    "zuhauend": "zuhauen",
    "zuhauende": "zuhauend",
    "zuhauendem": "zuhauend",
    "zuhauenden": "zuhauend",
    "zuhauender": "zuhauend",
    "zuhauendes": "zuhauend",
    "zuhauest": "zuhauen",
    "zuhauet": "zuhauen",
    "zuhaust": "zuhauen",
    "zuhaut": "zuhauen",
    "zuhaute": "zuhauen",
    "zuhauten": "zuhauen",
    "zuhautest": "zuhauen",
    "zuhautet": "zuhauen",
    "zuheile": "zuheilen",
    "zuheilend": "zuheilen",
    "zuheilende": "zuheilend",
    "zuheilendem": "zuheilend",
    "zuheilenden": "zuheilend",
    "zuheilender": "zuheilend",
    "zuheilendere": "zuheilend",
    "zuheilenderem": "zuheilend",
    "zuheilenderen": "zuheilend",
    "zuheilenderer": "zuheilend",
    "zuheilenderes": "zuheilend",
    "zuheilendes": "zuheilend",
    "zuheilendste": "zuheilend",
    "zuheilendstem": "zuheilend",
    "zuheilendsten": "zuheilend",
    "zuheilendster": "zuheilend",
    "zuheilendstes": "zuheilend",
    "zuheilest": "zuheilen",
    "zuheilet": "zuheilen",
    "zuheilst": "zuheilen",
    "zuheilt": "zuheilen",
    "zuheilte": "zuheilen",
    "zuheilten": "zuheilen",
    "zuheiltest": "zuheilen",
    "zuheiltet": "zuheilen",
    "zuhielt": "zuhalten",
    "zuhielte": "zuhalten",
    "zuhielten": "zuhalten",
    "zuhieltest": "zuhalten",
    "zuhieltet": "zuhalten",
    "zuhing": "zuhängen",
    "zuhinge": "zuhängen",
    "zuhingen": "zuhängen",
    "zuhingest": "zuhängen",
    "zuhinget": "zuhängen",
    "zuhingst": "zuhängen",
    "zuhingt": "zuhängen",
    "zuhält": "zuhalten",
    "zuhältst": "zuhalten",
    "zuhänge": "zuhängen",
    "zuhängend": "zuhängen",
    "zuhängende": "zuhängend",
    "zuhängendem": "zuhängend",
    "zuhängenden": "zuhängend",
    "zuhängender": "zuhängend",
    "zuhängendes": "zuhängend",
    "zuhängest": "zuhängen",
    "zuhänget": "zuhängen",
    "zuhängst": "zuhängen",
    "zuhängt": "zuhängen",
    "zuhängte": "zuhängen",
    "zuhängten": "zuhängen",
    "zuhängtest": "zuhängen",
    "zuhängtet": "zuhängen",
    "zuhöre": "zuhören",
    "zuhörend": "zuhören",
    "zuhörende": "zuhörend",
    "zuhörendem": "zuhörend",
    "zuhörenden": "zuhörend",
    "zuhörender": "zuhörend",
    "zuhörendere": "zuhörend",
    "zuhörenderem": "zuhörend",
    "zuhörenderen": "zuhörend",
    "zuhörenderer": "zuhörend",
    "zuhörenderes": "zuhörend",
    "zuhörendes": "zuhörend",
    "zuhörendste": "zuhörend",
    "zuhörendstem": "zuhörend",
    "zuhörendsten": "zuhörend",
    "zuhörendster": "zuhörend",
    "zuhörendstes": "zuhörend",
    "zuhörest": "zuhören",
    "zuhöret": "zuhören",
    "zuhörst": "zuhören",
    "zuhört": "zuhören",
    "zuhörte": "zuhören",
    "zuhörten": "zuhören",
    "zuhörtest": "zuhören",
    "zuhörtet": "zuhören",
    "zujauchze": "zujauchzen",
    "zujauchzend": "zujauchzen",
    "zujauchzende": "zujauchzend",
    "zujauchzendem": "zujauchzend",
    "zujauchzenden": "zujauchzend",
    "zujauchzender": "zujauchzend",
    "zujauchzendere": "zujauchzend",
    "zujauchzenderem": "zujauchzend",
    "zujauchzenderen": "zujauchzend",
    "zujauchzenderer": "zujauchzend",
    "zujauchzenderes": "zujauchzend",
    "zujauchzendes": "zujauchzend",
    "zujauchzendste": "zujauchzend",
    "zujauchzendstem": "zujauchzend",
    "zujauchzendsten": "zujauchzend",
    "zujauchzendster": "zujauchzend",
    "zujauchzendstes": "zujauchzend",
    "zujauchzest": "zujauchzen",
    "zujauchzet": "zujauchzen",
    "zujauchzt": "zujauchzen",
    "zujauchzte": "zujauchzen",
    "zujauchzten": "zujauchzen",
    "zujauchztest": "zujauchzen",
    "zujauchztet": "zujauchzen",
    "zujubele": "zujubeln",
    "zujubelnd": "zujubeln",
    "zujubelnde": "zujubelnd",
    "zujubelndem": "zujubelnd",
    "zujubelnden": "zujubelnd",
    "zujubelnder": "zujubelnd",
    "zujubelndere": "zujubelnd",
    "zujubelnderem": "zujubelnd",
    "zujubelnderen": "zujubelnd",
    "zujubelnderer": "zujubelnd",
    "zujubelnderes": "zujubelnd",
    "zujubelndes": "zujubelnd",
    "zujubelndste": "zujubelnd",
    "zujubelndstem": "zujubelnd",
    "zujubelndsten": "zujubelnd",
    "zujubelndster": "zujubelnd",
    "zujubelndstes": "zujubelnd",
    "zujubelst": "zujubeln",
    "zujubelt": "zujubeln",
    "zujubelte": "zujubeln",
    "zujubelten": "zujubeln",
    "zujubeltest": "zujubeln",
    "zujubeltet": "zujubeln",
    "zujuble": "zujubeln",
    "zukam": "zukommen",
    "zukamen": "zukommen",
    "zukamst": "zukommen",
    "zukamt": "zukommen",
    "zukehre": "zukehren",
    "zukehrend": "zukehren",
    "zukehrende": "zukehrend",
    "zukehrendem": "zukehrend",
    "zukehrenden": "zukehrend",
    "zukehrender": "zukehrend",
    "zukehrendes": "zukehrend",
    "zukehrest": "zukehren",
    "zukehret": "zukehren",
    "zukehrst": "zukehren",
    "zukehrt": "zukehren",
    "zukehrte": "zukehren",
    "zukehrten": "zukehren",
    "zukehrtest": "zukehren",
    "zukehrtet": "zukehren",
    "zuklappe": "zuklappen",
    "zuklappend": "zuklappen",
    "zuklappende": "zuklappend",
    "zuklappendem": "zuklappend",
    "zuklappenden": "zuklappend",
    "zuklappender": "zuklappend",
    "zuklappendes": "zuklappend",
    "zuklappest": "zuklappen",
    "zuklappet": "zuklappen",
    "zuklappst": "zuklappen",
    "zuklappt": "zuklappen",
    "zuklappte": "zuklappen",
    "zuklappten": "zuklappen",
    "zuklapptest": "zuklappen",
    "zuklapptet": "zuklappen",
    "zuklebe": "zukleben",
    "zuklebend": "zukleben",
    "zuklebende": "zuklebend",
    "zuklebendem": "zuklebend",
    "zuklebenden": "zuklebend",
    "zuklebender": "zuklebend",
    "zuklebendes": "zuklebend",
    "zuklebest": "zukleben",
    "zuklebet": "zukleben",
    "zuklebst": "zukleben",
    "zuklebt": "zukleben",
    "zuklebte": "zukleben",
    "zuklebten": "zukleben",
    "zuklebtest": "zukleben",
    "zuklebtet": "zukleben",
    "zuklinke": "zuklinken",
    "zuklinkend": "zuklinken",
    "zuklinkende": "zuklinkend",
    "zuklinkendem": "zuklinkend",
    "zuklinkenden": "zuklinkend",
    "zuklinkender": "zuklinkend",
    "zuklinkendes": "zuklinkend",
    "zuklinkest": "zuklinken",
    "zuklinket": "zuklinken",
    "zuklinkst": "zuklinken",
    "zuklinkt": "zuklinken",
    "zuklinkte": "zuklinken",
    "zuklinkten": "zuklinken",
    "zuklinktest": "zuklinken",
    "zuklinktet": "zuklinken",
    "zuknalle": "zuknallen",
    "zuknallend": "zuknallen",
    "zuknallende": "zuknallend",
    "zuknallendem": "zuknallend",
    "zuknallenden": "zuknallend",
    "zuknallender": "zuknallend",
    "zuknallendes": "zuknallend",
    "zuknallest": "zuknallen",
    "zuknallet": "zuknallen",
    "zuknallst": "zuknallen",
    "zuknallt": "zuknallen",
    "zuknallte": "zuknallen",
    "zuknallten": "zuknallen",
    "zuknalltest": "zuknallen",
    "zuknalltet": "zuknallen",
    "zuknöpfe": "zuknöpfen",
    "zuknöpfend": "zuknöpfen",
    "zuknöpfende": "zuknöpfend",
    "zuknöpfendem": "zuknöpfend",
    "zuknöpfenden": "zuknöpfend",
    "zuknöpfender": "zuknöpfend",
    "zuknöpfendes": "zuknöpfend",
    "zuknöpfest": "zuknöpfen",
    "zuknöpfet": "zuknöpfen",
    "zuknöpfst": "zuknöpfen",
    "zuknöpft": "zuknöpfen",
    "zuknöpfte": "zuknöpfen",
    "zuknöpften": "zuknöpfen",
    "zuknöpftest": "zuknöpfen",
    "zuknöpftet": "zuknöpfen",
    "zukomme": "zukommen",
    "zukommend": "zukommen",
    "zukommende": "zukommend",
    "zukommendem": "zukommend",
    "zukommenden": "zukommend",
    "zukommender": "zukommend",
    "zukommendes": "zukommend",
    "zukommest": "zukommen",
    "zukommet": "zukommen",
    "zukommst": "zukommen",
    "zukommt": "zukommen",
    "zukorke": "zukorken",
    "zukorkend": "zukorken",
    "zukorkende": "zukorkend",
    "zukorkendem": "zukorkend",
    "zukorkenden": "zukorkend",
    "zukorkender": "zukorkend",
    "zukorkendes": "zukorkend",
    "zukorkest": "zukorken",
    "zukorket": "zukorken",
    "zukorkst": "zukorken",
    "zukorkt": "zukorken",
    "zukorkte": "zukorken",
    "zukorkten": "zukorken",
    "zukorktest": "zukorken",
    "zukorktet": "zukorken",
    "zukriege": "zukriegen",
    "zukriegend": "zukriegen",
    "zukriegende": "zukriegend",
    "zukriegendem": "zukriegend",
    "zukriegenden": "zukriegend",
    "zukriegender": "zukriegend",
    "zukriegendes": "zukriegend",
    "zukriegest": "zukriegen",
    "zukrieget": "zukriegen",
    "zukriegst": "zukriegen",
    "zukriegt": "zukriegen",
    "zukriegte": "zukriegen",
    "zukriegten": "zukriegen",
    "zukriegtest": "zukriegen",
    "zukriegtet": "zukriegen",
    "zukunftsträchtige": "zukunftsträchtig",
    "zukunftsträchtigem": "zukunftsträchtig",
    "zukunftsträchtigen": "zukunftsträchtig",
    "zukunftsträchtiger": "zukunftsträchtig",
    "zukunftsträchtigere": "zukunftsträchtig",
    "zukunftsträchtigerem": "zukunftsträchtig",
    "zukunftsträchtigeren": "zukunftsträchtig",
    "zukunftsträchtigerer": "zukunftsträchtig",
    "zukunftsträchtigeres": "zukunftsträchtig",
    "zukunftsträchtiges": "zukunftsträchtig",
    "zukunftsträchtigste": "zukunftsträchtig",
    "zukunftsträchtigstem": "zukunftsträchtig",
    "zukunftsträchtigsten": "zukunftsträchtig",
    "zukunftsträchtigster": "zukunftsträchtig",
    "zukunftsträchtigstes": "zukunftsträchtig",
    "zukäme": "zukommen",
    "zukämen": "zukommen",
    "zukämest": "zukommen",
    "zukämet": "zukommen",
    "zukünftige": "zukünftig",
    "zukünftigem": "zukünftig",
    "zukünftigen": "zukünftig",
    "zukünftiger": "zukünftig",
    "zukünftiges": "zukünftig",
    "zulache": "zulachen",
    "zulachend": "zulachen",
    "zulachende": "zulachend",
    "zulachendem": "zulachend",
    "zulachenden": "zulachend",
    "zulachender": "zulachend",
    "zulachendes": "zulachend",
    "zulachest": "zulachen",
    "zulachet": "zulachen",
    "zulachst": "zulachen",
    "zulacht": "zulachen",
    "zulachte": "zulachen",
    "zulachten": "zulachen",
    "zulachtest": "zulachen",
    "zulachtet": "zulachen",
    "zulade": "zuladen",
    "zuladend": "zuladen",
    "zuladende": "zuladend",
    "zuladendem": "zuladend",
    "zuladenden": "zuladend",
    "zuladender": "zuladend",
    "zuladendes": "zuladend",
    "zuladest": "zuladen",
    "zuladet": "zuladen",
    "zulange": "zulangen",
    "zulangend": "zulangen",
    "zulangende": "zulangend",
    "zulangendem": "zulangend",
    "zulangenden": "zulangend",
    "zulangender": "zulangend",
    "zulangendes": "zulangend",
    "zulangest": "zulangen",
    "zulanget": "zulangen",
    "zulangst": "zulangen",
    "zulangt": "zulangen",
    "zulangte": "zulangen",
    "zulangten": "zulangen",
    "zulangtest": "zulangen",
    "zulangtet": "zulangen",
    "zulasse": "zulassen",
    "zulassend": "zulassen",
    "zulassende": "zulassend",
    "zulassendem": "zulassend",
    "zulassenden": "zulassend",
    "zulassender": "zulassend",
    "zulassendes": "zulassend",
    "zulassest": "zulassen",
    "zulasset": "zulassen",
    "zulaufend": "zulaufen",
    "zulaufende": "zulaufend",
    "zulaufendem": "zulaufend",
    "zulaufenden": "zulaufend",
    "zulaufender": "zulaufend",
    "zulaufendes": "zulaufend",
    "zulaufest": "zulaufen",
    "zulaufet": "zulaufen",
    "zulauft": "zulaufen",
    "zulaßt": "zulassen",
    "zulege": "zulegen",
    "zulegend": "zulegen",
    "zulegende": "zulegend",
    "zulegendem": "zulegend",
    "zulegenden": "zulegend",
    "zulegender": "zulegend",
    "zulegendes": "zulegend",
    "zulegest": "zulegen",
    "zuleget": "zulegen",
    "zulegst": "zulegen",
    "zulegt": "zulegen",
    "zulegte": "zulegen",
    "zulegten": "zulegen",
    "zulegtest": "zulegen",
    "zulegtet": "zulegen",
    "zuleite": "zuleiten",
    "zuleitend": "zuleiten",
    "zuleitende": "zuleitend",
    "zuleitendem": "zuleitend",
    "zuleitenden": "zuleitend",
    "zuleitender": "zuleitend",
    "zuleitendes": "zuleitend",
    "zuleitest": "zuleiten",
    "zuleitet": "zuleiten",
    "zuleitete": "zuleiten",
    "zuleiteten": "zuleiten",
    "zuleitetest": "zuleiten",
    "zuleitetet": "zuleiten",
    "zulief": "zulaufen",
    "zuliefe": "zulaufen",
    "zuliefen": "zulaufen",
    "zuliefest": "zulaufen",
    "zuliefet": "zulaufen",
    "zuliefst": "zulaufen",
    "zulieft": "zulaufen",
    "zuließ": "zulassen",
    "zuließe": "zulassen",
    "zuließen": "zulassen",
    "zuließest": "zulassen",
    "zuließet": "zulassen",
    "zuließt": "zulassen",
    "zulud": "zuladen",
    "zuluden": "zuladen",
    "zuludest": "zuladen",
    "zuludet": "zuladen",
    "zulächele": "zulächeln",
    "zulächelnd": "zulächeln",
    "zulächelnde": "zulächelnd",
    "zulächelndem": "zulächelnd",
    "zulächelnden": "zulächelnd",
    "zulächelnder": "zulächelnd",
    "zulächelndere": "zulächelnd",
    "zulächelnderem": "zulächelnd",
    "zulächelnderen": "zulächelnd",
    "zulächelnderer": "zulächelnd",
    "zulächelnderes": "zulächelnd",
    "zulächelndes": "zulächelnd",
    "zulächelndste": "zulächelnd",
    "zulächelndstem": "zulächelnd",
    "zulächelndsten": "zulächelnd",
    "zulächelndster": "zulächelnd",
    "zulächelndstes": "zulächelnd",
    "zulächelst": "zulächeln",
    "zulächelt": "zulächeln",
    "zulächelte": "zulächeln",
    "zulächelten": "zulächeln",
    "zulächeltest": "zulächeln",
    "zulächeltet": "zulächeln",
    "zulächle": "zulächeln",
    "zulädst": "zuladen",
    "zulädt": "zuladen",
    "zulässige": "zulässig",
    "zulässigem": "zulässig",
    "zulässigen": "zulässig",
    "zulässiger": "zulässig",
    "zulässigere": "zulässig",
    "zulässigerem": "zulässig",
    "zulässigeren": "zulässig",
    "zulässigerer": "zulässig",
    "zulässigeres": "zulässig",
    "zulässiges": "zulässig",
    "zulässigste": "zulässig",
    "zulässigstem": "zulässig",
    "zulässigsten": "zulässig",
    "zulässigster": "zulässig",
    "zulässigstes": "zulässig",
    "zuläufst": "zulaufen",
    "zuläuft": "zulaufen",
    "zuläßt": "zulassen",
    "zulöte": "zulöten",
    "zulötend": "zulöten",
    "zulötende": "zulötend",
    "zulötendem": "zulötend",
    "zulötenden": "zulötend",
    "zulötender": "zulötend",
    "zulötendes": "zulötend",
    "zulötest": "zulöten",
    "zulötet": "zulöten",
    "zulötete": "zulöten",
    "zulöteten": "zulöten",
    "zulötetest": "zulöten",
    "zulötetet": "zulöten",
    "zulüde": "zuladen",
    "zulüden": "zuladen",
    "zulüdest": "zuladen",
    "zulüdet": "zuladen",
    "zumache": "zumachen",
    "zumachend": "zumachen",
    "zumachende": "zumachend",
    "zumachendem": "zumachend",
    "zumachenden": "zumachend",
    "zumachender": "zumachend",
    "zumachendes": "zumachend",
    "zumachest": "zumachen",
    "zumachet": "zumachen",
    "zumachst": "zumachen",
    "zumacht": "zumachen",
    "zumachte": "zumachen",
    "zumachten": "zumachen",
    "zumachtest": "zumachen",
    "zumachtet": "zumachen",
    "zumauere": "zumauern",
    "zumauernd": "zumauern",
    "zumauernde": "zumauernd",
    "zumauerndem": "zumauernd",
    "zumauernden": "zumauernd",
    "zumauernder": "zumauernd",
    "zumauerndere": "zumauernd",
    "zumauernderem": "zumauernd",
    "zumauernderen": "zumauernd",
    "zumauernderer": "zumauernd",
    "zumauernderes": "zumauernd",
    "zumauerndes": "zumauernd",
    "zumauerndste": "zumauernd",
    "zumauerndstem": "zumauernd",
    "zumauerndsten": "zumauernd",
    "zumauerndster": "zumauernd",
    "zumauerndstes": "zumauernd",
    "zumauerst": "zumauern",
    "zumauert": "zumauern",
    "zumauerte": "zumauern",
    "zumauerten": "zumauern",
    "zumauertest": "zumauern",
    "zumauertet": "zumauern",
    "zumaß": "zumessen",
    "zumaßen": "zumessen",
    "zumaßt": "zumessen",
    "zumesse": "zumessen",
    "zumessend": "zumessen",
    "zumessende": "zumessend",
    "zumessendem": "zumessend",
    "zumessenden": "zumessend",
    "zumessender": "zumessend",
    "zumessendes": "zumessend",
    "zumessest": "zumessen",
    "zumesset": "zumessen",
    "zumeßt": "zumessen",
    "zumißt": "zumessen",
    "zumute": "zumuten",
    "zumutend": "zumuten",
    "zumutende": "zumutend",
    "zumutendem": "zumutend",
    "zumutenden": "zumutend",
    "zumutender": "zumutend",
    "zumutendes": "zumutend",
    "zumutest": "zumuten",
    "zumutet": "zumuten",
    "zumutete": "zumuten",
    "zumuteten": "zumuten",
    "zumutetest": "zumuten",
    "zumutetet": "zumuten",
    "zumäße": "zumessen",
    "zumäßen": "zumessen",
    "zumäßest": "zumessen",
    "zumäßet": "zumessen",
    "zunagele": "zunageln",
    "zunagelnd": "zunageln",
    "zunagelnde": "zunagelnd",
    "zunagelndem": "zunagelnd",
    "zunagelnden": "zunagelnd",
    "zunagelnder": "zunagelnd",
    "zunagelndes": "zunagelnd",
    "zunagelst": "zunageln",
    "zunagelt": "zunageln",
    "zunagelte": "zunageln",
    "zunagelten": "zunageln",
    "zunageltest": "zunageln",
    "zunageltet": "zunageln",
    "zunagle": "zunageln",
    "zunahm": "zunehmen",
    "zunahmst": "zunehmen",
    "zunahmt": "zunehmen",
    "zunehme": "zunehmen",
    "zunehmend": "zunehmen",
    "zunehmende": "zunehmend",
    "zunehmendem": "zunehmend",
    "zunehmenden": "zunehmend",
    "zunehmender": "zunehmend",
    "zunehmendere": "zunehmend",
    "zunehmenderem": "zunehmend",
    "zunehmenderen": "zunehmend",
    "zunehmenderer": "zunehmend",
    "zunehmenderes": "zunehmend",
    "zunehmendes": "zunehmend",
    "zunehmendste": "zunehmend",
    "zunehmendstem": "zunehmend",
    "zunehmendsten": "zunehmend",
    "zunehmendster": "zunehmend",
    "zunehmendstes": "zunehmend",
    "zunehmest": "zunehmen",
    "zunehmet": "zunehmen",
    "zunehmt": "zunehmen",
    "zuneige": "zuneigen",
    "zuneigend": "zuneigen",
    "zuneigende": "zuneigend",
    "zuneigendem": "zuneigend",
    "zuneigenden": "zuneigend",
    "zuneigender": "zuneigend",
    "zuneigendere": "zuneigend",
    "zuneigenderem": "zuneigend",
    "zuneigenderen": "zuneigend",
    "zuneigenderer": "zuneigend",
    "zuneigenderes": "zuneigend",
    "zuneigendes": "zuneigend",
    "zuneigendste": "zuneigend",
    "zuneigendstem": "zuneigend",
    "zuneigendsten": "zuneigend",
    "zuneigendster": "zuneigend",
    "zuneigendstes": "zuneigend",
    "zuneigest": "zuneigen",
    "zuneiget": "zuneigen",
    "zuneigst": "zuneigen",
    "zuneigt": "zuneigen",
    "zuneigte": "zuneigen",
    "zuneigten": "zuneigen",
    "zuneigtest": "zuneigen",
    "zuneigtet": "zuneigen",
    "zunimmst": "zunehmen",
    "zunimmt": "zunehmen",
    "zunähe": "zunähen",
    "zunähend": "zunähen",
    "zunähende": "zunähend",
    "zunähendem": "zunähend",
    "zunähenden": "zunähend",
    "zunähender": "zunähend",
    "zunähendes": "zunähend",
    "zunähest": "zunähen",
    "zunähet": "zunähen",
    "zunähme": "zunehmen",
    "zunähmen": "zunehmen",
    "zunähmest": "zunehmen",
    "zunähmet": "zunehmen",
    "zunähst": "zunähen",
    "zunäht": "zunähen",
    "zunähte": "zunähen",
    "zunähten": "zunähen",
    "zunähtest": "zunähen",
    "zunähtet": "zunähen",
    "zuordne": "zuordnen",
    "zuordnend": "zuordnen",
    "zuordnende": "zuordnend",
    "zuordnendem": "zuordnend",
    "zuordnenden": "zuordnend",
    "zuordnender": "zuordnend",
    "zuordnendes": "zuordnend",
    "zuordnest": "zuordnen",
    "zuordnet": "zuordnen",
    "zuordnete": "zuordnen",
    "zuordneten": "zuordnen",
    "zuordnetest": "zuordnen",
    "zuordnetet": "zuordnen",
    "zupacke": "zupacken",
    "zupackend": "zupacken",
    "zupackende": "zupackend",
    "zupackendem": "zupackend",
    "zupackenden": "zupackend",
    "zupackender": "zupackend",
    "zupackendere": "zupackend",
    "zupackenderem": "zupackend",
    "zupackenderen": "zupackend",
    "zupackenderer": "zupackend",
    "zupackenderes": "zupackend",
    "zupackendes": "zupackend",
    "zupackendste": "zupackend",
    "zupackendstem": "zupackend",
    "zupackendsten": "zupackend",
    "zupackendster": "zupackend",
    "zupackendstes": "zupackend",
    "zupackest": "zupacken",
    "zupacket": "zupacken",
    "zupackst": "zupacken",
    "zupackt": "zupacken",
    "zupackte": "zupacken",
    "zupackten": "zupacken",
    "zupacktest": "zupacken",
    "zupacktet": "zupacken",
    "zupfe": "zupfen",
    "zupfend": "zupfen",
    "zupfende": "zupfend",
    "zupfendem": "zupfend",
    "zupfenden": "zupfend",
    "zupfender": "zupfend",
    "zupfendes": "zupfend",
    "zupfest": "zupfen",
    "zupfet": "zupfen",
    "zupfropfe": "zupfropfen",
    "zupfropfend": "zupfropfen",
    "zupfropfende": "zupfropfend",
    "zupfropfendem": "zupfropfend",
    "zupfropfenden": "zupfropfend",
    "zupfropfender": "zupfropfend",
    "zupfropfendere": "zupfropfend",
    "zupfropfenderem": "zupfropfend",
    "zupfropfenderen": "zupfropfend",
    "zupfropfenderer": "zupfropfend",
    "zupfropfenderes": "zupfropfend",
    "zupfropfendes": "zupfropfend",
    "zupfropfendste": "zupfropfend",
    "zupfropfendstem": "zupfropfend",
    "zupfropfendsten": "zupfropfend",
    "zupfropfendster": "zupfropfend",
    "zupfropfendstes": "zupfropfend",
    "zupfropfest": "zupfropfen",
    "zupfropfet": "zupfropfen",
    "zupfropfst": "zupfropfen",
    "zupfropft": "zupfropfen",
    "zupfropfte": "zupfropfen",
    "zupfropften": "zupfropfen",
    "zupfropftest": "zupfropfen",
    "zupfropftet": "zupfropfen",
    "zupfst": "zupfen",
    "zupft": "zupfen",
    "zupfte": "zupfen",
    "zupften": "zupfen",
    "zupftest": "zupfen",
    "zupftet": "zupfen",
    "zuproste": "zuprosten",
    "zuprostend": "zuprosten",
    "zuprostende": "zuprostend",
    "zuprostendem": "zuprostend",
    "zuprostenden": "zuprostend",
    "zuprostender": "zuprostend",
    "zuprostendes": "zuprostend",
    "zuprostest": "zuprosten",
    "zuprostet": "zuprosten",
    "zuprostete": "zuprosten",
    "zuprosteten": "zuprosten",
    "zuprostetest": "zuprosten",
    "zuprostetet": "zuprosten",
    "zurate": "zuraten",
    "zuratend": "zuraten",
    "zuratende": "zuratend",
    "zuratendem": "zuratend",
    "zuratenden": "zuratend",
    "zuratender": "zuratend",
    "zuratendes": "zuratend",
    "zuratest": "zuraten",
    "zuratet": "zuraten",
    "zuraune": "zuraunen",
    "zuraunend": "zuraunen",
    "zuraunende": "zuraunend",
    "zuraunendem": "zuraunend",
    "zuraunenden": "zuraunend",
    "zuraunender": "zuraunend",
    "zuraunendes": "zuraunend",
    "zuraunest": "zuraunen",
    "zuraunet": "zuraunen",
    "zuraunst": "zuraunen",
    "zuraunt": "zuraunen",
    "zuraunte": "zuraunen",
    "zuraunten": "zuraunen",
    "zurauntest": "zuraunen",
    "zurauntet": "zuraunen",
    "zurechne": "zurechnen",
    "zurechnend": "zurechnen",
    "zurechnende": "zurechnend",
    "zurechnendem": "zurechnend",
    "zurechnenden": "zurechnend",
    "zurechnender": "zurechnend",
    "zurechnendes": "zurechnend",
    "zurechnest": "zurechnen",
    "zurechnet": "zurechnen",
    "zurechnete": "zurechnen",
    "zurechneten": "zurechnen",
    "zurechnetest": "zurechnen",
    "zurechnetet": "zurechnen",
    "zurechnungsfähige": "zurechnungsfähig",
    "zurechnungsfähigem": "zurechnungsfähig",
    "zurechnungsfähigen": "zurechnungsfähig",
    "zurechnungsfähiger": "zurechnungsfähig",
    "zurechnungsfähigere": "zurechnungsfähig",
    "zurechnungsfähigerem": "zurechnungsfähig",
    "zurechnungsfähigeren": "zurechnungsfähig",
    "zurechnungsfähigerer": "zurechnungsfähig",
    "zurechnungsfähigeres": "zurechnungsfähig",
    "zurechnungsfähiges": "zurechnungsfähig",
    "zurechnungsfähigste": "zurechnungsfähig",
    "zurechnungsfähigstem": "zurechnungsfähig",
    "zurechnungsfähigsten": "zurechnungsfähig",
    "zurechnungsfähigster": "zurechnungsfähig",
    "zurechnungsfähigstes": "zurechnungsfähig",
    "zurechtbiege": "zurechtbiegen",
    "zurechtbiegend": "zurechtbiegen",
    "zurechtbiegende": "zurechtbiegend",
    "zurechtbiegendem": "zurechtbiegend",
    "zurechtbiegenden": "zurechtbiegend",
    "zurechtbiegender": "zurechtbiegend",
    "zurechtbiegendere": "zurechtbiegend",
    "zurechtbiegenderem": "zurechtbiegend",
    "zurechtbiegenderen": "zurechtbiegend",
    "zurechtbiegenderer": "zurechtbiegend",
    "zurechtbiegenderes": "zurechtbiegend",
    "zurechtbiegendes": "zurechtbiegend",
    "zurechtbiegendste": "zurechtbiegend",
    "zurechtbiegendstem": "zurechtbiegend",
    "zurechtbiegendsten": "zurechtbiegend",
    "zurechtbiegendster": "zurechtbiegend",
    "zurechtbiegendstes": "zurechtbiegend",
    "zurechtbiegest": "zurechtbiegen",
    "zurechtbieget": "zurechtbiegen",
    "zurechtbiegst": "zurechtbiegen",
    "zurechtbiegt": "zurechtbiegen",
    "zurechtbog": "zurechtbiegen",
    "zurechtbogen": "zurechtbiegen",
    "zurechtbogst": "zurechtbiegen",
    "zurechtbogt": "zurechtbiegen",
    "zurechtböge": "zurechtbiegen",
    "zurechtbögen": "zurechtbiegen",
    "zurechtbögest": "zurechtbiegen",
    "zurechtböget": "zurechtbiegen",
    "zurechtfand": "zurechtfinden",
    "zurechtfanden": "zurechtfinden",
    "zurechtfandest": "zurechtfinden",
    "zurechtfandet": "zurechtfinden",
    "zurechtfinde": "zurechtfinden",
    "zurechtfindend": "zurechtfinden",
    "zurechtfindende": "zurechtfindend",
    "zurechtfindendem": "zurechtfindend",
    "zurechtfindenden": "zurechtfindend",
    "zurechtfindender": "zurechtfindend",
    "zurechtfindendere": "zurechtfindend",
    "zurechtfindenderem": "zurechtfindend",
    "zurechtfindenderen": "zurechtfindend",
    "zurechtfindenderer": "zurechtfindend",
    "zurechtfindenderes": "zurechtfindend",
    "zurechtfindendes": "zurechtfindend",
    "zurechtfindendste": "zurechtfindend",
    "zurechtfindendstem": "zurechtfindend",
    "zurechtfindendsten": "zurechtfindend",
    "zurechtfindendster": "zurechtfindend",
    "zurechtfindendstes": "zurechtfindend",
    "zurechtfindest": "zurechtfinden",
    "zurechtfindet": "zurechtfinden",
    "zurechtfände": "zurechtfinden",
    "zurechtfänden": "zurechtfinden",
    "zurechtfändest": "zurechtfinden",
    "zurechtfändet": "zurechtfinden",
    "zurechtgebogen": "zurechtbiegen",
    "zurechtgebogene": "zurechtgebogen",
    "zurechtgebogenem": "zurechtgebogen",
    "zurechtgebogenen": "zurechtgebogen",
    "zurechtgebogener": "zurechtgebogen",
    "zurechtgebogenere": "zurechtgebogen",
    "zurechtgebogenerem": "zurechtgebogen",
    "zurechtgebogeneren": "zurechtgebogen",
    "zurechtgebogenerer": "zurechtgebogen",
    "zurechtgebogeneres": "zurechtgebogen",
    "zurechtgebogenes": "zurechtgebogen",
    "zurechtgebogenste": "zurechtgebogen",
    "zurechtgebogenstem": "zurechtgebogen",
    "zurechtgebogensten": "zurechtgebogen",
    "zurechtgebogenster": "zurechtgebogen",
    "zurechtgebogenstes": "zurechtgebogen",
    "zurechtgefunden": "zurechtfinden",
    "zurechtgefundene": "zurechtgefunden",
    "zurechtgefundenem": "zurechtgefunden",
    "zurechtgefundenen": "zurechtgefunden",
    "zurechtgefundener": "zurechtgefunden",
    "zurechtgefundenere": "zurechtgefunden",
    "zurechtgefundenerem": "zurechtgefunden",
    "zurechtgefundeneren": "zurechtgefunden",
    "zurechtgefundenerer": "zurechtgefunden",
    "zurechtgefundeneres": "zurechtgefunden",
    "zurechtgefundenes": "zurechtgefunden",
    "zurechtgefundenste": "zurechtgefunden",
    "zurechtgefundenstem": "zurechtgefunden",
    "zurechtgefundensten": "zurechtgefunden",
    "zurechtgefundenster": "zurechtgefunden",
    "zurechtgefundenstes": "zurechtgefunden",
    "zurechtgekommen": "zurechtkommen",
    "zurechtgekommene": "zurechtgekommen",
    "zurechtgekommenem": "zurechtgekommen",
    "zurechtgekommenen": "zurechtgekommen",
    "zurechtgekommener": "zurechtgekommen",
    "zurechtgekommenere": "zurechtgekommen",
    "zurechtgekommenerem": "zurechtgekommen",
    "zurechtgekommeneren": "zurechtgekommen",
    "zurechtgekommenerer": "zurechtgekommen",
    "zurechtgekommeneres": "zurechtgekommen",
    "zurechtgekommenes": "zurechtgekommen",
    "zurechtgekommenste": "zurechtgekommen",
    "zurechtgekommenstem": "zurechtgekommen",
    "zurechtgekommensten": "zurechtgekommen",
    "zurechtgekommenster": "zurechtgekommen",
    "zurechtgekommenstes": "zurechtgekommen",
    "zurechtgekriegt": "zurechtkriegen",
    "zurechtgekriegte": "zurechtgekriegt",
    "zurechtgekriegtem": "zurechtgekriegt",
    "zurechtgekriegten": "zurechtgekriegt",
    "zurechtgekriegter": "zurechtgekriegt",
    "zurechtgekriegtes": "zurechtgekriegt",
    "zurechtgelegt": "zurechtlegen",
    "zurechtgelegte": "zurechtgelegt",
    "zurechtgelegtem": "zurechtgelegt",
    "zurechtgelegten": "zurechtgelegt",
    "zurechtgelegter": "zurechtgelegt",
    "zurechtgelegtes": "zurechtgelegt",
    "zurechtgemacht": "zurechtmachen",
    "zurechtgemachte": "zurechtgemacht",
    "zurechtgemachtem": "zurechtgemacht",
    "zurechtgemachten": "zurechtgemacht",
    "zurechtgemachter": "zurechtgemacht",
    "zurechtgemachtere": "zurechtgemacht",
    "zurechtgemachterem": "zurechtgemacht",
    "zurechtgemachteren": "zurechtgemacht",
    "zurechtgemachterer": "zurechtgemacht",
    "zurechtgemachteres": "zurechtgemacht",
    "zurechtgemachtes": "zurechtgemacht",
    "zurechtgemachteste": "zurechtgemacht",
    "zurechtgemachtestem": "zurechtgemacht",
    "zurechtgemachtesten": "zurechtgemacht",
    "zurechtgemachtester": "zurechtgemacht",
    "zurechtgemachtestes": "zurechtgemacht",
    "zurechtgeschustert": "zurechtschustern",
    "zurechtgeschusterte": "zurechtgeschustert",
    "zurechtgeschustertem": "zurechtgeschustert",
    "zurechtgeschusterten": "zurechtgeschustert",
    "zurechtgeschusterter": "zurechtgeschustert",
    "zurechtgeschustertes": "zurechtgeschustert",
    "zurechtgesetzt": "zurechtsetzen",
    "zurechtgesetzte": "zurechtgesetzt",
    "zurechtgesetztem": "zurechtgesetzt",
    "zurechtgesetzten": "zurechtgesetzt",
    "zurechtgesetzter": "zurechtgesetzt",
    "zurechtgesetztes": "zurechtgesetzt",
    "zurechtgestutzt": "zurechtstutzen",
    "zurechtgestutzte": "zurechtgestutzt",
    "zurechtgestutztem": "zurechtgestutzt",
    "zurechtgestutzten": "zurechtgestutzt",
    "zurechtgestutzter": "zurechtgestutzt",
    "zurechtgestutztes": "zurechtgestutzt",
    "zurechtgewiesen": "zurechtweisen",
    "zurechtgewiesene": "zurechtgewiesen",
    "zurechtgewiesenem": "zurechtgewiesen",
    "zurechtgewiesenen": "zurechtgewiesen",
    "zurechtgewiesener": "zurechtgewiesen",
    "zurechtgewiesenere": "zurechtgewiesen",
    "zurechtgewiesenerem": "zurechtgewiesen",
    "zurechtgewieseneren": "zurechtgewiesen",
    "zurechtgewiesenerer": "zurechtgewiesen",
    "zurechtgewieseneres": "zurechtgewiesen",
    "zurechtgewiesenes": "zurechtgewiesen",
    "zurechtgewiesenste": "zurechtgewiesen",
    "zurechtgewiesenstem": "zurechtgewiesen",
    "zurechtgewiesensten": "zurechtgewiesen",
    "zurechtgewiesenster": "zurechtgewiesen",
    "zurechtgewiesenstes": "zurechtgewiesen",
    "zurechtgezimmert": "zurechtzimmern",
    "zurechtgezimmerte": "zurechtgezimmert",
    "zurechtgezimmertem": "zurechtgezimmert",
    "zurechtgezimmerten": "zurechtgezimmert",
    "zurechtgezimmerter": "zurechtgezimmert",
    "zurechtgezimmertes": "zurechtgezimmert",
    "zurechtkam": "zurechtkommen",
    "zurechtkamen": "zurechtkommen",
    "zurechtkamst": "zurechtkommen",
    "zurechtkamt": "zurechtkommen",
    "zurechtkomme": "zurechtkommen",
    "zurechtkommend": "zurechtkommen",
    "zurechtkommende": "zurechtkommend",
    "zurechtkommendem": "zurechtkommend",
    "zurechtkommenden": "zurechtkommend",
    "zurechtkommender": "zurechtkommend",
    "zurechtkommendere": "zurechtkommend",
    "zurechtkommenderem": "zurechtkommend",
    "zurechtkommenderen": "zurechtkommend",
    "zurechtkommenderer": "zurechtkommend",
    "zurechtkommenderes": "zurechtkommend",
    "zurechtkommendes": "zurechtkommend",
    "zurechtkommendste": "zurechtkommend",
    "zurechtkommendstem": "zurechtkommend",
    "zurechtkommendsten": "zurechtkommend",
    "zurechtkommendster": "zurechtkommend",
    "zurechtkommendstes": "zurechtkommend",
    "zurechtkommest": "zurechtkommen",
    "zurechtkommet": "zurechtkommen",
    "zurechtkommst": "zurechtkommen",
    "zurechtkommt": "zurechtkommen",
    "zurechtkriege": "zurechtkriegen",
    "zurechtkriegend": "zurechtkriegen",
    "zurechtkriegende": "zurechtkriegend",
    "zurechtkriegendem": "zurechtkriegend",
    "zurechtkriegenden": "zurechtkriegend",
    "zurechtkriegender": "zurechtkriegend",
    "zurechtkriegendes": "zurechtkriegend",
    "zurechtkriegest": "zurechtkriegen",
    "zurechtkrieget": "zurechtkriegen",
    "zurechtkriegst": "zurechtkriegen",
    "zurechtkriegt": "zurechtkriegen",
    "zurechtkriegte": "zurechtkriegen",
    "zurechtkriegten": "zurechtkriegen",
    "zurechtkriegtest": "zurechtkriegen",
    "zurechtkriegtet": "zurechtkriegen",
    "zurechtkäme": "zurechtkommen",
    "zurechtkämen": "zurechtkommen",
    "zurechtkämest": "zurechtkommen",
    "zurechtkämet": "zurechtkommen",
    "zurechtlege": "zurechtlegen",
    "zurechtlegend": "zurechtlegen",
    "zurechtlegende": "zurechtlegend",
    "zurechtlegendem": "zurechtlegend",
    "zurechtlegenden": "zurechtlegend",
    "zurechtlegender": "zurechtlegend",
    "zurechtlegendes": "zurechtlegend",
    "zurechtlegest": "zurechtlegen",
    "zurechtleget": "zurechtlegen",
    "zurechtlegst": "zurechtlegen",
    "zurechtlegt": "zurechtlegen",
    "zurechtlegte": "zurechtlegen",
    "zurechtlegten": "zurechtlegen",
    "zurechtlegtest": "zurechtlegen",
    "zurechtlegtet": "zurechtlegen",
    "zurechtmache": "zurechtmachen",
    "zurechtmachend": "zurechtmachen",
    "zurechtmachende": "zurechtmachend",
    "zurechtmachendem": "zurechtmachend",
    "zurechtmachenden": "zurechtmachend",
    "zurechtmachender": "zurechtmachend",
    "zurechtmachendere": "zurechtmachend",
    "zurechtmachenderem": "zurechtmachend",
    "zurechtmachenderen": "zurechtmachend",
    "zurechtmachenderer": "zurechtmachend",
    "zurechtmachenderes": "zurechtmachend",
    "zurechtmachendes": "zurechtmachend",
    "zurechtmachendste": "zurechtmachend",
    "zurechtmachendstem": "zurechtmachend",
    "zurechtmachendsten": "zurechtmachend",
    "zurechtmachendster": "zurechtmachend",
    "zurechtmachendstes": "zurechtmachend",
    "zurechtmachest": "zurechtmachen",
    "zurechtmachet": "zurechtmachen",
    "zurechtmachst": "zurechtmachen",
    "zurechtmacht": "zurechtmachen",
    "zurechtmachte": "zurechtmachen",
    "zurechtmachten": "zurechtmachen",
    "zurechtmachtest": "zurechtmachen",
    "zurechtmachtet": "zurechtmachen",
    "zurechtschustere": "zurechtschustern",
    "zurechtschusternd": "zurechtschustern",
    "zurechtschusternde": "zurechtschusternd",
    "zurechtschusterndem": "zurechtschusternd",
    "zurechtschusternden": "zurechtschusternd",
    "zurechtschusternder": "zurechtschusternd",
    "zurechtschusterndes": "zurechtschusternd",
    "zurechtschusterst": "zurechtschustern",
    "zurechtschustert": "zurechtschustern",
    "zurechtschusterte": "zurechtschustern",
    "zurechtschusterten": "zurechtschustern",
    "zurechtschustertest": "zurechtschustern",
    "zurechtschustertet": "zurechtschustern",
    "zurechtsetze": "zurechtsetzen",
    "zurechtsetzend": "zurechtsetzen",
    "zurechtsetzende": "zurechtsetzend",
    "zurechtsetzendem": "zurechtsetzend",
    "zurechtsetzenden": "zurechtsetzend",
    "zurechtsetzender": "zurechtsetzend",
    "zurechtsetzendes": "zurechtsetzend",
    "zurechtsetzest": "zurechtsetzen",
    "zurechtsetzet": "zurechtsetzen",
    "zurechtsetzt": "zurechtsetzen",
    "zurechtsetzte": "zurechtsetzen",
    "zurechtsetzten": "zurechtsetzen",
    "zurechtsetztest": "zurechtsetzen",
    "zurechtsetztet": "zurechtsetzen",
    "zurechtstutze": "zurechtstutzen",
    "zurechtstutzend": "zurechtstutzen",
    "zurechtstutzende": "zurechtstutzend",
    "zurechtstutzendem": "zurechtstutzend",
    "zurechtstutzenden": "zurechtstutzend",
    "zurechtstutzender": "zurechtstutzend",
    "zurechtstutzendes": "zurechtstutzend",
    "zurechtstutzest": "zurechtstutzen",
    "zurechtstutzet": "zurechtstutzen",
    "zurechtstutzt": "zurechtstutzen",
    "zurechtstutzte": "zurechtstutzen",
    "zurechtstutzten": "zurechtstutzen",
    "zurechtstutztest": "zurechtstutzen",
    "zurechtstutztet": "zurechtstutzen",
    "zurechtweise": "zurechtweisen",
    "zurechtweisend": "zurechtweisen",
    "zurechtweisende": "zurechtweisend",
    "zurechtweisendem": "zurechtweisend",
    "zurechtweisenden": "zurechtweisend",
    "zurechtweisender": "zurechtweisend",
    "zurechtweisendere": "zurechtweisend",
    "zurechtweisenderem": "zurechtweisend",
    "zurechtweisenderen": "zurechtweisend",
    "zurechtweisenderer": "zurechtweisend",
    "zurechtweisenderes": "zurechtweisend",
    "zurechtweisendes": "zurechtweisend",
    "zurechtweisendste": "zurechtweisend",
    "zurechtweisendstem": "zurechtweisend",
    "zurechtweisendsten": "zurechtweisend",
    "zurechtweisendster": "zurechtweisend",
    "zurechtweisendstes": "zurechtweisend",
    "zurechtweisest": "zurechtweisen",
    "zurechtweiset": "zurechtweisen",
    "zurechtweist": "zurechtweisen",
    "zurechtwies": "zurechtweisen",
    "zurechtwiese": "zurechtweisen",
    "zurechtwiesen": "zurechtweisen",
    "zurechtwiesest": "zurechtweisen",
    "zurechtwieset": "zurechtweisen",
    "zurechtwiest": "zurechtweisen",
    "zurechtzimmere": "zurechtzimmern",
    "zurechtzimmernd": "zurechtzimmern",
    "zurechtzimmernde": "zurechtzimmernd",
    "zurechtzimmerndem": "zurechtzimmernd",
    "zurechtzimmernden": "zurechtzimmernd",
    "zurechtzimmernder": "zurechtzimmernd",
    "zurechtzimmerndes": "zurechtzimmernd",
    "zurechtzimmerst": "zurechtzimmern",
    "zurechtzimmert": "zurechtzimmern",
    "zurechtzimmerte": "zurechtzimmern",
    "zurechtzimmerten": "zurechtzimmern",
    "zurechtzimmertest": "zurechtzimmern",
    "zurechtzimmertet": "zurechtzimmern",
    "zurechtzubiegen": "zurechtbiegen",
    "zurechtzufinden": "zurechtfinden",
    "zurechtzukommen": "zurechtkommen",
    "zurechtzukriegen": "zurechtkriegen",
    "zurechtzulegen": "zurechtlegen",
    "zurechtzumachen": "zurechtmachen",
    "zurechtzuschustern": "zurechtschustern",
    "zurechtzusetzen": "zurechtsetzen",
    "zurechtzustutzen": "zurechtstutzen",
    "zurechtzuweisen": "zurechtweisen",
    "zurechtzuzimmern": "zurechtzimmern",
    "zurede": "zureden",
    "zuredend": "zureden",
    "zuredende": "zuredend",
    "zuredendem": "zuredend",
    "zuredenden": "zuredend",
    "zuredender": "zuredend",
    "zuredendes": "zuredend",
    "zuredest": "zureden",
    "zuredet": "zureden",
    "zuredete": "zureden",
    "zuredeten": "zureden",
    "zuredetest": "zureden",
    "zuredetet": "zureden",
    "zureiche": "zureichen",
    "zureichend": "zureichen",
    "zureichende": "zureichend",
    "zureichendem": "zureichend",
    "zureichenden": "zureichend",
    "zureichender": "zureichend",
    "zureichendes": "zureichend",
    "zureichest": "zureichen",
    "zureichet": "zureichen",
    "zureichst": "zureichen",
    "zureicht": "zureichen",
    "zureichte": "zureichen",
    "zureichten": "zureichen",
    "zureichtest": "zureichen",
    "zureichtet": "zureichen",
    "zureite": "zureiten",
    "zureitend": "zureiten",
    "zureitende": "zureitend",
    "zureitendem": "zureitend",
    "zureitenden": "zureitend",
    "zureitender": "zureitend",
    "zureitendes": "zureitend",
    "zureitest": "zureiten",
    "zureitet": "zureiten",
    "zurichte": "zurichten",
    "zurichtend": "zurichten",
    "zurichtende": "zurichtend",
    "zurichtendem": "zurichtend",
    "zurichtenden": "zurichtend",
    "zurichtender": "zurichtend",
    "zurichtendes": "zurichtend",
    "zurichtest": "zurichten",
    "zurichtet": "zurichten",
    "zurichtete": "zurichten",
    "zurichteten": "zurichten",
    "zurichtetest": "zurichten",
    "zurichtetet": "zurichten",
    "zurief": "zurufen",
    "zuriefe": "zurufen",
    "zuriefen": "zurufen",
    "zuriefest": "zurufen",
    "zuriefet": "zurufen",
    "zuriefst": "zurufen",
    "zurieft": "zurufen",
    "zuriegele": "zuriegeln",
    "zuriegelnd": "zuriegeln",
    "zuriegelnde": "zuriegelnd",
    "zuriegelndem": "zuriegelnd",
    "zuriegelnden": "zuriegelnd",
    "zuriegelnder": "zuriegelnd",
    "zuriegelndes": "zuriegelnd",
    "zuriegelst": "zuriegeln",
    "zuriegelt": "zuriegeln",
    "zuriegelte": "zuriegeln",
    "zuriegelten": "zuriegeln",
    "zuriegeltest": "zuriegeln",
    "zuriegeltet": "zuriegeln",
    "zuriegle": "zuriegeln",
    "zuriet": "zuraten",
    "zuriete": "zuraten",
    "zurieten": "zuraten",
    "zurietest": "zuraten",
    "zurietet": "zuraten",
    "zuritt": "zureiten",
    "zuritte": "zureiten",
    "zuritten": "zureiten",
    "zurittest": "zureiten",
    "zurittet": "zureiten",
    "zurolle": "zurollen",
    "zurollend": "zurollen",
    "zurollende": "zurollend",
    "zurollendem": "zurollend",
    "zurollenden": "zurollend",
    "zurollender": "zurollend",
    "zurollendes": "zurollend",
    "zurollest": "zurollen",
    "zurollet": "zurollen",
    "zurollst": "zurollen",
    "zurollt": "zurollen",
    "zurollte": "zurollen",
    "zurollten": "zurollen",
    "zurolltest": "zurollen",
    "zurolltet": "zurollen",
    "zurre": "zurren",
    "zurrend": "zurren",
    "zurrende": "zurrend",
    "zurrendem": "zurrend",
    "zurrenden": "zurrend",
    "zurrender": "zurrend",
    "zurrendes": "zurrend",
    "zurrest": "zurren",
    "zurret": "zurren",
    "zurrst": "zurren",
    "zurrt": "zurren",
    "zurrte": "zurren",
    "zurrten": "zurren",
    "zurrtest": "zurren",
    "zurrtet": "zurren",
    "zurufe": "zurufen",
    "zurufend": "zurufen",
    "zurufende": "zurufend",
    "zurufendem": "zurufend",
    "zurufenden": "zurufend",
    "zurufender": "zurufend",
    "zurufendes": "zurufend",
    "zurufest": "zurufen",
    "zurufet": "zurufen",
    "zurufst": "zurufen",
    "zuruft": "zurufen",
    "zurät": "zuraten",
    "zurätst": "zuraten",
    "zurückbegab": "zurückbegeben",
    "zurückbegaben": "zurückbegeben",
    "zurückbegabst": "zurückbegeben",
    "zurückbegabt": "zurückbegeben",
    "zurückbegebe": "zurückbegeben",
    "zurückbegebend": "zurückbegeben",
    "zurückbegebende": "zurückbegebend",
    "zurückbegebendem": "zurückbegebend",
    "zurückbegebenden": "zurückbegebend",
    "zurückbegebender": "zurückbegebend",
    "zurückbegebendes": "zurückbegebend",
    "zurückbegebene": "zurückbegeben",
    "zurückbegebenem": "zurückbegeben",
    "zurückbegebenen": "zurückbegeben",
    "zurückbegebener": "zurückbegeben",
    "zurückbegebenes": "zurückbegeben",
    "zurückbegebest": "zurückbegeben",
    "zurückbegebet": "zurückbegeben",
    "zurückbegebt": "zurückbegeben",
    "zurückbegibst": "zurückbegeben",
    "zurückbegibt": "zurückbegeben",
    "zurückbegleite": "zurückbegleiten",
    "zurückbegleitend": "zurückbegleiten",
    "zurückbegleitende": "zurückbegleitend",
    "zurückbegleitendem": "zurückbegleitend",
    "zurückbegleitenden": "zurückbegleitend",
    "zurückbegleitender": "zurückbegleitend",
    "zurückbegleitendes": "zurückbegleitend",
    "zurückbegleitest": "zurückbegleiten",
    "zurückbegleitet": "zurückbegleiten",
    "zurückbegleitete": "zurückbegleiten",
    "zurückbegleitetem": "zurückbegleitet",
    "zurückbegleiteten": "zurückbegleiten",
    "zurückbegleiteter": "zurückbegleitet",
    "zurückbegleitetes": "zurückbegleitet",
    "zurückbegleitetest": "zurückbegleiten",
    "zurückbegleitetet": "zurückbegleiten",
    "zurückbegäbe": "zurückbegeben",
    "zurückbegäben": "zurückbegeben",
    "zurückbegäbest": "zurückbegeben",
    "zurückbegäbet": "zurückbegeben",
    "zurückbehalte": "zurückbehalten",
    "zurückbehaltend": "zurückbehalten",
    "zurückbehaltende": "zurückbehaltend",
    "zurückbehaltendem": "zurückbehaltend",
    "zurückbehaltenden": "zurückbehaltend",
    "zurückbehaltender": "zurückbehaltend",
    "zurückbehaltendes": "zurückbehaltend",
    "zurückbehaltene": "zurückbehalten",
    "zurückbehaltenem": "zurückbehalten",
    "zurückbehaltenen": "zurückbehalten",
    "zurückbehaltener": "zurückbehalten",
    "zurückbehaltenes": "zurückbehalten",
    "zurückbehaltest": "zurückbehalten",
    "zurückbehaltet": "zurückbehalten",
    "zurückbehielt": "zurückbehalten",
    "zurückbehielte": "zurückbehalten",
    "zurückbehielten": "zurückbehalten",
    "zurückbehieltest": "zurückbehalten",
    "zurückbehieltet": "zurückbehalten",
    "zurückbehält": "zurückbehalten",
    "zurückbehältst": "zurückbehalten",
    "zurückbekam": "zurückbekommen",
    "zurückbekamen": "zurückbekommen",
    "zurückbekamst": "zurückbekommen",
    "zurückbekamt": "zurückbekommen",
    "zurückbekomme": "zurückbekommen",
    "zurückbekommend": "zurückbekommen",
    "zurückbekommende": "zurückbekommend",
    "zurückbekommendem": "zurückbekommend",
    "zurückbekommenden": "zurückbekommend",
    "zurückbekommender": "zurückbekommend",
    "zurückbekommendes": "zurückbekommend",
    "zurückbekommene": "zurückbekommen",
    "zurückbekommenem": "zurückbekommen",
    "zurückbekommenen": "zurückbekommen",
    "zurückbekommener": "zurückbekommen",
    "zurückbekommenes": "zurückbekommen",
    "zurückbekommest": "zurückbekommen",
    "zurückbekommet": "zurückbekommen",
    "zurückbekommst": "zurückbekommen",
    "zurückbekommt": "zurückbekommen",
    "zurückbekäme": "zurückbekommen",
    "zurückbekämen": "zurückbekommen",
    "zurückbekämest": "zurückbekommen",
    "zurückbekämet": "zurückbekommen",
    "zurückbeuge": "zurückbeugen",
    "zurückbeugend": "zurückbeugen",
    "zurückbeugende": "zurückbeugend",
    "zurückbeugendem": "zurückbeugend",
    "zurückbeugenden": "zurückbeugend",
    "zurückbeugender": "zurückbeugend",
    "zurückbeugendere": "zurückbeugend",
    "zurückbeugenderem": "zurückbeugend",
    "zurückbeugenderen": "zurückbeugend",
    "zurückbeugenderer": "zurückbeugend",
    "zurückbeugenderes": "zurückbeugend",
    "zurückbeugendes": "zurückbeugend",
    "zurückbeugendste": "zurückbeugend",
    "zurückbeugendstem": "zurückbeugend",
    "zurückbeugendsten": "zurückbeugend",
    "zurückbeugendster": "zurückbeugend",
    "zurückbeugendstes": "zurückbeugend",
    "zurückbeugest": "zurückbeugen",
    "zurückbeuget": "zurückbeugen",
    "zurückbeugst": "zurückbeugen",
    "zurückbeugt": "zurückbeugen",
    "zurückbeugte": "zurückbeugen",
    "zurückbeugten": "zurückbeugen",
    "zurückbeugtest": "zurückbeugen",
    "zurückbeugtet": "zurückbeugen",
    "zurückbewege": "zurückbewegen",
    "zurückbewegend": "zurückbewegen",
    "zurückbewegende": "zurückbewegend",
    "zurückbewegendem": "zurückbewegend",
    "zurückbewegenden": "zurückbewegend",
    "zurückbewegender": "zurückbewegend",
    "zurückbewegendes": "zurückbewegend",
    "zurückbewegest": "zurückbewegen",
    "zurückbeweget": "zurückbewegen",
    "zurückbewegst": "zurückbewegen",
    "zurückbewegt": "zurückbewegen",
    "zurückbewegte": "zurückbewegen",
    "zurückbewegtem": "zurückbewegt",
    "zurückbewegten": "zurückbewegen",
    "zurückbewegter": "zurückbewegt",
    "zurückbewegtes": "zurückbewegt",
    "zurückbewegtest": "zurückbewegen",
    "zurückbewegtet": "zurückbewegen",
    "zurückbewog": "zurückbewegen",
    "zurückbewogen": "zurückbewegen",
    "zurückbewogene": "zurückbewogen",
    "zurückbewogenem": "zurückbewogen",
    "zurückbewogenen": "zurückbewogen",
    "zurückbewogener": "zurückbewogen",
    "zurückbewogenes": "zurückbewogen",
    "zurückbewogst": "zurückbewegen",
    "zurückbewogt": "zurückbewegen",
    "zurückbewöge": "zurückbewegen",
    "zurückbewögen": "zurückbewegen",
    "zurückbewögest": "zurückbewegen",
    "zurückbewöget": "zurückbewegen",
    "zurückbiege": "zurückbiegen",
    "zurückbiegend": "zurückbiegen",
    "zurückbiegende": "zurückbiegend",
    "zurückbiegendem": "zurückbiegend",
    "zurückbiegenden": "zurückbiegend",
    "zurückbiegender": "zurückbiegend",
    "zurückbiegendes": "zurückbiegend",
    "zurückbiegest": "zurückbiegen",
    "zurückbieget": "zurückbiegen",
    "zurückbiegst": "zurückbiegen",
    "zurückbiegt": "zurückbiegen",
    "zurückbilde": "zurückbilden",
    "zurückbildend": "zurückbilden",
    "zurückbildende": "zurückbildend",
    "zurückbildendem": "zurückbildend",
    "zurückbildenden": "zurückbildend",
    "zurückbildender": "zurückbildend",
    "zurückbildendere": "zurückbildend",
    "zurückbildenderem": "zurückbildend",
    "zurückbildenderen": "zurückbildend",
    "zurückbildenderer": "zurückbildend",
    "zurückbildenderes": "zurückbildend",
    "zurückbildendes": "zurückbildend",
    "zurückbildendste": "zurückbildend",
    "zurückbildendstem": "zurückbildend",
    "zurückbildendsten": "zurückbildend",
    "zurückbildendster": "zurückbildend",
    "zurückbildendstes": "zurückbildend",
    "zurückbildest": "zurückbilden",
    "zurückbildet": "zurückbilden",
    "zurückbildete": "zurückbilden",
    "zurückbildeten": "zurückbilden",
    "zurückbildetest": "zurückbilden",
    "zurückbildetet": "zurückbilden",
    "zurückbleibe": "zurückbleiben",
    "zurückbleibend": "zurückbleiben",
    "zurückbleibende": "zurückbleibend",
    "zurückbleibendem": "zurückbleibend",
    "zurückbleibenden": "zurückbleibend",
    "zurückbleibender": "zurückbleibend",
    "zurückbleibendes": "zurückbleibend",
    "zurückbleibest": "zurückbleiben",
    "zurückbleibet": "zurückbleiben",
    "zurückbleibst": "zurückbleiben",
    "zurückbleibt": "zurückbleiben",
    "zurückblicke": "zurückblicken",
    "zurückblickend": "zurückblicken",
    "zurückblickende": "zurückblickend",
    "zurückblickendem": "zurückblickend",
    "zurückblickenden": "zurückblickend",
    "zurückblickender": "zurückblickend",
    "zurückblickendere": "zurückblickend",
    "zurückblickenderem": "zurückblickend",
    "zurückblickenderen": "zurückblickend",
    "zurückblickenderer": "zurückblickend",
    "zurückblickenderes": "zurückblickend",
    "zurückblickendes": "zurückblickend",
    "zurückblickendste": "zurückblickend",
    "zurückblickendstem": "zurückblickend",
    "zurückblickendsten": "zurückblickend",
    "zurückblickendster": "zurückblickend",
    "zurückblickendstes": "zurückblickend",
    "zurückblickest": "zurückblicken",
    "zurückblicket": "zurückblicken",
    "zurückblickst": "zurückblicken",
    "zurückblickt": "zurückblicken",
    "zurückblickte": "zurückblicken",
    "zurückblickten": "zurückblicken",
    "zurückblicktest": "zurückblicken",
    "zurückblicktet": "zurückblicken",
    "zurückblieb": "zurückbleiben",
    "zurückbliebe": "zurückbleiben",
    "zurückblieben": "zurückbleiben",
    "zurückbliebest": "zurückbleiben",
    "zurückbliebet": "zurückbleiben",
    "zurückbliebst": "zurückbleiben",
    "zurückbliebt": "zurückbleiben",
    "zurückbog": "zurückbiegen",
    "zurückbogen": "zurückbiegen",
    "zurückbogst": "zurückbiegen",
    "zurückbogt": "zurückbiegen",
    "zurückbrachte": "zurückbringen",
    "zurückbrachten": "zurückbringen",
    "zurückbrachtest": "zurückbringen",
    "zurückbrachtet": "zurückbringen",
    "zurückbringe": "zurückbringen",
    "zurückbringend": "zurückbringen",
    "zurückbringende": "zurückbringend",
    "zurückbringendem": "zurückbringend",
    "zurückbringenden": "zurückbringend",
    "zurückbringender": "zurückbringend",
    "zurückbringendes": "zurückbringend",
    "zurückbringest": "zurückbringen",
    "zurückbringet": "zurückbringen",
    "zurückbringst": "zurückbringen",
    "zurückbringt": "zurückbringen",
    "zurückbrächte": "zurückbringen",
    "zurückbrächten": "zurückbringen",
    "zurückbrächtest": "zurückbringen",
    "zurückbrächtet": "zurückbringen",
    "zurückböge": "zurückbiegen",
    "zurückbögen": "zurückbiegen",
    "zurückbögest": "zurückbiegen",
    "zurückböget": "zurückbiegen",
    "zurückdachte": "zurückdenken",
    "zurückdachten": "zurückdenken",
    "zurückdachtest": "zurückdenken",
    "zurückdachtet": "zurückdenken",
    "zurückdatiere": "zurückdatieren",
    "zurückdatierend": "zurückdatieren",
    "zurückdatierende": "zurückdatierend",
    "zurückdatierendem": "zurückdatierend",
    "zurückdatierenden": "zurückdatierend",
    "zurückdatierender": "zurückdatierend",
    "zurückdatierendes": "zurückdatierend",
    "zurückdatierest": "zurückdatieren",
    "zurückdatieret": "zurückdatieren",
    "zurückdatierst": "zurückdatieren",
    "zurückdatiert": "zurückdatieren",
    "zurückdatierte": "zurückdatieren",
    "zurückdatiertem": "zurückdatiert",
    "zurückdatierten": "zurückdatieren",
    "zurückdatierter": "zurückdatiert",
    "zurückdatiertes": "zurückdatiert",
    "zurückdatiertest": "zurückdatieren",
    "zurückdatiertet": "zurückdatieren",
    "zurückdenke": "zurückdenken",
    "zurückdenkend": "zurückdenken",
    "zurückdenkende": "zurückdenkend",
    "zurückdenkendem": "zurückdenkend",
    "zurückdenkenden": "zurückdenkend",
    "zurückdenkender": "zurückdenkend",
    "zurückdenkendes": "zurückdenkend",
    "zurückdenkest": "zurückdenken",
    "zurückdenket": "zurückdenken",
    "zurückdenkst": "zurückdenken",
    "zurückdenkt": "zurückdenken",
    "zurückdrehe": "zurückdrehen",
    "zurückdrehend": "zurückdrehen",
    "zurückdrehende": "zurückdrehend",
    "zurückdrehendem": "zurückdrehend",
    "zurückdrehenden": "zurückdrehend",
    "zurückdrehender": "zurückdrehend",
    "zurückdrehendes": "zurückdrehend",
    "zurückdrehest": "zurückdrehen",
    "zurückdrehet": "zurückdrehen",
    "zurückdrehst": "zurückdrehen",
    "zurückdreht": "zurückdrehen",
    "zurückdrehte": "zurückdrehen",
    "zurückdrehten": "zurückdrehen",
    "zurückdrehtest": "zurückdrehen",
    "zurückdrehtet": "zurückdrehen",
    "zurückdränge": "zurückdrängen",
    "zurückdrängend": "zurückdrängen",
    "zurückdrängende": "zurückdrängend",
    "zurückdrängendem": "zurückdrängend",
    "zurückdrängenden": "zurückdrängend",
    "zurückdrängender": "zurückdrängend",
    "zurückdrängendere": "zurückdrängend",
    "zurückdrängenderem": "zurückdrängend",
    "zurückdrängenderen": "zurückdrängend",
    "zurückdrängenderer": "zurückdrängend",
    "zurückdrängenderes": "zurückdrängend",
    "zurückdrängendes": "zurückdrängend",
    "zurückdrängendste": "zurückdrängend",
    "zurückdrängendstem": "zurückdrängend",
    "zurückdrängendsten": "zurückdrängend",
    "zurückdrängendster": "zurückdrängend",
    "zurückdrängendstes": "zurückdrängend",
    "zurückdrängest": "zurückdrängen",
    "zurückdränget": "zurückdrängen",
    "zurückdrängst": "zurückdrängen",
    "zurückdrängt": "zurückdrängen",
    "zurückdrängte": "zurückdrängen",
    "zurückdrängten": "zurückdrängen",
    "zurückdrängtest": "zurückdrängen",
    "zurückdrängtet": "zurückdrängen",
    "zurückdächte": "zurückdenken",
    "zurückdächten": "zurückdenken",
    "zurückdächtest": "zurückdenken",
    "zurückdächtet": "zurückdenken",
    "zurückeile": "zurückeilen",
    "zurückeilend": "zurückeilen",
    "zurückeilende": "zurückeilend",
    "zurückeilendem": "zurückeilend",
    "zurückeilenden": "zurückeilend",
    "zurückeilender": "zurückeilend",
    "zurückeilendes": "zurückeilend",
    "zurückeilest": "zurückeilen",
    "zurückeilet": "zurückeilen",
    "zurückeilst": "zurückeilen",
    "zurückeilt": "zurückeilen",
    "zurückeilte": "zurückeilen",
    "zurückeilten": "zurückeilen",
    "zurückeiltest": "zurückeilen",
    "zurückeiltet": "zurückeilen",
    "zurückerbat": "zurückerbitten",
    "zurückerbaten": "zurückerbitten",
    "zurückerbatest": "zurückerbitten",
    "zurückerbatet": "zurückerbitten",
    "zurückerbeten": "zurückerbitten",
    "zurückerbetene": "zurückerbeten",
    "zurückerbetenem": "zurückerbeten",
    "zurückerbetenen": "zurückerbeten",
    "zurückerbetener": "zurückerbeten",
    "zurückerbetenes": "zurückerbeten",
    "zurückerbitte": "zurückerbitten",
    "zurückerbittend": "zurückerbitten",
    "zurückerbittende": "zurückerbittend",
    "zurückerbittendem": "zurückerbittend",
    "zurückerbittenden": "zurückerbittend",
    "zurückerbittender": "zurückerbittend",
    "zurückerbittendes": "zurückerbittend",
    "zurückerbittest": "zurückerbitten",
    "zurückerbittet": "zurückerbitten",
    "zurückerbäte": "zurückerbitten",
    "zurückerbäten": "zurückerbitten",
    "zurückerbätest": "zurückerbitten",
    "zurückerbätet": "zurückerbitten",
    "zurückerhalte": "zurückerhalten",
    "zurückerhaltend": "zurückerhalten",
    "zurückerhaltende": "zurückerhaltend",
    "zurückerhaltendem": "zurückerhaltend",
    "zurückerhaltenden": "zurückerhaltend",
    "zurückerhaltender": "zurückerhaltend",
    "zurückerhaltendes": "zurückerhaltend",
    "zurückerhaltene": "zurückerhalten",
    "zurückerhaltenem": "zurückerhalten",
    "zurückerhaltenen": "zurückerhalten",
    "zurückerhaltener": "zurückerhalten",
    "zurückerhaltenes": "zurückerhalten",
    "zurückerhaltest": "zurückerhalten",
    "zurückerhaltet": "zurückerhalten",
    "zurückerhielt": "zurückerhalten",
    "zurückerhielte": "zurückerhalten",
    "zurückerhielten": "zurückerhalten",
    "zurückerhieltest": "zurückerhalten",
    "zurückerhieltet": "zurückerhalten",
    "zurückerhält": "zurückerhalten",
    "zurückerhältst": "zurückerhalten",
    "zurückerinnere": "zurückerinnern",
    "zurückerinnernd": "zurückerinnern",
    "zurückerinnernde": "zurückerinnernd",
    "zurückerinnerndem": "zurückerinnernd",
    "zurückerinnernden": "zurückerinnernd",
    "zurückerinnernder": "zurückerinnernd",
    "zurückerinnerndes": "zurückerinnernd",
    "zurückerinnerst": "zurückerinnern",
    "zurückerinnert": "zurückerinnern",
    "zurückerinnerte": "zurückerinnern",
    "zurückerinnertem": "zurückerinnert",
    "zurückerinnerten": "zurückerinnern",
    "zurückerinnerter": "zurückerinnert",
    "zurückerinnertes": "zurückerinnert",
    "zurückerinnertest": "zurückerinnern",
    "zurückerinnertet": "zurückerinnern",
    "zurückerlange": "zurückerlangen",
    "zurückerlangend": "zurückerlangen",
    "zurückerlangende": "zurückerlangend",
    "zurückerlangendem": "zurückerlangend",
    "zurückerlangenden": "zurückerlangend",
    "zurückerlangender": "zurückerlangend",
    "zurückerlangendes": "zurückerlangend",
    "zurückerlangest": "zurückerlangen",
    "zurückerlanget": "zurückerlangen",
    "zurückerlangst": "zurückerlangen",
    "zurückerlangt": "zurückerlangen",
    "zurückerlangte": "zurückerlangen",
    "zurückerlangtem": "zurückerlangt",
    "zurückerlangten": "zurückerlangen",
    "zurückerlangter": "zurückerlangt",
    "zurückerlangtes": "zurückerlangt",
    "zurückerlangtest": "zurückerlangen",
    "zurückerlangtet": "zurückerlangen",
    "zurückerobere": "zurückerobern",
    "zurückerobernd": "zurückerobern",
    "zurückerobernde": "zurückerobernd",
    "zurückeroberndem": "zurückerobernd",
    "zurückerobernden": "zurückerobernd",
    "zurückerobernder": "zurückerobernd",
    "zurückeroberndes": "zurückerobernd",
    "zurückeroberst": "zurückerobern",
    "zurückerobert": "zurückerobern",
    "zurückeroberte": "zurückerobern",
    "zurückerobertem": "zurückerobert",
    "zurückeroberten": "zurückerobern",
    "zurückeroberter": "zurückerobert",
    "zurückerobertes": "zurückerobert",
    "zurückerobertest": "zurückerobern",
    "zurückerobertet": "zurückerobern",
    "zurückerstatte": "zurückerstatten",
    "zurückerstattend": "zurückerstatten",
    "zurückerstattende": "zurückerstattend",
    "zurückerstattendem": "zurückerstattend",
    "zurückerstattenden": "zurückerstattend",
    "zurückerstattender": "zurückerstattend",
    "zurückerstattendes": "zurückerstattend",
    "zurückerstattest": "zurückerstatten",
    "zurückerstattet": "zurückerstatten",
    "zurückerstattete": "zurückerstatten",
    "zurückerstattetem": "zurückerstattet",
    "zurückerstatteten": "zurückerstatten",
    "zurückerstatteter": "zurückerstattet",
    "zurückerstattetes": "zurückerstattet",
    "zurückerstattetest": "zurückerstatten",
    "zurückerstattetet": "zurückerstatten",
    "zurückerwarb": "zurückerwerben",
    "zurückerwarben": "zurückerwerben",
    "zurückerwarbst": "zurückerwerben",
    "zurückerwarbt": "zurückerwerben",
    "zurückerwarte": "zurückerwarten",
    "zurückerwartend": "zurückerwarten",
    "zurückerwartende": "zurückerwartend",
    "zurückerwartendem": "zurückerwartend",
    "zurückerwartenden": "zurückerwartend",
    "zurückerwartender": "zurückerwartend",
    "zurückerwartendes": "zurückerwartend",
    "zurückerwartest": "zurückerwarten",
    "zurückerwartet": "zurückerwarten",
    "zurückerwartete": "zurückerwarten",
    "zurückerwartetem": "zurückerwartet",
    "zurückerwarteten": "zurückerwarten",
    "zurückerwarteter": "zurückerwartet",
    "zurückerwartetes": "zurückerwartet",
    "zurückerwartetest": "zurückerwarten",
    "zurückerwartetet": "zurückerwarten",
    "zurückerwerbe": "zurückerwerben",
    "zurückerwerbend": "zurückerwerben",
    "zurückerwerbende": "zurückerwerbend",
    "zurückerwerbendem": "zurückerwerbend",
    "zurückerwerbenden": "zurückerwerbend",
    "zurückerwerbender": "zurückerwerbend",
    "zurückerwerbendes": "zurückerwerbend",
    "zurückerwerbest": "zurückerwerben",
    "zurückerwerbet": "zurückerwerben",
    "zurückerwerbt": "zurückerwerben",
    "zurückerwirbst": "zurückerwerben",
    "zurückerwirbt": "zurückerwerben",
    "zurückerworben": "zurückerwerben",
    "zurückerworbene": "zurückerworben",
    "zurückerworbenem": "zurückerworben",
    "zurückerworbenen": "zurückerworben",
    "zurückerworbener": "zurückerworben",
    "zurückerworbenes": "zurückerworben",
    "zurückerwärbe": "zurückerwerben",
    "zurückerwärben": "zurückerwerben",
    "zurückerwärbest": "zurückerwerben",
    "zurückerwärbet": "zurückerwerben",
    "zurückfahre": "zurückfahren",
    "zurückfahrend": "zurückfahren",
    "zurückfahrende": "zurückfahrend",
    "zurückfahrendem": "zurückfahrend",
    "zurückfahrenden": "zurückfahrend",
    "zurückfahrender": "zurückfahrend",
    "zurückfahrendes": "zurückfahrend",
    "zurückfahrest": "zurückfahren",
    "zurückfahret": "zurückfahren",
    "zurückfahrt": "zurückfahren",
    "zurückfalle": "zurückfallen",
    "zurückfallend": "zurückfallen",
    "zurückfallende": "zurückfallend",
    "zurückfallendem": "zurückfallend",
    "zurückfallenden": "zurückfallend",
    "zurückfallender": "zurückfallend",
    "zurückfallendes": "zurückfallend",
    "zurückfallest": "zurückfallen",
    "zurückfallet": "zurückfallen",
    "zurückfallt": "zurückfallen",
    "zurückfand": "zurückfinden",
    "zurückfanden": "zurückfinden",
    "zurückfandest": "zurückfinden",
    "zurückfandet": "zurückfinden",
    "zurückfiel": "zurückfallen",
    "zurückfiele": "zurückfallen",
    "zurückfielen": "zurückfallen",
    "zurückfielest": "zurückfallen",
    "zurückfielet": "zurückfallen",
    "zurückfielst": "zurückfallen",
    "zurückfielt": "zurückfallen",
    "zurückfinde": "zurückfinden",
    "zurückfindend": "zurückfinden",
    "zurückfindende": "zurückfindend",
    "zurückfindendem": "zurückfindend",
    "zurückfindenden": "zurückfindend",
    "zurückfindender": "zurückfindend",
    "zurückfindendes": "zurückfindend",
    "zurückfindest": "zurückfinden",
    "zurückfindet": "zurückfinden",
    "zurückfliege": "zurückfliegen",
    "zurückfliegend": "zurückfliegen",
    "zurückfliegende": "zurückfliegend",
    "zurückfliegendem": "zurückfliegend",
    "zurückfliegenden": "zurückfliegend",
    "zurückfliegender": "zurückfliegend",
    "zurückfliegendes": "zurückfliegend",
    "zurückfliegest": "zurückfliegen",
    "zurückflieget": "zurückfliegen",
    "zurückfliegst": "zurückfliegen",
    "zurückfliegt": "zurückfliegen",
    "zurückfließe": "zurückfließen",
    "zurückfließend": "zurückfließen",
    "zurückfließende": "zurückfließend",
    "zurückfließendem": "zurückfließend",
    "zurückfließenden": "zurückfließend",
    "zurückfließender": "zurückfließend",
    "zurückfließendes": "zurückfließend",
    "zurückfließest": "zurückfließen",
    "zurückfließet": "zurückfließen",
    "zurückfließt": "zurückfließen",
    "zurückflog": "zurückfliegen",
    "zurückflogen": "zurückfliegen",
    "zurückflogst": "zurückfliegen",
    "zurückflogt": "zurückfliegen",
    "zurückflossen": "zurückfließen",
    "zurückfloß": "zurückfließen",
    "zurückfloßt": "zurückfließen",
    "zurückflöge": "zurückfliegen",
    "zurückflögen": "zurückfliegen",
    "zurückflögest": "zurückfliegen",
    "zurückflöget": "zurückfliegen",
    "zurückflösse": "zurückfließen",
    "zurückflössen": "zurückfließen",
    "zurückflössest": "zurückfließen",
    "zurückflösset": "zurückfließen",
    "zurückfordere": "zurückfordern",
    "zurückfordernd": "zurückfordern",
    "zurückfordernde": "zurückfordernd",
    "zurückforderndem": "zurückfordernd",
    "zurückfordernden": "zurückfordernd",
    "zurückfordernder": "zurückfordernd",
    "zurückforderndes": "zurückfordernd",
    "zurückforderst": "zurückfordern",
    "zurückfordert": "zurückfordern",
    "zurückforderte": "zurückfordern",
    "zurückforderten": "zurückfordern",
    "zurückfordertest": "zurückfordern",
    "zurückfordertet": "zurückfordern",
    "zurückfrage": "zurückfragen",
    "zurückfragend": "zurückfragen",
    "zurückfragende": "zurückfragend",
    "zurückfragendem": "zurückfragend",
    "zurückfragenden": "zurückfragend",
    "zurückfragender": "zurückfragend",
    "zurückfragendes": "zurückfragend",
    "zurückfragest": "zurückfragen",
    "zurückfraget": "zurückfragen",
    "zurückfragst": "zurückfragen",
    "zurückfragt": "zurückfragen",
    "zurückfragte": "zurückfragen",
    "zurückfragten": "zurückfragen",
    "zurückfragtest": "zurückfragen",
    "zurückfragtet": "zurückfragen",
    "zurückfuhr": "zurückfahren",
    "zurückfuhren": "zurückfahren",
    "zurückfuhrst": "zurückfahren",
    "zurückfuhrt": "zurückfahren",
    "zurückfährst": "zurückfahren",
    "zurückfährt": "zurückfahren",
    "zurückfällst": "zurückfallen",
    "zurückfällt": "zurückfallen",
    "zurückfände": "zurückfinden",
    "zurückfänden": "zurückfinden",
    "zurückfändest": "zurückfinden",
    "zurückfändet": "zurückfinden",
    "zurückführe": "zurückführen",
    "zurückführen": "zurückfahren",
    "zurückführend": "zurückführen",
    "zurückführende": "zurückführend",
    "zurückführendem": "zurückführend",
    "zurückführenden": "zurückführend",
    "zurückführender": "zurückführend",
    "zurückführendes": "zurückführend",
    "zurückführest": "zurückführen",
    "zurückführet": "zurückführen",
    "zurückführst": "zurückführen",
    "zurückführt": "zurückführen",
    "zurückführte": "zurückführen",
    "zurückführten": "zurückführen",
    "zurückführtest": "zurückführen",
    "zurückführtet": "zurückführen",
    "zurückgab": "zurückgeben",
    "zurückgaben": "zurückgeben",
    "zurückgabst": "zurückgeben",
    "zurückgabt": "zurückgeben",
    "zurückgebe": "zurückgeben",
    "zurückgebend": "zurückgeben",
    "zurückgebende": "zurückgebend",
    "zurückgebendem": "zurückgebend",
    "zurückgebenden": "zurückgebend",
    "zurückgebender": "zurückgebend",
    "zurückgebendes": "zurückgebend",
    "zurückgebest": "zurückgeben",
    "zurückgebet": "zurückgeben",
    "zurückgebeugt": "zurückbeugen",
    "zurückgebeugte": "zurückgebeugt",
    "zurückgebeugtem": "zurückgebeugt",
    "zurückgebeugten": "zurückgebeugt",
    "zurückgebeugter": "zurückgebeugt",
    "zurückgebeugtere": "zurückgebeugt",
    "zurückgebeugterem": "zurückgebeugt",
    "zurückgebeugteren": "zurückgebeugt",
    "zurückgebeugterer": "zurückgebeugt",
    "zurückgebeugteres": "zurückgebeugt",
    "zurückgebeugtes": "zurückgebeugt",
    "zurückgebeugteste": "zurückgebeugt",
    "zurückgebeugtestem": "zurückgebeugt",
    "zurückgebeugtesten": "zurückgebeugt",
    "zurückgebeugtester": "zurückgebeugt",
    "zurückgebeugtestes": "zurückgebeugt",
    "zurückgebildet": "zurückbilden",
    "zurückgebildete": "zurückgebildet",
    "zurückgebildetem": "zurückgebildet",
    "zurückgebildeten": "zurückgebildet",
    "zurückgebildeter": "zurückgebildet",
    "zurückgebildetere": "zurückgebildet",
    "zurückgebildeterem": "zurückgebildet",
    "zurückgebildeteren": "zurückgebildet",
    "zurückgebildeterer": "zurückgebildet",
    "zurückgebildeteres": "zurückgebildet",
    "zurückgebildetes": "zurückgebildet",
    "zurückgebildeteste": "zurückgebildet",
    "zurückgebildetestem": "zurückgebildet",
    "zurückgebildetesten": "zurückgebildet",
    "zurückgebildetester": "zurückgebildet",
    "zurückgebildetestes": "zurückgebildet",
    "zurückgeblickt": "zurückblicken",
    "zurückgeblickte": "zurückgeblickt",
    "zurückgeblicktem": "zurückgeblickt",
    "zurückgeblickten": "zurückgeblickt",
    "zurückgeblickter": "zurückgeblickt",
    "zurückgeblicktes": "zurückgeblickt",
    "zurückgeblieben": "zurückbleiben",
    "zurückgebliebene": "zurückgeblieben",
    "zurückgebliebenem": "zurückgeblieben",
    "zurückgebliebenen": "zurückgeblieben",
    "zurückgebliebener": "zurückgeblieben",
    "zurückgebliebenes": "zurückgeblieben",
    "zurückgebogen": "zurückbiegen",
    "zurückgebogene": "zurückgebogen",
    "zurückgebogenem": "zurückgebogen",
    "zurückgebogenen": "zurückgebogen",
    "zurückgebogener": "zurückgebogen",
    "zurückgebogenes": "zurückgebogen",
    "zurückgebracht": "zurückbringen",
    "zurückgebrachte": "zurückgebracht",
    "zurückgebrachtem": "zurückgebracht",
    "zurückgebrachten": "zurückgebracht",
    "zurückgebrachter": "zurückgebracht",
    "zurückgebrachtes": "zurückgebracht",
    "zurückgebt": "zurückgeben",
    "zurückgedacht": "zurückdenken",
    "zurückgedachte": "zurückgedacht",
    "zurückgedachtem": "zurückgedacht",
    "zurückgedachten": "zurückgedacht",
    "zurückgedachter": "zurückgedacht",
    "zurückgedachtes": "zurückgedacht",
    "zurückgedreht": "zurückdrehen",
    "zurückgedrehte": "zurückgedreht",
    "zurückgedrehtem": "zurückgedreht",
    "zurückgedrehten": "zurückgedreht",
    "zurückgedrehter": "zurückgedreht",
    "zurückgedrehtes": "zurückgedreht",
    "zurückgedrängt": "zurückdrängen",
    "zurückgedrängte": "zurückgedrängt",
    "zurückgedrängtem": "zurückgedrängt",
    "zurückgedrängten": "zurückgedrängt",
    "zurückgedrängter": "zurückgedrängt",
    "zurückgedrängtere": "zurückgedrängt",
    "zurückgedrängterem": "zurückgedrängt",
    "zurückgedrängteren": "zurückgedrängt",
    "zurückgedrängterer": "zurückgedrängt",
    "zurückgedrängteres": "zurückgedrängt",
    "zurückgedrängtes": "zurückgedrängt",
    "zurückgedrängteste": "zurückgedrängt",
    "zurückgedrängtestem": "zurückgedrängt",
    "zurückgedrängtesten": "zurückgedrängt",
    "zurückgedrängtester": "zurückgedrängt",
    "zurückgedrängtestes": "zurückgedrängt",
    "zurückgeeilt": "zurückeilen",
    "zurückgeeilte": "zurückgeeilt",
    "zurückgeeiltem": "zurückgeeilt",
    "zurückgeeilten": "zurückgeeilt",
    "zurückgeeilter": "zurückgeeilt",
    "zurückgeeiltes": "zurückgeeilt",
    "zurückgefahren": "zurückfahren",
    "zurückgefahrene": "zurückgefahren",
    "zurückgefahrenem": "zurückgefahren",
    "zurückgefahrenen": "zurückgefahren",
    "zurückgefahrener": "zurückgefahren",
    "zurückgefahrenes": "zurückgefahren",
    "zurückgefallen": "zurückfallen",
    "zurückgefallene": "zurückgefallen",
    "zurückgefallenem": "zurückgefallen",
    "zurückgefallenen": "zurückgefallen",
    "zurückgefallener": "zurückgefallen",
    "zurückgefallenes": "zurückgefallen",
    "zurückgeflogen": "zurückfliegen",
    "zurückgeflogene": "zurückgeflogen",
    "zurückgeflogenem": "zurückgeflogen",
    "zurückgeflogenen": "zurückgeflogen",
    "zurückgeflogener": "zurückgeflogen",
    "zurückgeflogenes": "zurückgeflogen",
    "zurückgeflossen": "zurückfließen",
    "zurückgeflossene": "zurückgeflossen",
    "zurückgeflossenem": "zurückgeflossen",
    "zurückgeflossenen": "zurückgeflossen",
    "zurückgeflossener": "zurückgeflossen",
    "zurückgeflossenes": "zurückgeflossen",
    "zurückgefordert": "zurückfordern",
    "zurückgeforderte": "zurückgefordert",
    "zurückgefordertem": "zurückgefordert",
    "zurückgeforderten": "zurückgefordert",
    "zurückgeforderter": "zurückgefordert",
    "zurückgefordertes": "zurückgefordert",
    "zurückgefragt": "zurückfragen",
    "zurückgefragte": "zurückgefragt",
    "zurückgefragtem": "zurückgefragt",
    "zurückgefragten": "zurückgefragt",
    "zurückgefragter": "zurückgefragt",
    "zurückgefragtes": "zurückgefragt",
    "zurückgefunden": "zurückfinden",
    "zurückgefundene": "zurückgefunden",
    "zurückgefundenem": "zurückgefunden",
    "zurückgefundenen": "zurückgefunden",
    "zurückgefundener": "zurückgefunden",
    "zurückgefundenes": "zurückgefunden",
    "zurückgeführt": "zurückführen",
    "zurückgeführte": "zurückgeführt",
    "zurückgeführtem": "zurückgeführt",
    "zurückgeführten": "zurückgeführt",
    "zurückgeführter": "zurückgeführt",
    "zurückgeführtes": "zurückgeführt",
    "zurückgegangen": "zurückgehen",
    "zurückgegangene": "zurückgegangen",
    "zurückgegangenem": "zurückgegangen",
    "zurückgegangenen": "zurückgegangen",
    "zurückgegangener": "zurückgegangen",
    "zurückgegangenes": "zurückgegangen",
    "zurückgegeben": "zurückgeben",
    "zurückgegebene": "zurückgegeben",
    "zurückgegebenem": "zurückgegeben",
    "zurückgegebenen": "zurückgegeben",
    "zurückgegebener": "zurückgegeben",
    "zurückgegebenes": "zurückgegeben",
    "zurückgegriffen": "zurückgreifen",
    "zurückgegriffene": "zurückgegriffen",
    "zurückgegriffenem": "zurückgegriffen",
    "zurückgegriffenen": "zurückgegriffen",
    "zurückgegriffener": "zurückgegriffen",
    "zurückgegriffenes": "zurückgegriffen",
    "zurückgehalten": "zurückhalten",
    "zurückgehaltene": "zurückgehalten",
    "zurückgehaltenem": "zurückgehalten",
    "zurückgehaltenen": "zurückgehalten",
    "zurückgehaltener": "zurückgehalten",
    "zurückgehaltenes": "zurückgehalten",
    "zurückgehe": "zurückgehen",
    "zurückgehend": "zurückgehen",
    "zurückgehende": "zurückgehend",
    "zurückgehendem": "zurückgehend",
    "zurückgehenden": "zurückgehend",
    "zurückgehender": "zurückgehend",
    "zurückgehendes": "zurückgehend",
    "zurückgehest": "zurückgehen",
    "zurückgehet": "zurückgehen",
    "zurückgeholt": "zurückholen",
    "zurückgeholte": "zurückgeholt",
    "zurückgeholtem": "zurückgeholt",
    "zurückgeholten": "zurückgeholt",
    "zurückgeholter": "zurückgeholt",
    "zurückgeholtes": "zurückgeholt",
    "zurückgehst": "zurückgehen",
    "zurückgeht": "zurückgehen",
    "zurückgejagt": "zurückjagen",
    "zurückgejagte": "zurückgejagt",
    "zurückgejagtem": "zurückgejagt",
    "zurückgejagten": "zurückgejagt",
    "zurückgejagter": "zurückgejagt",
    "zurückgejagtes": "zurückgejagt",
    "zurückgekauft": "zurückkaufen",
    "zurückgekaufte": "zurückgekauft",
    "zurückgekauftem": "zurückgekauft",
    "zurückgekauften": "zurückgekauft",
    "zurückgekaufter": "zurückgekauft",
    "zurückgekauftes": "zurückgekauft",
    "zurückgekehrt": "zurückkehren",
    "zurückgekehrte": "zurückgekehrt",
    "zurückgekehrtem": "zurückgekehrt",
    "zurückgekehrten": "zurückgekehrt",
    "zurückgekehrter": "zurückgekehrt",
    "zurückgekehrtes": "zurückgekehrt",
    "zurückgeklappt": "zurückklappen",
    "zurückgeklappte": "zurückgeklappt",
    "zurückgeklapptem": "zurückgeklappt",
    "zurückgeklappten": "zurückgeklappt",
    "zurückgeklappter": "zurückgeklappt",
    "zurückgeklapptes": "zurückgeklappt",
    "zurückgekommen": "zurückkommen",
    "zurückgekommene": "zurückgekommen",
    "zurückgekommenem": "zurückgekommen",
    "zurückgekommenen": "zurückgekommen",
    "zurückgekommener": "zurückgekommen",
    "zurückgekommenes": "zurückgekommen",
    "zurückgekämmt": "zurückkämmen",
    "zurückgekämmte": "zurückgekämmt",
    "zurückgekämmtem": "zurückgekämmt",
    "zurückgekämmten": "zurückgekämmt",
    "zurückgekämmter": "zurückgekämmt",
    "zurückgekämmtes": "zurückgekämmt",
    "zurückgelassen": "zurücklassen",
    "zurückgelassene": "zurückgelassen",
    "zurückgelassenem": "zurückgelassen",
    "zurückgelassenen": "zurückgelassen",
    "zurückgelassener": "zurückgelassen",
    "zurückgelassenes": "zurückgelassen",
    "zurückgelaufen": "zurücklaufen",
    "zurückgelaufene": "zurückgelaufen",
    "zurückgelaufenem": "zurückgelaufen",
    "zurückgelaufenen": "zurückgelaufen",
    "zurückgelaufener": "zurückgelaufen",
    "zurückgelaufenes": "zurückgelaufen",
    "zurückgelegen": "zurückliegen",
    "zurückgelegene": "zurückgelegen",
    "zurückgelegenem": "zurückgelegen",
    "zurückgelegenen": "zurückgelegen",
    "zurückgelegener": "zurückgelegen",
    "zurückgelegenes": "zurückgelegen",
    "zurückgelehnt": "zurücklehnen",
    "zurückgelehnte": "zurückgelehnt",
    "zurückgelehntem": "zurückgelehnt",
    "zurückgelehnten": "zurückgelehnt",
    "zurückgelehnter": "zurückgelehnt",
    "zurückgelehntere": "zurückgelehnt",
    "zurückgelehnterem": "zurückgelehnt",
    "zurückgelehnteren": "zurückgelehnt",
    "zurückgelehnterer": "zurückgelehnt",
    "zurückgelehnteres": "zurückgelehnt",
    "zurückgelehntes": "zurückgelehnt",
    "zurückgelehnteste": "zurückgelehnt",
    "zurückgelehntestem": "zurückgelehnt",
    "zurückgelehntesten": "zurückgelehnt",
    "zurückgelehntester": "zurückgelehnt",
    "zurückgelehntestes": "zurückgelehnt",
    "zurückgemeldet": "zurückmelden",
    "zurückgemeldete": "zurückgemeldet",
    "zurückgemeldetem": "zurückgemeldet",
    "zurückgemeldeten": "zurückgemeldet",
    "zurückgemeldeter": "zurückgemeldet",
    "zurückgemeldetes": "zurückgemeldet",
    "zurückgenommen": "zurücknehmen",
    "zurückgenommene": "zurückgenommen",
    "zurückgenommenem": "zurückgenommen",
    "zurückgenommenen": "zurückgenommen",
    "zurückgenommener": "zurückgenommen",
    "zurückgenommenes": "zurückgenommen",
    "zurückgeprallt": "zurückprallen",
    "zurückgeprallte": "zurückgeprallt",
    "zurückgepralltem": "zurückgeprallt",
    "zurückgeprallten": "zurückgeprallt",
    "zurückgeprallter": "zurückgeprallt",
    "zurückgepralltes": "zurückgeprallt",
    "zurückgereist": "zurückreisen",
    "zurückgereiste": "zurückgereist",
    "zurückgereistem": "zurückgereist",
    "zurückgereisten": "zurückgereist",
    "zurückgereister": "zurückgereist",
    "zurückgereistes": "zurückgereist",
    "zurückgerissen": "zurückreißen",
    "zurückgerissene": "zurückgerissen",
    "zurückgerissenem": "zurückgerissen",
    "zurückgerissenen": "zurückgerissen",
    "zurückgerissener": "zurückgerissen",
    "zurückgerissenes": "zurückgerissen",
    "zurückgeritten": "zurückreiten",
    "zurückgerittene": "zurückgeritten",
    "zurückgerittenem": "zurückgeritten",
    "zurückgerittenen": "zurückgeritten",
    "zurückgerittener": "zurückgeritten",
    "zurückgerittenes": "zurückgeritten",
    "zurückgerollt": "zurückrollen",
    "zurückgerollte": "zurückgerollt",
    "zurückgerolltem": "zurückgerollt",
    "zurückgerollten": "zurückgerollt",
    "zurückgerollter": "zurückgerollt",
    "zurückgerolltes": "zurückgerollt",
    "zurückgerufen": "zurückrufen",
    "zurückgerufene": "zurückgerufen",
    "zurückgerufenem": "zurückgerufen",
    "zurückgerufenen": "zurückgerufen",
    "zurückgerufener": "zurückgerufen",
    "zurückgerufenes": "zurückgerufen",
    "zurückgesandt": "zurücksenden",
    "zurückgesandte": "zurückgesandt",
    "zurückgesandtem": "zurückgesandt",
    "zurückgesandten": "zurückgesandt",
    "zurückgesandter": "zurückgesandt",
    "zurückgesandtes": "zurückgesandt",
    "zurückgeschaffen": "zurückschaffen",
    "zurückgeschaffene": "zurückgeschaffen",
    "zurückgeschaffenem": "zurückgeschaffen",
    "zurückgeschaffenen": "zurückgeschaffen",
    "zurückgeschaffener": "zurückgeschaffen",
    "zurückgeschaffenes": "zurückgeschaffen",
    "zurückgeschafft": "zurückschaffen",
    "zurückgeschaffte": "zurückgeschafft",
    "zurückgeschafftem": "zurückgeschafft",
    "zurückgeschafften": "zurückgeschafft",
    "zurückgeschaffter": "zurückgeschafft",
    "zurückgeschafftes": "zurückgeschafft",
    "zurückgeschallt": "zurückschallen",
    "zurückgeschallte": "zurückgeschallt",
    "zurückgeschalltem": "zurückgeschallt",
    "zurückgeschallten": "zurückgeschallt",
    "zurückgeschallter": "zurückgeschallt",
    "zurückgeschalltes": "zurückgeschallt",
    "zurückgeschaltet": "zurückschalten",
    "zurückgeschaltete": "zurückgeschaltet",
    "zurückgeschaltetem": "zurückgeschaltet",
    "zurückgeschalteten": "zurückgeschaltet",
    "zurückgeschalteter": "zurückgeschaltet",
    "zurückgeschaltetes": "zurückgeschaltet",
    "zurückgeschaudert": "zurückschaudern",
    "zurückgeschauderte": "zurückgeschaudert",
    "zurückgeschaudertem": "zurückgeschaudert",
    "zurückgeschauderten": "zurückgeschaudert",
    "zurückgeschauderter": "zurückgeschaudert",
    "zurückgeschaudertere": "zurückgeschaudert",
    "zurückgeschauderterem": "zurückgeschaudert",
    "zurückgeschauderteren": "zurückgeschaudert",
    "zurückgeschauderterer": "zurückgeschaudert",
    "zurückgeschauderteres": "zurückgeschaudert",
    "zurückgeschaudertes": "zurückgeschaudert",
    "zurückgeschauderteste": "zurückgeschaudert",
    "zurückgeschaudertestem": "zurückgeschaudert",
    "zurückgeschaudertesten": "zurückgeschaudert",
    "zurückgeschaudertester": "zurückgeschaudert",
    "zurückgeschaudertestes": "zurückgeschaudert",
    "zurückgeschaut": "zurückschauen",
    "zurückgeschaute": "zurückgeschaut",
    "zurückgeschautem": "zurückgeschaut",
    "zurückgeschauten": "zurückgeschaut",
    "zurückgeschauter": "zurückgeschaut",
    "zurückgeschautes": "zurückgeschaut",
    "zurückgescheucht": "zurückscheuchen",
    "zurückgescheuchte": "zurückgescheucht",
    "zurückgescheuchtem": "zurückgescheucht",
    "zurückgescheuchten": "zurückgescheucht",
    "zurückgescheuchter": "zurückgescheucht",
    "zurückgescheuchtes": "zurückgescheucht",
    "zurückgescheut": "zurückscheuen",
    "zurückgescheute": "zurückgescheut",
    "zurückgescheutem": "zurückgescheut",
    "zurückgescheuten": "zurückgescheut",
    "zurückgescheuter": "zurückgescheut",
    "zurückgescheutes": "zurückgescheut",
    "zurückgeschlagen": "zurückschlagen",
    "zurückgeschlagene": "zurückgeschlagen",
    "zurückgeschlagenem": "zurückgeschlagen",
    "zurückgeschlagenen": "zurückgeschlagen",
    "zurückgeschlagener": "zurückgeschlagen",
    "zurückgeschlagenes": "zurückgeschlagen",
    "zurückgeschnellt": "zurückschnellen",
    "zurückgeschnellte": "zurückgeschnellt",
    "zurückgeschnelltem": "zurückgeschnellt",
    "zurückgeschnellten": "zurückgeschnellt",
    "zurückgeschnellter": "zurückgeschnellt",
    "zurückgeschnelltes": "zurückgeschnellt",
    "zurückgeschoben": "zurückschieben",
    "zurückgeschobene": "zurückgeschoben",
    "zurückgeschobenem": "zurückgeschoben",
    "zurückgeschobenen": "zurückgeschoben",
    "zurückgeschobener": "zurückgeschoben",
    "zurückgeschobenes": "zurückgeschoben",
    "zurückgeschraubt": "zurückschrauben",
    "zurückgeschraubte": "zurückgeschraubt",
    "zurückgeschraubtem": "zurückgeschraubt",
    "zurückgeschraubten": "zurückgeschraubt",
    "zurückgeschraubter": "zurückgeschraubt",
    "zurückgeschraubtes": "zurückgeschraubt",
    "zurückgeschreckt": "zurückschrecken",
    "zurückgeschreckte": "zurückgeschreckt",
    "zurückgeschrecktem": "zurückgeschreckt",
    "zurückgeschreckten": "zurückgeschreckt",
    "zurückgeschreckter": "zurückgeschreckt",
    "zurückgeschrecktere": "zurückgeschreckt",
    "zurückgeschreckterem": "zurückgeschreckt",
    "zurückgeschreckteren": "zurückgeschreckt",
    "zurückgeschreckterer": "zurückgeschreckt",
    "zurückgeschreckteres": "zurückgeschreckt",
    "zurückgeschrecktes": "zurückgeschreckt",
    "zurückgeschreckteste": "zurückgeschreckt",
    "zurückgeschrecktestem": "zurückgeschreckt",
    "zurückgeschrecktesten": "zurückgeschreckt",
    "zurückgeschrecktester": "zurückgeschreckt",
    "zurückgeschrecktestes": "zurückgeschreckt",
    "zurückgeschrieben": "zurückschreiben",
    "zurückgeschriebene": "zurückgeschrieben",
    "zurückgeschriebenem": "zurückgeschrieben",
    "zurückgeschriebenen": "zurückgeschrieben",
    "zurückgeschriebener": "zurückgeschrieben",
    "zurückgeschriebenes": "zurückgeschrieben",
    "zurückgeschrocken": "zurückschrecken",
    "zurückgeschrockene": "zurückgeschrocken",
    "zurückgeschrockenem": "zurückgeschrocken",
    "zurückgeschrockenen": "zurückgeschrocken",
    "zurückgeschrockener": "zurückgeschrocken",
    "zurückgeschrockenes": "zurückgeschrocken",
    "zurückgeschwommen": "zurückschwimmen",
    "zurückgeschwommene": "zurückgeschwommen",
    "zurückgeschwommenem": "zurückgeschwommen",
    "zurückgeschwommenen": "zurückgeschwommen",
    "zurückgeschwommener": "zurückgeschwommen",
    "zurückgeschwommenes": "zurückgeschwommen",
    "zurückgesehnt": "zurücksehnen",
    "zurückgesehnte": "zurückgesehnt",
    "zurückgesehntem": "zurückgesehnt",
    "zurückgesehnten": "zurückgesehnt",
    "zurückgesehnter": "zurückgesehnt",
    "zurückgesehntere": "zurückgesehnt",
    "zurückgesehnterem": "zurückgesehnt",
    "zurückgesehnteren": "zurückgesehnt",
    "zurückgesehnterer": "zurückgesehnt",
    "zurückgesehnteres": "zurückgesehnt",
    "zurückgesehntes": "zurückgesehnt",
    "zurückgesehnteste": "zurückgesehnt",
    "zurückgesehntestem": "zurückgesehnt",
    "zurückgesehntesten": "zurückgesehnt",
    "zurückgesehntester": "zurückgesehnt",
    "zurückgesehntestes": "zurückgesehnt",
    "zurückgesendet": "zurücksenden",
    "zurückgesendete": "zurückgesendet",
    "zurückgesendetem": "zurückgesendet",
    "zurückgesendeten": "zurückgesendet",
    "zurückgesendeter": "zurückgesendet",
    "zurückgesendetes": "zurückgesendet",
    "zurückgesetzt": "zurücksetzen",
    "zurückgesetzte": "zurückgesetzt",
    "zurückgesetztem": "zurückgesetzt",
    "zurückgesetzten": "zurückgesetzt",
    "zurückgesetzter": "zurückgesetzt",
    "zurückgesetztes": "zurückgesetzt",
    "zurückgesprungen": "zurückspringen",
    "zurückgesprungene": "zurückgesprungen",
    "zurückgesprungenem": "zurückgesprungen",
    "zurückgesprungenen": "zurückgesprungen",
    "zurückgesprungener": "zurückgesprungen",
    "zurückgesprungenes": "zurückgesprungen",
    "zurückgespult": "zurückspulen",
    "zurückgespulte": "zurückgespult",
    "zurückgespultem": "zurückgespult",
    "zurückgespulten": "zurückgespult",
    "zurückgespulter": "zurückgespult",
    "zurückgespultes": "zurückgespult",
    "zurückgestanden": "zurückstehen",
    "zurückgestandene": "zurückgestanden",
    "zurückgestandenem": "zurückgestanden",
    "zurückgestandenen": "zurückgestanden",
    "zurückgestandener": "zurückgestanden",
    "zurückgestandenes": "zurückgestanden",
    "zurückgestellt": "zurückstellen",
    "zurückgestellte": "zurückgestellt",
    "zurückgestelltem": "zurückgestellt",
    "zurückgestellten": "zurückgestellt",
    "zurückgestellter": "zurückgestellt",
    "zurückgestelltes": "zurückgestellt",
    "zurückgestoßen": "zurückstoßen",
    "zurückgestoßene": "zurückgestoßen",
    "zurückgestoßenem": "zurückgestoßen",
    "zurückgestoßenen": "zurückgestoßen",
    "zurückgestoßener": "zurückgestoßen",
    "zurückgestoßenes": "zurückgestoßen",
    "zurückgestrahlt": "zurückstrahlen",
    "zurückgestrahlte": "zurückgestrahlt",
    "zurückgestrahltem": "zurückgestrahlt",
    "zurückgestrahlten": "zurückgestrahlt",
    "zurückgestrahlter": "zurückgestrahlt",
    "zurückgestrahltere": "zurückgestrahlt",
    "zurückgestrahlterem": "zurückgestrahlt",
    "zurückgestrahlteren": "zurückgestrahlt",
    "zurückgestrahlterer": "zurückgestrahlt",
    "zurückgestrahlteres": "zurückgestrahlt",
    "zurückgestrahltes": "zurückgestrahlt",
    "zurückgestrahlteste": "zurückgestrahlt",
    "zurückgestrahltestem": "zurückgestrahlt",
    "zurückgestrahltesten": "zurückgestrahlt",
    "zurückgestrahltester": "zurückgestrahlt",
    "zurückgestrahltestes": "zurückgestrahlt",
    "zurückgestreift": "zurückstreifen",
    "zurückgestreifte": "zurückgestreift",
    "zurückgestreiftem": "zurückgestreift",
    "zurückgestreiften": "zurückgestreift",
    "zurückgestreifter": "zurückgestreift",
    "zurückgestreiftes": "zurückgestreift",
    "zurückgestrichen": "zurückstreichen",
    "zurückgestrichene": "zurückgestrichen",
    "zurückgestrichenem": "zurückgestrichen",
    "zurückgestrichenen": "zurückgestrichen",
    "zurückgestrichener": "zurückgestrichen",
    "zurückgestrichenes": "zurückgestrichen",
    "zurückgeströmt": "zurückströmen",
    "zurückgeströmte": "zurückgeströmt",
    "zurückgeströmtem": "zurückgeströmt",
    "zurückgeströmten": "zurückgeströmt",
    "zurückgeströmter": "zurückgeströmt",
    "zurückgeströmtes": "zurückgeströmt",
    "zurückgestutzt": "zurückstutzen",
    "zurückgestutzte": "zurückgestutzt",
    "zurückgestutztem": "zurückgestutzt",
    "zurückgestutzten": "zurückgestutzt",
    "zurückgestutzter": "zurückgestutzt",
    "zurückgestutztes": "zurückgestutzt",
    "zurückgesunken": "zurücksinken",
    "zurückgesunkene": "zurückgesunken",
    "zurückgesunkenem": "zurückgesunken",
    "zurückgesunkenen": "zurückgesunken",
    "zurückgesunkener": "zurückgesunken",
    "zurückgesunkenes": "zurückgesunken",
    "zurückgetaumelt": "zurücktaumeln",
    "zurückgetaumelte": "zurückgetaumelt",
    "zurückgetaumeltem": "zurückgetaumelt",
    "zurückgetaumelten": "zurückgetaumelt",
    "zurückgetaumelter": "zurückgetaumelt",
    "zurückgetaumeltes": "zurückgetaumelt",
    "zurückgetragen": "zurücktragen",
    "zurückgetragene": "zurückgetragen",
    "zurückgetragenem": "zurückgetragen",
    "zurückgetragenen": "zurückgetragen",
    "zurückgetragener": "zurückgetragen",
    "zurückgetragenes": "zurückgetragen",
    "zurückgetreten": "zurücktreten",
    "zurückgetretene": "zurückgetreten",
    "zurückgetretenem": "zurückgetreten",
    "zurückgetretenen": "zurückgetreten",
    "zurückgetretener": "zurückgetreten",
    "zurückgetretenes": "zurückgetreten",
    "zurückgetrieben": "zurücktreiben",
    "zurückgetriebene": "zurückgetrieben",
    "zurückgetriebenem": "zurückgetrieben",
    "zurückgetriebenen": "zurückgetrieben",
    "zurückgetriebener": "zurückgetrieben",
    "zurückgetriebenes": "zurückgetrieben",
    "zurückgewandert": "zurückwandern",
    "zurückgewanderte": "zurückgewandert",
    "zurückgewandertem": "zurückgewandert",
    "zurückgewanderten": "zurückgewandert",
    "zurückgewanderter": "zurückgewandert",
    "zurückgewandertes": "zurückgewandert",
    "zurückgewann": "zurückgewinnen",
    "zurückgewannen": "zurückgewinnen",
    "zurückgewannst": "zurückgewinnen",
    "zurückgewannt": "zurückgewinnen",
    "zurückgeweicht": "zurückweichen",
    "zurückgeweichte": "zurückgeweicht",
    "zurückgeweichtem": "zurückgeweicht",
    "zurückgeweichten": "zurückgeweicht",
    "zurückgeweichter": "zurückgeweicht",
    "zurückgeweichtes": "zurückgeweicht",
    "zurückgewichen": "zurückweichen",
    "zurückgewichene": "zurückgewichen",
    "zurückgewichenem": "zurückgewichen",
    "zurückgewichenen": "zurückgewichen",
    "zurückgewichener": "zurückgewichen",
    "zurückgewichenes": "zurückgewichen",
    "zurückgewiesen": "zurückweisen",
    "zurückgewiesene": "zurückgewiesen",
    "zurückgewiesenem": "zurückgewiesen",
    "zurückgewiesenen": "zurückgewiesen",
    "zurückgewiesener": "zurückgewiesen",
    "zurückgewiesenere": "zurückgewiesen",
    "zurückgewiesenerem": "zurückgewiesen",
    "zurückgewieseneren": "zurückgewiesen",
    "zurückgewiesenerer": "zurückgewiesen",
    "zurückgewieseneres": "zurückgewiesen",
    "zurückgewiesenes": "zurückgewiesen",
    "zurückgewiesenste": "zurückgewiesen",
    "zurückgewiesenstem": "zurückgewiesen",
    "zurückgewiesensten": "zurückgewiesen",
    "zurückgewiesenster": "zurückgewiesen",
    "zurückgewiesenstes": "zurückgewiesen",
    "zurückgewinne": "zurückgewinnen",
    "zurückgewinnend": "zurückgewinnen",
    "zurückgewinnende": "zurückgewinnend",
    "zurückgewinnendem": "zurückgewinnend",
    "zurückgewinnenden": "zurückgewinnend",
    "zurückgewinnender": "zurückgewinnend",
    "zurückgewinnendes": "zurückgewinnend",
    "zurückgewinnest": "zurückgewinnen",
    "zurückgewinnet": "zurückgewinnen",
    "zurückgewinnst": "zurückgewinnen",
    "zurückgewinnt": "zurückgewinnen",
    "zurückgewirkt": "zurückwirken",
    "zurückgewirkte": "zurückgewirkt",
    "zurückgewirktem": "zurückgewirkt",
    "zurückgewirkten": "zurückgewirkt",
    "zurückgewirkter": "zurückgewirkt",
    "zurückgewirktes": "zurückgewirkt",
    "zurückgewonnen": "zurückgewinnen",
    "zurückgewonnene": "zurückgewonnen",
    "zurückgewonnenem": "zurückgewonnen",
    "zurückgewonnenen": "zurückgewonnen",
    "zurückgewonnener": "zurückgewonnen",
    "zurückgewonnenes": "zurückgewonnen",
    "zurückgeworfen": "zurückwerfen",
    "zurückgeworfene": "zurückgeworfen",
    "zurückgeworfenem": "zurückgeworfen",
    "zurückgeworfenen": "zurückgeworfen",
    "zurückgeworfener": "zurückgeworfen",
    "zurückgeworfenere": "zurückgeworfen",
    "zurückgeworfenerem": "zurückgeworfen",
    "zurückgeworfeneren": "zurückgeworfen",
    "zurückgeworfenerer": "zurückgeworfen",
    "zurückgeworfeneres": "zurückgeworfen",
    "zurückgeworfenes": "zurückgeworfen",
    "zurückgeworfenste": "zurückgeworfen",
    "zurückgeworfenstem": "zurückgeworfen",
    "zurückgeworfensten": "zurückgeworfen",
    "zurückgeworfenster": "zurückgeworfen",
    "zurückgeworfenstes": "zurückgeworfen",
    "zurückgewänne": "zurückgewinnen",
    "zurückgewännen": "zurückgewinnen",
    "zurückgewännest": "zurückgewinnen",
    "zurückgewännet": "zurückgewinnen",
    "zurückgewünscht": "zurückwünschen",
    "zurückgewünschte": "zurückgewünscht",
    "zurückgewünschtem": "zurückgewünscht",
    "zurückgewünschten": "zurückgewünscht",
    "zurückgewünschter": "zurückgewünscht",
    "zurückgewünschtes": "zurückgewünscht",
    "zurückgezahlt": "zurückzahlen",
    "zurückgezahlte": "zurückgezahlt",
    "zurückgezahltem": "zurückgezahlt",
    "zurückgezahlten": "zurückgezahlt",
    "zurückgezahlter": "zurückgezahlt",
    "zurückgezahltes": "zurückgezahlt",
    "zurückgezogen": "zurückziehen",
    "zurückgezogene": "zurückgezogen",
    "zurückgezogenem": "zurückgezogen",
    "zurückgezogenen": "zurückgezogen",
    "zurückgezogener": "zurückgezogen",
    "zurückgezogenere": "zurückgezogen",
    "zurückgezogenerem": "zurückgezogen",
    "zurückgezogeneren": "zurückgezogen",
    "zurückgezogenerer": "zurückgezogen",
    "zurückgezogeneres": "zurückgezogen",
    "zurückgezogenes": "zurückgezogen",
    "zurückgezogenste": "zurückgezogen",
    "zurückgezogenstem": "zurückgezogen",
    "zurückgezogensten": "zurückgezogen",
    "zurückgezogenster": "zurückgezogen",
    "zurückgezogenstes": "zurückgezogen",
    "zurückgibst": "zurückgeben",
    "zurückgibt": "zurückgeben",
    "zurückging": "zurückgehen",
    "zurückginge": "zurückgehen",
    "zurückgingen": "zurückgehen",
    "zurückgingest": "zurückgehen",
    "zurückginget": "zurückgehen",
    "zurückgingst": "zurückgehen",
    "zurückgingt": "zurückgehen",
    "zurückgreife": "zurückgreifen",
    "zurückgreifend": "zurückgreifen",
    "zurückgreifende": "zurückgreifend",
    "zurückgreifendem": "zurückgreifend",
    "zurückgreifenden": "zurückgreifend",
    "zurückgreifender": "zurückgreifend",
    "zurückgreifendes": "zurückgreifend",
    "zurückgreifest": "zurückgreifen",
    "zurückgreifet": "zurückgreifen",
    "zurückgreifst": "zurückgreifen",
    "zurückgreift": "zurückgreifen",
    "zurückgriff": "zurückgreifen",
    "zurückgriffe": "zurückgreifen",
    "zurückgriffen": "zurückgreifen",
    "zurückgriffest": "zurückgreifen",
    "zurückgriffet": "zurückgreifen",
    "zurückgriffst": "zurückgreifen",
    "zurückgrifft": "zurückgreifen",
    "zurückgäbe": "zurückgeben",
    "zurückgäben": "zurückgeben",
    "zurückgäbest": "zurückgeben",
    "zurückgäbet": "zurückgeben",
    "zurückhalte": "zurückhalten",
    "zurückhaltend": "zurückhalten",
    "zurückhaltende": "zurückhaltend",
    "zurückhaltendem": "zurückhaltend",
    "zurückhaltenden": "zurückhaltend",
    "zurückhaltender": "zurückhaltend",
    "zurückhaltendere": "zurückhaltend",
    "zurückhaltenderem": "zurückhaltend",
    "zurückhaltenderen": "zurückhaltend",
    "zurückhaltenderer": "zurückhaltend",
    "zurückhaltenderes": "zurückhaltend",
    "zurückhaltendes": "zurückhaltend",
    "zurückhaltendste": "zurückhaltend",
    "zurückhaltendstem": "zurückhaltend",
    "zurückhaltendsten": "zurückhaltend",
    "zurückhaltendster": "zurückhaltend",
    "zurückhaltendstes": "zurückhaltend",
    "zurückhaltest": "zurückhalten",
    "zurückhaltet": "zurückhalten",
    "zurückhielt": "zurückhalten",
    "zurückhielte": "zurückhalten",
    "zurückhielten": "zurückhalten",
    "zurückhieltest": "zurückhalten",
    "zurückhieltet": "zurückhalten",
    "zurückhole": "zurückholen",
    "zurückholend": "zurückholen",
    "zurückholende": "zurückholend",
    "zurückholendem": "zurückholend",
    "zurückholenden": "zurückholend",
    "zurückholender": "zurückholend",
    "zurückholendes": "zurückholend",
    "zurückholest": "zurückholen",
    "zurückholet": "zurückholen",
    "zurückholst": "zurückholen",
    "zurückholt": "zurückholen",
    "zurückholte": "zurückholen",
    "zurückholten": "zurückholen",
    "zurückholtest": "zurückholen",
    "zurückholtet": "zurückholen",
    "zurückhält": "zurückhalten",
    "zurückhältst": "zurückhalten",
    "zurückjage": "zurückjagen",
    "zurückjagend": "zurückjagen",
    "zurückjagende": "zurückjagend",
    "zurückjagendem": "zurückjagend",
    "zurückjagenden": "zurückjagend",
    "zurückjagender": "zurückjagend",
    "zurückjagendes": "zurückjagend",
    "zurückjagest": "zurückjagen",
    "zurückjaget": "zurückjagen",
    "zurückjagst": "zurückjagen",
    "zurückjagt": "zurückjagen",
    "zurückjagte": "zurückjagen",
    "zurückjagten": "zurückjagen",
    "zurückjagtest": "zurückjagen",
    "zurückjagtet": "zurückjagen",
    "zurückkam": "zurückkommen",
    "zurückkamen": "zurückkommen",
    "zurückkamst": "zurückkommen",
    "zurückkamt": "zurückkommen",
    "zurückkaufe": "zurückkaufen",
    "zurückkaufend": "zurückkaufen",
    "zurückkaufende": "zurückkaufend",
    "zurückkaufendem": "zurückkaufend",
    "zurückkaufenden": "zurückkaufend",
    "zurückkaufender": "zurückkaufend",
    "zurückkaufendes": "zurückkaufend",
    "zurückkaufest": "zurückkaufen",
    "zurückkaufet": "zurückkaufen",
    "zurückkaufst": "zurückkaufen",
    "zurückkauft": "zurückkaufen",
    "zurückkaufte": "zurückkaufen",
    "zurückkauften": "zurückkaufen",
    "zurückkauftest": "zurückkaufen",
    "zurückkauftet": "zurückkaufen",
    "zurückkehre": "zurückkehren",
    "zurückkehrend": "zurückkehren",
    "zurückkehrende": "zurückkehrend",
    "zurückkehrendem": "zurückkehrend",
    "zurückkehrenden": "zurückkehrend",
    "zurückkehrender": "zurückkehrend",
    "zurückkehrendes": "zurückkehrend",
    "zurückkehrest": "zurückkehren",
    "zurückkehret": "zurückkehren",
    "zurückkehrst": "zurückkehren",
    "zurückkehrt": "zurückkehren",
    "zurückkehrte": "zurückkehren",
    "zurückkehrten": "zurückkehren",
    "zurückkehrtest": "zurückkehren",
    "zurückkehrtet": "zurückkehren",
    "zurückklappe": "zurückklappen",
    "zurückklappend": "zurückklappen",
    "zurückklappende": "zurückklappend",
    "zurückklappendem": "zurückklappend",
    "zurückklappenden": "zurückklappend",
    "zurückklappender": "zurückklappend",
    "zurückklappendes": "zurückklappend",
    "zurückklappest": "zurückklappen",
    "zurückklappet": "zurückklappen",
    "zurückklappst": "zurückklappen",
    "zurückklappt": "zurückklappen",
    "zurückklappte": "zurückklappen",
    "zurückklappten": "zurückklappen",
    "zurückklapptest": "zurückklappen",
    "zurückklapptet": "zurückklappen",
    "zurückkomme": "zurückkommen",
    "zurückkommend": "zurückkommen",
    "zurückkommende": "zurückkommend",
    "zurückkommendem": "zurückkommend",
    "zurückkommenden": "zurückkommend",
    "zurückkommender": "zurückkommend",
    "zurückkommendes": "zurückkommend",
    "zurückkommest": "zurückkommen",
    "zurückkommet": "zurückkommen",
    "zurückkommst": "zurückkommen",
    "zurückkommt": "zurückkommen",
    "zurückkäme": "zurückkommen",
    "zurückkämen": "zurückkommen",
    "zurückkämest": "zurückkommen",
    "zurückkämet": "zurückkommen",
    "zurückkämme": "zurückkämmen",
    "zurückkämmend": "zurückkämmen",
    "zurückkämmende": "zurückkämmend",
    "zurückkämmendem": "zurückkämmend",
    "zurückkämmenden": "zurückkämmend",
    "zurückkämmender": "zurückkämmend",
    "zurückkämmendes": "zurückkämmend",
    "zurückkämmest": "zurückkämmen",
    "zurückkämmet": "zurückkämmen",
    "zurückkämmst": "zurückkämmen",
    "zurückkämmt": "zurückkämmen",
    "zurückkämmte": "zurückkämmen",
    "zurückkämmten": "zurückkämmen",
    "zurückkämmtest": "zurückkämmen",
    "zurückkämmtet": "zurückkämmen",
    "zurücklag": "zurückliegen",
    "zurücklagen": "zurückliegen",
    "zurücklagst": "zurückliegen",
    "zurücklagt": "zurückliegen",
    "zurücklasse": "zurücklassen",
    "zurücklassend": "zurücklassen",
    "zurücklassende": "zurücklassend",
    "zurücklassendem": "zurücklassend",
    "zurücklassenden": "zurücklassend",
    "zurücklassender": "zurücklassend",
    "zurücklassendes": "zurücklassend",
    "zurücklassest": "zurücklassen",
    "zurücklasset": "zurücklassen",
    "zurücklaufe": "zurücklaufen",
    "zurücklaufend": "zurücklaufen",
    "zurücklaufende": "zurücklaufend",
    "zurücklaufendem": "zurücklaufend",
    "zurücklaufenden": "zurücklaufend",
    "zurücklaufender": "zurücklaufend",
    "zurücklaufendes": "zurücklaufend",
    "zurücklaufest": "zurücklaufen",
    "zurücklaufet": "zurücklaufen",
    "zurücklauft": "zurücklaufen",
    "zurücklaßt": "zurücklassen",
    "zurücklehne": "zurücklehnen",
    "zurücklehnend": "zurücklehnen",
    "zurücklehnende": "zurücklehnend",
    "zurücklehnendem": "zurücklehnend",
    "zurücklehnenden": "zurücklehnend",
    "zurücklehnender": "zurücklehnend",
    "zurücklehnendere": "zurücklehnend",
    "zurücklehnenderem": "zurücklehnend",
    "zurücklehnenderen": "zurücklehnend",
    "zurücklehnenderer": "zurücklehnend",
    "zurücklehnenderes": "zurücklehnend",
    "zurücklehnendes": "zurücklehnend",
    "zurücklehnendste": "zurücklehnend",
    "zurücklehnendstem": "zurücklehnend",
    "zurücklehnendsten": "zurücklehnend",
    "zurücklehnendster": "zurücklehnend",
    "zurücklehnendstes": "zurücklehnend",
    "zurücklehnest": "zurücklehnen",
    "zurücklehnet": "zurücklehnen",
    "zurücklehnst": "zurücklehnen",
    "zurücklehnt": "zurücklehnen",
    "zurücklehnte": "zurücklehnen",
    "zurücklehnten": "zurücklehnen",
    "zurücklehntest": "zurücklehnen",
    "zurücklehntet": "zurücklehnen",
    "zurücklief": "zurücklaufen",
    "zurückliefe": "zurücklaufen",
    "zurückliefen": "zurücklaufen",
    "zurückliefest": "zurücklaufen",
    "zurückliefet": "zurücklaufen",
    "zurückliefst": "zurücklaufen",
    "zurücklieft": "zurücklaufen",
    "zurückliege": "zurückliegen",
    "zurückliegend": "zurückliegen",
    "zurückliegende": "zurückliegend",
    "zurückliegendem": "zurückliegend",
    "zurückliegenden": "zurückliegend",
    "zurückliegender": "zurückliegend",
    "zurückliegendere": "zurückliegend",
    "zurückliegenderem": "zurückliegend",
    "zurückliegenderen": "zurückliegend",
    "zurückliegenderer": "zurückliegend",
    "zurückliegenderes": "zurückliegend",
    "zurückliegendes": "zurückliegend",
    "zurückliegendste": "zurückliegend",
    "zurückliegendstem": "zurückliegend",
    "zurückliegendsten": "zurückliegend",
    "zurückliegendster": "zurückliegend",
    "zurückliegendstes": "zurückliegend",
    "zurückliegest": "zurückliegen",
    "zurücklieget": "zurückliegen",
    "zurückliegst": "zurückliegen",
    "zurückliegt": "zurückliegen",
    "zurückließ": "zurücklassen",
    "zurückließe": "zurücklassen",
    "zurückließen": "zurücklassen",
    "zurückließest": "zurücklassen",
    "zurückließet": "zurücklassen",
    "zurückließt": "zurücklassen",
    "zurückläge": "zurückliegen",
    "zurücklägen": "zurückliegen",
    "zurücklägest": "zurückliegen",
    "zurückläget": "zurückliegen",
    "zurückläufst": "zurücklaufen",
    "zurückläuft": "zurücklaufen",
    "zurückläßt": "zurücklassen",
    "zurückmarschiere": "zurückmarschieren",
    "zurückmarschierend": "zurückmarschieren",
    "zurückmarschierende": "zurückmarschierend",
    "zurückmarschierendem": "zurückmarschierend",
    "zurückmarschierenden": "zurückmarschierend",
    "zurückmarschierender": "zurückmarschierend",
    "zurückmarschierendes": "zurückmarschierend",
    "zurückmarschierest": "zurückmarschieren",
    "zurückmarschieret": "zurückmarschieren",
    "zurückmarschierst": "zurückmarschieren",
    "zurückmarschiert": "zurückmarschieren",
    "zurückmarschierte": "zurückmarschieren",
    "zurückmarschiertem": "zurückmarschiert",
    "zurückmarschierten": "zurückmarschieren",
    "zurückmarschierter": "zurückmarschiert",
    "zurückmarschiertes": "zurückmarschiert",
    "zurückmarschiertest": "zurückmarschieren",
    "zurückmarschiertet": "zurückmarschieren",
    "zurückmelde": "zurückmelden",
    "zurückmeldend": "zurückmelden",
    "zurückmeldende": "zurückmeldend",
    "zurückmeldendem": "zurückmeldend",
    "zurückmeldenden": "zurückmeldend",
    "zurückmeldender": "zurückmeldend",
    "zurückmeldendes": "zurückmeldend",
    "zurückmeldest": "zurückmelden",
    "zurückmeldet": "zurückmelden",
    "zurückmeldete": "zurückmelden",
    "zurückmeldeten": "zurückmelden",
    "zurückmeldetest": "zurückmelden",
    "zurückmeldetet": "zurückmelden",
    "zurücknahm": "zurücknehmen",
    "zurücknahmen": "zurücknehmen",
    "zurücknahmst": "zurücknehmen",
    "zurücknahmt": "zurücknehmen",
    "zurücknehme": "zurücknehmen",
    "zurücknehmend": "zurücknehmen",
    "zurücknehmende": "zurücknehmend",
    "zurücknehmendem": "zurücknehmend",
    "zurücknehmenden": "zurücknehmend",
    "zurücknehmender": "zurücknehmend",
    "zurücknehmendes": "zurücknehmend",
    "zurücknehmest": "zurücknehmen",
    "zurücknehmet": "zurücknehmen",
    "zurücknehmt": "zurücknehmen",
    "zurücknimmst": "zurücknehmen",
    "zurücknimmt": "zurücknehmen",
    "zurücknähme": "zurücknehmen",
    "zurücknähmen": "zurücknehmen",
    "zurücknähmest": "zurücknehmen",
    "zurücknähmet": "zurücknehmen",
    "zurückpralle": "zurückprallen",
    "zurückprallend": "zurückprallen",
    "zurückprallende": "zurückprallend",
    "zurückprallendem": "zurückprallend",
    "zurückprallenden": "zurückprallend",
    "zurückprallender": "zurückprallend",
    "zurückprallendes": "zurückprallend",
    "zurückprallest": "zurückprallen",
    "zurückprallet": "zurückprallen",
    "zurückprallst": "zurückprallen",
    "zurückprallt": "zurückprallen",
    "zurückprallte": "zurückprallen",
    "zurückprallten": "zurückprallen",
    "zurückpralltest": "zurückprallen",
    "zurückpralltet": "zurückprallen",
    "zurückreise": "zurückreisen",
    "zurückreisend": "zurückreisen",
    "zurückreisende": "zurückreisend",
    "zurückreisendem": "zurückreisend",
    "zurückreisenden": "zurückreisend",
    "zurückreisender": "zurückreisend",
    "zurückreisendes": "zurückreisend",
    "zurückreisest": "zurückreisen",
    "zurückreiset": "zurückreisen",
    "zurückreist": "zurückreisen",
    "zurückreiste": "zurückreisen",
    "zurückreisten": "zurückreisen",
    "zurückreistest": "zurückreisen",
    "zurückreistet": "zurückreisen",
    "zurückreite": "zurückreiten",
    "zurückreitend": "zurückreiten",
    "zurückreitende": "zurückreitend",
    "zurückreitendem": "zurückreitend",
    "zurückreitenden": "zurückreitend",
    "zurückreitender": "zurückreitend",
    "zurückreitendes": "zurückreitend",
    "zurückreitest": "zurückreiten",
    "zurückreitet": "zurückreiten",
    "zurückreiße": "zurückreißen",
    "zurückreißend": "zurückreißen",
    "zurückreißende": "zurückreißend",
    "zurückreißendem": "zurückreißend",
    "zurückreißenden": "zurückreißend",
    "zurückreißender": "zurückreißend",
    "zurückreißendes": "zurückreißend",
    "zurückreißest": "zurückreißen",
    "zurückreißet": "zurückreißen",
    "zurückreißt": "zurückreißen",
    "zurückrief": "zurückrufen",
    "zurückriefe": "zurückrufen",
    "zurückriefen": "zurückrufen",
    "zurückriefest": "zurückrufen",
    "zurückriefet": "zurückrufen",
    "zurückriefst": "zurückrufen",
    "zurückrieft": "zurückrufen",
    "zurückrisse": "zurückreißen",
    "zurückrissen": "zurückreißen",
    "zurückrissest": "zurückreißen",
    "zurückrisset": "zurückreißen",
    "zurückritt": "zurückreiten",
    "zurückritte": "zurückreiten",
    "zurückritten": "zurückreiten",
    "zurückrittest": "zurückreiten",
    "zurückrittet": "zurückreiten",
    "zurückriß": "zurückreißen",
    "zurückrißt": "zurückreißen",
    "zurückrolle": "zurückrollen",
    "zurückrollend": "zurückrollen",
    "zurückrollende": "zurückrollend",
    "zurückrollendem": "zurückrollend",
    "zurückrollenden": "zurückrollend",
    "zurückrollender": "zurückrollend",
    "zurückrollendes": "zurückrollend",
    "zurückrollest": "zurückrollen",
    "zurückrollet": "zurückrollen",
    "zurückrollst": "zurückrollen",
    "zurückrollt": "zurückrollen",
    "zurückrollte": "zurückrollen",
    "zurückrollten": "zurückrollen",
    "zurückrolltest": "zurückrollen",
    "zurückrolltet": "zurückrollen",
    "zurückrufe": "zurückrufen",
    "zurückrufend": "zurückrufen",
    "zurückrufende": "zurückrufend",
    "zurückrufendem": "zurückrufend",
    "zurückrufenden": "zurückrufend",
    "zurückrufender": "zurückrufend",
    "zurückrufendes": "zurückrufend",
    "zurückrufest": "zurückrufen",
    "zurückrufet": "zurückrufen",
    "zurückrufst": "zurückrufen",
    "zurückruft": "zurückrufen",
    "zurücksandte": "zurücksenden",
    "zurücksandten": "zurücksenden",
    "zurücksandtest": "zurücksenden",
    "zurücksandtet": "zurücksenden",
    "zurücksank": "zurücksinken",
    "zurücksanken": "zurücksinken",
    "zurücksankst": "zurücksinken",
    "zurücksankt": "zurücksinken",
    "zurückschaffe": "zurückschaffen",
    "zurückschaffend": "zurückschaffen",
    "zurückschaffende": "zurückschaffend",
    "zurückschaffendem": "zurückschaffend",
    "zurückschaffenden": "zurückschaffend",
    "zurückschaffender": "zurückschaffend",
    "zurückschaffendes": "zurückschaffend",
    "zurückschaffest": "zurückschaffen",
    "zurückschaffet": "zurückschaffen",
    "zurückschaffst": "zurückschaffen",
    "zurückschafft": "zurückschaffen",
    "zurückschaffte": "zurückschaffen",
    "zurückschafften": "zurückschaffen",
    "zurückschafftest": "zurückschaffen",
    "zurückschafftet": "zurückschaffen",
    "zurückschalle": "zurückschallen",
    "zurückschallend": "zurückschallen",
    "zurückschallende": "zurückschallend",
    "zurückschallendem": "zurückschallend",
    "zurückschallenden": "zurückschallend",
    "zurückschallender": "zurückschallend",
    "zurückschallendes": "zurückschallend",
    "zurückschallest": "zurückschallen",
    "zurückschallet": "zurückschallen",
    "zurückschallst": "zurückschallen",
    "zurückschallt": "zurückschallen",
    "zurückschallte": "zurückschallen",
    "zurückschallten": "zurückschallen",
    "zurückschalltest": "zurückschallen",
    "zurückschalltet": "zurückschallen",
    "zurückschalte": "zurückschalten",
    "zurückschaltend": "zurückschalten",
    "zurückschaltende": "zurückschaltend",
    "zurückschaltendem": "zurückschaltend",
    "zurückschaltenden": "zurückschaltend",
    "zurückschaltender": "zurückschaltend",
    "zurückschaltendes": "zurückschaltend",
    "zurückschaltest": "zurückschalten",
    "zurückschaltet": "zurückschalten",
    "zurückschaltete": "zurückschalten",
    "zurückschalteten": "zurückschalten",
    "zurückschaltetest": "zurückschalten",
    "zurückschaltetet": "zurückschalten",
    "zurückschaudere": "zurückschaudern",
    "zurückschaudernd": "zurückschaudern",
    "zurückschaudernde": "zurückschaudernd",
    "zurückschauderndem": "zurückschaudernd",
    "zurückschaudernden": "zurückschaudernd",
    "zurückschaudernder": "zurückschaudernd",
    "zurückschauderndere": "zurückschaudernd",
    "zurückschaudernderem": "zurückschaudernd",
    "zurückschaudernderen": "zurückschaudernd",
    "zurückschaudernderer": "zurückschaudernd",
    "zurückschaudernderes": "zurückschaudernd",
    "zurückschauderndes": "zurückschaudernd",
    "zurückschauderndste": "zurückschaudernd",
    "zurückschauderndstem": "zurückschaudernd",
    "zurückschauderndsten": "zurückschaudernd",
    "zurückschauderndster": "zurückschaudernd",
    "zurückschauderndstes": "zurückschaudernd",
    "zurückschauderst": "zurückschaudern",
    "zurückschaudert": "zurückschaudern",
    "zurückschauderte": "zurückschaudern",
    "zurückschauderten": "zurückschaudern",
    "zurückschaudertest": "zurückschaudern",
    "zurückschaudertet": "zurückschaudern",
    "zurückschaue": "zurückschauen",
    "zurückschauend": "zurückschauen",
    "zurückschauende": "zurückschauend",
    "zurückschauendem": "zurückschauend",
    "zurückschauenden": "zurückschauend",
    "zurückschauender": "zurückschauend",
    "zurückschauendes": "zurückschauend",
    "zurückschauest": "zurückschauen",
    "zurückschauet": "zurückschauen",
    "zurückschaust": "zurückschauen",
    "zurückschaut": "zurückschauen",
    "zurückschaute": "zurückschauen",
    "zurückschauten": "zurückschauen",
    "zurückschautest": "zurückschauen",
    "zurückschautet": "zurückschauen",
    "zurückscheuche": "zurückscheuchen",
    "zurückscheuchend": "zurückscheuchen",
    "zurückscheuchende": "zurückscheuchend",
    "zurückscheuchendem": "zurückscheuchend",
    "zurückscheuchenden": "zurückscheuchend",
    "zurückscheuchender": "zurückscheuchend",
    "zurückscheuchendes": "zurückscheuchend",
    "zurückscheuchest": "zurückscheuchen",
    "zurückscheuchet": "zurückscheuchen",
    "zurückscheuchst": "zurückscheuchen",
    "zurückscheucht": "zurückscheuchen",
    "zurückscheuchte": "zurückscheuchen",
    "zurückscheuchten": "zurückscheuchen",
    "zurückscheuchtest": "zurückscheuchen",
    "zurückscheuchtet": "zurückscheuchen",
    "zurückscheue": "zurückscheuen",
    "zurückscheuend": "zurückscheuen",
    "zurückscheuende": "zurückscheuend",
    "zurückscheuendem": "zurückscheuend",
    "zurückscheuenden": "zurückscheuend",
    "zurückscheuender": "zurückscheuend",
    "zurückscheuendes": "zurückscheuend",
    "zurückscheuest": "zurückscheuen",
    "zurückscheuet": "zurückscheuen",
    "zurückscheust": "zurückscheuen",
    "zurückscheut": "zurückscheuen",
    "zurückscheute": "zurückscheuen",
    "zurückscheuten": "zurückscheuen",
    "zurückscheutest": "zurückscheuen",
    "zurückscheutet": "zurückscheuen",
    "zurückschiebe": "zurückschieben",
    "zurückschiebend": "zurückschieben",
    "zurückschiebende": "zurückschiebend",
    "zurückschiebendem": "zurückschiebend",
    "zurückschiebenden": "zurückschiebend",
    "zurückschiebender": "zurückschiebend",
    "zurückschiebendes": "zurückschiebend",
    "zurückschiebest": "zurückschieben",
    "zurückschiebet": "zurückschieben",
    "zurückschiebst": "zurückschieben",
    "zurückschiebt": "zurückschieben",
    "zurückschlage": "zurückschlagen",
    "zurückschlagend": "zurückschlagen",
    "zurückschlagende": "zurückschlagend",
    "zurückschlagendem": "zurückschlagend",
    "zurückschlagenden": "zurückschlagend",
    "zurückschlagender": "zurückschlagend",
    "zurückschlagendes": "zurückschlagend",
    "zurückschlagest": "zurückschlagen",
    "zurückschlaget": "zurückschlagen",
    "zurückschlagt": "zurückschlagen",
    "zurückschlug": "zurückschlagen",
    "zurückschlugen": "zurückschlagen",
    "zurückschlugst": "zurückschlagen",
    "zurückschlugt": "zurückschlagen",
    "zurückschlägst": "zurückschlagen",
    "zurückschlägt": "zurückschlagen",
    "zurückschlüge": "zurückschlagen",
    "zurückschlügen": "zurückschlagen",
    "zurückschlügest": "zurückschlagen",
    "zurückschlüget": "zurückschlagen",
    "zurückschnelle": "zurückschnellen",
    "zurückschnellend": "zurückschnellen",
    "zurückschnellende": "zurückschnellend",
    "zurückschnellendem": "zurückschnellend",
    "zurückschnellenden": "zurückschnellend",
    "zurückschnellender": "zurückschnellend",
    "zurückschnellendes": "zurückschnellend",
    "zurückschnellest": "zurückschnellen",
    "zurückschnellet": "zurückschnellen",
    "zurückschnellst": "zurückschnellen",
    "zurückschnellt": "zurückschnellen",
    "zurückschnellte": "zurückschnellen",
    "zurückschnellten": "zurückschnellen",
    "zurückschnelltest": "zurückschnellen",
    "zurückschnelltet": "zurückschnellen",
    "zurückschob": "zurückschieben",
    "zurückschoben": "zurückschieben",
    "zurückschobst": "zurückschieben",
    "zurückschobt": "zurückschieben",
    "zurückschrak": "zurückschrecken",
    "zurückschraken": "zurückschrecken",
    "zurückschrakst": "zurückschrecken",
    "zurückschrakt": "zurückschrecken",
    "zurückschraube": "zurückschrauben",
    "zurückschraubend": "zurückschrauben",
    "zurückschraubende": "zurückschraubend",
    "zurückschraubendem": "zurückschraubend",
    "zurückschraubenden": "zurückschraubend",
    "zurückschraubender": "zurückschraubend",
    "zurückschraubendes": "zurückschraubend",
    "zurückschraubest": "zurückschrauben",
    "zurückschraubet": "zurückschrauben",
    "zurückschraubst": "zurückschrauben",
    "zurückschraubt": "zurückschrauben",
    "zurückschraubte": "zurückschrauben",
    "zurückschraubten": "zurückschrauben",
    "zurückschraubtest": "zurückschrauben",
    "zurückschraubtet": "zurückschrauben",
    "zurückschrecke": "zurückschrecken",
    "zurückschreckend": "zurückschrecken",
    "zurückschreckende": "zurückschreckend",
    "zurückschreckendem": "zurückschreckend",
    "zurückschreckenden": "zurückschreckend",
    "zurückschreckender": "zurückschreckend",
    "zurückschreckendere": "zurückschreckend",
    "zurückschreckenderem": "zurückschreckend",
    "zurückschreckenderen": "zurückschreckend",
    "zurückschreckenderer": "zurückschreckend",
    "zurückschreckenderes": "zurückschreckend",
    "zurückschreckendes": "zurückschreckend",
    "zurückschreckendste": "zurückschreckend",
    "zurückschreckendstem": "zurückschreckend",
    "zurückschreckendsten": "zurückschreckend",
    "zurückschreckendster": "zurückschreckend",
    "zurückschreckendstes": "zurückschreckend",
    "zurückschreckest": "zurückschrecken",
    "zurückschrecket": "zurückschrecken",
    "zurückschreckst": "zurückschrecken",
    "zurückschreckt": "zurückschrecken",
    "zurückschreckte": "zurückschrecken",
    "zurückschreckten": "zurückschrecken",
    "zurückschrecktest": "zurückschrecken",
    "zurückschrecktet": "zurückschrecken",
    "zurückschreibe": "zurückschreiben",
    "zurückschreibend": "zurückschreiben",
    "zurückschreibende": "zurückschreibend",
    "zurückschreibendem": "zurückschreibend",
    "zurückschreibenden": "zurückschreibend",
    "zurückschreibender": "zurückschreibend",
    "zurückschreibendes": "zurückschreibend",
    "zurückschreibest": "zurückschreiben",
    "zurückschreibet": "zurückschreiben",
    "zurückschreibst": "zurückschreiben",
    "zurückschreibt": "zurückschreiben",
    "zurückschrickst": "zurückschrecken",
    "zurückschrickt": "zurückschrecken",
    "zurückschrieb": "zurückschreiben",
    "zurückschriebe": "zurückschreiben",
    "zurückschrieben": "zurückschreiben",
    "zurückschriebest": "zurückschreiben",
    "zurückschriebet": "zurückschreiben",
    "zurückschriebst": "zurückschreiben",
    "zurückschriebt": "zurückschreiben",
    "zurückschräke": "zurückschrecken",
    "zurückschräken": "zurückschrecken",
    "zurückschräkest": "zurückschrecken",
    "zurückschräket": "zurückschrecken",
    "zurückschuf": "zurückschaffen",
    "zurückschufen": "zurückschaffen",
    "zurückschufst": "zurückschaffen",
    "zurückschuft": "zurückschaffen",
    "zurückschwamm": "zurückschwimmen",
    "zurückschwammen": "zurückschwimmen",
    "zurückschwammst": "zurückschwimmen",
    "zurückschwammt": "zurückschwimmen",
    "zurückschwimme": "zurückschwimmen",
    "zurückschwimmend": "zurückschwimmen",
    "zurückschwimmende": "zurückschwimmend",
    "zurückschwimmendem": "zurückschwimmend",
    "zurückschwimmenden": "zurückschwimmend",
    "zurückschwimmender": "zurückschwimmend",
    "zurückschwimmendes": "zurückschwimmend",
    "zurückschwimmest": "zurückschwimmen",
    "zurückschwimmet": "zurückschwimmen",
    "zurückschwimmst": "zurückschwimmen",
    "zurückschwimmt": "zurückschwimmen",
    "zurückschwämme": "zurückschwimmen",
    "zurückschwämmen": "zurückschwimmen",
    "zurückschwämmest": "zurückschwimmen",
    "zurückschwämmet": "zurückschwimmen",
    "zurückschöbe": "zurückschieben",
    "zurückschöben": "zurückschieben",
    "zurückschöbest": "zurückschieben",
    "zurückschöbet": "zurückschieben",
    "zurückschüfe": "zurückschaffen",
    "zurückschüfen": "zurückschaffen",
    "zurückschüfest": "zurückschaffen",
    "zurückschüfet": "zurückschaffen",
    "zurücksehne": "zurücksehnen",
    "zurücksehnend": "zurücksehnen",
    "zurücksehnende": "zurücksehnend",
    "zurücksehnendem": "zurücksehnend",
    "zurücksehnenden": "zurücksehnend",
    "zurücksehnender": "zurücksehnend",
    "zurücksehnendere": "zurücksehnend",
    "zurücksehnenderem": "zurücksehnend",
    "zurücksehnenderen": "zurücksehnend",
    "zurücksehnenderer": "zurücksehnend",
    "zurücksehnenderes": "zurücksehnend",
    "zurücksehnendes": "zurücksehnend",
    "zurücksehnendste": "zurücksehnend",
    "zurücksehnendstem": "zurücksehnend",
    "zurücksehnendsten": "zurücksehnend",
    "zurücksehnendster": "zurücksehnend",
    "zurücksehnendstes": "zurücksehnend",
    "zurücksehnest": "zurücksehnen",
    "zurücksehnet": "zurücksehnen",
    "zurücksehnst": "zurücksehnen",
    "zurücksehnt": "zurücksehnen",
    "zurücksehnte": "zurücksehnen",
    "zurücksehnten": "zurücksehnen",
    "zurücksehntest": "zurücksehnen",
    "zurücksehntet": "zurücksehnen",
    "zurücksende": "zurücksenden",
    "zurücksendend": "zurücksenden",
    "zurücksendende": "zurücksendend",
    "zurücksendendem": "zurücksendend",
    "zurücksendenden": "zurücksendend",
    "zurücksendender": "zurücksendend",
    "zurücksendendes": "zurücksendend",
    "zurücksendest": "zurücksenden",
    "zurücksendet": "zurücksenden",
    "zurücksendete": "zurücksenden",
    "zurücksendeten": "zurücksenden",
    "zurücksendetest": "zurücksenden",
    "zurücksendetet": "zurücksenden",
    "zurücksetze": "zurücksetzen",
    "zurücksetzend": "zurücksetzen",
    "zurücksetzende": "zurücksetzend",
    "zurücksetzendem": "zurücksetzend",
    "zurücksetzenden": "zurücksetzend",
    "zurücksetzender": "zurücksetzend",
    "zurücksetzendes": "zurücksetzend",
    "zurücksetzest": "zurücksetzen",
    "zurücksetzet": "zurücksetzen",
    "zurücksetzt": "zurücksetzen",
    "zurücksetzte": "zurücksetzen",
    "zurücksetzten": "zurücksetzen",
    "zurücksetztest": "zurücksetzen",
    "zurücksetztet": "zurücksetzen",
    "zurücksinke": "zurücksinken",
    "zurücksinkend": "zurücksinken",
    "zurücksinkende": "zurücksinkend",
    "zurücksinkendem": "zurücksinkend",
    "zurücksinkenden": "zurücksinkend",
    "zurücksinkender": "zurücksinkend",
    "zurücksinkendes": "zurücksinkend",
    "zurücksinkest": "zurücksinken",
    "zurücksinket": "zurücksinken",
    "zurücksinkst": "zurücksinken",
    "zurücksinkt": "zurücksinken",
    "zurücksprang": "zurückspringen",
    "zurücksprangen": "zurückspringen",
    "zurücksprangst": "zurückspringen",
    "zurücksprangt": "zurückspringen",
    "zurückspringe": "zurückspringen",
    "zurückspringend": "zurückspringen",
    "zurückspringende": "zurückspringend",
    "zurückspringendem": "zurückspringend",
    "zurückspringenden": "zurückspringend",
    "zurückspringender": "zurückspringend",
    "zurückspringendes": "zurückspringend",
    "zurückspringest": "zurückspringen",
    "zurückspringet": "zurückspringen",
    "zurückspringst": "zurückspringen",
    "zurückspringt": "zurückspringen",
    "zurückspränge": "zurückspringen",
    "zurücksprängen": "zurückspringen",
    "zurücksprängest": "zurückspringen",
    "zurückspränget": "zurückspringen",
    "zurückspule": "zurückspulen",
    "zurückspulend": "zurückspulen",
    "zurückspulende": "zurückspulend",
    "zurückspulendem": "zurückspulend",
    "zurückspulenden": "zurückspulend",
    "zurückspulender": "zurückspulend",
    "zurückspulendes": "zurückspulend",
    "zurückspulest": "zurückspulen",
    "zurückspulet": "zurückspulen",
    "zurückspulst": "zurückspulen",
    "zurückspult": "zurückspulen",
    "zurückspulte": "zurückspulen",
    "zurückspulten": "zurückspulen",
    "zurückspultest": "zurückspulen",
    "zurückspultet": "zurückspulen",
    "zurückstand": "zurückstehen",
    "zurückstanden": "zurückstehen",
    "zurückstandest": "zurückstehen",
    "zurückstandet": "zurückstehen",
    "zurückstehe": "zurückstehen",
    "zurückstehend": "zurückstehen",
    "zurückstehende": "zurückstehend",
    "zurückstehendem": "zurückstehend",
    "zurückstehenden": "zurückstehend",
    "zurückstehender": "zurückstehend",
    "zurückstehendes": "zurückstehend",
    "zurückstehest": "zurückstehen",
    "zurückstehet": "zurückstehen",
    "zurückstehst": "zurückstehen",
    "zurücksteht": "zurückstehen",
    "zurückstelle": "zurückstellen",
    "zurückstellend": "zurückstellen",
    "zurückstellende": "zurückstellend",
    "zurückstellendem": "zurückstellend",
    "zurückstellenden": "zurückstellend",
    "zurückstellender": "zurückstellend",
    "zurückstellendes": "zurückstellend",
    "zurückstellest": "zurückstellen",
    "zurückstellet": "zurückstellen",
    "zurückstellst": "zurückstellen",
    "zurückstellt": "zurückstellen",
    "zurückstellte": "zurückstellen",
    "zurückstellten": "zurückstellen",
    "zurückstelltest": "zurückstellen",
    "zurückstelltet": "zurückstellen",
    "zurückstieß": "zurückstoßen",
    "zurückstieße": "zurückstoßen",
    "zurückstießen": "zurückstoßen",
    "zurückstießest": "zurückstoßen",
    "zurückstießet": "zurückstoßen",
    "zurückstießt": "zurückstoßen",
    "zurückstoße": "zurückstoßen",
    "zurückstoßend": "zurückstoßen",
    "zurückstoßende": "zurückstoßend",
    "zurückstoßendem": "zurückstoßend",
    "zurückstoßenden": "zurückstoßend",
    "zurückstoßender": "zurückstoßend",
    "zurückstoßendes": "zurückstoßend",
    "zurückstoßest": "zurückstoßen",
    "zurückstoßet": "zurückstoßen",
    "zurückstoßt": "zurückstoßen",
    "zurückstrahle": "zurückstrahlen",
    "zurückstrahlend": "zurückstrahlen",
    "zurückstrahlende": "zurückstrahlend",
    "zurückstrahlendem": "zurückstrahlend",
    "zurückstrahlenden": "zurückstrahlend",
    "zurückstrahlender": "zurückstrahlend",
    "zurückstrahlendere": "zurückstrahlend",
    "zurückstrahlenderem": "zurückstrahlend",
    "zurückstrahlenderen": "zurückstrahlend",
    "zurückstrahlenderer": "zurückstrahlend",
    "zurückstrahlenderes": "zurückstrahlend",
    "zurückstrahlendes": "zurückstrahlend",
    "zurückstrahlendste": "zurückstrahlend",
    "zurückstrahlendstem": "zurückstrahlend",
    "zurückstrahlendsten": "zurückstrahlend",
    "zurückstrahlendster": "zurückstrahlend",
    "zurückstrahlendstes": "zurückstrahlend",
    "zurückstrahlest": "zurückstrahlen",
    "zurückstrahlet": "zurückstrahlen",
    "zurückstrahlst": "zurückstrahlen",
    "zurückstrahlt": "zurückstrahlen",
    "zurückstrahlte": "zurückstrahlen",
    "zurückstrahlten": "zurückstrahlen",
    "zurückstrahltest": "zurückstrahlen",
    "zurückstrahltet": "zurückstrahlen",
    "zurückstreiche": "zurückstreichen",
    "zurückstreichend": "zurückstreichen",
    "zurückstreichende": "zurückstreichend",
    "zurückstreichendem": "zurückstreichend",
    "zurückstreichenden": "zurückstreichend",
    "zurückstreichender": "zurückstreichend",
    "zurückstreichendes": "zurückstreichend",
    "zurückstreichest": "zurückstreichen",
    "zurückstreichet": "zurückstreichen",
    "zurückstreichst": "zurückstreichen",
    "zurückstreicht": "zurückstreichen",
    "zurückstreife": "zurückstreifen",
    "zurückstreifend": "zurückstreifen",
    "zurückstreifende": "zurückstreifend",
    "zurückstreifendem": "zurückstreifend",
    "zurückstreifenden": "zurückstreifend",
    "zurückstreifender": "zurückstreifend",
    "zurückstreifendes": "zurückstreifend",
    "zurückstreifest": "zurückstreifen",
    "zurückstreifet": "zurückstreifen",
    "zurückstreifst": "zurückstreifen",
    "zurückstreift": "zurückstreifen",
    "zurückstreifte": "zurückstreifen",
    "zurückstreiften": "zurückstreifen",
    "zurückstreiftest": "zurückstreifen",
    "zurückstreiftet": "zurückstreifen",
    "zurückstrich": "zurückstreichen",
    "zurückstriche": "zurückstreichen",
    "zurückstrichen": "zurückstreichen",
    "zurückstrichest": "zurückstreichen",
    "zurückstrichet": "zurückstreichen",
    "zurückstrichst": "zurückstreichen",
    "zurückstricht": "zurückstreichen",
    "zurückströme": "zurückströmen",
    "zurückströmend": "zurückströmen",
    "zurückströmende": "zurückströmend",
    "zurückströmendem": "zurückströmend",
    "zurückströmenden": "zurückströmend",
    "zurückströmender": "zurückströmend",
    "zurückströmendes": "zurückströmend",
    "zurückströmest": "zurückströmen",
    "zurückströmet": "zurückströmen",
    "zurückströmst": "zurückströmen",
    "zurückströmt": "zurückströmen",
    "zurückströmte": "zurückströmen",
    "zurückströmten": "zurückströmen",
    "zurückströmtest": "zurückströmen",
    "zurückströmtet": "zurückströmen",
    "zurückstutze": "zurückstutzen",
    "zurückstutzend": "zurückstutzen",
    "zurückstutzende": "zurückstutzend",
    "zurückstutzendem": "zurückstutzend",
    "zurückstutzenden": "zurückstutzend",
    "zurückstutzender": "zurückstutzend",
    "zurückstutzendes": "zurückstutzend",
    "zurückstutzest": "zurückstutzen",
    "zurückstutzet": "zurückstutzen",
    "zurückstutzt": "zurückstutzen",
    "zurückstutzte": "zurückstutzen",
    "zurückstutzten": "zurückstutzen",
    "zurückstutztest": "zurückstutzen",
    "zurückstutztet": "zurückstutzen",
    "zurückstößt": "zurückstoßen",
    "zurückstünde": "zurückstehen",
    "zurückstünden": "zurückstehen",
    "zurückstündest": "zurückstehen",
    "zurückstündet": "zurückstehen",
    "zurücksänke": "zurücksinken",
    "zurücksänken": "zurücksinken",
    "zurücksänkest": "zurücksinken",
    "zurücksänket": "zurücksinken",
    "zurücktaumele": "zurücktaumeln",
    "zurücktaumelnd": "zurücktaumeln",
    "zurücktaumelnde": "zurücktaumelnd",
    "zurücktaumelndem": "zurücktaumelnd",
    "zurücktaumelnden": "zurücktaumelnd",
    "zurücktaumelnder": "zurücktaumelnd",
    "zurücktaumelndes": "zurücktaumelnd",
    "zurücktaumelst": "zurücktaumeln",
    "zurücktaumelt": "zurücktaumeln",
    "zurücktaumelte": "zurücktaumeln",
    "zurücktaumelten": "zurücktaumeln",
    "zurücktaumeltest": "zurücktaumeln",
    "zurücktaumeltet": "zurücktaumeln",
    "zurücktaumle": "zurücktaumeln",
    "zurücktrage": "zurücktragen",
    "zurücktragend": "zurücktragen",
    "zurücktragende": "zurücktragend",
    "zurücktragendem": "zurücktragend",
    "zurücktragenden": "zurücktragend",
    "zurücktragender": "zurücktragend",
    "zurücktragendes": "zurücktragend",
    "zurücktragest": "zurücktragen",
    "zurücktraget": "zurücktragen",
    "zurücktragt": "zurücktragen",
    "zurücktrat": "zurücktreten",
    "zurücktraten": "zurücktreten",
    "zurücktratest": "zurücktreten",
    "zurücktratet": "zurücktreten",
    "zurücktreibe": "zurücktreiben",
    "zurücktreibend": "zurücktreiben",
    "zurücktreibende": "zurücktreibend",
    "zurücktreibendem": "zurücktreibend",
    "zurücktreibenden": "zurücktreibend",
    "zurücktreibender": "zurücktreibend",
    "zurücktreibendes": "zurücktreibend",
    "zurücktreibest": "zurücktreiben",
    "zurücktreibet": "zurücktreiben",
    "zurücktreibst": "zurücktreiben",
    "zurücktreibt": "zurücktreiben",
    "zurücktrete": "zurücktreten",
    "zurücktretend": "zurücktreten",
    "zurücktretende": "zurücktretend",
    "zurücktretendem": "zurücktretend",
    "zurücktretenden": "zurücktretend",
    "zurücktretender": "zurücktretend",
    "zurücktretendes": "zurücktretend",
    "zurücktretest": "zurücktreten",
    "zurücktretet": "zurücktreten",
    "zurücktrieb": "zurücktreiben",
    "zurücktriebe": "zurücktreiben",
    "zurücktrieben": "zurücktreiben",
    "zurücktriebest": "zurücktreiben",
    "zurücktriebet": "zurücktreiben",
    "zurücktriebst": "zurücktreiben",
    "zurücktriebt": "zurücktreiben",
    "zurücktritt": "zurücktreten",
    "zurücktrittst": "zurücktreten",
    "zurücktrug": "zurücktragen",
    "zurücktrugen": "zurücktragen",
    "zurücktrugst": "zurücktragen",
    "zurücktrugt": "zurücktragen",
    "zurückträgst": "zurücktragen",
    "zurückträgt": "zurücktragen",
    "zurückträte": "zurücktreten",
    "zurückträten": "zurücktreten",
    "zurückträtest": "zurücktreten",
    "zurückträtet": "zurücktreten",
    "zurücktrüge": "zurücktragen",
    "zurücktrügen": "zurücktragen",
    "zurücktrügest": "zurücktragen",
    "zurücktrüget": "zurücktragen",
    "zurückverfolge": "zurückverfolgen",
    "zurückverfolgend": "zurückverfolgen",
    "zurückverfolgende": "zurückverfolgend",
    "zurückverfolgendem": "zurückverfolgend",
    "zurückverfolgenden": "zurückverfolgend",
    "zurückverfolgender": "zurückverfolgend",
    "zurückverfolgendes": "zurückverfolgend",
    "zurückverfolgest": "zurückverfolgen",
    "zurückverfolget": "zurückverfolgen",
    "zurückverfolgst": "zurückverfolgen",
    "zurückverfolgt": "zurückverfolgen",
    "zurückverfolgte": "zurückverfolgen",
    "zurückverfolgtem": "zurückverfolgt",
    "zurückverfolgten": "zurückverfolgen",
    "zurückverfolgter": "zurückverfolgt",
    "zurückverfolgtes": "zurückverfolgt",
    "zurückverfolgtest": "zurückverfolgen",
    "zurückverfolgtet": "zurückverfolgen",
    "zurückverlange": "zurückverlangen",
    "zurückverlangend": "zurückverlangen",
    "zurückverlangende": "zurückverlangend",
    "zurückverlangendem": "zurückverlangend",
    "zurückverlangenden": "zurückverlangend",
    "zurückverlangender": "zurückverlangend",
    "zurückverlangendes": "zurückverlangend",
    "zurückverlangest": "zurückverlangen",
    "zurückverlanget": "zurückverlangen",
    "zurückverlangst": "zurückverlangen",
    "zurückverlangt": "zurückverlangen",
    "zurückverlangte": "zurückverlangen",
    "zurückverlangtem": "zurückverlangt",
    "zurückverlangten": "zurückverlangen",
    "zurückverlangter": "zurückverlangt",
    "zurückverlangtes": "zurückverlangt",
    "zurückverlangtest": "zurückverlangen",
    "zurückverlangtet": "zurückverlangen",
    "zurückverlege": "zurückverlegen",
    "zurückverlegend": "zurückverlegen",
    "zurückverlegende": "zurückverlegend",
    "zurückverlegendem": "zurückverlegend",
    "zurückverlegenden": "zurückverlegend",
    "zurückverlegender": "zurückverlegend",
    "zurückverlegendes": "zurückverlegend",
    "zurückverlegest": "zurückverlegen",
    "zurückverleget": "zurückverlegen",
    "zurückverlegst": "zurückverlegen",
    "zurückverlegt": "zurückverlegen",
    "zurückverlegte": "zurückverlegen",
    "zurückverlegtem": "zurückverlegt",
    "zurückverlegten": "zurückverlegen",
    "zurückverlegter": "zurückverlegt",
    "zurückverlegtes": "zurückverlegt",
    "zurückverlegtest": "zurückverlegen",
    "zurückverlegtet": "zurückverlegen",
    "zurückversetze": "zurückversetzen",
    "zurückversetzend": "zurückversetzen",
    "zurückversetzende": "zurückversetzend",
    "zurückversetzendem": "zurückversetzend",
    "zurückversetzenden": "zurückversetzend",
    "zurückversetzender": "zurückversetzend",
    "zurückversetzendes": "zurückversetzend",
    "zurückversetzest": "zurückversetzen",
    "zurückversetzet": "zurückversetzen",
    "zurückversetzt": "zurückversetzen",
    "zurückversetzte": "zurückversetzen",
    "zurückversetztem": "zurückversetzt",
    "zurückversetzten": "zurückversetzen",
    "zurückversetzter": "zurückversetzt",
    "zurückversetztes": "zurückversetzt",
    "zurückversetztest": "zurückversetzen",
    "zurückversetztet": "zurückversetzen",
    "zurückverweise": "zurückverweisen",
    "zurückverweisend": "zurückverweisen",
    "zurückverweisende": "zurückverweisend",
    "zurückverweisendem": "zurückverweisend",
    "zurückverweisenden": "zurückverweisend",
    "zurückverweisender": "zurückverweisend",
    "zurückverweisendes": "zurückverweisend",
    "zurückverweisest": "zurückverweisen",
    "zurückverweiset": "zurückverweisen",
    "zurückverweist": "zurückverweisen",
    "zurückverwies": "zurückverweisen",
    "zurückverwiese": "zurückverweisen",
    "zurückverwiesen": "zurückverweisen",
    "zurückverwiesene": "zurückverwiesen",
    "zurückverwiesenem": "zurückverwiesen",
    "zurückverwiesenen": "zurückverwiesen",
    "zurückverwiesener": "zurückverwiesen",
    "zurückverwiesenes": "zurückverwiesen",
    "zurückverwiesest": "zurückverweisen",
    "zurückverwieset": "zurückverweisen",
    "zurückverwiest": "zurückverweisen",
    "zurückwandere": "zurückwandern",
    "zurückwandernd": "zurückwandern",
    "zurückwandernde": "zurückwandernd",
    "zurückwanderndem": "zurückwandernd",
    "zurückwandernden": "zurückwandernd",
    "zurückwandernder": "zurückwandernd",
    "zurückwanderndes": "zurückwandernd",
    "zurückwanderst": "zurückwandern",
    "zurückwandert": "zurückwandern",
    "zurückwanderte": "zurückwandern",
    "zurückwanderten": "zurückwandern",
    "zurückwandertest": "zurückwandern",
    "zurückwandertet": "zurückwandern",
    "zurückwarf": "zurückwerfen",
    "zurückwarfen": "zurückwerfen",
    "zurückwarfst": "zurückwerfen",
    "zurückwarft": "zurückwerfen",
    "zurückweiche": "zurückweichen",
    "zurückweichend": "zurückweichen",
    "zurückweichende": "zurückweichend",
    "zurückweichendem": "zurückweichend",
    "zurückweichenden": "zurückweichend",
    "zurückweichender": "zurückweichend",
    "zurückweichendes": "zurückweichend",
    "zurückweichest": "zurückweichen",
    "zurückweichet": "zurückweichen",
    "zurückweichst": "zurückweichen",
    "zurückweicht": "zurückweichen",
    "zurückweichte": "zurückweichen",
    "zurückweichten": "zurückweichen",
    "zurückweichtest": "zurückweichen",
    "zurückweichtet": "zurückweichen",
    "zurückweise": "zurückweisen",
    "zurückweisend": "zurückweisen",
    "zurückweisende": "zurückweisend",
    "zurückweisendem": "zurückweisend",
    "zurückweisenden": "zurückweisend",
    "zurückweisender": "zurückweisend",
    "zurückweisendere": "zurückweisend",
    "zurückweisenderem": "zurückweisend",
    "zurückweisenderen": "zurückweisend",
    "zurückweisenderer": "zurückweisend",
    "zurückweisenderes": "zurückweisend",
    "zurückweisendes": "zurückweisend",
    "zurückweisendste": "zurückweisend",
    "zurückweisendstem": "zurückweisend",
    "zurückweisendsten": "zurückweisend",
    "zurückweisendster": "zurückweisend",
    "zurückweisendstes": "zurückweisend",
    "zurückweisest": "zurückweisen",
    "zurückweiset": "zurückweisen",
    "zurückweist": "zurückweisen",
    "zurückwerfe": "zurückwerfen",
    "zurückwerfend": "zurückwerfen",
    "zurückwerfende": "zurückwerfend",
    "zurückwerfendem": "zurückwerfend",
    "zurückwerfenden": "zurückwerfend",
    "zurückwerfender": "zurückwerfend",
    "zurückwerfendes": "zurückwerfend",
    "zurückwerfest": "zurückwerfen",
    "zurückwerfet": "zurückwerfen",
    "zurückwerft": "zurückwerfen",
    "zurückwich": "zurückweichen",
    "zurückwiche": "zurückweichen",
    "zurückwichen": "zurückweichen",
    "zurückwichest": "zurückweichen",
    "zurückwichet": "zurückweichen",
    "zurückwichst": "zurückweichen",
    "zurückwicht": "zurückweichen",
    "zurückwies": "zurückweisen",
    "zurückwiese": "zurückweisen",
    "zurückwiesen": "zurückweisen",
    "zurückwiesest": "zurückweisen",
    "zurückwieset": "zurückweisen",
    "zurückwiest": "zurückweisen",
    "zurückwirfst": "zurückwerfen",
    "zurückwirft": "zurückwerfen",
    "zurückwirke": "zurückwirken",
    "zurückwirkend": "zurückwirken",
    "zurückwirkende": "zurückwirkend",
    "zurückwirkendem": "zurückwirkend",
    "zurückwirkenden": "zurückwirkend",
    "zurückwirkender": "zurückwirkend",
    "zurückwirkendes": "zurückwirkend",
    "zurückwirkest": "zurückwirken",
    "zurückwirket": "zurückwirken",
    "zurückwirkst": "zurückwirken",
    "zurückwirkt": "zurückwirken",
    "zurückwirkte": "zurückwirken",
    "zurückwirkten": "zurückwirken",
    "zurückwirktest": "zurückwirken",
    "zurückwirktet": "zurückwirken",
    "zurückwärfe": "zurückwerfen",
    "zurückwärfen": "zurückwerfen",
    "zurückwärfest": "zurückwerfen",
    "zurückwärfet": "zurückwerfen",
    "zurückwünsche": "zurückwünschen",
    "zurückwünschend": "zurückwünschen",
    "zurückwünschende": "zurückwünschend",
    "zurückwünschendem": "zurückwünschend",
    "zurückwünschenden": "zurückwünschend",
    "zurückwünschender": "zurückwünschend",
    "zurückwünschendes": "zurückwünschend",
    "zurückwünschest": "zurückwünschen",
    "zurückwünschet": "zurückwünschen",
    "zurückwünschst": "zurückwünschen",
    "zurückwünscht": "zurückwünschen",
    "zurückwünschte": "zurückwünschen",
    "zurückwünschten": "zurückwünschen",
    "zurückwünschtest": "zurückwünschen",
    "zurückwünschtet": "zurückwünschen",
    "zurückzahle": "zurückzahlen",
    "zurückzahlend": "zurückzahlen",
    "zurückzahlende": "zurückzahlend",
    "zurückzahlendem": "zurückzahlend",
    "zurückzahlenden": "zurückzahlend",
    "zurückzahlender": "zurückzahlend",
    "zurückzahlendes": "zurückzahlend",
    "zurückzahlest": "zurückzahlen",
    "zurückzahlet": "zurückzahlen",
    "zurückzahlst": "zurückzahlen",
    "zurückzahlt": "zurückzahlen",
    "zurückzahlte": "zurückzahlen",
    "zurückzahlten": "zurückzahlen",
    "zurückzahltest": "zurückzahlen",
    "zurückzahltet": "zurückzahlen",
    "zurückziehe": "zurückziehen",
    "zurückziehend": "zurückziehen",
    "zurückziehende": "zurückziehend",
    "zurückziehendem": "zurückziehend",
    "zurückziehenden": "zurückziehend",
    "zurückziehender": "zurückziehend",
    "zurückziehendes": "zurückziehend",
    "zurückziehest": "zurückziehen",
    "zurückziehet": "zurückziehen",
    "zurückziehst": "zurückziehen",
    "zurückzieht": "zurückziehen",
    "zurückzog": "zurückziehen",
    "zurückzogen": "zurückziehen",
    "zurückzogst": "zurückziehen",
    "zurückzogt": "zurückziehen",
    "zurückzubegeben": "zurückbegeben",
    "zurückzubegleiten": "zurückbegleiten",
    "zurückzubehalten": "zurückbehalten",
    "zurückzubekommen": "zurückbekommen",
    "zurückzubeugen": "zurückbeugen",
    "zurückzubewegen": "zurückbewegen",
    "zurückzubiegen": "zurückbiegen",
    "zurückzubilden": "zurückbilden",
    "zurückzubleiben": "zurückbleiben",
    "zurückzublicken": "zurückblicken",
    "zurückzubringen": "zurückbringen",
    "zurückzudatieren": "zurückdatieren",
    "zurückzudenken": "zurückdenken",
    "zurückzudrehen": "zurückdrehen",
    "zurückzudrängen": "zurückdrängen",
    "zurückzueilen": "zurückeilen",
    "zurückzuerbitten": "zurückerbitten",
    "zurückzuerhalten": "zurückerhalten",
    "zurückzuerinnern": "zurückerinnern",
    "zurückzuerlangen": "zurückerlangen",
    "zurückzuerobern": "zurückerobern",
    "zurückzuerstatten": "zurückerstatten",
    "zurückzuerwarten": "zurückerwarten",
    "zurückzuerwerben": "zurückerwerben",
    "zurückzufahren": "zurückfahren",
    "zurückzufallen": "zurückfallen",
    "zurückzufinden": "zurückfinden",
    "zurückzufliegen": "zurückfliegen",
    "zurückzufließen": "zurückfließen",
    "zurückzufordern": "zurückfordern",
    "zurückzufragen": "zurückfragen",
    "zurückzuführen": "zurückführen",
    "zurückzugeben": "zurückgeben",
    "zurückzugehen": "zurückgehen",
    "zurückzugewinnen": "zurückgewinnen",
    "zurückzugreifen": "zurückgreifen",
    "zurückzuhalten": "zurückhalten",
    "zurückzuholen": "zurückholen",
    "zurückzujagen": "zurückjagen",
    "zurückzukaufen": "zurückkaufen",
    "zurückzukehren": "zurückkehren",
    "zurückzuklappen": "zurückklappen",
    "zurückzukommen": "zurückkommen",
    "zurückzukämmen": "zurückkämmen",
    "zurückzulassen": "zurücklassen",
    "zurückzulaufen": "zurücklaufen",
    "zurückzulehnen": "zurücklehnen",
    "zurückzuliegen": "zurückliegen",
    "zurückzumarschieren": "zurückmarschieren",
    "zurückzumelden": "zurückmelden",
    "zurückzunehmen": "zurücknehmen",
    "zurückzuprallen": "zurückprallen",
    "zurückzureisen": "zurückreisen",
    "zurückzureiten": "zurückreiten",
    "zurückzureißen": "zurückreißen",
    "zurückzurollen": "zurückrollen",
    "zurückzurufen": "zurückrufen",
    "zurückzuschaffen": "zurückschaffen",
    "zurückzuschallen": "zurückschallen",
    "zurückzuschalten": "zurückschalten",
    "zurückzuschaudern": "zurückschaudern",
    "zurückzuschauen": "zurückschauen",
    "zurückzuscheuchen": "zurückscheuchen",
    "zurückzuscheuen": "zurückscheuen",
    "zurückzuschieben": "zurückschieben",
    "zurückzuschlagen": "zurückschlagen",
    "zurückzuschnellen": "zurückschnellen",
    "zurückzuschrauben": "zurückschrauben",
    "zurückzuschrecken": "zurückschrecken",
    "zurückzuschreiben": "zurückschreiben",
    "zurückzuschwimmen": "zurückschwimmen",
    "zurückzusehnen": "zurücksehnen",
    "zurückzusenden": "zurücksenden",
    "zurückzusetzen": "zurücksetzen",
    "zurückzusinken": "zurücksinken",
    "zurückzuspringen": "zurückspringen",
    "zurückzuspulen": "zurückspulen",
    "zurückzustehen": "zurückstehen",
    "zurückzustellen": "zurückstellen",
    "zurückzustoßen": "zurückstoßen",
    "zurückzustrahlen": "zurückstrahlen",
    "zurückzustreichen": "zurückstreichen",
    "zurückzustreifen": "zurückstreifen",
    "zurückzuströmen": "zurückströmen",
    "zurückzustutzen": "zurückstutzen",
    "zurückzutaumeln": "zurücktaumeln",
    "zurückzutragen": "zurücktragen",
    "zurückzutreiben": "zurücktreiben",
    "zurückzutreten": "zurücktreten",
    "zurückzuverfolgen": "zurückverfolgen",
    "zurückzuverlangen": "zurückverlangen",
    "zurückzuverlegen": "zurückverlegen",
    "zurückzuversetzen": "zurückversetzen",
    "zurückzuverweisen": "zurückverweisen",
    "zurückzuwandern": "zurückwandern",
    "zurückzuweichen": "zurückweichen",
    "zurückzuweisen": "zurückweisen",
    "zurückzuwerfen": "zurückwerfen",
    "zurückzuwirken": "zurückwirken",
    "zurückzuwünschen": "zurückwünschen",
    "zurückzuzahlen": "zurückzahlen",
    "zurückzuziehen": "zurückziehen",
    "zurückzuübersetzen": "zurückübersetzen",
    "zurückzöge": "zurückziehen",
    "zurückzögen": "zurückziehen",
    "zurückzögest": "zurückziehen",
    "zurückzöget": "zurückziehen",
    "zurückübersetze": "zurückübersetzen",
    "zurückübersetzend": "zurückübersetzen",
    "zurückübersetzende": "zurückübersetzend",
    "zurückübersetzendem": "zurückübersetzend",
    "zurückübersetzenden": "zurückübersetzend",
    "zurückübersetzender": "zurückübersetzend",
    "zurückübersetzendes": "zurückübersetzend",
    "zurückübersetzest": "zurückübersetzen",
    "zurückübersetzet": "zurückübersetzen",
    "zurückübersetzt": "zurückübersetzen",
    "zurückübersetzte": "zurückübersetzen",
    "zurückübersetztem": "zurückübersetzt",
    "zurückübersetzten": "zurückübersetzen",
    "zurückübersetzter": "zurückübersetzt",
    "zurückübersetztes": "zurückübersetzt",
    "zurückübersetztest": "zurückübersetzen",
    "zurückübersetztet": "zurückübersetzen",
    "zurüste": "zurüsten",
    "zurüstend": "zurüsten",
    "zurüstende": "zurüstend",
    "zurüstendem": "zurüstend",
    "zurüstenden": "zurüstend",
    "zurüstender": "zurüstend",
    "zurüstendes": "zurüstend",
    "zurüstest": "zurüsten",
    "zurüstet": "zurüsten",
    "zurüstete": "zurüsten",
    "zurüsteten": "zurüsten",
    "zurüstetest": "zurüsten",
    "zurüstetet": "zurüsten",
    "zusage": "zusagen",
    "zusagend": "zusagen",
    "zusagende": "zusagend",
    "zusagendem": "zusagend",
    "zusagenden": "zusagend",
    "zusagender": "zusagend",
    "zusagendes": "zusagend",
    "zusagest": "zusagen",
    "zusaget": "zusagen",
    "zusagst": "zusagen",
    "zusagt": "zusagen",
    "zusagte": "zusagen",
    "zusagten": "zusagen",
    "zusagtest": "zusagen",
    "zusagtet": "zusagen",
    "zusah": "zusehen",
    "zusahen": "zusehen",
    "zusahst": "zusehen",
    "zusaht": "zusehen",
    "zusammenarbeite": "zusammenarbeiten",
    "zusammenarbeitend": "zusammenarbeiten",
    "zusammenarbeitende": "zusammenarbeitend",
    "zusammenarbeitendem": "zusammenarbeitend",
    "zusammenarbeitenden": "zusammenarbeitend",
    "zusammenarbeitender": "zusammenarbeitend",
    "zusammenarbeitendes": "zusammenarbeitend",
    "zusammenarbeitest": "zusammenarbeiten",
    "zusammenarbeitet": "zusammenarbeiten",
    "zusammenarbeitete": "zusammenarbeiten",
    "zusammenarbeiteten": "zusammenarbeiten",
    "zusammenarbeitetest": "zusammenarbeiten",
    "zusammenarbeitetet": "zusammenarbeiten",
    "zusammenballe": "zusammenballen",
    "zusammenballend": "zusammenballen",
    "zusammenballende": "zusammenballend",
    "zusammenballendem": "zusammenballend",
    "zusammenballenden": "zusammenballend",
    "zusammenballender": "zusammenballend",
    "zusammenballendes": "zusammenballend",
    "zusammenballest": "zusammenballen",
    "zusammenballet": "zusammenballen",
    "zusammenballst": "zusammenballen",
    "zusammenballt": "zusammenballen",
    "zusammenballte": "zusammenballen",
    "zusammenballten": "zusammenballen",
    "zusammenballtest": "zusammenballen",
    "zusammenballtet": "zusammenballen",
    "zusammenband": "zusammenbinden",
    "zusammenbanden": "zusammenbinden",
    "zusammenbandest": "zusammenbinden",
    "zusammenbandet": "zusammenbinden",
    "zusammenbaue": "zusammenbauen",
    "zusammenbauend": "zusammenbauen",
    "zusammenbauende": "zusammenbauend",
    "zusammenbauendem": "zusammenbauend",
    "zusammenbauenden": "zusammenbauend",
    "zusammenbauender": "zusammenbauend",
    "zusammenbauendes": "zusammenbauend",
    "zusammenbauest": "zusammenbauen",
    "zusammenbauet": "zusammenbauen",
    "zusammenbaust": "zusammenbauen",
    "zusammenbaut": "zusammenbauen",
    "zusammenbaute": "zusammenbauen",
    "zusammenbauten": "zusammenbauen",
    "zusammenbautest": "zusammenbauen",
    "zusammenbautet": "zusammenbauen",
    "zusammenbeiße": "zusammenbeißen",
    "zusammenbeißend": "zusammenbeißen",
    "zusammenbeißende": "zusammenbeißend",
    "zusammenbeißendem": "zusammenbeißend",
    "zusammenbeißenden": "zusammenbeißend",
    "zusammenbeißender": "zusammenbeißend",
    "zusammenbeißendes": "zusammenbeißend",
    "zusammenbeißest": "zusammenbeißen",
    "zusammenbeißet": "zusammenbeißen",
    "zusammenbeißt": "zusammenbeißen",
    "zusammenbettele": "zusammenbetteln",
    "zusammenbettelnd": "zusammenbetteln",
    "zusammenbettelnde": "zusammenbettelnd",
    "zusammenbettelndem": "zusammenbettelnd",
    "zusammenbettelnden": "zusammenbettelnd",
    "zusammenbettelnder": "zusammenbettelnd",
    "zusammenbettelndes": "zusammenbettelnd",
    "zusammenbettelst": "zusammenbetteln",
    "zusammenbettelt": "zusammenbetteln",
    "zusammenbettelte": "zusammenbetteln",
    "zusammenbettelten": "zusammenbetteln",
    "zusammenbetteltest": "zusammenbetteln",
    "zusammenbetteltet": "zusammenbetteln",
    "zusammenbettle": "zusammenbetteln",
    "zusammenbinde": "zusammenbinden",
    "zusammenbindend": "zusammenbinden",
    "zusammenbindende": "zusammenbindend",
    "zusammenbindendem": "zusammenbindend",
    "zusammenbindenden": "zusammenbindend",
    "zusammenbindender": "zusammenbindend",
    "zusammenbindendes": "zusammenbindend",
    "zusammenbindest": "zusammenbinden",
    "zusammenbindet": "zusammenbinden",
    "zusammenbisse": "zusammenbeißen",
    "zusammenbissen": "zusammenbeißen",
    "zusammenbissest": "zusammenbeißen",
    "zusammenbisset": "zusammenbeißen",
    "zusammenbiß": "zusammenbeißen",
    "zusammenbißt": "zusammenbeißen",
    "zusammenbleibe": "zusammenbleiben",
    "zusammenbleibend": "zusammenbleiben",
    "zusammenbleibende": "zusammenbleibend",
    "zusammenbleibendem": "zusammenbleibend",
    "zusammenbleibenden": "zusammenbleibend",
    "zusammenbleibender": "zusammenbleibend",
    "zusammenbleibendes": "zusammenbleibend",
    "zusammenbleibest": "zusammenbleiben",
    "zusammenbleibet": "zusammenbleiben",
    "zusammenbleibst": "zusammenbleiben",
    "zusammenbleibt": "zusammenbleiben",
    "zusammenblieb": "zusammenbleiben",
    "zusammenbliebe": "zusammenbleiben",
    "zusammenblieben": "zusammenbleiben",
    "zusammenbliebest": "zusammenbleiben",
    "zusammenbliebet": "zusammenbleiben",
    "zusammenbliebst": "zusammenbleiben",
    "zusammenbliebt": "zusammenbleiben",
    "zusammenborge": "zusammenborgen",
    "zusammenborgend": "zusammenborgen",
    "zusammenborgende": "zusammenborgend",
    "zusammenborgendem": "zusammenborgend",
    "zusammenborgenden": "zusammenborgend",
    "zusammenborgender": "zusammenborgend",
    "zusammenborgendes": "zusammenborgend",
    "zusammenborgest": "zusammenborgen",
    "zusammenborget": "zusammenborgen",
    "zusammenborgst": "zusammenborgen",
    "zusammenborgt": "zusammenborgen",
    "zusammenborgte": "zusammenborgen",
    "zusammenborgten": "zusammenborgen",
    "zusammenborgtest": "zusammenborgen",
    "zusammenborgtet": "zusammenborgen",
    "zusammenbrach": "zusammenbrechen",
    "zusammenbrachen": "zusammenbrechen",
    "zusammenbrachst": "zusammenbrechen",
    "zusammenbracht": "zusammenbrechen",
    "zusammenbrachte": "zusammenbringen",
    "zusammenbrachten": "zusammenbringen",
    "zusammenbrachtest": "zusammenbringen",
    "zusammenbrachtet": "zusammenbringen",
    "zusammenbraue": "zusammenbrauen",
    "zusammenbrauend": "zusammenbrauen",
    "zusammenbrauende": "zusammenbrauend",
    "zusammenbrauendem": "zusammenbrauend",
    "zusammenbrauenden": "zusammenbrauend",
    "zusammenbrauender": "zusammenbrauend",
    "zusammenbrauendes": "zusammenbrauend",
    "zusammenbrauest": "zusammenbrauen",
    "zusammenbrauet": "zusammenbrauen",
    "zusammenbraust": "zusammenbrauen",
    "zusammenbraut": "zusammenbrauen",
    "zusammenbraute": "zusammenbrauen",
    "zusammenbrauten": "zusammenbrauen",
    "zusammenbrautest": "zusammenbrauen",
    "zusammenbrautet": "zusammenbrauen",
    "zusammenbreche": "zusammenbrechen",
    "zusammenbrechend": "zusammenbrechen",
    "zusammenbrechende": "zusammenbrechend",
    "zusammenbrechendem": "zusammenbrechend",
    "zusammenbrechenden": "zusammenbrechend",
    "zusammenbrechender": "zusammenbrechend",
    "zusammenbrechendes": "zusammenbrechend",
    "zusammenbrechest": "zusammenbrechen",
    "zusammenbrechet": "zusammenbrechen",
    "zusammenbrecht": "zusammenbrechen",
    "zusammenbrichst": "zusammenbrechen",
    "zusammenbricht": "zusammenbrechen",
    "zusammenbringe": "zusammenbringen",
    "zusammenbringend": "zusammenbringen",
    "zusammenbringende": "zusammenbringend",
    "zusammenbringendem": "zusammenbringend",
    "zusammenbringenden": "zusammenbringend",
    "zusammenbringender": "zusammenbringend",
    "zusammenbringendes": "zusammenbringend",
    "zusammenbringest": "zusammenbringen",
    "zusammenbringet": "zusammenbringen",
    "zusammenbringst": "zusammenbringen",
    "zusammenbringt": "zusammenbringen",
    "zusammenbräche": "zusammenbrechen",
    "zusammenbrächen": "zusammenbrechen",
    "zusammenbrächest": "zusammenbrechen",
    "zusammenbrächet": "zusammenbrechen",
    "zusammenbrächte": "zusammenbringen",
    "zusammenbrächten": "zusammenbringen",
    "zusammenbrächtest": "zusammenbringen",
    "zusammenbrächtet": "zusammenbringen",
    "zusammenbände": "zusammenbinden",
    "zusammenbänden": "zusammenbinden",
    "zusammenbändest": "zusammenbinden",
    "zusammenbändet": "zusammenbinden",
    "zusammendränge": "zusammendrängen",
    "zusammendrängend": "zusammendrängen",
    "zusammendrängende": "zusammendrängend",
    "zusammendrängendem": "zusammendrängend",
    "zusammendrängenden": "zusammendrängend",
    "zusammendrängender": "zusammendrängend",
    "zusammendrängendes": "zusammendrängend",
    "zusammendrängest": "zusammendrängen",
    "zusammendränget": "zusammendrängen",
    "zusammendrängst": "zusammendrängen",
    "zusammendrängt": "zusammendrängen",
    "zusammendrängte": "zusammendrängen",
    "zusammendrängten": "zusammendrängen",
    "zusammendrängtest": "zusammendrängen",
    "zusammendrängtet": "zusammendrängen",
    "zusammenfahre": "zusammenfahren",
    "zusammenfahrend": "zusammenfahren",
    "zusammenfahrende": "zusammenfahrend",
    "zusammenfahrendem": "zusammenfahrend",
    "zusammenfahrenden": "zusammenfahrend",
    "zusammenfahrender": "zusammenfahrend",
    "zusammenfahrendere": "zusammenfahrend",
    "zusammenfahrenderem": "zusammenfahrend",
    "zusammenfahrenderen": "zusammenfahrend",
    "zusammenfahrenderer": "zusammenfahrend",
    "zusammenfahrenderes": "zusammenfahrend",
    "zusammenfahrendes": "zusammenfahrend",
    "zusammenfahrendste": "zusammenfahrend",
    "zusammenfahrendstem": "zusammenfahrend",
    "zusammenfahrendsten": "zusammenfahrend",
    "zusammenfahrendster": "zusammenfahrend",
    "zusammenfahrendstes": "zusammenfahrend",
    "zusammenfahrest": "zusammenfahren",
    "zusammenfahret": "zusammenfahren",
    "zusammenfahrt": "zusammenfahren",
    "zusammenfalle": "zusammenfallen",
    "zusammenfallend": "zusammenfallen",
    "zusammenfallende": "zusammenfallend",
    "zusammenfallendem": "zusammenfallend",
    "zusammenfallenden": "zusammenfallend",
    "zusammenfallender": "zusammenfallend",
    "zusammenfallendes": "zusammenfallend",
    "zusammenfallest": "zusammenfallen",
    "zusammenfallet": "zusammenfallen",
    "zusammenfallt": "zusammenfallen",
    "zusammenfalte": "zusammenfalten",
    "zusammenfaltend": "zusammenfalten",
    "zusammenfaltende": "zusammenfaltend",
    "zusammenfaltendem": "zusammenfaltend",
    "zusammenfaltenden": "zusammenfaltend",
    "zusammenfaltender": "zusammenfaltend",
    "zusammenfaltendere": "zusammenfaltend",
    "zusammenfaltenderem": "zusammenfaltend",
    "zusammenfaltenderen": "zusammenfaltend",
    "zusammenfaltenderer": "zusammenfaltend",
    "zusammenfaltenderes": "zusammenfaltend",
    "zusammenfaltendes": "zusammenfaltend",
    "zusammenfaltendste": "zusammenfaltend",
    "zusammenfaltendstem": "zusammenfaltend",
    "zusammenfaltendsten": "zusammenfaltend",
    "zusammenfaltendster": "zusammenfaltend",
    "zusammenfaltendstes": "zusammenfaltend",
    "zusammenfaltest": "zusammenfalten",
    "zusammenfaltet": "zusammenfalten",
    "zusammenfaltete": "zusammenfalten",
    "zusammenfalteten": "zusammenfalten",
    "zusammenfaltetest": "zusammenfalten",
    "zusammenfaltetet": "zusammenfalten",
    "zusammenfand": "zusammenfinden",
    "zusammenfanden": "zusammenfinden",
    "zusammenfandest": "zusammenfinden",
    "zusammenfandet": "zusammenfinden",
    "zusammenfasse": "zusammenfassen",
    "zusammenfassend": "zusammenfassen",
    "zusammenfassende": "zusammenfassend",
    "zusammenfassendem": "zusammenfassend",
    "zusammenfassenden": "zusammenfassend",
    "zusammenfassender": "zusammenfassend",
    "zusammenfassendes": "zusammenfassend",
    "zusammenfassest": "zusammenfassen",
    "zusammenfasset": "zusammenfassen",
    "zusammenfaßt": "zusammenfassen",
    "zusammenfaßte": "zusammenfassen",
    "zusammenfaßten": "zusammenfassen",
    "zusammenfaßtest": "zusammenfassen",
    "zusammenfaßtet": "zusammenfassen",
    "zusammenfegend": "zusammenfegen",
    "zusammenfegende": "zusammenfegend",
    "zusammenfegendem": "zusammenfegend",
    "zusammenfegenden": "zusammenfegend",
    "zusammenfegender": "zusammenfegend",
    "zusammenfegendere": "zusammenfegend",
    "zusammenfegenderem": "zusammenfegend",
    "zusammenfegenderen": "zusammenfegend",
    "zusammenfegenderer": "zusammenfegend",
    "zusammenfegenderes": "zusammenfegend",
    "zusammenfegendes": "zusammenfegend",
    "zusammenfegendste": "zusammenfegend",
    "zusammenfegendstem": "zusammenfegend",
    "zusammenfegendsten": "zusammenfegend",
    "zusammenfegendster": "zusammenfegend",
    "zusammenfegendstes": "zusammenfegend",
    "zusammenfegest": "zusammenfegen",
    "zusammenfeget": "zusammenfegen",
    "zusammenfegst": "zusammenfegen",
    "zusammenfegt": "zusammenfegen",
    "zusammenfegte": "zusammenfegen",
    "zusammenfegten": "zusammenfegen",
    "zusammenfegtest": "zusammenfegen",
    "zusammenfegtet": "zusammenfegen",
    "zusammenfiel": "zusammenfallen",
    "zusammenfiele": "zusammenfallen",
    "zusammenfielen": "zusammenfallen",
    "zusammenfielest": "zusammenfallen",
    "zusammenfielet": "zusammenfallen",
    "zusammenfielst": "zusammenfallen",
    "zusammenfielt": "zusammenfallen",
    "zusammenfinde": "zusammenfinden",
    "zusammenfindend": "zusammenfinden",
    "zusammenfindende": "zusammenfindend",
    "zusammenfindendem": "zusammenfindend",
    "zusammenfindenden": "zusammenfindend",
    "zusammenfindender": "zusammenfindend",
    "zusammenfindendere": "zusammenfindend",
    "zusammenfindenderem": "zusammenfindend",
    "zusammenfindenderen": "zusammenfindend",
    "zusammenfindenderer": "zusammenfindend",
    "zusammenfindenderes": "zusammenfindend",
    "zusammenfindendes": "zusammenfindend",
    "zusammenfindendste": "zusammenfindend",
    "zusammenfindendstem": "zusammenfindend",
    "zusammenfindendsten": "zusammenfindend",
    "zusammenfindendster": "zusammenfindend",
    "zusammenfindendstes": "zusammenfindend",
    "zusammenfindest": "zusammenfinden",
    "zusammenfindet": "zusammenfinden",
    "zusammenflechte": "zusammenflechten",
    "zusammenflechtend": "zusammenflechten",
    "zusammenflechtende": "zusammenflechtend",
    "zusammenflechtendem": "zusammenflechtend",
    "zusammenflechtenden": "zusammenflechtend",
    "zusammenflechtender": "zusammenflechtend",
    "zusammenflechtendere": "zusammenflechtend",
    "zusammenflechtenderem": "zusammenflechtend",
    "zusammenflechtenderen": "zusammenflechtend",
    "zusammenflechtenderer": "zusammenflechtend",
    "zusammenflechtenderes": "zusammenflechtend",
    "zusammenflechtendes": "zusammenflechtend",
    "zusammenflechtendste": "zusammenflechtend",
    "zusammenflechtendstem": "zusammenflechtend",
    "zusammenflechtendsten": "zusammenflechtend",
    "zusammenflechtendster": "zusammenflechtend",
    "zusammenflechtendstes": "zusammenflechtend",
    "zusammenflechtest": "zusammenflechten",
    "zusammenflechtet": "zusammenflechten",
    "zusammenflicht": "zusammenflechten",
    "zusammenflichtst": "zusammenflechten",
    "zusammenfließe": "zusammenfließen",
    "zusammenfließend": "zusammenfließen",
    "zusammenfließende": "zusammenfließend",
    "zusammenfließendem": "zusammenfließend",
    "zusammenfließenden": "zusammenfließend",
    "zusammenfließender": "zusammenfließend",
    "zusammenfließendes": "zusammenfließend",
    "zusammenfließest": "zusammenfließen",
    "zusammenfließet": "zusammenfließen",
    "zusammenfließt": "zusammenfließen",
    "zusammenflocht": "zusammenflechten",
    "zusammenflochten": "zusammenflechten",
    "zusammenflochtest": "zusammenflechten",
    "zusammenflochtet": "zusammenflechten",
    "zusammenflossen": "zusammenfließen",
    "zusammenfloß": "zusammenfließen",
    "zusammenfloßt": "zusammenfließen",
    "zusammenflöchte": "zusammenflechten",
    "zusammenflöchten": "zusammenflechten",
    "zusammenflöchtest": "zusammenflechten",
    "zusammenflöchtet": "zusammenflechten",
    "zusammenflösse": "zusammenfließen",
    "zusammenflössen": "zusammenfließen",
    "zusammenflössest": "zusammenfließen",
    "zusammenflösset": "zusammenfließen",
    "zusammenfuhr": "zusammenfahren",
    "zusammenfuhren": "zusammenfahren",
    "zusammenfuhrst": "zusammenfahren",
    "zusammenfuhrt": "zusammenfahren",
    "zusammenfährst": "zusammenfahren",
    "zusammenfährt": "zusammenfahren",
    "zusammenfällst": "zusammenfallen",
    "zusammenfällt": "zusammenfallen",
    "zusammenfände": "zusammenfinden",
    "zusammenfänden": "zusammenfinden",
    "zusammenfändest": "zusammenfinden",
    "zusammenfändet": "zusammenfinden",
    "zusammenfüge": "zusammenfügen",
    "zusammenfügend": "zusammenfügen",
    "zusammenfügende": "zusammenfügend",
    "zusammenfügendem": "zusammenfügend",
    "zusammenfügenden": "zusammenfügend",
    "zusammenfügender": "zusammenfügend",
    "zusammenfügendes": "zusammenfügend",
    "zusammenfügest": "zusammenfügen",
    "zusammenfüget": "zusammenfügen",
    "zusammenfügst": "zusammenfügen",
    "zusammenfügt": "zusammenfügen",
    "zusammenfügte": "zusammenfügen",
    "zusammenfügten": "zusammenfügen",
    "zusammenfügtest": "zusammenfügen",
    "zusammenfügtet": "zusammenfügen",
    "zusammenführe": "zusammenführen",
    "zusammenführen": "zusammenfahren",
    "zusammenführend": "zusammenführen",
    "zusammenführende": "zusammenführend",
    "zusammenführendem": "zusammenführend",
    "zusammenführenden": "zusammenführend",
    "zusammenführender": "zusammenführend",
    "zusammenführendes": "zusammenführend",
    "zusammenführest": "zusammenführen",
    "zusammenführet": "zusammenführen",
    "zusammenführst": "zusammenführen",
    "zusammenführt": "zusammenführen",
    "zusammenführte": "zusammenführen",
    "zusammenführten": "zusammenführen",
    "zusammenführtest": "zusammenführen",
    "zusammenführtet": "zusammenführen",
    "zusammengab": "zusammengeben",
    "zusammengaben": "zusammengeben",
    "zusammengabst": "zusammengeben",
    "zusammengabt": "zusammengeben",
    "zusammengearbeitet": "zusammenarbeiten",
    "zusammengearbeitete": "zusammengearbeitet",
    "zusammengearbeitetem": "zusammengearbeitet",
    "zusammengearbeiteten": "zusammengearbeitet",
    "zusammengearbeiteter": "zusammengearbeitet",
    "zusammengearbeitetes": "zusammengearbeitet",
    "zusammengeballt": "zusammenballen",
    "zusammengeballte": "zusammengeballt",
    "zusammengeballtem": "zusammengeballt",
    "zusammengeballten": "zusammengeballt",
    "zusammengeballter": "zusammengeballt",
    "zusammengeballtere": "zusammengeballt",
    "zusammengeballterem": "zusammengeballt",
    "zusammengeballteren": "zusammengeballt",
    "zusammengeballterer": "zusammengeballt",
    "zusammengeballteres": "zusammengeballt",
    "zusammengeballtes": "zusammengeballt",
    "zusammengeballteste": "zusammengeballt",
    "zusammengeballtestem": "zusammengeballt",
    "zusammengeballtesten": "zusammengeballt",
    "zusammengeballtester": "zusammengeballt",
    "zusammengeballtestes": "zusammengeballt",
    "zusammengebaut": "zusammenbauen",
    "zusammengebaute": "zusammengebaut",
    "zusammengebautem": "zusammengebaut",
    "zusammengebauten": "zusammengebaut",
    "zusammengebauter": "zusammengebaut",
    "zusammengebautes": "zusammengebaut",
    "zusammengebe": "zusammengeben",
    "zusammengebend": "zusammengeben",
    "zusammengebende": "zusammengebend",
    "zusammengebendem": "zusammengebend",
    "zusammengebenden": "zusammengebend",
    "zusammengebender": "zusammengebend",
    "zusammengebendes": "zusammengebend",
    "zusammengebest": "zusammengeben",
    "zusammengebet": "zusammengeben",
    "zusammengebettelt": "zusammenbetteln",
    "zusammengebettelte": "zusammengebettelt",
    "zusammengebetteltem": "zusammengebettelt",
    "zusammengebettelten": "zusammengebettelt",
    "zusammengebettelter": "zusammengebettelt",
    "zusammengebetteltes": "zusammengebettelt",
    "zusammengebissen": "zusammenbeißen",
    "zusammengebissene": "zusammengebissen",
    "zusammengebissenem": "zusammengebissen",
    "zusammengebissenen": "zusammengebissen",
    "zusammengebissener": "zusammengebissen",
    "zusammengebissenes": "zusammengebissen",
    "zusammengeblieben": "zusammenbleiben",
    "zusammengebliebene": "zusammengeblieben",
    "zusammengebliebenem": "zusammengeblieben",
    "zusammengebliebenen": "zusammengeblieben",
    "zusammengebliebener": "zusammengeblieben",
    "zusammengebliebenes": "zusammengeblieben",
    "zusammengeborgt": "zusammenborgen",
    "zusammengeborgte": "zusammengeborgt",
    "zusammengeborgtem": "zusammengeborgt",
    "zusammengeborgten": "zusammengeborgt",
    "zusammengeborgter": "zusammengeborgt",
    "zusammengeborgtes": "zusammengeborgt",
    "zusammengebracht": "zusammenbringen",
    "zusammengebrachte": "zusammengebracht",
    "zusammengebrachtem": "zusammengebracht",
    "zusammengebrachten": "zusammengebracht",
    "zusammengebrachter": "zusammengebracht",
    "zusammengebrachtes": "zusammengebracht",
    "zusammengebraut": "zusammenbrauen",
    "zusammengebraute": "zusammengebraut",
    "zusammengebrautem": "zusammengebraut",
    "zusammengebrauten": "zusammengebraut",
    "zusammengebrauter": "zusammengebraut",
    "zusammengebrautes": "zusammengebraut",
    "zusammengebrochen": "zusammenbrechen",
    "zusammengebrochene": "zusammengebrochen",
    "zusammengebrochenem": "zusammengebrochen",
    "zusammengebrochenen": "zusammengebrochen",
    "zusammengebrochener": "zusammengebrochen",
    "zusammengebrochenes": "zusammengebrochen",
    "zusammengebt": "zusammengeben",
    "zusammengebunden": "zusammenbinden",
    "zusammengebundene": "zusammengebunden",
    "zusammengebundenem": "zusammengebunden",
    "zusammengebundenen": "zusammengebunden",
    "zusammengebundener": "zusammengebunden",
    "zusammengebundenes": "zusammengebunden",
    "zusammengedrängt": "zusammendrängen",
    "zusammengedrängte": "zusammengedrängt",
    "zusammengedrängtem": "zusammengedrängt",
    "zusammengedrängten": "zusammengedrängt",
    "zusammengedrängter": "zusammengedrängt",
    "zusammengedrängtes": "zusammengedrängt",
    "zusammengefahren": "zusammenfahren",
    "zusammengefahrene": "zusammengefahren",
    "zusammengefahrenem": "zusammengefahren",
    "zusammengefahrenen": "zusammengefahren",
    "zusammengefahrener": "zusammengefahren",
    "zusammengefahrenere": "zusammengefahren",
    "zusammengefahrenerem": "zusammengefahren",
    "zusammengefahreneren": "zusammengefahren",
    "zusammengefahrenerer": "zusammengefahren",
    "zusammengefahreneres": "zusammengefahren",
    "zusammengefahrenes": "zusammengefahren",
    "zusammengefahrenste": "zusammengefahren",
    "zusammengefahrenstem": "zusammengefahren",
    "zusammengefahrensten": "zusammengefahren",
    "zusammengefahrenster": "zusammengefahren",
    "zusammengefahrenstes": "zusammengefahren",
    "zusammengefallen": "zusammenfallen",
    "zusammengefallene": "zusammengefallen",
    "zusammengefallenem": "zusammengefallen",
    "zusammengefallenen": "zusammengefallen",
    "zusammengefallener": "zusammengefallen",
    "zusammengefallenes": "zusammengefallen",
    "zusammengefaltet": "zusammenfalten",
    "zusammengefaltete": "zusammengefaltet",
    "zusammengefaltetem": "zusammengefaltet",
    "zusammengefalteten": "zusammengefaltet",
    "zusammengefalteter": "zusammengefaltet",
    "zusammengefaltetere": "zusammengefaltet",
    "zusammengefalteterem": "zusammengefaltet",
    "zusammengefalteteren": "zusammengefaltet",
    "zusammengefalteterer": "zusammengefaltet",
    "zusammengefalteteres": "zusammengefaltet",
    "zusammengefaltetes": "zusammengefaltet",
    "zusammengefalteteste": "zusammengefaltet",
    "zusammengefaltetestem": "zusammengefaltet",
    "zusammengefaltetesten": "zusammengefaltet",
    "zusammengefaltetester": "zusammengefaltet",
    "zusammengefaltetestes": "zusammengefaltet",
    "zusammengefaßt": "zusammenfassen",
    "zusammengefaßte": "zusammengefaßt",
    "zusammengefaßtem": "zusammengefaßt",
    "zusammengefaßten": "zusammengefaßt",
    "zusammengefaßter": "zusammengefaßt",
    "zusammengefaßtes": "zusammengefaßt",
    "zusammengefegt": "zusammenfegen",
    "zusammengefegte": "zusammengefegt",
    "zusammengefegtem": "zusammengefegt",
    "zusammengefegten": "zusammengefegt",
    "zusammengefegter": "zusammengefegt",
    "zusammengefegtere": "zusammengefegt",
    "zusammengefegterem": "zusammengefegt",
    "zusammengefegteren": "zusammengefegt",
    "zusammengefegterer": "zusammengefegt",
    "zusammengefegteres": "zusammengefegt",
    "zusammengefegtes": "zusammengefegt",
    "zusammengefegteste": "zusammengefegt",
    "zusammengefegtestem": "zusammengefegt",
    "zusammengefegtesten": "zusammengefegt",
    "zusammengefegtester": "zusammengefegt",
    "zusammengefegtestes": "zusammengefegt",
    "zusammengeflochten": "zusammenflechten",
    "zusammengeflochtene": "zusammengeflochten",
    "zusammengeflochtenem": "zusammengeflochten",
    "zusammengeflochtenen": "zusammengeflochten",
    "zusammengeflochtener": "zusammengeflochten",
    "zusammengeflochtenere": "zusammengeflochten",
    "zusammengeflochtenerem": "zusammengeflochten",
    "zusammengeflochteneren": "zusammengeflochten",
    "zusammengeflochtenerer": "zusammengeflochten",
    "zusammengeflochteneres": "zusammengeflochten",
    "zusammengeflochtenes": "zusammengeflochten",
    "zusammengeflochtenste": "zusammengeflochten",
    "zusammengeflochtenstem": "zusammengeflochten",
    "zusammengeflochtensten": "zusammengeflochten",
    "zusammengeflochtenster": "zusammengeflochten",
    "zusammengeflochtenstes": "zusammengeflochten",
    "zusammengeflossen": "zusammenfließen",
    "zusammengeflossene": "zusammengeflossen",
    "zusammengeflossenem": "zusammengeflossen",
    "zusammengeflossenen": "zusammengeflossen",
    "zusammengeflossener": "zusammengeflossen",
    "zusammengeflossenes": "zusammengeflossen",
    "zusammengefunden": "zusammenfinden",
    "zusammengefundene": "zusammengefunden",
    "zusammengefundenem": "zusammengefunden",
    "zusammengefundenen": "zusammengefunden",
    "zusammengefundener": "zusammengefunden",
    "zusammengefundenere": "zusammengefunden",
    "zusammengefundenerem": "zusammengefunden",
    "zusammengefundeneren": "zusammengefunden",
    "zusammengefundenerer": "zusammengefunden",
    "zusammengefundeneres": "zusammengefunden",
    "zusammengefundenes": "zusammengefunden",
    "zusammengefundenste": "zusammengefunden",
    "zusammengefundenstem": "zusammengefunden",
    "zusammengefundensten": "zusammengefunden",
    "zusammengefundenster": "zusammengefunden",
    "zusammengefundenstes": "zusammengefunden",
    "zusammengefügt": "zusammenfügen",
    "zusammengefügte": "zusammengefügt",
    "zusammengefügtem": "zusammengefügt",
    "zusammengefügten": "zusammengefügt",
    "zusammengefügter": "zusammengefügt",
    "zusammengefügtes": "zusammengefügt",
    "zusammengeführt": "zusammenführen",
    "zusammengeführte": "zusammengeführt",
    "zusammengeführtem": "zusammengeführt",
    "zusammengeführten": "zusammengeführt",
    "zusammengeführter": "zusammengeführt",
    "zusammengeführtes": "zusammengeführt",
    "zusammengegangen": "zusammengehen",
    "zusammengegangene": "zusammengegangen",
    "zusammengegangenem": "zusammengegangen",
    "zusammengegangenen": "zusammengegangen",
    "zusammengegangener": "zusammengegangen",
    "zusammengegangenes": "zusammengegangen",
    "zusammengegeben": "zusammengeben",
    "zusammengegebene": "zusammengegeben",
    "zusammengegebenem": "zusammengegeben",
    "zusammengegebenen": "zusammengegeben",
    "zusammengegebener": "zusammengegeben",
    "zusammengegebenes": "zusammengegeben",
    "zusammengegossen": "zusammengießen",
    "zusammengegossene": "zusammengegossen",
    "zusammengegossenem": "zusammengegossen",
    "zusammengegossenen": "zusammengegossen",
    "zusammengegossener": "zusammengegossen",
    "zusammengegossenes": "zusammengegossen",
    "zusammengehalten": "zusammenhalten",
    "zusammengehaltene": "zusammengehalten",
    "zusammengehaltenem": "zusammengehalten",
    "zusammengehaltenen": "zusammengehalten",
    "zusammengehaltener": "zusammengehalten",
    "zusammengehaltenere": "zusammengehalten",
    "zusammengehaltenerem": "zusammengehalten",
    "zusammengehalteneren": "zusammengehalten",
    "zusammengehaltenerer": "zusammengehalten",
    "zusammengehalteneres": "zusammengehalten",
    "zusammengehaltenes": "zusammengehalten",
    "zusammengehaltenste": "zusammengehalten",
    "zusammengehaltenstem": "zusammengehalten",
    "zusammengehaltensten": "zusammengehalten",
    "zusammengehaltenster": "zusammengehalten",
    "zusammengehaltenstes": "zusammengehalten",
    "zusammengehangen": "zusammenhängen",
    "zusammengehangene": "zusammengehangen",
    "zusammengehangenem": "zusammengehangen",
    "zusammengehangenen": "zusammengehangen",
    "zusammengehangener": "zusammengehangen",
    "zusammengehangenes": "zusammengehangen",
    "zusammengehauen": "zusammenhauen",
    "zusammengehauene": "zusammengehauen",
    "zusammengehauenem": "zusammengehauen",
    "zusammengehauenen": "zusammengehauen",
    "zusammengehauener": "zusammengehauen",
    "zusammengehauenes": "zusammengehauen",
    "zusammengehe": "zusammengehen",
    "zusammengeheftet": "zusammenheften",
    "zusammengeheftete": "zusammengeheftet",
    "zusammengeheftetem": "zusammengeheftet",
    "zusammengehefteten": "zusammengeheftet",
    "zusammengehefteter": "zusammengeheftet",
    "zusammengeheftetes": "zusammengeheftet",
    "zusammengeheilt": "zusammenheilen",
    "zusammengeheilte": "zusammengeheilt",
    "zusammengeheiltem": "zusammengeheilt",
    "zusammengeheilten": "zusammengeheilt",
    "zusammengeheilter": "zusammengeheilt",
    "zusammengeheiltere": "zusammengeheilt",
    "zusammengeheilterem": "zusammengeheilt",
    "zusammengeheilteren": "zusammengeheilt",
    "zusammengeheilterer": "zusammengeheilt",
    "zusammengeheilteres": "zusammengeheilt",
    "zusammengeheiltes": "zusammengeheilt",
    "zusammengeheilteste": "zusammengeheilt",
    "zusammengeheiltestem": "zusammengeheilt",
    "zusammengeheiltesten": "zusammengeheilt",
    "zusammengeheiltester": "zusammengeheilt",
    "zusammengeheiltestes": "zusammengeheilt",
    "zusammengehend": "zusammengehen",
    "zusammengehende": "zusammengehend",
    "zusammengehendem": "zusammengehend",
    "zusammengehenden": "zusammengehend",
    "zusammengehender": "zusammengehend",
    "zusammengehendes": "zusammengehend",
    "zusammengehest": "zusammengehen",
    "zusammengehet": "zusammengehen",
    "zusammengehst": "zusammengehen",
    "zusammengeht": "zusammengehen",
    "zusammengehängt": "zusammenhängen",
    "zusammengehängte": "zusammengehängt",
    "zusammengehängtem": "zusammengehängt",
    "zusammengehängten": "zusammengehängt",
    "zusammengehängter": "zusammengehängt",
    "zusammengehängtes": "zusammengehängt",
    "zusammengehöre": "zusammengehören",
    "zusammengehörend": "zusammengehören",
    "zusammengehörende": "zusammengehörend",
    "zusammengehörendem": "zusammengehörend",
    "zusammengehörenden": "zusammengehörend",
    "zusammengehörender": "zusammengehörend",
    "zusammengehörendes": "zusammengehörend",
    "zusammengehörest": "zusammengehören",
    "zusammengehöret": "zusammengehören",
    "zusammengehörige": "zusammengehörig",
    "zusammengehörigem": "zusammengehörig",
    "zusammengehörigen": "zusammengehörig",
    "zusammengehöriger": "zusammengehörig",
    "zusammengehöriges": "zusammengehörig",
    "zusammengehörst": "zusammengehören",
    "zusammengehört": "zusammengehören",
    "zusammengehörte": "zusammengehören",
    "zusammengehörtem": "zusammengehört",
    "zusammengehörten": "zusammengehören",
    "zusammengehörter": "zusammengehört",
    "zusammengehörtes": "zusammengehört",
    "zusammengehörtest": "zusammengehören",
    "zusammengehörtet": "zusammengehören",
    "zusammengekauft": "zusammenkaufen",
    "zusammengekaufte": "zusammengekauft",
    "zusammengekauftem": "zusammengekauft",
    "zusammengekauften": "zusammengekauft",
    "zusammengekaufter": "zusammengekauft",
    "zusammengekauftere": "zusammengekauft",
    "zusammengekaufterem": "zusammengekauft",
    "zusammengekaufteren": "zusammengekauft",
    "zusammengekaufterer": "zusammengekauft",
    "zusammengekaufteres": "zusammengekauft",
    "zusammengekauftes": "zusammengekauft",
    "zusammengekaufteste": "zusammengekauft",
    "zusammengekauftestem": "zusammengekauft",
    "zusammengekauftesten": "zusammengekauft",
    "zusammengekauftester": "zusammengekauft",
    "zusammengekauftestes": "zusammengekauft",
    "zusammengekehrt": "zusammenkehren",
    "zusammengekehrte": "zusammengekehrt",
    "zusammengekehrtem": "zusammengekehrt",
    "zusammengekehrten": "zusammengekehrt",
    "zusammengekehrter": "zusammengekehrt",
    "zusammengekehrtes": "zusammengekehrt",
    "zusammengekettet": "zusammenketten",
    "zusammengekettete": "zusammengekettet",
    "zusammengekettetem": "zusammengekettet",
    "zusammengeketteten": "zusammengekettet",
    "zusammengeketteter": "zusammengekettet",
    "zusammengekettetes": "zusammengekettet",
    "zusammengekittet": "zusammenkitten",
    "zusammengekittete": "zusammengekittet",
    "zusammengekittetem": "zusammengekittet",
    "zusammengekitteten": "zusammengekittet",
    "zusammengekitteter": "zusammengekittet",
    "zusammengekittetes": "zusammengekittet",
    "zusammengeklammert": "zusammenklammern",
    "zusammengeklammerte": "zusammengeklammert",
    "zusammengeklammertem": "zusammengeklammert",
    "zusammengeklammerten": "zusammengeklammert",
    "zusammengeklammerter": "zusammengeklammert",
    "zusammengeklammertere": "zusammengeklammert",
    "zusammengeklammerterem": "zusammengeklammert",
    "zusammengeklammerteren": "zusammengeklammert",
    "zusammengeklammerterer": "zusammengeklammert",
    "zusammengeklammerteres": "zusammengeklammert",
    "zusammengeklammertes": "zusammengeklammert",
    "zusammengeklammerteste": "zusammengeklammert",
    "zusammengeklammertestem": "zusammengeklammert",
    "zusammengeklammertesten": "zusammengeklammert",
    "zusammengeklammertester": "zusammengeklammert",
    "zusammengeklammertestes": "zusammengeklammert",
    "zusammengeklappt": "zusammenklappen",
    "zusammengeklappte": "zusammengeklappt",
    "zusammengeklapptem": "zusammengeklappt",
    "zusammengeklappten": "zusammengeklappt",
    "zusammengeklappter": "zusammengeklappt",
    "zusammengeklapptes": "zusammengeklappt",
    "zusammengeklebt": "zusammenkleben",
    "zusammengeklebte": "zusammengeklebt",
    "zusammengeklebtem": "zusammengeklebt",
    "zusammengeklebten": "zusammengeklebt",
    "zusammengeklebter": "zusammengeklebt",
    "zusammengeklebtes": "zusammengeklebt",
    "zusammengekleistert": "zusammenkleistern",
    "zusammengekleisterte": "zusammengekleistert",
    "zusammengekleistertem": "zusammengekleistert",
    "zusammengekleisterten": "zusammengekleistert",
    "zusammengekleisterter": "zusammengekleistert",
    "zusammengekleistertere": "zusammengekleistert",
    "zusammengekleisterterem": "zusammengekleistert",
    "zusammengekleisterteren": "zusammengekleistert",
    "zusammengekleisterterer": "zusammengekleistert",
    "zusammengekleisterteres": "zusammengekleistert",
    "zusammengekleistertes": "zusammengekleistert",
    "zusammengekleisterteste": "zusammengekleistert",
    "zusammengekleistertestem": "zusammengekleistert",
    "zusammengekleistertesten": "zusammengekleistert",
    "zusammengekleistertester": "zusammengekleistert",
    "zusammengekleistertestes": "zusammengekleistert",
    "zusammengeklungen": "zusammenklingen",
    "zusammengeklungene": "zusammengeklungen",
    "zusammengeklungenem": "zusammengeklungen",
    "zusammengeklungenen": "zusammengeklungen",
    "zusammengeklungener": "zusammengeklungen",
    "zusammengeklungenes": "zusammengeklungen",
    "zusammengekniffen": "zusammenkneifen",
    "zusammengekniffene": "zusammengekniffen",
    "zusammengekniffenem": "zusammengekniffen",
    "zusammengekniffenen": "zusammengekniffen",
    "zusammengekniffener": "zusammengekniffen",
    "zusammengekniffenere": "zusammengekniffen",
    "zusammengekniffenerem": "zusammengekniffen",
    "zusammengekniffeneren": "zusammengekniffen",
    "zusammengekniffenerer": "zusammengekniffen",
    "zusammengekniffeneres": "zusammengekniffen",
    "zusammengekniffenes": "zusammengekniffen",
    "zusammengekniffenste": "zusammengekniffen",
    "zusammengekniffenstem": "zusammengekniffen",
    "zusammengekniffensten": "zusammengekniffen",
    "zusammengekniffenster": "zusammengekniffen",
    "zusammengekniffenstes": "zusammengekniffen",
    "zusammengeknüllt": "zusammenknüllen",
    "zusammengeknüllte": "zusammengeknüllt",
    "zusammengeknülltem": "zusammengeknüllt",
    "zusammengeknüllten": "zusammengeknüllt",
    "zusammengeknüllter": "zusammengeknüllt",
    "zusammengeknülltere": "zusammengeknüllt",
    "zusammengeknüllterem": "zusammengeknüllt",
    "zusammengeknüllteren": "zusammengeknüllt",
    "zusammengeknüllterer": "zusammengeknüllt",
    "zusammengeknüllteres": "zusammengeknüllt",
    "zusammengeknülltes": "zusammengeknüllt",
    "zusammengeknüllteste": "zusammengeknüllt",
    "zusammengeknülltestem": "zusammengeknüllt",
    "zusammengeknülltesten": "zusammengeknüllt",
    "zusammengeknülltester": "zusammengeknüllt",
    "zusammengeknülltestes": "zusammengeknüllt",
    "zusammengeknüpft": "zusammenknüpfen",
    "zusammengeknüpfte": "zusammengeknüpft",
    "zusammengeknüpftem": "zusammengeknüpft",
    "zusammengeknüpften": "zusammengeknüpft",
    "zusammengeknüpfter": "zusammengeknüpft",
    "zusammengeknüpftes": "zusammengeknüpft",
    "zusammengekommen": "zusammenkommen",
    "zusammengekommene": "zusammengekommen",
    "zusammengekommenem": "zusammengekommen",
    "zusammengekommenen": "zusammengekommen",
    "zusammengekommener": "zusammengekommen",
    "zusammengekommenes": "zusammengekommen",
    "zusammengekoppelt": "zusammenkoppeln",
    "zusammengekoppelte": "zusammengekoppelt",
    "zusammengekoppeltem": "zusammengekoppelt",
    "zusammengekoppelten": "zusammengekoppelt",
    "zusammengekoppelter": "zusammengekoppelt",
    "zusammengekoppeltes": "zusammengekoppelt",
    "zusammengekrampft": "zusammenkrampfen",
    "zusammengekrampfte": "zusammengekrampft",
    "zusammengekrampftem": "zusammengekrampft",
    "zusammengekrampften": "zusammengekrampft",
    "zusammengekrampfter": "zusammengekrampft",
    "zusammengekrampftere": "zusammengekrampft",
    "zusammengekrampfterem": "zusammengekrampft",
    "zusammengekrampfteren": "zusammengekrampft",
    "zusammengekrampfterer": "zusammengekrampft",
    "zusammengekrampfteres": "zusammengekrampft",
    "zusammengekrampftes": "zusammengekrampft",
    "zusammengekrampfteste": "zusammengekrampft",
    "zusammengekrampftestem": "zusammengekrampft",
    "zusammengekrampftesten": "zusammengekrampft",
    "zusammengekrampftester": "zusammengekrampft",
    "zusammengekrampftestes": "zusammengekrampft",
    "zusammengekramt": "zusammenkramen",
    "zusammengekramte": "zusammengekramt",
    "zusammengekramtem": "zusammengekramt",
    "zusammengekramten": "zusammengekramt",
    "zusammengekramter": "zusammengekramt",
    "zusammengekramtes": "zusammengekramt",
    "zusammengekratzt": "zusammenkratzen",
    "zusammengekratzte": "zusammengekratzt",
    "zusammengekratztem": "zusammengekratzt",
    "zusammengekratzten": "zusammengekratzt",
    "zusammengekratzter": "zusammengekratzt",
    "zusammengekratztes": "zusammengekratzt",
    "zusammengekuppelt": "zusammenkuppeln",
    "zusammengekuppelte": "zusammengekuppelt",
    "zusammengekuppeltem": "zusammengekuppelt",
    "zusammengekuppelten": "zusammengekuppelt",
    "zusammengekuppelter": "zusammengekuppelt",
    "zusammengekuppeltes": "zusammengekuppelt",
    "zusammengelassen": "zusammenlassen",
    "zusammengelassene": "zusammengelassen",
    "zusammengelassenem": "zusammengelassen",
    "zusammengelassenen": "zusammengelassen",
    "zusammengelassener": "zusammengelassen",
    "zusammengelassenes": "zusammengelassen",
    "zusammengelaufen": "zusammenlaufen",
    "zusammengelaufene": "zusammengelaufen",
    "zusammengelaufenem": "zusammengelaufen",
    "zusammengelaufenen": "zusammengelaufen",
    "zusammengelaufener": "zusammengelaufen",
    "zusammengelaufenes": "zusammengelaufen",
    "zusammengelebt": "zusammenleben",
    "zusammengelebte": "zusammengelebt",
    "zusammengelebtem": "zusammengelebt",
    "zusammengelebten": "zusammengelebt",
    "zusammengelebter": "zusammengelebt",
    "zusammengelebtes": "zusammengelebt",
    "zusammengelegen": "zusammenliegen",
    "zusammengelegene": "zusammengelegen",
    "zusammengelegenem": "zusammengelegen",
    "zusammengelegenen": "zusammengelegen",
    "zusammengelegener": "zusammengelegen",
    "zusammengelegenes": "zusammengelegen",
    "zusammengelegt": "zusammenlegen",
    "zusammengelegte": "zusammengelegt",
    "zusammengelegtem": "zusammengelegt",
    "zusammengelegten": "zusammengelegt",
    "zusammengelegter": "zusammengelegt",
    "zusammengelegtes": "zusammengelegt",
    "zusammengeleimt": "zusammenleimen",
    "zusammengeleimte": "zusammengeleimt",
    "zusammengeleimtem": "zusammengeleimt",
    "zusammengeleimten": "zusammengeleimt",
    "zusammengeleimter": "zusammengeleimt",
    "zusammengeleimtes": "zusammengeleimt",
    "zusammengelesen": "zusammenlesen",
    "zusammengelesene": "zusammengelesen",
    "zusammengelesenem": "zusammengelesen",
    "zusammengelesenen": "zusammengelesen",
    "zusammengelesener": "zusammengelesen",
    "zusammengelesenes": "zusammengelesen",
    "zusammengelogen": "zusammenlügen",
    "zusammengelogene": "zusammengelogen",
    "zusammengelogenem": "zusammengelogen",
    "zusammengelogenen": "zusammengelogen",
    "zusammengelogener": "zusammengelogen",
    "zusammengelogenere": "zusammengelogen",
    "zusammengelogenerem": "zusammengelogen",
    "zusammengelogeneren": "zusammengelogen",
    "zusammengelogenerer": "zusammengelogen",
    "zusammengelogeneres": "zusammengelogen",
    "zusammengelogenes": "zusammengelogen",
    "zusammengelogenste": "zusammengelogen",
    "zusammengelogenstem": "zusammengelogen",
    "zusammengelogensten": "zusammengelogen",
    "zusammengelogenster": "zusammengelogen",
    "zusammengelogenstes": "zusammengelogen",
    "zusammengeläppert": "zusammenläppern",
    "zusammengeläpperte": "zusammengeläppert",
    "zusammengeläppertem": "zusammengeläppert",
    "zusammengeläpperten": "zusammengeläppert",
    "zusammengeläpperter": "zusammengeläppert",
    "zusammengeläppertes": "zusammengeläppert",
    "zusammengenagelt": "zusammennageln",
    "zusammengenagelte": "zusammengenagelt",
    "zusammengenageltem": "zusammengenagelt",
    "zusammengenagelten": "zusammengenagelt",
    "zusammengenagelter": "zusammengenagelt",
    "zusammengenageltes": "zusammengenagelt",
    "zusammengenommen": "zusammennehmen",
    "zusammengenommene": "zusammengenommen",
    "zusammengenommenem": "zusammengenommen",
    "zusammengenommenen": "zusammengenommen",
    "zusammengenommener": "zusammengenommen",
    "zusammengenommenes": "zusammengenommen",
    "zusammengenäht": "zusammennähen",
    "zusammengenähte": "zusammengenäht",
    "zusammengenähtem": "zusammengenäht",
    "zusammengenähten": "zusammengenäht",
    "zusammengenähter": "zusammengenäht",
    "zusammengenähtes": "zusammengenäht",
    "zusammengepaßt": "zusammenpassen",
    "zusammengepaßte": "zusammengepaßt",
    "zusammengepaßtem": "zusammengepaßt",
    "zusammengepaßten": "zusammengepaßt",
    "zusammengepaßter": "zusammengepaßt",
    "zusammengepaßtere": "zusammengepaßt",
    "zusammengepaßterem": "zusammengepaßt",
    "zusammengepaßteren": "zusammengepaßt",
    "zusammengepaßterer": "zusammengepaßt",
    "zusammengepaßteres": "zusammengepaßt",
    "zusammengepaßtes": "zusammengepaßt",
    "zusammengepaßteste": "zusammengepaßt",
    "zusammengepaßtestem": "zusammengepaßt",
    "zusammengepaßtesten": "zusammengepaßt",
    "zusammengepaßtester": "zusammengepaßt",
    "zusammengepaßtestes": "zusammengepaßt",
    "zusammengepfercht": "zusammenpferchen",
    "zusammengepferchte": "zusammengepfercht",
    "zusammengepferchtem": "zusammengepfercht",
    "zusammengepferchten": "zusammengepfercht",
    "zusammengepferchter": "zusammengepfercht",
    "zusammengepferchtere": "zusammengepfercht",
    "zusammengepferchterem": "zusammengepfercht",
    "zusammengepferchteren": "zusammengepfercht",
    "zusammengepferchterer": "zusammengepfercht",
    "zusammengepferchteres": "zusammengepfercht",
    "zusammengepferchtes": "zusammengepfercht",
    "zusammengepferchteste": "zusammengepfercht",
    "zusammengepferchtestem": "zusammengepfercht",
    "zusammengepferchtesten": "zusammengepfercht",
    "zusammengepferchtester": "zusammengepfercht",
    "zusammengepferchtestes": "zusammengepfercht",
    "zusammengeprallt": "zusammenprallen",
    "zusammengeprallte": "zusammengeprallt",
    "zusammengepralltem": "zusammengeprallt",
    "zusammengeprallten": "zusammengeprallt",
    "zusammengeprallter": "zusammengeprallt",
    "zusammengepralltes": "zusammengeprallt",
    "zusammengepreßt": "zusammenpressen",
    "zusammengepreßte": "zusammengepreßt",
    "zusammengepreßtem": "zusammengepreßt",
    "zusammengepreßten": "zusammengepreßt",
    "zusammengepreßter": "zusammengepreßt",
    "zusammengepreßtere": "zusammengepreßt",
    "zusammengepreßterem": "zusammengepreßt",
    "zusammengepreßteren": "zusammengepreßt",
    "zusammengepreßterer": "zusammengepreßt",
    "zusammengepreßteres": "zusammengepreßt",
    "zusammengepreßtes": "zusammengepreßt",
    "zusammengepreßteste": "zusammengepreßt",
    "zusammengepreßtestem": "zusammengepreßt",
    "zusammengepreßtesten": "zusammengepreßt",
    "zusammengepreßtester": "zusammengepreßt",
    "zusammengepreßtestes": "zusammengepreßt",
    "zusammengerafft": "zusammenraffen",
    "zusammengeraffte": "zusammengerafft",
    "zusammengerafftem": "zusammengerafft",
    "zusammengerafften": "zusammengerafft",
    "zusammengeraffter": "zusammengerafft",
    "zusammengerafftes": "zusammengerafft",
    "zusammengerate": "zusammengeraten",
    "zusammengeratend": "zusammengeraten",
    "zusammengeratende": "zusammengeratend",
    "zusammengeratendem": "zusammengeratend",
    "zusammengeratenden": "zusammengeratend",
    "zusammengeratender": "zusammengeratend",
    "zusammengeratendes": "zusammengeratend",
    "zusammengeratene": "zusammengeraten",
    "zusammengeratenem": "zusammengeraten",
    "zusammengeratenen": "zusammengeraten",
    "zusammengeratener": "zusammengeraten",
    "zusammengeratenes": "zusammengeraten",
    "zusammengeratest": "zusammengeraten",
    "zusammengeratet": "zusammengeraten",
    "zusammengerauft": "zusammenraufen",
    "zusammengeraufte": "zusammengerauft",
    "zusammengerauftem": "zusammengerauft",
    "zusammengerauften": "zusammengerauft",
    "zusammengeraufter": "zusammengerauft",
    "zusammengerauftes": "zusammengerauft",
    "zusammengerechnet": "zusammenrechnen",
    "zusammengerechnete": "zusammengerechnet",
    "zusammengerechnetem": "zusammengerechnet",
    "zusammengerechneten": "zusammengerechnet",
    "zusammengerechneter": "zusammengerechnet",
    "zusammengerechnetes": "zusammengerechnet",
    "zusammengereiht": "zusammenreihen",
    "zusammengereihte": "zusammengereiht",
    "zusammengereihtem": "zusammengereiht",
    "zusammengereihten": "zusammengereiht",
    "zusammengereihter": "zusammengereiht",
    "zusammengereihtes": "zusammengereiht",
    "zusammengereimt": "zusammenreimen",
    "zusammengereimte": "zusammengereimt",
    "zusammengereimtem": "zusammengereimt",
    "zusammengereimten": "zusammengereimt",
    "zusammengereimter": "zusammengereimt",
    "zusammengereimtes": "zusammengereimt",
    "zusammengeriet": "zusammengeraten",
    "zusammengeriete": "zusammengeraten",
    "zusammengerieten": "zusammengeraten",
    "zusammengerietest": "zusammengeraten",
    "zusammengerietet": "zusammengeraten",
    "zusammengeringelt": "zusammenringeln",
    "zusammengeringelte": "zusammengeringelt",
    "zusammengeringeltem": "zusammengeringelt",
    "zusammengeringelten": "zusammengeringelt",
    "zusammengeringelter": "zusammengeringelt",
    "zusammengeringeltes": "zusammengeringelt",
    "zusammengerissen": "zusammenreißen",
    "zusammengerissene": "zusammengerissen",
    "zusammengerissenem": "zusammengerissen",
    "zusammengerissenen": "zusammengerissen",
    "zusammengerissener": "zusammengerissen",
    "zusammengerissenes": "zusammengerissen",
    "zusammengerollt": "zusammenrollen",
    "zusammengerollte": "zusammengerollt",
    "zusammengerolltem": "zusammengerollt",
    "zusammengerollten": "zusammengerollt",
    "zusammengerollter": "zusammengerollt",
    "zusammengerolltes": "zusammengerollt",
    "zusammengerottet": "zusammenrotten",
    "zusammengerottete": "zusammengerottet",
    "zusammengerottetem": "zusammengerottet",
    "zusammengerotteten": "zusammengerottet",
    "zusammengerotteter": "zusammengerottet",
    "zusammengerottetes": "zusammengerottet",
    "zusammengerufen": "zusammenrufen",
    "zusammengerufene": "zusammengerufen",
    "zusammengerufenem": "zusammengerufen",
    "zusammengerufenen": "zusammengerufen",
    "zusammengerufener": "zusammengerufen",
    "zusammengerufenes": "zusammengerufen",
    "zusammengerät": "zusammengeraten",
    "zusammengerätst": "zusammengeraten",
    "zusammengeräumt": "zusammenräumen",
    "zusammengeräumte": "zusammengeräumt",
    "zusammengeräumtem": "zusammengeräumt",
    "zusammengeräumten": "zusammengeräumt",
    "zusammengeräumter": "zusammengeräumt",
    "zusammengeräumtes": "zusammengeräumt",
    "zusammengerückt": "zusammenrücken",
    "zusammengerückte": "zusammengerückt",
    "zusammengerücktem": "zusammengerückt",
    "zusammengerückten": "zusammengerückt",
    "zusammengerückter": "zusammengerückt",
    "zusammengerücktes": "zusammengerückt",
    "zusammengescharrt": "zusammenscharren",
    "zusammengescharrte": "zusammengescharrt",
    "zusammengescharrtem": "zusammengescharrt",
    "zusammengescharrten": "zusammengescharrt",
    "zusammengescharrter": "zusammengescharrt",
    "zusammengescharrtes": "zusammengescharrt",
    "zusammengeschart": "zusammenscharen",
    "zusammengescharte": "zusammengeschart",
    "zusammengeschartem": "zusammengeschart",
    "zusammengescharten": "zusammengeschart",
    "zusammengescharter": "zusammengeschart",
    "zusammengeschartes": "zusammengeschart",
    "zusammengeschlagen": "zusammenschlagen",
    "zusammengeschlagene": "zusammengeschlagen",
    "zusammengeschlagenem": "zusammengeschlagen",
    "zusammengeschlagenen": "zusammengeschlagen",
    "zusammengeschlagener": "zusammengeschlagen",
    "zusammengeschlagenes": "zusammengeschlagen",
    "zusammengeschlossen": "zusammenschließen",
    "zusammengeschlossene": "zusammengeschlossen",
    "zusammengeschlossenem": "zusammengeschlossen",
    "zusammengeschlossenen": "zusammengeschlossen",
    "zusammengeschlossener": "zusammengeschlossen",
    "zusammengeschlossenes": "zusammengeschlossen",
    "zusammengeschmolzen": "zusammenschmelzen",
    "zusammengeschmolzene": "zusammengeschmolzen",
    "zusammengeschmolzenem": "zusammengeschmolzen",
    "zusammengeschmolzenen": "zusammengeschmolzen",
    "zusammengeschmolzener": "zusammengeschmolzen",
    "zusammengeschmolzenes": "zusammengeschmolzen",
    "zusammengeschnürt": "zusammenschnüren",
    "zusammengeschnürte": "zusammengeschnürt",
    "zusammengeschnürtem": "zusammengeschnürt",
    "zusammengeschnürten": "zusammengeschnürt",
    "zusammengeschnürter": "zusammengeschnürt",
    "zusammengeschnürtes": "zusammengeschnürt",
    "zusammengeschoben": "zusammenschieben",
    "zusammengeschobene": "zusammengeschoben",
    "zusammengeschobenem": "zusammengeschoben",
    "zusammengeschobenen": "zusammengeschoben",
    "zusammengeschobener": "zusammengeschoben",
    "zusammengeschobenes": "zusammengeschoben",
    "zusammengeschossen": "zusammenschießen",
    "zusammengeschossene": "zusammengeschossen",
    "zusammengeschossenem": "zusammengeschossen",
    "zusammengeschossenen": "zusammengeschossen",
    "zusammengeschossener": "zusammengeschossen",
    "zusammengeschossenere": "zusammengeschossen",
    "zusammengeschossenerem": "zusammengeschossen",
    "zusammengeschosseneren": "zusammengeschossen",
    "zusammengeschossenerer": "zusammengeschossen",
    "zusammengeschosseneres": "zusammengeschossen",
    "zusammengeschossenes": "zusammengeschossen",
    "zusammengeschossenste": "zusammengeschossen",
    "zusammengeschossenstem": "zusammengeschossen",
    "zusammengeschossensten": "zusammengeschossen",
    "zusammengeschossenster": "zusammengeschossen",
    "zusammengeschossenstes": "zusammengeschossen",
    "zusammengeschraubt": "zusammenschrauben",
    "zusammengeschraubte": "zusammengeschraubt",
    "zusammengeschraubtem": "zusammengeschraubt",
    "zusammengeschraubten": "zusammengeschraubt",
    "zusammengeschraubter": "zusammengeschraubt",
    "zusammengeschraubtes": "zusammengeschraubt",
    "zusammengeschreckt": "zusammenschrecken",
    "zusammengeschreckte": "zusammengeschreckt",
    "zusammengeschrecktem": "zusammengeschreckt",
    "zusammengeschreckten": "zusammengeschreckt",
    "zusammengeschreckter": "zusammengeschreckt",
    "zusammengeschrecktere": "zusammengeschreckt",
    "zusammengeschreckterem": "zusammengeschreckt",
    "zusammengeschreckteren": "zusammengeschreckt",
    "zusammengeschreckterer": "zusammengeschreckt",
    "zusammengeschreckteres": "zusammengeschreckt",
    "zusammengeschrecktes": "zusammengeschreckt",
    "zusammengeschreckteste": "zusammengeschreckt",
    "zusammengeschrecktestem": "zusammengeschreckt",
    "zusammengeschrecktesten": "zusammengeschreckt",
    "zusammengeschrecktester": "zusammengeschreckt",
    "zusammengeschrecktestes": "zusammengeschreckt",
    "zusammengeschrieben": "zusammenschreiben",
    "zusammengeschriebene": "zusammengeschrieben",
    "zusammengeschriebenem": "zusammengeschrieben",
    "zusammengeschriebenen": "zusammengeschrieben",
    "zusammengeschriebener": "zusammengeschrieben",
    "zusammengeschriebenes": "zusammengeschrieben",
    "zusammengeschrocken": "zusammenschrecken",
    "zusammengeschrockene": "zusammengeschrocken",
    "zusammengeschrockenem": "zusammengeschrocken",
    "zusammengeschrockenen": "zusammengeschrocken",
    "zusammengeschrockener": "zusammengeschrocken",
    "zusammengeschrockenes": "zusammengeschrocken",
    "zusammengeschrumpft": "zusammenschrumpfe",
    "zusammengeschrumpfte": "zusammengeschrumpft",
    "zusammengeschrumpftem": "zusammengeschrumpft",
    "zusammengeschrumpften": "zusammengeschrumpft",
    "zusammengeschrumpfter": "zusammengeschrumpft",
    "zusammengeschrumpftes": "zusammengeschrumpft",
    "zusammengeschweißt": "zusammenschweißen",
    "zusammengeschweißte": "zusammengeschweißt",
    "zusammengeschweißtem": "zusammengeschweißt",
    "zusammengeschweißten": "zusammengeschweißt",
    "zusammengeschweißter": "zusammengeschweißt",
    "zusammengeschweißtere": "zusammengeschweißt",
    "zusammengeschweißterem": "zusammengeschweißt",
    "zusammengeschweißteren": "zusammengeschweißt",
    "zusammengeschweißterer": "zusammengeschweißt",
    "zusammengeschweißteres": "zusammengeschweißt",
    "zusammengeschweißtes": "zusammengeschweißt",
    "zusammengeschweißteste": "zusammengeschweißt",
    "zusammengeschweißtestem": "zusammengeschweißt",
    "zusammengeschweißtesten": "zusammengeschweißt",
    "zusammengeschweißtester": "zusammengeschweißt",
    "zusammengeschweißtestes": "zusammengeschweißt",
    "zusammengeschüttet": "zusammenschütten",
    "zusammengeschüttete": "zusammengeschüttet",
    "zusammengeschüttetem": "zusammengeschüttet",
    "zusammengeschütteten": "zusammengeschüttet",
    "zusammengeschütteter": "zusammengeschüttet",
    "zusammengeschüttetes": "zusammengeschüttet",
    "zusammengesessen": "zusammensitzen",
    "zusammengesessene": "zusammengesessen",
    "zusammengesessenem": "zusammengesessen",
    "zusammengesessenen": "zusammengesessen",
    "zusammengesessener": "zusammengesessen",
    "zusammengesessenes": "zusammengesessen",
    "zusammengesetzt": "zusammensetzen",
    "zusammengesetzte": "zusammengesetzt",
    "zusammengesetztem": "zusammengesetzt",
    "zusammengesetzten": "zusammengesetzt",
    "zusammengesetzter": "zusammengesetzt",
    "zusammengesetztes": "zusammengesetzt",
    "zusammengespannt": "zusammenspannen",
    "zusammengespannte": "zusammengespannt",
    "zusammengespanntem": "zusammengespannt",
    "zusammengespannten": "zusammengespannt",
    "zusammengespannter": "zusammengespannt",
    "zusammengespanntes": "zusammengespannt",
    "zusammengespart": "zusammensparen",
    "zusammengesparte": "zusammengespart",
    "zusammengespartem": "zusammengespart",
    "zusammengesparten": "zusammengespart",
    "zusammengesparter": "zusammengespart",
    "zusammengespartere": "zusammengespart",
    "zusammengesparterem": "zusammengespart",
    "zusammengesparteren": "zusammengespart",
    "zusammengesparterer": "zusammengespart",
    "zusammengesparteres": "zusammengespart",
    "zusammengespartes": "zusammengespart",
    "zusammengesparteste": "zusammengespart",
    "zusammengespartestem": "zusammengespart",
    "zusammengespartesten": "zusammengespart",
    "zusammengespartester": "zusammengespart",
    "zusammengespartestes": "zusammengespart",
    "zusammengesperrt": "zusammensperren",
    "zusammengesperrte": "zusammengesperrt",
    "zusammengesperrtem": "zusammengesperrt",
    "zusammengesperrten": "zusammengesperrt",
    "zusammengesperrter": "zusammengesperrt",
    "zusammengesperrtes": "zusammengesperrt",
    "zusammengestanden": "zusammenstehen",
    "zusammengestandene": "zusammengestanden",
    "zusammengestandenem": "zusammengestanden",
    "zusammengestandenen": "zusammengestanden",
    "zusammengestandener": "zusammengestanden",
    "zusammengestandenes": "zusammengestanden",
    "zusammengestaucht": "zusammenstauchen",
    "zusammengestauchte": "zusammengestaucht",
    "zusammengestauchtem": "zusammengestaucht",
    "zusammengestauchten": "zusammengestaucht",
    "zusammengestauchter": "zusammengestaucht",
    "zusammengestauchtere": "zusammengestaucht",
    "zusammengestauchterem": "zusammengestaucht",
    "zusammengestauchteren": "zusammengestaucht",
    "zusammengestauchterer": "zusammengestaucht",
    "zusammengestauchteres": "zusammengestaucht",
    "zusammengestauchtes": "zusammengestaucht",
    "zusammengestauchteste": "zusammengestaucht",
    "zusammengestauchtestem": "zusammengestaucht",
    "zusammengestauchtesten": "zusammengestaucht",
    "zusammengestauchtester": "zusammengestaucht",
    "zusammengestauchtestes": "zusammengestaucht",
    "zusammengesteckt": "zusammenstecken",
    "zusammengesteckte": "zusammengesteckt",
    "zusammengestecktem": "zusammengesteckt",
    "zusammengesteckten": "zusammengesteckt",
    "zusammengesteckter": "zusammengesteckt",
    "zusammengestecktes": "zusammengesteckt",
    "zusammengestellt": "zusammenstellen",
    "zusammengestellte": "zusammengestellt",
    "zusammengestelltem": "zusammengestellt",
    "zusammengestellten": "zusammengestellt",
    "zusammengestellter": "zusammengestellt",
    "zusammengestelltes": "zusammengestellt",
    "zusammengestimmt": "zusammenstimmen",
    "zusammengestimmte": "zusammengestimmt",
    "zusammengestimmtem": "zusammengestimmt",
    "zusammengestimmten": "zusammengestimmt",
    "zusammengestimmter": "zusammengestimmt",
    "zusammengestimmtes": "zusammengestimmt",
    "zusammengestoßen": "zusammenstoßen",
    "zusammengestoßene": "zusammengestoßen",
    "zusammengestoßenem": "zusammengestoßen",
    "zusammengestoßenen": "zusammengestoßen",
    "zusammengestoßener": "zusammengestoßen",
    "zusammengestoßenes": "zusammengestoßen",
    "zusammengeströmt": "zusammenströmen",
    "zusammengeströmte": "zusammengeströmt",
    "zusammengeströmtem": "zusammengeströmt",
    "zusammengeströmten": "zusammengeströmt",
    "zusammengeströmter": "zusammengeströmt",
    "zusammengeströmtes": "zusammengeströmt",
    "zusammengestürzt": "zusammenstürzen",
    "zusammengestürzte": "zusammengestürzt",
    "zusammengestürztem": "zusammengestürzt",
    "zusammengestürzten": "zusammengestürzt",
    "zusammengestürzter": "zusammengestürzt",
    "zusammengestürztes": "zusammengestürzt",
    "zusammengesucht": "zusammensuchen",
    "zusammengesuchte": "zusammengesucht",
    "zusammengesuchtem": "zusammengesucht",
    "zusammengesuchten": "zusammengesucht",
    "zusammengesuchter": "zusammengesucht",
    "zusammengesuchtes": "zusammengesucht",
    "zusammengesunken": "zusammensinken",
    "zusammengesunkene": "zusammengesunken",
    "zusammengesunkenem": "zusammengesunken",
    "zusammengesunkenen": "zusammengesunken",
    "zusammengesunkener": "zusammengesunken",
    "zusammengesunkenes": "zusammengesunken",
    "zusammengetragen": "zusammentragen",
    "zusammengetragene": "zusammengetragen",
    "zusammengetragenem": "zusammengetragen",
    "zusammengetragenen": "zusammengetragen",
    "zusammengetragener": "zusammengetragen",
    "zusammengetragenes": "zusammengetragen",
    "zusammengetreten": "zusammentreten",
    "zusammengetretene": "zusammengetreten",
    "zusammengetretenem": "zusammengetreten",
    "zusammengetretenen": "zusammengetreten",
    "zusammengetretener": "zusammengetreten",
    "zusammengetretenere": "zusammengetreten",
    "zusammengetretenerem": "zusammengetreten",
    "zusammengetreteneren": "zusammengetreten",
    "zusammengetretenerer": "zusammengetreten",
    "zusammengetreteneres": "zusammengetreten",
    "zusammengetretenes": "zusammengetreten",
    "zusammengetretenste": "zusammengetreten",
    "zusammengetretenstem": "zusammengetreten",
    "zusammengetretensten": "zusammengetreten",
    "zusammengetretenster": "zusammengetreten",
    "zusammengetretenstes": "zusammengetreten",
    "zusammengetrieben": "zusammentreiben",
    "zusammengetriebene": "zusammengetrieben",
    "zusammengetriebenem": "zusammengetrieben",
    "zusammengetriebenen": "zusammengetrieben",
    "zusammengetriebener": "zusammengetrieben",
    "zusammengetriebenes": "zusammengetrieben",
    "zusammengetrocknet": "zusammentrocknen",
    "zusammengetrocknete": "zusammengetrocknet",
    "zusammengetrocknetem": "zusammengetrocknet",
    "zusammengetrockneten": "zusammengetrocknet",
    "zusammengetrockneter": "zusammengetrocknet",
    "zusammengetrocknetes": "zusammengetrocknet",
    "zusammengetroffen": "zusammentreffen",
    "zusammengetroffene": "zusammengetroffen",
    "zusammengetroffenem": "zusammengetroffen",
    "zusammengetroffenen": "zusammengetroffen",
    "zusammengetroffener": "zusammengetroffen",
    "zusammengetroffenes": "zusammengetroffen",
    "zusammengetrommelt": "zusammentrommeln",
    "zusammengetrommelte": "zusammengetrommelt",
    "zusammengetrommeltem": "zusammengetrommelt",
    "zusammengetrommelten": "zusammengetrommelt",
    "zusammengetrommelter": "zusammengetrommelt",
    "zusammengetrommeltes": "zusammengetrommelt",
    "zusammengewachsen": "zusammenwachsen",
    "zusammengewachsene": "zusammengewachsen",
    "zusammengewachsenem": "zusammengewachsen",
    "zusammengewachsenen": "zusammengewachsen",
    "zusammengewachsener": "zusammengewachsen",
    "zusammengewachsenes": "zusammengewachsen",
    "zusammengewachst": "zusammenwachsen",
    "zusammengewachste": "zusammengewachst",
    "zusammengewachstem": "zusammengewachst",
    "zusammengewachsten": "zusammengewachst",
    "zusammengewachster": "zusammengewachst",
    "zusammengewachstes": "zusammengewachst",
    "zusammengewirkt": "zusammenwirken",
    "zusammengewirkte": "zusammengewirkt",
    "zusammengewirktem": "zusammengewirkt",
    "zusammengewirkten": "zusammengewirkt",
    "zusammengewirkter": "zusammengewirkt",
    "zusammengewirktes": "zusammengewirkt",
    "zusammengeworfen": "zusammenwerfen",
    "zusammengeworfene": "zusammengeworfen",
    "zusammengeworfenem": "zusammengeworfen",
    "zusammengeworfenen": "zusammengeworfen",
    "zusammengeworfener": "zusammengeworfen",
    "zusammengeworfenes": "zusammengeworfen",
    "zusammengewürfelte": "zusammengewürfelt",
    "zusammengewürfeltem": "zusammengewürfelt",
    "zusammengewürfelten": "zusammengewürfelt",
    "zusammengewürfelter": "zusammengewürfelt",
    "zusammengewürfeltes": "zusammengewürfelt",
    "zusammengezogen": "zusammenziehen",
    "zusammengezogene": "zusammengezogen",
    "zusammengezogenem": "zusammengezogen",
    "zusammengezogenen": "zusammengezogen",
    "zusammengezogener": "zusammengezogen",
    "zusammengezogenes": "zusammengezogen",
    "zusammengezählt": "zusammenzählen",
    "zusammengezählte": "zusammengezählt",
    "zusammengezähltem": "zusammengezählt",
    "zusammengezählten": "zusammengezählt",
    "zusammengezählter": "zusammengezählt",
    "zusammengezähltes": "zusammengezählt",
    "zusammengibst": "zusammengeben",
    "zusammengibt": "zusammengeben",
    "zusammengieße": "zusammengießen",
    "zusammengießend": "zusammengießen",
    "zusammengießende": "zusammengießend",
    "zusammengießendem": "zusammengießend",
    "zusammengießenden": "zusammengießend",
    "zusammengießender": "zusammengießend",
    "zusammengießendes": "zusammengießend",
    "zusammengießest": "zusammengießen",
    "zusammengießet": "zusammengießen",
    "zusammengießt": "zusammengießen",
    "zusammenging": "zusammengehen",
    "zusammenginge": "zusammengehen",
    "zusammengingen": "zusammengehen",
    "zusammengingest": "zusammengehen",
    "zusammenginget": "zusammengehen",
    "zusammengingst": "zusammengehen",
    "zusammengingt": "zusammengehen",
    "zusammengossen": "zusammengießen",
    "zusammengoß": "zusammengießen",
    "zusammengoßt": "zusammengießen",
    "zusammengäbe": "zusammengeben",
    "zusammengäben": "zusammengeben",
    "zusammengäbest": "zusammengeben",
    "zusammengäbet": "zusammengeben",
    "zusammengösse": "zusammengießen",
    "zusammengössen": "zusammengießen",
    "zusammengössest": "zusammengießen",
    "zusammengösset": "zusammengießen",
    "zusammenhalte": "zusammenhalten",
    "zusammenhaltend": "zusammenhalten",
    "zusammenhaltende": "zusammenhaltend",
    "zusammenhaltendem": "zusammenhaltend",
    "zusammenhaltenden": "zusammenhaltend",
    "zusammenhaltender": "zusammenhaltend",
    "zusammenhaltendere": "zusammenhaltend",
    "zusammenhaltenderem": "zusammenhaltend",
    "zusammenhaltenderen": "zusammenhaltend",
    "zusammenhaltenderer": "zusammenhaltend",
    "zusammenhaltenderes": "zusammenhaltend",
    "zusammenhaltendes": "zusammenhaltend",
    "zusammenhaltendste": "zusammenhaltend",
    "zusammenhaltendstem": "zusammenhaltend",
    "zusammenhaltendsten": "zusammenhaltend",
    "zusammenhaltendster": "zusammenhaltend",
    "zusammenhaltendstes": "zusammenhaltend",
    "zusammenhaltest": "zusammenhalten",
    "zusammenhaltet": "zusammenhalten",
    "zusammenhanglose": "zusammenhanglos",
    "zusammenhanglosem": "zusammenhanglos",
    "zusammenhanglosen": "zusammenhanglos",
    "zusammenhangloser": "zusammenhanglos",
    "zusammenhanglosere": "zusammenhanglos",
    "zusammenhangloserem": "zusammenhanglos",
    "zusammenhangloseren": "zusammenhanglos",
    "zusammenhangloserer": "zusammenhanglos",
    "zusammenhangloseres": "zusammenhanglos",
    "zusammenhangloses": "zusammenhanglos",
    "zusammenhangloseste": "zusammenhanglos",
    "zusammenhanglosestem": "zusammenhanglos",
    "zusammenhanglosesten": "zusammenhanglos",
    "zusammenhanglosester": "zusammenhanglos",
    "zusammenhanglosestes": "zusammenhanglos",
    "zusammenhangslosem": "zusammenhangslos",
    "zusammenhangslosen": "zusammenhangslos",
    "zusammenhangsloser": "zusammenhangslos",
    "zusammenhangsloses": "zusammenhangslos",
    "zusammenhaue": "zusammenhauen",
    "zusammenhauend": "zusammenhauen",
    "zusammenhauende": "zusammenhauend",
    "zusammenhauendem": "zusammenhauend",
    "zusammenhauenden": "zusammenhauend",
    "zusammenhauender": "zusammenhauend",
    "zusammenhauendes": "zusammenhauend",
    "zusammenhauest": "zusammenhauen",
    "zusammenhauet": "zusammenhauen",
    "zusammenhaust": "zusammenhauen",
    "zusammenhaut": "zusammenhauen",
    "zusammenhaute": "zusammenhauen",
    "zusammenhauten": "zusammenhauen",
    "zusammenhautest": "zusammenhauen",
    "zusammenhautet": "zusammenhauen",
    "zusammenhefte": "zusammenheften",
    "zusammenheftend": "zusammenheften",
    "zusammenheftende": "zusammenheftend",
    "zusammenheftendem": "zusammenheftend",
    "zusammenheftenden": "zusammenheftend",
    "zusammenheftender": "zusammenheftend",
    "zusammenheftendes": "zusammenheftend",
    "zusammenheftest": "zusammenheften",
    "zusammenheftet": "zusammenheften",
    "zusammenheftete": "zusammenheften",
    "zusammenhefteten": "zusammenheften",
    "zusammenheftetest": "zusammenheften",
    "zusammenheftetet": "zusammenheften",
    "zusammenheile": "zusammenheilen",
    "zusammenheilend": "zusammenheilen",
    "zusammenheilende": "zusammenheilend",
    "zusammenheilendem": "zusammenheilend",
    "zusammenheilenden": "zusammenheilend",
    "zusammenheilender": "zusammenheilend",
    "zusammenheilendere": "zusammenheilend",
    "zusammenheilenderem": "zusammenheilend",
    "zusammenheilenderen": "zusammenheilend",
    "zusammenheilenderer": "zusammenheilend",
    "zusammenheilenderes": "zusammenheilend",
    "zusammenheilendes": "zusammenheilend",
    "zusammenheilendste": "zusammenheilend",
    "zusammenheilendstem": "zusammenheilend",
    "zusammenheilendsten": "zusammenheilend",
    "zusammenheilendster": "zusammenheilend",
    "zusammenheilendstes": "zusammenheilend",
    "zusammenheilest": "zusammenheilen",
    "zusammenheilet": "zusammenheilen",
    "zusammenheilst": "zusammenheilen",
    "zusammenheilt": "zusammenheilen",
    "zusammenheilte": "zusammenheilen",
    "zusammenheilten": "zusammenheilen",
    "zusammenheiltest": "zusammenheilen",
    "zusammenheiltet": "zusammenheilen",
    "zusammenhielt": "zusammenhalten",
    "zusammenhielte": "zusammenhalten",
    "zusammenhielten": "zusammenhalten",
    "zusammenhieltest": "zusammenhalten",
    "zusammenhieltet": "zusammenhalten",
    "zusammenhing": "zusammenhängen",
    "zusammenhinge": "zusammenhängen",
    "zusammenhingen": "zusammenhängen",
    "zusammenhingest": "zusammenhängen",
    "zusammenhinget": "zusammenhängen",
    "zusammenhingst": "zusammenhängen",
    "zusammenhingt": "zusammenhängen",
    "zusammenhält": "zusammenhalten",
    "zusammenhältst": "zusammenhalten",
    "zusammenhängend": "zusammenhängen",
    "zusammenhängende": "zusammenhängend",
    "zusammenhängendem": "zusammenhängend",
    "zusammenhängenden": "zusammenhängend",
    "zusammenhängender": "zusammenhängend",
    "zusammenhängendere": "zusammenhängend",
    "zusammenhängenderem": "zusammenhängend",
    "zusammenhängenderen": "zusammenhängend",
    "zusammenhängenderer": "zusammenhängend",
    "zusammenhängenderes": "zusammenhängend",
    "zusammenhängendes": "zusammenhängend",
    "zusammenhängendste": "zusammenhängend",
    "zusammenhängendstem": "zusammenhängend",
    "zusammenhängendsten": "zusammenhängend",
    "zusammenhängendster": "zusammenhängend",
    "zusammenhängendstes": "zusammenhängend",
    "zusammenhängest": "zusammenhängen",
    "zusammenhänget": "zusammenhängen",
    "zusammenhängst": "zusammenhängen",
    "zusammenhängt": "zusammenhängen",
    "zusammenhängte": "zusammenhängen",
    "zusammenhängten": "zusammenhängen",
    "zusammenhängtest": "zusammenhängen",
    "zusammenhängtet": "zusammenhängen",
    "zusammenkam": "zusammenkommen",
    "zusammenkamen": "zusammenkommen",
    "zusammenkamst": "zusammenkommen",
    "zusammenkamt": "zusammenkommen",
    "zusammenkaufe": "zusammenkaufen",
    "zusammenkaufend": "zusammenkaufen",
    "zusammenkaufende": "zusammenkaufend",
    "zusammenkaufendem": "zusammenkaufend",
    "zusammenkaufenden": "zusammenkaufend",
    "zusammenkaufender": "zusammenkaufend",
    "zusammenkaufendere": "zusammenkaufend",
    "zusammenkaufenderem": "zusammenkaufend",
    "zusammenkaufenderen": "zusammenkaufend",
    "zusammenkaufenderer": "zusammenkaufend",
    "zusammenkaufenderes": "zusammenkaufend",
    "zusammenkaufendes": "zusammenkaufend",
    "zusammenkaufendste": "zusammenkaufend",
    "zusammenkaufendstem": "zusammenkaufend",
    "zusammenkaufendsten": "zusammenkaufend",
    "zusammenkaufendster": "zusammenkaufend",
    "zusammenkaufendstes": "zusammenkaufend",
    "zusammenkaufest": "zusammenkaufen",
    "zusammenkaufet": "zusammenkaufen",
    "zusammenkaufst": "zusammenkaufen",
    "zusammenkauft": "zusammenkaufen",
    "zusammenkaufte": "zusammenkaufen",
    "zusammenkauften": "zusammenkaufen",
    "zusammenkauftest": "zusammenkaufen",
    "zusammenkauftet": "zusammenkaufen",
    "zusammenkehre": "zusammenkehren",
    "zusammenkehrend": "zusammenkehren",
    "zusammenkehrende": "zusammenkehrend",
    "zusammenkehrendem": "zusammenkehrend",
    "zusammenkehrenden": "zusammenkehrend",
    "zusammenkehrender": "zusammenkehrend",
    "zusammenkehrendes": "zusammenkehrend",
    "zusammenkehrest": "zusammenkehren",
    "zusammenkehret": "zusammenkehren",
    "zusammenkehrst": "zusammenkehren",
    "zusammenkehrt": "zusammenkehren",
    "zusammenkehrte": "zusammenkehren",
    "zusammenkehrten": "zusammenkehren",
    "zusammenkehrtest": "zusammenkehren",
    "zusammenkehrtet": "zusammenkehren",
    "zusammenkette": "zusammenketten",
    "zusammenkettend": "zusammenketten",
    "zusammenkettende": "zusammenkettend",
    "zusammenkettendem": "zusammenkettend",
    "zusammenkettenden": "zusammenkettend",
    "zusammenkettender": "zusammenkettend",
    "zusammenkettendes": "zusammenkettend",
    "zusammenkettest": "zusammenketten",
    "zusammenkettet": "zusammenketten",
    "zusammenkettete": "zusammenketten",
    "zusammenketteten": "zusammenketten",
    "zusammenkettetest": "zusammenketten",
    "zusammenkettetet": "zusammenketten",
    "zusammenkitte": "zusammenkitten",
    "zusammenkittend": "zusammenkitten",
    "zusammenkittende": "zusammenkittend",
    "zusammenkittendem": "zusammenkittend",
    "zusammenkittenden": "zusammenkittend",
    "zusammenkittender": "zusammenkittend",
    "zusammenkittendes": "zusammenkittend",
    "zusammenkittest": "zusammenkitten",
    "zusammenkittet": "zusammenkitten",
    "zusammenkittete": "zusammenkitten",
    "zusammenkitteten": "zusammenkitten",
    "zusammenkittetest": "zusammenkitten",
    "zusammenkittetet": "zusammenkitten",
    "zusammenklammere": "zusammenklammern",
    "zusammenklammernd": "zusammenklammern",
    "zusammenklammernde": "zusammenklammernd",
    "zusammenklammerndem": "zusammenklammernd",
    "zusammenklammernden": "zusammenklammernd",
    "zusammenklammernder": "zusammenklammernd",
    "zusammenklammerndere": "zusammenklammernd",
    "zusammenklammernderem": "zusammenklammernd",
    "zusammenklammernderen": "zusammenklammernd",
    "zusammenklammernderer": "zusammenklammernd",
    "zusammenklammernderes": "zusammenklammernd",
    "zusammenklammerndes": "zusammenklammernd",
    "zusammenklammerndste": "zusammenklammernd",
    "zusammenklammerndstem": "zusammenklammernd",
    "zusammenklammerndsten": "zusammenklammernd",
    "zusammenklammerndster": "zusammenklammernd",
    "zusammenklammerndstes": "zusammenklammernd",
    "zusammenklammerst": "zusammenklammern",
    "zusammenklammert": "zusammenklammern",
    "zusammenklammerte": "zusammenklammern",
    "zusammenklammerten": "zusammenklammern",
    "zusammenklammertest": "zusammenklammern",
    "zusammenklammertet": "zusammenklammern",
    "zusammenklang": "zusammenklingen",
    "zusammenklangen": "zusammenklingen",
    "zusammenklangst": "zusammenklingen",
    "zusammenklangt": "zusammenklingen",
    "zusammenklappbare": "zusammenklappbar",
    "zusammenklappbarem": "zusammenklappbar",
    "zusammenklappbaren": "zusammenklappbar",
    "zusammenklappbarer": "zusammenklappbar",
    "zusammenklappbares": "zusammenklappbar",
    "zusammenklappe": "zusammenklappen",
    "zusammenklappend": "zusammenklappen",
    "zusammenklappende": "zusammenklappend",
    "zusammenklappendem": "zusammenklappend",
    "zusammenklappenden": "zusammenklappend",
    "zusammenklappender": "zusammenklappend",
    "zusammenklappendes": "zusammenklappend",
    "zusammenklappest": "zusammenklappen",
    "zusammenklappet": "zusammenklappen",
    "zusammenklappst": "zusammenklappen",
    "zusammenklappt": "zusammenklappen",
    "zusammenklappte": "zusammenklappen",
    "zusammenklappten": "zusammenklappen",
    "zusammenklapptest": "zusammenklappen",
    "zusammenklapptet": "zusammenklappen",
    "zusammenklebe": "zusammenkleben",
    "zusammenklebend": "zusammenkleben",
    "zusammenklebende": "zusammenklebend",
    "zusammenklebendem": "zusammenklebend",
    "zusammenklebenden": "zusammenklebend",
    "zusammenklebender": "zusammenklebend",
    "zusammenklebendes": "zusammenklebend",
    "zusammenklebest": "zusammenkleben",
    "zusammenklebet": "zusammenkleben",
    "zusammenklebst": "zusammenkleben",
    "zusammenklebt": "zusammenkleben",
    "zusammenklebte": "zusammenkleben",
    "zusammenklebten": "zusammenkleben",
    "zusammenklebtest": "zusammenkleben",
    "zusammenklebtet": "zusammenkleben",
    "zusammenkleistere": "zusammenkleistern",
    "zusammenkleisternd": "zusammenkleistern",
    "zusammenkleisternde": "zusammenkleisternd",
    "zusammenkleisterndem": "zusammenkleisternd",
    "zusammenkleisternden": "zusammenkleisternd",
    "zusammenkleisternder": "zusammenkleisternd",
    "zusammenkleisterndere": "zusammenkleisternd",
    "zusammenkleisternderem": "zusammenkleisternd",
    "zusammenkleisternderen": "zusammenkleisternd",
    "zusammenkleisternderer": "zusammenkleisternd",
    "zusammenkleisternderes": "zusammenkleisternd",
    "zusammenkleisterndes": "zusammenkleisternd",
    "zusammenkleisterndste": "zusammenkleisternd",
    "zusammenkleisterndstem": "zusammenkleisternd",
    "zusammenkleisterndsten": "zusammenkleisternd",
    "zusammenkleisterndster": "zusammenkleisternd",
    "zusammenkleisterndstes": "zusammenkleisternd",
    "zusammenkleisterst": "zusammenkleistern",
    "zusammenkleistert": "zusammenkleistern",
    "zusammenkleisterte": "zusammenkleistern",
    "zusammenkleisterten": "zusammenkleistern",
    "zusammenkleistertest": "zusammenkleistern",
    "zusammenkleistertet": "zusammenkleistern",
    "zusammenklinge": "zusammenklingen",
    "zusammenklingend": "zusammenklingen",
    "zusammenklingende": "zusammenklingend",
    "zusammenklingendem": "zusammenklingend",
    "zusammenklingenden": "zusammenklingend",
    "zusammenklingender": "zusammenklingend",
    "zusammenklingendes": "zusammenklingend",
    "zusammenklingest": "zusammenklingen",
    "zusammenklinget": "zusammenklingen",
    "zusammenklingst": "zusammenklingen",
    "zusammenklingt": "zusammenklingen",
    "zusammenklängest": "zusammenklingen",
    "zusammenklänget": "zusammenklingen",
    "zusammenkneife": "zusammenkneifen",
    "zusammenkneifend": "zusammenkneifen",
    "zusammenkneifende": "zusammenkneifend",
    "zusammenkneifendem": "zusammenkneifend",
    "zusammenkneifenden": "zusammenkneifend",
    "zusammenkneifender": "zusammenkneifend",
    "zusammenkneifendere": "zusammenkneifend",
    "zusammenkneifenderem": "zusammenkneifend",
    "zusammenkneifenderen": "zusammenkneifend",
    "zusammenkneifenderer": "zusammenkneifend",
    "zusammenkneifenderes": "zusammenkneifend",
    "zusammenkneifendes": "zusammenkneifend",
    "zusammenkneifendste": "zusammenkneifend",
    "zusammenkneifendstem": "zusammenkneifend",
    "zusammenkneifendsten": "zusammenkneifend",
    "zusammenkneifendster": "zusammenkneifend",
    "zusammenkneifendstes": "zusammenkneifend",
    "zusammenkneifest": "zusammenkneifen",
    "zusammenkneifet": "zusammenkneifen",
    "zusammenkneifst": "zusammenkneifen",
    "zusammenkneift": "zusammenkneifen",
    "zusammenkniff": "zusammenkneifen",
    "zusammenkniffe": "zusammenkneifen",
    "zusammenkniffen": "zusammenkneifen",
    "zusammenkniffest": "zusammenkneifen",
    "zusammenkniffet": "zusammenkneifen",
    "zusammenkniffst": "zusammenkneifen",
    "zusammenknifft": "zusammenkneifen",
    "zusammenknülle": "zusammenknüllen",
    "zusammenknüllend": "zusammenknüllen",
    "zusammenknüllende": "zusammenknüllend",
    "zusammenknüllendem": "zusammenknüllend",
    "zusammenknüllenden": "zusammenknüllend",
    "zusammenknüllender": "zusammenknüllend",
    "zusammenknüllendere": "zusammenknüllend",
    "zusammenknüllenderem": "zusammenknüllend",
    "zusammenknüllenderen": "zusammenknüllend",
    "zusammenknüllenderer": "zusammenknüllend",
    "zusammenknüllenderes": "zusammenknüllend",
    "zusammenknüllendes": "zusammenknüllend",
    "zusammenknüllendste": "zusammenknüllend",
    "zusammenknüllendstem": "zusammenknüllend",
    "zusammenknüllendsten": "zusammenknüllend",
    "zusammenknüllendster": "zusammenknüllend",
    "zusammenknüllendstes": "zusammenknüllend",
    "zusammenknüllest": "zusammenknüllen",
    "zusammenknüllet": "zusammenknüllen",
    "zusammenknüllst": "zusammenknüllen",
    "zusammenknüllt": "zusammenknüllen",
    "zusammenknüllte": "zusammenknüllen",
    "zusammenknüllten": "zusammenknüllen",
    "zusammenknülltest": "zusammenknüllen",
    "zusammenknülltet": "zusammenknüllen",
    "zusammenknüpfe": "zusammenknüpfen",
    "zusammenknüpfend": "zusammenknüpfen",
    "zusammenknüpfende": "zusammenknüpfend",
    "zusammenknüpfendem": "zusammenknüpfend",
    "zusammenknüpfenden": "zusammenknüpfend",
    "zusammenknüpfender": "zusammenknüpfend",
    "zusammenknüpfendes": "zusammenknüpfend",
    "zusammenknüpfest": "zusammenknüpfen",
    "zusammenknüpfet": "zusammenknüpfen",
    "zusammenknüpfst": "zusammenknüpfen",
    "zusammenknüpft": "zusammenknüpfen",
    "zusammenknüpfte": "zusammenknüpfen",
    "zusammenknüpften": "zusammenknüpfen",
    "zusammenknüpftest": "zusammenknüpfen",
    "zusammenknüpftet": "zusammenknüpfen",
    "zusammenkomme": "zusammenkommen",
    "zusammenkommend": "zusammenkommen",
    "zusammenkommende": "zusammenkommend",
    "zusammenkommendem": "zusammenkommend",
    "zusammenkommenden": "zusammenkommend",
    "zusammenkommender": "zusammenkommend",
    "zusammenkommendes": "zusammenkommend",
    "zusammenkommest": "zusammenkommen",
    "zusammenkommet": "zusammenkommen",
    "zusammenkommst": "zusammenkommen",
    "zusammenkommt": "zusammenkommen",
    "zusammenkoppele": "zusammenkoppeln",
    "zusammenkoppelnd": "zusammenkoppeln",
    "zusammenkoppelnde": "zusammenkoppelnd",
    "zusammenkoppelndem": "zusammenkoppelnd",
    "zusammenkoppelnden": "zusammenkoppelnd",
    "zusammenkoppelnder": "zusammenkoppelnd",
    "zusammenkoppelndes": "zusammenkoppelnd",
    "zusammenkoppelst": "zusammenkoppeln",
    "zusammenkoppelt": "zusammenkoppeln",
    "zusammenkoppelte": "zusammenkoppeln",
    "zusammenkoppelten": "zusammenkoppeln",
    "zusammenkoppeltest": "zusammenkoppeln",
    "zusammenkoppeltet": "zusammenkoppeln",
    "zusammenkopple": "zusammenkoppeln",
    "zusammenkrame": "zusammenkramen",
    "zusammenkramend": "zusammenkramen",
    "zusammenkramende": "zusammenkramend",
    "zusammenkramendem": "zusammenkramend",
    "zusammenkramenden": "zusammenkramend",
    "zusammenkramender": "zusammenkramend",
    "zusammenkramendes": "zusammenkramend",
    "zusammenkramest": "zusammenkramen",
    "zusammenkramet": "zusammenkramen",
    "zusammenkrampfe": "zusammenkrampfen",
    "zusammenkrampfend": "zusammenkrampfen",
    "zusammenkrampfende": "zusammenkrampfend",
    "zusammenkrampfendem": "zusammenkrampfend",
    "zusammenkrampfenden": "zusammenkrampfend",
    "zusammenkrampfender": "zusammenkrampfend",
    "zusammenkrampfendere": "zusammenkrampfend",
    "zusammenkrampfenderem": "zusammenkrampfend",
    "zusammenkrampfenderen": "zusammenkrampfend",
    "zusammenkrampfenderer": "zusammenkrampfend",
    "zusammenkrampfenderes": "zusammenkrampfend",
    "zusammenkrampfendes": "zusammenkrampfend",
    "zusammenkrampfendste": "zusammenkrampfend",
    "zusammenkrampfendstem": "zusammenkrampfend",
    "zusammenkrampfendsten": "zusammenkrampfend",
    "zusammenkrampfendster": "zusammenkrampfend",
    "zusammenkrampfendstes": "zusammenkrampfend",
    "zusammenkrampfest": "zusammenkrampfen",
    "zusammenkrampfet": "zusammenkrampfen",
    "zusammenkrampfst": "zusammenkrampfen",
    "zusammenkrampft": "zusammenkrampfen",
    "zusammenkrampfte": "zusammenkrampfen",
    "zusammenkrampften": "zusammenkrampfen",
    "zusammenkrampftest": "zusammenkrampfen",
    "zusammenkrampftet": "zusammenkrampfen",
    "zusammenkramst": "zusammenkramen",
    "zusammenkramt": "zusammenkramen",
    "zusammenkramte": "zusammenkramen",
    "zusammenkramten": "zusammenkramen",
    "zusammenkramtest": "zusammenkramen",
    "zusammenkramtet": "zusammenkramen",
    "zusammenkratze": "zusammenkratzen",
    "zusammenkratzend": "zusammenkratzen",
    "zusammenkratzende": "zusammenkratzend",
    "zusammenkratzendem": "zusammenkratzend",
    "zusammenkratzenden": "zusammenkratzend",
    "zusammenkratzender": "zusammenkratzend",
    "zusammenkratzendes": "zusammenkratzend",
    "zusammenkratzest": "zusammenkratzen",
    "zusammenkratzet": "zusammenkratzen",
    "zusammenkratzt": "zusammenkratzen",
    "zusammenkratzte": "zusammenkratzen",
    "zusammenkratzten": "zusammenkratzen",
    "zusammenkratztest": "zusammenkratzen",
    "zusammenkratztet": "zusammenkratzen",
    "zusammenkuppele": "zusammenkuppeln",
    "zusammenkuppelnd": "zusammenkuppeln",
    "zusammenkuppelnde": "zusammenkuppelnd",
    "zusammenkuppelndem": "zusammenkuppelnd",
    "zusammenkuppelnden": "zusammenkuppelnd",
    "zusammenkuppelnder": "zusammenkuppelnd",
    "zusammenkuppelndes": "zusammenkuppelnd",
    "zusammenkuppelst": "zusammenkuppeln",
    "zusammenkuppelt": "zusammenkuppeln",
    "zusammenkuppelte": "zusammenkuppeln",
    "zusammenkuppelten": "zusammenkuppeln",
    "zusammenkuppeltest": "zusammenkuppeln",
    "zusammenkuppeltet": "zusammenkuppeln",
    "zusammenkupple": "zusammenkuppeln",
    "zusammenkäme": "zusammenkommen",
    "zusammenkämen": "zusammenkommen",
    "zusammenkämest": "zusammenkommen",
    "zusammenkämet": "zusammenkommen",
    "zusammenlag": "zusammenliegen",
    "zusammenlagen": "zusammenliegen",
    "zusammenlagst": "zusammenliegen",
    "zusammenlagt": "zusammenliegen",
    "zusammenlas": "zusammenlesen",
    "zusammenlasen": "zusammenlesen",
    "zusammenlasse": "zusammenlassen",
    "zusammenlassend": "zusammenlassen",
    "zusammenlassende": "zusammenlassend",
    "zusammenlassendem": "zusammenlassend",
    "zusammenlassenden": "zusammenlassend",
    "zusammenlassender": "zusammenlassend",
    "zusammenlassendes": "zusammenlassend",
    "zusammenlassest": "zusammenlassen",
    "zusammenlasset": "zusammenlassen",
    "zusammenlast": "zusammenlesen",
    "zusammenlaufend": "zusammenlaufen",
    "zusammenlaufende": "zusammenlaufend",
    "zusammenlaufendem": "zusammenlaufend",
    "zusammenlaufenden": "zusammenlaufend",
    "zusammenlaufender": "zusammenlaufend",
    "zusammenlaufendes": "zusammenlaufend",
    "zusammenlaufest": "zusammenlaufen",
    "zusammenlaufet": "zusammenlaufen",
    "zusammenlauft": "zusammenlaufen",
    "zusammenlaßt": "zusammenlassen",
    "zusammenlebe": "zusammenleben",
    "zusammenlebend": "zusammenleben",
    "zusammenlebende": "zusammenlebend",
    "zusammenlebendem": "zusammenlebend",
    "zusammenlebenden": "zusammenlebend",
    "zusammenlebender": "zusammenlebend",
    "zusammenlebendes": "zusammenlebend",
    "zusammenlebest": "zusammenleben",
    "zusammenlebet": "zusammenleben",
    "zusammenlebst": "zusammenleben",
    "zusammenlebt": "zusammenleben",
    "zusammenlebte": "zusammenleben",
    "zusammenlebten": "zusammenleben",
    "zusammenlebtest": "zusammenleben",
    "zusammenlebtet": "zusammenleben",
    "zusammenlege": "zusammenlegen",
    "zusammenlegend": "zusammenlegen",
    "zusammenlegende": "zusammenlegend",
    "zusammenlegendem": "zusammenlegend",
    "zusammenlegenden": "zusammenlegend",
    "zusammenlegender": "zusammenlegend",
    "zusammenlegendes": "zusammenlegend",
    "zusammenlegest": "zusammenlegen",
    "zusammenleget": "zusammenlegen",
    "zusammenlegst": "zusammenlegen",
    "zusammenlegt": "zusammenlegen",
    "zusammenlegte": "zusammenlegen",
    "zusammenlegten": "zusammenlegen",
    "zusammenlegtest": "zusammenlegen",
    "zusammenlegtet": "zusammenlegen",
    "zusammenleime": "zusammenleimen",
    "zusammenleimend": "zusammenleimen",
    "zusammenleimende": "zusammenleimend",
    "zusammenleimendem": "zusammenleimend",
    "zusammenleimenden": "zusammenleimend",
    "zusammenleimender": "zusammenleimend",
    "zusammenleimendes": "zusammenleimend",
    "zusammenleimest": "zusammenleimen",
    "zusammenleimet": "zusammenleimen",
    "zusammenleimst": "zusammenleimen",
    "zusammenleimt": "zusammenleimen",
    "zusammenleimte": "zusammenleimen",
    "zusammenleimten": "zusammenleimen",
    "zusammenleimtest": "zusammenleimen",
    "zusammenleimtet": "zusammenleimen",
    "zusammenlese": "zusammenlesen",
    "zusammenlesend": "zusammenlesen",
    "zusammenlesende": "zusammenlesend",
    "zusammenlesendem": "zusammenlesend",
    "zusammenlesenden": "zusammenlesend",
    "zusammenlesender": "zusammenlesend",
    "zusammenlesendes": "zusammenlesend",
    "zusammenlesest": "zusammenlesen",
    "zusammenleset": "zusammenlesen",
    "zusammenlest": "zusammenlesen",
    "zusammenlief": "zusammenlaufen",
    "zusammenliefe": "zusammenlaufen",
    "zusammenliefen": "zusammenlaufen",
    "zusammenliefest": "zusammenlaufen",
    "zusammenliefet": "zusammenlaufen",
    "zusammenliefst": "zusammenlaufen",
    "zusammenlieft": "zusammenlaufen",
    "zusammenliege": "zusammenliegen",
    "zusammenliegend": "zusammenliegen",
    "zusammenliegende": "zusammenliegend",
    "zusammenliegendem": "zusammenliegend",
    "zusammenliegenden": "zusammenliegend",
    "zusammenliegender": "zusammenliegend",
    "zusammenliegendes": "zusammenliegend",
    "zusammenliegest": "zusammenliegen",
    "zusammenlieget": "zusammenliegen",
    "zusammenliegst": "zusammenliegen",
    "zusammenliegt": "zusammenliegen",
    "zusammenliest": "zusammenlesen",
    "zusammenließ": "zusammenlassen",
    "zusammenließe": "zusammenlassen",
    "zusammenließen": "zusammenlassen",
    "zusammenließest": "zusammenlassen",
    "zusammenließet": "zusammenlassen",
    "zusammenließt": "zusammenlassen",
    "zusammenlog": "zusammenlügen",
    "zusammenlogen": "zusammenlügen",
    "zusammenlogst": "zusammenlügen",
    "zusammenlogt": "zusammenlügen",
    "zusammenläge": "zusammenliegen",
    "zusammenlägen": "zusammenliegen",
    "zusammenlägest": "zusammenliegen",
    "zusammenläget": "zusammenliegen",
    "zusammenläppere": "zusammenläppern",
    "zusammenläppernd": "zusammenläppern",
    "zusammenläppernde": "zusammenläppernd",
    "zusammenläpperndem": "zusammenläppernd",
    "zusammenläppernden": "zusammenläppernd",
    "zusammenläppernder": "zusammenläppernd",
    "zusammenläpperndes": "zusammenläppernd",
    "zusammenläpperst": "zusammenläppern",
    "zusammenläppert": "zusammenläppern",
    "zusammenläpperte": "zusammenläppern",
    "zusammenläpperten": "zusammenläppern",
    "zusammenläppertest": "zusammenläppern",
    "zusammenläppertet": "zusammenläppern",
    "zusammenläse": "zusammenlesen",
    "zusammenläsen": "zusammenlesen",
    "zusammenläsest": "zusammenlesen",
    "zusammenläset": "zusammenlesen",
    "zusammenläufst": "zusammenlaufen",
    "zusammenläuft": "zusammenlaufen",
    "zusammenläßt": "zusammenlassen",
    "zusammenlöge": "zusammenlügen",
    "zusammenlögen": "zusammenlügen",
    "zusammenlögest": "zusammenlügen",
    "zusammenlöget": "zusammenlügen",
    "zusammenlüge": "zusammenlügen",
    "zusammenlügend": "zusammenlügen",
    "zusammenlügende": "zusammenlügend",
    "zusammenlügendem": "zusammenlügend",
    "zusammenlügenden": "zusammenlügend",
    "zusammenlügender": "zusammenlügend",
    "zusammenlügendere": "zusammenlügend",
    "zusammenlügenderem": "zusammenlügend",
    "zusammenlügenderen": "zusammenlügend",
    "zusammenlügenderer": "zusammenlügend",
    "zusammenlügenderes": "zusammenlügend",
    "zusammenlügendes": "zusammenlügend",
    "zusammenlügendste": "zusammenlügend",
    "zusammenlügendstem": "zusammenlügend",
    "zusammenlügendsten": "zusammenlügend",
    "zusammenlügendster": "zusammenlügend",
    "zusammenlügendstes": "zusammenlügend",
    "zusammenlügest": "zusammenlügen",
    "zusammenlüget": "zusammenlügen",
    "zusammenlügst": "zusammenlügen",
    "zusammenlügt": "zusammenlügen",
    "zusammennagele": "zusammennageln",
    "zusammennagelnd": "zusammennageln",
    "zusammennagelnde": "zusammennagelnd",
    "zusammennagelndem": "zusammennagelnd",
    "zusammennagelnden": "zusammennagelnd",
    "zusammennagelnder": "zusammennagelnd",
    "zusammennagelndes": "zusammennagelnd",
    "zusammennagelst": "zusammennageln",
    "zusammennagelt": "zusammennageln",
    "zusammennagelte": "zusammennageln",
    "zusammennagelten": "zusammennageln",
    "zusammennageltest": "zusammennageln",
    "zusammennageltet": "zusammennageln",
    "zusammennagle": "zusammennageln",
    "zusammennahm": "zusammennehmen",
    "zusammennahmen": "zusammennehmen",
    "zusammennahmst": "zusammennehmen",
    "zusammennahmt": "zusammennehmen",
    "zusammennehme": "zusammennehmen",
    "zusammennehmend": "zusammennehmen",
    "zusammennehmende": "zusammennehmend",
    "zusammennehmendem": "zusammennehmend",
    "zusammennehmenden": "zusammennehmend",
    "zusammennehmender": "zusammennehmend",
    "zusammennehmendes": "zusammennehmend",
    "zusammennehmest": "zusammennehmen",
    "zusammennehmet": "zusammennehmen",
    "zusammennehmt": "zusammennehmen",
    "zusammennimmst": "zusammennehmen",
    "zusammennimmt": "zusammennehmen",
    "zusammennähe": "zusammennähen",
    "zusammennähend": "zusammennähen",
    "zusammennähende": "zusammennähend",
    "zusammennähendem": "zusammennähend",
    "zusammennähenden": "zusammennähend",
    "zusammennähender": "zusammennähend",
    "zusammennähendes": "zusammennähend",
    "zusammennähest": "zusammennähen",
    "zusammennähet": "zusammennähen",
    "zusammennähme": "zusammennehmen",
    "zusammennähmen": "zusammennehmen",
    "zusammennähmest": "zusammennehmen",
    "zusammennähmet": "zusammennehmen",
    "zusammennähst": "zusammennähen",
    "zusammennäht": "zusammennähen",
    "zusammennähte": "zusammennähen",
    "zusammennähten": "zusammennähen",
    "zusammennähtest": "zusammennähen",
    "zusammennähtet": "zusammennähen",
    "zusammenpasse": "zusammenpassen",
    "zusammenpassend": "zusammenpassen",
    "zusammenpassende": "zusammenpassend",
    "zusammenpassendem": "zusammenpassend",
    "zusammenpassenden": "zusammenpassend",
    "zusammenpassender": "zusammenpassend",
    "zusammenpassendere": "zusammenpassend",
    "zusammenpassenderem": "zusammenpassend",
    "zusammenpassenderen": "zusammenpassend",
    "zusammenpassenderer": "zusammenpassend",
    "zusammenpassenderes": "zusammenpassend",
    "zusammenpassendes": "zusammenpassend",
    "zusammenpassendste": "zusammenpassend",
    "zusammenpassendstem": "zusammenpassend",
    "zusammenpassendsten": "zusammenpassend",
    "zusammenpassendster": "zusammenpassend",
    "zusammenpassendstes": "zusammenpassend",
    "zusammenpassest": "zusammenpassen",
    "zusammenpasset": "zusammenpassen",
    "zusammenpaßt": "zusammenpassen",
    "zusammenpaßte": "zusammenpassen",
    "zusammenpaßten": "zusammenpassen",
    "zusammenpaßtest": "zusammenpassen",
    "zusammenpaßtet": "zusammenpassen",
    "zusammenpferche": "zusammenpferchen",
    "zusammenpferchend": "zusammenpferchen",
    "zusammenpferchende": "zusammenpferchend",
    "zusammenpferchendem": "zusammenpferchend",
    "zusammenpferchenden": "zusammenpferchend",
    "zusammenpferchender": "zusammenpferchend",
    "zusammenpferchendere": "zusammenpferchend",
    "zusammenpferchenderem": "zusammenpferchend",
    "zusammenpferchenderen": "zusammenpferchend",
    "zusammenpferchenderer": "zusammenpferchend",
    "zusammenpferchenderes": "zusammenpferchend",
    "zusammenpferchendes": "zusammenpferchend",
    "zusammenpferchendste": "zusammenpferchend",
    "zusammenpferchendstem": "zusammenpferchend",
    "zusammenpferchendsten": "zusammenpferchend",
    "zusammenpferchendster": "zusammenpferchend",
    "zusammenpferchendstes": "zusammenpferchend",
    "zusammenpferchest": "zusammenpferchen",
    "zusammenpferchet": "zusammenpferchen",
    "zusammenpferchst": "zusammenpferchen",
    "zusammenpfercht": "zusammenpferchen",
    "zusammenpferchte": "zusammenpferchen",
    "zusammenpferchten": "zusammenpferchen",
    "zusammenpferchtest": "zusammenpferchen",
    "zusammenpferchtet": "zusammenpferchen",
    "zusammenpralle": "zusammenprallen",
    "zusammenprallend": "zusammenprallen",
    "zusammenprallende": "zusammenprallend",
    "zusammenprallendem": "zusammenprallend",
    "zusammenprallenden": "zusammenprallend",
    "zusammenprallender": "zusammenprallend",
    "zusammenprallendes": "zusammenprallend",
    "zusammenprallest": "zusammenprallen",
    "zusammenprallet": "zusammenprallen",
    "zusammenprallst": "zusammenprallen",
    "zusammenprallt": "zusammenprallen",
    "zusammenprallte": "zusammenprallen",
    "zusammenprallten": "zusammenprallen",
    "zusammenpralltest": "zusammenprallen",
    "zusammenpralltet": "zusammenprallen",
    "zusammenpresse": "zusammenpressen",
    "zusammenpressend": "zusammenpressen",
    "zusammenpressende": "zusammenpressend",
    "zusammenpressendem": "zusammenpressend",
    "zusammenpressenden": "zusammenpressend",
    "zusammenpressender": "zusammenpressend",
    "zusammenpressendere": "zusammenpressend",
    "zusammenpressenderem": "zusammenpressend",
    "zusammenpressenderen": "zusammenpressend",
    "zusammenpressenderer": "zusammenpressend",
    "zusammenpressenderes": "zusammenpressend",
    "zusammenpressendes": "zusammenpressend",
    "zusammenpressendste": "zusammenpressend",
    "zusammenpressendstem": "zusammenpressend",
    "zusammenpressendsten": "zusammenpressend",
    "zusammenpressendster": "zusammenpressend",
    "zusammenpressendstes": "zusammenpressend",
    "zusammenpressest": "zusammenpressen",
    "zusammenpresset": "zusammenpressen",
    "zusammenpreßt": "zusammenpressen",
    "zusammenpreßte": "zusammenpressen",
    "zusammenpreßten": "zusammenpressen",
    "zusammenpreßtest": "zusammenpressen",
    "zusammenpreßtet": "zusammenpressen",
    "zusammenraffe": "zusammenraffen",
    "zusammenraffend": "zusammenraffen",
    "zusammenraffende": "zusammenraffend",
    "zusammenraffendem": "zusammenraffend",
    "zusammenraffenden": "zusammenraffend",
    "zusammenraffender": "zusammenraffend",
    "zusammenraffendes": "zusammenraffend",
    "zusammenraffest": "zusammenraffen",
    "zusammenraffet": "zusammenraffen",
    "zusammenraffst": "zusammenraffen",
    "zusammenrafft": "zusammenraffen",
    "zusammenraffte": "zusammenraffen",
    "zusammenrafften": "zusammenraffen",
    "zusammenrafftest": "zusammenraffen",
    "zusammenrafftet": "zusammenraffen",
    "zusammenraufe": "zusammenraufen",
    "zusammenraufend": "zusammenraufen",
    "zusammenraufende": "zusammenraufend",
    "zusammenraufendem": "zusammenraufend",
    "zusammenraufenden": "zusammenraufend",
    "zusammenraufender": "zusammenraufend",
    "zusammenraufendes": "zusammenraufend",
    "zusammenraufest": "zusammenraufen",
    "zusammenraufet": "zusammenraufen",
    "zusammenraufst": "zusammenraufen",
    "zusammenrauft": "zusammenraufen",
    "zusammenraufte": "zusammenraufen",
    "zusammenrauften": "zusammenraufen",
    "zusammenrauftest": "zusammenraufen",
    "zusammenrauftet": "zusammenraufen",
    "zusammenrechne": "zusammenrechnen",
    "zusammenrechnend": "zusammenrechnen",
    "zusammenrechnende": "zusammenrechnend",
    "zusammenrechnendem": "zusammenrechnend",
    "zusammenrechnenden": "zusammenrechnend",
    "zusammenrechnender": "zusammenrechnend",
    "zusammenrechnendes": "zusammenrechnend",
    "zusammenrechnest": "zusammenrechnen",
    "zusammenrechnet": "zusammenrechnen",
    "zusammenrechnete": "zusammenrechnen",
    "zusammenrechneten": "zusammenrechnen",
    "zusammenrechnetest": "zusammenrechnen",
    "zusammenrechnetet": "zusammenrechnen",
    "zusammenreihe": "zusammenreihen",
    "zusammenreihend": "zusammenreihen",
    "zusammenreihende": "zusammenreihend",
    "zusammenreihendem": "zusammenreihend",
    "zusammenreihenden": "zusammenreihend",
    "zusammenreihender": "zusammenreihend",
    "zusammenreihendes": "zusammenreihend",
    "zusammenreihest": "zusammenreihen",
    "zusammenreihet": "zusammenreihen",
    "zusammenreihst": "zusammenreihen",
    "zusammenreiht": "zusammenreihen",
    "zusammenreihte": "zusammenreihen",
    "zusammenreihten": "zusammenreihen",
    "zusammenreihtest": "zusammenreihen",
    "zusammenreihtet": "zusammenreihen",
    "zusammenreime": "zusammenreimen",
    "zusammenreimend": "zusammenreimen",
    "zusammenreimende": "zusammenreimend",
    "zusammenreimendem": "zusammenreimend",
    "zusammenreimenden": "zusammenreimend",
    "zusammenreimender": "zusammenreimend",
    "zusammenreimendes": "zusammenreimend",
    "zusammenreimest": "zusammenreimen",
    "zusammenreimet": "zusammenreimen",
    "zusammenreimst": "zusammenreimen",
    "zusammenreimt": "zusammenreimen",
    "zusammenreimte": "zusammenreimen",
    "zusammenreimten": "zusammenreimen",
    "zusammenreimtest": "zusammenreimen",
    "zusammenreimtet": "zusammenreimen",
    "zusammenreiße": "zusammenreißen",
    "zusammenreißend": "zusammenreißen",
    "zusammenreißende": "zusammenreißend",
    "zusammenreißendem": "zusammenreißend",
    "zusammenreißenden": "zusammenreißend",
    "zusammenreißender": "zusammenreißend",
    "zusammenreißendes": "zusammenreißend",
    "zusammenreißest": "zusammenreißen",
    "zusammenreißet": "zusammenreißen",
    "zusammenreißt": "zusammenreißen",
    "zusammenrief": "zusammenrufen",
    "zusammenriefe": "zusammenrufen",
    "zusammenriefen": "zusammenrufen",
    "zusammenriefest": "zusammenrufen",
    "zusammenriefet": "zusammenrufen",
    "zusammenriefst": "zusammenrufen",
    "zusammenrieft": "zusammenrufen",
    "zusammenringele": "zusammenringeln",
    "zusammenringelnd": "zusammenringeln",
    "zusammenringelnde": "zusammenringelnd",
    "zusammenringelndem": "zusammenringelnd",
    "zusammenringelnden": "zusammenringelnd",
    "zusammenringelnder": "zusammenringelnd",
    "zusammenringelndes": "zusammenringelnd",
    "zusammenringelst": "zusammenringeln",
    "zusammenringelt": "zusammenringeln",
    "zusammenringelte": "zusammenringeln",
    "zusammenringelten": "zusammenringeln",
    "zusammenringeltest": "zusammenringeln",
    "zusammenringeltet": "zusammenringeln",
    "zusammenringle": "zusammenringeln",
    "zusammenrisse": "zusammenreißen",
    "zusammenrissen": "zusammenreißen",
    "zusammenrissest": "zusammenreißen",
    "zusammenrisset": "zusammenreißen",
    "zusammenriß": "zusammenreißen",
    "zusammenrißt": "zusammenreißen",
    "zusammenrolle": "zusammenrollen",
    "zusammenrollend": "zusammenrollen",
    "zusammenrollende": "zusammenrollend",
    "zusammenrollendem": "zusammenrollend",
    "zusammenrollenden": "zusammenrollend",
    "zusammenrollender": "zusammenrollend",
    "zusammenrollendes": "zusammenrollend",
    "zusammenrollest": "zusammenrollen",
    "zusammenrollet": "zusammenrollen",
    "zusammenrollst": "zusammenrollen",
    "zusammenrollt": "zusammenrollen",
    "zusammenrollte": "zusammenrollen",
    "zusammenrollten": "zusammenrollen",
    "zusammenrolltest": "zusammenrollen",
    "zusammenrolltet": "zusammenrollen",
    "zusammenrotte": "zusammenrotten",
    "zusammenrottend": "zusammenrotten",
    "zusammenrottende": "zusammenrottend",
    "zusammenrottendem": "zusammenrottend",
    "zusammenrottenden": "zusammenrottend",
    "zusammenrottender": "zusammenrottend",
    "zusammenrottendes": "zusammenrottend",
    "zusammenrottest": "zusammenrotten",
    "zusammenrottet": "zusammenrotten",
    "zusammenrottete": "zusammenrotten",
    "zusammenrotteten": "zusammenrotten",
    "zusammenrottetest": "zusammenrotten",
    "zusammenrottetet": "zusammenrotten",
    "zusammenrufe": "zusammenrufen",
    "zusammenrufend": "zusammenrufen",
    "zusammenrufende": "zusammenrufend",
    "zusammenrufendem": "zusammenrufend",
    "zusammenrufenden": "zusammenrufend",
    "zusammenrufender": "zusammenrufend",
    "zusammenrufendes": "zusammenrufend",
    "zusammenrufest": "zusammenrufen",
    "zusammenrufet": "zusammenrufen",
    "zusammenrufst": "zusammenrufen",
    "zusammenruft": "zusammenrufen",
    "zusammenräume": "zusammenräumen",
    "zusammenräumend": "zusammenräumen",
    "zusammenräumende": "zusammenräumend",
    "zusammenräumendem": "zusammenräumend",
    "zusammenräumenden": "zusammenräumend",
    "zusammenräumender": "zusammenräumend",
    "zusammenräumendes": "zusammenräumend",
    "zusammenräumest": "zusammenräumen",
    "zusammenräumet": "zusammenräumen",
    "zusammenräumst": "zusammenräumen",
    "zusammenräumt": "zusammenräumen",
    "zusammenräumte": "zusammenräumen",
    "zusammenräumten": "zusammenräumen",
    "zusammenräumtest": "zusammenräumen",
    "zusammenräumtet": "zusammenräumen",
    "zusammenrücke": "zusammenrücken",
    "zusammenrückend": "zusammenrücken",
    "zusammenrückende": "zusammenrückend",
    "zusammenrückendem": "zusammenrückend",
    "zusammenrückenden": "zusammenrückend",
    "zusammenrückender": "zusammenrückend",
    "zusammenrückendes": "zusammenrückend",
    "zusammenrückest": "zusammenrücken",
    "zusammenrücket": "zusammenrücken",
    "zusammenrückst": "zusammenrücken",
    "zusammenrückt": "zusammenrücken",
    "zusammenrückte": "zusammenrücken",
    "zusammenrückten": "zusammenrücken",
    "zusammenrücktest": "zusammenrücken",
    "zusammenrücktet": "zusammenrücken",
    "zusammensank": "zusammensinken",
    "zusammensanken": "zusammensinken",
    "zusammensankst": "zusammensinken",
    "zusammensankt": "zusammensinken",
    "zusammensaß": "zusammensitzen",
    "zusammensaßen": "zusammensitzen",
    "zusammensaßt": "zusammensitzen",
    "zusammenschare": "zusammenscharen",
    "zusammenscharend": "zusammenscharen",
    "zusammenscharende": "zusammenscharend",
    "zusammenscharendem": "zusammenscharend",
    "zusammenscharenden": "zusammenscharend",
    "zusammenscharender": "zusammenscharend",
    "zusammenscharendes": "zusammenscharend",
    "zusammenscharest": "zusammenscharen",
    "zusammenscharet": "zusammenscharen",
    "zusammenscharre": "zusammenscharren",
    "zusammenscharrend": "zusammenscharren",
    "zusammenscharrende": "zusammenscharrend",
    "zusammenscharrendem": "zusammenscharrend",
    "zusammenscharrenden": "zusammenscharrend",
    "zusammenscharrender": "zusammenscharrend",
    "zusammenscharrendes": "zusammenscharrend",
    "zusammenscharrest": "zusammenscharren",
    "zusammenscharret": "zusammenscharren",
    "zusammenscharrst": "zusammenscharren",
    "zusammenscharrt": "zusammenscharren",
    "zusammenscharrte": "zusammenscharren",
    "zusammenscharrten": "zusammenscharren",
    "zusammenscharrtest": "zusammenscharren",
    "zusammenscharrtet": "zusammenscharren",
    "zusammenscharst": "zusammenscharen",
    "zusammenschart": "zusammenscharen",
    "zusammenscharte": "zusammenscharen",
    "zusammenscharten": "zusammenscharen",
    "zusammenschartest": "zusammenscharen",
    "zusammenschartet": "zusammenscharen",
    "zusammenschiebe": "zusammenschieben",
    "zusammenschiebend": "zusammenschieben",
    "zusammenschiebende": "zusammenschiebend",
    "zusammenschiebendem": "zusammenschiebend",
    "zusammenschiebenden": "zusammenschiebend",
    "zusammenschiebender": "zusammenschiebend",
    "zusammenschiebendes": "zusammenschiebend",
    "zusammenschiebest": "zusammenschieben",
    "zusammenschiebet": "zusammenschieben",
    "zusammenschiebst": "zusammenschieben",
    "zusammenschiebt": "zusammenschieben",
    "zusammenschieße": "zusammenschießen",
    "zusammenschießend": "zusammenschießen",
    "zusammenschießende": "zusammenschießend",
    "zusammenschießendem": "zusammenschießend",
    "zusammenschießenden": "zusammenschießend",
    "zusammenschießender": "zusammenschießend",
    "zusammenschießendes": "zusammenschießend",
    "zusammenschießest": "zusammenschießen",
    "zusammenschießet": "zusammenschießen",
    "zusammenschießt": "zusammenschießen",
    "zusammenschlage": "zusammenschlagen",
    "zusammenschlagend": "zusammenschlagen",
    "zusammenschlagende": "zusammenschlagend",
    "zusammenschlagendem": "zusammenschlagend",
    "zusammenschlagenden": "zusammenschlagend",
    "zusammenschlagender": "zusammenschlagend",
    "zusammenschlagendes": "zusammenschlagend",
    "zusammenschlagest": "zusammenschlagen",
    "zusammenschlaget": "zusammenschlagen",
    "zusammenschlagt": "zusammenschlagen",
    "zusammenschließe": "zusammenschließen",
    "zusammenschließend": "zusammenschließen",
    "zusammenschließende": "zusammenschließend",
    "zusammenschließendem": "zusammenschließend",
    "zusammenschließenden": "zusammenschließend",
    "zusammenschließender": "zusammenschließend",
    "zusammenschließendes": "zusammenschließend",
    "zusammenschließest": "zusammenschließen",
    "zusammenschließet": "zusammenschließen",
    "zusammenschließt": "zusammenschließen",
    "zusammenschlossen": "zusammenschließen",
    "zusammenschloß": "zusammenschließen",
    "zusammenschloßt": "zusammenschließen",
    "zusammenschlug": "zusammenschlagen",
    "zusammenschlugen": "zusammenschlagen",
    "zusammenschlugst": "zusammenschlagen",
    "zusammenschlugt": "zusammenschlagen",
    "zusammenschlägst": "zusammenschlagen",
    "zusammenschlägt": "zusammenschlagen",
    "zusammenschlösse": "zusammenschließen",
    "zusammenschlössen": "zusammenschließen",
    "zusammenschlössest": "zusammenschließen",
    "zusammenschlösset": "zusammenschließen",
    "zusammenschlüge": "zusammenschlagen",
    "zusammenschlügen": "zusammenschlagen",
    "zusammenschlügest": "zusammenschlagen",
    "zusammenschlüget": "zusammenschlagen",
    "zusammenschmelze": "zusammenschmelzen",
    "zusammenschmelzend": "zusammenschmelzen",
    "zusammenschmelzende": "zusammenschmelzend",
    "zusammenschmelzendem": "zusammenschmelzend",
    "zusammenschmelzenden": "zusammenschmelzend",
    "zusammenschmelzender": "zusammenschmelzend",
    "zusammenschmelzendes": "zusammenschmelzend",
    "zusammenschmelzest": "zusammenschmelzen",
    "zusammenschmelzet": "zusammenschmelzen",
    "zusammenschmelzt": "zusammenschmelzen",
    "zusammenschmilzt": "zusammenschmelzen",
    "zusammenschmolz": "zusammenschmelzen",
    "zusammenschmolzen": "zusammenschmelzen",
    "zusammenschmolzst": "zusammenschmelzen",
    "zusammenschmolzt": "zusammenschmelzen",
    "zusammenschmölze": "zusammenschmelzen",
    "zusammenschmölzen": "zusammenschmelzen",
    "zusammenschmölzest": "zusammenschmelzen",
    "zusammenschmölzet": "zusammenschmelzen",
    "zusammenschnüre": "zusammenschnüren",
    "zusammenschnürend": "zusammenschnüren",
    "zusammenschnürende": "zusammenschnürend",
    "zusammenschnürendem": "zusammenschnürend",
    "zusammenschnürenden": "zusammenschnürend",
    "zusammenschnürender": "zusammenschnürend",
    "zusammenschnürendes": "zusammenschnürend",
    "zusammenschnürest": "zusammenschnüren",
    "zusammenschnüret": "zusammenschnüren",
    "zusammenschnürst": "zusammenschnüren",
    "zusammenschnürt": "zusammenschnüren",
    "zusammenschnürte": "zusammenschnüren",
    "zusammenschnürten": "zusammenschnüren",
    "zusammenschnürtest": "zusammenschnüren",
    "zusammenschnürtet": "zusammenschnüren",
    "zusammenschob": "zusammenschieben",
    "zusammenschoben": "zusammenschieben",
    "zusammenschobst": "zusammenschieben",
    "zusammenschobt": "zusammenschieben",
    "zusammenschossen": "zusammenschießen",
    "zusammenschoß": "zusammenschießen",
    "zusammenschoßt": "zusammenschießen",
    "zusammenschrak": "zusammenschrecken",
    "zusammenschraken": "zusammenschrecken",
    "zusammenschrakst": "zusammenschrecken",
    "zusammenschrakt": "zusammenschrecken",
    "zusammenschraube": "zusammenschrauben",
    "zusammenschraubend": "zusammenschrauben",
    "zusammenschraubende": "zusammenschraubend",
    "zusammenschraubendem": "zusammenschraubend",
    "zusammenschraubenden": "zusammenschraubend",
    "zusammenschraubender": "zusammenschraubend",
    "zusammenschraubendes": "zusammenschraubend",
    "zusammenschraubest": "zusammenschrauben",
    "zusammenschraubet": "zusammenschrauben",
    "zusammenschraubst": "zusammenschrauben",
    "zusammenschraubt": "zusammenschrauben",
    "zusammenschraubte": "zusammenschrauben",
    "zusammenschraubten": "zusammenschrauben",
    "zusammenschraubtest": "zusammenschrauben",
    "zusammenschraubtet": "zusammenschrauben",
    "zusammenschrecke": "zusammenschrecken",
    "zusammenschreckend": "zusammenschrecken",
    "zusammenschreckende": "zusammenschreckend",
    "zusammenschreckendem": "zusammenschreckend",
    "zusammenschreckenden": "zusammenschreckend",
    "zusammenschreckender": "zusammenschreckend",
    "zusammenschreckendere": "zusammenschreckend",
    "zusammenschreckenderem": "zusammenschreckend",
    "zusammenschreckenderen": "zusammenschreckend",
    "zusammenschreckenderer": "zusammenschreckend",
    "zusammenschreckenderes": "zusammenschreckend",
    "zusammenschreckendes": "zusammenschreckend",
    "zusammenschreckendste": "zusammenschreckend",
    "zusammenschreckendstem": "zusammenschreckend",
    "zusammenschreckendsten": "zusammenschreckend",
    "zusammenschreckendster": "zusammenschreckend",
    "zusammenschreckendstes": "zusammenschreckend",
    "zusammenschreckest": "zusammenschrecken",
    "zusammenschrecket": "zusammenschrecken",
    "zusammenschreckst": "zusammenschrecken",
    "zusammenschreckt": "zusammenschrecken",
    "zusammenschreckte": "zusammenschrecken",
    "zusammenschreckten": "zusammenschrecken",
    "zusammenschrecktest": "zusammenschrecken",
    "zusammenschrecktet": "zusammenschrecken",
    "zusammenschreibe": "zusammenschreiben",
    "zusammenschreibend": "zusammenschreiben",
    "zusammenschreibende": "zusammenschreibend",
    "zusammenschreibendem": "zusammenschreibend",
    "zusammenschreibenden": "zusammenschreibend",
    "zusammenschreibender": "zusammenschreibend",
    "zusammenschreibendes": "zusammenschreibend",
    "zusammenschreibest": "zusammenschreiben",
    "zusammenschreibet": "zusammenschreiben",
    "zusammenschreibst": "zusammenschreiben",
    "zusammenschreibt": "zusammenschreiben",
    "zusammenschrickst": "zusammenschrecken",
    "zusammenschrickt": "zusammenschrecken",
    "zusammenschrieb": "zusammenschreiben",
    "zusammenschriebe": "zusammenschreiben",
    "zusammenschrieben": "zusammenschreiben",
    "zusammenschriebest": "zusammenschreiben",
    "zusammenschriebet": "zusammenschreiben",
    "zusammenschriebst": "zusammenschreiben",
    "zusammenschriebt": "zusammenschreiben",
    "zusammenschrumpfen": "zusammenschrumpfe",
    "zusammenschrumpfend": "zusammenschrumpfe",
    "zusammenschrumpfende": "zusammenschrumpfend",
    "zusammenschrumpfendem": "zusammenschrumpfend",
    "zusammenschrumpfenden": "zusammenschrumpfend",
    "zusammenschrumpfender": "zusammenschrumpfend",
    "zusammenschrumpfendes": "zusammenschrumpfend",
    "zusammenschrumpfest": "zusammenschrumpfe",
    "zusammenschrumpfet": "zusammenschrumpfe",
    "zusammenschrumpfst": "zusammenschrumpfe",
    "zusammenschrumpft": "zusammenschrumpfe",
    "zusammenschrumpfte": "zusammenschrumpfe",
    "zusammenschrumpften": "zusammenschrumpfe",
    "zusammenschrumpftest": "zusammenschrumpfe",
    "zusammenschrumpftet": "zusammenschrumpfe",
    "zusammenschräke": "zusammenschrecken",
    "zusammenschräken": "zusammenschrecken",
    "zusammenschräkest": "zusammenschrecken",
    "zusammenschräket": "zusammenschrecken",
    "zusammenschweiße": "zusammenschweißen",
    "zusammenschweißend": "zusammenschweißen",
    "zusammenschweißende": "zusammenschweißend",
    "zusammenschweißendem": "zusammenschweißend",
    "zusammenschweißenden": "zusammenschweißend",
    "zusammenschweißender": "zusammenschweißend",
    "zusammenschweißendere": "zusammenschweißend",
    "zusammenschweißenderem": "zusammenschweißend",
    "zusammenschweißenderen": "zusammenschweißend",
    "zusammenschweißenderer": "zusammenschweißend",
    "zusammenschweißenderes": "zusammenschweißend",
    "zusammenschweißendes": "zusammenschweißend",
    "zusammenschweißendste": "zusammenschweißend",
    "zusammenschweißendstem": "zusammenschweißend",
    "zusammenschweißendsten": "zusammenschweißend",
    "zusammenschweißendster": "zusammenschweißend",
    "zusammenschweißendstes": "zusammenschweißend",
    "zusammenschweißest": "zusammenschweißen",
    "zusammenschweißet": "zusammenschweißen",
    "zusammenschweißt": "zusammenschweißen",
    "zusammenschweißte": "zusammenschweißen",
    "zusammenschweißten": "zusammenschweißen",
    "zusammenschweißtest": "zusammenschweißen",
    "zusammenschweißtet": "zusammenschweißen",
    "zusammenschöbe": "zusammenschieben",
    "zusammenschöben": "zusammenschieben",
    "zusammenschöbest": "zusammenschieben",
    "zusammenschöbet": "zusammenschieben",
    "zusammenschösse": "zusammenschießen",
    "zusammenschössen": "zusammenschießen",
    "zusammenschössest": "zusammenschießen",
    "zusammenschösset": "zusammenschießen",
    "zusammenschütte": "zusammenschütten",
    "zusammenschüttend": "zusammenschütten",
    "zusammenschüttende": "zusammenschüttend",
    "zusammenschüttendem": "zusammenschüttend",
    "zusammenschüttenden": "zusammenschüttend",
    "zusammenschüttender": "zusammenschüttend",
    "zusammenschüttendes": "zusammenschüttend",
    "zusammenschüttest": "zusammenschütten",
    "zusammenschüttet": "zusammenschütten",
    "zusammenschüttete": "zusammenschütten",
    "zusammenschütteten": "zusammenschütten",
    "zusammenschüttetest": "zusammenschütten",
    "zusammenschüttetet": "zusammenschütten",
    "zusammensetze": "zusammensetzen",
    "zusammensetzend": "zusammensetzen",
    "zusammensetzende": "zusammensetzend",
    "zusammensetzendem": "zusammensetzend",
    "zusammensetzenden": "zusammensetzend",
    "zusammensetzender": "zusammensetzend",
    "zusammensetzendes": "zusammensetzend",
    "zusammensetzest": "zusammensetzen",
    "zusammensetzet": "zusammensetzen",
    "zusammensetzt": "zusammensetzen",
    "zusammensetzte": "zusammensetzen",
    "zusammensetzten": "zusammensetzen",
    "zusammensetztest": "zusammensetzen",
    "zusammensetztet": "zusammensetzen",
    "zusammensinke": "zusammensinken",
    "zusammensinkend": "zusammensinken",
    "zusammensinkende": "zusammensinkend",
    "zusammensinkendem": "zusammensinkend",
    "zusammensinkenden": "zusammensinkend",
    "zusammensinkender": "zusammensinkend",
    "zusammensinkendes": "zusammensinkend",
    "zusammensinkest": "zusammensinken",
    "zusammensinket": "zusammensinken",
    "zusammensinkst": "zusammensinken",
    "zusammensinkt": "zusammensinken",
    "zusammensitze": "zusammensitzen",
    "zusammensitzend": "zusammensitzen",
    "zusammensitzende": "zusammensitzend",
    "zusammensitzendem": "zusammensitzend",
    "zusammensitzenden": "zusammensitzend",
    "zusammensitzender": "zusammensitzend",
    "zusammensitzendes": "zusammensitzend",
    "zusammensitzest": "zusammensitzen",
    "zusammensitzet": "zusammensitzen",
    "zusammensitzt": "zusammensitzen",
    "zusammenspanne": "zusammenspannen",
    "zusammenspannend": "zusammenspannen",
    "zusammenspannende": "zusammenspannend",
    "zusammenspannendem": "zusammenspannend",
    "zusammenspannenden": "zusammenspannend",
    "zusammenspannender": "zusammenspannend",
    "zusammenspannendes": "zusammenspannend",
    "zusammenspannest": "zusammenspannen",
    "zusammenspannet": "zusammenspannen",
    "zusammenspannst": "zusammenspannen",
    "zusammenspannt": "zusammenspannen",
    "zusammenspannte": "zusammenspannen",
    "zusammenspannten": "zusammenspannen",
    "zusammenspanntest": "zusammenspannen",
    "zusammenspanntet": "zusammenspannen",
    "zusammenspare": "zusammensparen",
    "zusammensparend": "zusammensparen",
    "zusammensparende": "zusammensparend",
    "zusammensparendem": "zusammensparend",
    "zusammensparenden": "zusammensparend",
    "zusammensparender": "zusammensparend",
    "zusammensparendere": "zusammensparend",
    "zusammensparenderem": "zusammensparend",
    "zusammensparenderen": "zusammensparend",
    "zusammensparenderer": "zusammensparend",
    "zusammensparenderes": "zusammensparend",
    "zusammensparendes": "zusammensparend",
    "zusammensparendste": "zusammensparend",
    "zusammensparendstem": "zusammensparend",
    "zusammensparendsten": "zusammensparend",
    "zusammensparendster": "zusammensparend",
    "zusammensparendstes": "zusammensparend",
    "zusammensparest": "zusammensparen",
    "zusammensparet": "zusammensparen",
    "zusammensparst": "zusammensparen",
    "zusammenspart": "zusammensparen",
    "zusammensparte": "zusammensparen",
    "zusammensparten": "zusammensparen",
    "zusammenspartest": "zusammensparen",
    "zusammenspartet": "zusammensparen",
    "zusammensperre": "zusammensperren",
    "zusammensperrend": "zusammensperren",
    "zusammensperrende": "zusammensperrend",
    "zusammensperrendem": "zusammensperrend",
    "zusammensperrenden": "zusammensperrend",
    "zusammensperrender": "zusammensperrend",
    "zusammensperrendes": "zusammensperrend",
    "zusammensperrest": "zusammensperren",
    "zusammensperret": "zusammensperren",
    "zusammensperrst": "zusammensperren",
    "zusammensperrt": "zusammensperren",
    "zusammensperrte": "zusammensperren",
    "zusammensperrten": "zusammensperren",
    "zusammensperrtest": "zusammensperren",
    "zusammensperrtet": "zusammensperren",
    "zusammenstand": "zusammenstehen",
    "zusammenstanden": "zusammenstehen",
    "zusammenstandest": "zusammenstehen",
    "zusammenstandet": "zusammenstehen",
    "zusammenstauche": "zusammenstauchen",
    "zusammenstauchend": "zusammenstauchen",
    "zusammenstauchende": "zusammenstauchend",
    "zusammenstauchendem": "zusammenstauchend",
    "zusammenstauchenden": "zusammenstauchend",
    "zusammenstauchender": "zusammenstauchend",
    "zusammenstauchendere": "zusammenstauchend",
    "zusammenstauchenderem": "zusammenstauchend",
    "zusammenstauchenderen": "zusammenstauchend",
    "zusammenstauchenderer": "zusammenstauchend",
    "zusammenstauchenderes": "zusammenstauchend",
    "zusammenstauchendes": "zusammenstauchend",
    "zusammenstauchendste": "zusammenstauchend",
    "zusammenstauchendstem": "zusammenstauchend",
    "zusammenstauchendsten": "zusammenstauchend",
    "zusammenstauchendster": "zusammenstauchend",
    "zusammenstauchendstes": "zusammenstauchend",
    "zusammenstauchest": "zusammenstauchen",
    "zusammenstauchet": "zusammenstauchen",
    "zusammenstauchst": "zusammenstauchen",
    "zusammenstaucht": "zusammenstauchen",
    "zusammenstauchte": "zusammenstauchen",
    "zusammenstauchten": "zusammenstauchen",
    "zusammenstauchtest": "zusammenstauchen",
    "zusammenstauchtet": "zusammenstauchen",
    "zusammenstecke": "zusammenstecken",
    "zusammensteckend": "zusammenstecken",
    "zusammensteckende": "zusammensteckend",
    "zusammensteckendem": "zusammensteckend",
    "zusammensteckenden": "zusammensteckend",
    "zusammensteckender": "zusammensteckend",
    "zusammensteckendes": "zusammensteckend",
    "zusammensteckest": "zusammenstecken",
    "zusammenstecket": "zusammenstecken",
    "zusammensteckst": "zusammenstecken",
    "zusammensteckt": "zusammenstecken",
    "zusammensteckte": "zusammenstecken",
    "zusammensteckten": "zusammenstecken",
    "zusammenstecktest": "zusammenstecken",
    "zusammenstecktet": "zusammenstecken",
    "zusammenstehe": "zusammenstehen",
    "zusammenstehend": "zusammenstehen",
    "zusammenstehende": "zusammenstehend",
    "zusammenstehendem": "zusammenstehend",
    "zusammenstehenden": "zusammenstehend",
    "zusammenstehender": "zusammenstehend",
    "zusammenstehendes": "zusammenstehend",
    "zusammenstehest": "zusammenstehen",
    "zusammenstehet": "zusammenstehen",
    "zusammenstehst": "zusammenstehen",
    "zusammensteht": "zusammenstehen",
    "zusammenstelle": "zusammenstellen",
    "zusammenstellend": "zusammenstellen",
    "zusammenstellende": "zusammenstellend",
    "zusammenstellendem": "zusammenstellend",
    "zusammenstellenden": "zusammenstellend",
    "zusammenstellender": "zusammenstellend",
    "zusammenstellendes": "zusammenstellend",
    "zusammenstellest": "zusammenstellen",
    "zusammenstellet": "zusammenstellen",
    "zusammenstellst": "zusammenstellen",
    "zusammenstellt": "zusammenstellen",
    "zusammenstellte": "zusammenstellen",
    "zusammenstellten": "zusammenstellen",
    "zusammenstelltest": "zusammenstellen",
    "zusammenstelltet": "zusammenstellen",
    "zusammenstieß": "zusammenstoßen",
    "zusammenstieße": "zusammenstoßen",
    "zusammenstießen": "zusammenstoßen",
    "zusammenstießest": "zusammenstoßen",
    "zusammenstießet": "zusammenstoßen",
    "zusammenstießt": "zusammenstoßen",
    "zusammenstimme": "zusammenstimmen",
    "zusammenstimmend": "zusammenstimmen",
    "zusammenstimmende": "zusammenstimmend",
    "zusammenstimmendem": "zusammenstimmend",
    "zusammenstimmenden": "zusammenstimmend",
    "zusammenstimmender": "zusammenstimmend",
    "zusammenstimmendes": "zusammenstimmend",
    "zusammenstimmest": "zusammenstimmen",
    "zusammenstimmet": "zusammenstimmen",
    "zusammenstimmst": "zusammenstimmen",
    "zusammenstimmt": "zusammenstimmen",
    "zusammenstimmte": "zusammenstimmen",
    "zusammenstimmten": "zusammenstimmen",
    "zusammenstimmtest": "zusammenstimmen",
    "zusammenstimmtet": "zusammenstimmen",
    "zusammenstoßend": "zusammenstoßen",
    "zusammenstoßende": "zusammenstoßend",
    "zusammenstoßendem": "zusammenstoßend",
    "zusammenstoßenden": "zusammenstoßend",
    "zusammenstoßender": "zusammenstoßend",
    "zusammenstoßendes": "zusammenstoßend",
    "zusammenstoßest": "zusammenstoßen",
    "zusammenstoßet": "zusammenstoßen",
    "zusammenstoßt": "zusammenstoßen",
    "zusammenströme": "zusammenströmen",
    "zusammenströmend": "zusammenströmen",
    "zusammenströmende": "zusammenströmend",
    "zusammenströmendem": "zusammenströmend",
    "zusammenströmenden": "zusammenströmend",
    "zusammenströmender": "zusammenströmend",
    "zusammenströmendes": "zusammenströmend",
    "zusammenströmest": "zusammenströmen",
    "zusammenströmet": "zusammenströmen",
    "zusammenströmst": "zusammenströmen",
    "zusammenströmt": "zusammenströmen",
    "zusammenströmte": "zusammenströmen",
    "zusammenströmten": "zusammenströmen",
    "zusammenströmtest": "zusammenströmen",
    "zusammenströmtet": "zusammenströmen",
    "zusammenstößt": "zusammenstoßen",
    "zusammenstünde": "zusammenstehen",
    "zusammenstünden": "zusammenstehen",
    "zusammenstündest": "zusammenstehen",
    "zusammenstündet": "zusammenstehen",
    "zusammenstürze": "zusammenstürzen",
    "zusammenstürzend": "zusammenstürzen",
    "zusammenstürzende": "zusammenstürzend",
    "zusammenstürzendem": "zusammenstürzend",
    "zusammenstürzenden": "zusammenstürzend",
    "zusammenstürzender": "zusammenstürzend",
    "zusammenstürzendes": "zusammenstürzend",
    "zusammenstürzest": "zusammenstürzen",
    "zusammenstürzet": "zusammenstürzen",
    "zusammenstürzt": "zusammenstürzen",
    "zusammenstürzte": "zusammenstürzen",
    "zusammenstürzten": "zusammenstürzen",
    "zusammenstürztest": "zusammenstürzen",
    "zusammenstürztet": "zusammenstürzen",
    "zusammensuche": "zusammensuchen",
    "zusammensuchend": "zusammensuchen",
    "zusammensuchende": "zusammensuchend",
    "zusammensuchendem": "zusammensuchend",
    "zusammensuchenden": "zusammensuchend",
    "zusammensuchender": "zusammensuchend",
    "zusammensuchendes": "zusammensuchend",
    "zusammensuchest": "zusammensuchen",
    "zusammensuchet": "zusammensuchen",
    "zusammensuchst": "zusammensuchen",
    "zusammensucht": "zusammensuchen",
    "zusammensuchte": "zusammensuchen",
    "zusammensuchten": "zusammensuchen",
    "zusammensuchtest": "zusammensuchen",
    "zusammensuchtet": "zusammensuchen",
    "zusammensänke": "zusammensinken",
    "zusammensänken": "zusammensinken",
    "zusammensänkest": "zusammensinken",
    "zusammensänket": "zusammensinken",
    "zusammensäße": "zusammensitzen",
    "zusammensäßen": "zusammensitzen",
    "zusammensäßest": "zusammensitzen",
    "zusammensäßet": "zusammensitzen",
    "zusammentraf": "zusammentreffen",
    "zusammentrafen": "zusammentreffen",
    "zusammentrafst": "zusammentreffen",
    "zusammentraft": "zusammentreffen",
    "zusammentrage": "zusammentragen",
    "zusammentragend": "zusammentragen",
    "zusammentragende": "zusammentragend",
    "zusammentragendem": "zusammentragend",
    "zusammentragenden": "zusammentragend",
    "zusammentragender": "zusammentragend",
    "zusammentragendes": "zusammentragend",
    "zusammentragest": "zusammentragen",
    "zusammentraget": "zusammentragen",
    "zusammentragt": "zusammentragen",
    "zusammentrat": "zusammentreten",
    "zusammentraten": "zusammentreten",
    "zusammentratest": "zusammentreten",
    "zusammentratet": "zusammentreten",
    "zusammentreffe": "zusammentreffen",
    "zusammentreffend": "zusammentreffen",
    "zusammentreffende": "zusammentreffend",
    "zusammentreffendem": "zusammentreffend",
    "zusammentreffenden": "zusammentreffend",
    "zusammentreffender": "zusammentreffend",
    "zusammentreffendes": "zusammentreffend",
    "zusammentreffest": "zusammentreffen",
    "zusammentreffet": "zusammentreffen",
    "zusammentrefft": "zusammentreffen",
    "zusammentreibe": "zusammentreiben",
    "zusammentreibend": "zusammentreiben",
    "zusammentreibende": "zusammentreibend",
    "zusammentreibendem": "zusammentreibend",
    "zusammentreibenden": "zusammentreibend",
    "zusammentreibender": "zusammentreibend",
    "zusammentreibendes": "zusammentreibend",
    "zusammentreibest": "zusammentreiben",
    "zusammentreibet": "zusammentreiben",
    "zusammentreibst": "zusammentreiben",
    "zusammentreibt": "zusammentreiben",
    "zusammentrete": "zusammentreten",
    "zusammentretend": "zusammentreten",
    "zusammentretende": "zusammentretend",
    "zusammentretendem": "zusammentretend",
    "zusammentretenden": "zusammentretend",
    "zusammentretender": "zusammentretend",
    "zusammentretendere": "zusammentretend",
    "zusammentretenderem": "zusammentretend",
    "zusammentretenderen": "zusammentretend",
    "zusammentretenderer": "zusammentretend",
    "zusammentretenderes": "zusammentretend",
    "zusammentretendes": "zusammentretend",
    "zusammentretendste": "zusammentretend",
    "zusammentretendstem": "zusammentretend",
    "zusammentretendsten": "zusammentretend",
    "zusammentretendster": "zusammentretend",
    "zusammentretendstes": "zusammentretend",
    "zusammentretest": "zusammentreten",
    "zusammentretet": "zusammentreten",
    "zusammentrieb": "zusammentreiben",
    "zusammentriebe": "zusammentreiben",
    "zusammentrieben": "zusammentreiben",
    "zusammentriebest": "zusammentreiben",
    "zusammentriebet": "zusammentreiben",
    "zusammentriebst": "zusammentreiben",
    "zusammentriebt": "zusammentreiben",
    "zusammentriffst": "zusammentreffen",
    "zusammentrifft": "zusammentreffen",
    "zusammentritt": "zusammentreten",
    "zusammentrittst": "zusammentreten",
    "zusammentrockne": "zusammentrocknen",
    "zusammentrocknend": "zusammentrocknen",
    "zusammentrocknende": "zusammentrocknend",
    "zusammentrocknendem": "zusammentrocknend",
    "zusammentrocknenden": "zusammentrocknend",
    "zusammentrocknender": "zusammentrocknend",
    "zusammentrocknendes": "zusammentrocknend",
    "zusammentrocknest": "zusammentrocknen",
    "zusammentrocknet": "zusammentrocknen",
    "zusammentrocknete": "zusammentrocknen",
    "zusammentrockneten": "zusammentrocknen",
    "zusammentrocknetest": "zusammentrocknen",
    "zusammentrocknetet": "zusammentrocknen",
    "zusammentrommele": "zusammentrommeln",
    "zusammentrommelnd": "zusammentrommeln",
    "zusammentrommelnde": "zusammentrommelnd",
    "zusammentrommelndem": "zusammentrommelnd",
    "zusammentrommelnden": "zusammentrommelnd",
    "zusammentrommelnder": "zusammentrommelnd",
    "zusammentrommelndes": "zusammentrommelnd",
    "zusammentrommelst": "zusammentrommeln",
    "zusammentrommelt": "zusammentrommeln",
    "zusammentrommelte": "zusammentrommeln",
    "zusammentrommelten": "zusammentrommeln",
    "zusammentrommeltest": "zusammentrommeln",
    "zusammentrommeltet": "zusammentrommeln",
    "zusammentrommle": "zusammentrommeln",
    "zusammentrug": "zusammentragen",
    "zusammentrugen": "zusammentragen",
    "zusammentrugst": "zusammentragen",
    "zusammentrugt": "zusammentragen",
    "zusammenträfe": "zusammentreffen",
    "zusammenträfen": "zusammentreffen",
    "zusammenträfest": "zusammentreffen",
    "zusammenträfet": "zusammentreffen",
    "zusammenträgst": "zusammentragen",
    "zusammenträgt": "zusammentragen",
    "zusammenträte": "zusammentreten",
    "zusammenträten": "zusammentreten",
    "zusammenträtest": "zusammentreten",
    "zusammenträtet": "zusammentreten",
    "zusammentrüge": "zusammentragen",
    "zusammentrügen": "zusammentragen",
    "zusammentrügest": "zusammentragen",
    "zusammentrüget": "zusammentragen",
    "zusammenwachse": "zusammenwachsen",
    "zusammenwachsend": "zusammenwachsen",
    "zusammenwachsende": "zusammenwachsend",
    "zusammenwachsendem": "zusammenwachsend",
    "zusammenwachsenden": "zusammenwachsend",
    "zusammenwachsender": "zusammenwachsend",
    "zusammenwachsendes": "zusammenwachsend",
    "zusammenwachsest": "zusammenwachsen",
    "zusammenwachset": "zusammenwachsen",
    "zusammenwachst": "zusammenwachsen",
    "zusammenwachste": "zusammenwachsen",
    "zusammenwachsten": "zusammenwachsen",
    "zusammenwachstest": "zusammenwachsen",
    "zusammenwachstet": "zusammenwachsen",
    "zusammenwarf": "zusammenwerfen",
    "zusammenwarfen": "zusammenwerfen",
    "zusammenwarfst": "zusammenwerfen",
    "zusammenwarft": "zusammenwerfen",
    "zusammenwerfe": "zusammenwerfen",
    "zusammenwerfend": "zusammenwerfen",
    "zusammenwerfende": "zusammenwerfend",
    "zusammenwerfendem": "zusammenwerfend",
    "zusammenwerfenden": "zusammenwerfend",
    "zusammenwerfender": "zusammenwerfend",
    "zusammenwerfendes": "zusammenwerfend",
    "zusammenwerfest": "zusammenwerfen",
    "zusammenwerfet": "zusammenwerfen",
    "zusammenwerft": "zusammenwerfen",
    "zusammenwirfst": "zusammenwerfen",
    "zusammenwirft": "zusammenwerfen",
    "zusammenwirke": "zusammenwirken",
    "zusammenwirkend": "zusammenwirken",
    "zusammenwirkende": "zusammenwirkend",
    "zusammenwirkendem": "zusammenwirkend",
    "zusammenwirkenden": "zusammenwirkend",
    "zusammenwirkender": "zusammenwirkend",
    "zusammenwirkendes": "zusammenwirkend",
    "zusammenwirkest": "zusammenwirken",
    "zusammenwirket": "zusammenwirken",
    "zusammenwirkst": "zusammenwirken",
    "zusammenwirkt": "zusammenwirken",
    "zusammenwirkte": "zusammenwirken",
    "zusammenwirkten": "zusammenwirken",
    "zusammenwirktest": "zusammenwirken",
    "zusammenwirktet": "zusammenwirken",
    "zusammenwuchs": "zusammenwachsen",
    "zusammenwuchsen": "zusammenwachsen",
    "zusammenwuchst": "zusammenwachsen",
    "zusammenwächst": "zusammenwachsen",
    "zusammenwärfe": "zusammenwerfen",
    "zusammenwärfen": "zusammenwerfen",
    "zusammenwärfest": "zusammenwerfen",
    "zusammenwärfet": "zusammenwerfen",
    "zusammenwüchse": "zusammenwachsen",
    "zusammenwüchsen": "zusammenwachsen",
    "zusammenwüchsest": "zusammenwachsen",
    "zusammenwüchset": "zusammenwachsen",
    "zusammenziehe": "zusammenziehen",
    "zusammenziehend": "zusammenziehen",
    "zusammenziehende": "zusammenziehend",
    "zusammenziehendem": "zusammenziehend",
    "zusammenziehenden": "zusammenziehend",
    "zusammenziehender": "zusammenziehend",
    "zusammenziehendes": "zusammenziehend",
    "zusammenziehest": "zusammenziehen",
    "zusammenziehet": "zusammenziehen",
    "zusammenziehst": "zusammenziehen",
    "zusammenzieht": "zusammenziehen",
    "zusammenzog": "zusammenziehen",
    "zusammenzogen": "zusammenziehen",
    "zusammenzogst": "zusammenziehen",
    "zusammenzogt": "zusammenziehen",
    "zusammenzuarbeiten": "zusammenarbeiten",
    "zusammenzuballen": "zusammenballen",
    "zusammenzubauen": "zusammenbauen",
    "zusammenzubeißen": "zusammenbeißen",
    "zusammenzubetteln": "zusammenbetteln",
    "zusammenzubinden": "zusammenbinden",
    "zusammenzubleiben": "zusammenbleiben",
    "zusammenzuborgen": "zusammenborgen",
    "zusammenzubrauen": "zusammenbrauen",
    "zusammenzubrechen": "zusammenbrechen",
    "zusammenzubringen": "zusammenbringen",
    "zusammenzudrängen": "zusammendrängen",
    "zusammenzufahren": "zusammenfahren",
    "zusammenzufallen": "zusammenfallen",
    "zusammenzufalten": "zusammenfalten",
    "zusammenzufassen": "zusammenfassen",
    "zusammenzufegen": "zusammenfegen",
    "zusammenzufinden": "zusammenfinden",
    "zusammenzuflechten": "zusammenflechten",
    "zusammenzufließen": "zusammenfließen",
    "zusammenzufügen": "zusammenfügen",
    "zusammenzuführen": "zusammenführen",
    "zusammenzugeben": "zusammengeben",
    "zusammenzugehen": "zusammengehen",
    "zusammenzugehören": "zusammengehören",
    "zusammenzugeraten": "zusammengeraten",
    "zusammenzugießen": "zusammengießen",
    "zusammenzuhalten": "zusammenhalten",
    "zusammenzuhauen": "zusammenhauen",
    "zusammenzuheften": "zusammenheften",
    "zusammenzuheilen": "zusammenheilen",
    "zusammenzuhängen": "zusammenhängen",
    "zusammenzukaufen": "zusammenkaufen",
    "zusammenzukehren": "zusammenkehren",
    "zusammenzuketten": "zusammenketten",
    "zusammenzukitten": "zusammenkitten",
    "zusammenzuklammern": "zusammenklammern",
    "zusammenzuklappen": "zusammenklappen",
    "zusammenzukleben": "zusammenkleben",
    "zusammenzukleistern": "zusammenkleistern",
    "zusammenzuklingen": "zusammenklingen",
    "zusammenzukneifen": "zusammenkneifen",
    "zusammenzuknüllen": "zusammenknüllen",
    "zusammenzuknüpfen": "zusammenknüpfen",
    "zusammenzukommen": "zusammenkommen",
    "zusammenzukoppeln": "zusammenkoppeln",
    "zusammenzukramen": "zusammenkramen",
    "zusammenzukrampfen": "zusammenkrampfen",
    "zusammenzukratzen": "zusammenkratzen",
    "zusammenzukuppeln": "zusammenkuppeln",
    "zusammenzulassen": "zusammenlassen",
    "zusammenzulaufen": "zusammenlaufen",
    "zusammenzuleben": "zusammenleben",
    "zusammenzulegen": "zusammenlegen",
    "zusammenzuleimen": "zusammenleimen",
    "zusammenzulesen": "zusammenlesen",
    "zusammenzuliegen": "zusammenliegen",
    "zusammenzuläppern": "zusammenläppern",
    "zusammenzulügen": "zusammenlügen",
    "zusammenzunageln": "zusammennageln",
    "zusammenzunehmen": "zusammennehmen",
    "zusammenzunähen": "zusammennähen",
    "zusammenzupassen": "zusammenpassen",
    "zusammenzupferchen": "zusammenpferchen",
    "zusammenzuprallen": "zusammenprallen",
    "zusammenzupressen": "zusammenpressen",
    "zusammenzuraffen": "zusammenraffen",
    "zusammenzuraufen": "zusammenraufen",
    "zusammenzurechnen": "zusammenrechnen",
    "zusammenzureihen": "zusammenreihen",
    "zusammenzureimen": "zusammenreimen",
    "zusammenzureißen": "zusammenreißen",
    "zusammenzuringeln": "zusammenringeln",
    "zusammenzurollen": "zusammenrollen",
    "zusammenzurotten": "zusammenrotten",
    "zusammenzurufen": "zusammenrufen",
    "zusammenzuräumen": "zusammenräumen",
    "zusammenzurücken": "zusammenrücken",
    "zusammenzuscharen": "zusammenscharen",
    "zusammenzuscharren": "zusammenscharren",
    "zusammenzuschieben": "zusammenschieben",
    "zusammenzuschießen": "zusammenschießen",
    "zusammenzuschlagen": "zusammenschlagen",
    "zusammenzuschließen": "zusammenschließen",
    "zusammenzuschmelzen": "zusammenschmelzen",
    "zusammenzuschnüren": "zusammenschnüren",
    "zusammenzuschrauben": "zusammenschrauben",
    "zusammenzuschrecken": "zusammenschrecken",
    "zusammenzuschreiben": "zusammenschreiben",
    "zusammenzuschrumpfen": "zusammenschrumpfe",
    "zusammenzuschweißen": "zusammenschweißen",
    "zusammenzuschütten": "zusammenschütten",
    "zusammenzusetzen": "zusammensetzen",
    "zusammenzusinken": "zusammensinken",
    "zusammenzusitzen": "zusammensitzen",
    "zusammenzuspannen": "zusammenspannen",
    "zusammenzusparen": "zusammensparen",
    "zusammenzusperren": "zusammensperren",
    "zusammenzustauchen": "zusammenstauchen",
    "zusammenzustecken": "zusammenstecken",
    "zusammenzustehen": "zusammenstehen",
    "zusammenzustellen": "zusammenstellen",
    "zusammenzustimmen": "zusammenstimmen",
    "zusammenzustoßen": "zusammenstoßen",
    "zusammenzuströmen": "zusammenströmen",
    "zusammenzustürzen": "zusammenstürzen",
    "zusammenzusuchen": "zusammensuchen",
    "zusammenzutragen": "zusammentragen",
    "zusammenzutreffen": "zusammentreffen",
    "zusammenzutreiben": "zusammentreiben",
    "zusammenzutreten": "zusammentreten",
    "zusammenzutrocknen": "zusammentrocknen",
    "zusammenzutrommeln": "zusammentrommeln",
    "zusammenzuwachsen": "zusammenwachsen",
    "zusammenzuwerfen": "zusammenwerfen",
    "zusammenzuwirken": "zusammenwirken",
    "zusammenzuziehen": "zusammenziehen",
    "zusammenzuzählen": "zusammenzählen",
    "zusammenzähle": "zusammenzählen",
    "zusammenzählend": "zusammenzählen",
    "zusammenzählende": "zusammenzählend",
    "zusammenzählendem": "zusammenzählend",
    "zusammenzählenden": "zusammenzählend",
    "zusammenzählender": "zusammenzählend",
    "zusammenzählendes": "zusammenzählend",
    "zusammenzählest": "zusammenzählen",
    "zusammenzählet": "zusammenzählen",
    "zusammenzählst": "zusammenzählen",
    "zusammenzählt": "zusammenzählen",
    "zusammenzählte": "zusammenzählen",
    "zusammenzählten": "zusammenzählen",
    "zusammenzähltest": "zusammenzählen",
    "zusammenzähltet": "zusammenzählen",
    "zusammenzöge": "zusammenziehen",
    "zusammenzögen": "zusammenziehen",
    "zusammenzögest": "zusammenziehen",
    "zusammenzöget": "zusammenziehen",
    "zusandte": "zusenden",
    "zusandten": "zusenden",
    "zusandtest": "zusenden",
    "zusandtet": "zusenden",
    "zusaß": "zusitzen",
    "zusaßen": "zusitzen",
    "zusaßt": "zusitzen",
    "zuschanze": "zuschanzen",
    "zuschanzend": "zuschanzen",
    "zuschanzende": "zuschanzend",
    "zuschanzendem": "zuschanzend",
    "zuschanzenden": "zuschanzend",
    "zuschanzender": "zuschanzend",
    "zuschanzendes": "zuschanzend",
    "zuschanzest": "zuschanzen",
    "zuschanzet": "zuschanzen",
    "zuschanzt": "zuschanzen",
    "zuschanzte": "zuschanzen",
    "zuschanzten": "zuschanzen",
    "zuschanztest": "zuschanzen",
    "zuschanztet": "zuschanzen",
    "zuschaue": "zuschauen",
    "zuschauend": "zuschauen",
    "zuschauende": "zuschauend",
    "zuschauendem": "zuschauend",
    "zuschauenden": "zuschauend",
    "zuschauender": "zuschauend",
    "zuschauendes": "zuschauend",
    "zuschauest": "zuschauen",
    "zuschauet": "zuschauen",
    "zuschaufele": "zuschaufeln",
    "zuschaufelnd": "zuschaufeln",
    "zuschaufelnde": "zuschaufelnd",
    "zuschaufelndem": "zuschaufelnd",
    "zuschaufelnden": "zuschaufelnd",
    "zuschaufelnder": "zuschaufelnd",
    "zuschaufelndes": "zuschaufelnd",
    "zuschaufelst": "zuschaufeln",
    "zuschaufelt": "zuschaufeln",
    "zuschaufelte": "zuschaufeln",
    "zuschaufelten": "zuschaufeln",
    "zuschaufeltest": "zuschaufeln",
    "zuschaufeltet": "zuschaufeln",
    "zuschaufle": "zuschaufeln",
    "zuschaust": "zuschauen",
    "zuschaut": "zuschauen",
    "zuschaute": "zuschauen",
    "zuschauten": "zuschauen",
    "zuschautest": "zuschauen",
    "zuschautet": "zuschauen",
    "zuschiebe": "zuschieben",
    "zuschiebend": "zuschieben",
    "zuschiebende": "zuschiebend",
    "zuschiebendem": "zuschiebend",
    "zuschiebenden": "zuschiebend",
    "zuschiebender": "zuschiebend",
    "zuschiebendes": "zuschiebend",
    "zuschiebest": "zuschieben",
    "zuschiebet": "zuschieben",
    "zuschiebst": "zuschieben",
    "zuschiebt": "zuschieben",
    "zuschieße": "zuschießen",
    "zuschießend": "zuschießen",
    "zuschießende": "zuschießend",
    "zuschießendem": "zuschießend",
    "zuschießenden": "zuschießend",
    "zuschießender": "zuschießend",
    "zuschießendes": "zuschießend",
    "zuschießest": "zuschießen",
    "zuschießet": "zuschießen",
    "zuschießt": "zuschießen",
    "zuschlagend": "zuschlagen",
    "zuschlagende": "zuschlagend",
    "zuschlagendem": "zuschlagend",
    "zuschlagenden": "zuschlagend",
    "zuschlagender": "zuschlagend",
    "zuschlagendes": "zuschlagend",
    "zuschlagest": "zuschlagen",
    "zuschlaget": "zuschlagen",
    "zuschlagpflichtige": "zuschlagpflichtig",
    "zuschlagpflichtigem": "zuschlagpflichtig",
    "zuschlagpflichtigen": "zuschlagpflichtig",
    "zuschlagpflichtiger": "zuschlagpflichtig",
    "zuschlagpflichtiges": "zuschlagpflichtig",
    "zuschlagt": "zuschlagen",
    "zuschließe": "zuschließen",
    "zuschließend": "zuschließen",
    "zuschließende": "zuschließend",
    "zuschließendem": "zuschließend",
    "zuschließenden": "zuschließend",
    "zuschließender": "zuschließend",
    "zuschließendes": "zuschließend",
    "zuschließest": "zuschließen",
    "zuschließet": "zuschließen",
    "zuschließt": "zuschließen",
    "zuschlossen": "zuschließen",
    "zuschloß": "zuschließen",
    "zuschloßt": "zuschließen",
    "zuschlug": "zuschlagen",
    "zuschlugen": "zuschlagen",
    "zuschlugst": "zuschlagen",
    "zuschlugt": "zuschlagen",
    "zuschlägst": "zuschlagen",
    "zuschlägt": "zuschlagen",
    "zuschlösse": "zuschließen",
    "zuschlössen": "zuschließen",
    "zuschlössest": "zuschließen",
    "zuschlösset": "zuschließen",
    "zuschlüge": "zuschlagen",
    "zuschlügen": "zuschlagen",
    "zuschlügest": "zuschlagen",
    "zuschlüget": "zuschlagen",
    "zuschmeiße": "zuschmeißen",
    "zuschmeißend": "zuschmeißen",
    "zuschmeißende": "zuschmeißend",
    "zuschmeißendem": "zuschmeißend",
    "zuschmeißenden": "zuschmeißend",
    "zuschmeißender": "zuschmeißend",
    "zuschmeißendes": "zuschmeißend",
    "zuschmeißest": "zuschmeißen",
    "zuschmeißet": "zuschmeißen",
    "zuschmeißt": "zuschmeißen",
    "zuschmisse": "zuschmeißen",
    "zuschmissen": "zuschmeißen",
    "zuschmissest": "zuschmeißen",
    "zuschmisset": "zuschmeißen",
    "zuschmiß": "zuschmeißen",
    "zuschmißt": "zuschmeißen",
    "zuschnalle": "zuschnallen",
    "zuschnallend": "zuschnallen",
    "zuschnallende": "zuschnallend",
    "zuschnallendem": "zuschnallend",
    "zuschnallenden": "zuschnallend",
    "zuschnallender": "zuschnallend",
    "zuschnallendes": "zuschnallend",
    "zuschnallest": "zuschnallen",
    "zuschnallet": "zuschnallen",
    "zuschnallst": "zuschnallen",
    "zuschnallt": "zuschnallen",
    "zuschnallte": "zuschnallen",
    "zuschnallten": "zuschnallen",
    "zuschnalltest": "zuschnallen",
    "zuschnalltet": "zuschnallen",
    "zuschnappe": "zuschnappen",
    "zuschnappend": "zuschnappen",
    "zuschnappende": "zuschnappend",
    "zuschnappendem": "zuschnappend",
    "zuschnappenden": "zuschnappend",
    "zuschnappender": "zuschnappend",
    "zuschnappendes": "zuschnappend",
    "zuschnappest": "zuschnappen",
    "zuschnappet": "zuschnappen",
    "zuschnappst": "zuschnappen",
    "zuschnappt": "zuschnappen",
    "zuschnappte": "zuschnappen",
    "zuschnappten": "zuschnappen",
    "zuschnapptest": "zuschnappen",
    "zuschnapptet": "zuschnappen",
    "zuschneide": "zuschneiden",
    "zuschneidend": "zuschneiden",
    "zuschneidende": "zuschneidend",
    "zuschneidendem": "zuschneidend",
    "zuschneidenden": "zuschneidend",
    "zuschneidender": "zuschneidend",
    "zuschneidendes": "zuschneidend",
    "zuschneidest": "zuschneiden",
    "zuschneidet": "zuschneiden",
    "zuschneie": "zuschneien",
    "zuschneiend": "zuschneien",
    "zuschneiende": "zuschneiend",
    "zuschneiendem": "zuschneiend",
    "zuschneienden": "zuschneiend",
    "zuschneiender": "zuschneiend",
    "zuschneiendere": "zuschneiend",
    "zuschneienderem": "zuschneiend",
    "zuschneienderen": "zuschneiend",
    "zuschneienderer": "zuschneiend",
    "zuschneienderes": "zuschneiend",
    "zuschneiendes": "zuschneiend",
    "zuschneiendste": "zuschneiend",
    "zuschneiendstem": "zuschneiend",
    "zuschneiendsten": "zuschneiend",
    "zuschneiendster": "zuschneiend",
    "zuschneiendstes": "zuschneiend",
    "zuschneiest": "zuschneien",
    "zuschneiet": "zuschneien",
    "zuschneist": "zuschneien",
    "zuschneit": "zuschneien",
    "zuschneite": "zuschneien",
    "zuschneiten": "zuschneien",
    "zuschneitest": "zuschneien",
    "zuschneitet": "zuschneien",
    "zuschnitt": "zuschneiden",
    "zuschnitte": "zuschneiden",
    "zuschnitten": "zuschneiden",
    "zuschnittest": "zuschneiden",
    "zuschnittet": "zuschneiden",
    "zuschnüre": "zuschnüren",
    "zuschnürend": "zuschnüren",
    "zuschnürende": "zuschnürend",
    "zuschnürendem": "zuschnürend",
    "zuschnürenden": "zuschnürend",
    "zuschnürender": "zuschnürend",
    "zuschnürendes": "zuschnürend",
    "zuschnürest": "zuschnüren",
    "zuschnüret": "zuschnüren",
    "zuschnürst": "zuschnüren",
    "zuschnürt": "zuschnüren",
    "zuschnürte": "zuschnüren",
    "zuschnürten": "zuschnüren",
    "zuschnürtest": "zuschnüren",
    "zuschnürtet": "zuschnüren",
    "zuschob": "zuschieben",
    "zuschoben": "zuschieben",
    "zuschobst": "zuschieben",
    "zuschobt": "zuschieben",
    "zuschossen": "zuschießen",
    "zuschoß": "zuschießen",
    "zuschoßt": "zuschießen",
    "zuschraube": "zuschrauben",
    "zuschraubend": "zuschrauben",
    "zuschraubende": "zuschraubend",
    "zuschraubendem": "zuschraubend",
    "zuschraubenden": "zuschraubend",
    "zuschraubender": "zuschraubend",
    "zuschraubendes": "zuschraubend",
    "zuschraubest": "zuschrauben",
    "zuschraubet": "zuschrauben",
    "zuschraubst": "zuschrauben",
    "zuschraubt": "zuschrauben",
    "zuschraubte": "zuschrauben",
    "zuschraubten": "zuschrauben",
    "zuschraubtest": "zuschrauben",
    "zuschraubtet": "zuschrauben",
    "zuschreibe": "zuschreiben",
    "zuschreibend": "zuschreiben",
    "zuschreibende": "zuschreibend",
    "zuschreibendem": "zuschreibend",
    "zuschreibenden": "zuschreibend",
    "zuschreibender": "zuschreibend",
    "zuschreibendes": "zuschreibend",
    "zuschreibest": "zuschreiben",
    "zuschreibet": "zuschreiben",
    "zuschreibst": "zuschreiben",
    "zuschreibt": "zuschreiben",
    "zuschrieb": "zuschreiben",
    "zuschriebe": "zuschreiben",
    "zuschrieben": "zuschreiben",
    "zuschriebest": "zuschreiben",
    "zuschriebet": "zuschreiben",
    "zuschriebst": "zuschreiben",
    "zuschriebt": "zuschreiben",
    "zuschustere": "zuschustern",
    "zuschusternd": "zuschustern",
    "zuschusternde": "zuschusternd",
    "zuschusterndem": "zuschusternd",
    "zuschusternden": "zuschusternd",
    "zuschusternder": "zuschusternd",
    "zuschusterndes": "zuschusternd",
    "zuschusterst": "zuschustern",
    "zuschustert": "zuschustern",
    "zuschusterte": "zuschustern",
    "zuschusterten": "zuschustern",
    "zuschustertest": "zuschustern",
    "zuschustertet": "zuschustern",
    "zuschöbe": "zuschieben",
    "zuschöben": "zuschieben",
    "zuschöbest": "zuschieben",
    "zuschöbet": "zuschieben",
    "zuschösse": "zuschießen",
    "zuschössen": "zuschießen",
    "zuschössest": "zuschießen",
    "zuschösset": "zuschießen",
    "zuschütte": "zuschütten",
    "zuschüttend": "zuschütten",
    "zuschüttende": "zuschüttend",
    "zuschüttendem": "zuschüttend",
    "zuschüttenden": "zuschüttend",
    "zuschüttender": "zuschüttend",
    "zuschüttendes": "zuschüttend",
    "zuschüttest": "zuschütten",
    "zuschüttet": "zuschütten",
    "zuschüttete": "zuschütten",
    "zuschütteten": "zuschütten",
    "zuschüttetest": "zuschütten",
    "zuschüttetet": "zuschütten",
    "zusehe": "zusehen",
    "zusehend": "zusehen",
    "zusehende": "zusehend",
    "zusehendem": "zusehend",
    "zusehenden": "zusehend",
    "zusehender": "zusehend",
    "zusehendes": "zusehend",
    "zusehest": "zusehen",
    "zusehet": "zusehen",
    "zuseht": "zusehen",
    "zusende": "zusenden",
    "zusendend": "zusenden",
    "zusendende": "zusendend",
    "zusendendem": "zusendend",
    "zusendenden": "zusendend",
    "zusendender": "zusendend",
    "zusendendes": "zusendend",
    "zusendest": "zusenden",
    "zusendet": "zusenden",
    "zusendete": "zusenden",
    "zusendeten": "zusenden",
    "zusendetest": "zusenden",
    "zusendetet": "zusenden",
    "zusetze": "zusetzen",
    "zusetzend": "zusetzen",
    "zusetzende": "zusetzend",
    "zusetzendem": "zusetzend",
    "zusetzenden": "zusetzend",
    "zusetzender": "zusetzend",
    "zusetzendere": "zusetzend",
    "zusetzenderem": "zusetzend",
    "zusetzenderen": "zusetzend",
    "zusetzenderer": "zusetzend",
    "zusetzenderes": "zusetzend",
    "zusetzendes": "zusetzend",
    "zusetzendste": "zusetzend",
    "zusetzendstem": "zusetzend",
    "zusetzendsten": "zusetzend",
    "zusetzendster": "zusetzend",
    "zusetzendstes": "zusetzend",
    "zusetzest": "zusetzen",
    "zusetzet": "zusetzen",
    "zusetzt": "zusetzen",
    "zusetzte": "zusetzen",
    "zusetzten": "zusetzen",
    "zusetztest": "zusetzen",
    "zusetztet": "zusetzen",
    "zusichere": "zusichern",
    "zusichernd": "zusichern",
    "zusichernde": "zusichernd",
    "zusicherndem": "zusichernd",
    "zusichernden": "zusichernd",
    "zusichernder": "zusichernd",
    "zusicherndes": "zusichernd",
    "zusicherst": "zusichern",
    "zusichert": "zusichern",
    "zusicherte": "zusichern",
    "zusicherten": "zusichern",
    "zusichertest": "zusichern",
    "zusichertet": "zusichern",
    "zusiehst": "zusehen",
    "zusieht": "zusehen",
    "zusitze": "zusitzen",
    "zusitzend": "zusitzen",
    "zusitzende": "zusitzend",
    "zusitzendem": "zusitzend",
    "zusitzenden": "zusitzend",
    "zusitzender": "zusitzend",
    "zusitzendes": "zusitzend",
    "zusitzest": "zusitzen",
    "zusitzet": "zusitzen",
    "zusitzt": "zusitzen",
    "zusperre": "zusperren",
    "zusperrend": "zusperren",
    "zusperrende": "zusperrend",
    "zusperrendem": "zusperrend",
    "zusperrenden": "zusperrend",
    "zusperrender": "zusperrend",
    "zusperrendes": "zusperrend",
    "zusperrest": "zusperren",
    "zusperret": "zusperren",
    "zusperrst": "zusperren",
    "zusperrt": "zusperren",
    "zusperrte": "zusperren",
    "zusperrten": "zusperren",
    "zusperrtest": "zusperren",
    "zusperrtet": "zusperren",
    "zuspielend": "zuspielen",
    "zuspielende": "zuspielend",
    "zuspielendem": "zuspielend",
    "zuspielenden": "zuspielend",
    "zuspielender": "zuspielend",
    "zuspielendes": "zuspielend",
    "zuspielest": "zuspielen",
    "zuspielet": "zuspielen",
    "zuspielst": "zuspielen",
    "zuspielt": "zuspielen",
    "zuspielte": "zuspielen",
    "zuspielten": "zuspielen",
    "zuspieltest": "zuspielen",
    "zuspieltet": "zuspielen",
    "zuspitze": "zuspitzen",
    "zuspitzend": "zuspitzen",
    "zuspitzende": "zuspitzend",
    "zuspitzendem": "zuspitzend",
    "zuspitzenden": "zuspitzend",
    "zuspitzender": "zuspitzend",
    "zuspitzendes": "zuspitzend",
    "zuspitzest": "zuspitzen",
    "zuspitzet": "zuspitzen",
    "zuspitzt": "zuspitzen",
    "zuspitzte": "zuspitzen",
    "zuspitzten": "zuspitzen",
    "zuspitztest": "zuspitzen",
    "zuspitztet": "zuspitzen",
    "zusprach": "zusprechen",
    "zusprachen": "zusprechen",
    "zusprachst": "zusprechen",
    "zuspracht": "zusprechen",
    "zusprang": "zuspringen",
    "zusprangen": "zuspringen",
    "zusprangst": "zuspringen",
    "zusprangt": "zuspringen",
    "zuspreche": "zusprechen",
    "zusprechend": "zusprechen",
    "zusprechende": "zusprechend",
    "zusprechendem": "zusprechend",
    "zusprechenden": "zusprechend",
    "zusprechender": "zusprechend",
    "zusprechendes": "zusprechend",
    "zusprechest": "zusprechen",
    "zusprechet": "zusprechen",
    "zusprecht": "zusprechen",
    "zusprichst": "zusprechen",
    "zuspricht": "zusprechen",
    "zuspringe": "zuspringen",
    "zuspringend": "zuspringen",
    "zuspringende": "zuspringend",
    "zuspringendem": "zuspringend",
    "zuspringenden": "zuspringend",
    "zuspringender": "zuspringend",
    "zuspringendes": "zuspringend",
    "zuspringest": "zuspringen",
    "zuspringet": "zuspringen",
    "zuspringst": "zuspringen",
    "zuspringt": "zuspringen",
    "zuspräche": "zusprechen",
    "zusprächen": "zusprechen",
    "zusprächest": "zusprechen",
    "zusprächet": "zusprechen",
    "zuspränge": "zuspringen",
    "zusprängen": "zuspringen",
    "zusprängest": "zuspringen",
    "zuspränget": "zuspringen",
    "zustach": "zustechen",
    "zustachen": "zustechen",
    "zustachst": "zustechen",
    "zustacht": "zustechen",
    "zustand": "zustehen",
    "zustandegekommen": "zustandekommen",
    "zustandegekommene": "zustandegekommen",
    "zustandegekommenem": "zustandegekommen",
    "zustandegekommenen": "zustandegekommen",
    "zustandegekommener": "zustandegekommen",
    "zustandegekommenes": "zustandegekommen",
    "zustandekam": "zustandekommen",
    "zustandekamen": "zustandekommen",
    "zustandekamst": "zustandekommen",
    "zustandekamt": "zustandekommen",
    "zustandekomme": "zustandekommen",
    "zustandekommend": "zustandekommen",
    "zustandekommende": "zustandekommend",
    "zustandekommendem": "zustandekommend",
    "zustandekommenden": "zustandekommend",
    "zustandekommender": "zustandekommend",
    "zustandekommendes": "zustandekommend",
    "zustandekommest": "zustandekommen",
    "zustandekommet": "zustandekommen",
    "zustandekommst": "zustandekommen",
    "zustandekommt": "zustandekommen",
    "zustandekäme": "zustandekommen",
    "zustandekämen": "zustandekommen",
    "zustandekämest": "zustandekommen",
    "zustandekämet": "zustandekommen",
    "zustanden": "zustehen",
    "zustandest": "zustehen",
    "zustandet": "zustehen",
    "zustandezukommen": "zustandekommen",
    "zusteche": "zustechen",
    "zustechend": "zustechen",
    "zustechende": "zustechend",
    "zustechendem": "zustechend",
    "zustechenden": "zustechend",
    "zustechender": "zustechend",
    "zustechendes": "zustechend",
    "zustechest": "zustechen",
    "zustechet": "zustechen",
    "zustecht": "zustechen",
    "zustecke": "zustecken",
    "zusteckend": "zustecken",
    "zusteckende": "zusteckend",
    "zusteckendem": "zusteckend",
    "zusteckenden": "zusteckend",
    "zusteckender": "zusteckend",
    "zusteckendes": "zusteckend",
    "zusteckest": "zustecken",
    "zustecket": "zustecken",
    "zusteckst": "zustecken",
    "zusteckt": "zustecken",
    "zusteckte": "zustecken",
    "zusteckten": "zustecken",
    "zustecktest": "zustecken",
    "zustecktet": "zustecken",
    "zustehe": "zustehen",
    "zustehend": "zustehen",
    "zustehende": "zustehend",
    "zustehendem": "zustehend",
    "zustehenden": "zustehend",
    "zustehender": "zustehend",
    "zustehendes": "zustehend",
    "zustehest": "zustehen",
    "zustehet": "zustehen",
    "zustehst": "zustehen",
    "zusteht": "zustehen",
    "zusteige": "zusteigen",
    "zusteigend": "zusteigen",
    "zusteigende": "zusteigend",
    "zusteigendem": "zusteigend",
    "zusteigenden": "zusteigend",
    "zusteigender": "zusteigend",
    "zusteigendes": "zusteigend",
    "zusteigest": "zusteigen",
    "zusteiget": "zusteigen",
    "zusteigst": "zusteigen",
    "zusteigt": "zusteigen",
    "zustelle": "zustellen",
    "zustellend": "zustellen",
    "zustellende": "zustellend",
    "zustellendem": "zustellend",
    "zustellenden": "zustellend",
    "zustellender": "zustellend",
    "zustellendes": "zustellend",
    "zustellest": "zustellen",
    "zustellet": "zustellen",
    "zustellst": "zustellen",
    "zustellt": "zustellen",
    "zustellte": "zustellen",
    "zustellten": "zustellen",
    "zustelltest": "zustellen",
    "zustelltet": "zustellen",
    "zusteuere": "zusteuern",
    "zusteuernd": "zusteuern",
    "zusteuernde": "zusteuernd",
    "zusteuerndem": "zusteuernd",
    "zusteuernden": "zusteuernd",
    "zusteuernder": "zusteuernd",
    "zusteuerndes": "zusteuernd",
    "zusteuerst": "zusteuern",
    "zusteuert": "zusteuern",
    "zusteuerte": "zusteuern",
    "zusteuerten": "zusteuern",
    "zusteuertest": "zusteuern",
    "zusteuertet": "zusteuern",
    "zustichst": "zustechen",
    "zusticht": "zustechen",
    "zustieg": "zusteigen",
    "zustiege": "zusteigen",
    "zustiegen": "zusteigen",
    "zustiegest": "zusteigen",
    "zustieget": "zusteigen",
    "zustiegst": "zusteigen",
    "zustiegt": "zusteigen",
    "zustieß": "zustoßen",
    "zustieße": "zustoßen",
    "zustießen": "zustoßen",
    "zustießest": "zustoßen",
    "zustießet": "zustoßen",
    "zustießt": "zustoßen",
    "zustimme": "zustimmen",
    "zustimmend": "zustimmen",
    "zustimmende": "zustimmend",
    "zustimmendem": "zustimmend",
    "zustimmenden": "zustimmend",
    "zustimmender": "zustimmend",
    "zustimmendere": "zustimmend",
    "zustimmenderem": "zustimmend",
    "zustimmenderen": "zustimmend",
    "zustimmenderer": "zustimmend",
    "zustimmenderes": "zustimmend",
    "zustimmendes": "zustimmend",
    "zustimmendste": "zustimmend",
    "zustimmendstem": "zustimmend",
    "zustimmendsten": "zustimmend",
    "zustimmendster": "zustimmend",
    "zustimmendstes": "zustimmend",
    "zustimmest": "zustimmen",
    "zustimmet": "zustimmen",
    "zustimmst": "zustimmen",
    "zustimmt": "zustimmen",
    "zustimmte": "zustimmen",
    "zustimmten": "zustimmen",
    "zustimmtest": "zustimmen",
    "zustimmtet": "zustimmen",
    "zustopfe": "zustopfen",
    "zustopfend": "zustopfen",
    "zustopfende": "zustopfend",
    "zustopfendem": "zustopfend",
    "zustopfenden": "zustopfend",
    "zustopfender": "zustopfend",
    "zustopfendere": "zustopfend",
    "zustopfenderem": "zustopfend",
    "zustopfenderen": "zustopfend",
    "zustopfenderer": "zustopfend",
    "zustopfenderes": "zustopfend",
    "zustopfendes": "zustopfend",
    "zustopfendste": "zustopfend",
    "zustopfendstem": "zustopfend",
    "zustopfendsten": "zustopfend",
    "zustopfendster": "zustopfend",
    "zustopfendstes": "zustopfend",
    "zustopfest": "zustopfen",
    "zustopfet": "zustopfen",
    "zustopfst": "zustopfen",
    "zustopft": "zustopfen",
    "zustopfte": "zustopfen",
    "zustopften": "zustopfen",
    "zustopftest": "zustopfen",
    "zustopftet": "zustopfen",
    "zustoße": "zustoßen",
    "zustoßend": "zustoßen",
    "zustoßende": "zustoßend",
    "zustoßendem": "zustoßend",
    "zustoßenden": "zustoßend",
    "zustoßender": "zustoßend",
    "zustoßendes": "zustoßend",
    "zustoßest": "zustoßen",
    "zustoßet": "zustoßen",
    "zustoßt": "zustoßen",
    "zustrebe": "zustreben",
    "zustrebend": "zustreben",
    "zustrebende": "zustrebend",
    "zustrebendem": "zustrebend",
    "zustrebenden": "zustrebend",
    "zustrebender": "zustrebend",
    "zustrebendes": "zustrebend",
    "zustrebest": "zustreben",
    "zustrebet": "zustreben",
    "zustrebst": "zustreben",
    "zustrebt": "zustreben",
    "zustrebte": "zustreben",
    "zustrebten": "zustreben",
    "zustrebtest": "zustreben",
    "zustrebtet": "zustreben",
    "zuströmend": "zuströmen",
    "zuströmende": "zuströmend",
    "zuströmendem": "zuströmend",
    "zuströmenden": "zuströmend",
    "zuströmender": "zuströmend",
    "zuströmendes": "zuströmend",
    "zuströmest": "zuströmen",
    "zuströmet": "zuströmen",
    "zuströmst": "zuströmen",
    "zuströmt": "zuströmen",
    "zuströmte": "zuströmen",
    "zuströmten": "zuströmen",
    "zuströmtest": "zuströmen",
    "zuströmtet": "zuströmen",
    "zustutze": "zustutzen",
    "zustutzend": "zustutzen",
    "zustutzende": "zustutzend",
    "zustutzendem": "zustutzend",
    "zustutzenden": "zustutzend",
    "zustutzender": "zustutzend",
    "zustutzendes": "zustutzend",
    "zustutzest": "zustutzen",
    "zustutzet": "zustutzen",
    "zustutzt": "zustutzen",
    "zustutzte": "zustutzen",
    "zustutzten": "zustutzen",
    "zustutztest": "zustutzen",
    "zustutztet": "zustutzen",
    "zustäche": "zustechen",
    "zustächen": "zustechen",
    "zustächest": "zustechen",
    "zustächet": "zustechen",
    "zuständige": "zuständig",
    "zuständigem": "zuständig",
    "zuständigen": "zuständig",
    "zuständiger": "zuständig",
    "zuständiges": "zuständig",
    "zustöpsele": "zustöpseln",
    "zustöpselnd": "zustöpseln",
    "zustöpselnde": "zustöpselnd",
    "zustöpselndem": "zustöpselnd",
    "zustöpselnden": "zustöpselnd",
    "zustöpselnder": "zustöpselnd",
    "zustöpselndes": "zustöpselnd",
    "zustöpselst": "zustöpseln",
    "zustöpselt": "zustöpseln",
    "zustöpselte": "zustöpseln",
    "zustöpselten": "zustöpseln",
    "zustöpseltest": "zustöpseln",
    "zustöpseltet": "zustöpseln",
    "zustöpsle": "zustöpseln",
    "zustößt": "zustoßen",
    "zustünde": "zustehen",
    "zustünden": "zustehen",
    "zustündest": "zustehen",
    "zustündet": "zustehen",
    "zustürze": "zustürzen",
    "zustürzend": "zustürzen",
    "zustürzende": "zustürzend",
    "zustürzendem": "zustürzend",
    "zustürzenden": "zustürzend",
    "zustürzender": "zustürzend",
    "zustürzendes": "zustürzend",
    "zustürzest": "zustürzen",
    "zustürzet": "zustürzen",
    "zustürzt": "zustürzen",
    "zustürzte": "zustürzen",
    "zustürzten": "zustürzen",
    "zustürztest": "zustürzen",
    "zustürztet": "zustürzen",
    "zusähe": "zusehen",
    "zusähen": "zusehen",
    "zusähest": "zusehen",
    "zusähet": "zusehen",
    "zusätzlichem": "zusätzlich",
    "zusätzlichen": "zusätzlich",
    "zusätzlicher": "zusätzlich",
    "zusätzliches": "zusätzlich",
    "zusäße": "zusitzen",
    "zusäßen": "zusitzen",
    "zusäßest": "zusitzen",
    "zusäßet": "zusitzen",
    "zuteile": "zuteilen",
    "zuteilend": "zuteilen",
    "zuteilende": "zuteilend",
    "zuteilendem": "zuteilend",
    "zuteilenden": "zuteilend",
    "zuteilender": "zuteilend",
    "zuteilendes": "zuteilend",
    "zuteilest": "zuteilen",
    "zuteilet": "zuteilen",
    "zuteilst": "zuteilen",
    "zuteilt": "zuteilen",
    "zuteilte": "zuteilen",
    "zuteilten": "zuteilen",
    "zuteiltest": "zuteilen",
    "zuteiltet": "zuteilen",
    "zutraf": "zutreffen",
    "zutrafen": "zutreffen",
    "zutrafst": "zutreffen",
    "zutraft": "zutreffen",
    "zutrage": "zutragen",
    "zutragend": "zutragen",
    "zutragende": "zutragend",
    "zutragendem": "zutragend",
    "zutragenden": "zutragend",
    "zutragender": "zutragend",
    "zutragendes": "zutragend",
    "zutragest": "zutragen",
    "zutraget": "zutragen",
    "zutragt": "zutragen",
    "zutrank": "zutrinken",
    "zutranken": "zutrinken",
    "zutrankst": "zutrinken",
    "zutrankt": "zutrinken",
    "zutraue": "zutrauen",
    "zutrauend": "zutrauen",
    "zutrauende": "zutrauend",
    "zutrauendem": "zutrauend",
    "zutrauenden": "zutrauend",
    "zutrauender": "zutrauend",
    "zutrauendes": "zutrauend",
    "zutrauest": "zutrauen",
    "zutrauet": "zutrauen",
    "zutrauliche": "zutraulich",
    "zutraulichem": "zutraulich",
    "zutraulichen": "zutraulich",
    "zutraulicher": "zutraulich",
    "zutraulichere": "zutraulich",
    "zutraulicherem": "zutraulich",
    "zutraulicheren": "zutraulich",
    "zutraulicherer": "zutraulich",
    "zutraulicheres": "zutraulich",
    "zutrauliches": "zutraulich",
    "zutraulichste": "zutraulich",
    "zutraulichstem": "zutraulich",
    "zutraulichsten": "zutraulich",
    "zutraulichster": "zutraulich",
    "zutraulichstes": "zutraulich",
    "zutraust": "zutrauen",
    "zutraut": "zutrauen",
    "zutraute": "zutrauen",
    "zutrauten": "zutrauen",
    "zutrautest": "zutrauen",
    "zutrautet": "zutrauen",
    "zutreffe": "zutreffen",
    "zutreffend": "zutreffen",
    "zutreffende": "zutreffend",
    "zutreffendem": "zutreffend",
    "zutreffenden": "zutreffend",
    "zutreffender": "zutreffend",
    "zutreffendere": "zutreffend",
    "zutreffenderem": "zutreffend",
    "zutreffenderen": "zutreffend",
    "zutreffenderer": "zutreffend",
    "zutreffenderes": "zutreffend",
    "zutreffendes": "zutreffend",
    "zutreffendste": "zutreffend",
    "zutreffendstem": "zutreffend",
    "zutreffendsten": "zutreffend",
    "zutreffendster": "zutreffend",
    "zutreffendstes": "zutreffend",
    "zutreffest": "zutreffen",
    "zutreffet": "zutreffen",
    "zutrefft": "zutreffen",
    "zutreibe": "zutreiben",
    "zutreibend": "zutreiben",
    "zutreibende": "zutreibend",
    "zutreibendem": "zutreibend",
    "zutreibenden": "zutreibend",
    "zutreibender": "zutreibend",
    "zutreibendes": "zutreibend",
    "zutreibest": "zutreiben",
    "zutreibet": "zutreiben",
    "zutreibst": "zutreiben",
    "zutreibt": "zutreiben",
    "zutrieb": "zutreiben",
    "zutriebe": "zutreiben",
    "zutrieben": "zutreiben",
    "zutriebest": "zutreiben",
    "zutriebet": "zutreiben",
    "zutriebst": "zutreiben",
    "zutriebt": "zutreiben",
    "zutriffst": "zutreffen",
    "zutrifft": "zutreffen",
    "zutrinke": "zutrinken",
    "zutrinkend": "zutrinken",
    "zutrinkende": "zutrinkend",
    "zutrinkendem": "zutrinkend",
    "zutrinkenden": "zutrinkend",
    "zutrinkender": "zutrinkend",
    "zutrinkendes": "zutrinkend",
    "zutrinkest": "zutrinken",
    "zutrinket": "zutrinken",
    "zutrinkst": "zutrinken",
    "zutrinkt": "zutrinken",
    "zutrug": "zutragen",
    "zutrugen": "zutragen",
    "zutrugst": "zutragen",
    "zutrugt": "zutragen",
    "zuträfe": "zutreffen",
    "zuträfen": "zutreffen",
    "zuträfest": "zutreffen",
    "zuträfet": "zutreffen",
    "zuträgliche": "zuträglich",
    "zuträglichem": "zuträglich",
    "zuträglichen": "zuträglich",
    "zuträglicher": "zuträglich",
    "zuträglichere": "zuträglich",
    "zuträglicherem": "zuträglich",
    "zuträglicheren": "zuträglich",
    "zuträglicherer": "zuträglich",
    "zuträglicheres": "zuträglich",
    "zuträgliches": "zuträglich",
    "zuträglichste": "zuträglich",
    "zuträglichstem": "zuträglich",
    "zuträglichsten": "zuträglich",
    "zuträglichster": "zuträglich",
    "zuträglichstes": "zuträglich",
    "zuträgst": "zutragen",
    "zuträgt": "zutragen",
    "zutränke": "zutrinken",
    "zutränken": "zutrinken",
    "zutränkest": "zutrinken",
    "zutränket": "zutrinken",
    "zutrüge": "zutragen",
    "zutrügen": "zutragen",
    "zutrügest": "zutragen",
    "zutrüget": "zutragen",
    "zuverlässige": "zuverlässig",
    "zuverlässigem": "zuverlässig",
    "zuverlässigen": "zuverlässig",
    "zuverlässiger": "zuverlässig",
    "zuverlässigere": "zuverlässig",
    "zuverlässigerem": "zuverlässig",
    "zuverlässigeren": "zuverlässig",
    "zuverlässigerer": "zuverlässig",
    "zuverlässigeres": "zuverlässig",
    "zuverlässiges": "zuverlässig",
    "zuverlässigstem": "zuverlässig",
    "zuverlässigsten": "zuverlässig",
    "zuverlässigster": "zuverlässig",
    "zuverlässigstes": "zuverlässig",
    "zuversichtliche": "zuversichtlich",
    "zuversichtlichem": "zuversichtlich",
    "zuversichtlichen": "zuversichtlich",
    "zuversichtlicher": "zuversichtlich",
    "zuversichtlichere": "zuversichtlich",
    "zuversichtlicherem": "zuversichtlich",
    "zuversichtlicheren": "zuversichtlich",
    "zuversichtlicherer": "zuversichtlich",
    "zuversichtlicheres": "zuversichtlich",
    "zuversichtliches": "zuversichtlich",
    "zuversichtlichste": "zuversichtlich",
    "zuversichtlichstem": "zuversichtlich",
    "zuversichtlichsten": "zuversichtlich",
    "zuversichtlichster": "zuversichtlich",
    "zuversichtlichstes": "zuversichtlich",
    "zuvorgekommen": "zuvorkommen",
    "zuvorgekommene": "zuvorgekommen",
    "zuvorgekommenem": "zuvorgekommen",
    "zuvorgekommenen": "zuvorgekommen",
    "zuvorgekommener": "zuvorgekommen",
    "zuvorgekommenere": "zuvorgekommen",
    "zuvorgekommenerem": "zuvorgekommen",
    "zuvorgekommeneren": "zuvorgekommen",
    "zuvorgekommenerer": "zuvorgekommen",
    "zuvorgekommeneres": "zuvorgekommen",
    "zuvorgekommenes": "zuvorgekommen",
    "zuvorgekommenste": "zuvorgekommen",
    "zuvorgekommenstem": "zuvorgekommen",
    "zuvorgekommensten": "zuvorgekommen",
    "zuvorgekommenster": "zuvorgekommen",
    "zuvorgekommenstes": "zuvorgekommen",
    "zuvorkam": "zuvorkommen",
    "zuvorkamen": "zuvorkommen",
    "zuvorkamst": "zuvorkommen",
    "zuvorkamt": "zuvorkommen",
    "zuvorkomme": "zuvorkommen",
    "zuvorkommend": "zuvorkommen",
    "zuvorkommende": "zuvorkommend",
    "zuvorkommendem": "zuvorkommend",
    "zuvorkommenden": "zuvorkommend",
    "zuvorkommender": "zuvorkommend",
    "zuvorkommendere": "zuvorkommend",
    "zuvorkommenderem": "zuvorkommend",
    "zuvorkommenderen": "zuvorkommend",
    "zuvorkommenderer": "zuvorkommend",
    "zuvorkommenderes": "zuvorkommend",
    "zuvorkommendes": "zuvorkommend",
    "zuvorkommendste": "zuvorkommend",
    "zuvorkommendstem": "zuvorkommend",
    "zuvorkommendsten": "zuvorkommend",
    "zuvorkommendster": "zuvorkommend",
    "zuvorkommendstes": "zuvorkommend",
    "zuvorkommest": "zuvorkommen",
    "zuvorkommet": "zuvorkommen",
    "zuvorkommst": "zuvorkommen",
    "zuvorkommt": "zuvorkommen",
    "zuvorkäme": "zuvorkommen",
    "zuvorkämen": "zuvorkommen",
    "zuvorkämest": "zuvorkommen",
    "zuvorkämet": "zuvorkommen",
    "zuvorzukommen": "zuvorkommen",
    "zuwandere": "zuwandern",
    "zuwandernd": "zuwandern",
    "zuwandernde": "zuwandernd",
    "zuwanderndem": "zuwandernd",
    "zuwandernden": "zuwandernd",
    "zuwandernder": "zuwandernd",
    "zuwanderndes": "zuwandernd",
    "zuwanderst": "zuwandern",
    "zuwandert": "zuwandern",
    "zuwanderte": "zuwandern",
    "zuwanderten": "zuwandern",
    "zuwandertest": "zuwandern",
    "zuwandertet": "zuwandern",
    "zuwandte": "zuwenden",
    "zuwandten": "zuwenden",
    "zuwandtest": "zuwenden",
    "zuwandtet": "zuwenden",
    "zuwarf": "zuwerfen",
    "zuwarfen": "zuwerfen",
    "zuwarfst": "zuwerfen",
    "zuwarft": "zuwerfen",
    "zuwehe": "zuwehen",
    "zuwehend": "zuwehen",
    "zuwehende": "zuwehend",
    "zuwehendem": "zuwehend",
    "zuwehenden": "zuwehend",
    "zuwehender": "zuwehend",
    "zuwehendere": "zuwehend",
    "zuwehenderem": "zuwehend",
    "zuwehenderen": "zuwehend",
    "zuwehenderer": "zuwehend",
    "zuwehenderes": "zuwehend",
    "zuwehendes": "zuwehend",
    "zuwehendste": "zuwehend",
    "zuwehendstem": "zuwehend",
    "zuwehendsten": "zuwehend",
    "zuwehendster": "zuwehend",
    "zuwehendstes": "zuwehend",
    "zuwehest": "zuwehen",
    "zuwehet": "zuwehen",
    "zuwehst": "zuwehen",
    "zuweht": "zuwehen",
    "zuwehte": "zuwehen",
    "zuwehten": "zuwehen",
    "zuwehtest": "zuwehen",
    "zuwehtet": "zuwehen",
    "zuweise": "zuweisen",
    "zuweisend": "zuweisen",
    "zuweisende": "zuweisend",
    "zuweisendem": "zuweisend",
    "zuweisenden": "zuweisend",
    "zuweisender": "zuweisend",
    "zuweisendes": "zuweisend",
    "zuweisest": "zuweisen",
    "zuweiset": "zuweisen",
    "zuweist": "zuweisen",
    "zuwende": "zuwenden",
    "zuwendend": "zuwenden",
    "zuwendende": "zuwendend",
    "zuwendendem": "zuwendend",
    "zuwendenden": "zuwendend",
    "zuwendender": "zuwendend",
    "zuwendendere": "zuwendend",
    "zuwendenderem": "zuwendend",
    "zuwendenderen": "zuwendend",
    "zuwendenderer": "zuwendend",
    "zuwendenderes": "zuwendend",
    "zuwendendes": "zuwendend",
    "zuwendendste": "zuwendend",
    "zuwendendstem": "zuwendend",
    "zuwendendsten": "zuwendend",
    "zuwendendster": "zuwendend",
    "zuwendendstes": "zuwendend",
    "zuwendest": "zuwenden",
    "zuwendet": "zuwenden",
    "zuwendete": "zuwenden",
    "zuwendeten": "zuwenden",
    "zuwendetest": "zuwenden",
    "zuwendetet": "zuwenden",
    "zuwerfe": "zuwerfen",
    "zuwerfend": "zuwerfen",
    "zuwerfende": "zuwerfend",
    "zuwerfendem": "zuwerfend",
    "zuwerfenden": "zuwerfend",
    "zuwerfender": "zuwerfend",
    "zuwerfendes": "zuwerfend",
    "zuwerfest": "zuwerfen",
    "zuwerfet": "zuwerfen",
    "zuwerft": "zuwerfen",
    "zuwidergehandelt": "zuwiderhandeln",
    "zuwidergehandelte": "zuwidergehandelt",
    "zuwidergehandeltem": "zuwidergehandelt",
    "zuwidergehandelten": "zuwidergehandelt",
    "zuwidergehandelter": "zuwidergehandelt",
    "zuwidergehandeltes": "zuwidergehandelt",
    "zuwidergelaufen": "zuwiderlaufen",
    "zuwidergelaufene": "zuwidergelaufen",
    "zuwidergelaufenem": "zuwidergelaufen",
    "zuwidergelaufenen": "zuwidergelaufen",
    "zuwidergelaufener": "zuwidergelaufen",
    "zuwidergelaufenes": "zuwidergelaufen",
    "zuwiderhandele": "zuwiderhandeln",
    "zuwiderhandelnd": "zuwiderhandeln",
    "zuwiderhandelnde": "zuwiderhandelnd",
    "zuwiderhandelndem": "zuwiderhandelnd",
    "zuwiderhandelnden": "zuwiderhandelnd",
    "zuwiderhandelnder": "zuwiderhandelnd",
    "zuwiderhandelndes": "zuwiderhandelnd",
    "zuwiderhandelst": "zuwiderhandeln",
    "zuwiderhandelt": "zuwiderhandeln",
    "zuwiderhandelte": "zuwiderhandeln",
    "zuwiderhandelten": "zuwiderhandeln",
    "zuwiderhandeltest": "zuwiderhandeln",
    "zuwiderhandeltet": "zuwiderhandeln",
    "zuwiderhandle": "zuwiderhandeln",
    "zuwiderlaufe": "zuwiderlaufen",
    "zuwiderlaufend": "zuwiderlaufen",
    "zuwiderlaufende": "zuwiderlaufend",
    "zuwiderlaufendem": "zuwiderlaufend",
    "zuwiderlaufenden": "zuwiderlaufend",
    "zuwiderlaufender": "zuwiderlaufend",
    "zuwiderlaufendes": "zuwiderlaufend",
    "zuwiderlaufest": "zuwiderlaufen",
    "zuwiderlaufet": "zuwiderlaufen",
    "zuwiderlauft": "zuwiderlaufen",
    "zuwiderlief": "zuwiderlaufen",
    "zuwiderliefe": "zuwiderlaufen",
    "zuwiderliefen": "zuwiderlaufen",
    "zuwiderliefest": "zuwiderlaufen",
    "zuwiderliefet": "zuwiderlaufen",
    "zuwiderliefst": "zuwiderlaufen",
    "zuwiderlieft": "zuwiderlaufen",
    "zuwiderläufst": "zuwiderlaufen",
    "zuwiderläuft": "zuwiderlaufen",
    "zuwiderzuhandeln": "zuwiderhandeln",
    "zuwiderzulaufen": "zuwiderlaufen",
    "zuwies": "zuweisen",
    "zuwiese": "zuweisen",
    "zuwiesen": "zuweisen",
    "zuwiesest": "zuweisen",
    "zuwieset": "zuweisen",
    "zuwiest": "zuweisen",
    "zuwinke": "zuwinken",
    "zuwinkend": "zuwinken",
    "zuwinkende": "zuwinkend",
    "zuwinkendem": "zuwinkend",
    "zuwinkenden": "zuwinkend",
    "zuwinkender": "zuwinkend",
    "zuwinkendes": "zuwinkend",
    "zuwinkest": "zuwinken",
    "zuwinket": "zuwinken",
    "zuwinkst": "zuwinken",
    "zuwinkt": "zuwinken",
    "zuwinkte": "zuwinken",
    "zuwinkten": "zuwinken",
    "zuwinktest": "zuwinken",
    "zuwinktet": "zuwinken",
    "zuwirfst": "zuwerfen",
    "zuwirft": "zuwerfen",
    "zuwärfe": "zuwerfen",
    "zuwärfen": "zuwerfen",
    "zuwärfest": "zuwerfen",
    "zuwärfet": "zuwerfen",
    "zuzahle": "zuzahlen",
    "zuzahlend": "zuzahlen",
    "zuzahlende": "zuzahlend",
    "zuzahlendem": "zuzahlend",
    "zuzahlenden": "zuzahlend",
    "zuzahlender": "zuzahlend",
    "zuzahlendes": "zuzahlend",
    "zuzahlest": "zuzahlen",
    "zuzahlet": "zuzahlen",
    "zuzahlst": "zuzahlen",
    "zuzahlt": "zuzahlen",
    "zuzahlte": "zuzahlen",
    "zuzahlten": "zuzahlen",
    "zuzahltest": "zuzahlen",
    "zuzahltet": "zuzahlen",
    "zuziehe": "zuziehen",
    "zuziehend": "zuziehen",
    "zuziehende": "zuziehend",
    "zuziehendem": "zuziehend",
    "zuziehenden": "zuziehend",
    "zuziehender": "zuziehend",
    "zuziehendes": "zuziehend",
    "zuziehest": "zuziehen",
    "zuziehet": "zuziehen",
    "zuziehst": "zuziehen",
    "zuzieht": "zuziehen",
    "zuzog": "zuziehen",
    "zuzogen": "zuziehen",
    "zuzogst": "zuziehen",
    "zuzogt": "zuziehen",
    "zuzuarbeiten": "zuarbeiten",
    "zuzuballern": "zuballern",
    "zuzubauen": "zubauen",
    "zuzubeißen": "zubeißen",
    "zuzubekommen": "zubekommen",
    "zuzubereiten": "zubereiten",
    "zuzubetonieren": "zubetonieren",
    "zuzubilligen": "zubilligen",
    "zuzubinden": "zubinden",
    "zuzublinzeln": "zublinzeln",
    "zuzubringen": "zubringen",
    "zuzubuttern": "zubuttern",
    "zuzudenken": "zudenken",
    "zuzudienen": "zudienen",
    "zuzudiktieren": "zudiktieren",
    "zuzudrehen": "zudrehen",
    "zuzudrücken": "zudrücken",
    "zuzueignen": "zueignen",
    "zuzuerkennen": "zuerkennen",
    "zuzufallen": "zufallen",
    "zuzufassen": "zufassen",
    "zuzufaxen": "zufaxen",
    "zuzufliegen": "zufliegen",
    "zuzufließen": "zufließen",
    "zuzuflüstern": "zuflüstern",
    "zuzufrieren": "zufrieren",
    "zuzufächeln": "zufächeln",
    "zuzufügen": "zufügen",
    "zuzuführen": "zuführen",
    "zuzugeben": "zugeben",
    "zuzugehen": "zugehen",
    "zuzugehören": "zugehören",
    "zuzugesellen": "zugesellen",
    "zuzugestehen": "zugestehen",
    "zuzugießen": "zugießen",
    "zuzugreifen": "zugreifen",
    "zuzuhaken": "zuhaken",
    "zuzuhalten": "zuhalten",
    "zuzuhauen": "zuhauen",
    "zuzuheilen": "zuheilen",
    "zuzuhängen": "zuhängen",
    "zuzuhören": "zuhören",
    "zuzujauchzen": "zujauchzen",
    "zuzujubeln": "zujubeln",
    "zuzukehren": "zukehren",
    "zuzuklappen": "zuklappen",
    "zuzukleben": "zukleben",
    "zuzuklinken": "zuklinken",
    "zuzuknallen": "zuknallen",
    "zuzuknöpfen": "zuknöpfen",
    "zuzukommen": "zukommen",
    "zuzukorken": "zukorken",
    "zuzukriegen": "zukriegen",
    "zuzulachen": "zulachen",
    "zuzuladen": "zuladen",
    "zuzulangen": "zulangen",
    "zuzulassen": "zulassen",
    "zuzulaufen": "zulaufen",
    "zuzulegen": "zulegen",
    "zuzuleiten": "zuleiten",
    "zuzulächeln": "zulächeln",
    "zuzulöten": "zulöten",
    "zuzumachen": "zumachen",
    "zuzumauern": "zumauern",
    "zuzumessen": "zumessen",
    "zuzumuten": "zumuten",
    "zuzunageln": "zunageln",
    "zuzunehmen": "zunehmen",
    "zuzuneigen": "zuneigen",
    "zuzunähen": "zunähen",
    "zuzuordnen": "zuordnen",
    "zuzupacken": "zupacken",
    "zuzupfropfen": "zupfropfen",
    "zuzuprosten": "zuprosten",
    "zuzuraten": "zuraten",
    "zuzuraunen": "zuraunen",
    "zuzurechnen": "zurechnen",
    "zuzureden": "zureden",
    "zuzureichen": "zureichen",
    "zuzureiten": "zureiten",
    "zuzurichten": "zurichten",
    "zuzuriegeln": "zuriegeln",
    "zuzurollen": "zurollen",
    "zuzurufen": "zurufen",
    "zuzurüsten": "zurüsten",
    "zuzusagen": "zusagen",
    "zuzuschanzen": "zuschanzen",
    "zuzuschauen": "zuschauen",
    "zuzuschaufeln": "zuschaufeln",
    "zuzuschieben": "zuschieben",
    "zuzuschießen": "zuschießen",
    "zuzuschlagen": "zuschlagen",
    "zuzuschließen": "zuschließen",
    "zuzuschmeißen": "zuschmeißen",
    "zuzuschnallen": "zuschnallen",
    "zuzuschnappen": "zuschnappen",
    "zuzuschneiden": "zuschneiden",
    "zuzuschneien": "zuschneien",
    "zuzuschnüren": "zuschnüren",
    "zuzuschrauben": "zuschrauben",
    "zuzuschreiben": "zuschreiben",
    "zuzuschustern": "zuschustern",
    "zuzuschütten": "zuschütten",
    "zuzusehen": "zusehen",
    "zuzusenden": "zusenden",
    "zuzusetzen": "zusetzen",
    "zuzusichern": "zusichern",
    "zuzusitzen": "zusitzen",
    "zuzusperren": "zusperren",
    "zuzuspielen": "zuspielen",
    "zuzuspitzen": "zuspitzen",
    "zuzusprechen": "zusprechen",
    "zuzuspringen": "zuspringen",
    "zuzustechen": "zustechen",
    "zuzustecken": "zustecken",
    "zuzustehen": "zustehen",
    "zuzusteigen": "zusteigen",
    "zuzustellen": "zustellen",
    "zuzusteuern": "zusteuern",
    "zuzustimmen": "zustimmen",
    "zuzustopfen": "zustopfen",
    "zuzustoßen": "zustoßen",
    "zuzustreben": "zustreben",
    "zuzuströmen": "zuströmen",
    "zuzustutzen": "zustutzen",
    "zuzustöpseln": "zustöpseln",
    "zuzustürzen": "zustürzen",
    "zuzuteilen": "zuteilen",
    "zuzutragen": "zutragen",
    "zuzutrauen": "zutrauen",
    "zuzutreffen": "zutreffen",
    "zuzutreiben": "zutreiben",
    "zuzutrinken": "zutrinken",
    "zuzuwandern": "zuwandern",
    "zuzuwehen": "zuwehen",
    "zuzuweisen": "zuweisen",
    "zuzuwenden": "zuwenden",
    "zuzuwerfen": "zuwerfen",
    "zuzuwinken": "zuwinken",
    "zuzuzahlen": "zuzahlen",
    "zuzuziehen": "zuziehen",
    "zuzuzwinkern": "zuzwinkern",
    "zuzuzählen": "zuzählen",
    "zuzwinkere": "zuzwinkern",
    "zuzwinkernd": "zuzwinkern",
    "zuzwinkernde": "zuzwinkernd",
    "zuzwinkerndem": "zuzwinkernd",
    "zuzwinkernden": "zuzwinkernd",
    "zuzwinkernder": "zuzwinkernd",
    "zuzwinkerndes": "zuzwinkernd",
    "zuzwinkerst": "zuzwinkern",
    "zuzwinkert": "zuzwinkern",
    "zuzwinkerte": "zuzwinkern",
    "zuzwinkerten": "zuzwinkern",
    "zuzwinkertest": "zuzwinkern",
    "zuzwinkertet": "zuzwinkern",
    "zuzähle": "zuzählen",
    "zuzählend": "zuzählen",
    "zuzählendem": "zuzählend",
    "zuzählender": "zuzählend",
    "zuzählendes": "zuzählend",
    "zuzählest": "zuzählen",
    "zuzählet": "zuzählen",
    "zuzählst": "zuzählen",
    "zuzählt": "zuzählen",
    "zuzählte": "zuzählen",
    "zuzählten": "zuzählen",
    "zuzähltest": "zuzählen",
    "zuzähltet": "zuzählen",
    "zuzöge": "zuziehen",
    "zuzögen": "zuziehen",
    "zuzögest": "zuziehen",
    "zuzöget": "zuziehen",
    "zwang": "zwingen",
    "zwangen": "zwingen",
    "zwanghafte": "zwanghaft",
    "zwanghaftem": "zwanghaft",
    "zwanghaften": "zwanghaft",
    "zwanghafter": "zwanghaft",
    "zwanghaftere": "zwanghaft",
    "zwanghafterem": "zwanghaft",
    "zwanghafteren": "zwanghaft",
    "zwanghafterer": "zwanghaft",
    "zwanghafteres": "zwanghaft",
    "zwanghaftes": "zwanghaft",
    "zwanghafteste": "zwanghaft",
    "zwanghaftestem": "zwanghaft",
    "zwanghaftesten": "zwanghaft",
    "zwanghaftester": "zwanghaft",
    "zwanghaftestes": "zwanghaft",
    "zwanglose": "zwanglos",
    "zwanglosem": "zwanglos",
    "zwanglosen": "zwanglos",
    "zwangloser": "zwanglos",
    "zwanglosere": "zwanglos",
    "zwangloserem": "zwanglos",
    "zwangloseren": "zwanglos",
    "zwangloserer": "zwanglos",
    "zwangloseres": "zwanglos",
    "zwangloses": "zwanglos",
    "zwangloseste": "zwanglos",
    "zwanglosestem": "zwanglos",
    "zwanglosesten": "zwanglos",
    "zwanglosester": "zwanglos",
    "zwanglosestes": "zwanglos",
    "zwangsläufigem": "zwangsläufig",
    "zwangsläufigen": "zwangsläufig",
    "zwangsläufiger": "zwangsläufig",
    "zwangsläufigere": "zwangsläufig",
    "zwangsläufigerem": "zwangsläufig",
    "zwangsläufigeren": "zwangsläufig",
    "zwangsläufigerer": "zwangsläufig",
    "zwangsläufigeres": "zwangsläufig",
    "zwangsläufiges": "zwangsläufig",
    "zwangsläufigste": "zwangsläufig",
    "zwangsläufigstem": "zwangsläufig",
    "zwangsläufigsten": "zwangsläufig",
    "zwangsläufigster": "zwangsläufig",
    "zwangsläufigstes": "zwangsläufig",
    "zwangsmäßige": "zwangsmäßig",
    "zwangsmäßigem": "zwangsmäßig",
    "zwangsmäßigen": "zwangsmäßig",
    "zwangsmäßiger": "zwangsmäßig",
    "zwangsmäßiges": "zwangsmäßig",
    "zwangst": "zwingen",
    "zwangsumgesiedelt": "zwangsumsiedeln",
    "zwangsumgesiedelte": "zwangsumgesiedelt",
    "zwangsumgesiedeltem": "zwangsumgesiedelt",
    "zwangsumgesiedelten": "zwangsumgesiedelt",
    "zwangsumgesiedelter": "zwangsumgesiedelt",
    "zwangsumgesiedeltes": "zwangsumgesiedelt",
    "zwangsumsiedele": "zwangsumsiedeln",
    "zwangsumsiedelnd": "zwangsumsiedeln",
    "zwangsumsiedelnde": "zwangsumsiedelnd",
    "zwangsumsiedelndem": "zwangsumsiedelnd",
    "zwangsumsiedelnden": "zwangsumsiedelnd",
    "zwangsumsiedelnder": "zwangsumsiedelnd",
    "zwangsumsiedelndes": "zwangsumsiedelnd",
    "zwangsumsiedelst": "zwangsumsiedeln",
    "zwangsumsiedelt": "zwangsumsiedeln",
    "zwangsumsiedelte": "zwangsumsiedeln",
    "zwangsumsiedelten": "zwangsumsiedeln",
    "zwangsumsiedeltest": "zwangsumsiedeln",
    "zwangsumsiedeltet": "zwangsumsiedeln",
    "zwangsumsiedle": "zwangsumsiedeln",
    "zwangsumzusiedeln": "zwangsumsiedeln",
    "zwangsweisem": "zwangsweise",
    "zwangsweisen": "zwangsweise",
    "zwangsweiser": "zwangsweise",
    "zwangsweisere": "zwangsweise",
    "zwangsweiserem": "zwangsweise",
    "zwangsweiseren": "zwangsweise",
    "zwangsweiserer": "zwangsweise",
    "zwangsweiseres": "zwangsweise",
    "zwangsweises": "zwangsweise",
    "zwangsweiseste": "zwangsweise",
    "zwangsweisestem": "zwangsweise",
    "zwangsweisesten": "zwangsweise",
    "zwangsweisester": "zwangsweise",
    "zwangsweisestes": "zwangsweise",
    "zwangt": "zwingen",
    "zweckdienlichem": "zweckdienlich",
    "zweckdienlichen": "zweckdienlich",
    "zweckdienlicher": "zweckdienlich",
    "zweckdienliches": "zweckdienlich",
    "zweckentfremdetem": "zweckentfremdet",
    "zweckentfremdeten": "zweckentfremdet",
    "zweckentfremdeter": "zweckentfremdet",
    "zweckentfremdetes": "zweckentfremdet",
    "zweckgebundene": "zweckgebunden",
    "zweckgebundenem": "zweckgebunden",
    "zweckgebundenen": "zweckgebunden",
    "zweckgebundener": "zweckgebunden",
    "zweckgebundenes": "zweckgebunden",
    "zwecklose": "zwecklos",
    "zwecklosem": "zwecklos",
    "zwecklosen": "zwecklos",
    "zweckloser": "zwecklos",
    "zwecklosere": "zwecklos",
    "zweckloserem": "zwecklos",
    "zweckloseren": "zwecklos",
    "zweckloserer": "zwecklos",
    "zweckloseres": "zwecklos",
    "zweckloses": "zwecklos",
    "zweckloseste": "zwecklos",
    "zwecklosestem": "zwecklos",
    "zwecklosesten": "zwecklos",
    "zwecklosester": "zwecklos",
    "zwecklosestes": "zwecklos",
    "zweckmäßige": "zweckmäßig",
    "zweckmäßigem": "zweckmäßig",
    "zweckmäßigen": "zweckmäßig",
    "zweckmäßiger": "zweckmäßig",
    "zweckmäßigere": "zweckmäßig",
    "zweckmäßigerem": "zweckmäßig",
    "zweckmäßigeren": "zweckmäßig",
    "zweckmäßigerer": "zweckmäßig",
    "zweckmäßigeres": "zweckmäßig",
    "zweckmäßiges": "zweckmäßig",
    "zweckmäßigste": "zweckmäßig",
    "zweckmäßigstem": "zweckmäßig",
    "zweckmäßigsten": "zweckmäßig",
    "zweckmäßigster": "zweckmäßig",
    "zweckmäßigstes": "zweckmäßig",
    "zweideutigem": "zweideutig",
    "zweideutigen": "zweideutig",
    "zweideutiger": "zweideutig",
    "zweideutigere": "zweideutig",
    "zweideutigerem": "zweideutig",
    "zweideutigeren": "zweideutig",
    "zweideutigerer": "zweideutig",
    "zweideutigeres": "zweideutig",
    "zweideutiges": "zweideutig",
    "zweideutigste": "zweideutig",
    "zweideutigstem": "zweideutig",
    "zweideutigsten": "zweideutig",
    "zweideutigster": "zweideutig",
    "zweideutigstes": "zweideutig",
    "zweidimensionale": "zweidimensional",
    "zweidimensionalem": "zweidimensional",
    "zweidimensionalen": "zweidimensional",
    "zweidimensionaler": "zweidimensional",
    "zweidimensionales": "zweidimensional",
    "zweieiige": "zweieiig",
    "zweieiigem": "zweieiig",
    "zweieiigen": "zweieiig",
    "zweieiiger": "zweieiig",
    "zweieiiges": "zweieiig",
    "zweifachem": "zweifach",
    "zweifachen": "zweifach",
    "zweifacher": "zweifach",
    "zweifaches": "zweifach",
    "zweifele": "zweifeln",
    "zweifelhafte": "zweifelhaft",
    "zweifelhaftem": "zweifelhaft",
    "zweifelhaften": "zweifelhaft",
    "zweifelhafter": "zweifelhaft",
    "zweifelhaftere": "zweifelhaft",
    "zweifelhafterem": "zweifelhaft",
    "zweifelhafteren": "zweifelhaft",
    "zweifelhafterer": "zweifelhaft",
    "zweifelhafteres": "zweifelhaft",
    "zweifelhaftes": "zweifelhaft",
    "zweifelhafteste": "zweifelhaft",
    "zweifelhaftestem": "zweifelhaft",
    "zweifelhaftesten": "zweifelhaft",
    "zweifelhaftester": "zweifelhaft",
    "zweifelhaftestes": "zweifelhaft",
    "zweifellose": "zweifellos",
    "zweifellosem": "zweifellos",
    "zweifellosen": "zweifellos",
    "zweifelloser": "zweifellos",
    "zweifellosere": "zweifellos",
    "zweifelloserem": "zweifellos",
    "zweifelloseren": "zweifellos",
    "zweifelloserer": "zweifellos",
    "zweifelloseres": "zweifellos",
    "zweifelloses": "zweifellos",
    "zweifelloseste": "zweifellos",
    "zweifellosestem": "zweifellos",
    "zweifellosesten": "zweifellos",
    "zweifellosester": "zweifellos",
    "zweifellosestes": "zweifellos",
    "zweifelnd": "zweifeln",
    "zweifelnde": "zweifelnd",
    "zweifelndem": "zweifelnd",
    "zweifelnden": "zweifelnd",
    "zweifelnder": "zweifelnd",
    "zweifelndere": "zweifelnd",
    "zweifelnderem": "zweifelnd",
    "zweifelnderen": "zweifelnd",
    "zweifelnderer": "zweifelnd",
    "zweifelnderes": "zweifelnd",
    "zweifelndes": "zweifelnd",
    "zweifelndste": "zweifelnd",
    "zweifelndstem": "zweifelnd",
    "zweifelndsten": "zweifelnd",
    "zweifelndster": "zweifelnd",
    "zweifelndstes": "zweifelnd",
    "zweifelsfreiem": "zweifelsfrei",
    "zweifelsfreien": "zweifelsfrei",
    "zweifelsfreier": "zweifelsfrei",
    "zweifelsfreiere": "zweifelsfrei",
    "zweifelsfreierem": "zweifelsfrei",
    "zweifelsfreieren": "zweifelsfrei",
    "zweifelsfreierer": "zweifelsfrei",
    "zweifelsfreieres": "zweifelsfrei",
    "zweifelsfreies": "zweifelsfrei",
    "zweifelsfreieste": "zweifelsfrei",
    "zweifelsfreiestem": "zweifelsfrei",
    "zweifelsfreiesten": "zweifelsfrei",
    "zweifelsfreiester": "zweifelsfrei",
    "zweifelsfreiestes": "zweifelsfrei",
    "zweifelst": "zweifeln",
    "zweifelt": "zweifeln",
    "zweifelte": "zweifeln",
    "zweifelten": "zweifeln",
    "zweifeltest": "zweifeln",
    "zweifeltet": "zweifeln",
    "zweifle": "zweifeln",
    "zweigend": "zweigen",
    "zweigende": "zweigend",
    "zweigendem": "zweigend",
    "zweigenden": "zweigend",
    "zweigender": "zweigend",
    "zweigendes": "zweigend",
    "zweigeschlechtigem": "zweigeschlechtig",
    "zweigeschlechtigen": "zweigeschlechtig",
    "zweigeschlechtiger": "zweigeschlechtig",
    "zweigeschlechtiges": "zweigeschlechtig",
    "zweigest": "zweigen",
    "zweiget": "zweigen",
    "zweigeteilte": "zweigeteilt",
    "zweigeteiltem": "zweigeteilt",
    "zweigeteilten": "zweigeteilt",
    "zweigeteilter": "zweigeteilt",
    "zweigeteiltes": "zweigeteilt",
    "zweigleisige": "zweigleisig",
    "zweigleisigem": "zweigleisig",
    "zweigleisigen": "zweigleisig",
    "zweigleisiger": "zweigleisig",
    "zweigleisiges": "zweigleisig",
    "zweigst": "zweigen",
    "zweigt": "zweigen",
    "zweigte": "zweigen",
    "zweigten": "zweigen",
    "zweigtest": "zweigen",
    "zweigtet": "zweigen",
    "zweihändige": "zweihändig",
    "zweihändigem": "zweihändig",
    "zweihändigen": "zweihändig",
    "zweihändiger": "zweihändig",
    "zweihändiges": "zweihändig",
    "zweihäusige": "zweihäusig",
    "zweihäusigem": "zweihäusig",
    "zweihäusigen": "zweihäusig",
    "zweihäusiger": "zweihäusig",
    "zweihäusiges": "zweihäusig",
    "zweijährige": "zweijährig",
    "zweijährigem": "zweijährig",
    "zweijährigen": "zweijährig",
    "zweijähriger": "zweijährig",
    "zweijähriges": "zweijährig",
    "zweiköpfige": "zweiköpfig",
    "zweiköpfigem": "zweiköpfig",
    "zweiköpfigen": "zweiköpfig",
    "zweiköpfiger": "zweiköpfig",
    "zweiköpfiges": "zweiköpfig",
    "zweimalige": "zweimalig",
    "zweimaligem": "zweimalig",
    "zweimaligen": "zweimalig",
    "zweimaliger": "zweimalig",
    "zweimaliges": "zweimalig",
    "zweimotorige": "zweimotorig",
    "zweimotorigem": "zweimotorig",
    "zweimotorigen": "zweimotorig",
    "zweimotoriger": "zweimotorig",
    "zweimotoriges": "zweimotorig",
    "zweipolige": "zweipolig",
    "zweipoligem": "zweipolig",
    "zweipoligen": "zweipolig",
    "zweipoliger": "zweipolig",
    "zweipoliges": "zweipolig",
    "zweireihigem": "zweireihig",
    "zweireihigen": "zweireihig",
    "zweireihiger": "zweireihig",
    "zweireihiges": "zweireihig",
    "zweischneidige": "zweischneidig",
    "zweischneidigem": "zweischneidig",
    "zweischneidigen": "zweischneidig",
    "zweischneidiger": "zweischneidig",
    "zweischneidigere": "zweischneidig",
    "zweischneidigerem": "zweischneidig",
    "zweischneidigeren": "zweischneidig",
    "zweischneidigerer": "zweischneidig",
    "zweischneidigeres": "zweischneidig",
    "zweischneidiges": "zweischneidig",
    "zweischneidigste": "zweischneidig",
    "zweischneidigstem": "zweischneidig",
    "zweischneidigsten": "zweischneidig",
    "zweischneidigster": "zweischneidig",
    "zweischneidigstes": "zweischneidig",
    "zweiseitige": "zweiseitig",
    "zweiseitigem": "zweiseitig",
    "zweiseitigen": "zweiseitig",
    "zweiseitiger": "zweiseitig",
    "zweiseitiges": "zweiseitig",
    "zweispaltigem": "zweispaltig",
    "zweispaltigen": "zweispaltig",
    "zweispaltiger": "zweispaltig",
    "zweispaltiges": "zweispaltig",
    "zweisprachige": "zweisprachig",
    "zweisprachigem": "zweisprachig",
    "zweisprachigen": "zweisprachig",
    "zweisprachiger": "zweisprachig",
    "zweisprachiges": "zweisprachig",
    "zweispurigem": "zweispurig",
    "zweispurigen": "zweispurig",
    "zweispuriger": "zweispurig",
    "zweispuriges": "zweispurig",
    "zweispännigem": "zweispännig",
    "zweispännigen": "zweispännig",
    "zweispänniger": "zweispännig",
    "zweispänniges": "zweispännig",
    "zweistrahligem": "zweistrahlig",
    "zweistrahligen": "zweistrahlig",
    "zweistrahliger": "zweistrahlig",
    "zweistrahliges": "zweistrahlig",
    "zweistündige": "zweistündig",
    "zweistündigem": "zweistündig",
    "zweistündigen": "zweistündig",
    "zweistündiger": "zweistündig",
    "zweistündiges": "zweistündig",
    "zweiteiligem": "zweiteilig",
    "zweiteiligen": "zweiteilig",
    "zweiteiliger": "zweiteilig",
    "zweiteiliges": "zweiteilig",
    "zweitem": "zweit",
    "zweiten": "zweit",
    "zweiter": "zweit",
    "zweites": "zweit",
    "zweitklassige": "zweitklassig",
    "zweitklassigem": "zweitklassig",
    "zweitklassigen": "zweitklassig",
    "zweitklassiger": "zweitklassig",
    "zweitklassiges": "zweitklassig",
    "zweitrangigem": "zweitrangig",
    "zweitrangigen": "zweitrangig",
    "zweitrangiger": "zweitrangig",
    "zweitrangiges": "zweitrangig",
    "zweitägige": "zweitägig",
    "zweitägigem": "zweitägig",
    "zweitägigen": "zweitägig",
    "zweitägiger": "zweitägig",
    "zweitägiges": "zweitägig",
    "zwergenhaftem": "zwergenhaft",
    "zwergenhaften": "zwergenhaft",
    "zwergenhafter": "zwergenhaft",
    "zwergenhaftere": "zwergenhaft",
    "zwergenhafterem": "zwergenhaft",
    "zwergenhafteren": "zwergenhaft",
    "zwergenhafterer": "zwergenhaft",
    "zwergenhafteres": "zwergenhaft",
    "zwergenhaftes": "zwergenhaft",
    "zwergenhafteste": "zwergenhaft",
    "zwergenhaftestem": "zwergenhaft",
    "zwergenhaftesten": "zwergenhaft",
    "zwergenhaftester": "zwergenhaft",
    "zwergenhaftestes": "zwergenhaft",
    "zwiebele": "zwiebeln",
    "zwiebelnd": "zwiebeln",
    "zwiebelnde": "zwiebelnd",
    "zwiebelndem": "zwiebelnd",
    "zwiebelnden": "zwiebelnd",
    "zwiebelnder": "zwiebelnd",
    "zwiebelndes": "zwiebelnd",
    "zwiebelst": "zwiebeln",
    "zwiebelt": "zwiebeln",
    "zwiebelte": "zwiebeln",
    "zwiebelten": "zwiebeln",
    "zwiebeltest": "zwiebeln",
    "zwiebeltet": "zwiebeln",
    "zwieble": "zwiebeln",
    "zwielichtige": "zwielichtig",
    "zwielichtigem": "zwielichtig",
    "zwielichtigen": "zwielichtig",
    "zwielichtiger": "zwielichtig",
    "zwielichtigere": "zwielichtig",
    "zwielichtigerem": "zwielichtig",
    "zwielichtigeren": "zwielichtig",
    "zwielichtigerer": "zwielichtig",
    "zwielichtigeres": "zwielichtig",
    "zwielichtiges": "zwielichtig",
    "zwielichtigste": "zwielichtig",
    "zwielichtigstem": "zwielichtig",
    "zwielichtigsten": "zwielichtig",
    "zwielichtigster": "zwielichtig",
    "zwielichtigstes": "zwielichtig",
    "zwiespältigem": "zwiespältig",
    "zwiespältigen": "zwiespältig",
    "zwiespältiger": "zwiespältig",
    "zwiespältigere": "zwiespältig",
    "zwiespältigerem": "zwiespältig",
    "zwiespältigeren": "zwiespältig",
    "zwiespältigerer": "zwiespältig",
    "zwiespältigeres": "zwiespältig",
    "zwiespältiges": "zwiespältig",
    "zwiespältigste": "zwiespältig",
    "zwiespältigstem": "zwiespältig",
    "zwiespältigsten": "zwiespältig",
    "zwiespältigster": "zwiespältig",
    "zwiespältigstes": "zwiespältig",
    "zwinge": "zwingen",
    "zwingend": "zwingen",
    "zwingende": "zwingend",
    "zwingendem": "zwingend",
    "zwingenden": "zwingend",
    "zwingender": "zwingend",
    "zwingendes": "zwingend",
    "zwingest": "zwingen",
    "zwinget": "zwingen",
    "zwingst": "zwingen",
    "zwingt": "zwingen",
    "zwinkere": "zwinkern",
    "zwinkernd": "zwinkern",
    "zwinkernde": "zwinkernd",
    "zwinkerndem": "zwinkernd",
    "zwinkernden": "zwinkernd",
    "zwinkernder": "zwinkernd",
    "zwinkerndere": "zwinkernd",
    "zwinkernderem": "zwinkernd",
    "zwinkernderen": "zwinkernd",
    "zwinkernderer": "zwinkernd",
    "zwinkernderes": "zwinkernd",
    "zwinkerndes": "zwinkernd",
    "zwinkerndste": "zwinkernd",
    "zwinkerndstem": "zwinkernd",
    "zwinkerndsten": "zwinkernd",
    "zwinkerndster": "zwinkernd",
    "zwinkerndstes": "zwinkernd",
    "zwinkerst": "zwinkern",
    "zwinkert": "zwinkern",
    "zwinkerte": "zwinkern",
    "zwinkerten": "zwinkern",
    "zwinkertest": "zwinkern",
    "zwinkertet": "zwinkern",
    "zwirbele": "zwirbeln",
    "zwirbelnd": "zwirbeln",
    "zwirbelnde": "zwirbelnd",
    "zwirbelndem": "zwirbelnd",
    "zwirbelnden": "zwirbelnd",
    "zwirbelnder": "zwirbelnd",
    "zwirbelndere": "zwirbelnd",
    "zwirbelnderem": "zwirbelnd",
    "zwirbelnderen": "zwirbelnd",
    "zwirbelnderer": "zwirbelnd",
    "zwirbelnderes": "zwirbelnd",
    "zwirbelndes": "zwirbelnd",
    "zwirbelndste": "zwirbelnd",
    "zwirbelndstem": "zwirbelnd",
    "zwirbelndsten": "zwirbelnd",
    "zwirbelndster": "zwirbelnd",
    "zwirbelndstes": "zwirbelnd",
    "zwirbelst": "zwirbeln",
    "zwirbelt": "zwirbeln",
    "zwirbelte": "zwirbeln",
    "zwirbelten": "zwirbeln",
    "zwirbeltest": "zwirbeln",
    "zwirbeltet": "zwirbeln",
    "zwirble": "zwirbeln",
    "zwischenbetrieblichem": "zwischenbetrieblich",
    "zwischenbetrieblichen": "zwischenbetrieblich",
    "zwischenbetrieblicher": "zwischenbetrieblich",
    "zwischenbetriebliches": "zwischenbetrieblich",
    "zwischenblende": "zwischenblenden",
    "zwischenblendend": "zwischenblenden",
    "zwischenblendende": "zwischenblendend",
    "zwischenblendendem": "zwischenblendend",
    "zwischenblendenden": "zwischenblendend",
    "zwischenblendender": "zwischenblendend",
    "zwischenblendendes": "zwischenblendend",
    "zwischenblendest": "zwischenblenden",
    "zwischenblendet": "zwischenblenden",
    "zwischenblendete": "zwischenblenden",
    "zwischenblendeten": "zwischenblenden",
    "zwischenblendetest": "zwischenblenden",
    "zwischenblendetet": "zwischenblenden",
    "zwischengeblendet": "zwischenblenden",
    "zwischengeblendete": "zwischengeblendet",
    "zwischengeblendetem": "zwischengeblendet",
    "zwischengeblendeten": "zwischengeblendet",
    "zwischengeblendeter": "zwischengeblendet",
    "zwischengeblendetes": "zwischengeblendet",
    "zwischengelandet": "zwischenlanden",
    "zwischengelandete": "zwischengelandet",
    "zwischengelandetem": "zwischengelandet",
    "zwischengelandeten": "zwischengelandet",
    "zwischengelandeter": "zwischengelandet",
    "zwischengelandetes": "zwischengelandet",
    "zwischenlande": "zwischenlanden",
    "zwischenlandend": "zwischenlanden",
    "zwischenlandende": "zwischenlandend",
    "zwischenlandendem": "zwischenlandend",
    "zwischenlandenden": "zwischenlandend",
    "zwischenlandender": "zwischenlandend",
    "zwischenlandendes": "zwischenlandend",
    "zwischenlandest": "zwischenlanden",
    "zwischenlandet": "zwischenlanden",
    "zwischenlandete": "zwischenlanden",
    "zwischenlandeten": "zwischenlanden",
    "zwischenlandetest": "zwischenlanden",
    "zwischenlandetet": "zwischenlanden",
    "zwischenmenschlichem": "zwischenmenschlich",
    "zwischenmenschlichen": "zwischenmenschlich",
    "zwischenmenschlicher": "zwischenmenschlich",
    "zwischenmenschliches": "zwischenmenschlich",
    "zwischenstaatlichem": "zwischenstaatlich",
    "zwischenstaatlichen": "zwischenstaatlich",
    "zwischenstaatlicher": "zwischenstaatlich",
    "zwischenstaatliches": "zwischenstaatlich",
    "zwischenzeitlichem": "zwischenzeitlich",
    "zwischenzeitlichen": "zwischenzeitlich",
    "zwischenzeitlicher": "zwischenzeitlich",
    "zwischenzeitliches": "zwischenzeitlich",
    "zwischenzublenden": "zwischenblenden",
    "zwischenzulanden": "zwischenlanden",
    "zwitschere": "zwitschern",
    "zwitschernd": "zwitschern",
    "zwitschernde": "zwitschernd",
    "zwitscherndem": "zwitschernd",
    "zwitschernden": "zwitschernd",
    "zwitschernder": "zwitschernd",
    "zwitscherndes": "zwitschernd",
    "zwitscherst": "zwitschern",
    "zwitschert": "zwitschern",
    "zwitscherte": "zwitschern",
    "zwitscherten": "zwitschern",
    "zwitschertest": "zwitschern",
    "zwitschertet": "zwitschern",
    "zwänge": "zwingen",
    "zwängend": "zwängen",
    "zwängende": "zwängend",
    "zwängendem": "zwängend",
    "zwängenden": "zwängend",
    "zwängender": "zwängend",
    "zwängendes": "zwängend",
    "zwängest": "zwingen",
    "zwänget": "zwingen",
    "zwängst": "zwängen",
    "zwängt": "zwängen",
    "zwängte": "zwängen",
    "zwängten": "zwängen",
    "zwängtest": "zwängen",
    "zwängtet": "zwängen",
    "zyklischem": "zyklisch",
    "zyklischen": "zyklisch",
    "zyklischer": "zyklisch",
    "zyklisches": "zyklisch",
    "zynischem": "zynisch",
    "zynischen": "zynisch",
    "zynischer": "zynisch",
    "zynischere": "zynisch",
    "zynischerem": "zynisch",
    "zynischeren": "zynisch",
    "zynischerer": "zynisch",
    "zynischeres": "zynisch",
    "zynisches": "zynisch",
    "zynischste": "zynisch",
    "zynischstem": "zynisch",
    "zynischsten": "zynisch",
    "zynischster": "zynisch",
    "zynischstes": "zynisch",
    "zähe": "zäh",
    "zähem": "zäh",
    "zähen": "zäh",
    "zäher": "zäh",
    "zähere": "zäh",
    "zäherem": "zäh",
    "zäheren": "zäh",
    "zäherer": "zäh",
    "zäheres": "zäh",
    "zähes": "zäh",
    "zäheste": "zäh",
    "zähestem": "zäh",
    "zähesten": "zäh",
    "zähester": "zäh",
    "zähestes": "zäh",
    "zähflüssige": "zähflüssig",
    "zähflüssigem": "zähflüssig",
    "zähflüssigen": "zähflüssig",
    "zähflüssiger": "zähflüssig",
    "zähflüssigere": "zähflüssig",
    "zähflüssigerem": "zähflüssig",
    "zähflüssigeren": "zähflüssig",
    "zähflüssigerer": "zähflüssig",
    "zähflüssigeres": "zähflüssig",
    "zähflüssiges": "zähflüssig",
    "zähflüssigste": "zähflüssig",
    "zähflüssigstem": "zähflüssig",
    "zähflüssigsten": "zähflüssig",
    "zähflüssigster": "zähflüssig",
    "zähflüssigstes": "zähflüssig",
    "zählbarem": "zählbar",
    "zählbaren": "zählbar",
    "zählbarer": "zählbar",
    "zählbares": "zählbar",
    "zähle": "zählen",
    "zählend": "zählen",
    "zählendem": "zählend",
    "zählender": "zählend",
    "zählendes": "zählend",
    "zählest": "zählen",
    "zählet": "zählen",
    "zählst": "zählen",
    "zählt": "zählen",
    "zählte": "zählen",
    "zählten": "zählen",
    "zähltest": "zählen",
    "zähltet": "zählen",
    "zähmbare": "zähmbar",
    "zähmbarem": "zähmbar",
    "zähmbaren": "zähmbar",
    "zähmbarer": "zähmbar",
    "zähmbarere": "zähmbar",
    "zähmbarerem": "zähmbar",
    "zähmbareren": "zähmbar",
    "zähmbarerer": "zähmbar",
    "zähmbareres": "zähmbar",
    "zähmbares": "zähmbar",
    "zähmbarste": "zähmbar",
    "zähmbarstem": "zähmbar",
    "zähmbarsten": "zähmbar",
    "zähmbarster": "zähmbar",
    "zähmbarstes": "zähmbar",
    "zähme": "zähmen",
    "zähmend": "zähmen",
    "zähmende": "zähmend",
    "zähmendem": "zähmend",
    "zähmenden": "zähmend",
    "zähmender": "zähmend",
    "zähmendere": "zähmend",
    "zähmenderem": "zähmend",
    "zähmenderen": "zähmend",
    "zähmenderer": "zähmend",
    "zähmenderes": "zähmend",
    "zähmendes": "zähmend",
    "zähmendste": "zähmend",
    "zähmendstem": "zähmend",
    "zähmendsten": "zähmend",
    "zähmendster": "zähmend",
    "zähmendstes": "zähmend",
    "zähmest": "zähmen",
    "zähmet": "zähmen",
    "zähmst": "zähmen",
    "zähmt": "zähmen",
    "zähmte": "zähmen",
    "zähmten": "zähmen",
    "zähmtest": "zähmen",
    "zähmtet": "zähmen",
    "zähneknirschendem": "zähneknirschend",
    "zähneknirschenden": "zähneknirschend",
    "zähneknirschender": "zähneknirschend",
    "zähneknirschendes": "zähneknirschend",
    "zänkische": "zänkisch",
    "zänkischem": "zänkisch",
    "zänkischen": "zänkisch",
    "zänkischer": "zänkisch",
    "zänkischere": "zänkisch",
    "zänkischerem": "zänkisch",
    "zänkischeren": "zänkisch",
    "zänkischerer": "zänkisch",
    "zänkischeres": "zänkisch",
    "zänkisches": "zänkisch",
    "zänkischste": "zänkisch",
    "zänkischstem": "zänkisch",
    "zänkischsten": "zänkisch",
    "zänkischster": "zänkisch",
    "zänkischstes": "zänkisch",
    "zärtliche": "zärtlich",
    "zärtlichem": "zärtlich",
    "zärtlichen": "zärtlich",
    "zärtlicher": "zärtlich",
    "zärtlichere": "zärtlich",
    "zärtlicherem": "zärtlich",
    "zärtlicheren": "zärtlich",
    "zärtlicherer": "zärtlich",
    "zärtlicheres": "zärtlich",
    "zärtliches": "zärtlich",
    "zärtlichstem": "zärtlich",
    "zärtlichsten": "zärtlich",
    "zärtlichster": "zärtlich",
    "zärtlichstes": "zärtlich",
    "zäume": "zäumen",
    "zäumend": "zäumen",
    "zäumende": "zäumend",
    "zäumendem": "zäumend",
    "zäumenden": "zäumend",
    "zäumender": "zäumend",
    "zäumendes": "zäumend",
    "zäumest": "zäumen",
    "zäumet": "zäumen",
    "zäumst": "zäumen",
    "zäumt": "zäumen",
    "zäumte": "zäumen",
    "zäumten": "zäumen",
    "zäumtest": "zäumen",
    "zäumtet": "zäumen",
    "zäunend": "zäunen",
    "zäunende": "zäunend",
    "zäunendem": "zäunend",
    "zäunenden": "zäunend",
    "zäunender": "zäunend",
    "zäunendes": "zäunend",
    "zäunest": "zäunen",
    "zäunet": "zäunen",
    "zäunst": "zäunen",
    "zäunt": "zäunen",
    "zäunte": "zäunen",
    "zäunten": "zäunen",
    "zäuntest": "zäunen",
    "zäuntet": "zäunen",
    "zöge": "ziehen",
    "zögen": "ziehen",
    "zögere": "zögern",
    "zögerliche": "zögerlich",
    "zögerlichem": "zögerlich",
    "zögerlichen": "zögerlich",
    "zögerlicher": "zögerlich",
    "zögerlichere": "zögerlich",
    "zögerlicherem": "zögerlich",
    "zögerlicheren": "zögerlich",
    "zögerlicherer": "zögerlich",
    "zögerlicheres": "zögerlich",
    "zögerliches": "zögerlich",
    "zögerlichste": "zögerlich",
    "zögerlichstem": "zögerlich",
    "zögerlichsten": "zögerlich",
    "zögerlichster": "zögerlich",
    "zögerlichstes": "zögerlich",
    "zögernd": "zögern",
    "zögernde": "zögernd",
    "zögerndem": "zögernd",
    "zögernden": "zögernd",
    "zögernder": "zögernd",
    "zögerndere": "zögernd",
    "zögernderem": "zögernd",
    "zögernderen": "zögernd",
    "zögernderer": "zögernd",
    "zögernderes": "zögernd",
    "zögerndes": "zögernd",
    "zögerndste": "zögernd",
    "zögerndstem": "zögernd",
    "zögerndsten": "zögernd",
    "zögerndster": "zögernd",
    "zögerndstes": "zögernd",
    "zögerst": "zögern",
    "zögert": "zögern",
    "zögerte": "zögern",
    "zögerten": "zögern",
    "zögertest": "zögern",
    "zögertet": "zögern",
    "zögest": "ziehen",
    "zöget": "ziehen",
    "züchte": "züchten",
    "züchtend": "züchten",
    "züchtende": "züchtend",
    "züchtendem": "züchtend",
    "züchtenden": "züchtend",
    "züchtender": "züchtend",
    "züchtendes": "züchtend",
    "züchtest": "züchten",
    "züchtet": "züchten",
    "züchtete": "züchten",
    "züchteten": "züchten",
    "züchtetest": "züchten",
    "züchtetet": "züchten",
    "züchtige": "züchtigen",
    "züchtigend": "züchtigen",
    "züchtigende": "züchtigend",
    "züchtigendem": "züchtigend",
    "züchtigenden": "züchtigend",
    "züchtigender": "züchtigend",
    "züchtigendes": "züchtigend",
    "züchtigest": "züchtigen",
    "züchtiget": "züchtigen",
    "züchtigst": "züchtigen",
    "züchtigt": "züchtigen",
    "züchtigte": "züchtigen",
    "züchtigten": "züchtigen",
    "züchtigtest": "züchtigen",
    "züchtigtet": "züchtigen",
    "zügele": "zügeln",
    "zügellose": "zügellos",
    "zügellosem": "zügellos",
    "zügellosen": "zügellos",
    "zügelloser": "zügellos",
    "zügellosere": "zügellos",
    "zügelloserem": "zügellos",
    "zügelloseren": "zügellos",
    "zügelloserer": "zügellos",
    "zügelloseres": "zügellos",
    "zügelloses": "zügellos",
    "zügelloseste": "zügellos",
    "zügellosestem": "zügellos",
    "zügellosesten": "zügellos",
    "zügellosester": "zügellos",
    "zügellosestes": "zügellos",
    "zügelnd": "zügeln",
    "zügelnde": "zügelnd",
    "zügelndem": "zügelnd",
    "zügelnden": "zügelnd",
    "zügelnder": "zügelnd",
    "zügelndere": "zügelnd",
    "zügelnderem": "zügelnd",
    "zügelnderen": "zügelnd",
    "zügelnderer": "zügelnd",
    "zügelnderes": "zügelnd",
    "zügelndes": "zügelnd",
    "zügelndste": "zügelnd",
    "zügelndstem": "zügelnd",
    "zügelndsten": "zügelnd",
    "zügelndster": "zügelnd",
    "zügelndstes": "zügelnd",
    "zügelst": "zügeln",
    "zügelt": "zügeln",
    "zügelte": "zügeln",
    "zügelten": "zügeln",
    "zügeltest": "zügeln",
    "zügeltet": "zügeln",
    "zügige": "zügig",
    "zügigem": "zügig",
    "zügigen": "zügig",
    "zügiger": "zügig",
    "zügigere": "zügig",
    "zügigerem": "zügig",
    "zügigeren": "zügig",
    "zügigerer": "zügig",
    "zügigeres": "zügig",
    "zügiges": "zügig",
    "zügigste": "zügig",
    "zügigstem": "zügig",
    "zügigsten": "zügig",
    "zügigster": "zügig",
    "zügigstes": "zügig",
    "zügle": "zügeln",
    "zünde": "zünden",
    "zündele": "zündeln",
    "zündelnd": "zündeln",
    "zündelnde": "zündelnd",
    "zündelndem": "zündelnd",
    "zündelnden": "zündelnd",
    "zündelnder": "zündelnd",
    "zündelndes": "zündelnd",
    "zündelst": "zündeln",
    "zündelt": "zündeln",
    "zündelte": "zündeln",
    "zündelten": "zündeln",
    "zündeltest": "zündeln",
    "zündeltet": "zündeln",
    "zündend": "zünden",
    "zündende": "zündend",
    "zündendem": "zündend",
    "zündenden": "zündend",
    "zündender": "zündend",
    "zündendere": "zündend",
    "zündenderem": "zündend",
    "zündenderen": "zündend",
    "zündenderer": "zündend",
    "zündenderes": "zündend",
    "zündendes": "zündend",
    "zündendste": "zündend",
    "zündendstem": "zündend",
    "zündendsten": "zündend",
    "zündendster": "zündend",
    "zündendstes": "zündend",
    "zündest": "zünden",
    "zündet": "zünden",
    "zündete": "zünden",
    "zündeten": "zünden",
    "zündetest": "zünden",
    "zündetet": "zünden",
    "zündle": "zündeln",
    "zünftigem": "zünftig",
    "zünftigen": "zünftig",
    "zünftiger": "zünftig",
    "zünftigere": "zünftig",
    "zünftigerem": "zünftig",
    "zünftigeren": "zünftig",
    "zünftigerer": "zünftig",
    "zünftigeres": "zünftig",
    "zünftiges": "zünftig",
    "zünftigste": "zünftig",
    "zünftigstem": "zünftig",
    "zünftigsten": "zünftig",
    "zünftigster": "zünftig",
    "zünftigstes": "zünftig",
    "züngele": "züngeln",
    "züngelnd": "züngeln",
    "züngelnde": "züngelnd",
    "züngelndem": "züngelnd",
    "züngelnden": "züngelnd",
    "züngelnder": "züngelnd",
    "züngelndere": "züngelnd",
    "züngelnderem": "züngelnd",
    "züngelnderen": "züngelnd",
    "züngelnderer": "züngelnd",
    "züngelnderes": "züngelnd",
    "züngelndes": "züngelnd",
    "züngelndste": "züngelnd",
    "züngelndstem": "züngelnd",
    "züngelndsten": "züngelnd",
    "züngelndster": "züngelnd",
    "züngelndstes": "züngelnd",
    "züngelst": "züngeln",
    "züngelt": "züngeln",
    "züngelte": "züngeln",
    "züngelten": "züngeln",
    "züngeltest": "züngeln",
    "züngeltet": "züngeln",
    "züngle": "züngeln",
    "zürne": "zürnen",
    "zürnend": "zürnen",
    "zürnende": "zürnend",
    "zürnendem": "zürnend",
    "zürnenden": "zürnend",
    "zürnender": "zürnend",
    "zürnendere": "zürnend",
    "zürnenderem": "zürnend",
    "zürnenderen": "zürnend",
    "zürnenderer": "zürnend",
    "zürnenderes": "zürnend",
    "zürnendes": "zürnend",
    "zürnendste": "zürnend",
    "zürnendstem": "zürnend",
    "zürnendsten": "zürnend",
    "zürnendster": "zürnend",
    "zürnendstes": "zürnend",
    "zürnest": "zürnen",
    "zürnet": "zürnen",
    "zürnst": "zürnen",
    "zürnt": "zürnen",
    "zürnte": "zürnen",
    "zürnten": "zürnen",
    "zürntest": "zürnen",
    "zürntet": "zürnen",
    "Äbte": "Abt",
    "Äbten": "Abt",
    "Ächtens": "Ächten",
    "Ächzens": "Ächzen",
    "Äcker": "Acker",
    "Äckern": "Acker",
    "Äffens": "Äffen",
    "Ägyptens": "Ägypten",
    "Ägyptologen": "Ägyptologe",
    "Ähnelns": "Ähneln",
    "Ähnlichkeiten": "Ähnlichkeit",
    "Ähren": "Ähre",
    "Ältesten": "Älteste",
    "Ämter": "Amt",
    "Ämtern": "Amt",
    "Änderns": "Ändern",
    "Änderungen": "Änderung",
    "Ängste": "Angst",
    "Ängsten": "Angst",
    "Ängstigens": "Ängstigen",
    "Ängstlichkeiten": "Ängstlichkeit",
    "Äpfel": "Apfel",
    "Äpfeln": "Apfel",
    "Ärger": "ärgern",
    "Ärgernisse": "Ärgernis",
    "Ärgernissen": "Ärgernis",
    "Ärgernisses": "Ärgernis",
    "Ärgerns": "Ärgern",
    "Ärgers": "Ärger",
    "Ärmchens": "Ärmchen",
    "Ärmeln": "Ärmel",
    "Ärmels": "Ärmel",
    "Ärmlinge": "Ärmling",
    "Ärmlingen": "Ärmling",
    "Ärmlings": "Ärmling",
    "Ärzte": "Arzt",
    "Ärzten": "Arzt",
    "Ärzteschaften": "Ärzteschaft",
    "Ärztinnen": "Ärztin",
    "Äscher": "äschern",
    "Äschern": "Äscher",
    "Äscherns": "Äschern",
    "Äschers": "Äscher",
    "Äste": "ästen",
    "Ästen": "Ast",
    "Ästens": "Ästen",
    "Ästheten": "Ästhet",
    "Äthanole": "Äthanol",
    "Äthanolen": "Äthanol",
    "Äthanols": "Äthanol",
    "Äthern": "Äther",
    "Äthers": "Äther",
    "Äthiopiens": "Äthiopien",
    "Äthylene": "Äthylen",
    "Äthylenen": "Äthylen",
    "Äthylens": "Äthylen",
    "Ätzens": "Ätzen",
    "Ätzkalks": "Ätzkalk",
    "Ätzungen": "Ätzung",
    "Äugleins": "Äuglein",
    "Äußerlichkeiten": "Äußerlichkeit",
    "Äußerns": "Äußern",
    "Äußerungen": "Äußerung",
    "Äxte": "Axt",
    "Äxten": "Axt",
    "Ödens": "Öden",
    "Ödlands": "Ödland",
    "Öfen": "Ofen",
    "Öffentlichkeiten": "Öffentlichkeit",
    "Öffnens": "Öffnen",
    "Öffnern": "Öffner",
    "Öffners": "Öffner",
    "Öffnungen": "Öffnung",
    "Öffnungszeiten": "Öffnungszeit",
    "Öhrleins": "Öhrlein",
    "Ökologen": "Ökologe",
    "Ökonomen": "Ökonom",
    "Ökonomien": "Ökonomie",
    "Ökos": "Öko",
    "Ökosysteme": "Ökosystem",
    "Ökosystemen": "Ökosystem",
    "Ökosystems": "Ökosystem",
    "Öl": "ölen",
    "Öle": "ölen",
    "Ölen": "Öl",
    "Ölens": "Ölen",
    "Öles": "Öl",
    "Ölgesellschaften": "Ölgesellschaft",
    "Öls": "Öl",
    "Ölungen": "Ölung",
    "Örtlichkeiten": "Örtlichkeit",
    "Ösen": "Öse",
    "Österreichern": "Österreicher",
    "Österreichers": "Österreicher",
    "Österreichs": "Österreich",
    "Übelkeiten": "Übelkeit",
    "Übellaunigkeiten": "Übellaunigkeit",
    "Übeln": "Übel",
    "Übelnehmens": "Übelnehmen",
    "Übels": "Übel",
    "Übeltaten": "Übeltat",
    "Übeltätern": "Übeltäter",
    "Übeltäters": "Übeltäter",
    "Übens": "Üben",
    "Überangepaßtheiten": "Überangepaßtheit",
    "Überanstrengens": "Überanstrengen",
    "Überarbeitens": "Überarbeiten",
    "Überarbeitungen": "Überarbeitung",
    "Überbauens": "Überbauen",
    "Überbeanspruchens": "Überbeanspruchen",
    "Überbehaltens": "Überbehalten",
    "Überbekommens": "Überbekommen",
    "Überbelastungen": "Überbelastung",
    "Überbelichtens": "Überbelichten",
    "Überbelichtungen": "Überbelichtung",
    "Überbetonens": "Überbetonen",
    "Überbewertens": "Überbewerten",
    "Überbewertungen": "Überbewertung",
    "Überbietens": "Überbieten",
    "Überbleibseln": "Überbleibsel",
    "Überbleibsels": "Überbleibsel",
    "Überblendungen": "Überblendung",
    "Überblicke": "Überblick",
    "Überblicken": "Überblick",
    "Überblickes": "Überblick",
    "Überblicks": "Überblick",
    "Überbratens": "Überbraten",
    "Überbringens": "Überbringen",
    "Überbringern": "Überbringer",
    "Überbringers": "Überbringer",
    "Überbrückens": "Überbrücken",
    "Überdachens": "Überdachen",
    "Überdachungen": "Überdachung",
    "Überdauerns": "Überdauern",
    "Überdehnens": "Überdehnen",
    "Überdenkens": "Überdenken",
    "Überdosierens": "Überdosieren",
    "Überdrehens": "Überdrehen",
    "Überdrucke": "Überdruck",
    "Überdrucken": "Überdruck",
    "Überdruckes": "Überdruck",
    "Überdrucks": "Überdruck",
    "Übereignens": "Übereignen",
    "Übereinklange": "Übereinklang",
    "Übereinklanges": "Übereinklang",
    "Übereinklangs": "Übereinklang",
    "Übereinklänge": "Übereinklang",
    "Übereinklängen": "Übereinklang",
    "Übereinkommens": "Übereinkommen",
    "Übereinkünfte": "Übereinkunft",
    "Übereinkünften": "Übereinkunft",
    "Übereinstimmens": "Übereinstimmen",
    "Übereinstimmungen": "Übereinstimmung",
    "Überernährungen": "Überernährung",
    "Überessens": "Überessen",
    "Überfahrens": "Überfahren",
    "Überfall": "überfallen",
    "Überfalle": "überfallen",
    "Überfallens": "Überfallen",
    "Überfalles": "Überfall",
    "Überfliegens": "Überfliegen",
    "Überfließens": "Überfließen",
    "Überflusse": "Überfluß",
    "Überflusses": "Überfluß",
    "Überflutens": "Überfluten",
    "Überflutungen": "Überflutung",
    "Überflügelns": "Überflügeln",
    "Überflüsse": "Überfluß",
    "Überflüssen": "Überfluß",
    "Überforderns": "Überfordern",
    "Überforderungen": "Überforderung",
    "Überfrachtens": "Überfrachten",
    "Überfragens": "Überfragen",
    "Überfremdens": "Überfremden",
    "Überfremdungen": "Überfremdung",
    "Überfressens": "Überfressen",
    "Überfälle": "Überfall",
    "Überfällen": "Überfall",
    "Überführens": "Überführen",
    "Überfüllens": "Überfüllen",
    "Überfütterns": "Überfüttern",
    "Übergange": "Übergang",
    "Übergangs": "Übergang",
    "Übergardinen": "Übergardine",
    "Übergebens": "Übergeben",
    "Übergehens": "Übergehen",
    "Übergewichte": "Übergewicht",
    "Übergewichtes": "Übergewicht",
    "Übergewichts": "Übergewicht",
    "Übergießens": "Übergießen",
    "Übergreifens": "Übergreifen",
    "Übergriffe": "Übergriff",
    "Übergriffen": "Übergriff",
    "Übergriffs": "Übergriff",
    "Übergrößen": "Übergröße",
    "Übergänge": "Übergang",
    "Übergängen": "Übergang",
    "Überhandnehmens": "Überhandnehmen",
    "Überheizens": "Überheizen",
    "Überhitzens": "Überhitzen",
    "Überholens": "Überholen",
    "Überholspuren": "Überholspur",
    "Überholverbote": "Überholverbot",
    "Überholverboten": "Überholverbot",
    "Überholverbots": "Überholverbot",
    "Überhängens": "Überhängen",
    "Überhäufens": "Überhäufen",
    "Überhöhens": "Überhöhen",
    "Überhöhungen": "Überhöhung",
    "Überhörens": "Überhören",
    "Überichs": "Überich",
    "Überkippens": "Überkippen",
    "Überklebens": "Überkleben",
    "Überkochens": "Überkochen",
    "Überkommens": "Überkommen",
    "Überkompensierens": "Überkompensieren",
    "Überkriegens": "Überkriegen",
    "Überkrustens": "Überkrusten",
    "Überladens": "Überladen",
    "Überlagerns": "Überlagern",
    "Überlagerungen": "Überlagerung",
    "Überlandbahnen": "Überlandbahn",
    "Überlappens": "Überlappen",
    "Überlassens": "Überlassen",
    "Überlastens": "Überlasten",
    "Überlaufens": "Überlaufen",
    "Überlebens": "Überleben",
    "Überlegenheiten": "Überlegenheit",
    "Überlegens": "Überlegen",
    "Überlegungen": "Überlegung",
    "Überleitens": "Überleiten",
    "Überleitungen": "Überleitung",
    "Überlesens": "Überlesen",
    "Überlieferns": "Überliefern",
    "Überliegens": "Überliegen",
    "Überlistens": "Überlisten",
    "Überlängen": "Überlänge",
    "Übermalens": "Übermalen",
    "Übermalungen": "Übermalung",
    "Übermannens": "Übermannen",
    "Übermaße": "Übermaß",
    "Übermaßen": "Übermaß",
    "Übermaßes": "Übermaß",
    "Übermenschen": "Übermensch",
    "Übermittelns": "Übermitteln",
    "Übermittelungen": "Übermittelung",
    "Übermute": "Übermut",
    "Übermutes": "Übermut",
    "Übermuts": "Übermut",
    "Übermüdens": "Übermüden",
    "Übernachtens": "Übernachten",
    "Übernachtungen": "Übernachtung",
    "Übernahmen": "übernehmen",
    "Übernamen": "Übername",
    "Übernehmens": "Übernehmen",
    "Überordnens": "Überordnen",
    "Überprüfens": "Überprüfen",
    "Überprüfungen": "Überprüfung",
    "Überquellens": "Überquellen",
    "Überquerens": "Überqueren",
    "Überragens": "Überragen",
    "Überraschens": "Überraschen",
    "Überraschungen": "Überraschung",
    "Überredens": "Überreden",
    "Überreichens": "Überreichen",
    "Überreichungen": "Überreichung",
    "Überreizens": "Überreizen",
    "Überrennens": "Überrennen",
    "Überreste": "Überrest",
    "Überresten": "Überrest",
    "Überrests": "Überrest",
    "Überriesen": "Überriese",
    "Überrollens": "Überrollen",
    "Überrumpelns": "Überrumpeln",
    "Überrundens": "Überrunden",
    "Überschalle": "Überschall",
    "Überschalles": "Überschall",
    "Überschalls": "Überschall",
    "Überschattens": "Überschatten",
    "Überschau": "überschauen",
    "Überschauens": "Überschauen",
    "Überschlafens": "Überschlafen",
    "Überschlag": "überschlagen",
    "Überschlage": "überschlagen",
    "Überschlagens": "Überschlagen",
    "Überschlags": "Überschlag",
    "Überschläge": "Überschlag",
    "Überschlägen": "Überschlag",
    "Überschnappens": "Überschnappen",
    "Überschneidens": "Überschneiden",
    "Überschneidungen": "Überschneidung",
    "Überschreibens": "Überschreiben",
    "Überschreibungen": "Überschreibung",
    "Überschreitens": "Überschreiten",
    "Überschriften": "Überschrift",
    "Überschusse": "Überschuß",
    "Überschusses": "Überschuß",
    "Überschwangs": "Überschwang",
    "Überschwappens": "Überschwappen",
    "Überschwemmens": "Überschwemmen",
    "Überschwemmungen": "Überschwemmung",
    "Überschätzens": "Überschätzen",
    "Überschäumens": "Überschäumen",
    "Überschüsse": "Überschuß",
    "Überschüssen": "Überschuß",
    "Übersehens": "Übersehen",
    "Übersendens": "Übersenden",
    "Übersendungen": "Übersendung",
    "Übersetzens": "Übersetzen",
    "Übersetzerinnen": "Übersetzerin",
    "Übersetzern": "Übersetzer",
    "Übersetzers": "Übersetzer",
    "Übersetzungen": "Übersetzung",
    "Übersichten": "Übersicht",
    "Übersiedlern": "Übersiedler",
    "Übersiedlers": "Übersiedler",
    "Überspannens": "Überspannen",
    "Überspielens": "Überspielen",
    "Überspinnens": "Überspinnen",
    "Überspitzens": "Überspitzen",
    "Überspringens": "Überspringen",
    "Übersprudelns": "Übersprudeln",
    "Überstehens": "Überstehen",
    "Übersteigens": "Übersteigen",
    "Überstellens": "Überstellen",
    "Überstimmens": "Überstimmen",
    "Überstrahlens": "Überstrahlen",
    "Überstrapazierens": "Überstrapazieren",
    "Überstreichens": "Überstreichen",
    "Überstreifens": "Überstreifen",
    "Überströmens": "Überströmen",
    "Überstunden": "Überstunde",
    "Überstürzens": "Überstürzen",
    "Übersättigens": "Übersättigen",
    "Übersättigungen": "Übersättigung",
    "Übersäuerns": "Übersäuern",
    "Übertopfe": "Übertopf",
    "Übertopfs": "Übertopf",
    "Übertrag": "übertragen",
    "Übertrage": "übertragen",
    "Übertragens": "Übertragen",
    "Übertragern": "Übertrager",
    "Übertragers": "Übertrager",
    "Übertrags": "Übertrag",
    "Übertragungen": "Übertragung",
    "Übertreffens": "Übertreffen",
    "Übertreibens": "Übertreiben",
    "Übertreibungen": "Übertreibung",
    "Übertretens": "Übertreten",
    "Übertretungen": "Übertretung",
    "Übertritte": "Übertritt",
    "Übertritten": "Übertritt",
    "Übertritts": "Übertritt",
    "Übertrumpfens": "Übertrumpfen",
    "Übertrumpfungen": "Übertrumpfung",
    "Überträge": "Übertrag",
    "Überträgen": "Übertrag",
    "Überträgern": "Überträger",
    "Überträgers": "Überträger",
    "Übertölpelns": "Übertölpeln",
    "Übertönens": "Übertönen",
    "Übertöpfe": "Übertopf",
    "Übertöpfen": "Übertopf",
    "Übertünchens": "Übertünchen",
    "Überversicherns": "Überversichern",
    "Übervorteilens": "Übervorteilen",
    "Übervorteilungen": "Übervorteilung",
    "Überwachens": "Überwachen",
    "Überwachungen": "Überwachung",
    "Überwallens": "Überwallen",
    "Überwasserstrecken": "Überwasserstrecke",
    "Überweisens": "Überweisen",
    "Überweisungen": "Überweisung",
    "Überwerfens": "Überwerfen",
    "Überwiegens": "Überwiegen",
    "Überwindens": "Überwinden",
    "Überwindungen": "Überwindung",
    "Überwinterns": "Überwintern",
    "Überwucherns": "Überwuchern",
    "Überwältigens": "Überwältigen",
    "Überwältigungen": "Überwältigung",
    "Überzahl": "überzahlen",
    "Überzahlens": "Überzahlen",
    "Überzeugens": "Überzeugen",
    "Überzeugungen": "Überzeugung",
    "Überziehens": "Überziehen",
    "Überziehern": "Überzieher",
    "Überziehers": "Überzieher",
    "Überzuge": "Überzug",
    "Überzugs": "Überzug",
    "Überzählens": "Überzählen",
    "Überzüchtens": "Überzüchten",
    "Überzüge": "Überzug",
    "Überzügen": "Überzug",
    "Übrigbehaltens": "Übrigbehalten",
    "Übrigbleibens": "Übrigbleiben",
    "Übungen": "Übung",
    "Ülzens": "Ülzen",
    "ächte": "ächten",
    "ächtend": "ächten",
    "ächtende": "ächtend",
    "ächtendem": "ächtend",
    "ächtenden": "ächtend",
    "ächtender": "ächtend",
    "ächtendere": "ächtend",
    "ächtenderem": "ächtend",
    "ächtenderen": "ächtend",
    "ächtenderer": "ächtend",
    "ächtenderes": "ächtend",
    "ächtendes": "ächtend",
    "ächtendste": "ächtend",
    "ächtendstem": "ächtend",
    "ächtendsten": "ächtend",
    "ächtendster": "ächtend",
    "ächtendstes": "ächtend",
    "ächtest": "ächten",
    "ächtet": "ächten",
    "ächtete": "ächten",
    "ächteten": "ächten",
    "ächtetest": "ächten",
    "ächtetet": "ächten",
    "ächze": "ächzen",
    "ächzend": "ächzen",
    "ächzende": "ächzend",
    "ächzendem": "ächzend",
    "ächzenden": "ächzend",
    "ächzender": "ächzend",
    "ächzendere": "ächzend",
    "ächzenderem": "ächzend",
    "ächzenderen": "ächzend",
    "ächzenderer": "ächzend",
    "ächzenderes": "ächzend",
    "ächzendes": "ächzend",
    "ächzendste": "ächzend",
    "ächzendstem": "ächzend",
    "ächzendsten": "ächzend",
    "ächzendster": "ächzend",
    "ächzendstes": "ächzend",
    "ächzest": "ächzen",
    "ächzet": "ächzen",
    "ächzt": "ächzen",
    "ächzte": "ächzen",
    "ächzten": "ächzen",
    "ächztest": "ächzen",
    "ächztet": "ächzen",
    "äffe": "äffen",
    "äffend": "äffen",
    "äffende": "äffend",
    "äffendem": "äffend",
    "äffenden": "äffend",
    "äffender": "äffend",
    "äffendere": "äffend",
    "äffenderem": "äffend",
    "äffenderen": "äffend",
    "äffenderer": "äffend",
    "äffenderes": "äffend",
    "äffendes": "äffend",
    "äffendste": "äffend",
    "äffendstem": "äffend",
    "äffendsten": "äffend",
    "äffendster": "äffend",
    "äffendstes": "äffend",
    "äffest": "äffen",
    "äffet": "äffen",
    "äffst": "äffen",
    "äfft": "äffen",
    "äffte": "äffen",
    "äfften": "äffen",
    "äfftest": "äffen",
    "äfftet": "äffen",
    "ägyptische": "ägyptisch",
    "ägyptischem": "ägyptisch",
    "ägyptischen": "ägyptisch",
    "ägyptischer": "ägyptisch",
    "ägyptisches": "ägyptisch",
    "ägyptologische": "ägyptologisch",
    "ägyptologischem": "ägyptologisch",
    "ägyptologischen": "ägyptologisch",
    "ägyptologischer": "ägyptologisch",
    "ägyptologisches": "ägyptologisch",
    "ähnele": "ähneln",
    "ähnelnd": "ähneln",
    "ähnelnde": "ähnelnd",
    "ähnelndem": "ähnelnd",
    "ähnelnden": "ähnelnd",
    "ähnelnder": "ähnelnd",
    "ähnelndere": "ähnelnd",
    "ähnelnderem": "ähnelnd",
    "ähnelnderen": "ähnelnd",
    "ähnelnderer": "ähnelnd",
    "ähnelnderes": "ähnelnd",
    "ähnelndes": "ähnelnd",
    "ähnelndste": "ähnelnd",
    "ähnelndstem": "ähnelnd",
    "ähnelndsten": "ähnelnd",
    "ähnelndster": "ähnelnd",
    "ähnelndstes": "ähnelnd",
    "ähnelst": "ähneln",
    "ähnelt": "ähneln",
    "ähnelte": "ähneln",
    "ähnelten": "ähneln",
    "ähneltest": "ähneln",
    "ähneltet": "ähneln",
    "ähnle": "ähneln",
    "ähnliche": "ähnlich",
    "ähnlichem": "ähnlich",
    "ähnlichen": "ähnlich",
    "ähnlicher": "ähnlich",
    "ähnlichere": "ähnlich",
    "ähnlicherem": "ähnlich",
    "ähnlicheren": "ähnlich",
    "ähnlicherer": "ähnlich",
    "ähnlicheres": "ähnlich",
    "ähnliches": "ähnlich",
    "ähnlichste": "ähnlich",
    "ähnlichstem": "ähnlich",
    "ähnlichsten": "ähnlich",
    "ähnlichster": "ähnlich",
    "ähnlichstes": "ähnlich",
    "älter": "alt",
    "ältere": "alt",
    "älterem": "alt",
    "älteren": "alt",
    "älterer": "alt",
    "älteres": "alt",
    "älteste": "alt",
    "ältestem": "alt",
    "ältesten": "alt",
    "ältester": "alt",
    "ältestes": "alt",
    "ändere": "ändern",
    "ändernd": "ändern",
    "ändernde": "ändernd",
    "änderndem": "ändernd",
    "ändernden": "ändernd",
    "ändernder": "ändernd",
    "änderndere": "ändernd",
    "ändernderem": "ändernd",
    "ändernderen": "ändernd",
    "ändernderer": "ändernd",
    "ändernderes": "ändernd",
    "änderndes": "ändernd",
    "änderndste": "ändernd",
    "änderndstem": "ändernd",
    "änderndsten": "ändernd",
    "änderndster": "ändernd",
    "änderndstes": "ändernd",
    "änderst": "ändern",
    "ändert": "ändern",
    "änderte": "ändern",
    "änderten": "ändern",
    "ändertest": "ändern",
    "ändertet": "ändern",
    "ängstige": "ängstigen",
    "ängstigend": "ängstigen",
    "ängstigende": "ängstigend",
    "ängstigendem": "ängstigend",
    "ängstigenden": "ängstigend",
    "ängstigender": "ängstigend",
    "ängstigendere": "ängstigend",
    "ängstigenderem": "ängstigend",
    "ängstigenderen": "ängstigend",
    "ängstigenderer": "ängstigend",
    "ängstigenderes": "ängstigend",
    "ängstigendes": "ängstigend",
    "ängstigendste": "ängstigend",
    "ängstigendstem": "ängstigend",
    "ängstigendsten": "ängstigend",
    "ängstigendster": "ängstigend",
    "ängstigendstes": "ängstigend",
    "ängstigest": "ängstigen",
    "ängstiget": "ängstigen",
    "ängstigst": "ängstigen",
    "ängstigt": "ängstigen",
    "ängstigte": "ängstigen",
    "ängstigten": "ängstigen",
    "ängstigtest": "ängstigen",
    "ängstigtet": "ängstigen",
    "ängstliche": "ängstlich",
    "ängstlichem": "ängstlich",
    "ängstlichen": "ängstlich",
    "ängstlicher": "ängstlich",
    "ängstlichere": "ängstlich",
    "ängstlicherem": "ängstlich",
    "ängstlicheren": "ängstlich",
    "ängstlicherer": "ängstlich",
    "ängstlicheres": "ängstlich",
    "ängstliches": "ängstlich",
    "ängstlichste": "ängstlich",
    "ängstlichstem": "ängstlich",
    "ängstlichsten": "ängstlich",
    "ängstlichster": "ängstlich",
    "ängstlichstes": "ängstlich",
    "äquatoriale": "äquatorial",
    "äquatorialem": "äquatorial",
    "äquatorialen": "äquatorial",
    "äquatorialer": "äquatorial",
    "äquatoriales": "äquatorial",
    "ärgere": "ärgern",
    "ärgerliche": "ärgerlich",
    "ärgerlichem": "ärgerlich",
    "ärgerlichen": "ärgerlich",
    "ärgerlicher": "ärgerlich",
    "ärgerlichere": "ärgerlich",
    "ärgerlicherem": "ärgerlich",
    "ärgerlicheren": "ärgerlich",
    "ärgerlicherer": "ärgerlich",
    "ärgerlicheres": "ärgerlich",
    "ärgerliches": "ärgerlich",
    "ärgerlichste": "ärgerlich",
    "ärgerlichstem": "ärgerlich",
    "ärgerlichsten": "ärgerlich",
    "ärgerlichster": "ärgerlich",
    "ärgerlichstes": "ärgerlich",
    "ärgernd": "ärgern",
    "ärgernde": "ärgernd",
    "ärgerndem": "ärgernd",
    "ärgernden": "ärgernd",
    "ärgernder": "ärgernd",
    "ärgerndes": "ärgernd",
    "ärgerst": "ärgern",
    "ärgert": "ärgern",
    "ärgerte": "ärgern",
    "ärgerten": "ärgern",
    "ärgertest": "ärgern",
    "ärgertet": "ärgern",
    "ärmellose": "ärmellos",
    "ärmellosem": "ärmellos",
    "ärmellosen": "ärmellos",
    "ärmelloser": "ärmellos",
    "ärmelloses": "ärmellos",
    "ärmer": "arm",
    "ärmere": "arm",
    "ärmerem": "arm",
    "ärmeren": "arm",
    "ärmerer": "arm",
    "ärmeres": "arm",
    "ärmliche": "ärmlich",
    "ärmlichem": "ärmlich",
    "ärmlichen": "ärmlich",
    "ärmlicher": "ärmlich",
    "ärmlichere": "ärmlich",
    "ärmlicherem": "ärmlich",
    "ärmlicheren": "ärmlich",
    "ärmlicherer": "ärmlich",
    "ärmlicheres": "ärmlich",
    "ärmliches": "ärmlich",
    "ärmlichste": "ärmlich",
    "ärmlichstem": "ärmlich",
    "ärmlichsten": "ärmlich",
    "ärmlichster": "ärmlich",
    "ärmlichstes": "ärmlich",
    "ärmste": "arm",
    "ärmstem": "arm",
    "ärmsten": "arm",
    "ärmster": "arm",
    "ärmstes": "arm",
    "ärztliche": "ärztlich",
    "ärztlichem": "ärztlich",
    "ärztlichen": "ärztlich",
    "ärztlicher": "ärztlich",
    "ärztliches": "ärztlich",
    "äschere": "äschern",
    "äschernd": "äschern",
    "äschernde": "äschernd",
    "äscherndem": "äschernd",
    "äschernden": "äschernd",
    "äschernder": "äschernd",
    "äscherndes": "äschernd",
    "äscherst": "äschern",
    "äschert": "äschern",
    "äscherte": "äschern",
    "äscherten": "äschern",
    "äschertest": "äschern",
    "äschertet": "äschern",
    "ästend": "ästen",
    "ästende": "ästend",
    "ästendem": "ästend",
    "ästenden": "ästend",
    "ästender": "ästend",
    "ästendes": "ästend",
    "ästest": "ästen",
    "ästet": "ästen",
    "ästete": "ästen",
    "ästeten": "ästen",
    "ästetest": "ästen",
    "ästetet": "ästen",
    "ästhetische": "ästhetisch",
    "ästhetischem": "ästhetisch",
    "ästhetischen": "ästhetisch",
    "ästhetischer": "ästhetisch",
    "ästhetischere": "ästhetisch",
    "ästhetischerem": "ästhetisch",
    "ästhetischeren": "ästhetisch",
    "ästhetischerer": "ästhetisch",
    "ästhetischeres": "ästhetisch",
    "ästhetisches": "ästhetisch",
    "ästhetischste": "ästhetisch",
    "ästhetischstem": "ästhetisch",
    "ästhetischsten": "ästhetisch",
    "ästhetischster": "ästhetisch",
    "ästhetischstes": "ästhetisch",
    "ätherische": "ätherisch",
    "ätherischem": "ätherisch",
    "ätherischen": "ätherisch",
    "ätherischer": "ätherisch",
    "ätherisches": "ätherisch",
    "ätze": "ätzen",
    "ätzend": "ätzen",
    "ätzende": "ätzend",
    "ätzendem": "ätzend",
    "ätzenden": "ätzend",
    "ätzender": "ätzend",
    "ätzendere": "ätzend",
    "ätzenderem": "ätzend",
    "ätzenderen": "ätzend",
    "ätzenderer": "ätzend",
    "ätzenderes": "ätzend",
    "ätzendes": "ätzend",
    "ätzendste": "ätzend",
    "ätzendstem": "ätzend",
    "ätzendsten": "ätzend",
    "ätzendster": "ätzend",
    "ätzendstes": "ätzend",
    "ätzest": "ätzen",
    "ätzet": "ätzen",
    "ätzt": "ätzen",
    "ätzte": "ätzen",
    "ätzten": "ätzen",
    "ätztest": "ätzen",
    "ätztet": "ätzen",
    "äußer": "äußern",
    "äußere": "äußern",
    "äußerem": "äußer",
    "äußeren": "äußer",
    "äußerer": "äußer",
    "äußerere": "äußer",
    "äußererem": "äußer",
    "äußereren": "äußer",
    "äußererer": "äußer",
    "äußereres": "äußer",
    "äußeres": "äußer",
    "äußerliche": "äußerlich",
    "äußerlichem": "äußerlich",
    "äußerlichen": "äußerlich",
    "äußerlicher": "äußerlich",
    "äußerliches": "äußerlich",
    "äußernd": "äußern",
    "äußernde": "äußernd",
    "äußerndem": "äußernd",
    "äußernden": "äußernd",
    "äußernder": "äußernd",
    "äußerndes": "äußernd",
    "äußerst": "äußern",
    "äußerste": "äußer",
    "äußerstem": "äußer",
    "äußersten": "äußer",
    "äußerster": "äußer",
    "äußerstes": "äußer",
    "äußert": "äußern",
    "äußerte": "äußern",
    "äußerten": "äußern",
    "äußertest": "äußern",
    "äußertet": "äußern",
    "äße": "essen",
    "äßen": "essen",
    "äßest": "essen",
    "äßet": "essen",
    "öde": "öden",
    "ödend": "öden",
    "ödende": "ödend",
    "ödendem": "ödend",
    "ödenden": "ödend",
    "ödender": "ödend",
    "ödendere": "ödend",
    "ödenderem": "ödend",
    "ödenderen": "ödend",
    "ödenderer": "ödend",
    "ödenderes": "ödend",
    "ödendes": "ödend",
    "ödendste": "ödend",
    "ödendstem": "ödend",
    "ödendsten": "ödend",
    "ödendster": "ödend",
    "ödendstes": "ödend",
    "ödest": "öden",
    "ödet": "öden",
    "ödete": "öden",
    "ödeten": "öden",
    "ödetest": "öden",
    "ödetet": "öden",
    "ödipale": "ödipal",
    "ödipalem": "ödipal",
    "ödipalen": "ödipal",
    "ödipaler": "ödipal",
    "ödipales": "ödipal",
    "öffentliche": "öffentlich",
    "öffentlichem": "öffentlich",
    "öffentlichen": "öffentlich",
    "öffentlicher": "öffentlich",
    "öffentlichere": "öffentlich",
    "öffentlicherem": "öffentlich",
    "öffentlicheren": "öffentlich",
    "öffentlicherer": "öffentlich",
    "öffentlicheres": "öffentlich",
    "öffentliches": "öffentlich",
    "öffentlichste": "öffentlich",
    "öffentlichstem": "öffentlich",
    "öffentlichsten": "öffentlich",
    "öffentlichster": "öffentlich",
    "öffentlichstes": "öffentlich",
    "öffne": "öffnen",
    "öffnend": "öffnen",
    "öffnende": "öffnend",
    "öffnendem": "öffnend",
    "öffnenden": "öffnend",
    "öffnender": "öffnend",
    "öffnendere": "öffnend",
    "öffnenderem": "öffnend",
    "öffnenderen": "öffnend",
    "öffnenderer": "öffnend",
    "öffnenderes": "öffnend",
    "öffnendes": "öffnend",
    "öffnendste": "öffnend",
    "öffnendstem": "öffnend",
    "öffnendsten": "öffnend",
    "öffnendster": "öffnend",
    "öffnendstes": "öffnend",
    "öffnest": "öffnen",
    "öffnet": "öffnen",
    "öffnete": "öffnen",
    "öffneten": "öffnen",
    "öffnetest": "öffnen",
    "öffnetet": "öffnen",
    "ökologische": "ökologisch",
    "ökologischem": "ökologisch",
    "ökologischen": "ökologisch",
    "ökologischer": "ökologisch",
    "ökologisches": "ökologisch",
    "ökonomische": "ökonomisch",
    "ökonomischem": "ökonomisch",
    "ökonomischen": "ökonomisch",
    "ökonomischer": "ökonomisch",
    "ökonomischere": "ökonomisch",
    "ökonomischerem": "ökonomisch",
    "ökonomischeren": "ökonomisch",
    "ökonomischerer": "ökonomisch",
    "ökonomischeres": "ökonomisch",
    "ökonomisches": "ökonomisch",
    "ökonomischste": "ökonomisch",
    "ökonomischstem": "ökonomisch",
    "ökonomischsten": "ökonomisch",
    "ökonomischster": "ökonomisch",
    "ökonomischstes": "ökonomisch",
    "ökumenische": "ökumenisch",
    "ökumenischem": "ökumenisch",
    "ökumenischen": "ökumenisch",
    "ökumenischer": "ökumenisch",
    "ökumenisches": "ökumenisch",
    "ölend": "ölen",
    "ölende": "ölend",
    "ölendem": "ölend",
    "ölenden": "ölend",
    "ölender": "ölend",
    "ölendes": "ölend",
    "ölest": "ölen",
    "ölet": "ölen",
    "ölige": "ölig",
    "öligem": "ölig",
    "öligen": "ölig",
    "öliger": "ölig",
    "öligere": "ölig",
    "öligerem": "ölig",
    "öligeren": "ölig",
    "öligerer": "ölig",
    "öligeres": "ölig",
    "öliges": "ölig",
    "öligste": "ölig",
    "öligstem": "ölig",
    "öligsten": "ölig",
    "öligster": "ölig",
    "öligstes": "ölig",
    "ölst": "ölen",
    "ölt": "ölen",
    "ölte": "ölen",
    "ölten": "ölen",
    "öltest": "ölen",
    "öltet": "ölen",
    "örtliche": "örtlich",
    "örtlichem": "örtlich",
    "örtlichen": "örtlich",
    "örtlicher": "örtlich",
    "örtliches": "örtlich",
    "österliche": "österlich",
    "österlichem": "österlich",
    "österlichen": "österlich",
    "österlicher": "österlich",
    "österlichere": "österlich",
    "österlicherem": "österlich",
    "österlicheren": "österlich",
    "österlicherer": "österlich",
    "österlicheres": "österlich",
    "österliches": "österlich",
    "österlichste": "österlich",
    "österlichstem": "österlich",
    "österlichsten": "österlich",
    "österlichster": "österlich",
    "österlichstes": "österlich",
    "österreichische": "österreichisch",
    "österreichischem": "österreichisch",
    "österreichischen": "österreichisch",
    "österreichischer": "österreichisch",
    "österreichisches": "österreichisch",
    "östliche": "östlich",
    "östlichem": "östlich",
    "östlichen": "östlich",
    "östlicher": "östlich",
    "östlichere": "östlich",
    "östlicherem": "östlich",
    "östlicheren": "östlich",
    "östlicherer": "östlich",
    "östlicheres": "östlich",
    "östliches": "östlich",
    "östlichste": "östlich",
    "östlichstem": "östlich",
    "östlichsten": "östlich",
    "östlichster": "östlich",
    "östlichstes": "östlich",
    "übe": "üben",
    "übelgenommen": "übelnehmen",
    "übelgenommene": "übelgenommen",
    "übelgenommenem": "übelgenommen",
    "übelgenommenen": "übelgenommen",
    "übelgenommener": "übelgenommen",
    "übelgenommenes": "übelgenommen",
    "übellaunige": "übellaunig",
    "übellaunigem": "übellaunig",
    "übellaunigen": "übellaunig",
    "übellauniger": "übellaunig",
    "übellauniges": "übellaunig",
    "übelnahm": "übelnehmen",
    "übelnahmen": "übelnehmen",
    "übelnahmst": "übelnehmen",
    "übelnahmt": "übelnehmen",
    "übelnehme": "übelnehmen",
    "übelnehmend": "übelnehmen",
    "übelnehmende": "übelnehmend",
    "übelnehmendem": "übelnehmend",
    "übelnehmenden": "übelnehmend",
    "übelnehmender": "übelnehmend",
    "übelnehmendes": "übelnehmend",
    "übelnehmest": "übelnehmen",
    "übelnehmet": "übelnehmen",
    "übelnehmt": "übelnehmen",
    "übelnimmst": "übelnehmen",
    "übelnimmt": "übelnehmen",
    "übelnähme": "übelnehmen",
    "übelnähmen": "übelnehmen",
    "übelnähmest": "übelnehmen",
    "übelnähmet": "übelnehmen",
    "übelriechende": "übelriechend",
    "übelriechendem": "übelriechend",
    "übelriechenden": "übelriechend",
    "übelriechender": "übelriechend",
    "übelriechendes": "übelriechend",
    "übelste": "übel",
    "übelstem": "übel",
    "übelsten": "übel",
    "übelster": "übel",
    "übelstes": "übel",
    "übelzunehmen": "übelnehmen",
    "übend": "üben",
    "übende": "übend",
    "übendem": "übend",
    "übenden": "übend",
    "übender": "übend",
    "übendes": "übend",
    "überalterte": "überaltert",
    "überaltertem": "überaltert",
    "überalterten": "überaltert",
    "überalterter": "überaltert",
    "überaltertere": "überaltert",
    "überalterterem": "überaltert",
    "überalterteren": "überaltert",
    "überalterterer": "überaltert",
    "überalterteres": "überaltert",
    "überaltertes": "überaltert",
    "überalterteste": "überaltert",
    "überaltertestem": "überaltert",
    "überaltertesten": "überaltert",
    "überaltertester": "überaltert",
    "überaltertestes": "überaltert",
    "überanstrenge": "überanstrengen",
    "überanstrengend": "überanstrengen",
    "überanstrengende": "überanstrengend",
    "überanstrengendem": "überanstrengend",
    "überanstrengenden": "überanstrengend",
    "überanstrengender": "überanstrengend",
    "überanstrengendere": "überanstrengend",
    "überanstrengenderem": "überanstrengend",
    "überanstrengenderen": "überanstrengend",
    "überanstrengenderer": "überanstrengend",
    "überanstrengenderes": "überanstrengend",
    "überanstrengendes": "überanstrengend",
    "überanstrengendste": "überanstrengend",
    "überanstrengendstem": "überanstrengend",
    "überanstrengendsten": "überanstrengend",
    "überanstrengendster": "überanstrengend",
    "überanstrengendstes": "überanstrengend",
    "überanstrengest": "überanstrengen",
    "überanstrenget": "überanstrengen",
    "überanstrengst": "überanstrengen",
    "überanstrengt": "überanstrengen",
    "überanstrengte": "überanstrengt",
    "überanstrengtem": "überanstrengt",
    "überanstrengten": "überanstrengt",
    "überanstrengter": "überanstrengt",
    "überanstrengtere": "überanstrengt",
    "überanstrengterem": "überanstrengt",
    "überanstrengteren": "überanstrengt",
    "überanstrengterer": "überanstrengt",
    "überanstrengteres": "überanstrengt",
    "überanstrengtes": "überanstrengt",
    "überanstrengtest": "überanstrengen",
    "überanstrengteste": "überanstrengt",
    "überanstrengtestem": "überanstrengt",
    "überanstrengtesten": "überanstrengt",
    "überanstrengtester": "überanstrengt",
    "überanstrengtestes": "überanstrengt",
    "überanstrengtet": "überanstrengen",
    "überarbeite": "überarbeiten",
    "überarbeitend": "überarbeiten",
    "überarbeitende": "überarbeitend",
    "überarbeitendem": "überarbeitend",
    "überarbeitenden": "überarbeitend",
    "überarbeitender": "überarbeitend",
    "überarbeitendes": "überarbeitend",
    "überarbeitest": "überarbeiten",
    "überarbeitet": "überarbeiten",
    "überarbeitete": "überarbeitet",
    "überarbeitetem": "überarbeitet",
    "überarbeiteten": "überarbeitet",
    "überarbeiteter": "überarbeitet",
    "überarbeitetere": "überarbeitet",
    "überarbeiteterem": "überarbeitet",
    "überarbeiteteren": "überarbeitet",
    "überarbeiteterer": "überarbeitet",
    "überarbeiteteres": "überarbeitet",
    "überarbeitetes": "überarbeitet",
    "überarbeitetest": "überarbeiten",
    "überarbeiteteste": "überarbeitet",
    "überarbeitetestem": "überarbeitet",
    "überarbeitetesten": "überarbeitet",
    "überarbeitetester": "überarbeitet",
    "überarbeitetestes": "überarbeitet",
    "überarbeitetet": "überarbeiten",
    "überaß": "überessen",
    "überaßen": "überessen",
    "überaßt": "überessen",
    "überbaue": "überbauen",
    "überbauend": "überbauen",
    "überbauende": "überbauend",
    "überbauendem": "überbauend",
    "überbauenden": "überbauend",
    "überbauender": "überbauend",
    "überbauendes": "überbauend",
    "überbauest": "überbauen",
    "überbauet": "überbauen",
    "überbaust": "überbauen",
    "überbaut": "überbauen",
    "überbaute": "überbauen",
    "überbauten": "überbauen",
    "überbautest": "überbauen",
    "überbautet": "überbauen",
    "überbeanspruche": "überbeanspruchen",
    "überbeanspruchend": "überbeanspruchen",
    "überbeanspruchende": "überbeanspruchend",
    "überbeanspruchendem": "überbeanspruchend",
    "überbeanspruchenden": "überbeanspruchend",
    "überbeanspruchender": "überbeanspruchend",
    "überbeanspruchendere": "überbeanspruchend",
    "überbeanspruchenderem": "überbeanspruchend",
    "überbeanspruchenderen": "überbeanspruchend",
    "überbeanspruchenderer": "überbeanspruchend",
    "überbeanspruchenderes": "überbeanspruchend",
    "überbeanspruchendes": "überbeanspruchend",
    "überbeanspruchendste": "überbeanspruchend",
    "überbeanspruchendstem": "überbeanspruchend",
    "überbeanspruchendsten": "überbeanspruchend",
    "überbeanspruchendster": "überbeanspruchend",
    "überbeanspruchendstes": "überbeanspruchend",
    "überbeanspruchest": "überbeanspruchen",
    "überbeanspruchet": "überbeanspruchen",
    "überbeanspruchst": "überbeanspruchen",
    "überbeansprucht": "überbeanspruchen",
    "überbeanspruchte": "überbeansprucht",
    "überbeanspruchtem": "überbeansprucht",
    "überbeanspruchten": "überbeansprucht",
    "überbeanspruchter": "überbeansprucht",
    "überbeanspruchtere": "überbeansprucht",
    "überbeanspruchterem": "überbeansprucht",
    "überbeanspruchteren": "überbeansprucht",
    "überbeanspruchterer": "überbeansprucht",
    "überbeanspruchteres": "überbeansprucht",
    "überbeanspruchtes": "überbeansprucht",
    "überbeanspruchtest": "überbeanspruchen",
    "überbeanspruchteste": "überbeansprucht",
    "überbeanspruchtestem": "überbeansprucht",
    "überbeanspruchtesten": "überbeansprucht",
    "überbeanspruchtester": "überbeansprucht",
    "überbeanspruchtestes": "überbeansprucht",
    "überbeanspruchtet": "überbeanspruchen",
    "überbehalte": "überbehalten",
    "überbehaltend": "überbehalten",
    "überbehaltende": "überbehaltend",
    "überbehaltendem": "überbehaltend",
    "überbehaltenden": "überbehaltend",
    "überbehaltender": "überbehaltend",
    "überbehaltendes": "überbehaltend",
    "überbehaltene": "überbehalten",
    "überbehaltenem": "überbehalten",
    "überbehaltenen": "überbehalten",
    "überbehaltener": "überbehalten",
    "überbehaltenes": "überbehalten",
    "überbehaltest": "überbehalten",
    "überbehaltet": "überbehalten",
    "überbehielt": "überbehalten",
    "überbehielte": "überbehalten",
    "überbehielten": "überbehalten",
    "überbehieltest": "überbehalten",
    "überbehieltet": "überbehalten",
    "überbehält": "überbehalten",
    "überbehältst": "überbehalten",
    "überbekam": "überbekommen",
    "überbekamen": "überbekommen",
    "überbekamst": "überbekommen",
    "überbekamt": "überbekommen",
    "überbekomme": "überbekommen",
    "überbekommend": "überbekommen",
    "überbekommende": "überbekommend",
    "überbekommendem": "überbekommend",
    "überbekommenden": "überbekommend",
    "überbekommender": "überbekommend",
    "überbekommendes": "überbekommend",
    "überbekommene": "überbekommen",
    "überbekommenem": "überbekommen",
    "überbekommenen": "überbekommen",
    "überbekommener": "überbekommen",
    "überbekommenes": "überbekommen",
    "überbekommest": "überbekommen",
    "überbekommet": "überbekommen",
    "überbekommst": "überbekommen",
    "überbekommt": "überbekommen",
    "überbekäme": "überbekommen",
    "überbekämen": "überbekommen",
    "überbekämest": "überbekommen",
    "überbekämet": "überbekommen",
    "überbelichte": "überbelichten",
    "überbelichtend": "überbelichten",
    "überbelichtende": "überbelichtend",
    "überbelichtendem": "überbelichtend",
    "überbelichtenden": "überbelichtend",
    "überbelichtender": "überbelichtend",
    "überbelichtendere": "überbelichtend",
    "überbelichtenderem": "überbelichtend",
    "überbelichtenderen": "überbelichtend",
    "überbelichtenderer": "überbelichtend",
    "überbelichtenderes": "überbelichtend",
    "überbelichtendes": "überbelichtend",
    "überbelichtendste": "überbelichtend",
    "überbelichtendstem": "überbelichtend",
    "überbelichtendsten": "überbelichtend",
    "überbelichtendster": "überbelichtend",
    "überbelichtendstes": "überbelichtend",
    "überbelichtest": "überbelichten",
    "überbelichtet": "überbelichten",
    "überbelichtete": "überbelichtet",
    "überbelichtetem": "überbelichtet",
    "überbelichteten": "überbelichtet",
    "überbelichteter": "überbelichtet",
    "überbelichtetere": "überbelichtet",
    "überbelichteterem": "überbelichtet",
    "überbelichteteren": "überbelichtet",
    "überbelichteterer": "überbelichtet",
    "überbelichteteres": "überbelichtet",
    "überbelichtetes": "überbelichtet",
    "überbelichtetest": "überbelichten",
    "überbelichteteste": "überbelichtet",
    "überbelichtetestem": "überbelichtet",
    "überbelichtetesten": "überbelichtet",
    "überbelichtetester": "überbelichtet",
    "überbelichtetestes": "überbelichtet",
    "überbelichtetet": "überbelichten",
    "überbetone": "überbetonen",
    "überbetonend": "überbetonen",
    "überbetonende": "überbetonend",
    "überbetonendem": "überbetonend",
    "überbetonenden": "überbetonend",
    "überbetonender": "überbetonend",
    "überbetonendere": "überbetonend",
    "überbetonenderem": "überbetonend",
    "überbetonenderen": "überbetonend",
    "überbetonenderer": "überbetonend",
    "überbetonenderes": "überbetonend",
    "überbetonendes": "überbetonend",
    "überbetonendste": "überbetonend",
    "überbetonendstem": "überbetonend",
    "überbetonendsten": "überbetonend",
    "überbetonendster": "überbetonend",
    "überbetonendstes": "überbetonend",
    "überbetonest": "überbetonen",
    "überbetonet": "überbetonen",
    "überbetonst": "überbetonen",
    "überbetont": "überbetonen",
    "überbetonte": "überbetont",
    "überbetontem": "überbetont",
    "überbetonten": "überbetont",
    "überbetonter": "überbetont",
    "überbetontere": "überbetont",
    "überbetonterem": "überbetont",
    "überbetonteren": "überbetont",
    "überbetonterer": "überbetont",
    "überbetonteres": "überbetont",
    "überbetontes": "überbetont",
    "überbetontest": "überbetonen",
    "überbetonteste": "überbetont",
    "überbetontestem": "überbetont",
    "überbetontesten": "überbetont",
    "überbetontester": "überbetont",
    "überbetontestes": "überbetont",
    "überbetontet": "überbetonen",
    "überbewerte": "überbewerten",
    "überbewertend": "überbewerten",
    "überbewertende": "überbewertend",
    "überbewertendem": "überbewertend",
    "überbewertenden": "überbewertend",
    "überbewertender": "überbewertend",
    "überbewertendere": "überbewertend",
    "überbewertenderem": "überbewertend",
    "überbewertenderen": "überbewertend",
    "überbewertenderer": "überbewertend",
    "überbewertenderes": "überbewertend",
    "überbewertendes": "überbewertend",
    "überbewertendste": "überbewertend",
    "überbewertendstem": "überbewertend",
    "überbewertendsten": "überbewertend",
    "überbewertendster": "überbewertend",
    "überbewertendstes": "überbewertend",
    "überbewertest": "überbewerten",
    "überbewertet": "überbewerten",
    "überbewertete": "überbewertet",
    "überbewertetem": "überbewertet",
    "überbewerteten": "überbewertet",
    "überbewerteter": "überbewertet",
    "überbewertetere": "überbewertet",
    "überbewerteterem": "überbewertet",
    "überbewerteteren": "überbewertet",
    "überbewerteterer": "überbewertet",
    "überbewerteteres": "überbewertet",
    "überbewertetes": "überbewertet",
    "überbewertetest": "überbewerten",
    "überbewerteteste": "überbewertet",
    "überbewertetestem": "überbewertet",
    "überbewertetesten": "überbewertet",
    "überbewertetester": "überbewertet",
    "überbewertetestes": "überbewertet",
    "überbewertetet": "überbewerten",
    "überbiete": "überbieten",
    "überbietend": "überbieten",
    "überbietende": "überbietend",
    "überbietendem": "überbietend",
    "überbietenden": "überbietend",
    "überbietender": "überbietend",
    "überbietendes": "überbietend",
    "überbietest": "überbieten",
    "überbietet": "überbieten",
    "überbot": "überbieten",
    "überboten": "überbieten",
    "überbotene": "überboten",
    "überbotenem": "überboten",
    "überbotenen": "überboten",
    "überbotener": "überboten",
    "überbotenes": "überboten",
    "überbotest": "überbieten",
    "überbotet": "überbieten",
    "überbracht": "überbringen",
    "überbrachte": "überbringen",
    "überbrachtem": "überbracht",
    "überbrachten": "überbringen",
    "überbrachter": "überbracht",
    "überbrachtes": "überbracht",
    "überbrachtest": "überbringen",
    "überbrachtet": "überbringen",
    "überbrate": "überbraten",
    "überbratend": "überbraten",
    "überbratende": "überbratend",
    "überbratendem": "überbratend",
    "überbratenden": "überbratend",
    "überbratender": "überbratend",
    "überbratendes": "überbratend",
    "überbratest": "überbraten",
    "überbratet": "überbraten",
    "überbriet": "überbraten",
    "überbriete": "überbraten",
    "überbrieten": "überbraten",
    "überbrietest": "überbraten",
    "überbrietet": "überbraten",
    "überbringe": "überbringen",
    "überbringend": "überbringen",
    "überbringende": "überbringend",
    "überbringendem": "überbringend",
    "überbringenden": "überbringend",
    "überbringender": "überbringend",
    "überbringendes": "überbringend",
    "überbringest": "überbringen",
    "überbringet": "überbringen",
    "überbringst": "überbringen",
    "überbringt": "überbringen",
    "überbrächte": "überbringen",
    "überbrächten": "überbringen",
    "überbrächtest": "überbringen",
    "überbrächtet": "überbringen",
    "überbrät": "überbraten",
    "überbrätst": "überbraten",
    "überbrücke": "überbrücken",
    "überbrückend": "überbrücken",
    "überbrückende": "überbrückend",
    "überbrückendem": "überbrückend",
    "überbrückenden": "überbrückend",
    "überbrückender": "überbrückend",
    "überbrückendes": "überbrückend",
    "überbrückest": "überbrücken",
    "überbrücket": "überbrücken",
    "überbrückst": "überbrücken",
    "überbrückt": "überbrücken",
    "überbrückte": "überbrückt",
    "überbrücktem": "überbrückt",
    "überbrückten": "überbrückt",
    "überbrückter": "überbrückt",
    "überbrücktes": "überbrückt",
    "überbrücktest": "überbrücken",
    "überbrücktet": "überbrücken",
    "überböte": "überbieten",
    "überböten": "überbieten",
    "überbötest": "überbieten",
    "überbötet": "überbieten",
    "überdache": "überdachen",
    "überdachend": "überdachen",
    "überdachende": "überdachend",
    "überdachendem": "überdachend",
    "überdachenden": "überdachend",
    "überdachender": "überdachend",
    "überdachendes": "überdachend",
    "überdachest": "überdachen",
    "überdachet": "überdachen",
    "überdachst": "überdachen",
    "überdacht": "überdachen",
    "überdachte": "überdenken",
    "überdachtem": "überdacht",
    "überdachten": "überdenken",
    "überdachter": "überdacht",
    "überdachtes": "überdacht",
    "überdachtest": "überdenken",
    "überdachtet": "überdenken",
    "überdauere": "überdauern",
    "überdauernd": "überdauern",
    "überdauernde": "überdauernd",
    "überdauerndem": "überdauernd",
    "überdauernden": "überdauernd",
    "überdauernder": "überdauernd",
    "überdauerndes": "überdauernd",
    "überdauerst": "überdauern",
    "überdauert": "überdauern",
    "überdauerte": "überdauert",
    "überdauertem": "überdauert",
    "überdauerten": "überdauert",
    "überdauerter": "überdauert",
    "überdauertes": "überdauert",
    "überdauertest": "überdauern",
    "überdauertet": "überdauern",
    "überdehne": "überdehnen",
    "überdehnend": "überdehnen",
    "überdehnende": "überdehnend",
    "überdehnendem": "überdehnend",
    "überdehnenden": "überdehnend",
    "überdehnender": "überdehnend",
    "überdehnendere": "überdehnend",
    "überdehnenderem": "überdehnend",
    "überdehnenderen": "überdehnend",
    "überdehnenderer": "überdehnend",
    "überdehnenderes": "überdehnend",
    "überdehnendes": "überdehnend",
    "überdehnendste": "überdehnend",
    "überdehnendstem": "überdehnend",
    "überdehnendsten": "überdehnend",
    "überdehnendster": "überdehnend",
    "überdehnendstes": "überdehnend",
    "überdehnest": "überdehnen",
    "überdehnet": "überdehnen",
    "überdehnst": "überdehnen",
    "überdehnt": "überdehnen",
    "überdehnte": "überdehnt",
    "überdehntem": "überdehnt",
    "überdehnten": "überdehnt",
    "überdehnter": "überdehnt",
    "überdehntere": "überdehnt",
    "überdehnterem": "überdehnt",
    "überdehnteren": "überdehnt",
    "überdehnterer": "überdehnt",
    "überdehnteres": "überdehnt",
    "überdehntes": "überdehnt",
    "überdehntest": "überdehnen",
    "überdehnteste": "überdehnt",
    "überdehntestem": "überdehnt",
    "überdehntesten": "überdehnt",
    "überdehntester": "überdehnt",
    "überdehntestes": "überdehnt",
    "überdehntet": "überdehnen",
    "überdenke": "überdenken",
    "überdenkend": "überdenken",
    "überdenkende": "überdenkend",
    "überdenkendem": "überdenkend",
    "überdenkenden": "überdenkend",
    "überdenkender": "überdenkend",
    "überdenkendere": "überdenkend",
    "überdenkenderem": "überdenkend",
    "überdenkenderen": "überdenkend",
    "überdenkenderer": "überdenkend",
    "überdenkenderes": "überdenkend",
    "überdenkendes": "überdenkend",
    "überdenkendste": "überdenkend",
    "überdenkendstem": "überdenkend",
    "überdenkendsten": "überdenkend",
    "überdenkendster": "überdenkend",
    "überdenkendstes": "überdenkend",
    "überdenkest": "überdenken",
    "überdenket": "überdenken",
    "überdenkst": "überdenken",
    "überdenkt": "überdenken",
    "überdeutliche": "überdeutlich",
    "überdeutlichem": "überdeutlich",
    "überdeutlichen": "überdeutlich",
    "überdeutlicher": "überdeutlich",
    "überdeutliches": "überdeutlich",
    "überdimensionale": "überdimensional",
    "überdimensionalem": "überdimensional",
    "überdimensionalen": "überdimensional",
    "überdimensionaler": "überdimensional",
    "überdimensionales": "überdimensional",
    "überdimensionierte": "überdimensioniert",
    "überdimensioniertem": "überdimensioniert",
    "überdimensionierten": "überdimensioniert",
    "überdimensionierter": "überdimensioniert",
    "überdimensioniertes": "überdimensioniert",
    "überdosiere": "überdosieren",
    "überdosierend": "überdosieren",
    "überdosierende": "überdosierend",
    "überdosierendem": "überdosierend",
    "überdosierenden": "überdosierend",
    "überdosierender": "überdosierend",
    "überdosierendere": "überdosierend",
    "überdosierenderem": "überdosierend",
    "überdosierenderen": "überdosierend",
    "überdosierenderer": "überdosierend",
    "überdosierenderes": "überdosierend",
    "überdosierendes": "überdosierend",
    "überdosierendste": "überdosierend",
    "überdosierendstem": "überdosierend",
    "überdosierendsten": "überdosierend",
    "überdosierendster": "überdosierend",
    "überdosierendstes": "überdosierend",
    "überdosierest": "überdosieren",
    "überdosieret": "überdosieren",
    "überdosierst": "überdosieren",
    "überdosiert": "überdosieren",
    "überdosierte": "überdosiert",
    "überdosiertem": "überdosiert",
    "überdosierten": "überdosiert",
    "überdosierter": "überdosiert",
    "überdosiertere": "überdosiert",
    "überdosierterem": "überdosiert",
    "überdosierteren": "überdosiert",
    "überdosierterer": "überdosiert",
    "überdosierteres": "überdosiert",
    "überdosiertes": "überdosiert",
    "überdosiertest": "überdosieren",
    "überdosierteste": "überdosiert",
    "überdosiertestem": "überdosiert",
    "überdosiertesten": "überdosiert",
    "überdosiertester": "überdosiert",
    "überdosiertestes": "überdosiert",
    "überdosiertet": "überdosieren",
    "überdrehe": "überdrehen",
    "überdrehend": "überdrehen",
    "überdrehende": "überdrehend",
    "überdrehendem": "überdrehend",
    "überdrehenden": "überdrehend",
    "überdrehender": "überdrehend",
    "überdrehendere": "überdrehend",
    "überdrehenderem": "überdrehend",
    "überdrehenderen": "überdrehend",
    "überdrehenderer": "überdrehend",
    "überdrehenderes": "überdrehend",
    "überdrehendes": "überdrehend",
    "überdrehendste": "überdrehend",
    "überdrehendstem": "überdrehend",
    "überdrehendsten": "überdrehend",
    "überdrehendster": "überdrehend",
    "überdrehendstes": "überdrehend",
    "überdrehest": "überdrehen",
    "überdrehet": "überdrehen",
    "überdrehst": "überdrehen",
    "überdreht": "überdrehen",
    "überdrehte": "überdreht",
    "überdrehtem": "überdreht",
    "überdrehten": "überdreht",
    "überdrehter": "überdreht",
    "überdrehtere": "überdreht",
    "überdrehterem": "überdreht",
    "überdrehteren": "überdreht",
    "überdrehterer": "überdreht",
    "überdrehteres": "überdreht",
    "überdrehtes": "überdreht",
    "überdrehtest": "überdrehen",
    "überdrehteste": "überdreht",
    "überdrehtestem": "überdreht",
    "überdrehtesten": "überdreht",
    "überdrehtester": "überdreht",
    "überdrehtestes": "überdreht",
    "überdrehtet": "überdrehen",
    "überdrüssige": "überdrüssig",
    "überdrüssigem": "überdrüssig",
    "überdrüssigen": "überdrüssig",
    "überdrüssiger": "überdrüssig",
    "überdrüssigere": "überdrüssig",
    "überdrüssigerem": "überdrüssig",
    "überdrüssigeren": "überdrüssig",
    "überdrüssigerer": "überdrüssig",
    "überdrüssigeres": "überdrüssig",
    "überdrüssiges": "überdrüssig",
    "überdrüssigste": "überdrüssig",
    "überdrüssigstem": "überdrüssig",
    "überdrüssigsten": "überdrüssig",
    "überdrüssigster": "überdrüssig",
    "überdrüssigstes": "überdrüssig",
    "überdurchschnittliche": "überdurchschnittlich",
    "überdurchschnittlichem": "überdurchschnittlich",
    "überdurchschnittlichen": "überdurchschnittlich",
    "überdurchschnittlicher": "überdurchschnittlich",
    "überdurchschnittliches": "überdurchschnittlich",
    "überdächte": "überdenken",
    "überdächten": "überdenken",
    "überdächtest": "überdenken",
    "überdächtet": "überdenken",
    "übereifrige": "übereifrig",
    "übereifrigem": "übereifrig",
    "übereifrigen": "übereifrig",
    "übereifriger": "übereifrig",
    "übereifrigere": "übereifrig",
    "übereifrigerem": "übereifrig",
    "übereifrigeren": "übereifrig",
    "übereifrigerer": "übereifrig",
    "übereifrigeres": "übereifrig",
    "übereifriges": "übereifrig",
    "übereifrigste": "übereifrig",
    "übereifrigstem": "übereifrig",
    "übereifrigsten": "übereifrig",
    "übereifrigster": "übereifrig",
    "übereifrigstes": "übereifrig",
    "übereigne": "übereignen",
    "übereignend": "übereignen",
    "übereignende": "übereignend",
    "übereignendem": "übereignend",
    "übereignenden": "übereignend",
    "übereignender": "übereignend",
    "übereignendes": "übereignend",
    "übereignest": "übereignen",
    "übereignet": "übereignen",
    "übereignete": "übereignet",
    "übereignetem": "übereignet",
    "übereigneten": "übereignet",
    "übereigneter": "übereignet",
    "übereignetes": "übereignet",
    "übereignetest": "übereignen",
    "übereignetet": "übereignen",
    "übereingekommen": "übereinkommen",
    "übereingekommene": "übereingekommen",
    "übereingekommenem": "übereingekommen",
    "übereingekommenen": "übereingekommen",
    "übereingekommener": "übereingekommen",
    "übereingekommenes": "übereingekommen",
    "übereingestimmt": "übereinstimmen",
    "übereingestimmte": "übereingestimmt",
    "übereingestimmtem": "übereingestimmt",
    "übereingestimmten": "übereingestimmt",
    "übereingestimmter": "übereingestimmt",
    "übereingestimmtes": "übereingestimmt",
    "übereinkam": "übereinkommen",
    "übereinkamen": "übereinkommen",
    "übereinkamst": "übereinkommen",
    "übereinkamt": "übereinkommen",
    "übereinkomme": "übereinkommen",
    "übereinkommend": "übereinkommen",
    "übereinkommende": "übereinkommend",
    "übereinkommendem": "übereinkommend",
    "übereinkommenden": "übereinkommend",
    "übereinkommender": "übereinkommend",
    "übereinkommendes": "übereinkommend",
    "übereinkommest": "übereinkommen",
    "übereinkommet": "übereinkommen",
    "übereinkommst": "übereinkommen",
    "übereinkommt": "übereinkommen",
    "übereinkäme": "übereinkommen",
    "übereinkämen": "übereinkommen",
    "übereinkämest": "übereinkommen",
    "übereinkämet": "übereinkommen",
    "übereinstimme": "übereinstimmen",
    "übereinstimmend": "übereinstimmen",
    "übereinstimmende": "übereinstimmend",
    "übereinstimmendem": "übereinstimmend",
    "übereinstimmenden": "übereinstimmend",
    "übereinstimmender": "übereinstimmend",
    "übereinstimmendere": "übereinstimmend",
    "übereinstimmenderem": "übereinstimmend",
    "übereinstimmenderen": "übereinstimmend",
    "übereinstimmenderer": "übereinstimmend",
    "übereinstimmenderes": "übereinstimmend",
    "übereinstimmendes": "übereinstimmend",
    "übereinstimmendste": "übereinstimmend",
    "übereinstimmendstem": "übereinstimmend",
    "übereinstimmendsten": "übereinstimmend",
    "übereinstimmendster": "übereinstimmend",
    "übereinstimmendstes": "übereinstimmend",
    "übereinstimmest": "übereinstimmen",
    "übereinstimmet": "übereinstimmen",
    "übereinstimmst": "übereinstimmen",
    "übereinstimmt": "übereinstimmen",
    "übereinstimmte": "übereinstimmen",
    "übereinstimmten": "übereinstimmen",
    "übereinstimmtest": "übereinstimmen",
    "übereinstimmtet": "übereinstimmen",
    "übereinzukommen": "übereinkommen",
    "übereinzustimmen": "übereinstimmen",
    "überempfindliche": "überempfindlich",
    "überempfindlichem": "überempfindlich",
    "überempfindlichen": "überempfindlich",
    "überempfindlicher": "überempfindlich",
    "überempfindlichere": "überempfindlich",
    "überempfindlicherem": "überempfindlich",
    "überempfindlicheren": "überempfindlich",
    "überempfindlicherer": "überempfindlich",
    "überempfindlicheres": "überempfindlich",
    "überempfindliches": "überempfindlich",
    "überempfindlichste": "überempfindlich",
    "überempfindlichstem": "überempfindlich",
    "überempfindlichsten": "überempfindlich",
    "überempfindlichster": "überempfindlich",
    "überempfindlichstes": "überempfindlich",
    "überesse": "überessen",
    "überessend": "überessen",
    "überessende": "überessend",
    "überessendem": "überessend",
    "überessenden": "überessend",
    "überessender": "überessend",
    "überessendere": "überessend",
    "überessenderem": "überessend",
    "überessenderen": "überessend",
    "überessenderer": "überessend",
    "überessenderes": "überessend",
    "überessendes": "überessend",
    "überessendste": "überessend",
    "überessendstem": "überessend",
    "überessendsten": "überessend",
    "überessendster": "überessend",
    "überessendstes": "überessend",
    "überessest": "überessen",
    "überesset": "überessen",
    "übereßt": "überessen",
    "überfahre": "überfahren",
    "überfahrend": "überfahren",
    "überfahrende": "überfahrend",
    "überfahrendem": "überfahrend",
    "überfahrenden": "überfahrend",
    "überfahrender": "überfahrend",
    "überfahrendes": "überfahrend",
    "überfahrene": "überfahren",
    "überfahrenem": "überfahren",
    "überfahrenen": "überfahren",
    "überfahrener": "überfahren",
    "überfahrenes": "überfahren",
    "überfahrest": "überfahren",
    "überfahret": "überfahren",
    "überfahrt": "überfahren",
    "überfallend": "überfallen",
    "überfallende": "überfallend",
    "überfallendem": "überfallend",
    "überfallenden": "überfallend",
    "überfallender": "überfallend",
    "überfallendes": "überfallend",
    "überfallene": "überfallen",
    "überfallenem": "überfallen",
    "überfallenen": "überfallen",
    "überfallener": "überfallen",
    "überfallenes": "überfallen",
    "überfallest": "überfallen",
    "überfallet": "überfallen",
    "überfallt": "überfallen",
    "überfiel": "überfallen",
    "überfiele": "überfallen",
    "überfielen": "überfallen",
    "überfielest": "überfallen",
    "überfielet": "überfallen",
    "überfielst": "überfallen",
    "überfielt": "überfallen",
    "überfliege": "überfliegen",
    "überfliegend": "überfliegen",
    "überfliegende": "überfliegend",
    "überfliegendem": "überfliegend",
    "überfliegenden": "überfliegend",
    "überfliegender": "überfliegend",
    "überfliegendes": "überfliegend",
    "überfliegest": "überfliegen",
    "überflieget": "überfliegen",
    "überfliegst": "überfliegen",
    "überfliegt": "überfliegen",
    "überfließe": "überfließen",
    "überfließend": "überfließen",
    "überfließende": "überfließend",
    "überfließendem": "überfließend",
    "überfließenden": "überfließend",
    "überfließender": "überfließend",
    "überfließendere": "überfließend",
    "überfließenderem": "überfließend",
    "überfließenderen": "überfließend",
    "überfließenderer": "überfließend",
    "überfließenderes": "überfließend",
    "überfließendes": "überfließend",
    "überfließendste": "überfließend",
    "überfließendstem": "überfließend",
    "überfließendsten": "überfließend",
    "überfließendster": "überfließend",
    "überfließendstes": "überfließend",
    "überfließest": "überfließen",
    "überfließet": "überfließen",
    "überfließt": "überfließen",
    "überflog": "überfliegen",
    "überflogen": "überfliegen",
    "überflogene": "überflogen",
    "überflogenem": "überflogen",
    "überflogenen": "überflogen",
    "überflogener": "überflogen",
    "überflogenes": "überflogen",
    "überflogst": "überfliegen",
    "überflogt": "überfliegen",
    "überflossen": "überfließen",
    "überfloß": "überfließen",
    "überfloßt": "überfließen",
    "überflute": "überfluten",
    "überflutend": "überfluten",
    "überflutende": "überflutend",
    "überflutendem": "überflutend",
    "überflutenden": "überflutend",
    "überflutender": "überflutend",
    "überflutendes": "überflutend",
    "überflutest": "überfluten",
    "überflutet": "überfluten",
    "überflutete": "überflutet",
    "überflutetem": "überflutet",
    "überfluteten": "überflutet",
    "überfluteter": "überflutet",
    "überflutetes": "überflutet",
    "überflutetest": "überfluten",
    "überflutetet": "überfluten",
    "überflöge": "überfliegen",
    "überflögen": "überfliegen",
    "überflögest": "überfliegen",
    "überflöget": "überfliegen",
    "überflösse": "überfließen",
    "überflössen": "überfließen",
    "überflössest": "überfließen",
    "überflösset": "überfließen",
    "überflügele": "überflügeln",
    "überflügelnd": "überflügeln",
    "überflügelnde": "überflügelnd",
    "überflügelndem": "überflügelnd",
    "überflügelnden": "überflügelnd",
    "überflügelnder": "überflügelnd",
    "überflügelndes": "überflügelnd",
    "überflügelst": "überflügeln",
    "überflügelt": "überflügeln",
    "überflügelte": "überflügelt",
    "überflügeltem": "überflügelt",
    "überflügelten": "überflügelt",
    "überflügelter": "überflügelt",
    "überflügeltes": "überflügelt",
    "überflügeltest": "überflügeln",
    "überflügeltet": "überflügeln",
    "überflügle": "überflügeln",
    "überflüssige": "überflüssig",
    "überflüssigem": "überflüssig",
    "überflüssigen": "überflüssig",
    "überflüssiger": "überflüssig",
    "überflüssigere": "überflüssig",
    "überflüssigerem": "überflüssig",
    "überflüssigeren": "überflüssig",
    "überflüssigerer": "überflüssig",
    "überflüssigeres": "überflüssig",
    "überflüssiges": "überflüssig",
    "überflüssigste": "überflüssig",
    "überflüssigstem": "überflüssig",
    "überflüssigsten": "überflüssig",
    "überflüssigster": "überflüssig",
    "überflüssigstes": "überflüssig",
    "überfordere": "überfordern",
    "überfordernd": "überfordern",
    "überfordernde": "überfordernd",
    "überforderndem": "überfordernd",
    "überfordernden": "überfordernd",
    "überfordernder": "überfordernd",
    "überforderndere": "überfordernd",
    "überfordernderem": "überfordernd",
    "überfordernderen": "überfordernd",
    "überfordernderer": "überfordernd",
    "überfordernderes": "überfordernd",
    "überforderndes": "überfordernd",
    "überforderndste": "überfordernd",
    "überforderndstem": "überfordernd",
    "überforderndsten": "überfordernd",
    "überforderndster": "überfordernd",
    "überforderndstes": "überfordernd",
    "überforderst": "überfordern",
    "überfordert": "überfordern",
    "überforderte": "überfordert",
    "überfordertem": "überfordert",
    "überforderten": "überfordert",
    "überforderter": "überfordert",
    "überfordertere": "überfordert",
    "überforderterem": "überfordert",
    "überforderteren": "überfordert",
    "überforderterer": "überfordert",
    "überforderteres": "überfordert",
    "überfordertes": "überfordert",
    "überfordertest": "überfordern",
    "überforderteste": "überfordert",
    "überfordertestem": "überfordert",
    "überfordertesten": "überfordert",
    "überfordertester": "überfordert",
    "überfordertestes": "überfordert",
    "überfordertet": "überfordern",
    "überfrachte": "überfrachten",
    "überfrachtend": "überfrachten",
    "überfrachtende": "überfrachtend",
    "überfrachtendem": "überfrachtend",
    "überfrachtenden": "überfrachtend",
    "überfrachtender": "überfrachtend",
    "überfrachtendere": "überfrachtend",
    "überfrachtenderem": "überfrachtend",
    "überfrachtenderen": "überfrachtend",
    "überfrachtenderer": "überfrachtend",
    "überfrachtenderes": "überfrachtend",
    "überfrachtendes": "überfrachtend",
    "überfrachtendste": "überfrachtend",
    "überfrachtendstem": "überfrachtend",
    "überfrachtendsten": "überfrachtend",
    "überfrachtendster": "überfrachtend",
    "überfrachtendstes": "überfrachtend",
    "überfrachtest": "überfrachten",
    "überfrachtet": "überfrachten",
    "überfrachtete": "überfrachtet",
    "überfrachtetem": "überfrachtet",
    "überfrachteten": "überfrachtet",
    "überfrachteter": "überfrachtet",
    "überfrachtetere": "überfrachtet",
    "überfrachteterem": "überfrachtet",
    "überfrachteteren": "überfrachtet",
    "überfrachteterer": "überfrachtet",
    "überfrachteteres": "überfrachtet",
    "überfrachtetes": "überfrachtet",
    "überfrachtetest": "überfrachten",
    "überfrachteteste": "überfrachtet",
    "überfrachtetestem": "überfrachtet",
    "überfrachtetesten": "überfrachtet",
    "überfrachtetester": "überfrachtet",
    "überfrachtetestes": "überfrachtet",
    "überfrachtetet": "überfrachten",
    "überfrage": "überfragen",
    "überfragend": "überfragen",
    "überfragende": "überfragend",
    "überfragendem": "überfragend",
    "überfragenden": "überfragend",
    "überfragender": "überfragend",
    "überfragendes": "überfragend",
    "überfragest": "überfragen",
    "überfraget": "überfragen",
    "überfragst": "überfragen",
    "überfragt": "überfragen",
    "überfragte": "überfragt",
    "überfragtem": "überfragt",
    "überfragten": "überfragt",
    "überfragter": "überfragt",
    "überfragtes": "überfragt",
    "überfragtest": "überfragen",
    "überfragtet": "überfragen",
    "überfraß": "überfressen",
    "überfraßen": "überfressen",
    "überfraßt": "überfressen",
    "überfremde": "überfremden",
    "überfremdend": "überfremden",
    "überfremdende": "überfremdend",
    "überfremdendem": "überfremdend",
    "überfremdenden": "überfremdend",
    "überfremdender": "überfremdend",
    "überfremdendere": "überfremdend",
    "überfremdenderem": "überfremdend",
    "überfremdenderen": "überfremdend",
    "überfremdenderer": "überfremdend",
    "überfremdenderes": "überfremdend",
    "überfremdendes": "überfremdend",
    "überfremdendste": "überfremdend",
    "überfremdendstem": "überfremdend",
    "überfremdendsten": "überfremdend",
    "überfremdendster": "überfremdend",
    "überfremdendstes": "überfremdend",
    "überfremdest": "überfremden",
    "überfremdet": "überfremden",
    "überfremdete": "überfremdet",
    "überfremdetem": "überfremdet",
    "überfremdeten": "überfremdet",
    "überfremdeter": "überfremdet",
    "überfremdetere": "überfremdet",
    "überfremdeterem": "überfremdet",
    "überfremdeteren": "überfremdet",
    "überfremdeterer": "überfremdet",
    "überfremdeteres": "überfremdet",
    "überfremdetes": "überfremdet",
    "überfremdetest": "überfremden",
    "überfremdeteste": "überfremdet",
    "überfremdetestem": "überfremdet",
    "überfremdetesten": "überfremdet",
    "überfremdetester": "überfremdet",
    "überfremdetestes": "überfremdet",
    "überfremdetet": "überfremden",
    "überfresse": "überfressen",
    "überfressend": "überfressen",
    "überfressende": "überfressend",
    "überfressendem": "überfressend",
    "überfressenden": "überfressend",
    "überfressender": "überfressend",
    "überfressendere": "überfressend",
    "überfressenderem": "überfressend",
    "überfressenderen": "überfressend",
    "überfressenderer": "überfressend",
    "überfressenderes": "überfressend",
    "überfressendes": "überfressend",
    "überfressendste": "überfressend",
    "überfressendstem": "überfressend",
    "überfressendsten": "überfressend",
    "überfressendster": "überfressend",
    "überfressendstes": "überfressend",
    "überfressene": "überfressen",
    "überfressenem": "überfressen",
    "überfressenen": "überfressen",
    "überfressener": "überfressen",
    "überfressenere": "überfressen",
    "überfressenerem": "überfressen",
    "überfresseneren": "überfressen",
    "überfressenerer": "überfressen",
    "überfresseneres": "überfressen",
    "überfressenes": "überfressen",
    "überfressenste": "überfressen",
    "überfressenstem": "überfressen",
    "überfressensten": "überfressen",
    "überfressenster": "überfressen",
    "überfressenstes": "überfressen",
    "überfressest": "überfressen",
    "überfresset": "überfressen",
    "überfreßt": "überfressen",
    "überfriß": "überfressen",
    "überfrißt": "überfressen",
    "überfräße": "überfressen",
    "überfräßen": "überfressen",
    "überfräßest": "überfressen",
    "überfräßet": "überfressen",
    "überfuhr": "überfahren",
    "überfuhren": "überfahren",
    "überfuhrst": "überfahren",
    "überfuhrt": "überfahren",
    "überfährst": "überfahren",
    "überfährt": "überfahren",
    "überfällige": "überfällig",
    "überfälligem": "überfällig",
    "überfälligen": "überfällig",
    "überfälliger": "überfällig",
    "überfälligere": "überfällig",
    "überfälligerem": "überfällig",
    "überfälligeren": "überfällig",
    "überfälligerer": "überfällig",
    "überfälligeres": "überfällig",
    "überfälliges": "überfällig",
    "überfälligste": "überfällig",
    "überfälligstem": "überfällig",
    "überfälligsten": "überfällig",
    "überfälligster": "überfällig",
    "überfälligstes": "überfällig",
    "überfällst": "überfallen",
    "überfällt": "überfallen",
    "überführe": "überführen",
    "überführen": "überfahren",
    "überführend": "überführen",
    "überführende": "überführend",
    "überführendem": "überführend",
    "überführenden": "überführend",
    "überführender": "überführend",
    "überführendes": "überführend",
    "überführest": "überführen",
    "überführet": "überführen",
    "überführst": "überführen",
    "überführt": "überführen",
    "überführte": "überführt",
    "überführtem": "überführt",
    "überführten": "überführt",
    "überführter": "überführt",
    "überführtes": "überführt",
    "überführtest": "überführen",
    "überführtet": "überführen",
    "überfülle": "überfüllen",
    "überfüllend": "überfüllen",
    "überfüllende": "überfüllend",
    "überfüllendem": "überfüllend",
    "überfüllenden": "überfüllend",
    "überfüllender": "überfüllend",
    "überfüllendere": "überfüllend",
    "überfüllenderem": "überfüllend",
    "überfüllenderen": "überfüllend",
    "überfüllenderer": "überfüllend",
    "überfüllenderes": "überfüllend",
    "überfüllendes": "überfüllend",
    "überfüllendste": "überfüllend",
    "überfüllendstem": "überfüllend",
    "überfüllendsten": "überfüllend",
    "überfüllendster": "überfüllend",
    "überfüllendstes": "überfüllend",
    "überfüllest": "überfüllen",
    "überfüllet": "überfüllen",
    "überfüllst": "überfüllen",
    "überfüllt": "überfüllen",
    "überfüllte": "überfüllt",
    "überfülltem": "überfüllt",
    "überfüllten": "überfüllt",
    "überfüllter": "überfüllt",
    "überfülltere": "überfüllt",
    "überfüllterem": "überfüllt",
    "überfüllteren": "überfüllt",
    "überfüllterer": "überfüllt",
    "überfüllteres": "überfüllt",
    "überfülltes": "überfüllt",
    "überfülltest": "überfüllen",
    "überfüllteste": "überfüllt",
    "überfülltestem": "überfüllt",
    "überfülltesten": "überfüllt",
    "überfülltester": "überfüllt",
    "überfülltestes": "überfüllt",
    "überfülltet": "überfüllen",
    "überfüttere": "überfüttern",
    "überfütternd": "überfüttern",
    "überfütternde": "überfütternd",
    "überfütterndem": "überfütternd",
    "überfütternden": "überfütternd",
    "überfütternder": "überfütternd",
    "überfütterndere": "überfütternd",
    "überfütternderem": "überfütternd",
    "überfütternderen": "überfütternd",
    "überfütternderer": "überfütternd",
    "überfütternderes": "überfütternd",
    "überfütterndes": "überfütternd",
    "überfütterndste": "überfütternd",
    "überfütterndstem": "überfütternd",
    "überfütterndsten": "überfütternd",
    "überfütterndster": "überfütternd",
    "überfütterndstes": "überfütternd",
    "überfütterst": "überfüttern",
    "überfüttert": "überfüttern",
    "überfütterte": "überfüttert",
    "überfüttertem": "überfüttert",
    "überfütterten": "überfüttert",
    "überfütterter": "überfüttert",
    "überfüttertere": "überfüttert",
    "überfütterterem": "überfüttert",
    "überfütterteren": "überfüttert",
    "überfütterterer": "überfüttert",
    "überfütterteres": "überfüttert",
    "überfüttertes": "überfüttert",
    "überfüttertest": "überfüttern",
    "überfütterteste": "überfüttert",
    "überfüttertestem": "überfüttert",
    "überfüttertesten": "überfüttert",
    "überfüttertester": "überfüttert",
    "überfüttertestes": "überfüttert",
    "überfüttertet": "überfüttern",
    "übergab": "übergeben",
    "übergaben": "übergeben",
    "übergabst": "übergeben",
    "übergabt": "übergeben",
    "übergangen": "übergehen",
    "übergangene": "übergangen",
    "übergangenem": "übergangen",
    "übergangenen": "übergangen",
    "übergangener": "übergangen",
    "übergangenes": "übergangen",
    "übergangslose": "übergangslos",
    "übergangslosem": "übergangslos",
    "übergangslosen": "übergangslos",
    "übergangsloser": "übergangslos",
    "übergangsloses": "übergangslos",
    "übergebaut": "überbauen",
    "übergebaute": "übergebaut",
    "übergebautem": "übergebaut",
    "übergebauten": "übergebaut",
    "übergebauter": "übergebaut",
    "übergebautes": "übergebaut",
    "übergebe": "übergeben",
    "übergebend": "übergeben",
    "übergebende": "übergebend",
    "übergebendem": "übergebend",
    "übergebenden": "übergebend",
    "übergebender": "übergebend",
    "übergebendes": "übergebend",
    "übergebene": "übergeben",
    "übergebenem": "übergeben",
    "übergebenen": "übergeben",
    "übergebener": "übergeben",
    "übergebenes": "übergeben",
    "übergebest": "übergeben",
    "übergebet": "übergeben",
    "übergebraten": "überbraten",
    "übergebratene": "übergebraten",
    "übergebratenem": "übergebraten",
    "übergebratenen": "übergebraten",
    "übergebratener": "übergebraten",
    "übergebratenes": "übergebraten",
    "übergebt": "übergeben",
    "übergedacht": "überdenken",
    "übergedachte": "übergedacht",
    "übergedachtem": "übergedacht",
    "übergedachten": "übergedacht",
    "übergedachter": "übergedacht",
    "übergedachtere": "übergedacht",
    "übergedachterem": "übergedacht",
    "übergedachteren": "übergedacht",
    "übergedachterer": "übergedacht",
    "übergedachteres": "übergedacht",
    "übergedachtes": "übergedacht",
    "übergedachteste": "übergedacht",
    "übergedachtestem": "übergedacht",
    "übergedachtesten": "übergedacht",
    "übergedachtester": "übergedacht",
    "übergedachtestes": "übergedacht",
    "übergeflossen": "überfließen",
    "übergeflossene": "übergeflossen",
    "übergeflossenem": "übergeflossen",
    "übergeflossenen": "übergeflossen",
    "übergeflossener": "übergeflossen",
    "übergeflossenere": "übergeflossen",
    "übergeflossenerem": "übergeflossen",
    "übergeflosseneren": "übergeflossen",
    "übergeflossenerer": "übergeflossen",
    "übergeflosseneres": "übergeflossen",
    "übergeflossenes": "übergeflossen",
    "übergeflossenste": "übergeflossen",
    "übergeflossenstem": "übergeflossen",
    "übergeflossensten": "übergeflossen",
    "übergeflossenster": "übergeflossen",
    "übergeflossenstes": "übergeflossen",
    "übergeflutet": "überfluten",
    "übergeflutete": "übergeflutet",
    "übergeflutetem": "übergeflutet",
    "übergefluteten": "übergeflutet",
    "übergefluteter": "übergeflutet",
    "übergeflutetere": "übergeflutet",
    "übergefluteterem": "übergeflutet",
    "übergefluteteren": "übergeflutet",
    "übergefluteterer": "übergeflutet",
    "übergefluteteres": "übergeflutet",
    "übergeflutetes": "übergeflutet",
    "übergefluteteste": "übergeflutet",
    "übergeflutetestem": "übergeflutet",
    "übergeflutetesten": "übergeflutet",
    "übergeflutetester": "übergeflutet",
    "übergeflutetestes": "übergeflutet",
    "übergegangene": "übergegangen",
    "übergegangenem": "übergegangen",
    "übergegangenen": "übergegangen",
    "übergegangener": "übergegangen",
    "übergegangenes": "übergegangen",
    "übergegessen": "überessen",
    "übergegessene": "übergegessen",
    "übergegessenem": "übergegessen",
    "übergegessenen": "übergegessen",
    "übergegessener": "übergegessen",
    "übergegessenere": "übergegessen",
    "übergegessenerem": "übergegessen",
    "übergegesseneren": "übergegessen",
    "übergegessenerer": "übergegessen",
    "übergegesseneres": "übergegessen",
    "übergegessenes": "übergegessen",
    "übergegessenste": "übergegessen",
    "übergegessenstem": "übergegessen",
    "übergegessensten": "übergegessen",
    "übergegessenster": "übergegessen",
    "übergegessenstes": "übergegessen",
    "übergegossen": "übergießen",
    "übergegossene": "übergegossen",
    "übergegossenem": "übergegossen",
    "übergegossenen": "übergegossen",
    "übergegossener": "übergegossen",
    "übergegossenes": "übergegossen",
    "übergegriffen": "übergreifen",
    "übergegriffene": "übergegriffen",
    "übergegriffenem": "übergegriffen",
    "übergegriffenen": "übergegriffen",
    "übergegriffener": "übergegriffen",
    "übergegriffenere": "übergegriffen",
    "übergegriffenerem": "übergegriffen",
    "übergegriffeneren": "übergegriffen",
    "übergegriffenerer": "übergegriffen",
    "übergegriffeneres": "übergegriffen",
    "übergegriffenes": "übergegriffen",
    "übergegriffenste": "übergegriffen",
    "übergegriffenstem": "übergegriffen",
    "übergegriffensten": "übergegriffen",
    "übergegriffenster": "übergegriffen",
    "übergegriffenstes": "übergegriffen",
    "übergehangen": "überhängen",
    "übergehangene": "übergehangen",
    "übergehangenem": "übergehangen",
    "übergehangenen": "übergehangen",
    "übergehangener": "übergehangen",
    "übergehangenes": "übergehangen",
    "übergehe": "übergehen",
    "übergehend": "übergehen",
    "übergehende": "übergehend",
    "übergehendem": "übergehend",
    "übergehenden": "übergehend",
    "übergehender": "übergehend",
    "übergehendes": "übergehend",
    "übergehest": "übergehen",
    "übergehet": "übergehen",
    "übergehst": "übergehen",
    "übergeht": "übergehen",
    "übergehängt": "überhängen",
    "übergehängte": "übergehängt",
    "übergehängtem": "übergehängt",
    "übergehängten": "übergehängt",
    "übergehängter": "übergehängt",
    "übergehängtes": "übergehängt",
    "übergekippt": "überkippen",
    "übergekippte": "übergekippt",
    "übergekipptem": "übergekippt",
    "übergekippten": "übergekippt",
    "übergekippter": "übergekippt",
    "übergekipptes": "übergekippt",
    "übergekocht": "überkochen",
    "übergekochte": "übergekocht",
    "übergekochtem": "übergekocht",
    "übergekochten": "übergekocht",
    "übergekochter": "übergekocht",
    "übergekochtere": "übergekocht",
    "übergekochterem": "übergekocht",
    "übergekochteren": "übergekocht",
    "übergekochterer": "übergekocht",
    "übergekochteres": "übergekocht",
    "übergekochtes": "übergekocht",
    "übergekochteste": "übergekocht",
    "übergekochtestem": "übergekocht",
    "übergekochtesten": "übergekocht",
    "übergekochtester": "übergekocht",
    "übergekochtestes": "übergekocht",
    "übergekriegt": "überkriegen",
    "übergekriegte": "übergekriegt",
    "übergekriegtem": "übergekriegt",
    "übergekriegten": "übergekriegt",
    "übergekriegter": "übergekriegt",
    "übergekriegtes": "übergekriegt",
    "übergelegen": "überliegen",
    "übergelegene": "übergelegen",
    "übergelegenem": "übergelegen",
    "übergelegenen": "übergelegen",
    "übergelegener": "übergelegen",
    "übergelegenes": "übergelegen",
    "übergeleitet": "überleiten",
    "übergeleitete": "übergeleitet",
    "übergeleitetem": "übergeleitet",
    "übergeleiteten": "übergeleitet",
    "übergeleiteter": "übergeleitet",
    "übergeleitetes": "übergeleitet",
    "übergeordnet": "überordnen",
    "übergeordnete": "übergeordnet",
    "übergeordnetem": "übergeordnet",
    "übergeordneten": "übergeordnet",
    "übergeordneter": "übergeordnet",
    "übergeordnetere": "übergeordnet",
    "übergeordneterem": "übergeordnet",
    "übergeordneteren": "übergeordnet",
    "übergeordneterer": "übergeordnet",
    "übergeordneteres": "übergeordnet",
    "übergeordnetes": "übergeordnet",
    "übergeordneteste": "übergeordnet",
    "übergeordnetestem": "übergeordnet",
    "übergeordnetesten": "übergeordnet",
    "übergeordnetester": "übergeordnet",
    "übergeordnetestes": "übergeordnet",
    "übergequellt": "überquellen",
    "übergequellte": "übergequellt",
    "übergequelltem": "übergequellt",
    "übergequellten": "übergequellt",
    "übergequellter": "übergequellt",
    "übergequelltes": "übergequellt",
    "übergequollen": "überquellen",
    "übergequollene": "übergequollen",
    "übergequollenem": "übergequollen",
    "übergequollenen": "übergequollen",
    "übergequollener": "übergequollen",
    "übergequollenes": "übergequollen",
    "übergeschlagen": "überschlagen",
    "übergeschlagene": "übergeschlagen",
    "übergeschlagenem": "übergeschlagen",
    "übergeschlagenen": "übergeschlagen",
    "übergeschlagener": "übergeschlagen",
    "übergeschlagenes": "übergeschlagen",
    "übergeschnappt": "überschnappen",
    "übergeschnappte": "übergeschnappt",
    "übergeschnapptem": "übergeschnappt",
    "übergeschnappten": "übergeschnappt",
    "übergeschnappter": "übergeschnappt",
    "übergeschnapptere": "übergeschnappt",
    "übergeschnappterem": "übergeschnappt",
    "übergeschnappteren": "übergeschnappt",
    "übergeschnappterer": "übergeschnappt",
    "übergeschnappteres": "übergeschnappt",
    "übergeschnapptes": "übergeschnappt",
    "übergeschnappteste": "übergeschnappt",
    "übergeschnapptestem": "übergeschnappt",
    "übergeschnapptesten": "übergeschnappt",
    "übergeschnapptester": "übergeschnappt",
    "übergeschnapptestes": "übergeschnappt",
    "übergeschwappt": "überschwappen",
    "übergeschwappte": "übergeschwappt",
    "übergeschwapptem": "übergeschwappt",
    "übergeschwappten": "übergeschwappt",
    "übergeschwappter": "übergeschwappt",
    "übergeschwapptere": "übergeschwappt",
    "übergeschwappterem": "übergeschwappt",
    "übergeschwappteren": "übergeschwappt",
    "übergeschwappterer": "übergeschwappt",
    "übergeschwappteres": "übergeschwappt",
    "übergeschwapptes": "übergeschwappt",
    "übergeschwappteste": "übergeschwappt",
    "übergeschwapptestem": "übergeschwappt",
    "übergeschwapptesten": "übergeschwappt",
    "übergeschwapptester": "übergeschwappt",
    "übergeschwapptestes": "übergeschwappt",
    "übergeschäumt": "überschäumen",
    "übergeschäumte": "übergeschäumt",
    "übergeschäumtem": "übergeschäumt",
    "übergeschäumten": "übergeschäumt",
    "übergeschäumter": "übergeschäumt",
    "übergeschäumtere": "übergeschäumt",
    "übergeschäumterem": "übergeschäumt",
    "übergeschäumteren": "übergeschäumt",
    "übergeschäumterer": "übergeschäumt",
    "übergeschäumteres": "übergeschäumt",
    "übergeschäumtes": "übergeschäumt",
    "übergeschäumteste": "übergeschäumt",
    "übergeschäumtestem": "übergeschäumt",
    "übergeschäumtesten": "übergeschäumt",
    "übergeschäumtester": "übergeschäumt",
    "übergeschäumtestes": "übergeschäumt",
    "übergesetzt": "übersetzen",
    "übergesetzte": "übergesetzt",
    "übergesetztem": "übergesetzt",
    "übergesetzten": "übergesetzt",
    "übergesetzter": "übergesetzt",
    "übergesetztes": "übergesetzt",
    "übergesprudelt": "übersprudeln",
    "übergesprudelte": "übergesprudelt",
    "übergesprudeltem": "übergesprudelt",
    "übergesprudelten": "übergesprudelt",
    "übergesprudelter": "übergesprudelt",
    "übergesprudeltes": "übergesprudelt",
    "übergesprungen": "überspringen",
    "übergesprungene": "übergesprungen",
    "übergesprungenem": "übergesprungen",
    "übergesprungenen": "übergesprungen",
    "übergesprungener": "übergesprungen",
    "übergesprungenes": "übergesprungen",
    "übergestreift": "überstreifen",
    "übergestreifte": "übergestreift",
    "übergestreiftem": "übergestreift",
    "übergestreiften": "übergestreift",
    "übergestreifter": "übergestreift",
    "übergestreiftes": "übergestreift",
    "übergeströmt": "überströmen",
    "übergeströmte": "übergeströmt",
    "übergeströmtem": "übergeströmt",
    "übergeströmten": "übergeströmt",
    "übergeströmter": "übergeströmt",
    "übergeströmtes": "übergeströmt",
    "übergetreten": "übertreten",
    "übergetretene": "übergetreten",
    "übergetretenem": "übergetreten",
    "übergetretenen": "übergetreten",
    "übergetretener": "übergetreten",
    "übergetretenes": "übergetreten",
    "übergewallt": "überwallen",
    "übergewallte": "übergewallt",
    "übergewalltem": "übergewallt",
    "übergewallten": "übergewallt",
    "übergewallter": "übergewallt",
    "übergewalltere": "übergewallt",
    "übergewallterem": "übergewallt",
    "übergewallteren": "übergewallt",
    "übergewallterer": "übergewallt",
    "übergewallteres": "übergewallt",
    "übergewalltes": "übergewallt",
    "übergewallteste": "übergewallt",
    "übergewalltestem": "übergewallt",
    "übergewalltesten": "übergewallt",
    "übergewalltester": "übergewallt",
    "übergewalltestes": "übergewallt",
    "übergeworfen": "überwerfen",
    "übergeworfene": "übergeworfen",
    "übergeworfenem": "übergeworfen",
    "übergeworfenen": "übergeworfen",
    "übergeworfener": "übergeworfen",
    "übergeworfenes": "übergeworfen",
    "übergezählt": "überzählen",
    "übergezählte": "übergezählt",
    "übergezähltem": "übergezählt",
    "übergezählten": "übergezählt",
    "übergezählter": "übergezählt",
    "übergezähltes": "übergezählt",
    "übergib": "übergeben",
    "übergibst": "übergeben",
    "übergibt": "übergeben",
    "übergieße": "übergießen",
    "übergießend": "übergießen",
    "übergießende": "übergießend",
    "übergießendem": "übergießend",
    "übergießenden": "übergießend",
    "übergießender": "übergießend",
    "übergießendes": "übergießend",
    "übergießest": "übergießen",
    "übergießet": "übergießen",
    "übergießt": "übergießen",
    "überging": "übergehen",
    "überginge": "übergehen",
    "übergingen": "übergehen",
    "übergingest": "übergehen",
    "überginget": "übergehen",
    "übergingst": "übergehen",
    "übergingt": "übergehen",
    "überglückliche": "überglücklich",
    "überglücklichem": "überglücklich",
    "überglücklichen": "überglücklich",
    "überglücklicher": "überglücklich",
    "überglückliches": "überglücklich",
    "übergossen": "übergießen",
    "übergossene": "übergossen",
    "übergossenem": "übergossen",
    "übergossenen": "übergossen",
    "übergossener": "übergossen",
    "übergossenes": "übergossen",
    "übergoß": "übergießen",
    "übergoßt": "übergießen",
    "übergreife": "übergreifen",
    "übergreifend": "übergreifen",
    "übergreifende": "übergreifend",
    "übergreifendem": "übergreifend",
    "übergreifenden": "übergreifend",
    "übergreifender": "übergreifend",
    "übergreifendere": "übergreifend",
    "übergreifenderem": "übergreifend",
    "übergreifenderen": "übergreifend",
    "übergreifenderer": "übergreifend",
    "übergreifenderes": "übergreifend",
    "übergreifendes": "übergreifend",
    "übergreifendste": "übergreifend",
    "übergreifendstem": "übergreifend",
    "übergreifendsten": "übergreifend",
    "übergreifendster": "übergreifend",
    "übergreifendstes": "übergreifend",
    "übergreifest": "übergreifen",
    "übergreifet": "übergreifen",
    "übergreifst": "übergreifen",
    "übergreift": "übergreifen",
    "übergriff": "übergreifen",
    "übergriffest": "übergreifen",
    "übergriffet": "übergreifen",
    "übergriffst": "übergreifen",
    "übergrifft": "übergreifen",
    "übergroße": "übergroß",
    "übergroßem": "übergroß",
    "übergroßen": "übergroß",
    "übergroßer": "übergroß",
    "übergroßes": "übergroß",
    "übergäbe": "übergeben",
    "übergäben": "übergeben",
    "übergäbest": "übergeben",
    "übergäbet": "übergeben",
    "übergösse": "übergießen",
    "übergössen": "übergießen",
    "übergössest": "übergießen",
    "übergösset": "übergießen",
    "überhandgenommen": "überhandnehmen",
    "überhandgenommene": "überhandgenommen",
    "überhandgenommenem": "überhandgenommen",
    "überhandgenommenen": "überhandgenommen",
    "überhandgenommener": "überhandgenommen",
    "überhandgenommenes": "überhandgenommen",
    "überhandnahm": "überhandnehmen",
    "überhandnahmen": "überhandnehmen",
    "überhandnahmst": "überhandnehmen",
    "überhandnahmt": "überhandnehmen",
    "überhandnehme": "überhandnehmen",
    "überhandnehmend": "überhandnehmen",
    "überhandnehmende": "überhandnehmend",
    "überhandnehmendem": "überhandnehmend",
    "überhandnehmenden": "überhandnehmend",
    "überhandnehmender": "überhandnehmend",
    "überhandnehmendes": "überhandnehmend",
    "überhandnehmest": "überhandnehmen",
    "überhandnehmet": "überhandnehmen",
    "überhandnehmt": "überhandnehmen",
    "überhandnimmst": "überhandnehmen",
    "überhandnimmt": "überhandnehmen",
    "überhandnähme": "überhandnehmen",
    "überhandnähmen": "überhandnehmen",
    "überhandnähmest": "überhandnehmen",
    "überhandnähmet": "überhandnehmen",
    "überhandzunehmen": "überhandnehmen",
    "überhebliche": "überheblich",
    "überheblichem": "überheblich",
    "überheblichen": "überheblich",
    "überheblicher": "überheblich",
    "überheblichere": "überheblich",
    "überheblicherem": "überheblich",
    "überheblicheren": "überheblich",
    "überheblicherer": "überheblich",
    "überheblicheres": "überheblich",
    "überhebliches": "überheblich",
    "überheblichste": "überheblich",
    "überheblichstem": "überheblich",
    "überheblichsten": "überheblich",
    "überheblichster": "überheblich",
    "überheblichstes": "überheblich",
    "überheize": "überheizen",
    "überheizend": "überheizen",
    "überheizende": "überheizend",
    "überheizendem": "überheizend",
    "überheizenden": "überheizend",
    "überheizender": "überheizend",
    "überheizendere": "überheizend",
    "überheizenderem": "überheizend",
    "überheizenderen": "überheizend",
    "überheizenderer": "überheizend",
    "überheizenderes": "überheizend",
    "überheizendes": "überheizend",
    "überheizendste": "überheizend",
    "überheizendstem": "überheizend",
    "überheizendsten": "überheizend",
    "überheizendster": "überheizend",
    "überheizendstes": "überheizend",
    "überheizest": "überheizen",
    "überheizet": "überheizen",
    "überheizt": "überheizen",
    "überheizte": "überheizt",
    "überheiztem": "überheizt",
    "überheizten": "überheizt",
    "überheizter": "überheizt",
    "überheiztere": "überheizt",
    "überheizterem": "überheizt",
    "überheizteren": "überheizt",
    "überheizterer": "überheizt",
    "überheizteres": "überheizt",
    "überheiztes": "überheizt",
    "überheiztest": "überheizen",
    "überheizteste": "überheizt",
    "überheiztestem": "überheizt",
    "überheiztesten": "überheizt",
    "überheiztester": "überheizt",
    "überheiztestes": "überheizt",
    "überheiztet": "überheizen",
    "überhing": "überhängen",
    "überhinge": "überhängen",
    "überhingen": "überhängen",
    "überhingest": "überhängen",
    "überhinget": "überhängen",
    "überhingst": "überhängen",
    "überhingt": "überhängen",
    "überhitze": "überhitzen",
    "überhitzend": "überhitzen",
    "überhitzende": "überhitzend",
    "überhitzendem": "überhitzend",
    "überhitzenden": "überhitzend",
    "überhitzender": "überhitzend",
    "überhitzendere": "überhitzend",
    "überhitzenderem": "überhitzend",
    "überhitzenderen": "überhitzend",
    "überhitzenderer": "überhitzend",
    "überhitzenderes": "überhitzend",
    "überhitzendes": "überhitzend",
    "überhitzendste": "überhitzend",
    "überhitzendstem": "überhitzend",
    "überhitzendsten": "überhitzend",
    "überhitzendster": "überhitzend",
    "überhitzendstes": "überhitzend",
    "überhitzest": "überhitzen",
    "überhitzet": "überhitzen",
    "überhitzt": "überhitzen",
    "überhitzte": "überhitzt",
    "überhitztem": "überhitzt",
    "überhitzten": "überhitzt",
    "überhitzter": "überhitzt",
    "überhitztere": "überhitzt",
    "überhitzterem": "überhitzt",
    "überhitzteren": "überhitzt",
    "überhitzterer": "überhitzt",
    "überhitzteres": "überhitzt",
    "überhitztes": "überhitzt",
    "überhitztest": "überhitzen",
    "überhitzteste": "überhitzt",
    "überhitztestem": "überhitzt",
    "überhitztesten": "überhitzt",
    "überhitztester": "überhitzt",
    "überhitztestes": "überhitzt",
    "überhitztet": "überhitzen",
    "überhole": "überholen",
    "überholend": "überholen",
    "überholende": "überholend",
    "überholendem": "überholend",
    "überholenden": "überholend",
    "überholender": "überholend",
    "überholendes": "überholend",
    "überholest": "überholen",
    "überholet": "überholen",
    "überholst": "überholen",
    "überholt": "überholen",
    "überholte": "überholt",
    "überholtem": "überholt",
    "überholten": "überholt",
    "überholter": "überholt",
    "überholtes": "überholt",
    "überholtest": "überholen",
    "überholtet": "überholen",
    "überhänge": "überhängen",
    "überhängend": "überhängen",
    "überhängende": "überhängend",
    "überhängendem": "überhängend",
    "überhängenden": "überhängend",
    "überhängender": "überhängend",
    "überhängendere": "überhängend",
    "überhängenderem": "überhängend",
    "überhängenderen": "überhängend",
    "überhängenderer": "überhängend",
    "überhängenderes": "überhängend",
    "überhängendes": "überhängend",
    "überhängendste": "überhängend",
    "überhängendstem": "überhängend",
    "überhängendsten": "überhängend",
    "überhängendster": "überhängend",
    "überhängendstes": "überhängend",
    "überhängest": "überhängen",
    "überhänget": "überhängen",
    "überhängst": "überhängen",
    "überhängt": "überhängen",
    "überhängte": "überhängen",
    "überhängten": "überhängen",
    "überhängtest": "überhängen",
    "überhängtet": "überhängen",
    "überhäufe": "überhäufen",
    "überhäufend": "überhäufen",
    "überhäufende": "überhäufend",
    "überhäufendem": "überhäufend",
    "überhäufenden": "überhäufend",
    "überhäufender": "überhäufend",
    "überhäufendere": "überhäufend",
    "überhäufenderem": "überhäufend",
    "überhäufenderen": "überhäufend",
    "überhäufenderer": "überhäufend",
    "überhäufenderes": "überhäufend",
    "überhäufendes": "überhäufend",
    "überhäufendste": "überhäufend",
    "überhäufendstem": "überhäufend",
    "überhäufendsten": "überhäufend",
    "überhäufendster": "überhäufend",
    "überhäufendstes": "überhäufend",
    "überhäufest": "überhäufen",
    "überhäufet": "überhäufen",
    "überhäufst": "überhäufen",
    "überhäuft": "überhäufen",
    "überhäufte": "überhäuft",
    "überhäuftem": "überhäuft",
    "überhäuften": "überhäuft",
    "überhäufter": "überhäuft",
    "überhäuftere": "überhäuft",
    "überhäufterem": "überhäuft",
    "überhäufteren": "überhäuft",
    "überhäufterer": "überhäuft",
    "überhäufteres": "überhäuft",
    "überhäuftes": "überhäuft",
    "überhäuftest": "überhäufen",
    "überhäufteste": "überhäuft",
    "überhäuftestem": "überhäuft",
    "überhäuftesten": "überhäuft",
    "überhäuftester": "überhäuft",
    "überhäuftestes": "überhäuft",
    "überhäuftet": "überhäufen",
    "überhöhe": "überhöhen",
    "überhöhend": "überhöhen",
    "überhöhende": "überhöhend",
    "überhöhendem": "überhöhend",
    "überhöhenden": "überhöhend",
    "überhöhender": "überhöhend",
    "überhöhendere": "überhöhend",
    "überhöhenderem": "überhöhend",
    "überhöhenderen": "überhöhend",
    "überhöhenderer": "überhöhend",
    "überhöhenderes": "überhöhend",
    "überhöhendes": "überhöhend",
    "überhöhendste": "überhöhend",
    "überhöhendstem": "überhöhend",
    "überhöhendsten": "überhöhend",
    "überhöhendster": "überhöhend",
    "überhöhendstes": "überhöhend",
    "überhöhest": "überhöhen",
    "überhöhet": "überhöhen",
    "überhöhst": "überhöhen",
    "überhöht": "überhöhen",
    "überhöhte": "überhöht",
    "überhöhtem": "überhöht",
    "überhöhten": "überhöht",
    "überhöhter": "überhöht",
    "überhöhtere": "überhöht",
    "überhöhterem": "überhöht",
    "überhöhteren": "überhöht",
    "überhöhterer": "überhöht",
    "überhöhteres": "überhöht",
    "überhöhtes": "überhöht",
    "überhöhtest": "überhöhen",
    "überhöhteste": "überhöht",
    "überhöhtestem": "überhöht",
    "überhöhtesten": "überhöht",
    "überhöhtester": "überhöht",
    "überhöhtestes": "überhöht",
    "überhöhtet": "überhöhen",
    "überhöre": "überhören",
    "überhörend": "überhören",
    "überhörende": "überhörend",
    "überhörendem": "überhörend",
    "überhörenden": "überhörend",
    "überhörender": "überhörend",
    "überhörendes": "überhörend",
    "überhörest": "überhören",
    "überhöret": "überhören",
    "überhörst": "überhören",
    "überhört": "überhören",
    "überhörte": "überhört",
    "überhörtem": "überhört",
    "überhörten": "überhört",
    "überhörter": "überhört",
    "überhörtes": "überhört",
    "überhörtest": "überhören",
    "überhörtet": "überhören",
    "überirdische": "überirdisch",
    "überirdischem": "überirdisch",
    "überirdischen": "überirdisch",
    "überirdischer": "überirdisch",
    "überirdisches": "überirdisch",
    "überißt": "überessen",
    "überkam": "überkommen",
    "überkamen": "überkommen",
    "überkamst": "überkommen",
    "überkamt": "überkommen",
    "überkippe": "überkippen",
    "überkippend": "überkippen",
    "überkippende": "überkippend",
    "überkippendem": "überkippend",
    "überkippenden": "überkippend",
    "überkippender": "überkippend",
    "überkippendes": "überkippend",
    "überkippest": "überkippen",
    "überkippet": "überkippen",
    "überkippst": "überkippen",
    "überkippt": "überkippen",
    "überkippte": "überkippen",
    "überkippten": "überkippen",
    "überkipptest": "überkippen",
    "überkipptet": "überkippen",
    "überklebe": "überkleben",
    "überklebend": "überkleben",
    "überklebende": "überklebend",
    "überklebendem": "überklebend",
    "überklebenden": "überklebend",
    "überklebender": "überklebend",
    "überklebendes": "überklebend",
    "überklebest": "überkleben",
    "überklebet": "überkleben",
    "überklebst": "überkleben",
    "überklebt": "überkleben",
    "überklebte": "überklebt",
    "überklebtem": "überklebt",
    "überklebten": "überklebt",
    "überklebter": "überklebt",
    "überklebtes": "überklebt",
    "überklebtest": "überkleben",
    "überklebtet": "überkleben",
    "überkoche": "überkochen",
    "überkochend": "überkochen",
    "überkochende": "überkochend",
    "überkochendem": "überkochend",
    "überkochenden": "überkochend",
    "überkochender": "überkochend",
    "überkochendere": "überkochend",
    "überkochenderem": "überkochend",
    "überkochenderen": "überkochend",
    "überkochenderer": "überkochend",
    "überkochenderes": "überkochend",
    "überkochendes": "überkochend",
    "überkochendste": "überkochend",
    "überkochendstem": "überkochend",
    "überkochendsten": "überkochend",
    "überkochendster": "überkochend",
    "überkochendstes": "überkochend",
    "überkochest": "überkochen",
    "überkochet": "überkochen",
    "überkochst": "überkochen",
    "überkocht": "überkochen",
    "überkochte": "überkochen",
    "überkochten": "überkochen",
    "überkochtest": "überkochen",
    "überkochtet": "überkochen",
    "überkomme": "überkommen",
    "überkommend": "überkommen",
    "überkommende": "überkommend",
    "überkommendem": "überkommend",
    "überkommenden": "überkommend",
    "überkommender": "überkommend",
    "überkommendes": "überkommend",
    "überkommene": "überkommen",
    "überkommenem": "überkommen",
    "überkommenen": "überkommen",
    "überkommener": "überkommen",
    "überkommenes": "überkommen",
    "überkommest": "überkommen",
    "überkommet": "überkommen",
    "überkommst": "überkommen",
    "überkommt": "überkommen",
    "überkompensiere": "überkompensieren",
    "überkompensierend": "überkompensieren",
    "überkompensierende": "überkompensierend",
    "überkompensierendem": "überkompensierend",
    "überkompensierenden": "überkompensierend",
    "überkompensierender": "überkompensierend",
    "überkompensierendes": "überkompensierend",
    "überkompensierest": "überkompensieren",
    "überkompensieret": "überkompensieren",
    "überkompensierst": "überkompensieren",
    "überkompensiert": "überkompensieren",
    "überkompensierte": "überkompensiert",
    "überkompensiertem": "überkompensiert",
    "überkompensierten": "überkompensiert",
    "überkompensierter": "überkompensiert",
    "überkompensiertes": "überkompensiert",
    "überkompensiertest": "überkompensieren",
    "überkompensiertet": "überkompensieren",
    "überkriege": "überkriegen",
    "überkriegend": "überkriegen",
    "überkriegende": "überkriegend",
    "überkriegendem": "überkriegend",
    "überkriegenden": "überkriegend",
    "überkriegender": "überkriegend",
    "überkriegendes": "überkriegend",
    "überkriegest": "überkriegen",
    "überkrieget": "überkriegen",
    "überkriegst": "überkriegen",
    "überkriegt": "überkriegen",
    "überkriegte": "überkriegen",
    "überkriegten": "überkriegen",
    "überkriegtest": "überkriegen",
    "überkriegtet": "überkriegen",
    "überkritische": "überkritisch",
    "überkritischem": "überkritisch",
    "überkritischen": "überkritisch",
    "überkritischer": "überkritisch",
    "überkritisches": "überkritisch",
    "überkruste": "überkrusten",
    "überkrustend": "überkrusten",
    "überkrustende": "überkrustend",
    "überkrustendem": "überkrustend",
    "überkrustenden": "überkrustend",
    "überkrustender": "überkrustend",
    "überkrustendere": "überkrustend",
    "überkrustenderem": "überkrustend",
    "überkrustenderen": "überkrustend",
    "überkrustenderer": "überkrustend",
    "überkrustenderes": "überkrustend",
    "überkrustendes": "überkrustend",
    "überkrustendste": "überkrustend",
    "überkrustendstem": "überkrustend",
    "überkrustendsten": "überkrustend",
    "überkrustendster": "überkrustend",
    "überkrustendstes": "überkrustend",
    "überkrustest": "überkrusten",
    "überkrustet": "überkrusten",
    "überkrustete": "überkrustet",
    "überkrustetem": "überkrustet",
    "überkrusteten": "überkrustet",
    "überkrusteter": "überkrustet",
    "überkrustetere": "überkrustet",
    "überkrusteterem": "überkrustet",
    "überkrusteteren": "überkrustet",
    "überkrusteterer": "überkrustet",
    "überkrusteteres": "überkrustet",
    "überkrustetes": "überkrustet",
    "überkrustetest": "überkrusten",
    "überkrusteteste": "überkrustet",
    "überkrustetestem": "überkrustet",
    "überkrustetesten": "überkrustet",
    "überkrustetester": "überkrustet",
    "überkrustetestes": "überkrustet",
    "überkrustetet": "überkrusten",
    "überkäme": "überkommen",
    "überkämen": "überkommen",
    "überkämest": "überkommen",
    "überkämet": "überkommen",
    "überlade": "überladen",
    "überladend": "überladen",
    "überladende": "überladend",
    "überladendem": "überladend",
    "überladenden": "überladend",
    "überladender": "überladend",
    "überladendere": "überladend",
    "überladenderem": "überladend",
    "überladenderen": "überladend",
    "überladenderer": "überladend",
    "überladenderes": "überladend",
    "überladendes": "überladend",
    "überladendste": "überladend",
    "überladendstem": "überladend",
    "überladendsten": "überladend",
    "überladendster": "überladend",
    "überladendstes": "überladend",
    "überladene": "überladen",
    "überladenem": "überladen",
    "überladenen": "überladen",
    "überladener": "überladen",
    "überladenere": "überladen",
    "überladenerem": "überladen",
    "überladeneren": "überladen",
    "überladenerer": "überladen",
    "überladeneres": "überladen",
    "überladenes": "überladen",
    "überladenste": "überladen",
    "überladenstem": "überladen",
    "überladensten": "überladen",
    "überladenster": "überladen",
    "überladenstes": "überladen",
    "überladest": "überladen",
    "überladet": "überladen",
    "überlag": "überliegen",
    "überlagen": "überliegen",
    "überlagere": "überlagern",
    "überlagernd": "überlagern",
    "überlagernde": "überlagernd",
    "überlagerndem": "überlagernd",
    "überlagernden": "überlagernd",
    "überlagernder": "überlagernd",
    "überlagerndere": "überlagernd",
    "überlagernderem": "überlagernd",
    "überlagernderen": "überlagernd",
    "überlagernderer": "überlagernd",
    "überlagernderes": "überlagernd",
    "überlagerndes": "überlagernd",
    "überlagerndste": "überlagernd",
    "überlagerndstem": "überlagernd",
    "überlagerndsten": "überlagernd",
    "überlagerndster": "überlagernd",
    "überlagerndstes": "überlagernd",
    "überlagerst": "überlagern",
    "überlagert": "überlagern",
    "überlagerte": "überlagert",
    "überlagertem": "überlagert",
    "überlagerten": "überlagert",
    "überlagerter": "überlagert",
    "überlagertere": "überlagert",
    "überlagerterem": "überlagert",
    "überlagerteren": "überlagert",
    "überlagerterer": "überlagert",
    "überlagerteres": "überlagert",
    "überlagertes": "überlagert",
    "überlagertest": "überlagern",
    "überlagerteste": "überlagert",
    "überlagertestem": "überlagert",
    "überlagertesten": "überlagert",
    "überlagertester": "überlagert",
    "überlagertestes": "überlagert",
    "überlagertet": "überlagern",
    "überlagst": "überliegen",
    "überlagt": "überliegen",
    "überlappe": "überlappen",
    "überlappend": "überlappen",
    "überlappende": "überlappend",
    "überlappendem": "überlappend",
    "überlappenden": "überlappend",
    "überlappender": "überlappend",
    "überlappendere": "überlappend",
    "überlappenderem": "überlappend",
    "überlappenderen": "überlappend",
    "überlappenderer": "überlappend",
    "überlappenderes": "überlappend",
    "überlappendes": "überlappend",
    "überlappendste": "überlappend",
    "überlappendstem": "überlappend",
    "überlappendsten": "überlappend",
    "überlappendster": "überlappend",
    "überlappendstes": "überlappend",
    "überlappest": "überlappen",
    "überlappet": "überlappen",
    "überlappst": "überlappen",
    "überlappt": "überlappen",
    "überlappte": "überlappt",
    "überlapptem": "überlappt",
    "überlappten": "überlappt",
    "überlappter": "überlappt",
    "überlapptere": "überlappt",
    "überlappterem": "überlappt",
    "überlappteren": "überlappt",
    "überlappterer": "überlappt",
    "überlappteres": "überlappt",
    "überlapptes": "überlappt",
    "überlapptest": "überlappen",
    "überlappteste": "überlappt",
    "überlapptestem": "überlappt",
    "überlapptesten": "überlappt",
    "überlapptester": "überlappt",
    "überlapptestes": "überlappt",
    "überlapptet": "überlappen",
    "überlas": "überlesen",
    "überlasen": "überlesen",
    "überlasse": "überlassen",
    "überlassend": "überlassen",
    "überlassende": "überlassend",
    "überlassendem": "überlassend",
    "überlassenden": "überlassend",
    "überlassender": "überlassend",
    "überlassendes": "überlassend",
    "überlassene": "überlassen",
    "überlassenem": "überlassen",
    "überlassenen": "überlassen",
    "überlassener": "überlassen",
    "überlassenes": "überlassen",
    "überlassest": "überlassen",
    "überlasset": "überlassen",
    "überlast": "überlesen",
    "überlaste": "überlasten",
    "überlastend": "überlasten",
    "überlastende": "überlastend",
    "überlastendem": "überlastend",
    "überlastenden": "überlastend",
    "überlastender": "überlastend",
    "überlastendere": "überlastend",
    "überlastenderem": "überlastend",
    "überlastenderen": "überlastend",
    "überlastenderer": "überlastend",
    "überlastenderes": "überlastend",
    "überlastendes": "überlastend",
    "überlastendste": "überlastend",
    "überlastendstem": "überlastend",
    "überlastendsten": "überlastend",
    "überlastendster": "überlastend",
    "überlastendstes": "überlastend",
    "überlastest": "überlasten",
    "überlastet": "überlasten",
    "überlastete": "überlastet",
    "überlastetem": "überlastet",
    "überlasteten": "überlastet",
    "überlasteter": "überlastet",
    "überlastetere": "überlastet",
    "überlasteterem": "überlastet",
    "überlasteteren": "überlastet",
    "überlasteterer": "überlastet",
    "überlasteteres": "überlastet",
    "überlastetes": "überlastet",
    "überlastetest": "überlasten",
    "überlasteteste": "überlastet",
    "überlastetestem": "überlastet",
    "überlastetesten": "überlastet",
    "überlastetester": "überlastet",
    "überlastetestes": "überlastet",
    "überlastetet": "überlasten",
    "überlaufe": "überlaufen",
    "überlaufend": "überlaufen",
    "überlaufende": "überlaufend",
    "überlaufendem": "überlaufend",
    "überlaufenden": "überlaufend",
    "überlaufender": "überlaufend",
    "überlaufendere": "überlaufend",
    "überlaufenderem": "überlaufend",
    "überlaufenderen": "überlaufend",
    "überlaufenderer": "überlaufend",
    "überlaufenderes": "überlaufend",
    "überlaufendes": "überlaufend",
    "überlaufendste": "überlaufend",
    "überlaufendstem": "überlaufend",
    "überlaufendsten": "überlaufend",
    "überlaufendster": "überlaufend",
    "überlaufendstes": "überlaufend",
    "überlaufene": "überlaufen",
    "überlaufenem": "überlaufen",
    "überlaufenen": "überlaufen",
    "überlaufener": "überlaufen",
    "überlaufenere": "überlaufen",
    "überlaufenerem": "überlaufen",
    "überlaufeneren": "überlaufen",
    "überlaufenerer": "überlaufen",
    "überlaufeneres": "überlaufen",
    "überlaufenes": "überlaufen",
    "überlaufenste": "überlaufen",
    "überlaufenstem": "überlaufen",
    "überlaufensten": "überlaufen",
    "überlaufenster": "überlaufen",
    "überlaufenstes": "überlaufen",
    "überlaufest": "überlaufen",
    "überlaufet": "überlaufen",
    "überlauft": "überlaufen",
    "überlaßt": "überlassen",
    "überlebe": "überleben",
    "überlebend": "überleben",
    "überlebende": "überlebend",
    "überlebendem": "überlebend",
    "überlebenden": "überlebend",
    "überlebender": "überlebend",
    "überlebendes": "überlebend",
    "überlebensgroße": "überlebensgroß",
    "überlebensgroßem": "überlebensgroß",
    "überlebensgroßen": "überlebensgroß",
    "überlebensgroßer": "überlebensgroß",
    "überlebensgroßes": "überlebensgroß",
    "überlebest": "überleben",
    "überlebet": "überleben",
    "überlebst": "überleben",
    "überlebt": "überleben",
    "überlebte": "überlebt",
    "überlebtem": "überlebt",
    "überlebten": "überlebt",
    "überlebter": "überlebt",
    "überlebtes": "überlebt",
    "überlebtest": "überleben",
    "überlebtet": "überleben",
    "überlege": "überlegen",
    "überlegend": "überlegen",
    "überlegende": "überlegend",
    "überlegendem": "überlegend",
    "überlegenden": "überlegend",
    "überlegender": "überlegend",
    "überlegendes": "überlegend",
    "überlegene": "überlegen",
    "überlegenem": "überlegen",
    "überlegenen": "überlegen",
    "überlegener": "überlegen",
    "überlegenere": "überlegen",
    "überlegenerem": "überlegen",
    "überlegeneren": "überlegen",
    "überlegenerer": "überlegen",
    "überlegeneres": "überlegen",
    "überlegenes": "überlegen",
    "überlegenste": "überlegen",
    "überlegenstem": "überlegen",
    "überlegensten": "überlegen",
    "überlegenster": "überlegen",
    "überlegenstes": "überlegen",
    "überlegest": "überlegen",
    "überleget": "überlegen",
    "überlegst": "überlegen",
    "überlegt": "überlegen",
    "überlegte": "überlegt",
    "überlegtem": "überlegt",
    "überlegten": "überlegt",
    "überlegter": "überlegt",
    "überlegtere": "überlegt",
    "überlegterem": "überlegt",
    "überlegteren": "überlegt",
    "überlegterer": "überlegt",
    "überlegteres": "überlegt",
    "überlegtes": "überlegt",
    "überlegtest": "überlegen",
    "überlegteste": "überlegt",
    "überlegtestem": "überlegt",
    "überlegtesten": "überlegt",
    "überlegtester": "überlegt",
    "überlegtestes": "überlegt",
    "überlegtet": "überlegen",
    "überleite": "überleiten",
    "überleitend": "überleiten",
    "überleitende": "überleitend",
    "überleitendem": "überleitend",
    "überleitenden": "überleitend",
    "überleitender": "überleitend",
    "überleitendes": "überleitend",
    "überleitest": "überleiten",
    "überleitet": "überleiten",
    "überleitete": "überleiten",
    "überleiteten": "überleiten",
    "überleitetest": "überleiten",
    "überleitetet": "überleiten",
    "überlese": "überlesen",
    "überlesend": "überlesen",
    "überlesende": "überlesend",
    "überlesendem": "überlesend",
    "überlesenden": "überlesend",
    "überlesender": "überlesend",
    "überlesendes": "überlesend",
    "überlesene": "überlesen",
    "überlesenem": "überlesen",
    "überlesenen": "überlesen",
    "überlesener": "überlesen",
    "überlesenes": "überlesen",
    "überlesest": "überlesen",
    "überleset": "überlesen",
    "überlest": "überlesen",
    "überlief": "überlaufen",
    "überliefe": "überlaufen",
    "überliefen": "überlaufen",
    "überliefere": "überliefern",
    "überliefernd": "überliefern",
    "überliefernde": "überliefernd",
    "überlieferndem": "überliefernd",
    "überliefernden": "überliefernd",
    "überliefernder": "überliefernd",
    "überlieferndes": "überliefernd",
    "überlieferst": "überliefern",
    "überliefert": "überliefern",
    "überlieferte": "überliefert",
    "überliefertem": "überliefert",
    "überlieferten": "überliefert",
    "überlieferter": "überliefert",
    "überliefertes": "überliefert",
    "überliefertest": "überliefern",
    "überliefertet": "überliefern",
    "überliefest": "überlaufen",
    "überliefet": "überlaufen",
    "überliefst": "überlaufen",
    "überlieft": "überlaufen",
    "überliege": "überliegen",
    "überliegend": "überliegen",
    "überliegende": "überliegend",
    "überliegendem": "überliegend",
    "überliegenden": "überliegend",
    "überliegender": "überliegend",
    "überliegendes": "überliegend",
    "überliegest": "überliegen",
    "überlieget": "überliegen",
    "überliegst": "überliegen",
    "überliegt": "überliegen",
    "überlies": "überlesen",
    "überliest": "überlesen",
    "überließ": "überlassen",
    "überließe": "überlassen",
    "überließen": "überlassen",
    "überließest": "überlassen",
    "überließet": "überlassen",
    "überließt": "überlassen",
    "überliste": "überlisten",
    "überlistend": "überlisten",
    "überlistende": "überlistend",
    "überlistendem": "überlistend",
    "überlistenden": "überlistend",
    "überlistender": "überlistend",
    "überlistendes": "überlistend",
    "überlistest": "überlisten",
    "überlistet": "überlisten",
    "überlistete": "überlistet",
    "überlistetem": "überlistet",
    "überlisteten": "überlistet",
    "überlisteter": "überlistet",
    "überlistetes": "überlistet",
    "überlistetest": "überlisten",
    "überlistetet": "überlisten",
    "überlud": "überladen",
    "überluden": "überladen",
    "überludest": "überladen",
    "überludet": "überladen",
    "überläd": "überladen",
    "überlädst": "überladen",
    "überläge": "überliegen",
    "überlägen": "überliegen",
    "überlägest": "überliegen",
    "überläget": "überliegen",
    "überläse": "überlesen",
    "überläsen": "überlesen",
    "überläsest": "überlesen",
    "überläset": "überlesen",
    "überläufst": "überlaufen",
    "überläuft": "überlaufen",
    "überläßt": "überlassen",
    "überlüde": "überladen",
    "überlüden": "überladen",
    "überlüdest": "überladen",
    "überlüdet": "überladen",
    "übermale": "übermalen",
    "übermalend": "übermalen",
    "übermalende": "übermalend",
    "übermalendem": "übermalend",
    "übermalenden": "übermalend",
    "übermalender": "übermalend",
    "übermalendes": "übermalend",
    "übermalest": "übermalen",
    "übermalet": "übermalen",
    "übermalst": "übermalen",
    "übermalt": "übermalen",
    "übermalte": "übermalt",
    "übermaltem": "übermalt",
    "übermalten": "übermalt",
    "übermalter": "übermalt",
    "übermaltes": "übermalt",
    "übermaltest": "übermalen",
    "übermaltet": "übermalen",
    "übermanne": "übermannen",
    "übermannend": "übermannen",
    "übermannende": "übermannend",
    "übermannendem": "übermannend",
    "übermannenden": "übermannend",
    "übermannender": "übermannend",
    "übermannendes": "übermannend",
    "übermannest": "übermannen",
    "übermannet": "übermannen",
    "übermannst": "übermannen",
    "übermannt": "übermannen",
    "übermannte": "übermannt",
    "übermanntem": "übermannt",
    "übermannten": "übermannt",
    "übermannter": "übermannt",
    "übermanntes": "übermannt",
    "übermanntest": "übermannen",
    "übermanntet": "übermannen",
    "übermenschliche": "übermenschlich",
    "übermenschlichem": "übermenschlich",
    "übermenschlichen": "übermenschlich",
    "übermenschlicher": "übermenschlich",
    "übermenschliches": "übermenschlich",
    "übermittele": "übermitteln",
    "übermittelnd": "übermitteln",
    "übermittelnde": "übermittelnd",
    "übermittelndem": "übermittelnd",
    "übermittelnden": "übermittelnd",
    "übermittelnder": "übermittelnd",
    "übermittelndes": "übermittelnd",
    "übermittelst": "übermitteln",
    "übermittelt": "übermitteln",
    "übermittelte": "übermittelt",
    "übermitteltem": "übermittelt",
    "übermittelten": "übermittelt",
    "übermittelter": "übermittelt",
    "übermitteltes": "übermittelt",
    "übermitteltest": "übermitteln",
    "übermitteltet": "übermitteln",
    "übermittle": "übermitteln",
    "übermächtige": "übermächtig",
    "übermächtigem": "übermächtig",
    "übermächtigen": "übermächtig",
    "übermächtiger": "übermächtig",
    "übermächtigere": "übermächtig",
    "übermächtigerem": "übermächtig",
    "übermächtigeren": "übermächtig",
    "übermächtigerer": "übermächtig",
    "übermächtigeres": "übermächtig",
    "übermächtiges": "übermächtig",
    "übermächtigste": "übermächtig",
    "übermächtigstem": "übermächtig",
    "übermächtigsten": "übermächtig",
    "übermächtigster": "übermächtig",
    "übermächtigstes": "übermächtig",
    "übermäßige": "übermäßig",
    "übermäßigem": "übermäßig",
    "übermäßigen": "übermäßig",
    "übermäßiger": "übermäßig",
    "übermäßiges": "übermäßig",
    "übermüde": "übermüden",
    "übermüdend": "übermüden",
    "übermüdende": "übermüdend",
    "übermüdendem": "übermüdend",
    "übermüdenden": "übermüdend",
    "übermüdender": "übermüdend",
    "übermüdendes": "übermüdend",
    "übermüdest": "übermüden",
    "übermüdet": "übermüden",
    "übermüdete": "übermüdet",
    "übermüdetem": "übermüdet",
    "übermüdeten": "übermüdet",
    "übermüdeter": "übermüdet",
    "übermüdetere": "übermüdet",
    "übermüdeterem": "übermüdet",
    "übermüdeteren": "übermüdet",
    "übermüdeterer": "übermüdet",
    "übermüdeteres": "übermüdet",
    "übermüdetes": "übermüdet",
    "übermüdetest": "übermüden",
    "übermüdeteste": "übermüdet",
    "übermüdetestem": "übermüdet",
    "übermüdetesten": "übermüdet",
    "übermüdetester": "übermüdet",
    "übermüdetestes": "übermüdet",
    "übermüdetet": "übermüden",
    "übermütige": "übermütig",
    "übermütigem": "übermütig",
    "übermütigen": "übermütig",
    "übermütiger": "übermütig",
    "übermütigere": "übermütig",
    "übermütigerem": "übermütig",
    "übermütigeren": "übermütig",
    "übermütigerer": "übermütig",
    "übermütigeres": "übermütig",
    "übermütiges": "übermütig",
    "übermütigste": "übermütig",
    "übermütigstem": "übermütig",
    "übermütigsten": "übermütig",
    "übermütigster": "übermütig",
    "übermütigstes": "übermütig",
    "übernachte": "übernachten",
    "übernachtend": "übernachten",
    "übernachtende": "übernachtend",
    "übernachtendem": "übernachtend",
    "übernachtenden": "übernachtend",
    "übernachtender": "übernachtend",
    "übernachtendes": "übernachtend",
    "übernachtest": "übernachten",
    "übernachtet": "übernachten",
    "übernachtete": "übernachtet",
    "übernachtetem": "übernachtet",
    "übernachteten": "übernachtet",
    "übernachteter": "übernachtet",
    "übernachtetes": "übernachtet",
    "übernachtetest": "übernachten",
    "übernachtetet": "übernachten",
    "übernahm": "übernehmen",
    "übernahmst": "übernehmen",
    "übernahmt": "übernehmen",
    "übernatürliche": "übernatürlich",
    "übernatürlichem": "übernatürlich",
    "übernatürlichen": "übernatürlich",
    "übernatürlicher": "übernatürlich",
    "übernatürliches": "übernatürlich",
    "übernehme": "übernehmen",
    "übernehmend": "übernehmen",
    "übernehmende": "übernehmend",
    "übernehmendem": "übernehmend",
    "übernehmenden": "übernehmend",
    "übernehmender": "übernehmend",
    "übernehmendes": "übernehmend",
    "übernehmest": "übernehmen",
    "übernehmet": "übernehmen",
    "übernehmt": "übernehmen",
    "übernimm": "übernehmen",
    "übernimmst": "übernehmen",
    "übernimmt": "übernehmen",
    "übernommen": "übernehmen",
    "übernommene": "übernommen",
    "übernommenem": "übernommen",
    "übernommenen": "übernommen",
    "übernommener": "übernommen",
    "übernommenes": "übernommen",
    "übernächste": "übernächst",
    "übernächstem": "übernächst",
    "übernächsten": "übernächst",
    "übernächster": "übernächst",
    "übernächstes": "übernächst",
    "übernähme": "übernehmen",
    "übernähmen": "übernehmen",
    "übernähmest": "übernehmen",
    "übernähmet": "übernehmen",
    "überordne": "überordnen",
    "überordnend": "überordnen",
    "überordnende": "überordnend",
    "überordnendem": "überordnend",
    "überordnenden": "überordnend",
    "überordnender": "überordnend",
    "überordnendere": "überordnend",
    "überordnenderem": "überordnend",
    "überordnenderen": "überordnend",
    "überordnenderer": "überordnend",
    "überordnenderes": "überordnend",
    "überordnendes": "überordnend",
    "überordnendste": "überordnend",
    "überordnendstem": "überordnend",
    "überordnendsten": "überordnend",
    "überordnendster": "überordnend",
    "überordnendstes": "überordnend",
    "überordnest": "überordnen",
    "überordnet": "überordnen",
    "überordnete": "überordnen",
    "überordneten": "überordnen",
    "überordnetest": "überordnen",
    "überordnetet": "überordnen",
    "überparteiliche": "überparteilich",
    "überparteilichem": "überparteilich",
    "überparteilichen": "überparteilich",
    "überparteilicher": "überparteilich",
    "überparteiliches": "überparteilich",
    "überprüfe": "überprüfen",
    "überprüfend": "überprüfen",
    "überprüfende": "überprüfend",
    "überprüfendem": "überprüfend",
    "überprüfenden": "überprüfend",
    "überprüfender": "überprüfend",
    "überprüfendes": "überprüfend",
    "überprüfest": "überprüfen",
    "überprüfet": "überprüfen",
    "überprüfst": "überprüfen",
    "überprüft": "überprüfen",
    "überprüfte": "überprüft",
    "überprüftem": "überprüft",
    "überprüften": "überprüft",
    "überprüfter": "überprüft",
    "überprüftes": "überprüft",
    "überprüftest": "überprüfen",
    "überprüftet": "überprüfen",
    "überquelle": "überquellen",
    "überquellend": "überquellen",
    "überquellende": "überquellend",
    "überquellendem": "überquellend",
    "überquellenden": "überquellend",
    "überquellender": "überquellend",
    "überquellendes": "überquellend",
    "überquellest": "überquellen",
    "überquellet": "überquellen",
    "überquellst": "überquellen",
    "überquellt": "überquellen",
    "überquellte": "überquellen",
    "überquellten": "überquellen",
    "überquelltest": "überquellen",
    "überquelltet": "überquellen",
    "überquere": "überqueren",
    "überquerend": "überqueren",
    "überquerende": "überquerend",
    "überquerendem": "überquerend",
    "überquerenden": "überquerend",
    "überquerender": "überquerend",
    "überquerendes": "überquerend",
    "überquerest": "überqueren",
    "überqueret": "überqueren",
    "überquerst": "überqueren",
    "überquert": "überqueren",
    "überquerte": "überquert",
    "überquertem": "überquert",
    "überquerten": "überquert",
    "überquerter": "überquert",
    "überquertes": "überquert",
    "überquertest": "überqueren",
    "überquertet": "überqueren",
    "überquillst": "überquellen",
    "überquillt": "überquellen",
    "überquoll": "überquellen",
    "überquollen": "überquellen",
    "überquollst": "überquellen",
    "überquollt": "überquellen",
    "überquölle": "überquellen",
    "überquöllen": "überquellen",
    "überquöllest": "überquellen",
    "überquöllet": "überquellen",
    "überrage": "überragen",
    "überragend": "überragen",
    "überragende": "überragend",
    "überragendem": "überragend",
    "überragenden": "überragend",
    "überragender": "überragend",
    "überragendere": "überragend",
    "überragenderem": "überragend",
    "überragenderen": "überragend",
    "überragenderer": "überragend",
    "überragenderes": "überragend",
    "überragendes": "überragend",
    "überragendste": "überragend",
    "überragendstem": "überragend",
    "überragendsten": "überragend",
    "überragendster": "überragend",
    "überragendstes": "überragend",
    "überragest": "überragen",
    "überraget": "überragen",
    "überragst": "überragen",
    "überragt": "überragen",
    "überragte": "überragt",
    "überragtem": "überragt",
    "überragten": "überragt",
    "überragter": "überragt",
    "überragtes": "überragt",
    "überragtest": "überragen",
    "überragtet": "überragen",
    "überrannt": "überrennen",
    "überrannte": "überrennen",
    "überranntem": "überrannt",
    "überrannten": "überrennen",
    "überrannter": "überrannt",
    "überranntes": "überrannt",
    "überranntest": "überrennen",
    "überranntet": "überrennen",
    "überrasche": "überraschen",
    "überraschend": "überraschen",
    "überraschende": "überraschend",
    "überraschendem": "überraschend",
    "überraschenden": "überraschend",
    "überraschender": "überraschend",
    "überraschendere": "überraschend",
    "überraschenderem": "überraschend",
    "überraschenderen": "überraschend",
    "überraschenderer": "überraschend",
    "überraschenderes": "überraschend",
    "überraschendes": "überraschend",
    "überraschendste": "überraschend",
    "überraschendstem": "überraschend",
    "überraschendsten": "überraschend",
    "überraschendster": "überraschend",
    "überraschendstes": "überraschend",
    "überraschest": "überraschen",
    "überraschet": "überraschen",
    "überraschst": "überraschen",
    "überrascht": "überraschen",
    "überraschte": "überrascht",
    "überraschtem": "überrascht",
    "überraschten": "überrascht",
    "überraschter": "überrascht",
    "überraschtere": "überrascht",
    "überraschterem": "überrascht",
    "überraschteren": "überrascht",
    "überraschterer": "überrascht",
    "überraschteres": "überrascht",
    "überraschtes": "überrascht",
    "überraschtest": "überraschen",
    "überraschteste": "überrascht",
    "überraschtestem": "überrascht",
    "überraschtesten": "überrascht",
    "überraschtester": "überrascht",
    "überraschtestes": "überrascht",
    "überraschtet": "überraschen",
    "überrede": "überreden",
    "überredend": "überreden",
    "überredende": "überredend",
    "überredendem": "überredend",
    "überredenden": "überredend",
    "überredender": "überredend",
    "überredendes": "überredend",
    "überredest": "überreden",
    "überredet": "überreden",
    "überredete": "überredet",
    "überredetem": "überredet",
    "überredeten": "überredet",
    "überredeter": "überredet",
    "überredetes": "überredet",
    "überredetest": "überreden",
    "überredetet": "überreden",
    "überregionale": "überregional",
    "überregionalem": "überregional",
    "überregionalen": "überregional",
    "überregionaler": "überregional",
    "überregionalere": "überregional",
    "überregionalerem": "überregional",
    "überregionaleren": "überregional",
    "überregionalerer": "überregional",
    "überregionaleres": "überregional",
    "überregionales": "überregional",
    "überregionalste": "überregional",
    "überregionalstem": "überregional",
    "überregionalsten": "überregional",
    "überregionalster": "überregional",
    "überregionalstes": "überregional",
    "überreiche": "überreichen",
    "überreichend": "überreichen",
    "überreichende": "überreichend",
    "überreichendem": "überreichend",
    "überreichenden": "überreichend",
    "überreichender": "überreichend",
    "überreichendes": "überreichend",
    "überreichest": "überreichen",
    "überreichet": "überreichen",
    "überreichst": "überreichen",
    "überreicht": "überreichen",
    "überreichte": "überreicht",
    "überreichtem": "überreicht",
    "überreichten": "überreicht",
    "überreichter": "überreicht",
    "überreichtes": "überreicht",
    "überreichtest": "überreichen",
    "überreichtet": "überreichen",
    "überreize": "überreizen",
    "überreizend": "überreizen",
    "überreizende": "überreizend",
    "überreizendem": "überreizend",
    "überreizenden": "überreizend",
    "überreizender": "überreizend",
    "überreizendere": "überreizend",
    "überreizenderem": "überreizend",
    "überreizenderen": "überreizend",
    "überreizenderer": "überreizend",
    "überreizenderes": "überreizend",
    "überreizendes": "überreizend",
    "überreizendste": "überreizend",
    "überreizendstem": "überreizend",
    "überreizendsten": "überreizend",
    "überreizendster": "überreizend",
    "überreizendstes": "überreizend",
    "überreizest": "überreizen",
    "überreizet": "überreizen",
    "überreizt": "überreizen",
    "überreizte": "überreizt",
    "überreiztem": "überreizt",
    "überreizten": "überreizt",
    "überreizter": "überreizt",
    "überreiztere": "überreizt",
    "überreizterem": "überreizt",
    "überreizteren": "überreizt",
    "überreizterer": "überreizt",
    "überreizteres": "überreizt",
    "überreiztes": "überreizt",
    "überreiztest": "überreizen",
    "überreizteste": "überreizt",
    "überreiztestem": "überreizt",
    "überreiztesten": "überreizt",
    "überreiztester": "überreizt",
    "überreiztestes": "überreizt",
    "überreiztet": "überreizen",
    "überrenne": "überrennen",
    "überrennend": "überrennen",
    "überrennende": "überrennend",
    "überrennendem": "überrennend",
    "überrennenden": "überrennend",
    "überrennender": "überrennend",
    "überrennendes": "überrennend",
    "überrennest": "überrennen",
    "überrennet": "überrennen",
    "überrennst": "überrennen",
    "überrennt": "überrennen",
    "überrolle": "überrollen",
    "überrollend": "überrollen",
    "überrollende": "überrollend",
    "überrollendem": "überrollend",
    "überrollenden": "überrollend",
    "überrollender": "überrollend",
    "überrollendes": "überrollend",
    "überrollest": "überrollen",
    "überrollet": "überrollen",
    "überrollst": "überrollen",
    "überrollt": "überrollen",
    "überrollte": "überrollt",
    "überrolltem": "überrollt",
    "überrollten": "überrollt",
    "überrollter": "überrollt",
    "überrolltes": "überrollt",
    "überrolltest": "überrollen",
    "überrolltet": "überrollen",
    "überrumpele": "überrumpeln",
    "überrumpelnd": "überrumpeln",
    "überrumpelnde": "überrumpelnd",
    "überrumpelndem": "überrumpelnd",
    "überrumpelnden": "überrumpelnd",
    "überrumpelnder": "überrumpelnd",
    "überrumpelndere": "überrumpelnd",
    "überrumpelnderem": "überrumpelnd",
    "überrumpelnderen": "überrumpelnd",
    "überrumpelnderer": "überrumpelnd",
    "überrumpelnderes": "überrumpelnd",
    "überrumpelndes": "überrumpelnd",
    "überrumpelndste": "überrumpelnd",
    "überrumpelndstem": "überrumpelnd",
    "überrumpelndsten": "überrumpelnd",
    "überrumpelndster": "überrumpelnd",
    "überrumpelndstes": "überrumpelnd",
    "überrumpelst": "überrumpeln",
    "überrumpelt": "überrumpeln",
    "überrumpelte": "überrumpelt",
    "überrumpeltem": "überrumpelt",
    "überrumpelten": "überrumpelt",
    "überrumpelter": "überrumpelt",
    "überrumpeltere": "überrumpelt",
    "überrumpelterem": "überrumpelt",
    "überrumpelteren": "überrumpelt",
    "überrumpelterer": "überrumpelt",
    "überrumpelteres": "überrumpelt",
    "überrumpeltes": "überrumpelt",
    "überrumpeltest": "überrumpeln",
    "überrumpelteste": "überrumpelt",
    "überrumpeltestem": "überrumpelt",
    "überrumpeltesten": "überrumpelt",
    "überrumpeltester": "überrumpelt",
    "überrumpeltestes": "überrumpelt",
    "überrumpeltet": "überrumpeln",
    "überrumple": "überrumpeln",
    "überrunde": "überrunden",
    "überrundend": "überrunden",
    "überrundende": "überrundend",
    "überrundendem": "überrundend",
    "überrundenden": "überrundend",
    "überrundender": "überrundend",
    "überrundendes": "überrundend",
    "überrundest": "überrunden",
    "überrundet": "überrunden",
    "überrundete": "überrundet",
    "überrundetem": "überrundet",
    "überrundeten": "überrundet",
    "überrundeter": "überrundet",
    "überrundetes": "überrundet",
    "überrundetest": "überrunden",
    "überrundetet": "überrunden",
    "übersah": "übersehen",
    "übersahen": "übersehen",
    "übersahst": "übersehen",
    "übersaht": "übersehen",
    "übersandt": "übersenden",
    "übersandte": "übersenden",
    "übersandtem": "übersandt",
    "übersandten": "übersenden",
    "übersandter": "übersandt",
    "übersandtes": "übersandt",
    "übersandtest": "übersenden",
    "übersandtet": "übersenden",
    "überscharfe": "überscharf",
    "überscharfem": "überscharf",
    "überscharfen": "überscharf",
    "überscharfer": "überscharf",
    "überscharfes": "überscharf",
    "überschatte": "überschatten",
    "überschattend": "überschatten",
    "überschattende": "überschattend",
    "überschattendem": "überschattend",
    "überschattenden": "überschattend",
    "überschattender": "überschattend",
    "überschattendes": "überschattend",
    "überschattest": "überschatten",
    "überschattet": "überschatten",
    "überschattete": "überschattet",
    "überschattetem": "überschattet",
    "überschatteten": "überschattet",
    "überschatteter": "überschattet",
    "überschattetes": "überschattet",
    "überschattetest": "überschatten",
    "überschattetet": "überschatten",
    "überschaue": "überschauen",
    "überschauend": "überschauen",
    "überschauende": "überschauend",
    "überschauendem": "überschauend",
    "überschauenden": "überschauend",
    "überschauender": "überschauend",
    "überschauendes": "überschauend",
    "überschauest": "überschauen",
    "überschauet": "überschauen",
    "überschaust": "überschauen",
    "überschaut": "überschauen",
    "überschaute": "überschaut",
    "überschautem": "überschaut",
    "überschauten": "überschaut",
    "überschauter": "überschaut",
    "überschautes": "überschaut",
    "überschautest": "überschauen",
    "überschautet": "überschauen",
    "überschlafe": "überschlafen",
    "überschlafend": "überschlafen",
    "überschlafende": "überschlafend",
    "überschlafendem": "überschlafend",
    "überschlafenden": "überschlafend",
    "überschlafender": "überschlafend",
    "überschlafendes": "überschlafend",
    "überschlafene": "überschlafen",
    "überschlafenem": "überschlafen",
    "überschlafenen": "überschlafen",
    "überschlafener": "überschlafen",
    "überschlafenes": "überschlafen",
    "überschlafest": "überschlafen",
    "überschlafet": "überschlafen",
    "überschlaft": "überschlafen",
    "überschlagend": "überschlagen",
    "überschlagende": "überschlagend",
    "überschlagendem": "überschlagend",
    "überschlagenden": "überschlagend",
    "überschlagender": "überschlagend",
    "überschlagendes": "überschlagend",
    "überschlagene": "überschlagen",
    "überschlagenem": "überschlagen",
    "überschlagenen": "überschlagen",
    "überschlagener": "überschlagen",
    "überschlagenes": "überschlagen",
    "überschlagest": "überschlagen",
    "überschlaget": "überschlagen",
    "überschlagt": "überschlagen",
    "überschlief": "überschlafen",
    "überschliefe": "überschlafen",
    "überschliefen": "überschlafen",
    "überschliefest": "überschlafen",
    "überschliefet": "überschlafen",
    "überschliefst": "überschlafen",
    "überschlieft": "überschlafen",
    "überschlug": "überschlagen",
    "überschlugen": "überschlagen",
    "überschlugst": "überschlagen",
    "überschlugt": "überschlagen",
    "überschläfst": "überschlafen",
    "überschläft": "überschlafen",
    "überschlägst": "überschlagen",
    "überschlägt": "überschlagen",
    "überschlüge": "überschlagen",
    "überschlügen": "überschlagen",
    "überschlügest": "überschlagen",
    "überschlüget": "überschlagen",
    "überschnappe": "überschnappen",
    "überschnappend": "überschnappen",
    "überschnappende": "überschnappend",
    "überschnappendem": "überschnappend",
    "überschnappenden": "überschnappend",
    "überschnappender": "überschnappend",
    "überschnappendere": "überschnappend",
    "überschnappenderem": "überschnappend",
    "überschnappenderen": "überschnappend",
    "überschnappenderer": "überschnappend",
    "überschnappenderes": "überschnappend",
    "überschnappendes": "überschnappend",
    "überschnappendste": "überschnappend",
    "überschnappendstem": "überschnappend",
    "überschnappendsten": "überschnappend",
    "überschnappendster": "überschnappend",
    "überschnappendstes": "überschnappend",
    "überschnappest": "überschnappen",
    "überschnappet": "überschnappen",
    "überschnappst": "überschnappen",
    "überschnappt": "überschnappen",
    "überschnappte": "überschnappen",
    "überschnappten": "überschnappen",
    "überschnapptest": "überschnappen",
    "überschnapptet": "überschnappen",
    "überschneide": "überschneiden",
    "überschneidend": "überschneiden",
    "überschneidende": "überschneidend",
    "überschneidendem": "überschneidend",
    "überschneidenden": "überschneidend",
    "überschneidender": "überschneidend",
    "überschneidendere": "überschneidend",
    "überschneidenderem": "überschneidend",
    "überschneidenderen": "überschneidend",
    "überschneidenderer": "überschneidend",
    "überschneidenderes": "überschneidend",
    "überschneidendes": "überschneidend",
    "überschneidendste": "überschneidend",
    "überschneidendstem": "überschneidend",
    "überschneidendsten": "überschneidend",
    "überschneidendster": "überschneidend",
    "überschneidendstes": "überschneidend",
    "überschneidest": "überschneiden",
    "überschneidet": "überschneiden",
    "überschnitt": "überschneiden",
    "überschnitte": "überschneiden",
    "überschnitten": "überschneiden",
    "überschnittene": "überschnitten",
    "überschnittenem": "überschnitten",
    "überschnittenen": "überschnitten",
    "überschnittener": "überschnitten",
    "überschnittenere": "überschnitten",
    "überschnittenerem": "überschnitten",
    "überschnitteneren": "überschnitten",
    "überschnittenerer": "überschnitten",
    "überschnitteneres": "überschnitten",
    "überschnittenes": "überschnitten",
    "überschnittenste": "überschnitten",
    "überschnittenstem": "überschnitten",
    "überschnittensten": "überschnitten",
    "überschnittenster": "überschnitten",
    "überschnittenstes": "überschnitten",
    "überschnittest": "überschneiden",
    "überschnittet": "überschneiden",
    "überschreibe": "überschreiben",
    "überschreibend": "überschreiben",
    "überschreibende": "überschreibend",
    "überschreibendem": "überschreibend",
    "überschreibenden": "überschreibend",
    "überschreibender": "überschreibend",
    "überschreibendes": "überschreibend",
    "überschreibest": "überschreiben",
    "überschreibet": "überschreiben",
    "überschreibst": "überschreiben",
    "überschreibt": "überschreiben",
    "überschreite": "überschreiten",
    "überschreitend": "überschreiten",
    "überschreitende": "überschreitend",
    "überschreitendem": "überschreitend",
    "überschreitenden": "überschreitend",
    "überschreitender": "überschreitend",
    "überschreitendes": "überschreitend",
    "überschreitest": "überschreiten",
    "überschreitet": "überschreiten",
    "überschrieb": "überschreiben",
    "überschriebe": "überschreiben",
    "überschrieben": "überschreiben",
    "überschriebene": "überschrieben",
    "überschriebenem": "überschrieben",
    "überschriebenen": "überschrieben",
    "überschriebener": "überschrieben",
    "überschriebenes": "überschrieben",
    "überschriebest": "überschreiben",
    "überschriebet": "überschreiben",
    "überschriebst": "überschreiben",
    "überschriebt": "überschreiben",
    "überschritt": "überschreiten",
    "überschritte": "überschreiten",
    "überschritten": "überschreiten",
    "überschrittene": "überschritten",
    "überschrittenem": "überschritten",
    "überschrittenen": "überschritten",
    "überschrittener": "überschritten",
    "überschrittenes": "überschritten",
    "überschrittest": "überschreiten",
    "überschrittet": "überschreiten",
    "überschuldete": "überschuldet",
    "überschuldetem": "überschuldet",
    "überschuldeten": "überschuldet",
    "überschuldeter": "überschuldet",
    "überschuldetes": "überschuldet",
    "überschwappe": "überschwappen",
    "überschwappend": "überschwappen",
    "überschwappende": "überschwappend",
    "überschwappendem": "überschwappend",
    "überschwappenden": "überschwappend",
    "überschwappender": "überschwappend",
    "überschwappendere": "überschwappend",
    "überschwappenderem": "überschwappend",
    "überschwappenderen": "überschwappend",
    "überschwappenderer": "überschwappend",
    "überschwappenderes": "überschwappend",
    "überschwappendes": "überschwappend",
    "überschwappendste": "überschwappend",
    "überschwappendstem": "überschwappend",
    "überschwappendsten": "überschwappend",
    "überschwappendster": "überschwappend",
    "überschwappendstes": "überschwappend",
    "überschwappest": "überschwappen",
    "überschwappet": "überschwappen",
    "überschwappst": "überschwappen",
    "überschwappt": "überschwappen",
    "überschwappte": "überschwappen",
    "überschwappten": "überschwappen",
    "überschwapptest": "überschwappen",
    "überschwapptet": "überschwappen",
    "überschwemme": "überschwemmen",
    "überschwemmend": "überschwemmen",
    "überschwemmende": "überschwemmend",
    "überschwemmendem": "überschwemmend",
    "überschwemmenden": "überschwemmend",
    "überschwemmender": "überschwemmend",
    "überschwemmendere": "überschwemmend",
    "überschwemmenderem": "überschwemmend",
    "überschwemmenderen": "überschwemmend",
    "überschwemmenderer": "überschwemmend",
    "überschwemmenderes": "überschwemmend",
    "überschwemmendes": "überschwemmend",
    "überschwemmendste": "überschwemmend",
    "überschwemmendstem": "überschwemmend",
    "überschwemmendsten": "überschwemmend",
    "überschwemmendster": "überschwemmend",
    "überschwemmendstes": "überschwemmend",
    "überschwemmest": "überschwemmen",
    "überschwemmet": "überschwemmen",
    "überschwemmst": "überschwemmen",
    "überschwemmt": "überschwemmen",
    "überschwemmte": "überschwemmt",
    "überschwemmtem": "überschwemmt",
    "überschwemmten": "überschwemmt",
    "überschwemmter": "überschwemmt",
    "überschwemmtere": "überschwemmt",
    "überschwemmterem": "überschwemmt",
    "überschwemmteren": "überschwemmt",
    "überschwemmterer": "überschwemmt",
    "überschwemmteres": "überschwemmt",
    "überschwemmtes": "überschwemmt",
    "überschwemmtest": "überschwemmen",
    "überschwemmteste": "überschwemmt",
    "überschwemmtestem": "überschwemmt",
    "überschwemmtesten": "überschwemmt",
    "überschwemmtester": "überschwemmt",
    "überschwemmtestes": "überschwemmt",
    "überschwemmtet": "überschwemmen",
    "überschwengliche": "überschwenglich",
    "überschwenglichem": "überschwenglich",
    "überschwenglichen": "überschwenglich",
    "überschwenglicher": "überschwenglich",
    "überschwengliches": "überschwenglich",
    "überschwängliche": "überschwänglich",
    "überschwänglichem": "überschwänglich",
    "überschwänglichen": "überschwänglich",
    "überschwänglicher": "überschwänglich",
    "überschwänglichere": "überschwänglich",
    "überschwänglicherem": "überschwänglich",
    "überschwänglicheren": "überschwänglich",
    "überschwänglicherer": "überschwänglich",
    "überschwänglicheres": "überschwänglich",
    "überschwängliches": "überschwänglich",
    "überschwänglichste": "überschwänglich",
    "überschwänglichstem": "überschwänglich",
    "überschwänglichsten": "überschwänglich",
    "überschwänglichster": "überschwänglich",
    "überschwänglichstes": "überschwänglich",
    "überschätze": "überschätzen",
    "überschätzend": "überschätzen",
    "überschätzende": "überschätzend",
    "überschätzendem": "überschätzend",
    "überschätzenden": "überschätzend",
    "überschätzender": "überschätzend",
    "überschätzendere": "überschätzend",
    "überschätzenderem": "überschätzend",
    "überschätzenderen": "überschätzend",
    "überschätzenderer": "überschätzend",
    "überschätzenderes": "überschätzend",
    "überschätzendes": "überschätzend",
    "überschätzendste": "überschätzend",
    "überschätzendstem": "überschätzend",
    "überschätzendsten": "überschätzend",
    "überschätzendster": "überschätzend",
    "überschätzendstes": "überschätzend",
    "überschätzest": "überschätzen",
    "überschätzet": "überschätzen",
    "überschätzt": "überschätzen",
    "überschätzte": "überschätzt",
    "überschätztem": "überschätzt",
    "überschätzten": "überschätzt",
    "überschätzter": "überschätzt",
    "überschätztere": "überschätzt",
    "überschätzterem": "überschätzt",
    "überschätzteren": "überschätzt",
    "überschätzterer": "überschätzt",
    "überschätzteres": "überschätzt",
    "überschätztes": "überschätzt",
    "überschätztest": "überschätzen",
    "überschätzteste": "überschätzt",
    "überschätztestem": "überschätzt",
    "überschätztesten": "überschätzt",
    "überschätztester": "überschätzt",
    "überschätztestes": "überschätzt",
    "überschätztet": "überschätzen",
    "überschäume": "überschäumen",
    "überschäumend": "überschäumen",
    "überschäumende": "überschäumend",
    "überschäumendem": "überschäumend",
    "überschäumenden": "überschäumend",
    "überschäumender": "überschäumend",
    "überschäumendere": "überschäumend",
    "überschäumenderem": "überschäumend",
    "überschäumenderen": "überschäumend",
    "überschäumenderer": "überschäumend",
    "überschäumenderes": "überschäumend",
    "überschäumendes": "überschäumend",
    "überschäumendste": "überschäumend",
    "überschäumendstem": "überschäumend",
    "überschäumendsten": "überschäumend",
    "überschäumendster": "überschäumend",
    "überschäumendstes": "überschäumend",
    "überschäumest": "überschäumen",
    "überschäumet": "überschäumen",
    "überschäumst": "überschäumen",
    "überschäumt": "überschäumen",
    "überschäumte": "überschäumen",
    "überschäumten": "überschäumen",
    "überschäumtest": "überschäumen",
    "überschäumtet": "überschäumen",
    "übersehbare": "übersehbar",
    "übersehbarem": "übersehbar",
    "übersehbaren": "übersehbar",
    "übersehbarer": "übersehbar",
    "übersehbares": "übersehbar",
    "übersehe": "übersehen",
    "übersehend": "übersehen",
    "übersehende": "übersehend",
    "übersehendem": "übersehend",
    "übersehenden": "übersehend",
    "übersehender": "übersehend",
    "übersehendes": "übersehend",
    "übersehene": "übersehen",
    "übersehenem": "übersehen",
    "übersehenen": "übersehen",
    "übersehener": "übersehen",
    "übersehenere": "übersehen",
    "übersehenerem": "übersehen",
    "überseheneren": "übersehen",
    "übersehenerer": "übersehen",
    "überseheneres": "übersehen",
    "übersehenes": "übersehen",
    "übersehenste": "übersehen",
    "übersehenstem": "übersehen",
    "übersehensten": "übersehen",
    "übersehenster": "übersehen",
    "übersehenstes": "übersehen",
    "übersehest": "übersehen",
    "übersehet": "übersehen",
    "überseht": "übersehen",
    "übersende": "übersenden",
    "übersendend": "übersenden",
    "übersendende": "übersendend",
    "übersendendem": "übersendend",
    "übersendenden": "übersendend",
    "übersendender": "übersendend",
    "übersendendes": "übersendend",
    "übersendest": "übersenden",
    "übersendet": "übersenden",
    "übersetze": "übersetzen",
    "übersetzend": "übersetzen",
    "übersetzende": "übersetzend",
    "übersetzendem": "übersetzend",
    "übersetzenden": "übersetzend",
    "übersetzender": "übersetzend",
    "übersetzendes": "übersetzend",
    "übersetzest": "übersetzen",
    "übersetzet": "übersetzen",
    "übersetzt": "übersetzen",
    "übersetzte": "übersetzt",
    "übersetztem": "übersetzt",
    "übersetzten": "übersetzt",
    "übersetzter": "übersetzt",
    "übersetztes": "übersetzt",
    "übersetztest": "übersetzen",
    "übersetztet": "übersetzen",
    "übersichtliche": "übersichtlich",
    "übersichtlichem": "übersichtlich",
    "übersichtlichen": "übersichtlich",
    "übersichtlicher": "übersichtlich",
    "übersichtlichere": "übersichtlich",
    "übersichtlicherem": "übersichtlich",
    "übersichtlicheren": "übersichtlich",
    "übersichtlicherer": "übersichtlich",
    "übersichtlicheres": "übersichtlich",
    "übersichtliches": "übersichtlich",
    "übersichtlichste": "übersichtlich",
    "übersichtlichstem": "übersichtlich",
    "übersichtlichsten": "übersichtlich",
    "übersichtlichster": "übersichtlich",
    "übersichtlichstes": "übersichtlich",
    "übersieh": "übersehen",
    "übersiehst": "übersehen",
    "übersieht": "übersehen",
    "übersinnliche": "übersinnlich",
    "übersinnlichem": "übersinnlich",
    "übersinnlichen": "übersinnlich",
    "übersinnlicher": "übersinnlich",
    "übersinnliches": "übersinnlich",
    "überspanne": "überspannen",
    "überspannend": "überspannen",
    "überspannende": "überspannend",
    "überspannendem": "überspannend",
    "überspannenden": "überspannend",
    "überspannender": "überspannend",
    "überspannendere": "überspannend",
    "überspannenderem": "überspannend",
    "überspannenderen": "überspannend",
    "überspannenderer": "überspannend",
    "überspannenderes": "überspannend",
    "überspannendes": "überspannend",
    "überspannendste": "überspannend",
    "überspannendstem": "überspannend",
    "überspannendsten": "überspannend",
    "überspannendster": "überspannend",
    "überspannendstes": "überspannend",
    "überspannest": "überspannen",
    "überspannet": "überspannen",
    "überspannst": "überspannen",
    "überspannt": "überspannen",
    "überspannte": "überspannt",
    "überspanntem": "überspannt",
    "überspannten": "überspannt",
    "überspannter": "überspannt",
    "überspanntere": "überspannt",
    "überspannterem": "überspannt",
    "überspannteren": "überspannt",
    "überspannterer": "überspannt",
    "überspannteres": "überspannt",
    "überspanntes": "überspannt",
    "überspanntest": "überspannen",
    "überspannteste": "überspannt",
    "überspanntestem": "überspannt",
    "überspanntesten": "überspannt",
    "überspanntester": "überspannt",
    "überspanntestes": "überspannt",
    "überspanntet": "überspannen",
    "überspiele": "überspielen",
    "überspielend": "überspielen",
    "überspielende": "überspielend",
    "überspielendem": "überspielend",
    "überspielenden": "überspielend",
    "überspielender": "überspielend",
    "überspielendes": "überspielend",
    "überspielest": "überspielen",
    "überspielet": "überspielen",
    "überspielst": "überspielen",
    "überspielt": "überspielen",
    "überspielte": "überspielt",
    "überspieltem": "überspielt",
    "überspielten": "überspielt",
    "überspielter": "überspielt",
    "überspieltes": "überspielt",
    "überspieltest": "überspielen",
    "überspieltet": "überspielen",
    "überspinne": "überspinnen",
    "überspinnend": "überspinnen",
    "überspinnende": "überspinnend",
    "überspinnendem": "überspinnend",
    "überspinnenden": "überspinnend",
    "überspinnender": "überspinnend",
    "überspinnendes": "überspinnend",
    "überspinnest": "überspinnen",
    "überspinnet": "überspinnen",
    "überspinnst": "überspinnen",
    "überspinnt": "überspinnen",
    "überspitze": "überspitzen",
    "überspitzend": "überspitzen",
    "überspitzende": "überspitzend",
    "überspitzendem": "überspitzend",
    "überspitzenden": "überspitzend",
    "überspitzender": "überspitzend",
    "überspitzendere": "überspitzend",
    "überspitzenderem": "überspitzend",
    "überspitzenderen": "überspitzend",
    "überspitzenderer": "überspitzend",
    "überspitzenderes": "überspitzend",
    "überspitzendes": "überspitzend",
    "überspitzendste": "überspitzend",
    "überspitzendstem": "überspitzend",
    "überspitzendsten": "überspitzend",
    "überspitzendster": "überspitzend",
    "überspitzendstes": "überspitzend",
    "überspitzest": "überspitzen",
    "überspitzet": "überspitzen",
    "überspitzt": "überspitzen",
    "überspitzte": "überspitzt",
    "überspitztem": "überspitzt",
    "überspitzten": "überspitzt",
    "überspitzter": "überspitzt",
    "überspitztere": "überspitzt",
    "überspitzterem": "überspitzt",
    "überspitzteren": "überspitzt",
    "überspitzterer": "überspitzt",
    "überspitzteres": "überspitzt",
    "überspitztes": "überspitzt",
    "überspitztest": "überspitzen",
    "überspitzteste": "überspitzt",
    "überspitztestem": "überspitzt",
    "überspitztesten": "überspitzt",
    "überspitztester": "überspitzt",
    "überspitztestes": "überspitzt",
    "überspitztet": "überspitzen",
    "übersponn": "überspinnen",
    "übersponnen": "überspinnen",
    "übersponnene": "übersponnen",
    "übersponnenem": "übersponnen",
    "übersponnenen": "übersponnen",
    "übersponnener": "übersponnen",
    "übersponnenere": "übersponnen",
    "übersponnenerem": "übersponnen",
    "übersponneneren": "übersponnen",
    "übersponnenerer": "übersponnen",
    "übersponneneres": "übersponnen",
    "übersponnenes": "übersponnen",
    "übersponnenste": "übersponnen",
    "übersponnenstem": "übersponnen",
    "übersponnensten": "übersponnen",
    "übersponnenster": "übersponnen",
    "übersponnenstes": "übersponnen",
    "übersponnst": "überspinnen",
    "übersponnt": "überspinnen",
    "übersprang": "überspringen",
    "übersprangen": "überspringen",
    "übersprangst": "überspringen",
    "übersprangt": "überspringen",
    "überspringe": "überspringen",
    "überspringend": "überspringen",
    "überspringende": "überspringend",
    "überspringendem": "überspringend",
    "überspringenden": "überspringend",
    "überspringender": "überspringend",
    "überspringendes": "überspringend",
    "überspringest": "überspringen",
    "überspringet": "überspringen",
    "überspringst": "überspringen",
    "überspringt": "überspringen",
    "übersprudele": "übersprudeln",
    "übersprudelnd": "übersprudeln",
    "übersprudelnde": "übersprudelnd",
    "übersprudelndem": "übersprudelnd",
    "übersprudelnden": "übersprudelnd",
    "übersprudelnder": "übersprudelnd",
    "übersprudelndes": "übersprudelnd",
    "übersprudelst": "übersprudeln",
    "übersprudelt": "übersprudeln",
    "übersprudelte": "übersprudeln",
    "übersprudelten": "übersprudeln",
    "übersprudeltest": "übersprudeln",
    "übersprudeltet": "übersprudeln",
    "übersprudle": "übersprudeln",
    "übersprungen": "überspringen",
    "übersprungene": "übersprungen",
    "übersprungenem": "übersprungen",
    "übersprungenen": "übersprungen",
    "übersprungener": "übersprungen",
    "übersprungenes": "übersprungen",
    "überspränge": "überspringen",
    "übersprängen": "überspringen",
    "übersprängest": "überspringen",
    "überspränget": "überspringen",
    "überspönne": "überspinnen",
    "überspönnen": "überspinnen",
    "überspönnest": "überspinnen",
    "überspönnet": "überspinnen",
    "überstand": "überstehen",
    "überstanden": "überstehen",
    "überstandene": "überstanden",
    "überstandenem": "überstanden",
    "überstandenen": "überstanden",
    "überstandener": "überstanden",
    "überstandenes": "überstanden",
    "überstandest": "überstehen",
    "überstandet": "überstehen",
    "überstehe": "überstehen",
    "überstehend": "überstehen",
    "überstehende": "überstehend",
    "überstehendem": "überstehend",
    "überstehenden": "überstehend",
    "überstehender": "überstehend",
    "überstehendes": "überstehend",
    "überstehest": "überstehen",
    "überstehet": "überstehen",
    "überstehst": "überstehen",
    "übersteht": "überstehen",
    "übersteige": "übersteigen",
    "übersteigend": "übersteigen",
    "übersteigende": "übersteigend",
    "übersteigendem": "übersteigend",
    "übersteigenden": "übersteigend",
    "übersteigender": "übersteigend",
    "übersteigendes": "übersteigend",
    "übersteigest": "übersteigen",
    "übersteiget": "übersteigen",
    "übersteigst": "übersteigen",
    "übersteigt": "übersteigen",
    "überstelle": "überstellen",
    "überstellend": "überstellen",
    "überstellende": "überstellend",
    "überstellendem": "überstellend",
    "überstellenden": "überstellend",
    "überstellender": "überstellend",
    "überstellendes": "überstellend",
    "überstellest": "überstellen",
    "überstellet": "überstellen",
    "überstellst": "überstellen",
    "überstellt": "überstellen",
    "überstellte": "überstellt",
    "überstelltem": "überstellt",
    "überstellten": "überstellt",
    "überstellter": "überstellt",
    "überstelltes": "überstellt",
    "überstelltest": "überstellen",
    "überstelltet": "überstellen",
    "überstieg": "übersteigen",
    "überstiege": "übersteigen",
    "überstiegen": "übersteigen",
    "überstiegene": "überstiegen",
    "überstiegenem": "überstiegen",
    "überstiegenen": "überstiegen",
    "überstiegener": "überstiegen",
    "überstiegenes": "überstiegen",
    "überstiegest": "übersteigen",
    "überstieget": "übersteigen",
    "überstiegst": "übersteigen",
    "überstiegt": "übersteigen",
    "überstimme": "überstimmen",
    "überstimmend": "überstimmen",
    "überstimmende": "überstimmend",
    "überstimmendem": "überstimmend",
    "überstimmenden": "überstimmend",
    "überstimmender": "überstimmend",
    "überstimmendes": "überstimmend",
    "überstimmest": "überstimmen",
    "überstimmet": "überstimmen",
    "überstimmst": "überstimmen",
    "überstimmt": "überstimmen",
    "überstimmte": "überstimmt",
    "überstimmtem": "überstimmt",
    "überstimmten": "überstimmt",
    "überstimmter": "überstimmt",
    "überstimmtes": "überstimmt",
    "überstimmtest": "überstimmen",
    "überstimmtet": "überstimmen",
    "überstrahle": "überstrahlen",
    "überstrahlend": "überstrahlen",
    "überstrahlende": "überstrahlend",
    "überstrahlendem": "überstrahlend",
    "überstrahlenden": "überstrahlend",
    "überstrahlender": "überstrahlend",
    "überstrahlendes": "überstrahlend",
    "überstrahlest": "überstrahlen",
    "überstrahlet": "überstrahlen",
    "überstrahlst": "überstrahlen",
    "überstrahlt": "überstrahlen",
    "überstrahlte": "überstrahlt",
    "überstrahltem": "überstrahlt",
    "überstrahlten": "überstrahlt",
    "überstrahlter": "überstrahlt",
    "überstrahltes": "überstrahlt",
    "überstrahltest": "überstrahlen",
    "überstrahltet": "überstrahlen",
    "überstrapaziere": "überstrapazieren",
    "überstrapazierend": "überstrapazieren",
    "überstrapazierende": "überstrapazierend",
    "überstrapazierendem": "überstrapazierend",
    "überstrapazierenden": "überstrapazierend",
    "überstrapazierender": "überstrapazierend",
    "überstrapazierendere": "überstrapazierend",
    "überstrapazierenderem": "überstrapazierend",
    "überstrapazierenderen": "überstrapazierend",
    "überstrapazierenderer": "überstrapazierend",
    "überstrapazierenderes": "überstrapazierend",
    "überstrapazierendes": "überstrapazierend",
    "überstrapazierendste": "überstrapazierend",
    "überstrapazierendstem": "überstrapazierend",
    "überstrapazierendsten": "überstrapazierend",
    "überstrapazierendster": "überstrapazierend",
    "überstrapazierendstes": "überstrapazierend",
    "überstrapazierest": "überstrapazieren",
    "überstrapazieret": "überstrapazieren",
    "überstrapazierst": "überstrapazieren",
    "überstrapaziert": "überstrapazieren",
    "überstrapazierte": "überstrapaziert",
    "überstrapaziertem": "überstrapaziert",
    "überstrapazierten": "überstrapaziert",
    "überstrapazierter": "überstrapaziert",
    "überstrapaziertere": "überstrapaziert",
    "überstrapazierterem": "überstrapaziert",
    "überstrapazierteren": "überstrapaziert",
    "überstrapazierterer": "überstrapaziert",
    "überstrapazierteres": "überstrapaziert",
    "überstrapaziertes": "überstrapaziert",
    "überstrapaziertest": "überstrapazieren",
    "überstrapazierteste": "überstrapaziert",
    "überstrapaziertestem": "überstrapaziert",
    "überstrapaziertesten": "überstrapaziert",
    "überstrapaziertester": "überstrapaziert",
    "überstrapaziertestes": "überstrapaziert",
    "überstrapaziertet": "überstrapazieren",
    "überstreiche": "überstreichen",
    "überstreichend": "überstreichen",
    "überstreichende": "überstreichend",
    "überstreichendem": "überstreichend",
    "überstreichenden": "überstreichend",
    "überstreichender": "überstreichend",
    "überstreichendes": "überstreichend",
    "überstreichest": "überstreichen",
    "überstreichet": "überstreichen",
    "überstreichst": "überstreichen",
    "überstreicht": "überstreichen",
    "überstreife": "überstreifen",
    "überstreifend": "überstreifen",
    "überstreifende": "überstreifend",
    "überstreifendem": "überstreifend",
    "überstreifenden": "überstreifend",
    "überstreifender": "überstreifend",
    "überstreifendes": "überstreifend",
    "überstreifest": "überstreifen",
    "überstreifet": "überstreifen",
    "überstreifst": "überstreifen",
    "überstreift": "überstreifen",
    "überstreifte": "überstreifen",
    "überstreiften": "überstreifen",
    "überstreiftest": "überstreifen",
    "überstreiftet": "überstreifen",
    "überstrich": "überstreichen",
    "überstriche": "überstreichen",
    "überstrichen": "überstreichen",
    "überstrichene": "überstrichen",
    "überstrichenem": "überstrichen",
    "überstrichenen": "überstrichen",
    "überstrichener": "überstrichen",
    "überstrichenes": "überstrichen",
    "überstrichest": "überstreichen",
    "überstrichet": "überstreichen",
    "überstrichst": "überstreichen",
    "überstricht": "überstreichen",
    "überströme": "überströmen",
    "überströmend": "überströmen",
    "überströmende": "überströmend",
    "überströmendem": "überströmend",
    "überströmenden": "überströmend",
    "überströmender": "überströmend",
    "überströmendes": "überströmend",
    "überströmest": "überströmen",
    "überströmet": "überströmen",
    "überströmst": "überströmen",
    "überströmt": "überströmen",
    "überströmte": "überströmen",
    "überströmten": "überströmen",
    "überströmtest": "überströmen",
    "überströmtet": "überströmen",
    "überstände": "überstehen",
    "überständen": "überstehen",
    "überständest": "überstehen",
    "überständet": "überstehen",
    "überstürze": "überstürzen",
    "überstürzend": "überstürzen",
    "überstürzende": "überstürzend",
    "überstürzendem": "überstürzend",
    "überstürzenden": "überstürzend",
    "überstürzender": "überstürzend",
    "überstürzendere": "überstürzend",
    "überstürzenderem": "überstürzend",
    "überstürzenderen": "überstürzend",
    "überstürzenderer": "überstürzend",
    "überstürzenderes": "überstürzend",
    "überstürzendes": "überstürzend",
    "überstürzendste": "überstürzend",
    "überstürzendstem": "überstürzend",
    "überstürzendsten": "überstürzend",
    "überstürzendster": "überstürzend",
    "überstürzendstes": "überstürzend",
    "überstürzest": "überstürzen",
    "überstürzet": "überstürzen",
    "überstürzt": "überstürzen",
    "überstürzte": "überstürzt",
    "überstürztem": "überstürzt",
    "überstürzten": "überstürzt",
    "überstürzter": "überstürzt",
    "überstürztere": "überstürzt",
    "überstürzterem": "überstürzt",
    "überstürzteren": "überstürzt",
    "überstürzterer": "überstürzt",
    "überstürzteres": "überstürzt",
    "überstürztes": "überstürzt",
    "überstürztest": "überstürzen",
    "überstürzteste": "überstürzt",
    "überstürztestem": "überstürzt",
    "überstürztesten": "überstürzt",
    "überstürztester": "überstürzt",
    "überstürztestes": "überstürzt",
    "überstürztet": "überstürzen",
    "übersähe": "übersehen",
    "übersähen": "übersehen",
    "übersähest": "übersehen",
    "übersähet": "übersehen",
    "übersättige": "übersättigen",
    "übersättigend": "übersättigen",
    "übersättigende": "übersättigend",
    "übersättigendem": "übersättigend",
    "übersättigenden": "übersättigend",
    "übersättigender": "übersättigend",
    "übersättigendere": "übersättigend",
    "übersättigenderem": "übersättigend",
    "übersättigenderen": "übersättigend",
    "übersättigenderer": "übersättigend",
    "übersättigenderes": "übersättigend",
    "übersättigendes": "übersättigend",
    "übersättigendste": "übersättigend",
    "übersättigendstem": "übersättigend",
    "übersättigendsten": "übersättigend",
    "übersättigendster": "übersättigend",
    "übersättigendstes": "übersättigend",
    "übersättigest": "übersättigen",
    "übersättiget": "übersättigen",
    "übersättigst": "übersättigen",
    "übersättigt": "übersättigen",
    "übersättigte": "übersättigt",
    "übersättigtem": "übersättigt",
    "übersättigten": "übersättigt",
    "übersättigter": "übersättigt",
    "übersättigtere": "übersättigt",
    "übersättigterem": "übersättigt",
    "übersättigteren": "übersättigt",
    "übersättigterer": "übersättigt",
    "übersättigteres": "übersättigt",
    "übersättigtes": "übersättigt",
    "übersättigtest": "übersättigen",
    "übersättigteste": "übersättigt",
    "übersättigtestem": "übersättigt",
    "übersättigtesten": "übersättigt",
    "übersättigtester": "übersättigt",
    "übersättigtestes": "übersättigt",
    "übersättigtet": "übersättigen",
    "übersäuere": "übersäuern",
    "übersäuernd": "übersäuern",
    "übersäuernde": "übersäuernd",
    "übersäuerndem": "übersäuernd",
    "übersäuernden": "übersäuernd",
    "übersäuernder": "übersäuernd",
    "übersäuerndere": "übersäuernd",
    "übersäuernderem": "übersäuernd",
    "übersäuernderen": "übersäuernd",
    "übersäuernderer": "übersäuernd",
    "übersäuernderes": "übersäuernd",
    "übersäuerndes": "übersäuernd",
    "übersäuerndste": "übersäuernd",
    "übersäuerndstem": "übersäuernd",
    "übersäuerndsten": "übersäuernd",
    "übersäuerndster": "übersäuernd",
    "übersäuerndstes": "übersäuernd",
    "übersäuerst": "übersäuern",
    "übersäuert": "übersäuern",
    "übersäuerte": "übersäuert",
    "übersäuertem": "übersäuert",
    "übersäuerten": "übersäuert",
    "übersäuerter": "übersäuert",
    "übersäuertere": "übersäuert",
    "übersäuerterem": "übersäuert",
    "übersäuerteren": "übersäuert",
    "übersäuerterer": "übersäuert",
    "übersäuerteres": "übersäuert",
    "übersäuertes": "übersäuert",
    "übersäuertest": "übersäuern",
    "übersäuerteste": "übersäuert",
    "übersäuertestem": "übersäuert",
    "übersäuertesten": "übersäuert",
    "übersäuertester": "übersäuert",
    "übersäuertestes": "übersäuert",
    "übersäuertet": "übersäuern",
    "übertarifliche": "übertariflich",
    "übertariflichem": "übertariflich",
    "übertariflichen": "übertariflich",
    "übertariflicher": "übertariflich",
    "übertarifliches": "übertariflich",
    "überteuerte": "überteuert",
    "überteuertem": "überteuert",
    "überteuerten": "überteuert",
    "überteuerter": "überteuert",
    "überteuertere": "überteuert",
    "überteuerterem": "überteuert",
    "überteuerteren": "überteuert",
    "überteuerterer": "überteuert",
    "überteuerteres": "überteuert",
    "überteuertes": "überteuert",
    "überteuerteste": "überteuert",
    "überteuertestem": "überteuert",
    "überteuertesten": "überteuert",
    "überteuertester": "überteuert",
    "überteuertestes": "überteuert",
    "übertraf": "übertreffen",
    "übertrafen": "übertreffen",
    "übertrafst": "übertreffen",
    "übertraft": "übertreffen",
    "übertragbare": "übertragbar",
    "übertragbarem": "übertragbar",
    "übertragbaren": "übertragbar",
    "übertragbarer": "übertragbar",
    "übertragbares": "übertragbar",
    "übertragend": "übertragen",
    "übertragende": "übertragend",
    "übertragendem": "übertragend",
    "übertragenden": "übertragend",
    "übertragender": "übertragend",
    "übertragendes": "übertragend",
    "übertragene": "übertragen",
    "übertragenem": "übertragen",
    "übertragenen": "übertragen",
    "übertragener": "übertragen",
    "übertragenes": "übertragen",
    "übertragest": "übertragen",
    "übertraget": "übertragen",
    "übertragt": "übertragen",
    "übertrat": "übertreten",
    "übertraten": "übertreten",
    "übertratest": "übertreten",
    "übertratet": "übertreten",
    "übertreffe": "übertreffen",
    "übertreffend": "übertreffen",
    "übertreffende": "übertreffend",
    "übertreffendem": "übertreffend",
    "übertreffenden": "übertreffend",
    "übertreffender": "übertreffend",
    "übertreffendes": "übertreffend",
    "übertreffest": "übertreffen",
    "übertreffet": "übertreffen",
    "übertrefft": "übertreffen",
    "übertreibe": "übertreiben",
    "übertreibend": "übertreiben",
    "übertreibende": "übertreibend",
    "übertreibendem": "übertreibend",
    "übertreibenden": "übertreibend",
    "übertreibender": "übertreibend",
    "übertreibendere": "übertreibend",
    "übertreibenderem": "übertreibend",
    "übertreibenderen": "übertreibend",
    "übertreibenderer": "übertreibend",
    "übertreibenderes": "übertreibend",
    "übertreibendes": "übertreibend",
    "übertreibendste": "übertreibend",
    "übertreibendstem": "übertreibend",
    "übertreibendsten": "übertreibend",
    "übertreibendster": "übertreibend",
    "übertreibendstes": "übertreibend",
    "übertreibest": "übertreiben",
    "übertreibet": "übertreiben",
    "übertreibst": "übertreiben",
    "übertreibt": "übertreiben",
    "übertrete": "übertreten",
    "übertretend": "übertreten",
    "übertretende": "übertretend",
    "übertretendem": "übertretend",
    "übertretenden": "übertretend",
    "übertretender": "übertretend",
    "übertretendes": "übertretend",
    "übertretene": "übertreten",
    "übertretenem": "übertreten",
    "übertretenen": "übertreten",
    "übertretener": "übertreten",
    "übertretenes": "übertreten",
    "übertretest": "übertreten",
    "übertretet": "übertreten",
    "übertrieb": "übertreiben",
    "übertriebe": "übertreiben",
    "übertrieben": "übertreiben",
    "übertriebene": "übertrieben",
    "übertriebenem": "übertrieben",
    "übertriebenen": "übertrieben",
    "übertriebener": "übertrieben",
    "übertriebenere": "übertrieben",
    "übertriebenerem": "übertrieben",
    "übertriebeneren": "übertrieben",
    "übertriebenerer": "übertrieben",
    "übertriebeneres": "übertrieben",
    "übertriebenes": "übertrieben",
    "übertriebenste": "übertrieben",
    "übertriebenstem": "übertrieben",
    "übertriebensten": "übertrieben",
    "übertriebenster": "übertrieben",
    "übertriebenstes": "übertrieben",
    "übertriebest": "übertreiben",
    "übertriebet": "übertreiben",
    "übertriebst": "übertreiben",
    "übertriebt": "übertreiben",
    "übertriffst": "übertreffen",
    "übertrifft": "übertreffen",
    "übertritt": "übertreten",
    "übertrittst": "übertreten",
    "übertroffen": "übertreffen",
    "übertroffene": "übertroffen",
    "übertroffenem": "übertroffen",
    "übertroffenen": "übertroffen",
    "übertroffener": "übertroffen",
    "übertroffenes": "übertroffen",
    "übertrug": "übertragen",
    "übertrugen": "übertragen",
    "übertrugst": "übertragen",
    "übertrugt": "übertragen",
    "übertrumpfe": "übertrumpfen",
    "übertrumpfend": "übertrumpfen",
    "übertrumpfende": "übertrumpfend",
    "übertrumpfendem": "übertrumpfend",
    "übertrumpfenden": "übertrumpfend",
    "übertrumpfender": "übertrumpfend",
    "übertrumpfendes": "übertrumpfend",
    "übertrumpfest": "übertrumpfen",
    "übertrumpfet": "übertrumpfen",
    "übertrumpfst": "übertrumpfen",
    "übertrumpft": "übertrumpfen",
    "übertrumpfte": "übertrumpft",
    "übertrumpftem": "übertrumpft",
    "übertrumpften": "übertrumpft",
    "übertrumpfter": "übertrumpft",
    "übertrumpftes": "übertrumpft",
    "übertrumpftest": "übertrumpfen",
    "übertrumpftet": "übertrumpfen",
    "überträfe": "übertreffen",
    "überträfen": "übertreffen",
    "überträfest": "übertreffen",
    "überträfet": "übertreffen",
    "überträgst": "übertragen",
    "überträgt": "übertragen",
    "überträte": "übertreten",
    "überträten": "übertreten",
    "überträtest": "übertreten",
    "überträtet": "übertreten",
    "übertrüge": "übertragen",
    "übertrügen": "übertragen",
    "übertrügest": "übertragen",
    "übertrüget": "übertragen",
    "übertölpele": "übertölpeln",
    "übertölpelnd": "übertölpeln",
    "übertölpelnde": "übertölpelnd",
    "übertölpelndem": "übertölpelnd",
    "übertölpelnden": "übertölpelnd",
    "übertölpelnder": "übertölpelnd",
    "übertölpelndes": "übertölpelnd",
    "übertölpelst": "übertölpeln",
    "übertölpelt": "übertölpeln",
    "übertölpelte": "übertölpelt",
    "übertölpeltem": "übertölpelt",
    "übertölpelten": "übertölpelt",
    "übertölpelter": "übertölpelt",
    "übertölpeltes": "übertölpelt",
    "übertölpeltest": "übertölpeln",
    "übertölpeltet": "übertölpeln",
    "übertölple": "übertölpeln",
    "übertöne": "übertönen",
    "übertönend": "übertönen",
    "übertönende": "übertönend",
    "übertönendem": "übertönend",
    "übertönenden": "übertönend",
    "übertönender": "übertönend",
    "übertönendes": "übertönend",
    "übertönest": "übertönen",
    "übertönet": "übertönen",
    "übertönst": "übertönen",
    "übertönt": "übertönen",
    "übertönte": "übertönt",
    "übertöntem": "übertönt",
    "übertönten": "übertönt",
    "übertönter": "übertönt",
    "übertöntes": "übertönt",
    "übertöntest": "übertönen",
    "übertöntet": "übertönen",
    "übertünche": "übertünchen",
    "übertünchend": "übertünchen",
    "übertünchende": "übertünchend",
    "übertünchendem": "übertünchend",
    "übertünchenden": "übertünchend",
    "übertünchender": "übertünchend",
    "übertünchendes": "übertünchend",
    "übertünchest": "übertünchen",
    "übertünchet": "übertünchen",
    "übertünchst": "übertünchen",
    "übertüncht": "übertünchen",
    "übertünchte": "übertüncht",
    "übertünchtem": "übertüncht",
    "übertünchten": "übertüncht",
    "übertünchter": "übertüncht",
    "übertünchtes": "übertüncht",
    "übertünchtest": "übertünchen",
    "übertünchtet": "übertünchen",
    "überversichere": "überversichern",
    "überversichernd": "überversichern",
    "überversichernde": "überversichernd",
    "überversicherndem": "überversichernd",
    "überversichernden": "überversichernd",
    "überversichernder": "überversichernd",
    "überversicherndes": "überversichernd",
    "überversicherst": "überversichern",
    "überversichert": "überversichern",
    "überversicherte": "überversichert",
    "überversichertem": "überversichert",
    "überversicherten": "überversichert",
    "überversicherter": "überversichert",
    "überversichertes": "überversichert",
    "überversichertest": "überversichern",
    "überversichertet": "überversichern",
    "übervorsichtige": "übervorsichtig",
    "übervorsichtigem": "übervorsichtig",
    "übervorsichtigen": "übervorsichtig",
    "übervorsichtiger": "übervorsichtig",
    "übervorsichtiges": "übervorsichtig",
    "übervorteile": "übervorteilen",
    "übervorteilend": "übervorteilen",
    "übervorteilende": "übervorteilend",
    "übervorteilendem": "übervorteilend",
    "übervorteilenden": "übervorteilend",
    "übervorteilender": "übervorteilend",
    "übervorteilendes": "übervorteilend",
    "übervorteilest": "übervorteilen",
    "übervorteilet": "übervorteilen",
    "übervorteilst": "übervorteilen",
    "übervorteilt": "übervorteilen",
    "übervorteilte": "übervorteilt",
    "übervorteiltem": "übervorteilt",
    "übervorteilten": "übervorteilt",
    "übervorteilter": "übervorteilt",
    "übervorteiltes": "übervorteilt",
    "übervorteiltest": "übervorteilen",
    "übervorteiltet": "übervorteilen",
    "überwache": "überwachen",
    "überwachend": "überwachen",
    "überwachende": "überwachend",
    "überwachendem": "überwachend",
    "überwachenden": "überwachend",
    "überwachender": "überwachend",
    "überwachendes": "überwachend",
    "überwachest": "überwachen",
    "überwachet": "überwachen",
    "überwachst": "überwachen",
    "überwacht": "überwachen",
    "überwachte": "überwacht",
    "überwachtem": "überwacht",
    "überwachten": "überwacht",
    "überwachter": "überwacht",
    "überwachtes": "überwacht",
    "überwachtest": "überwachen",
    "überwachtet": "überwachen",
    "überwalle": "überwallen",
    "überwallend": "überwallen",
    "überwallende": "überwallend",
    "überwallendem": "überwallend",
    "überwallenden": "überwallend",
    "überwallender": "überwallend",
    "überwallendere": "überwallend",
    "überwallenderem": "überwallend",
    "überwallenderen": "überwallend",
    "überwallenderer": "überwallend",
    "überwallenderes": "überwallend",
    "überwallendes": "überwallend",
    "überwallendste": "überwallend",
    "überwallendstem": "überwallend",
    "überwallendsten": "überwallend",
    "überwallendster": "überwallend",
    "überwallendstes": "überwallend",
    "überwallest": "überwallen",
    "überwallet": "überwallen",
    "überwallst": "überwallen",
    "überwallt": "überwallen",
    "überwallte": "überwallen",
    "überwallten": "überwallen",
    "überwalltest": "überwallen",
    "überwalltet": "überwallen",
    "überwand": "überwinden",
    "überwanden": "überwinden",
    "überwandest": "überwinden",
    "überwandet": "überwinden",
    "überwarf": "überwerfen",
    "überwarfen": "überwerfen",
    "überwarfst": "überwerfen",
    "überwarft": "überwerfen",
    "überweise": "überweisen",
    "überweisend": "überweisen",
    "überweisende": "überweisend",
    "überweisendem": "überweisend",
    "überweisenden": "überweisend",
    "überweisender": "überweisend",
    "überweisendes": "überweisend",
    "überweisest": "überweisen",
    "überweiset": "überweisen",
    "überweist": "überweisen",
    "überwerfe": "überwerfen",
    "überwerfend": "überwerfen",
    "überwerfende": "überwerfend",
    "überwerfendem": "überwerfend",
    "überwerfenden": "überwerfend",
    "überwerfender": "überwerfend",
    "überwerfendes": "überwerfend",
    "überwerfest": "überwerfen",
    "überwerfet": "überwerfen",
    "überwerft": "überwerfen",
    "überwiege": "überwiegen",
    "überwiegend": "überwiegen",
    "überwiegende": "überwiegend",
    "überwiegendem": "überwiegend",
    "überwiegenden": "überwiegend",
    "überwiegender": "überwiegend",
    "überwiegendere": "überwiegend",
    "überwiegenderem": "überwiegend",
    "überwiegenderen": "überwiegend",
    "überwiegenderer": "überwiegend",
    "überwiegenderes": "überwiegend",
    "überwiegendes": "überwiegend",
    "überwiegendste": "überwiegend",
    "überwiegendstem": "überwiegend",
    "überwiegendsten": "überwiegend",
    "überwiegendster": "überwiegend",
    "überwiegendstes": "überwiegend",
    "überwiegest": "überwiegen",
    "überwieget": "überwiegen",
    "überwiegst": "überwiegen",
    "überwiegt": "überwiegen",
    "überwies": "überweisen",
    "überwiese": "überweisen",
    "überwiesen": "überweisen",
    "überwiesene": "überwiesen",
    "überwiesenem": "überwiesen",
    "überwiesenen": "überwiesen",
    "überwiesener": "überwiesen",
    "überwiesenes": "überwiesen",
    "überwiesest": "überweisen",
    "überwieset": "überweisen",
    "überwiest": "überweisen",
    "überwindbare": "überwindbar",
    "überwindbarem": "überwindbar",
    "überwindbaren": "überwindbar",
    "überwindbarer": "überwindbar",
    "überwindbares": "überwindbar",
    "überwinde": "überwinden",
    "überwindend": "überwinden",
    "überwindende": "überwindend",
    "überwindendem": "überwindend",
    "überwindenden": "überwindend",
    "überwindender": "überwindend",
    "überwindendere": "überwindend",
    "überwindenderem": "überwindend",
    "überwindenderen": "überwindend",
    "überwindenderer": "überwindend",
    "überwindenderes": "überwindend",
    "überwindendes": "überwindend",
    "überwindendste": "überwindend",
    "überwindendstem": "überwindend",
    "überwindendsten": "überwindend",
    "überwindendster": "überwindend",
    "überwindendstes": "überwindend",
    "überwindest": "überwinden",
    "überwindet": "überwinden",
    "überwintere": "überwintern",
    "überwinternd": "überwintern",
    "überwinternde": "überwinternd",
    "überwinterndem": "überwinternd",
    "überwinternden": "überwinternd",
    "überwinternder": "überwinternd",
    "überwinterndes": "überwinternd",
    "überwinterst": "überwintern",
    "überwintert": "überwintern",
    "überwinterte": "überwintert",
    "überwintertem": "überwintert",
    "überwinterten": "überwintert",
    "überwinterter": "überwintert",
    "überwintertes": "überwintert",
    "überwintertest": "überwintern",
    "überwintertet": "überwintern",
    "überwirf": "überwerfen",
    "überwirfst": "überwerfen",
    "überwirft": "überwerfen",
    "überwog": "überwiegen",
    "überwogen": "überwiegen",
    "überwogene": "überwogen",
    "überwogenem": "überwogen",
    "überwogenen": "überwogen",
    "überwogener": "überwogen",
    "überwogenes": "überwogen",
    "überwogst": "überwiegen",
    "überwogt": "überwiegen",
    "überworfen": "überwerfen",
    "überworfene": "überworfen",
    "überworfenem": "überworfen",
    "überworfenen": "überworfen",
    "überworfener": "überworfen",
    "überworfenes": "überworfen",
    "überwuchere": "überwuchern",
    "überwuchernd": "überwuchern",
    "überwuchernde": "überwuchernd",
    "überwucherndem": "überwuchernd",
    "überwuchernden": "überwuchernd",
    "überwuchernder": "überwuchernd",
    "überwucherndere": "überwuchernd",
    "überwuchernderem": "überwuchernd",
    "überwuchernderen": "überwuchernd",
    "überwuchernderer": "überwuchernd",
    "überwuchernderes": "überwuchernd",
    "überwucherndes": "überwuchernd",
    "überwucherndste": "überwuchernd",
    "überwucherndstem": "überwuchernd",
    "überwucherndsten": "überwuchernd",
    "überwucherndster": "überwuchernd",
    "überwucherndstes": "überwuchernd",
    "überwucherst": "überwuchern",
    "überwuchert": "überwuchern",
    "überwucherte": "überwuchert",
    "überwuchertem": "überwuchert",
    "überwucherten": "überwuchert",
    "überwucherter": "überwuchert",
    "überwuchertere": "überwuchert",
    "überwucherterem": "überwuchert",
    "überwucherteren": "überwuchert",
    "überwucherterer": "überwuchert",
    "überwucherteres": "überwuchert",
    "überwuchertes": "überwuchert",
    "überwuchertest": "überwuchern",
    "überwucherteste": "überwuchert",
    "überwuchertestem": "überwuchert",
    "überwuchertesten": "überwuchert",
    "überwuchertester": "überwuchert",
    "überwuchertestes": "überwuchert",
    "überwuchertet": "überwuchern",
    "überwunden": "überwinden",
    "überwundene": "überwunden",
    "überwundenem": "überwunden",
    "überwundenen": "überwunden",
    "überwundener": "überwunden",
    "überwundenes": "überwunden",
    "überwältige": "überwältigen",
    "überwältigend": "überwältigen",
    "überwältigende": "überwältigend",
    "überwältigendem": "überwältigend",
    "überwältigenden": "überwältigend",
    "überwältigender": "überwältigend",
    "überwältigendere": "überwältigend",
    "überwältigenderem": "überwältigend",
    "überwältigenderen": "überwältigend",
    "überwältigenderer": "überwältigend",
    "überwältigenderes": "überwältigend",
    "überwältigendes": "überwältigend",
    "überwältigendste": "überwältigend",
    "überwältigendstem": "überwältigend",
    "überwältigendsten": "überwältigend",
    "überwältigendster": "überwältigend",
    "überwältigendstes": "überwältigend",
    "überwältigest": "überwältigen",
    "überwältiget": "überwältigen",
    "überwältigst": "überwältigen",
    "überwältigt": "überwältigen",
    "überwältigte": "überwältigt",
    "überwältigtem": "überwältigt",
    "überwältigten": "überwältigt",
    "überwältigter": "überwältigt",
    "überwältigtere": "überwältigt",
    "überwältigterem": "überwältigt",
    "überwältigteren": "überwältigt",
    "überwältigterer": "überwältigt",
    "überwältigteres": "überwältigt",
    "überwältigtes": "überwältigt",
    "überwältigtest": "überwältigen",
    "überwältigteste": "überwältigt",
    "überwältigtestem": "überwältigt",
    "überwältigtesten": "überwältigt",
    "überwältigtester": "überwältigt",
    "überwältigtestes": "überwältigt",
    "überwältigtet": "überwältigen",
    "überwände": "überwinden",
    "überwänden": "überwinden",
    "überwändest": "überwinden",
    "überwändet": "überwinden",
    "überwärfe": "überwerfen",
    "überwärfen": "überwerfen",
    "überwärfest": "überwerfen",
    "überwärfet": "überwerfen",
    "überwöge": "überwiegen",
    "überwögen": "überwiegen",
    "überwögest": "überwiegen",
    "überwöget": "überwiegen",
    "überzahle": "überzahlen",
    "überzahlend": "überzahlen",
    "überzahlende": "überzahlend",
    "überzahlendem": "überzahlend",
    "überzahlenden": "überzahlend",
    "überzahlender": "überzahlend",
    "überzahlendere": "überzahlend",
    "überzahlenderem": "überzahlend",
    "überzahlenderen": "überzahlend",
    "überzahlenderer": "überzahlend",
    "überzahlenderes": "überzahlend",
    "überzahlendes": "überzahlend",
    "überzahlendste": "überzahlend",
    "überzahlendstem": "überzahlend",
    "überzahlendsten": "überzahlend",
    "überzahlendster": "überzahlend",
    "überzahlendstes": "überzahlend",
    "überzahlest": "überzahlen",
    "überzahlet": "überzahlen",
    "überzahlst": "überzahlen",
    "überzahlt": "überzahlen",
    "überzahlte": "überzahlt",
    "überzahltem": "überzahlt",
    "überzahlten": "überzahlt",
    "überzahlter": "überzahlt",
    "überzahltere": "überzahlt",
    "überzahlterem": "überzahlt",
    "überzahlteren": "überzahlt",
    "überzahlterer": "überzahlt",
    "überzahlteres": "überzahlt",
    "überzahltes": "überzahlt",
    "überzahltest": "überzahlen",
    "überzahlteste": "überzahlt",
    "überzahltestem": "überzahlt",
    "überzahltesten": "überzahlt",
    "überzahltester": "überzahlt",
    "überzahltestes": "überzahlt",
    "überzahltet": "überzahlen",
    "überzeuge": "überzeugen",
    "überzeugend": "überzeugen",
    "überzeugende": "überzeugend",
    "überzeugendem": "überzeugend",
    "überzeugenden": "überzeugend",
    "überzeugender": "überzeugend",
    "überzeugendere": "überzeugend",
    "überzeugenderem": "überzeugend",
    "überzeugenderen": "überzeugend",
    "überzeugenderer": "überzeugend",
    "überzeugenderes": "überzeugend",
    "überzeugendes": "überzeugend",
    "überzeugendste": "überzeugend",
    "überzeugendstem": "überzeugend",
    "überzeugendsten": "überzeugend",
    "überzeugendster": "überzeugend",
    "überzeugendstes": "überzeugend",
    "überzeugest": "überzeugen",
    "überzeuget": "überzeugen",
    "überzeugst": "überzeugen",
    "überzeugt": "überzeugen",
    "überzeugte": "überzeugt",
    "überzeugtem": "überzeugt",
    "überzeugten": "überzeugt",
    "überzeugter": "überzeugt",
    "überzeugtere": "überzeugt",
    "überzeugterem": "überzeugt",
    "überzeugteren": "überzeugt",
    "überzeugterer": "überzeugt",
    "überzeugteres": "überzeugt",
    "überzeugtes": "überzeugt",
    "überzeugtest": "überzeugen",
    "überzeugteste": "überzeugt",
    "überzeugtestem": "überzeugt",
    "überzeugtesten": "überzeugt",
    "überzeugtester": "überzeugt",
    "überzeugtestes": "überzeugt",
    "überzeugtet": "überzeugen",
    "überziehe": "überziehen",
    "überziehend": "überziehen",
    "überziehende": "überziehend",
    "überziehendem": "überziehend",
    "überziehenden": "überziehend",
    "überziehender": "überziehend",
    "überziehendere": "überziehend",
    "überziehenderem": "überziehend",
    "überziehenderen": "überziehend",
    "überziehenderer": "überziehend",
    "überziehenderes": "überziehend",
    "überziehendes": "überziehend",
    "überziehendste": "überziehend",
    "überziehendstem": "überziehend",
    "überziehendsten": "überziehend",
    "überziehendster": "überziehend",
    "überziehendstes": "überziehend",
    "überziehest": "überziehen",
    "überziehet": "überziehen",
    "überziehst": "überziehen",
    "überzieht": "überziehen",
    "überzog": "überziehen",
    "überzogen": "überziehen",
    "überzogene": "überzogen",
    "überzogenem": "überzogen",
    "überzogenen": "überzogen",
    "überzogener": "überzogen",
    "überzogenere": "überzogen",
    "überzogenerem": "überzogen",
    "überzogeneren": "überzogen",
    "überzogenerer": "überzogen",
    "überzogeneres": "überzogen",
    "überzogenes": "überzogen",
    "überzogenste": "überzogen",
    "überzogenstem": "überzogen",
    "überzogensten": "überzogen",
    "überzogenster": "überzogen",
    "überzogenstes": "überzogen",
    "überzogst": "überziehen",
    "überzogt": "überziehen",
    "überzubauen": "überbauen",
    "überzubehalten": "überbehalten",
    "überzubekommen": "überbekommen",
    "überzubraten": "überbraten",
    "überzudenken": "überdenken",
    "überzuessen": "überessen",
    "überzufließen": "überfließen",
    "überzufluten": "überfluten",
    "überzugießen": "übergießen",
    "überzugreifen": "übergreifen",
    "überzuhängen": "überhängen",
    "überzukippen": "überkippen",
    "überzukochen": "überkochen",
    "überzukriegen": "überkriegen",
    "überzuleiten": "überleiten",
    "überzuliegen": "überliegen",
    "überzuordnen": "überordnen",
    "überzuquellen": "überquellen",
    "überzuschlagen": "überschlagen",
    "überzuschnappen": "überschnappen",
    "überzuschwappen": "überschwappen",
    "überzuschäumen": "überschäumen",
    "überzusetzen": "übersetzen",
    "überzuspringen": "überspringen",
    "überzusprudeln": "übersprudeln",
    "überzustreifen": "überstreifen",
    "überzuströmen": "überströmen",
    "überzutreten": "übertreten",
    "überzuwallen": "überwallen",
    "überzuwerfen": "überwerfen",
    "überzuzählen": "überzählen",
    "überzähle": "überzählen",
    "überzählend": "überzählen",
    "überzählende": "überzählend",
    "überzählendem": "überzählend",
    "überzählenden": "überzählend",
    "überzählender": "überzählend",
    "überzählendes": "überzählend",
    "überzählest": "überzählen",
    "überzählet": "überzählen",
    "überzählige": "überzählig",
    "überzähligem": "überzählig",
    "überzähligen": "überzählig",
    "überzähliger": "überzählig",
    "überzähliges": "überzählig",
    "überzählst": "überzählen",
    "überzählt": "überzählen",
    "überzählte": "überzählen",
    "überzählten": "überzählen",
    "überzähltest": "überzählen",
    "überzähltet": "überzählen",
    "überzöge": "überziehen",
    "überzögen": "überziehen",
    "überzögest": "überziehen",
    "überzöget": "überziehen",
    "überzüchte": "überzüchten",
    "überzüchtend": "überzüchten",
    "überzüchtende": "überzüchtend",
    "überzüchtendem": "überzüchtend",
    "überzüchtenden": "überzüchtend",
    "überzüchtender": "überzüchtend",
    "überzüchtendes": "überzüchtend",
    "überzüchtest": "überzüchten",
    "überzüchtet": "überzüchten",
    "überzüchtete": "überzüchtet",
    "überzüchtetem": "überzüchtet",
    "überzüchteten": "überzüchtet",
    "überzüchteter": "überzüchtet",
    "überzüchtetes": "überzüchtet",
    "überzüchtetest": "überzüchten",
    "überzüchtetet": "überzüchten",
    "überängstliche": "überängstlich",
    "überängstlichem": "überängstlich",
    "überängstlichen": "überängstlich",
    "überängstlicher": "überängstlich",
    "überängstliches": "überängstlich",
    "überäße": "überessen",
    "überäßen": "überessen",
    "überäßest": "überessen",
    "überäßet": "überessen",
    "übest": "üben",
    "übet": "üben",
    "üble": "übel",
    "üblem": "übel",
    "üblen": "übel",
    "übler": "übel",
    "üblere": "übel",
    "üblerem": "übel",
    "übleren": "übel",
    "üblerer": "übel",
    "übleres": "übel",
    "übles": "übel",
    "übliche": "üblich",
    "üblichem": "üblich",
    "üblichen": "üblich",
    "üblicher": "üblich",
    "üblichere": "üblich",
    "üblicherem": "üblich",
    "üblicheren": "üblich",
    "üblicherer": "üblich",
    "üblicheres": "üblich",
    "übliches": "üblich",
    "üblichste": "üblich",
    "üblichstem": "üblich",
    "üblichsten": "üblich",
    "üblichster": "üblich",
    "üblichstes": "üblich",
    "übrigbehalte": "übrigbehalten",
    "übrigbehaltend": "übrigbehalten",
    "übrigbehaltende": "übrigbehaltend",
    "übrigbehaltendem": "übrigbehaltend",
    "übrigbehaltenden": "übrigbehaltend",
    "übrigbehaltender": "übrigbehaltend",
    "übrigbehaltendes": "übrigbehaltend",
    "übrigbehaltene": "übrigbehalten",
    "übrigbehaltenem": "übrigbehalten",
    "übrigbehaltenen": "übrigbehalten",
    "übrigbehaltener": "übrigbehalten",
    "übrigbehaltenes": "übrigbehalten",
    "übrigbehaltest": "übrigbehalten",
    "übrigbehaltet": "übrigbehalten",
    "übrigbehielt": "übrigbehalten",
    "übrigbehielte": "übrigbehalten",
    "übrigbehielten": "übrigbehalten",
    "übrigbehieltest": "übrigbehalten",
    "übrigbehieltet": "übrigbehalten",
    "übrigbehält": "übrigbehalten",
    "übrigbehältst": "übrigbehalten",
    "übrigbleibe": "übrigbleiben",
    "übrigbleibend": "übrigbleiben",
    "übrigbleibende": "übrigbleibend",
    "übrigbleibendem": "übrigbleibend",
    "übrigbleibenden": "übrigbleibend",
    "übrigbleibender": "übrigbleibend",
    "übrigbleibendes": "übrigbleibend",
    "übrigbleibest": "übrigbleiben",
    "übrigbleibet": "übrigbleiben",
    "übrigbleibst": "übrigbleiben",
    "übrigbleibt": "übrigbleiben",
    "übrigblieb": "übrigbleiben",
    "übrigbliebe": "übrigbleiben",
    "übrigblieben": "übrigbleiben",
    "übrigbliebest": "übrigbleiben",
    "übrigbliebet": "übrigbleiben",
    "übrigbliebst": "übrigbleiben",
    "übrigbliebt": "übrigbleiben",
    "übrige": "übrig",
    "übrigem": "übrig",
    "übrigen": "übrig",
    "übriger": "übrig",
    "übriges": "übrig",
    "übriggeblieben": "übrigbleiben",
    "übriggebliebene": "übriggeblieben",
    "übriggebliebenem": "übriggeblieben",
    "übriggebliebenen": "übriggeblieben",
    "übriggebliebener": "übriggeblieben",
    "übriggebliebenes": "übriggeblieben",
    "übrigzubehalten": "übrigbehalten",
    "übrigzubleiben": "übrigbleiben",
    "übst": "üben",
    "übt": "üben",
    "übte": "üben",
    "übten": "üben",
    "übtest": "üben",
    "übtet": "üben",
    "üppige": "üppig",
    "üppigem": "üppig",
    "üppigen": "üppig",
    "üppiger": "üppig",
    "üppigere": "üppig",
    "üppigerem": "üppig",
    "üppigeren": "üppig",
    "üppigerer": "üppig",
    "üppigeres": "üppig",
    "üppiges": "üppig",
    "üppigste": "üppig",
    "üppigstem": "üppig",
    "üppigsten": "üppig",
    "üppigster": "üppig",
    "üppigstes": "üppig"
}
